(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 11.1' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[   9641942,     174962]
NotebookOptionsPosition[   9516425,     172249]
NotebookOutlinePosition[   9617872,     174398]
CellTagsIndexPosition[   9616324,     174342]
WindowTitle->Machine Learning: Elementary Introduction to the Wolfram \
Language
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[BoxData[
 InterpretationBox[Cell[
  "Machine Learning", "SectionInline",ExpressionUUID->
   "70ddfba7-9c46-4c07-80b4-a54e08ad2289"],
  $Line = 0; Null]], "SectionDoubleDigit",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CounterAssignments->{{"Section", 21}, {"Subsection", 0}, {
   "Subsubsection", 0}, {"Exercise", 0}},
 CellTags->"p:123",
 CellLabel->"In[1]:=",ExpressionUUID->"05fd2f4f-5bfb-4f04-979d-a3ff8480e23b"],

Cell[TextData[{
 "So far in this book, when we\[CloseCurlyQuote]ve wanted the Wolfram \
Language to do something, we\[CloseCurlyQuote]ve written code to tell it \
exactly what to do. But the Wolfram Language is also set up to be able to \
learn what to do just by looking at examples, using the idea of ",
 StyleBox["machine learning",
  FontSlant->"Italic"],
 ". "
}], "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:1",ExpressionUUID->"52a3adbb-d1d8-451a-833c-b151ac46c68b"],

Cell["\<\
We\[CloseCurlyQuote]ll talk about how to train the language yourself. But \
first let\[CloseCurlyQuote]s look at some built-in functions that have \
already been trained on huge numbers of examples.\
\>", "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"0a7295eb-4df9-473b-956a-dfaa59849cf0"],

Cell[TextData[{
 ButtonBox["LanguageIdentify",
  BaseStyle->"Link"],
 " takes pieces of text, and identifies what human language ",
 "they\[CloseCurlyQuote]re",
 " in."
}], "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:2",ExpressionUUID->"06bba364-0c4c-4db1-aefd-ffd8cc702fa9"],

Cell["Identify the language each phrase is in:", "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:3",ExpressionUUID->"0629a67c-2659-4616-af1a-583ee0cc67d4"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"LanguageIdentify", "[", 
  RowBox[{"{", " ", 
   RowBox[{
   "\"\<thank you\>\"", ",", "\"\<merci\>\"", ",", "\"\<dar las gracias\>\"", 
    ",", "\"\<\:611f\:8b1d\>\"", ",", 
    "\"\<\:0431\:043b\:0430\:0433\:043e\:0434\:0430\:0440\:0438\:0442\:044c\>\
\""}], "}"}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[1]:=",ExpressionUUID->"4d9e6a71-aafd-4d93-b26f-83defc43a5aa"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   TemplateBox[{"\"English\"",RowBox[{"Entity", "[", 
       RowBox[{"\"Language\"", ",", "\"English\""}], "]"}],
     "\"Entity[\\\"Language\\\", \\\"English\\\"]\"","\"language\""},
    "Entity"], ",", 
   TemplateBox[{"\"French\"",RowBox[{"Entity", "[", 
       RowBox[{"\"Language\"", ",", "\"French\""}], "]"}],
     "\"Entity[\\\"Language\\\", \\\"French\\\"]\"","\"language\""},
    "Entity"], ",", 
   TemplateBox[{"\"Spanish\"",RowBox[{"Entity", "[", 
       RowBox[{"\"Language\"", ",", "\"Spanish\""}], "]"}],
     "\"Entity[\\\"Language\\\", \\\"Spanish\\\"]\"","\"language\""},
    "Entity"], ",", 
   TemplateBox[{"\"Chinese\"",RowBox[{"Entity", "[", 
       RowBox[{"\"Language\"", ",", "\"Chinese\""}], "]"}],
     "\"Entity[\\\"Language\\\", \\\"Chinese\\\"]\"","\"language\""},
    "Entity"], ",", 
   TemplateBox[{"\"Russian\"",RowBox[{"Entity", "[", 
       RowBox[{"\"Language\"", ",", "\"Russian\""}], "]"}],
     "\"Entity[\\\"Language\\\", \\\"Russian\\\"]\"","\"language\""},
    "Entity"]}], "}"}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[1]=",ExpressionUUID->"28a5480e-df5f-421b-83b9-ae6d494b736f"]
}, Open  ]],

Cell["\<\
The Wolfram Language can also do the considerably more difficult \
\[OpenCurlyDoubleQuote]artificial intelligence\[CloseCurlyDoubleQuote] task \
of identifying what an image is of.\
\>", "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:4",ExpressionUUID->"4fb0b2cd-fe3b-4c21-b0d4-3b3356290189"],

Cell["Identify what an image is of:", "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:5",ExpressionUUID->"da59d4ed-3832-44ec-8225-4be5ac31156e"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ImageIdentify", "[", 
  GraphicsBox[
   TagBox[RasterBox[CompressedData["
1:eJxMu1eQLGd6pkdJN7rUjYKxHHLIGQyA49u78t57X5Xlvcny3nvvvetqb47p
Y4GD4wAceAwwGM5wDHYY5HKkXUmhUEgKiaLIFSkt9TdAMRTxdEZ2dnVHV1c+
//t+Wdk/0rsF5v/8D/7gD/z/JdgIdGG8z6eLCv8r8InY5bdZXCYj3RUwWUy+
bf1/AQ7+Fnzg/rM/+IPLffWUDg2Ikg5S1FiTNG5B7eu6wXXL5Lp+8Kau+yNV
+49V7R+qO3+q7r3xHT+R1XHyCk6Wx/AjOyzHKs2wzNCucLXrDOgWSfITvOSH
ONkfYVV/iNP+1wTLH9JcP6A5t7gBHJRh2VqKwNQQ3TdGDzTRPVlozvH0yPYq
2pbDODJkZ5IFR3i2IN/SkPhH2sTCnF5Y0rvG1FSfHGmiHWWkAflLMldGAqdk
ppAEcvGkNi5AZsBLNDixEi2QIPn8HR5ni8/aFjC3RVykgI9i87cp3FUM+wZG
cJOk2mSZ0CI/Aorh9RmGLsvV5/i6jAhK8EUBJsGExhmQKC0CqdlBaLcA2+qN
LdX6unV7y4FG2LAoMw5vJlGtdIaRSVXR+HquWM9XmMRaq1xhEAgVDBHEVBr4
Gi0klgqoLDKWikKSEQjK9iZpbYWwtIS7uUy4sUa4uYq9voq5toG5jsAvYSnr
KPxNBObmBura6s7V5c0rNzcuuQ52dq6vgOOkpR3aCoK9guGv4MWrRPkGWbMN
AM8Fr1jDilewwmWCcIUkXGWIt7gypBjCylUkOUSUKQhyOR4gVaOkarRMg5Op
SRKIzJdROCIKS0AiszFkDprCRTHFaJ4Kr7BSDV62LcL35A3+kjlcs0cbcKzu
CJcsvqzenVC7YwqrV2CA2SaYbXFxLTDH6uTa3XxngOEOc3xJcSCvjFSMiY4z
N44Ud9PlvSzY5ufx/CSa7vlidZsvp4YTUkNApHZzRRYqU4snQkicfAer2EFD
WyQ9hmUnSUMsTUpgLUq9bVVyai0eumq3C5WzXOU4Uz1ONY5S9f1EbR6tToOl
ka849OZ6zkzHkW7b011Hpgdnhq5C05NvXZJtedItZ6Jpi7Ys4ZYx1DGAn+lq
K7wDRWCmCu6q3BOJrcdxDuXmJkdbJpnqBO+QmToQFY5VxSNt7QyuHHvyC09y
4owObOGBOTa2xOe2YFcdGeiiQ32op/HUJbYC15phWTMcY4xuS/PAKRpralNt
U7JpjtVM4bLemhSYYlxtkKXy0VVeltrHVXuFaq+Yb2DydByejiu1KPQ+C5zw
+XKRQD4RLaQ8CZ8poFPCXKEJy9StsgxLPOs6z7EpD2DVcbIyiodiGGUCqYiv
C0I3/tVfcX1NXL/5nb83LZObwF9t58+UrT9RNH6gbP2psvMjIC9A2SBAVZw0
hxaGd9jwGt24QtcsM5XLRNHbWP6P0Pw/xsn+GKf6AUH/b6i2P2Z5fySJU4G8
horI1deEFub4oTl2qI3ty4G/3j4FrmPhIt5doPtyQn9a6onLHS1ZcKJP7dsz
e9b0rjk7M6SGunhbGarJfXmpOy2Dk3JzWKpy8qR2DvAXMpNkBuKlwnKMRIIR
C1ESPhogEqCFAjRXiKAK1gn8ZZJsjWlEC5zgDEFrUmRjkWMuCyxliakk1WTE
kiiX6aJQHASCBYO3YEh2PAUmEmEc3o5Be/F4HxHnJmJteOAvxUJjmZksPVNq
FUNWicYu1zsUkJEvVjLkWo7OJlJp5SIph8om4mhIJHUHQdvapK6vkVZWiDcB
q/gby+irtxBvLe+8tY68uoW5sYW99p28by9tvnVzA3DlxtbVG9vXbiFurGBv
AX+3GatIzipGuE6UbVGU2zQ9kqpDULQ7QGGCbJ0gWSNL1mnSTaZ8mwehRSqc
VIWXQjipAguQQWBlQ0hUSJEKI1Ti+XICW0Sg83AUDpbAQBJZSCIXSRej+WqC
0k43+bmOmNBbMP7//Y2Urf6cwZPUeOIqi0+ktTF0VrrextBb6AYrA1hs8dEc
IY4nIfHlVGHgb9udmUTyu4nsLJGZRtPjcHLoj3edwarRnYVscbHOx5M7GXwT
gapEYuWbKOk6Ur6BUmzidQiGHS8OMbUZPnhdfB11YmYG/lbOMuXTdPU0XTtJ
14/TjYN4fTcC/C2P/f/qb6pjv6QPpwfOTM2dbbjSDVey4UzU7WDdCNfN/obe
29B4mipPV+kfqUO7mvCexr+rAAo7+xJLi2uu0+AOLTrnFk8Vtdva+m1z846r
duor7nvSUzg6sIQHxtjEnJyDHXVsrAOAHeCvo8R35C+xZ/jOvChYgRItY7Zn
zXRs8boxVNKYExx9mKX205ReAEPl5ag8PJVHdOmvnsXX82Q2ucFvdia/87cQ
C2Zi7rjXEtCrXXyRGXfpr36Fb9sQOBEyPw4KkxRhvDyChuIIWXRd4L+hndKU
I4Ks/a/+3gT+mse39P231J0fyet/LK3+kaT2A0Xrz1TdN1S9t9St7/zNIITh
La5rg2VcpUE3yZJraNaPEMwforl/QlT8mGF8m+W4IgzchJJr1rbC3lG5h/rg
3Bo7hBPH9sSxMXGoDM/5gRHd0yJ5a7RQlR+tKmIlbayg9/Q00aklfeDI7juy
u7bs1JQcaGMtlb8gdWdEzqQETsiAv+DZyW2X/sotJKmJJNXiwXkrluNkMpxM
gpdLCRIxTiTB8KVoumSbKttk6pBAXkWIDSXxhgLT0RDDbbmzrYSbamNFocqK
RVEO20elOPFUF4ETpPNjHH6czQ7TaTE6PcakBuh4OwFrwFJMZI6VKbJy1R6Z
3g0ZPQqjU6Y08WRausrEMbukCq1IKGfS+QQCG41jIzFsBIK1ucVY36SvbdJW
gY8gf5eQby9tv7my/dYa4sr38t7cfPPa6htXV358df2t61tXQfjeQt1cxS2t
k1e3mKtI7jpOtE1SomhaDMOMu8SIpepQZNXOpdHKHZYKyVGheGq0SIMFqoI2
IlagJBBapsKKNFsi9Y5QheQrMWwphi5EktgILGMHRd3EMDbx3G2aBMXX4pUO
hjnEB/noLZj9JWuo6ojVnNGa/fv89aa0zpjS7BVqrEyliaYykiE9EWy1FprO
QzcF2OAbfXlNqGGN971A28J+KjOPpaahxDgQH7qiPXugrnPlZSCMNAG2zEXj
GDFE5QZaurojXUEp1tGqTZIRyXISpBGmLie012SBHvDXmD90lM+SgNpZqnGe
ap2n2yfJxl6kMgtUJv7S6NJfkLzJti3esSW69mTPEa85v8MBfvlQzRKomHwV
vbuiBf762prAQB+e6cMLgDawq/LPlXBP7Gjz7W2Gb8TKHEkaF9ruQ1P/gaN7
z9U89Zb33cmxNdzVB7taELuxiT46huITdWKqiQ5U/pbcVZW4y1JPReavQoBw
VZPqmPNDR65vi9V1/oJMH2FoQ8BcCuShQh660sNUurmgPfINdJ6eITDw5HaZ
MWhypbz+PPA36o4F4AgM/NW4BWILnqlb4xjXRDBC6kZLvXiJD4AFGSSPoESB
FbbrqnZGAf7Kuwjgr6S+BPzV9pZMwyV9/5qq9Yak/EfCwh8Kyz+Q1v9U0Qb+
XtG0cFAZJU5v8YMbXHiVaVgiy65heT9B0H+IZPwpQfgWR78k826rY1hLkepq
sUN7dkB43xk78iRPvekzd+rMmjzVRBfi8JQd6DFCbXasKU42tZmGNVO1h0am
5ALOH7rz+67s3JGbWFI9XaSqvJQ3IQQBYY9JzEGJ2smTWdkyK0dsJIoMBKEO
J1RiRQqQwjiJjCCVE6UQSQzhQSSxIARTg+BacbIAU5Pg6Yo0W5Pn6cu9Y7V3
pPWODPaORl+RyzNCXphBcxOoXiIvxpJmhZIMjx9nshIsTorDCjMIDjzWgKaa
iEKYA7mFpiBkCSrNfrnBKVKamQoDDZzbJrCq6LkCNYMpxVNEaJIQRRChcCIk
RrCDFSLQ3C0kY2ObvLKBvwn6MwDk7zr6xgri6rWNn7y18qM3l3/85sobVzeu
Xtu+fhNzaxm/tE5d22ZuIAXbOCmSqsYzDESGlcSykJgW/PcK07Qopg7N0WN5
OrRAjxHqMEI1SqBECC5jFyXTYMT6LbFuR6BDcFUIpgxBFmxj2esoxtoWaRlB
W8Fw1qlSFF9PUDqZhrDAlpK6c0ZP3uQrWoJFa6Bg8eVMnrTeldTaw3KDR6Cx
s1RWBmSkXi6YWjwERHYzdEGePaPw1cyxgTczjxSOUuXzXOksWzhJ5g4j2UUg
NXdGhyZ/U+UsS7UxtiJA5TlwFMMWTrOB020SjTskK4rpJgpCNCjNNVfEoOUG
R5rkriF7YCmeREqn0dp5vHUn1bmT7pwnG4eR2m6gOg2Ux77cwAX8BfLG2tYY
iLwuqA0uQKTuDNZs/orFXTY4imp7Uelt6f19fXhqju6aQ7uGwEzjn6q9U5Wz
K4Q7PHefHZ3zi6fy9gPt4JFp+MDeuws3T+Di3B7vG3xNBYhaX1sa6stjU0li
pkjOVfGxMtRVgC8F6qpQUxftmMMNQ7ihu/R3ZMv0TaEqBGe4miBV5SdDnksu
I9jDhNwshZMtNDOEJqbYwle5IEvE7Ml6/YWAPx+yBWCLH0y66u/95ejWuaZN
iQuj8BLFbpwARgtcGLEXIwki+N5VpuOaekJUD/GKHlLaWpM2lqHWkqa7bOgv
67o3lY23xKU/EeT/iF/4gbj2Z/LWW8ruVU0dpShsixIb/MAyB15mGG6QZG9j
uD8G8mI5b9AVtxROrCXJ8lbF0YEmszAlzgLxU3/sxAe2iXNf+rYnfW5Lnerj
h7L4Qhgdc6M9frIjT7f1uZa90HQldp25fXfx0FvYc+dncHZsTbT1wZICyGuP
CqwhgBCcSJCdLTUxAUIjga/H8bVYngorgHCXCiuIEogkVRFFaiJfjeNqMRwL
TuSmKKJsTUZoarDhgdg7hfxzjX9m8M9M8EBrakLqokSYZDMCJGaQLEwypXme
OMvhJeicBFOYvsxihpdEc+B5LpoqKDTFIGsEsoZlJp9IB7OUFiqo8UorSWUj
87VEjgrHUKDJMhRJiiRegiJIwBaDFyKxnEuFEdQ1JHUNRV4FbOKX1zA3b25f
eXv9DSDvm2tvXdm8emX7+hJueZW0vk7f3OEi0GI0QYGj6UgsE41pI/8LZiLd
gKMbMCwjjmfG8U04oREnMmKFOrRQswOQ6FFyA0Zk3hQatwSGHa5mmy7fIArW
0OzVHfrSFvXmNmMZw9+gKlB8I0nhYekjAnNC7Ejp4bTBnTYCXCkDnNA4Yip7
VGkOgr7B1zq5ALWNKTdSwNgCmSlQkGdIKtw1S3Tszx8mq3cKzYe1zjv17ru1
9jvl+sNs9V60dBYAbQqEV3AAmXN8XZqtCFMFPjzHjWN78bwAiR+myFJsVZ5n
rIqdHYVvqIpMtamFPntgKp4GKqfB2nm4fS/eu0j27iTbJ9Hmfri+CFZmvsLI
A8Ze4G+0fUmsY492/JGOJ9R2B1oOX8PmqhnhitZaVrlbel/fGJ5aYru28K41
MDX4xjqwhjuaPLjN9vbY8TmvdCptXyj7D3T9++bhPUf7xFGYm6Idpaciclf4
3qYg0BFGJtz4TJRaKJJTZWyoDvc0kZ4p0bcl+zBYQ6ItU6JrTg1M8bbaDZ5O
hKj0ERUeAuBf/PUyFC66DKZLbEyJjS2z87Q+hS1u8mRdvrzHm/MYPWa9S6t1
ylUwF/jL02/zLTtyN17ppwphAteK4dqBwmi+e4fjBP7eUI+wqiFK2UNAnU1l
e03VWlW1lzWtW9r2ElS/Ii7+mJv7E37hT0WVN6StK/LONXV1R1HclCbX+cEl
DnyDYbhGha6QxFeIois0+ZLYjDJHOIGqOtG35Beu2kkwczeSvBNK3A4CkZO3
/cnbnuS5NXGqSxzJ4/vi+FyQGIlTfSjXNZd6rmovmNv3Fo8CpcNAfuHJTR25
oRX0EF9WBsdFtiDf7OUavDy1gy0z0UV6mhiUECOeawCS4rhqLFeJ40M4gRIv
VBHATMfT4Hg6LN+CB/LKwkwgr74ksfX5ronMt6vyztTemdY70ztGWlMH0lSl
shwPCMuN08RZlqzAleRZgjRNkKJLs1xFjidJsGVRjjYhsuUgV05jj8ttUbHR
x9U56VqYooVJkAUr0m1SoU2KYgNAUmyCiZUo27lEiiTJ0CCLgb8Y5hb2O/CM
S9C07R3Kxjp+eQl58/rOtes7N64jb91ALX0n7zaCi8KI8QQFiaKm0A2My9Hb
TvsXLBSGicAyE7kWotBGFNlJYjtRasNLLTjwKkjNaLkVq3QQxLZNkXVLYNri
6rbo0AZRBKbpW9vMm2CmRvM3wO/G1OJFNprcy9ZE+Pq40BbV/CvWiMoSVppD
EJDX4BPrPEKtm6fzXFoM5mWVg6Fzc4x5nbNhj84jpdvF1pPW4Hlv/H5/8ro/
e90ff9DqPis0nyQq9/zZE3tsVxscK+x1gbUqMFV4+iJXU+CpizxNUaAtCU11
maUld3QU3oEyPNHEFzogb/7IXD71Vs589fNA515kcJEY3kv0bse6x9HWQQgo
XJ76M0NXsgtfmtu2hYHIg2B46A8NfKGBJ9h3+rsOX9fq6Zo9XaN/YApPbJGF
PbrnCM2tvrHBPdBaK3R7jepp06MTVuGQ3ziXdO4p+3f1w3v29omtMNVFGlJ3
iecssbx1TrDN8w/I4JGpXUlmoUrNtImROTkCKeNNDTyJHnzZATqmWEfnr0nM
SbIygJDDGDmMBUBOospNVrmpCpgis5HldobcxlLCfINf7ogZPGmrJ213Ja16
WKe2yeUWnsxCE5twAiNCaEXLXUTIRwMvMduMZVuxQGGOfYsNrwGFlYMdgGqw
o+7vaLrb6va6urGqrC1r22tQ7Za48BYv9wa/+Ia4+rakcU3WuqGqbCuLm/L0
ujC8xHFeY5mvMnRXWdqbItO2zIY2BpnBsgb8SUvzQP0w1j3P5B5EMxfR1N0w
sDh5J5A4d8dPzbFjTRTk7744uRClp7LcWFMc2WqTQHsWKx75ysd+kL+5XXdu
DGd61khV405JXTGJ1c83uFhaB1Nupgm1JIGGLNRR2QYsS49hqNBMJQqkHvM7
WBCGCV0e5BhB5SCDsVebFZmqcmtTYR+LXHOZexeCJ3LHWAFPVLaB2tiWq6oi
4KwowxRlGdICW15iy4oscY4uStMVOba6wNcU+MaCGC4rXWAxL6hcGZkjLjIF
mHovzRSgm0N0hR3JhG4QlEtE1TJJtUZSbZDAWKfcpkAIKoSlKXAkCQrP2wEj
J4GDIHOQACJrh8jB4NgoFA2xQ97aJG0ANiibm9StLfoOgovBS4gUFZ2uZbGM
HLaZx7UK2HYmx8G6xEZjW6kcK1lgp4icFDBUKtw0cHpcniQukspF0HnIBh9V
4UICZDBSYEWw9VtU5QZevIriL19eDYNQDD2OZ6VI3UxlkKONCvRxkTWitoRV
5hDQVglmBGNA/h1SvU+s8fDUbi5A5WIBDAGBI6HwjYPxg1Tlfr3/YjD7aLr4
dLb/BWA6+6Qz+rDWeZapPgxkz+2xPa1vJAFNFe4InF2Ruy9xDxWuodI5UDl6
kL2rgPtKgKuv8o/U0Zkus28sHlkrZ/bKuat27q7f9rXvBgcXsdFFfHQnPjiP
9S4VjlTn/tzYk+o5411HpGuPdODgIBAa+iPjYGwWjM8DiV1/fB/gjS7ckV04
unDG992A0Mzu6uktdUifw5uKBLhBDA4o2T1W7VTUu6sc3tP3zo31fX26B/nK
XHuaas1QnEWqt85wtzDgkcm5MLunzO6aMjN7ZurNzULpgT899IIUjvfMoZYS
LrK0MbTMtyay7IgsCLEVKXNgFDBBAZOkYLE14WU2qsxGh2CWziuyRdVwQmeP
acFfXger5UahUEMV6AigTYnMGKkNK3eRFR6G0EZmm/CgTLKtaKZlk+PYEHo2
od6GarClGWxrh0htb0fd2lbVNhTlVU1jC6quiIo3+Lm3BcUrwup1cfOGtH1L
U9lRl7eVuQ1xdInrusayXeVYr/Oty7ogwRRhePKSTM9eWYQaB/H2abp/p1h8
nMg/jGUuwul7oeRdf+wcDp8YQoeK8KE4diBM7gvTu/L8XFfZdbT2wv3DTOnE
Vzm59Pe78mxLdy3hstYZv/TX4uOBsgrmL4mBehmvKqJAS6FqkDQViqzYuQw7
yTaAJN0BkGXbVNUO04QReaiqBM9Ykdk7Kmdf65hJXAu5c66wjaWWodQ6VJj7
Cn1bJi9xgbbiHBM4Ky0wZUUGQFqgi5JEeY6mKXGNZb6tKvU0lK6K3JERe/Ny
OC0wh5nGIM2eYDmSTKAJRfEmXnOdqFui6Fep+g2qfoumQzC1WLaWwNIQGQoc
GIrJfCSNj6IL0HQ+ispFUPh4Mg93aTELg2WiMSw0lo1BczBIFgonIFAgGkvH
4Rr5PIuQbxUJbGK+g3MJzOY5WDwbne+giWCG3M2EvEy1n6UPABiGS2imEMMS
YYLXRRvAq314uRsnsmHY+h2aapMoX2NoUWDp41lJEhcD8nNB+OpiQpC/1pAG
8J25ChANBr/sOyS6gEjl4SlcTLmTAQBznDkm9ha18dNs4UGt83Iw+2zv8Ouj
w6/3Dr7ePfp6Mn5d77/MN55E83fgxIHeP5baWkxDhfzdsCn0TRWhhTq0pw3s
ar0TjXukcQ/UQF5PHwr2VYmprnBgrp84Wueu+rkT0Dr3dO74hheRyUV8ejc5
uZPsn0Q6h2EwCBfH3nTfdelvBwZ4+x7/0BeeBuJ7ofRRJHcWK9yOFe/ES3dj
ubNQ+tifOgokDnyBid1S16iyYnUKrc+i7RWcv0dK7zIap4L+PdX4vrFxqC5O
1dGG2JlmGqN4fQxnSROBwo4aAjwS+Js/0Ob3LDkw7s39+Xk4NQqkx/7U2B0b
WMBQbMnToci2yLvEM2wCBKZtiRUjs+NAQQJK8g1oqZUktVIUDrrWyzeHpWAc
M4fkYJHUwUqpns9RELhKjNCAkZix4FtkTgr4ywutVJ6JxDETWCY03bQB/JX4
kfLuMtRb1wy3tP0tIC9U34IqW4rypii7LM6tCLLLvNxNfumWpL4iaS4Lazf1
ddSlwsVNKLMmDF5nOd4WuG+CpQbOM0NNORhXawe+3nlq8qA8fVgd3iuX341n
HwSBuYDomdN/aPDuQcFDSfhIGDsRpE8k2WN54VBX2XeARtQ5SlTPvcVjd3Zh
T02syYE53jQECip3Uu5KyB0hidHNV1joIHx5KjxXRQRQ1CiSEoGXb+HE6xjh
OhrMd99BhHZoejTfSQZjr7EosbeV7pHOOzHYp2LbRGQZAsSmvljfFimrPBC1
oC0DeYUZKj9F5qeIggxBmCWK82RJBi9J4ZQ5qrXOd7akzqrEWZb665AjK4DT
fHuKbUuyLCmGIUaSubfYxht4/VW8/jrZsEQ1rgN/6Xokz0wAw47eJxUbLq9r
caQEkZIqhChsMY7JQ/FkdCoXh6PtgB2WlEriYjkQgyIksBR0BkS/fH/QLlU4
FWK7VGSTSRwKuVcqcvKUQZnUJVB4Rea4UgkGCh/XmpA6klJrTGQJ82wxnisp
guM8c5DhynGNEaraS9QHacYQS+tjfPcuBksGU1V+Nhh7lT6WOSExpaTaKN+Y
FNvCWoNXprTzIRtP7RLqvBKtRwi5OPqgWOXnylwMCUyR+ximlCTUtmRnvsz9
UuNFb/bZ7v7X+wdfLYC8+18OF592ph9WgLyZY1topnR3RdY601qnO1os94Af
nEkj++rogS5+aEwcWcILo2eo8fRVgaE2NjGmZ6b83FLeszYP4c6Ju3JoBRZ3
zr2tI2f72DM8D49B+B6GugfBzn6oPg+UJj7gLyjPoYY1UDN7Bi7/2BsGsXsQ
zJxGi/cSjSfZ7rNS40m69ihdvp/I34klDoOuvkWdlwkjbEloDYptmvI7vi4x
s2DWT4Ttc3n3XFPdU2UGcn+Rb45QNH6cOojVR/HmFMndIgR6tNhYlF1oiweO
4r6nsAgCf/PzKPA31gdDt8pW4GriOIl/je+6wdVuMqAVAF+/LTYBJVF8HYKn
RYqMOLmNrHEzDT4+4HIqcfM0Lq5EfXn9U6CmiHREiZkgtxHkDjLo22BkFlgo
HAOBZcSBKVgAo8Q+lDwEJt9l9WDVMNrRDy/DF5grya2JMhv85CrYCnPrgvyq
uLoJdZFQHyHrbOibaODvZYXOrAjC13i+t2SRJUMO4+/w0lNl7Rju3Y1MH+X2
nlb3ntanDyvld0KZC3fszBE5sQWOjO6F0r0Qew94oWNO9JQTP+WnjsWZQ2V+
31Tcd9cOg8VzR+HYmtk3p6bGxEAfaWkDJaU3q/SkIHtEennlysoSG6l8DRnI
y4bwVA0a+IuVbiAEqzv8FaRwDSPZxMo3mSYC20YUeKnKJM9Ukzp6KtdQDTD1
BYYuT9fmappcVR305EtnuQkyN0ZiRwisMJYZRrEiaG4cI0wTxFmCJIuSpNFQ
jmisMKw1jrXMsZV4LmBxUegqicDWnuOYUlRlGMd3rtFN1/GmKwTTdbJ5iWZe
Z5i2BVaC0s0FS6szqtNYhXw5iScjSpU0uZomgyhSBVkkY0gUTLmKY3Eo5Voe
S0hUGHhSA1dhEkkMfJlJqIYhvUejdmuUTpXKpVb75CIrF3JLlC6RPqCwJ3Vg
0TaFJM4E5EmrvWkl6CpwXORLyQIZBcCfl3gyQmuUDaqCKy0OlTSenNIU5uv9
XHtcaolLAGAccOYge1rmKqjgmM4SVGpdYpWDD/wF8mp8AoA2JAAdGwqwoBBb
nxR46tr0Lmi20dqzVu/1YPfL2eHPFqffLE5/Ntv7tDN+WahfBHOH1uBA7qxz
TXmqJolXJzC6NN5So7i63MBUEp5DiQND+sia2LeEJ4bIyJiYWPJzR3nhau67
2/ue7p6nd+Cu7Frq+/b6wlGeWqpTOzg4OAz2D4L9/XB3EW7ML69CZ3uueNse
rpuBv94BHBi7I3Nv4iCQPQ2X78Vb72R6LwqDV6Xe82LznVzpIhk/CNjbRllS
xPLS+N5bkvCqNrPhamITU2rxgFs7kjQOlcWpItGWubN8fZCqdOMhL04XIRmT
FHeTGuhy42NFdmEoHjhLB/7iXqiwCGVm/sTIHeqanVW5KcdSRrEi3zrXeZOl
3KBIlsjiW0xonavZ5qh32KptgMSMV9gpWg/L4OfqvcBcttLBgOx0oZLJV1B5
CrxAg5eZiUqwzDppCgdVamcIzRSukcgxYthmlMCJkAeR6hhWO17RT9dNkx0D
GIQb20BeXmKFFV5mR1Z4qU1hdkdc3FE0MboRST8jasY4QwujqSGg0qY0syKK
XwNoi1vONjGxJyqf6bsP3dOnsb0XuYNXlcWz8vhxrvzIlTgz+xcqz0wBTyX2
CQ+esz0HLP8JPXxGi54xYyccUKTje8r0nimzZ08dq9NH2vS+NjFTh3tQoKHw
V6FASX15905cYfSLVDBXbmGLjHSOmnTZSNUoEL4o0eoWd2mbt4wWbxAgJEUL
kpfKc1NEfroyybn0t6O0deTmpkjdYCprDFmJIsqReEkCK4qj+hBE1zbBuYWH
NwmONSK8SvVssoI7ggQahK8sj5RlkfIcSlMiGsp0U4FuKbAcFQFc/hesRa4u
RZMEUUz7Ctl4FWu6QjTfoFiW6ZYNsE6CdHNntMmap9AKucN6pY4tg2hqHctk
EVjtIjss0ah4Dlgdidpyeb/dqZDIKTaXwhPUWT2Qzi7VWMUGl8oeNDlCVlvQ
AgDlVmHl69wyk1/piGo9CaPJJ4OjKl9Cl6o6ih1Prg7HCvpI7vLN9ETJGMjI
wnnIm5Q6wvxwXlUderNtBxyTBPOaeN0cLusDBU2kYvAXNe6sPFjWgHXGGoS0
LhFk48qsTIWDqfSw1QEeKNggoIG55rzY3VDH5/bqnUj/ndzwo97s8/HeTyeg
M598NTr8tDN6N1U5dUYHKm+Nb01TtWGs1LXJsyxxzbcEthV5dBOMnHCD7euK
oxPV5V12CxswNzGyZEdAUndrERjsB0d7wcHc1xu7azMHoDqyFnvGcs/SnDgH
u/7hIgTo7YZbs1Bl5Mv33am2I1a3hGomT8fi79sjU1cKJONZoPog1n0vM3pV
nH9UG39Y7b8ogRQG+WvrGCUJIcND57pviIK31Kk1Rw0VHVGyu+zCnqi0kGdH
ULSpcKbFYCS5fN/WT9dFWOYk11cXBDqS+EiXW9hLB97yYaC0Hyzsh1JTT6Rv
BeOVpSjUJKnSEJLnXmPBN5nQJkm0RBDcpEhWwP73sJTbMitJCdN0XrbexwEW
g31wBAQuX0FnS4hMMQr0Z4WVrPUwNW4GBNMkFrLIQuWDVDKg2MZNgXNbFUWZ
cgTL7rplvmmcbKrb67LiKi+xxAwtMQKrrNAmN4EUZNGiEhZqk/RTmnFO087I
xg5e18Qoq9uy/Iokd1NZWrb10aE9WvZcVHuoGz5zTF8GF6/ii1fpydN490Eo
fa71z8XWLtPUopk6NNOAYpuSnQckzwnBd4IPnBGDJ7TgASe4EIEFObKrCR+I
Ygfi2J4sMpH6u2JvQxxoKMMNXbhi9GQ1lrACNDqVUyC2sDlaCk2BA2MvaM4g
dkH+okTreAWCpsOzLCS+m851kXlekiJ+efeXtSk11viqIl1aJINizElgGCEk
xbsDnEVZVhD6m9va64Ad7VWk/jreukT3bvCjSEkCqyjtyIsIRQGhLGC0RYK+
QDUXGbYK11bmm/JsfYalzbKUSQrPjyRbl9GGa0jdW1jTNZJpGfRngYNoSyry
vWB/UTw47ZZrYdgJGQ18u03s96liMX0qZQ559OWsf9BKzcalZMxiMvLiMVOh
5AlFDLBbYXZInV5tOA7HMr54NgjwJywWD+SNGv1xM8AXMzj8yljami25+5Ps
4XlzcVhpdiO5kiOdt2YKtkzZnK/Z0iVTsmAot5yDebQ1Caar5uY40JgEMg1z
tKhJVg2RstaXVQQLKldc54gojV4xZGdLLFSZjQq5GZogRxfjGdMCW0nibqvD
U3Pu1N14HO8/z00/a+990Tv4srf7cX36Mg9e8fyuIdQUw1m6KYJXubbF5lWO
8ipZ+GOC4A2K5G22/ZosuGHMEOEKJ9CWJcbGzMSaHthyA7g4cNZGvu4kNJ7H
ZvPoeBwc9X2NsbM+git9W6VjqXWt7aG7P/UP5+H+NNibBcFzAd9S6LnSbUe8
bolUTe663t8xhsfW5AIunnkbD8PD56np6wJg/GERpDCo0+mzqHtk1xTV4rhI
EFyRxNa1uU24iQmPKOk5J7crzM0VWVDmm1pXTmWKyHQhsSEiNacU9rzSX1NH
2obU0JbbdYPwBf4W9335PW9sZPZ3tLayWJdmQlGiMIBku9do9ltAVbJ4Bc+/
CbZ0+QZDcSkvR4343l9gLlAYtGiQxUBeUKqBv0wRnibY4SpQwF+d+9Jf8FWR
iSi2UYQWAsuwwzSsCN3ruhTKXiE4DjaBwrr+srRyk5e8xorcZIZWgLycMJKX
wAqzeFEJr2iRdGOmbkbXTMmGHknfxaubKEVtU1lbNQ22ffuE+G1m9oJXfVfR
e2kcvrQPX7hHz3zth3DltiU859s7ZG0JqSohtHWUoYO2TNCOfTR8uOM63vGc
IoHFnkOKd4/t3RX5dhW+PXpgjxVYcP1jrrfL87ZEwY4q3jPHO7Zg1QyndcYw
pPZIpA4e18BgqMlAXgBeskVQIChqDMNAZFvJPAeN66RynESuhyiL0XQlgaku
0JaY8jSJn8SxoxiKD6TtOtq6ijIubWtvbKiuriveBmxCbyM0V3HmmwznGj+A
kMTQ4sKaNL8uzW9Ks1uKHEpbIF2mcIltrQpUKbo4QpDGSKIoke7ZQRtvbqjf
2la/CSwm6Jfpxi0QvvEGPDmq3nkwe/7iznxai0dsbhgKeVXZhLlahFs177SZ
PhpVzhaNi5Nuvx5JRfS9Zng6SNWrvkzKFgkb4gl7oRiuVpO1RrbezCUzznDM
ki/5swUv2E9nXMkU3Omm9w7qDx7Nnz87vrg3nozzjXoY0G7F5ovieJodz9Lz
vfz+URGwd5zfP80fnBUmB/FSy5Yq6cC21LIkK9pUVRfKmLwpvSOiMPiEajdb
Dc6f7+TVJ3mWgsjZhEJTQ/LYXr4faL0XG7yfmX1c2fu8cfBpdfQ8UT2DUyOl
v8SxxYjWINbg3IEMq0LoBp33Exz1T3DUH5JZb3DM1xS+TUua7C7xwi1FamAq
jODCwFkZeGoDX3sQGg6js1F8PojNu5FpO1BqWIt1C6Bct9Zajlbb2et7h6NA
bxQEdEaB5sBX6blzLXuiZo5Wja4K5G1oIgNjem4tnbjaD4LgF5u/zo0/yIw/
yF1eUns3k70d9c3dlo5VWzEo0ghVDmUoo51tQmhMS8y56Zk4M1Gmh8ZY2+ov
WR1poyVltGXMcNHqqTpCoN60PZlhAMy83zVnf3bhTM/toZ7G1ZAZc5eLuSxK
EAbQbNcWzbbKgdBU0SaBu0IWrDNkW0z5NhtC8NRouYWitFN1bpbew9Y4GZCN
IjURxAacQE5nCfFU/jZbhgBH1DANcnyntokI1lKRjcDUbzINSzLfmimPdtbx
tr1V02RJ2brOz73Fil5hBG+ywxv8GEYQxwtSRBBVgjxBVqdohgzdjKmZUA19
qmlENQwImi4CVG7nPi50m5y8T88+ZlfeE7VeqNrPNK2n+uYTY+meOnss9w5I
5goSyqxCuTVNbdvQ3TGNt627W6bFsvVwGT7ZcJ6g4COC64Du2ue598W+Q7J/
n+LbpfkmTN+IFxxKYmNdamLLjNzxrtNfsdmSOo1fJoYFPBDBJubldWYFiqHB
cQwkroV6eUkWvoTjJAF/Qf5e+lvgGEocdZYqT+LoQQTZs421X5oLYndHd3Nb
fXNLdWMLur6tuoZUXcPqb5AsS0x4g+fdBqsoN31dkLslyi4L06vS7I66SAD+
GsoMS00gS1K5ARwvTGAHcSDHt/Q3NrQgf69gjbfIpnWuHetIK7sH+YfPDl59
eP+Lz56enwxB1MYDxmzM0ih5Bq3QuBt+72z8/Pb02fn4/Ye7dxblaSty96B8
76R2ul+eDVLdRqTXSAy6uVGvNBlUZ6NmuRQADHvZdiPerEUnw9LutHb/7vyD
l/c+/ejxx6/uP7q7uz+tz4fl40X73un4ycPdizuji7vDxw9njx9O7t/rPXzY
f/Z8evde/egs3x36ai1bf+wDodbowa2BK16yRvImb/pyWrm81S0uMiUExhTf
DpL3/5O3cOFpvBvqvkoMX2emH6R3P8rNXyWad+DkUOor0R0xrMW3bXZu6c3r
kOqWUHSNTn+DQPghmfwGk3FdbF/RhzGeIjvSkGe6xvIEBjNsexap9/y9YWw+
zRzOi8eTwtEwd9zLABptT7XhrNXhRtPZbrlbTVen7Rn0A6NhaDgK9ceh7jgI
FC51nNmmDSjsq0Khljre16VnpuKhpXHX1X8nMHoRHb9KDl+lus/TtSepzHkk
sPA6Ry5b32lqUi0Niq1NcvUpwTEjNuMmppLkSJUcmGMdOFz3eMs+b8nvrQT8
9WCgGY41Y8lOIjdKXv5rxjycmbrjY3N0pPW0JaCVaTJUKEGUx4hgYed40FTb
JluBoQi3CNw1sGVId5gyBFuB4qpAtlLVMBPI+72/IGolRrxIj+VKKAw+FvjL
ku6ItRi5hSgzf/dGkgkvBylsw7H0a2zzTWV43V5CwXWkcXJN278mq7/Fz/yE
GXmbGbrFjyJESaIoSRalqcIMmZ8lSmtU9Yipn3O0c6ZxwLBOWNYpzTzB23ax
/nNy9D4t/oCcfEQtPGWVnwqKjwXF+6L8PXHqhB9ZsL09vLm8qc4uqQsr+sam
sbtpGK4ap0u62VXj/nXr8ZLjdAs+wcLHFNcR130kDJ9RAsdk74LkndNDu/zk
QpnbtxT33bm5NzcJxDteOG9WB+UiWCCw84QOId9IEZppIgtdbGeKYJYQZgmc
DDD8Mu14Nkzg+4jSKBVK0aAURRrHCMMIgnMDY1tBGm5taa5taa7vaG4BEOpb
aN0KTr9MMK5SzOt0+wbLucn3bAm826zUm4LcDVFhWZxdBS1aXyebmyxjja3M
0UHsckN4bphI82Mw9g0AyY8mWlfpjm22EwOF2Kmu9857u5998+ybn3/w519/
+PjefreaKKec7XJg1osfTNPHu5lPHx1+9HD/g4vZl+8dvbw3ur9Xfvlg9OL+
8L2L/r3jxvG8dDirHM5qB5Pm4axzujeaDQrzYfF40Zz2i3uT2rsPDl48Pvn4
xcWXr9/96uP3Pnn58N2Lw4uT6aPbi1fv3P705ePXz+5+8PT2iydH7z3ee/7O
/vvPDl+/Ovjg/b37F80HDxonp/ndvej+YWK2GxyM3JOZ/3KCbjqTdRBnlkTD
Em4YfFUVXJKmZrbMIVy64609CgJ5W88j3VfxzgeJwbPg4F1/4541PZUFqwx3
Gu8IIazODYN5RatZUkhviHjXWLQ3qYSfsGnXJbxNpXvbliBHapJsV18e2zu7
gdFBcnqQHUySJyeNZ48Wnz4/+/LZ+RdPT7965/RnT8+fPp3ev+icnVaPDov7
88x0GJkMwruT+GwUnU5i01lsNIuCyl0fXioMUjje0iZ6hvRIn50ZCgtD+dhc
v2NrPnJ1nwbb74Ub78SK9yPx02Bwz+ed+wGBXYlvJvRN2IEpKzLjxOeC5EyW
nOiSIzgxCCR68UQ3E+8WYj1ALt7Pp9rFTK+QH+ULk3R2Gk4MHaGezteWwnWe
uUhXpQnAX3CyyWJUng9HtyO5SgJdgiILtukSBAfCAsBgy1fj1A725d0vPr7R
xwX+yi0kIC9fg2Lw8TQumsrdYkq2BSqk2ICVfHdbndh8eSFaZMOw9Cs825I2
vukoI+Dqlrr3E6j9hrjyBvCXHbvKjiwLYkhxiiQB5TDDuHw/JUuU1KmaMce0
xzfscQwjpnXOse+xrAsyfEQKXlDjj2jRB4TYA0L6ETnzmJa8R4uf0+LHDDAU
e8ekwABvrW1q80u68qqps2XqbeiHy7rRNc3kTf3ibcvRDfvZBnyKcZ5QXCcc
94koeo8WOiV7D0j+BT12IMyeaEun9st3hPcChd1Ichh0l+zqIAT8FcEimUem
dvEhFw8gd3ElLg7wF4QvD6bQLBimHcfzEkQhoiRKFIXRvMAW27uOs62A5AXy
riuvbCqvgvBFapZQ2mWSaZNs3qJZtxj2bZZzm+fa5rkvFWan3xKVlmSVdUVp
S1PHgUEeHgrtHSE/jGEH0EBeboxM8+Gwjm1KEC8tCRhuJNeLFQXIppSkvpd6
8cXFb/7y83/7u69/9eefPHt4Mm3nO+XQtJs6XZTuHlcvTqufPDz46P7e64v5
Ny/PPn48e3ra+OTd2UdPJs8vBo/POvcOGud7zbNF62S3e743vH8yv3vcv3PU
uzgd7o2qtw/6X3z4+MvXT7748J2Pn93/7OWjT188+uCdu+8/uQN2vv7o2Z9/
9urzV5cP+Oj5vacP9t5/evTNF4+++enD16/2Ht1vPXs2fOed9t27pZOTzHTq
7/Qco4l3sJ/u7iaa80h7EeseJhqHkfzMFRuYOg8S3SfxwbPk4GWy+yIO/K0/
DwI6j5zVO+bUXOZvMNw5gjuJhQPbFvuKVntDrbguE14Vs6+wKG8xSVeErFW1
BKt278BJeryuyPeN9Ymzvx+dHmf3joun5+1XL05+94sP/6d/9/P//fd/8be/
/4t/+P2v//Hff/vv/5svf/vrlz/97N4HL/Ye3++dHZSOdnNnh4XFNLE7T853
E9NFYjiPdsbB2sBb7rqyA3NuZMqPjbmpLjvT5vZ0xWND+dxcu++oPPSUHvgy
t/3RY29o3x86iESOYunb+uSpOnooi+zxY/uC1IEks6fO7lpAsGYn8fy0kJ/V
CrNWft7KzZrpWT3ba+T61cKoVBhn0+NgtGf1tSBXnW+vso0FsjKFV6YIqgxN
kaAL/CSGAyPUUlhyLEOK5kB4oZb0PSIdUe8G5vItQZHJLwD+ysxEgRbNVSEo
bDSZhQD+MsRbPGhHqEMDf8UmnNRCUMAUoRXNMizxHbcMqS24umMrrRqbS6ri
DXH6qjB1i5tc5SS3+Dm8uEoXlGjsApFTxEvbJPWYopmStBOsboZSTfHaGdG8
R4aPaQHg6T1q6gE++whTfIIsPEZkH+zE76CCx3jPguaccmxjrqOPtrZRuvqO
qrR1OQJXsIYm2dyhWQd0+5QJL1jOQxb4UfApxXFOdt4hWy9WHBfbrgt84B47
fgHl7tkqd8P1u5nyYSq/m4p1A3DBqI4IFUGWMsrUp7n6uFAV4kg9dKGTIoCp
IHm5dirTRmZYCUwbkQeTRB6qNECT+sgiD47vBPm4gTWsAWcR6mWUdhVvurx5
nmLD0mECzUmge0gAggOLtiLxMJYapHAybEVTrBvIVV2+qscyzXnmXZ5+xOLk
EOISWV7kCRM8bkAoCmr1Ob+zmbMl9UqP1OBTJSvhg7PJl199+Fff/vLbn//0
l5+8/ujBxf3Z6LRTv92tPhw3Xx6NPr23/w2Q7vH5V8/ug+3n79z52YuHr+8f
f/LoDBz58OLo/bsHr+7sv3s0eXo8BVzMOo/2hxfz/qPF6MN7p988e/Krl8//
4sWzv3jx4pfPn//svadfPX33F69e/uaTD3/z+Ud/8dmHv/z0g7/8/ItfvHr/
88ePAL/44MW3n330y49ffvni0WfPL14+OHjv/u6Lx3tP7k3ODmp3jpvvPZqB
teLuYe/iZHz7aHSw292b987OZg/fOf3gsyfvfHT28MPFyXut4b3E6GFk8m60
c+Gu75lLU32qDQUKYjjKNnloOhtJYyKKpNtyGUIm2hKwl9i0K3zmdUiwopNt
WeKbcBobrrKLfW171zs9yp/eHTx4dPTTn370b3/9q7/9n//X//Qf//Gf/vYf
/p+//ft//j//r3/63/7uP/2Hv/5fvv3lf/+bn//Vr37+ycfvP3py//Tu2fxg
Nt0d7h8Ojk57i+Pq6CjVPQrVjjyFfWtuV5OdqzMzKDtX5BaK/B6U3ZUnZ9LC
sTZzoEscGGKHl/9Q457b3Qt34DCUP3RUz731O/7Kmad47C4cefL77vTMndsN
pqeh9CRW2i02DlvNo35p1kr3K7kBCN9cdpgA6Rzu2PxNtach97RFwF9DkabO
EJVpsjJNBf4Kg0SmG8sw4yh6FFGFoKvRfCNJZqMrbCy5mSEz0U0+mT2iNvhl
Cidf6uCyjVS8DIkWXcGIr+KkV4mKGzTVKseAENsoKidP4xbLHXyJjS11UJQB
kiFBMGdRlvyOtb2qLl+XZK+IM7fE2XVhfkdcxsnqNGmDJqgRRQ28ok/Sjkma
MUYzQehmSO0uwbBHsh3SXKe00B1G4oKeeUjOPcbnH6Ky9xGJ21vhox3vAuOc
khxDpm3ABvKamwh9dVtb2tGVUfoa3tKm2fpMx4gDz7iufY7riO08ocOnVOcZ
Gb5Nge9vOe8jfRfk0H1u8oGq+MBeeRBsXmRKR7HsPBLqOO0FjS4uUsU4uhTP
kBcYk0J1lCfzM8RumsBFAcnLthHpFjyA5SDw3GQgryJMlwXJAjeW60CQbTt4
0wZGv4rWrWENG0QLEshLteMYbhLdRaS5iWQXAWtHY2woko/ESXDkdZlxpLMv
jOaZwjyXOo8U7lO5Y1+sbFH1HZ6hJVcW5fKUSpd3+Hv57H6/tldMdSKpZqQ2
LOyfjl+/fvrbX3797c++/PL509f37z092ns4Gz4Ytx/N2s+Php9c7H/9/MH3
tv6rvx89OAH74Pj3/oLty9t7wOJnp/O7k9bpoAYU/uj+2TfPH//qg+e//eDF
b95/+etXL377watvP3z/248//PbT10BS4O9vvnz97Vcf/+6zz4G/wOufv3j+
uy8++Ztvfvrtlx/9/PV77z86Af6+enL88fPzD947fu/h7vPHex+/On3x6PCd
OwvQwG8fju+eLZ6CKP/0xZ//8tM//+2nH/700dNPTh6+np0+rx88y8/fjXfu
uKszY7anDpXE7gTHHmQaYarKgJcqkFIpUi5DyUQ7As4Kh35dwLylEK1rFQiV
ZxlO4VJtWW1i6e4GDu403v/4/q9/+9Pf/81f/o//3X/4x7/7+3/+x3/+v/+P
v//nv/uP//wP/wT8/aff/9X/8Iuvfv/zr/7mt7/85mdfPH/57Pb9O7uH873D
2cnZ/OzO5PC8OTvNj87jnduh2qmnfGgs7OmycyXo8+mZFJCaSuITcXwmDY2k
vpHcO9K6xwbn2OLddYeOI+VTd+si1HuU6DyINe+FG3cjtbNQ6TBU3I/kdqO5
ebK8V2getVvHvfK8nRlU0r10qpuMdYPBptNT1cEVmaMicNS4tgoL+KvJklUZ
iirD+N7fy3/QsBFpRgxFi6Tr0CILVelkX95D7uJpnVxbSGaPKo0BqcYnUvmE
PCsN+IuSXMpLkF8nQTfp6jWuESmxU4G/Wo9E6ZIA01Velj7GsGQojhLeVkHB
/W199ZYid01evKWsbirrSEUTA3UIyh4J6uFVA7xuSgDJqx5ua0bb+tmO+Zhk
OSE7z2i+O6zoBTv9gJN/wqq8w8g/IGTuYmLHSP8c4Rqh4T7B3qPbeyxLC2lu
oox1lLGGNjfw9g4VHrBdE55nJvDtCf1HIv+JwHPKdp0y3Gd01znNeR/teUAM
PqTHH4lyj7XlJ47640D7SaJ0Fk7venwtk7Uo1+eE+hzfVBSayiJTRqxL8JVh
lsRHB/5yHUS6FUsxocCWDROFPpo8woLiLGmYwnWjmbYt4C/RsoU3XXIprx0D
5KU4cAwvmeYik10koouIh/F4F5EVZ8vKcuPU5DyCfbdd7jOT90wfumcI3dX6
TiDTgGcdiK0dyFBRqbM6W9WXXbSGj0/P3ztcXIx3z0f755Pzu/vvv3jys88+
/OLVi/fOT56fnbw4O3p2tHi8GD3Z7X54e/HzZ3eBuR8/PP3y6T2w/V5boDP4
FIgMjgC+ePcu8Bp8CSgM/L0zboKDv/30xe8+++DX77/3y+fv/uK9J9+88/Cv
P339+y8//W+/+vzf/fTT333++tvPP/zdV5/89c+/+Nmz5yB5P3v08JuXl/7+
9ddf/OrT/5ert26OJEuwfL/EPtvZnu2ZedbTsz3TXNWVjMpUgpRihghJoWAG
BTMzMzNzKEBSiBViSFRCZVVmcVVTdXVXw7y13Wfvqsvs/bFmx665Qq4wk+S/
e87xuO6+vL80v1pObTWye6uVw835/fXyzloeaHe9sLNcWZlPz2fC1Xx8s1l7
erL38ZsXn3/++uUHJyvbpcpyeH4jkFuxRqtKV46tC+H0XqzMPMuSjpI4vfi5
Hjju/vjUzf6hS4ODlwb7L/b1nOvpfKf73s/6u34xPnRhdvIGhHieLLgvs8xY
Q/RwVr20lnr/w6Nvv/31n7/5/V/+8If/9df//N9//n/+9rtv/ucfvv1f3/zp
j59/+dXR3sPG/NHKwsvHh48fHa1srhaqJWDB2XyqVEkWK+Fkzh7MqDxZsS3H
M6QZujhOFUFI/dNC97jAOcyzD7BtfUxLD0nXgVbdRyg74eqzayXQxmmym8CO
sdVJurnId9akjqrEPi+2lcWWgkCf4quiHEWIKw8IVGGZPqoDFqzwaoQ2OdvI
YhnpNA2BqIChxWMIcR9S2oVSdKKVnYDfackdqPguVNwJ+B1k3P4/+UW3T5G7
kYx+NGsQyxoi8Cbw3HEUaxjOGoIxhwfxHe2Qy9fHfnJj/Mftkz+7C/1F5/R7
vYhrY9h7EEL/FHEECEoZgjH6kIJunPweTn0Lr71Odd9AGd6bUv5sWvsO0nIR
4bg6a79ythbaeQVo1nMV4bsGsJ2yvzvjfA/pu4RJ3sam2snpe2f5ttAjKQ8o
q0O62pCq1KPIdgqitxmeGxTbDbKlnWTtJNu68eabePMtIIKlnWi7T3F2Uz0D
c74hVmScFRtjJceYieG5+AAl3gsopiQekPN35godnPKAsDquqMG1DbyhRjXX
mOocVRjCUSwQlHoYqR5Aa4dQumGkbgAlG54V9UO5PaN0wG876LwA3luwi/ex
17tJt4eZHZP8bqioe5Rzt4t8qR39Tjvy4m3EhTbkhe/gBeQC3cZdB+QC3aHc
uTt3/x69o5PTPaqcgNvRhChpLjvHKTFYBTIrj2Hl4HMJCCkwjLD0oEyDSP0o
TD4xI5rGqyjKiDmylM/W47FiIFUI5cvRajWz3qytViu5gD/hcJQCvqVkdCEe
LHptGYd+Ieber2UAnivZMEByMekHhAJUAb8AXpCrwbfAxuO12nGz/B3m5aAd
7PZktfbR0db7W81HjdKjRuVpY/6kUnizufp2ZwPo/a2V042lF62V93fX39/f
WMtmmskEGAG/7++1PjzcfdpaO1qpn6wtnO6tvTraerq/dtJaONqs76/N7yyX
9lZrO8vzrWb1cHPl1eOTz96+/urTt599/P7p6eFiM1+qBRsr4dKSK1ZUelM8
W5jmibAtHorKgOZJoGT6EBLzYBJ6Z3SkbWT45mD/1Z6uC72d53s73xvqvTQz
cQuH6MIw7jFlozonKVbQbe4VPvzo+OtvPv3rX77565/++Oevv/nb19/++de/
/8OnX3775a+/+eyLj5+c7hbSZZ+zkYoeb28eHe+tbW0urC7Xl5eaKwura42l
5UKxGogWDL6c3J7lG1IsY4oIEAYuLPFBhK4RjrVvTt9J1txHSNqm+NcnONfH
+Xchkp5Z9TjJgWVHWMrYnCnPd9Xk7rrCDcaa3F6SmrIibYKvivAVIb4yJFGH
lYqAQuSScMx8uo5MVeMJ8lmkaAwYxzSvEybqQMg6AcKz8vswaceM7MG0tGuC
3zlIv9NDvtmJunkPdrV96tK9mUv96DYItRPN6Sfwh4mCEapkgiwZxwiG4JyB
KVbvMOluJ/Jq2+RPb0N/fmf6l/en3+mCne9DXh/F3J3E903iBqGE4SkqgH0A
LerFyO/hNbcJuhvcQAfJfg1tOI+1XCR4rhJ8V9Ce80jPuVnPr2DudxG+c0j/
ebj3HMzxDsL9Hi54GZO6jk3fJGRuzeXu84q98uqopjFpWpg216CG0qQiOSwK
9nE93WcX9jr7OK5+urOD4XrAdHcxvX1s/wAnNMINjXMiE8L0jDA9xU9DOYkx
emyQFumnRfrosQFKupuR7+eVx2T1GfUCSr+INS6STAsUbYUkSiKp7nGceRBr
GsBZR7CWYaRxAKMYRskGQZYeZd3vI98G/N5FXrmDuNxDbh+YuzvG6QT/LIik
e4hzu4N8vg3987bZCzdh52/AAcKX2rHX7+Jv3iHcvIVvA57bTm7vYD7oEw0P
ycbH1FNwG5YcYjByHG6ZL6rxhTW2oEJmZZHk4Bja3osy96ENAxjtGEI2AeND
cVKCMmCINrK5SiyR8SVS/nw+ulgttFYaC/msV6+ziAQRkwHkZ8Bv1mUO6qVx
q3I+bAfxGNTbesyT95oLPgsIzABn4MKAXzA+Wa+/2G4+Wq0CkAHOAN7tcurp
Wv3lxuJxLbtXTD1plJ4vzj+pFV8sVYHAl0fzueN64dlKDez2sFmpR8LzwcBS
In6yvARS6GdPTj46OXh9tPvm4cEnp8cfPzt6cbD5cHNpf60OsN1aLB1vrj7d
a708Pnz/0cnHL55/9vqDj14+f/745NHh7lKjsFBPrq5nG0vBQtmSLxvy8/p4
WhWLy70+vlpNmJsbR8B7pqAdUEgnAtY3OdYx2Nc20Ht9sO/GxFA7CtYzR5qk
8SeUJkoiZ9raK7/5+NEfv/3qb3/941/++A1ovn/69dd/+c03f/riN19/8sWf
P//q92/fvtjfr/pccZO+GA601po7O6311lbr4GDv5GR9e2N7Z31jq15bSqSr
jkhF7y3JrXmBOUMxJAnaGFYZnBW7J9iWPrL6HlbahhDegLDPFgyPsm8DuKZl
wwQLih2gq6Isc07sriq9dfV3cs0rbEWZPiXUxPjKME/m54MULXBymEY6VUPF
yWEY6TRCODrF6ZkE7sC5Ny24B5d2AGdHKrtRqh6Uqg+uGACWMcK6PzDX3ott
f4C82TF7pRN+ZRB3c2ruPpbfS5YOEcUDc8qxOc0EXjY4y3kwPtc+TLk9SGq7
A3vnHvxXHfBfdcHPdSMuAn5H0PfGsT2AX+C/MPoYgjuEEfdhFfdx2jaC4bok
NsL2PaC6btG8bXOhm+TQFVzgPWzgHaTvp3DPj+Hun6J876A878Kd7yBd7wG6
4bFzyPglbPI6NdMO+FVUx/WLcOsSzrlIsNfwpgJal4SpwhCZf0ziHRF7hrne
Xr6/XxgekcYnpMkpWWpamp4WpWbkeaQkBxekoOzoGC04SPH304L9jMgQNTHI
yIzyy1PyOkK7hDE0sWdaxGrrKElumhkeo3gGSe6Rs9WYrjGMfRSvm8CoR5HS
AQjnwQD1TjfhZhf+BtAIowPAC8wX8DshejDAAd323A30T65PnftON+GXbmOu
AXiB7d4m3b5NuXOf0TkgGYXoZ2EWLMJOIAXZzLRU3FBIFhSyRal8QSip0rlp
DNk/jrP1Yw29GM0ATjWKFo/P0Mdg9CmOlmuPu4rlRDodTMUDqai/lI6u1+aX
C/mIxcJEzOpYzITVWAm6M06TXycBittV1ZAz6zQUvZa4WZW0amph10LMuzuf
Aejt13JgBBgeL5YOG4W9anY5FdwuxnbLiY1saDHsbIacmwnvVty7ErQfFWJA
rZR/NeLcSHj3Som9ShLsFjFqAzpVwmZazaWerC9/Z8FvHh59/OQh0NtHxy/2
dx5urO4tNYD2mwsvjg7ePH389unTV8cPXx6dvDp5cnpwcrzV2ltdWa2VNkES
2KptLKdXFiIbK5HN1XCt7KqWnJm40WbkcugwzOwAamYAgxijEmHw6aGxoY6R
gXtgnJroIWKhfDZBpqbFM47Dk5WPPjn97W8//csfv/7bt3/6K4jKX/3+26++
/ttv/vjXL3/3x08+/+sXX/7ugw8eb2xUPI60wzIfj2wsL262trb29w+ePjl5
9gwYcWtno7XTbK4Vys1IdskdXzIH6xpbfg4grE/g1WGExDMJ+KWq7mEkN9Gi
Nhj3JoR9Hcq5O83vgktHSEYk20fVxgW2osJb1/saBv+CPrBo8DV0rnmVMSME
FqwMc8ReBs9BoxuIRCUGI4HDeKCvDUDZ3d+dVJlgt5/xK3mA0fThdENE4yjJ
NIHTjyOUQ1BhLzgCx2jdI5QHg4Q7g4Rb45RbMM49vLSHqh4gyrvmtAMM4zBB
1TfDuzs6d3OM3jbJutuFu9iDu9SLv9yHu9KPuTqIaTs75YXtnSKOwSiTCCYE
xR9BS/oxyvsE/W2i+aYqDRdHJrihfm60ixm5QwleIQTexYd+iQ0Cfv9j1vnv
CNfPke5fIe3voRwXsM4rU8Gfw0K/REfPk1I3OYUHstq4cQnrWKa5F1nuGsdV
ZtrzNEsSrw/DVP5xuWeI7x0QBodlsQlVZlpTgGuLCE0JpSwigQC/3DiE5h8i
OnqBKO4Bun+EGp5gJqCCAlxRQ2mXsLpltH4JoVuEK6tTkuIkNznKjI7ORcZp
IQjFDyV5J+fMMxQDFHAEE/aNMzuHaXf/fsKqc0rQPyXsBX/DSXH3qPBeL/PG
HdJ719E/uQa9eBVy4Qr04nUY4Be82H6Xeredereb3/cdvCgnCeelE/xMekwk
LGjUqyZlUytvyGQ1gbTEFCRxTP803TlBNY/SDBNz2imSFAqjjkygB3EslNQo
BtjmU5FKNp6N+JM+z0Im2aqUFpNxKRlv5LHCBlXKbgibVC4l36sRha2qvNsE
sAX8pu06AHIj6gH8ApN9vFLdKibWc1GwvVNJA5bBBqC77LGUPMay21j3WppB
W9NvqTl1ZbNiK+rYSbhXQ/Z5u6bi0CwFbcthR8Nn9qhkNonArZQWfK7NUu5g
of54beXlTuvDk8NXB7sv9/Ze7e8/BVgsLgI9Wl9/dXz8waNHLw6Pjze2DlY3
H23sgM65VV3cri+26rWT9ZVnu2snm/XjjfLDVmVvJbu/Xtxezi4UA2GXWiWi
sSlIJhHBoWEkXBoFC4dBRmaho1jE1BwJo5TxvS5zLh/f29/47NM3v//dV3/8
/e/+8oc//uV3f/zmi69/8/bLrz/+6s+f/+YPbz/5zYtXv3v//Y8fHu/MFwtu
W8ZlK8XDi7XKytrqztHR/uOnrf2j9db2zt42eKuN7frCZnp+M5rb8CRWrI4y
x5Zn6BMERQAuck1yzQNzmg6y4g5echslbEcI7iLF3WjZIE41STej+T6aISGx
59Xeqt5bM3yHMODXXVUDUzakBcoIW+ilMSx4ogaOEEFmeGMQTjdwikl25wTr
HjBfqOABXN6LVg8CbGm2qbMLMVxImh2GN0wiFCMzkoFZ7sgMZwDK7Jlk3Iey
7yCF9wiKBzR9N1XXRTUC9eA1D2bF7RDOjUlu25SgfXCubYR+a3Tu1ij11gix
bQR3ZxzbNYkdmCGOz1IhgF8kbxQh7EHJ27G6GzjzNW2GqEggxPEpYWKEHeuk
BK8SAu8Rwu8Swu8gPT+esf870vELtPM8ynYRYb6EtFyd9P471P9jePCXhMRV
ZuE+4NfUxLtWWK4Gz12TeOel3qLAkaaaIkiNf0LlHuK6+0SBYXl8Upuf1ZdR
hioGSFtFK0twcXaGHR4nu/oxpi6csYdsG5xzjVP808woXJjDKKp47RJe18Rq
mwj10oxkflxYHONm/l6Z4xBmbIYehs2FZll2BMMCI2kgSPHwFKsbwugGVQLG
H0RJxuDioRlxP0TYNcK718O4Dvi9gfn5Ncjlq5OXrkAvX4NduYVpu0u+d3/u
PnDeEcXkhHYGbsPjfQyin00J8NkJubRkNmy41ItGaUUmKfAlGYYwRuQHUAI3
XOxGSR1ome1sqQOOPglBDqDJMwIF223U5yKh1flyLZmIO6zz4eBedX6vVi64
HXmXNeMwRowqu5St41LM4jm3VpBzGQG5Z2D6bfNBx0o61EwGgP+Ckgu2wSsA
Z0AxMN+NfKzgMbvEbK+MlzYrV6Oug0J0PxtqxZzrIfOKT9+K2taCprJZltYJ
ilZl1aWrOLRppzWoV4cMmkrIB/jdq1cfrjQBv6/3959tbj5vATs+fLm9e7iw
dNBYPN1sne7sP989eAScrbEMdNTc2K4uNRK5/cXlk+bK+3t7IH5/cNj68Kj1
/v7a0VLhw4et093l7UahEHZ59HKDmK0WsDRinlklFTLnaDg0g0KU8DlmnTod
j6wvN18+f/XZ209/+8Vvfv/V19/+7tv/+c1//umLbz578dGnTz/86sXb375+
89njp693dz482HmystAAc6DNELEakgF3PpeqLy22jo9aJw+ry6utvf3D44Oj
492dg+bKdqG+nShs+pMrDm9d7ChwdHGizDsrtI1xTP0sXQ9d/YAouYsT3cWL
OomyAbJyjKqd4VhxEh9dH5fbchp32egu6z3zOmDE3roWRGhrQWzI8pUxlsBL
mjOhsAooTDAMYfdN8joh/AdAUEHXtKgHIR/AacdIRsicDQbI5ftxggCB48HQ
rDCQDNGqEZRwAiEYmeX1T3M6prm34aJbWGX72UVMtk6K+R7JcA+nu4tUtM+I
Abxt08LbY7w749w7YGaYYN6ZoN4ZJ96fxPdA8UNT+PEZMgQ2Nz7LHgKle0Z8
A66+gjJcNuaZ2hxNncMr83BheoQeuQsiNDl6iRQFLfhnZ/eiBM5rvQQzXJzR
XJnV3Ri2/XDc/j+mvT/FRM7PZdvFlWHdAsbWZFmrfFAignVdsKr2F4WOJNkS
mTWGJoX+EaF/SBweVaQmdWW4qYE2NNAgDCvKMF5inOIFTbYLpe1Ea7oo1hG+
b5YbwwtTRHmRrKpRtYtkzSJGtQBX1KfF5QlhcUJYgIoKs7w0nBmG0QNwZgjN
d2LpBjhZCaGpYWIHSe1nCSwEogRCkEIoGsD1FEwyMMi43UG50o4/fx39i4uj
F88NnXtv5Nz12ev3SR097L4B0cioEjJlgE9qZqcNGKKPxY7LeEm1KKWX5y2W
Va+2YZUXFLK0QJ5gyyNzMi8BkGvwU+1htjMsMNhYAimBxcXyhVSFiu/S6eIe
Vz2VXMnnG/FoOeBZiIZaxcxOMb2aDANOQU7Wc0lqNt4ioQOEw3oZ8N/NQnw1
A4qqA4xAa9kI4BdQDBCuR9zAlAHCAOSgVqKm4osuCyi5L1eqbzbrr5YLeyn3
sle36FJuhIy7CeeSR5tUcjJ6YcNtANoq54F2qqWT5YXnrfXX+7uvdreft87I
fbqx8eboCIC8Xanu1RqvdvZetHY2K/Pz0UQtntpbaB4vb25XFoAer7Zetfaf
rW++bG1//ujhl08efrC7ebrefL7ZfL61crxcWyskwfyQ87uKIW8+6Ev6XPlI
yGs2WbVqm1bntdtrxfLjw+NXT0+/+ui3n3/41Tdfffu/v/1///b7//z6k68/
OX37dOv4eLn1xdNXXzx5drqx/mxt+XR1YSMTyTsMMasuYFYHXZZcNrm0vrx+
sL9+cLi+d/D01avHTx8dn+ztH6+1jhpLu9nsmi/cMHvrUmuBrY0RpB6Y0DbB
NQ4CeCnSu1RZB1ncQRQ9IEn76aoJvgUjP7tFDNcYk1tTaldeB/h1V7TuisZZ
UQJ+TVmBLs1VROlCH5FuQxN0ZzfRQsjGQXcG3RYm6wcJGaMdIximvrstD89P
FIepshhdEqGIw2SeDwcQBs0OIxxD8oamQZVjtkHY12Dia6C3Uqx3mJ4OmuMO
0XQLo7+F1t1Bqu/CZHeholswZd84/+4Q4+Y4ox1Kvz9B6pjE9kJxI5OYUQh2
dIIwNEnthrDvTEtvInRXUebLlorIUObqSjRVCSvMTNDC9/GB64TgFXzwEui8
05Zfwi0XEKZr09orU8pr06q2YfP/GLH826T9P2b9PyfGr3ILPer6rGmRbl+Q
eBuGYMMarht9RYkjSTGHYfrAOIBXEBgShYakqXFVEaqpwtRVmGJ+WlyAsGJD
ZE8v4Bet6wb1gWae4HtRvBhZkqGrykxdnalfoKkbRPUCVtVAAXJ5WYggPSPM
IPhxFCuIZPjRrABO6qLowzxfXg0aUK0VXdhO5ha9vqzOFBQJLCSceALC6hma
u9dLaWvHXLw6+4vzQ5fPDV64NHGlHXuvmzEwwB8ZFI8OyyegegAvCuekCVMq
3bzDOO82Vjzmil8LnCynV6bUuozKmlVaU2Kdd05uxDp8rGBUkkxqYzGdyyk1
6kUGnchskPsMhpjDUQ6Hm+nkSiaxlokfzOefrzUeL5QP59Ogui5E7H4NzyKi
Aum5BLeE4xAyK17rSiLQCLlqAUfVb2/l40e1/F45DV6sB51g3MxGF8LurE23
korul/Mv1pc+aC2dLhb2sv7VgLFmk64HDQtORcMhr1plJZO06TVsxT1rYQeA
d69eebzWfLW79eZo78PDfWC+zzbX3x4ePFldOd3YfH9nF4wvtlqPllcWYvGU
y13w+muR2Eom1yrPHzSaT1Y2X2zufrCz/2Kj9XKz9WZn58Xa2l6psJlJbefT
m8UsSBcHjflWOb9eyLQqhf2lxtFqE7T+UixWTiYWi6XV2sLJ9sGHz159+PT1
Jy+++v0nf/rm87/87u03v379mzePPjxY2m4kCqvZ8of7h2ByeLHWfLxUPa7m
m1F3zqaKWbUhqzYecJQrudXW+ubx/tbx0dbxycPT00dPHp483D84WQf8Lu5k
ssueUN3kqcqsBa42SpJ5ESI75IxfZRdVfI8muU8Vd1BFXVTJAEsNkVgxGh/D
HBGY42p7Rusu6D0lnbOkthcUtjyYAcT6NFuTZMojVL6fyHCgSAYYRjWJlI9N
yfpgykGUdgKQSzbD6Q4cx0sWBOdEYYYszlEmOPI4QxqdEwbBT8EJ+gm8ZAIj
Gp7ldkLZbVDeFbjsMt54ney4yfC1k11tWPM1pO46QtsGV9+BKe5Ny+7Oavog
0o4J3l0o5/4U48E4sXMC0wPFDk8gh8dRw6PY/nHygwnm7SnJtVndVbTtsqUq
1s9zdBW6ukIUZqepkW5CoB0fbEO6L83Yzk+Z3oMZL83or0FV1yZl1yalNwZ1
/z6g++Gg/l/HLT+E+35JS94SV8a0daJtUepZNAYXHYG6xVOU2RJUQwimCYzx
/YOCwIAwPChODEtyo9LiqLg4IigOczKD1HAv3tWFMXdi9D1Y7SDdOiP04sRJ
hqrANTVE5iWRvsFS12nqOkW7SBHnUPwkQpBASVIkSZImClPFIYYsynHFlYWm
//D5wuvPDz766tHbz46fvdo8fLRYXY654mqelojlQyYZfd3Ytlvwi22z566M
t12ZvN2OetDPHB4TQ0dkkBHZBOB3RA6d1iPpAZ6xag9upBJb+fh6EchW9prz
TmvW6s7bwmVHrGgOxBUeLy8aURSzpuV6aLOZXq6nKrlQOuKJBh35YDDv988D
fpOJjVxyt5Q5qRWeLVcOKondfGinGF5NulMWWUDF8ak5ThndI+WqqVi/QlBy
m3N2vU/Od4pYgOL9SubxUmW3lAI2dDCfBUQvRjyrySCAbiUV38omgQWDehuW
M31CkouN8vMwXg4qpWTUbPJ5q6Jm1wDzrTp0q8Uzpg4XawDhZ5urT9aXj5uN
g3rt0XLzu0UdT1aWTxYXjhr15WQirNMGdJpy0L+cSjeisdVM9snq2pu9g9fb
u6+2tk/XNp42myf1+moiUXA4cjZL1edpFQsPlxZfbm2+3N54vrX2YnsDTBQv
QDNdrG/MV1oLC0eAuc2d04NHrx+9PD148uroo9+9/fbLl799dfjB25M3j1aP
Evagji3MuTyPmksf72+/WG2c1HM72VDdZ8xbZV69xGdRxEL2Si3X3F5ZPdhZ
PzoACO+dHB2dHB6f7BycrG3sV6ob8dSiMzhvcM/LLDmeNkqR+9AS5xTfNMpS
dgN458RAnXOibqZ0SKCdVtnwpgDHERM50lpXVg/4dRe1jpzCnJEYUwJ9iquO
05WxOVmYAvIwy4Uhm2E43RRaPYlQj2H0EKIFTnVgGW4Sx08XhwGzImVSpMlI
NVkRQBi4MLBgthtFNk+SZBNY8RCc1zHFvTEtvIxUXSZYr1E9NxnBWyTPDWCg
MO2VGfWNWVU7XNUBV3bBdb0wde+sohsu6QV9cIL0YALTC0GPjMGHx5BDI5i+
YWLHKKNtUnxl1nAFY7+ir7G183R1maooY3mZKUqkF+e/gw22z7quzdqvwGxX
YeYbM/obUNWNCdm1cfG1fuWPexX/1qP4l37N9yes/4oOnmdluyXlWUODa22o
XXWLe97gyEuNCbI2PKM+47efHxzghfu48T5eqoed6WZmuhjpB4x0FzHUibHf
QxrvA//F64dZDrgsSD2Dty51rqoda0rTolhb5WgbHNOiEDiyPEdXZFmGosRS
VtnLWlfF6KvawMF08HDhg48PP/3i6aefPfnko8cfvj569WJvZ7dRbcRCGYvB
J6HIkH2Yu+0zlzvQbffQfZ24wQH65KQUPqNBT6rg48rpMeU03IyleJnKnDaw
Fisd1RceroEjb+FgtbjVyK4U4/VErBhI5L25grtc9NSK7lrGsVIJHa4Wnu0t
Pd1fO9xYWK2V6vnUci5XjcUqocBiIrKRT2wXEtv5MCB3HSTbkHE1Zl2JWnJ2
acLIT1skCbMIACvFwxUklJlDtQsYSjJaiJ4OqkQA2A93Vl9uLAIjPmkUAbwZ
qxbwm3d7NAy6SyqqB90hlUCBhUoQQ3zog7mhm+LpLj8Pl9XyAgKKi0VIaUSL
XvPuQm2jUlzKppYzqZVscjEZLfrdSZspZtYvxUOH9fJWIZ1zWqJaZVgtDyql
ccvZh1zNVKwRCa6mE09Wlt7f3gSB9ulq82SxDmx3KRJKGvVeqTikUgCE9+Yr
gN/nG6sf7LY+Pjn4+GTv5e46mCIerjdbtcpmpbI5X9+oNPYW1082DvaXt0/W
nr15+NmTjWd7jf3Ha8e1cF6Ep5MmIBm77XC++BoE8mbppJrcTLgqTkXeJNCL
KWYNx+815Iqx+ZVqfWt5aWdz/XB3c29n72D74Li1e7i83MoXlwPRqslX1jjL
EnMW8EsD/EqdMKFpjKPup0s6mEDiByxJL08+KtPDdE6SI8T1JaRn8OZ0nrze
mVdbQLiKc9VRhjJKU0SowHwBhoBftgcHQjLR+HeEDVM4E5xsx9I9FLaXwQtw
xVGJLCHXZlT6vEqblSkTvL/7L4HhhJ3dcEkyghb0wjh3prjXYJKLGOMVivsG
PdxGC18neq8hLRenNBegiqtTinaYqgul6Z/V9SL0fSj9IFoxCOP2TZG7Ibj+
Kez4BHJ0Ej0+gR0aIXWO0G+OiS/P6C6hnZdBRtXUiLIKRlyEM1Nj2EAnwn0b
6WlHem+hvHcwnntIezvcdGtad3NScW1MerlP8ose8Y86xf/cJf+HIcP3Z9z/
QUrcZGeHpSWSqsDXFhT6rFyX5KmiRGVwRhGc4Pr7zk5uR/pYsS5G/D41focY
ayPE22iZB/jwXZTjDsJ0D2XoIRrHeW6MOsY2VsWOZbV/y+TbNNqWVaYFhWVJ
5VgxOJpGa93gqJvDy970Zqy8nQEHU/O4cXyy+vRZ6+Xz3Ven++8/3f/g6cHr
x3vPj1uHLdCWygtLuVIjbotoiSLkKKl/hNw/xoaPcRAQERqmxsO0uAnl7Jhi
akI1w0uIFAWta9GX3i4sHC9vPd3ZOz06OH24++y49XB3dXultlAs5sPVXHht
Pn6wlN+tJQ8Wco9Wqy92zlY6PdvdOFhrbi3Ul3LZSjRUCngasQCosesZ/3LE
vhDQ172qilO2HNZtpayLAW3JKS06JFmLwCvjyQgIxtQIeaxPgJoSYWY4sxM2
Pn057n+7tw4EzLcZ84HdNDQc4FqAI8B6+sQEfMENfi2pkjDNh/XRhm/TBm9w
Ju6aKFNOJlqDhRjICGC+p43iQXMBwJvxujIuByA37bTaJQIxEa1mkGthz6Pl
2kYmBt5WzyBaeXNhjSTvtuRc5oLHCr4L5p/DRulkaf5sreZq46BWWk5G0jaj
QywwcphOiTBq0JZ9XpAHjhrVp+tLL7fX3t9df9Faeby+8HC1sVnKgUljIZUG
bXolV9muLm+Wm63K3uHS8VK6mfdmk9agEDeH6B3iwJGricijRunFcvlxLXlU
Dq1FTHkzL6llSLlotYRst8oiKU+mnik0K5WNpeXdjbXtjc3d9dbu8sZ2tbGW
yjTc4YrBW1Jb8yJ9kqUMkiQulMQ2LTCe8cuWAXK72JIurrRfqBhX6GeNdpIz
yPHHJM6UypFWOzJKa1Kij/LUINQFKNIgCUgSJAF4QZNlubFzdiTwXLwJhjUj
iHYMzUlheBgsL4fjFwqCElFYpkpoNGm1MimRhFkgcv/dfMcxqh4srx/O6Zxi
3ZziXYIrLgHzpQVvMGI3aeFrZ5/GWi5AVBfGZVcmpbdnlN0IzTBU0wnX96EN
QyjlEJw/AKcPwchjM/jJKQx0Gg+dJo2PU7uHmW0jwgtQ7Tm4/aJhhaBeQEvm
Ybz8BDnWB/fcmXbcgIFkHuo4uyAo2ovzdQCEZ403oOpLY9LzvaJfdQt/2iX6
v7vk3xvQ/bdJ5w9QofeI0fvMxDQ7RuJHmMIgi+8jC7wIoW9S4h9lB3o5wR52
tIcZ7aBEb+MiVzGRy+jIFXLmDjZ8G+2+i7V34a2DNNuU0EfUJrjWBZl7VRNo
mYPbNu+m1b1u8216Q61QYjcV3Ygn1pPl3crKo5Xd09bJ64Nnbx+/eLr34tHO
s8PW073NV4d7bx8df3B09KzVOlxZWquXl+r5peVieSntjJk4ujmcEIlQ0GZl
FLiSBNeSp9WYMfnMqBwK+KV5GcKIWJ81euf9+dXC1nHryctnr968f/rq/ecv
Xzx58uhot9Vq1rfr5eOleVA/X7eWX60vnq4uPF1dfLax8mRr/dHmxsn6OgiN
i9lUNR5aTASXEt5qwJSziBNaVlBKDMmIVZdkN2vfSpqXAuqqW1a0CdMmtUfM
EaNnsH0dDMgwb3aSOtavpeKWo74PWysf7a7v5BM5q87EJIN91GQMfmJmqqdf
SCCceaherqEiebAByvAt6vBN1li7Fj/uZmM9PEpaK24lAk+rxbTb7dYo9QKu
WynPeRx5r9MlFwrxSL9asl1Ovdpc2qskqwFr0iiNaoVZqxJsZ2zqrF2znPAe
VNPHjdxBPXu0kH/YrOxU0vWIN27WgHewS3gepTRs0AABv96rFQ8XytuV7G4t
+3Bl/sV2cz2fqEf99WhwIZFoxBKg3m4VF1Yz8yuZ1Xq0EdT7NXQZBYIevnkP
MzAU02keL8wDeB/Ox7cz7q2kZdEjz2gZSTVFIcCoZWSTWeiLWqPFcLKRK6xW
G62VpdZyc31xcaVYXUjmqr5o2eTNqRxZiS7BlgepQgeaa57mGSa5umGOsu87
eDnibq64TyAblamndSac1U13+rmmsNAcERkifF2YowzMST1EkYcAepzQh+d7
sGw3muFEA/MlWREE8yzgF2/BkOxEmnuO7mEz3Fy6U8B0ClkuEc8vEQVFwgCP
56WCvD1ng+E1g7OS+yhOF4x1d4p1fUZwGaO9RnZdp4dvMBM3KOHLeN9FwO+E
6vyI6NKoqA0q7ZpVDQF+gQUjdQMI+QDgF8UaRVIn4XjIDAY6S4DNUiEQet8I
6xbgd1L9qxnLOc3yrKwOEZRGGNkBQrQT4W2f9d5GBe8R4t1zmWFGZoQc7kG7
bs9ar0O1F8Zk7/TyL/QKf9kj+WGP8r8P6v9hwvEvMN9PkP7rhNAQyTdLceFJ
NtzZvbLNEKZ9hOMeYvl72CHAbxc9do8YuYEKXUSEzsHDF/GJG9jwLVywgxIc
nPNBmB64yE9SRVmWhtjRlAPzDe04I/v++GEidZzLncyXHy/lwVGyU186Wt87
PXzywdNXH718+9mHn75/+uGTk2c7Ww/X1k43Wx/sHby/s/d0bWOv1lgrlxYK
uVolW64l46WQPWZWuqUEAx+rZ2OMLLSJDjMQJlUIYMEzWsSsFkk0kdgOjtwl
c8VclcXK3sHusydPT5+9evr4+ZOjR492dh9vbZ1urL+/uf5ha/3T3dbrteXj
amk7n93M57bK5Z16Y29pab+5sFkrrhSSy9lwPWrPOuRRDSMkJ3sEaA8PXjCx
WgnDdtK4FtKuhLWA4qWwp+K2+KQ8AQIqRE6xpkYByBoKdjUeeL5SB3lyKxPN
2/QJvcIv41s5NAVTIJ1jGwTCoFbjVYo0cyj+7CAb2kUeuMmFPnBy0HmT5Oy0
c9y7l46thr0WiURCpbKxKDWHmXJYFhKRos8R0MoaUc/DZgng2Yy7QCUHaoQs
S1HrStzdCFoXQrazayuqyf35xHYxslWKbBaizaSvHLTnPKaC1zYf8tRi/mrU
Vw37V7PxVjm7UUiuZMPrhchuLX20VCgFbBmnqRxwNZOJ1Uxup1w/rK9slxbX
cmthQ1iM52OHYVMdA+i+EZtQsF/OP1kqPaqn1+O2ulvZcEnLVm7OwKjauGY1
1aCmGc08R1AXyHoilXh6sVABU3NzPj+fTmR8objZG9XaoxJjmKsJMiR+Ks+B
oeugFOUwTT7AlPcypF0gOTOEHUxBJ5PfxRMOCqTjcjVca8QbrVS5Y07pOpPU
RRHZ8XwbmmtHcp0ojhPFsiNoVhjJNIPXQzH6KYx+5kxmPMFKJNvnyHYG0cLC
Gxg4HROvYxINjDkLg2GnM+x4uh1JtUJxmj6Y+A6G1w3n3oVxbyIk1wmmGzQf
CM/X52LXiOFLWN9FmPWM30HhhUHejTHhgynpAFT3AGbomdX0zYh7Znn9GM44
4HcGMwlBjE9jpwC/UEb/KPv2kPD8mPrdKcu7ssa4oDzIzPfQUg8Isfvo0F1c
9AEl3U9K9jLzI6zCKDnWg/a0z1qvAr8ekf28l3+pT/irPtmP+tT/NGz83rj9
+1PuH8E8F9H+HqwTirbA0Xo4UjOJ042QTX10Wy/D/4Ad6gLhmRa/QwhfRQYv
wIPvzYbPIaNXMJFbpGg3KzHBjcJ5QQzgVx6iG2u8s7sqrenCu67kcSz/pFR5
tlh9vlo/3Sofrlb2lpePtw+fP3r64enrj97/+NM3f/jsk89fPAeGu19fOKgv
PF5af7q8+XBhtVWstqq15UqpkI5GYu5g0hXK+0JFH9UqIVuFJLuA5OShbbQZ
PXZah0aasHgLgWajs60sroGjsihDEf98pbSyuHR88HhnY3e9sbxRWzxabJ6u
bbze2Hyzvv56pfmoUlqLRspOF+huOY+nEomCrLi1UF2fz68WU9/xW3CrQEjO
WbgVhyCjo1YdvK24dj2iWQkqN6OG7YS5GfEChLMWLWDTyCBxYROEwS63iA1e
P6xkHy+U15OheY91LREEShqUxVCyFE4kna6A7oxfE4ekJEA1JCiAV0+GpnWc
Ba9+OWDdy0QOC6n1qD9kMul4PD4Rp2TR41ZjMx1fyyUW4oHFuG/nzHnNfiU7
a1MsRizLcftWzreR8W3lAq18EIwbWf9K0r0QsZUDxnLAVPAZ8l5jLepuzWdB
Qn662QQh+XipulXKgDdsxL2bpQQgF9QKQDHYM203VPyu1XRquwhm3/VXmwen
q3vblW27yIzqnxm/04cbhtiFkq1s9v2N5cNSspXxV92qtJ6VN7ABvBULezOi
dprZFj3TaOZafUp30uHPh2LVdH6pnKqkw0m/w6Mz2kQ6O0floEvtJIEVy3Pi
GaZZonzk7IGAwi6qqIsm6gDw0nn36Lz7TE4ni9vLEwyLpVC5GqnS4QRGnNCE
F1nwZ88+M6HYJjjLMsuywZk2ON0CIxogGM0ESjWBUE8gNVCUdgqhR6OMeJyJ
hDVQURoqXE6GSckwCQEhJ+I1ZIqJTDPjaFY44Bev7Z+V3MUL+zD8DqSwHaO8
SbbenPOfJWdK5CIhdPE7fkeV5wYEF/s510b4HRDxwIyxB/A7o+qZEnaB/gv4
RVAmoMix0ekhCGoSRpn8P/hlVdo48w/YpQFGFsJKozgZPCuFpcWn+YUpbn6Y
neuZS9zF+9tglmtjyiuDkkt90v8yqPi/xrTfmzT845T5X2DWHyHs76DsVzH2
e2hLL9I4BNMOTKl6Ydo+nO3sMSW0EJMepTISaHpqjBy/jw1fQQTOz3ovYYL3
saFBQmSSEJ7ChyHYyBgxOU7NjsvzJO0809aUAf/NPEyUHldKjxYrx6vbHzzZ
/+D50euXh6fPjp48evLs6evXrz799ONff/rll2/evn325MnW8k41tZn3tQru
g7J3PWleS1jAEdhMB6M2s04kcWitxXgh7skaFFajxuz1uk0uvUDD4GhIPBOB
LJtiaxECHYavQkuVRKuFHw7o01F7I19Yma8WYtG0379SKe03l45Wll7ut46a
1UbM75bztHN4r5xTD9iWY66yW18PWPZKsf1CdClkbXiNVZcmZxRmdZyNkLEV
NuzGTEcpy3HSsh/V7YTUe0H1SsjSDJiKFllSLQhJmKY5tI4M9whom0nfatS1
GvW00qG9UmK/nAQ6qKT2F9OrhUA5ZJCTIXLSeMbICQixRtKomz5lwY9EeKiG
WbDpVj5MOZ/lfRseddHri5mMZj4vZtSVfe7D+WIz4i/ZdbvZUM2t94uoPh4h
q2HPW8TLXtVxzr2TtG6Dv1tIvxUx78ftG35j06leD1gWnIayTXc2k2TiR0v1
hxurh+uruyvNrbh/0WNfDXr2svHDQuaomN1OJ+Y9Dq9YFFars1ZrIxzdq1Sf
rW+cbmw9bK6sxWMaIm5upI/Se9fDQJ8Wfa8rvhd5+8O47mFSv2hj+zgzLh68
7JI046aKX6VX0HRymlZFBxU4HLWnCqFMJR4vR30pj9Iu46mZEiNXbRcqTCyR
hiLWkISWOboKi+dPoNgDGE43jvsAw7mDYd0kcm99JxLvDlV4ny7pYikGOKoR
mgZKUY0TFcM4xQBB1UfS99HMA3T78Jx1hGAcwOgGsboxtHoSJp+AyaaQKgRa
jsSpMAQNDqPCzIoRE7ypUfbkBBsyI5xFydAULZFponIsVI6ecPb0Q/ksTtGD
U93B6i/i7T8lBn5Ejv0bOfETUvQ9QqANYe2YUndMSu6Pcq4N0d+BcH+JUpxD
GNqQhruzyruT/DsTrA4oawDKHJugDveiOjtnbz5AXB2iXIPwr0GFFyCSX80o
f0UvtHPnewXVSUEFJSyRxGW6qETlFVCi8jQI1dxiFz15Gx+4PmM5P6J8t0/0
i0HFfx1R/8OE/ntQ0/cBvzOWH8Jtv0DaLqFtdzG2s0ty4PozhJHGAaJrjB6c
mgszmPE5dgZDz4wT4/fQoctw3xm/IKJjQ/348AQhAgUiRieoqUlabkKSwSuL
NPOC1LdpTR5FCw9L84+Wqg/X118c770+ffLxm1effvL644/ffPT2k08++fKL
z778+HPA78cvTl8cbB4u5rcK/vWMfTNtrXrlNZ9qIWw9WzJhNRrFYhVXYpBq
/ZaITe20m5x+v98bcttDJo1LzFDgWGoMU4HiqrASLVmuoum0bL9TXUj51mrV
jUa9kc2W4tHVUhHU6pO1pScbS0/WFrfLmazT4BQzvFI2IHcrG9zLR9bjnqNy
Yq8QPjtt5TOUrPKEmp3WsOp2WStqOkzZtkP6nYjuUcZ+lDCuusSLXlNWL3Fx
SA4OMaLg/F3cvFmxGnGm9JKoil/3WvbyMaD9QvxRLXe0nGtmPEmbVIQblWKH
IwqKiw034octxFEbcSzIhmfEpIKctmSV7IUthzF7yedN26xBjXIxFm7lUieN
ctVrS+llWaMsb5ZnDaKSSdxwqgC/ZZNwxadei5hWg/qNiGknbtuKWJse7YJD
s+jUFw3yklULUsFRo3K6tXa4vNjIpTJB/7zNGFeIM3rlSsizlYg0g96UTmVk
UCVo4E5kr1RacLt2K+WXm2efHT9sLs87bTI0XDA9qsVNF7V8wO/zvPNlwd7y
iJtWdlSIMJFHnNzZnJVf9MjjJr5BOWfUMG1mUdBvSGV8mVIkWYyEsn69Wysz
iyRGvsouBvxKdHN8JVGkPnv4IFmKQLGGYXPdCEYHht3xHb8Y1nU08xqWeR3H
asOxbxN598mCToqwGysewYgGUYJelLALKe7AKh7gNd1EfR/FNIjTDWA0Z4s0
/n9+EUo4ToHCq7GAX6zyjN8p/gyUNw2EVmCJWgLTPCd0sCVOltg2JzASuDo0
RTdE1neSLDdIrnfIof+gRH9Ejv6EEH4P47kON96FyO+OCe+MsK9+xy9S/h5M
e31G3TYtuz3Bax+ZuzNE6hgm9I6SBv7O761O+JUB0rUJ9lWI4OKU+FczinNz
2S5BbVzRxCmX6MoGV1HnyaoMSRknrcJE88Ocwn1a4irG9y7U/JMh5b/1in84
ovvemOF7k+Z/hFq/D7X+M9Tyg2nrT2DW83BrG9L2AGkZQJgHgTD2YbJ/khmb
ocWYzPQcp4Bn5CcJiXuI4OVZ//lZ32WE/zY60IsPjxGjEFIMSklOzmUmwT78
OEqaJenmBc4VQ2TbnznMVR4u1h9vrj073H/1/PTjtx9+8fnHn3/xyaeff/7p
Z1989vlnbz/9/O3HX3zw+u2Toycbje1KdCVpaUZ0RZuw5JSWPZqy15SyG51y
uZBMI88gVVydXmw0qkxqmUqhkFmcJoNby5RQWDIyQ4KX6ZgOt8phk2uVXLtO
mg4512vz65XyciFfTURriegeyPLbq49W6s/OTl7Vd8uJolMb1QpLDjWIfw9r
qYNC5Lgc380G14B3e/VxFcvNw4fEJL8Av+CUAUCyKnpew9iOGADIOeUc4Cgs
59hYBOC5ANt5p67mNmwmvIt+S0jG9grnKk7dRsK7HHaAmeFRLbNdCVeChrCO
rSFP6alTESnJy0U6aRDFdKcRM2jBj7nJ0AgXm5XR60bRdsDokYgcAo5bzN/O
px8vzD9ZrNQ81qxJGVPxQTxoJd17Wf9uxtP06uZtkmW/djPpqDhUNZem4dHl
dMK8XlKzawp6WcmiKVqA/9qbyRAovLVEOOv3JFz2kJSvI2EsdFLWoKq6LVmj
1sllCpEzEgxCRyP5ZKKqz3Ncm3+1sXayWF/LJH1CthA2aSQismp+K2gE89hh
VHMS0zaM9Khg1kjo1xIGPCJMysKNmrkuJc2i57isopBfl854SpVYthwNp32O
sFWo5YsNfI1TbglodC6JSEPlSnECJR6YL0EAnaH2ThLvTZFvw+Zuz87dgNGu
zlIvz1Iv/n28DKdeRdBuIOduoebuTDN6ppld08xOGKcDxu9AiO6j5Z1YZRdR
34/RDKDVgyA/YzRTCDkUJpsB/JI0OIqOQNUTCRo8SoYECMMlSKQMTdZTGCaa
wMmW+XgqP0/pZcnsNLGFyLJOMm39dEc7zXuBFvwZJfzvxOB/4HzvgsgK092e
lNwd57ePsK6PMc9PC86hFBdmlFcmxZcnBNcmObcHiDfvz1ztmLk9hOntR3Y+
mL599jgP7OWRuUsT3AtT4vMw2XlGblTSQBnWmYY1gXpRKK9xxWWaqIgSz0N5
pW56+iou9DOY8wcTpn8a1vzjoOp7k9Z/gtr/ZdoJ9M9Q+/chtn8+e6i35RfT
lquz1rtIex/KPgSEc49SwxBWcoaaYDBzDE6ZyChO45Ods8Grs/6LcP+1WW8b
0v8ARGhSbJKWnKKnoYzsBDM3zg3DRQmCMscy15TeVUdyJ1k+ri8+3tp+9ejw
9ctnH715BUrvJ59/8gmA98vffP7rzz8CFvzpVx+9+fTlk7MVuYuZzax7JWZa
DKiXgrqGX1dy6fIOQ0SvUc3RiJOT6FEEDUEV0vh0Ih2LxjGZTIFUSGVSiDQ8
V8x0ukz5fDyfivhtRqdOFbIY68lIOeKvxkM5jyNsUjdT4ZetldONhdO16get
pZfr1f1iZAnES59hJWzdTLiOS5EDUB4TjrWIpeZSAXjVmHETeUaGGPDysD4u
VoEY1OHGsxrmvEUYFhEiSkHaIM9b1MBn12LupaCtGbIflxMrYUfZrinb1Sth
O1DFoak6tJsxd9Ymi+m5UTUrKKPE5JSkkhoWYP3sWdF4u262TzXVpYP1++hI
N3XWjIF46WgNBS/BwLUk3FYqfLo0f7pUXvDbwJwAJoqdTABMNQeF0F4usBl3
bsRsB3n/ZtYfUnNdfKqVRZChIRYGLq4Uurk0r4DlFbF9UoFfIXLJhU6F0KdX
xR3moIyvIaF1FCzYCCuETh7dQMPL8Sgrh+6V8DNm3Voi/GSx+qxZ30hFsxa9
HAWRwceCfMqKWw1msFZAuWzjVnXUmBCkiF7RTLuaMOSSYP1aOoDXKqN4bLKg
T5tOukrlcHk+ns4HPRG70aMT63hKi8Ts0zqjRotXIdPReTI8X05gKkF4hkBJ
XaPoWyPoK2O4y+O486OYdyfw7wGN4341hgU6N469OIG7AnS2wJjSAaV3wthd
SEE3Wtp7dlt+9QBRN4xTD2E1YwTdNF43i1HDMSokVodjmchsyxzQnIFCUuNx
KjxBQyTpyEwzg2tnSbx8dUCoDQi0Po7CSZfZyHzXDNc1ynJ3MLxXaP5fkn0/
xrp+jLT9Em66PKO+BRHdGePcGmffgHAvz4ovopWXoZJLo7xzY+xLE6y2Xsz1
myPv3hq50jfbCdQF+J263Im4MEC8OM66BBVempZcYKQnpTW8YY1vWJV8x6+k
RBYU4JzcAD11Cxf8Bcz1L5OWf5g0/ReI6b9Czf8w4/rBrOcHcO8PYJ5/nnL+
d4jt+xDrv0LMP4EYz81YbiLtXRjXINY9RPSPzEUn2OkpSoZOL9KZFSK9NI1P
dSOibbDAFVjg2oz7Gtx7FxPsI8fG5lIQZg7Kyk4ys2PcAFwYwcoSNE1WYKlo
A01/drdUP17ZfH588OrZszdv33z6xedf/OY3X/3+9199/fWv//Dl57/59Wdf
/frTT7/48OXbx3vPNqtHjcRe0btfcO8XvBsJe9WjLTu0eZveKxXKSFhY99hM
7zhuAkGAYVEQBHoWg8eSEHAMHI4UCyWxUHipXFmZryxk0oVAIOWwlfzOtMOY
cZoCGqmBQ0maVMeN3Mv1+ou1+ffX51+tlJ820oDZvax3M25fDhqPC769tBPk
z7WQoeaQ2eizwuluOWJYAO1RokbFM/3UoXb+dK9PSCpZpUWLBMwtjYBzLRHc
L6UfNvI72chGwn9cSR4WY3u50HbSt50CudS14jeVTNK4nKUiTFpZiLCMWjLz
i0ZOhI9106Am7JBg6KZmpkc91aOd6TOix8RjXXPdt0TjPU4OVY2Ha4nIjZjv
ST37tJEDzr7gMwNtJjzLIRtIDnWfcTXmBPnheD7RTPrMfKoYC2PDxknDPVL0
jIVJFsIhlKE+PnzKQCfbBSw9myqn4tQsilXCzZg1fhk/pBTFdXIHn6EioVV/
x9kv4cY14orTAPr743r+uJKedxk9QgZn9IGROJVTsZoOWcPMq+joeTnOTh7S
Y7uFkDbOZJucMGTgwLQckJTQOpBbPOpY2JLLeAvFcDYfjCRcDp/B6FQZHEqz
R+0MGb0RkyOg1pm5UhVFJCfSZSgcZwJK7BhGXh9CXhpGXxhCvTuA/PkA8mf9
iJ/2wX7SO/PT3umf9828MzB7bnD2wjD27hihY4rWjeT24yTDZOUYRTtBNUD+
P6be8kmSK8H2/AfW7K3tvh17b7p3ZnpmeqYltdSSqlQqzMyqrEpmDGZm8PBg
jvAAj/BgZo5kpspiZmaUqsTQ896s7X7eG639sGbHrrm5JXiYxe+ec9z9ust8
RLGXIEHJ8iBHERTIAmJFSA7HYHtS60zr7WkjsFptWKUKQHCwddrTENdbUgYk
Z0GLVl/BDPh1JyFnTG5MUVv8JgfgVLsytVcc/zMv9BHT9yndfYBq6wDwTquO
4lRHyPojDMtBlm0/ybhvGt4zrTqAh44Ocw63j33eMbZ/kNo7ROvrJ3f2EI/0
UvcP8w/gVIcohsMU0yFFlQjaLrIFwrPWuaF1rEKWJaFhgSIr9QjzB1jJD8iR
35GC/xsl/L/TY3/HSv53Zu6P7MK/swv/ysz/EzX9e1L8/yRG/0AMf4gPfEaN
dLCT/YLsuCg/LS3hoAZJM0dRLsLQMqRaFSuXGeK5SX69l1U+ysi1UxOHGelO
Xq5fWp2AZwgAXngWBzcmtVmGPs8xFcWWEoTUzeGlYOlkdeHS+sqF7VM3r9x9
9hT47c8//Y+//vyfv/7wH798++tPP/71px9+/um7b398+/r9kzsvb555fHbl
3k7jwVb1/jrAKgWY2s4Gwdd1MeItIUa/Vi8hkEi9g8S+MeLQNHOaLmZKRCwp
jyZ06h3VVGlzZvnC6saN7e1r62vn5lv3TiynA82wK+cyhLTSjF0N/PHe5syz
U4sPN5u3l4t3l4oP18uPN6v3V4u35tL3FtK3ZxMXy4FzBd92AskahW7+tF9M
weR0v4zm5BGM9HGPmF51G3ZLUYDMufna6ZnybjV/dXn26bntByeXbyzVAb/P
Tq3cWa4BW7xYid9ZLNxbKm7GkATMNlEHQwpazsBf8mlnHPKQcMpN7deNHoH7
99sJPX7meJhH8LFwZvyQgzKZVPDjsDAgZUWUvIuV5O2l6t2V+m4ufKYcX0ug
Gxms6jVGdeI8ogMpZQcYfS21XEhEbDq7jG8UsPQcukcuBoKI0+KJESOLFtQq
UzZD2KT2qCQ+nSzu0M1FfbMRdC0b3cjH634k69DlnPqcTTsfQsC0uVuIXmpm
QZvYLUQKVtjBIcLjHXE5FRz5sldVNXFzGkpWTTKTOiyUYxpCm47WbZdOOSCy
UUY2wUyvVZaMu0DzrVcT9UaqXI1n86FExh9LoclCAChTwDJFXyKLhGImjx+2
uySwlSnUEGiSfqKgkyhoJ4qP4IUHpnh7hxkfDdI+6CP9qYfwp17iRwPkz0bo
X46zDuJ4/STxIAMeF5oJcoSq8jHUGEMVYCgxugylyXxMVUiojsm1cbUxbbAW
rf6iLVB2YGXEm7dZkwZDTKOPaI0xvTVtdGYtYCf4Aaxg9ma0SOvFEFJtjKiO
TsDRPijeIY/uE4c+46CfMJyfkc1fEHVt01DbmOTQhPwQUX2QajhANX4xDX8+
qfh8QrZvSnJ4kHGgc2Jv5/iBfsKJQVL3APF4N6Gti9Ra149TtpG07UTtIUlp
CqqTtXMs7RxHP8PTz3LgGlleHGHHj7Die+ixD+iRf6JHf8eI/zcALzv19+zi
h5zSB5zyvzGLf6Bmf0dK/p4Q+0dC9N/woU+osSPc7ICoOCmt4OU1gmqWpF2k
QCuwYkkpXxLJl1jSJaJwdpRT6WLkjlLih+ipDm6uW1Yd1czgdHMEAK+yOqZO
0zQZpjrNghM8XUrmKFtiS/HSdn321PLmxVNX79198ebrH77/9def/udfv/+P
n7/55Zdf/+cvv/z11x9/+uWbd9+9fPzm3tWnlzYfnpq/v1W/s1a8sZAB5Q4I
FL2T2dBKxL1dykQNGiWFzBgawXcNMMZIai5kkpk1Aq1L7cj5E5uVmSur67e3
t+7vbDw4uQkq54VGFpjUXMgxF7BXXNr5oO1yM3lnpXRjNnOlEbveTNxdzDxa
Kz7ZKD/drDxdLTxezt1oRC6V/Gfz6BJmLNlkNSc8h5lmMUvJqQW8pEDVBcG4
ljo/Uzg9Wz1ZK26WshcWG49Ot5Y5XFsGR958urt0fa54thC+VI3dXy7dW8qf
y/oWPNoYxKxaJTkdt2YR5zVslDHkovRBvfsAv6q+A3Z8b0xIjopoYRE9oxKV
jZCdOooJSAWT9OZs5tZ87tZ8YTcfBIa+kwsBflNmhZGNRySMjFNTxaz1oD0f
8MYQq1cPu1RyVAP5dbBDKlJSiHYh3y0ThXVwxmHKOo0Zh6HgMTVCSC3kboY8
K+kw4HclE9zMRzdyodmAYz3tB//iVDF8qhACbbrqUIEQIuw/rBo+6OeOJRXE
soEdlU4i9C6UNwCN7dPgj6hJR3WsAZNoQi+aVglwWgXNYRb5wAwTduYyWL4Q
yuYCqbQvlfFn8v50zpfJo7m8L511xZO2SNjo96s8HrnByYOMFAE0xpL1MeRd
DEUnWQoQ/nKM89kw85N+6p97SB/1kz4dZeyf5naQRN0UyThTiRMZqJCTrUZ5
OoyvDfDgAFeFceQoS+HjwiGJIQGbMgZn2eGb8cdq7kTDG2t6Q1W3O2s1x3XG
qAbIljI6MiY3QDhn9KQ1SAyyhsQmH08VmoZCo8pQvzJ8XB46LMP2C1x7OLYv
aboDVFB75e1j4oOTskNkbRvNeISs+3JM+vGE5LNx0Z4RzpcDlP3d0we7Jo50
jbf347r68Md7cEe6CF8Osg5Oy48S1O3AhUXFIWllVFGZkBVbkhbGBal+Zvgo
NXCAFvqCFf2UHf+Ik/x3dvKfWYl/YCf+gVP6iFv+kFv5gFX6Z1ru96TU3xPj
/0CI/ish/DE9eURQGJRWpwC8ygYJRGLdElW1CsuXZNIFgWyRLV9iSObxvOoQ
I9dJiR+hJ9q52eOtS8Czk7oZHFxrrWhQpUiqJEUZp8lDNEWIq0+pfHVPaiWz
fmX71PUL1+7fefLi9Tfvf/zlx//xnz/930C//vU/AcK//vzLL99/88PbF28f
3Hhy6eT93UUQBW8s5W8u5h+uVZ9uNe8tly6UI1sJ9+lKdCXtq/ntPkgmwRFE
0yQjX+GUG11KsxsyZ13YqfrM7Y2NGyvzN1ZmH+0sf3Vx4+5qdTvjP5nzX2ok
1iKOGY8OZOOL5RAw2Su18M1m7NZM/M5c4uFy9tlG6fVO5dV2+d58/EolcLUa
OpPzbiacO1kfaMcXG5mdfKTkMebdxqUUtllIzCcDc8noeimz2yxfWZm/s7Vy
aaF2rpm/uz5zb73ZSs6VeIu7ufTlUuhSCQPOvhm27cTtRT2/oOXkIEaQOx7l
T5nGO2zTxwXtnyh7DwQ5uJScnYVBKOXayBP6qeMxGWUNM7zYrN9dzN2YSe+k
vOcqsUvNNAgAEYNEMtUnIww6pSxMJw0a5KhJE7CaEDVkkoocKoVTqdSyOQoK
2SYWAZADamXeZQXANoNI1WepoOZGxFvGnBUfaOXO2ajnZDnZ+owu3SxmWww7
liPO+YAZwAsyg2qik3z4I2XfXivumIvalVbgUc6AamSfmXhUMrxHMr5fhmuD
aD0Qa1DCHBYwR2RCnEbFspoVqMcQj7oyKV866QHK59ByKZCI23JpVzHvyaad
8agxgmmCPiXmlbtRidnBUekIEnhUoOrnQj1UaRtOsB8n+nKSv2+EtWeQtgfA
C9oxTTbAgce4KpJIR4dsPJ1XbA7KTCG5IShuvXnBz1d4AcI8dVBmSGhsWTNa
c0cWwqmmJzPrz8xh0QaK5m22uN4QUevDsCWhtyb1jpTOmWydubIERTovW+1i
KLBxBTYKBQagYJcq2Cn3tUucRwSWdo6+g63tIiuPTYvb8PIjDP0xpvkY1XBw
mP/huPCzMX7rOPtI+/oJR3qm2jtHDvdOHe/Fdfbg2k7g9g8wDk3Lj+Hhjinl
IV76KDfVwU50MGNtjGg7I9zGCHW0FG7jRNq4sUPs6D5m6BNm+ENu4kNh5iNW
/uPWSxPqn/Cqf6Ln/5GY/O/46O+JsT+SY58yUm2AX3kdB89StQsMzQIVCJiv
ZFYknuHLAMLzLGENz8oNMNNdrPQxQalLWu1TVPvVjVH93LSmNiFJ9ysTeChJ
lEWIfBQnxuj6lNJVtqMVdPbU/MkbZ+89f/TVN99+/93PP33/17/+8J//18//
z/c///XHn/7600+/gAj93ZtXbx7efXrt/KML23d35q8vla/MZoFRPtls3F3O
A+JOpgC/vsuzsasLWfA1K7psAbUKU2nDemvEYEuanWWPbz2durZQf7A1/wDE
49XS0+06yMa3FjJnCv6tJAIi8WbMthwwnM56zmTcu0nHTtx2KuUEtD5czLzY
KH91svZoOX17JgKIvr+YubeUfbBWerIzc3ulAtLySspf9JrzLnMziq7k4muF
ZDmAruSTq4XURjFzplFaz8VWUoHLs63AuRpzbSW8lyrR2/OZZ+vVp+ul6/XI
rWbyTNo761SmlYy0nJpXMbNySoQ36aMPKbr3QX0HzZPdkq6D/M79mokeC3EM
YJ6QU04lHDdqkYtF//liAHyKKzOplZhrI+OL6SV2EUVNn4Do44BfLywE/GpF
HDmTphPydAKBmEwWEQgwgxkxm1IOax6xAX4LLmPZa5oJ2OZCtoK7tQSjjNrr
QWfZ2yK64jYmjLKqW1dywEW7MmeUeIV4aPyYZPCweuqEenifcfKwnXjMST5u
wrerxw8oRr4UD38hHN0vwR0VE09w8F1c6oCMP61S0GEly2KSu5yaUMCSSXoK
WbSS81fyaC2P1oveUsaZiRjimDriU4RRedAjDbglLkRgt7GMJorGgFfqx8Sa
QRZ0gipvJ0kOEyRH8KI2gugYVdrHVo2K9QS5iaayCiGbUGUX6NxSEwa4UxqD
rau3Ki8fRgUwJtFHYXvWhFZdgRlfeD6UnfMBhFNNNDXjC1Zc9oQewAv8F8Br
imnMUZU1ChlDErWbpbRTIAdV7h+DsFF1aEQXGTVGR0yRMVNwzIxNQrZhqXmE
o+6jyDspUCfb1M02HSdpDgF4p8RfTPC+7CV+1jX1+QCxbZjc1Y87DtQ91X58
+lA36dAQt31KcYyoPk7SHWcnDzBi+8jBz/C+j/HeTwjop2T/l7RAW+t6bqyn
pehxfqyNHz8gTH0pzuznlfcKa1+Im5/zax/Rc38gJn4H8vP/n19Fnaieo2sX
mJp5OgBZNisV1YXCmkDWFMqafH6RxEoPMxLdnGyXuNyjqPVCtT64MaRrTMDl
cUl6UJ6cVqQI4sgU3zchwkjqpNheMrrLzvJ2Zfnc2sU7Vx69ePbV199+9/6n
H9//+tM3f/3hl/8A+unnX3/47vtv3759+/jhi1vXn109d3Nr+epSDYBwY7H4
cLP+aKNybSZxKodupI0nCw5A8W7RD1JxxW1O6NWYSp4ymwp2S9Pn3spGQF+7
t1F9sFG5t14A2fj2fOpaIwrc9lIleLkc2I7ZZl3Qsl+7gumAwMZ6wHA27boz
E3+2VgT++3a39mqr+ng1/3i18HSz9mi9dmOhcH2hBHL4ahor+6xZt7mMuRpR
P1AzFljNJVeyidl4YCbsawbcCzH0VCm+nvRVEf2C33Klnni4Wnm0Vn60XLwz
m77eTN1fKFzIYyWDyM+ZDHInQ7wpD6UfIfaA/KwbbTeMHaMf/Ij4xZ9Uw8cQ
xtRGQAd0pxm7UsJOJuwXCr6tuHMj7qggMEDMJaboWVMaxoSBgw8YJIiSjZk1
OiFHRMYJSXj25CR5cJA9Pg4xGHkvmvcggN8CYq6jtvmwE/SIpt/gV4swWJSx
a0GkAdGi6NQlDHI3CPCwIARxwipuFGK7uDh4+gRA2Ejqh/q/0I4cNE22G6c7
tJNHFMMHhP17OX17OYNfinGdCvqgkjOplpDNWr7NLANC7JDfq4+F7fmku5L1
1nLeet4zk3eX46ZcSJtC5VFEFHEKwRhFwCjEXGLUwUPsLJuNZrQRYPOESNsP
EGbBXWy4l6Pu52lGhfppQK7awTO6JEaPyuBWGD1Kiw+2BmALBulRGewRa1Cx
2ifW+uXGqBrJWXw1d6CJBmd8uVlfsuGO1xCQokGEdmXMloQOwGuOaw1RSB9R
GsNyHSZUIHSZjSSzEWS+YVVgTBeeMkfxjjgJiVGQCMUVpJvdZK2DIDWMctV9
PEO/0DbEtXSTNG0Twj0Twi+HGXtPTP/lxORnwH+HSJ19050D+BN9+GM9xPY+
2uEhftuEooOgab2rhZXYT418No1+MOb4w6j9nyeRD4noF3R/mzA+JIiNCCKj
otiwJDkky/TKsp2y3DFJrV3WPCJt7BdUPmHm/khO/CMx+gdS9N/Jkc8YiXZh
flhZI2lmmaBQq2cYqgZFUhUIClwgWUUoLQv4GRozPsGMDYhyA/JKn6re3+K3
OgBXRpSFEWlqWJkG/E5JYlM8bJznn1ZEWIas0p43JpZilc3KxsXNa/dvPXv1
+v2777//5ufv3v/yzQ8/f/PDj999/+M333z37s3bV0+ePL9759mNq7d3twDC
V5ZrV+dL99brT0/O3lzM7mS9yzHNYgReiujXEtaNJLIQsuesqoCSl9DLshZV
3WtaT3jOVUI3FlP3NwqPtsvARq/VQufz3otF381mFAh47gyiqNkkdbu04ZBV
reKKRTTnhgAd4CcBxS+3q292G0/Wig9XC89PNu+ulls1sBjdzoUX474Sakk5
DRmXpYA6Cj5n3muvh9GlZLgR9Kbt+pLHvBzzrcTRps+a0Epqbh1orM93Zh+t
Ve8uFkCQPleMXaomFnxGUGzlA4ethN4AZ8JLHwQRWnLiM/XQYdNkp/D4HnHP
fg9rIqlkrmPac2nnvdnYbtwOphoQwnfTrhoC+aRkv4Kup48BAQtGVdyYWe5R
st0qiYZN4eNGGSMDxN5ufHc3f3raJBKFjKao2ZCyGktu61LUs5UJrMSdDa8u
a9XE9YqMRV12GUqIvu41gyMvOjRxjTiiEkRgXkzVWg+lI/RDEyfU0z3qoYP6
sTYTrtNEOK6b7oQm2sWjhwXDhzX0YZOQ4FSxEZ0AMUoQi8xplluAd7s0IVSf
CFlzcUc5Ya8mbY2kdSZlyfuVKbcoamEH9DSgsIkJtmNWTswlBop4xUEf3+tl
WREybB4T6waE+iGpZQJyEjUIQ+vimNximw9yBTTukAkICRucIb0jqDP7Ia1L
Ajn4Or9cg0oBv5aoxl2wBeqeYMPrr7uzsx4Ab7hij1Zd4ZrLX3K68lZHzmxK
aHURpSYs1YbEsI8jdVJEVoLYhpeiQ4BfQ5TgTNJ9aX4wJQrFxcGYGA0IHG6m
1kpQmCcU9ikZMsk19xNUbURF24TgQB/5087Jj09M7QX+C/jtxx8bIB4foHYO
Mo4OcTtGRe0Tqg6C/hjFdoKTOMyIfEn0fzLp+rcJ5I/T7j9T0H0MrFMYGxeE
pwQhnCSOU2Zx6uKECnhrtgtqAh1XNI6IK3vYmQ+o8T+QI/9CCn0AHJwZ6xBl
R6AKWdNgaupsuEZXlimiHJufZgpTPElWDMRLMLlRIi8xriiNq2rD2uYAXOtV
lnpluT5ZekiaGlUVpqHctDQ5wQuOsv2j/CBRHuPqkgovmPEW4nOn5s/ePH/3
8cNXr9+CFvzD97++//4HIJCpAb9fv3339uWr14+evnrw8NGVy48vnr+1s3Zl
qXF7Y+bp6eVbK8WtLLqRMK9E9HN+VdMD1V3KikOWNQoTGg4mJcdgVtEqnfPp
tpKOi9Xg3eXM0+0KaLWAytNpBITkSyX/1WrwTMa1FjQseOFFVD3vUQGECwYe
ENgGCINQDeowIPfhagmY/rPtGcDvuWp8NmifwewgdqYd2oRFk7Drch5LyY9k
HIYG5topplaSobRNU3Qamn5HyqQsOrRJg2wes4P2/ersyvOd+dsLxfOl6FrC
10AtQQXXQhv38PAVk2jOqSgb+A5iN+BX2bfPTuhCaINxGblulZaNwrpFuBUy
XCx4QEgAx9w6+LA5AtFgfLeJPmxmjSMiYlTHz7vUBbcmrBcCP7WI6ErqFG98
iNzXRe7tkRCIdqlMz+WgsDLntNb9yGLEDeL3jM+Qs0gyZsgv5/hk7DBo3FpJ
wa6Z8dtmUGvWBKUNcqCUXhaQc0y0SeVkn3y8x07uc1IH3MxRL3fCzZ1ycibA
MehZEz41x6cH6V3iMUodepFFIzSq+XoVF3Wqgh51zK9LB/SZgDaPqUp+qILJ
s05O3EwLqvGoYhxVTARgXEhHjBjIKac47ZFm/bJ0SBYNCj0o0+TEQ+YJuWkM
dpJMfo49JHEGIASDvQG9P2Txx+1AvpgFjZoBwsCF/8avQI+2+NVjCltcByAN
z3qDTbev6kg2kEjZihXMWMkaqrsA1GgVARXPkjHo4ypNRKYJiyGMK3FRxcBe
ERLwXzgwaYlSPSlBKKtIZDSptC6V1EbCSi/KtzioOidR5yWrPDiOaWBa0c7W
D0yJ2rqIgN+/dOP2DZDaB8mdA6RjAN5h1okxQdeE9PgEdAynP0q2dzG9vexo
JzPSTgvtJ2N7SP7PqP4vaP7DdN9xYWxKGCaKo1RFiqEt0g1Voq46pi73wjOD
qmavstEpqRzg5j6hxf+NFPojAfuAiH1OC7XzEsOyPBkqM4DkBao0RxYlGIIo
EEeSEEsSUmGUJ04ylTmKporXNcb0s0Pqep8se0IY7xLFB6TJMXUFpyxNyTIT
/Ogw0z/IQEcFQbIiLjDntKFZf32nBiz4zNUL127dfvL05Vdff/fuu++BAMLf
fvfTt9/8+B7sef31+xdvn925+/L27QcXz13fXL61vfT47OqtjcZ2KXQy4wEC
AbLhhpJadlBOikDUlJ7pFU2EFOSMgVt1yhYD+pMZ1/XZ5MP1Mmi1N2ph4L/g
m38u5zmbdQOQQecFLgxo3YnbN8LmeQ/ccMhXMP25nHc37TlbxH773UdbjXtr
lZtLpZtLlaq3lS2TFihmVMbMUMqmK3lt9bBnJe7fLSZuLjfOVjPAv3I2ddYK
u0V0wG/NYzqZD9/fmHl5du31+Y3bS9WViDuiU7plHK+UVXJqdzPY2bx/PWRq
2mUB/oRqYJ+853PzVIeHOVA2cJe9qoqZXzYKllEN6L/gaFcDIJBrShaxmTbA
79unJvT4ZZS4nld2QfMRc92nLzihslsfM8lsAopocpDYdZTUfVwwNallswC/
wH8bAbQGMoNdk7MoMiZRUssNQwIHh+TiU8FGTC1OGxR5CwzGKCyKayRgI21U
RWAJwqcbqNNa0kRQSAyLyVEZLa7iJDX8hE4U1YlDOpFfJ/JqRHYVz6xk6+Vs
nYJtVgvseonPqQy6VTEvnEBVSbc05RRk7NysnRXR4oLKcVTc7xb0eEQDmHw0
Ak/FtfiUmZd1iAqorBCUp0LiAADWTTU4CWobzuihI2GJL6HG4iYsYsZCFixo
80dt/r/B6wkbnZjWjKr0LrkGEeu8MhCkjUHIlTYFa0h0xhtuIL6qDcAbKJp8
OaOvYAb7gzMeX8MN+LUWjIa0RhNXaGNSVYgvQ1vPXlOgdDk2pA5OWWMMNCmO
pjWplDGXsuQS5mRYE/RLXG6OA2VYMYbaS+KahwnQcZ55dELY3on7y9HJT7sJ
B/uJbX3kowDeEXbXuLAXD/WTtL0kczfF0c3y9/PDQ4xAHzPUw4qcYEU72OEj
jMBhmq+d4jkOnFcUpsoTHE2Oa6yyzU2SqTlmaPRrmmOamRG42auodYiKe9mp
j6nhD4j+Dwno5xR/Ozs8KEzgJGmqNEMTpyiiJBn8EX6AxsfYoqBIHJRKwhIo
JTZUBKYmzTQzbZod1dT6xKlj7GAHL9wHbBeqTMqLY5LsKC8+RMf6Kd5+bhCn
THBNeVVwzlfeLgELXtxZ2djduXDl6p0Hj5+9evnizdvXX7/7+t13X7/7/qu3
37599f7ti69e3H/y4u7DJ9eu3Tl76s7pzXtn1q9vNs8007vpyIVS8nwpvhy0
pjRcr2DSL56Kw+SQHBdTkbIGdsUumUW1GzEEmN2N2cKtRhTw21IjcqUSAEa8
FbUAZreiVjCuRyybMdtK0DiPaoCvnS/6T+ew3Tx2oRa7tVS4tVS62EidryUu
z+TmQo6K25iyqgDCWYeu6DU3Qshi0n+hnrm+UL6z2gAbSxE3CJ8A27RJCVxs
JeYFO++sNR+fXHp5buPmcm024MB0Si8sBUn7ZCF6bb4I/t1ywAAI9XFGZX17
eJ0fSLs/0YwfSEGEFRSasYvSaiZI+xthE5iCtmPWpgvKGwVGSh+3Z6+W0JU0
cAt2SR2FV+LWpl/T8KmbqD5tlti5RNFoF627gzPUJyPiNEyGRSiIW001zJ21
G6IaUcogqTqVIMCULbBPQHMwcG4e2cunBaWclEaa0MqzJrhg1ZYcprxVH9Mo
vFKeg8eyc5kxOTuu4CRU/LROmjNDwK+zDg3IJFEb7DcoHLDQrOQa5WyjkosY
ZAGnNuCCoh41gDftVaacoqSFFdeTEzqCT9jj4Z1AWEedzA4v70RA0h9VjiXg
yYSGmTbx8ogoi4oTfkEAZbu9DLuXZvPSnQGBP6GKZM3JHBJPIeGIMxCwuwK6
3+TwayweCHThlrxKvUdmwpT2uA7NWwCnoboTq9jQktGX0/vzBm9e78kb0Yod
a7jQutNeMlsKRn1ao04o4KhEGebL/Sw5xlCFOVBoVBOatkborSf2xNTxqDEd
seTClkxQF/bLfD4BGuYjEZ4OpQjt40zjENsw1rptY/KTzum9vaTDvaQ2AO8Y
twcvHybBwzTjKNM+yvQMcQKD/OggKLl0/xgzMMKJDHFjfbzoCXboGA3tpCDd
TO84DyPL4mx1lqMr0fTVKUNj0NDsNszgDDMTwDe1M11QtU2U28uKfkLx/4Xg
+pzsaWP4+jiBcUGEKIySgFobPjLPQ+G6GAKPQIBKWmtsswrHjNI2y7LM4c1z
Y9p6vzDRQfcdYWM90uSUtDgMqrEwO8hLDjFC/VQfmGRw6pzA0TSEl7HSTmHm
1Mz8ztLq7ubZy5dv3Ll779HDh0+fgEb86qv3wI7fvvnu1cv3L599/fLRq5cP
nj69fQcE6TtnT17bWrqwXD09lzuTzVwo5s/mU0sBR0YnxMQETDIdVeGBAMUZ
PQvY04xHtxZxn85GLpYz16uha39bd3BvIXVrJgb8F2C7GjAs+nUzbtWcVw3w
WfDpaw5l0wWvha27+WDr6kwjBcg9W4mB5ruTC21mA0CAPlASK6h5Nowsxr2r
6dbV0kv1zM2F8o350qVm9mIjA2ryZjpwMh8BY+v+h2Ls2kL17vrcw+2l64u1
tWRgJhmaS4a3q7lbm3MPtueuz2fPl4Ogm/t4Y5Kez2iH/sDr+Hf9+IG8lrLk
lWbVZB9/qmIRg4SwBfpvwFB3Kqp2mY05rBhvBy5ctIqLDmndq9pIOWYx7ULI
kDcL42q2k4dTE4dh4pieRTGymTCdYuJzQlp1ymaIGhQpo7yJGlfClgVM17Tr
PCyieqxXNd6rnhyw0qbDch7gd97vXgyhs35PzmoMKKUuIa8liSAu50Xk3KiC
l4DFKQMEinPSrIla1DG71m+AnGqJDRZYIB6QUy8F/IZdLfNNo3DGI085+DED
BfhsRDHs4R5zMdsd9EN22kGE0YZyOzFBT0DcF1dSU1pWxsxNObgxhB3wslAf
yxvgeMN8b1QaSKmTeUe+5MvlsWjUHfBbrR7I5lWB0YTIdXYJEODX5FOZfEpH
VOvP2YIVZ7Bi95VN7rwOyWqQhArN6tDC325yLpjdFZuzYjXnDaacXpNUKiMS
BYA3yJH4mbIAE46w4ci4Nowzh1qzB4q1bueO+YwpnyHugYMeKYYK/CEREuJq
PGSxY4pvn6BqhgYYh9pBeCYfGGIeG2R0jvN6qRBox0SuDc91TQn8k6LIhCgx
xk8M8eL9TAzPDuJ40UlBckQQ7+dGehj+Lpq7j2gbZHpw4ggDSjFVWSJcGFGX
u7S1TuMMwTg7bZofM8wBLz4uKx7kJvbQAp/hkT1E12GqpxckXjY2xQ0QeEEi
kMBL5CIktp3KcXL4LrEUkxpzsGte45jj2ReIlvlxwK8gDhz/INPXBfgVZvu4
mV5eqvWWcGa4jxYAdBN0ZbFv2ZHYCFVOFRbOLYAIffrK+et3b9978uTBk8dP
XjwH/vvuux+/+/6Xb7/99d3XP3795vs3z796+ejly3uPnt68eevszpnlxnYj
t9PInCvWzmRz6+FgzWFMqYVhOSWsICZhYkQ+FYFwCTUN2FPTrV8Le05l4meL
mdvNGOC3dWJqLgH4BS4GnBdEVuC5sx541qNZ9Btm3OqcSZQxCMp2+W4hdH2h
cHulAmwXwHu+ljpVjq0kvLulKKiNDZ91PurezId3K4lT1eTZRubKTAY03JuL
xVuLlcdb81dm84D3i39bPNiqmXH/xWbht/WDlxcqu5VUNYwtZGOnZyv3dlae
n994cnL+cj26GjYW9Gz12H764X8Wdf8ZZfbOu0RNO8+Eb3OyRis2aQNRgqmm
bJWATwdGA7nXRO1DuGMVh7RoFdU8yu0sMh/ULUdNWQM3reVElCxUysSUAj8k
NXEY/IlRi5CHwVDEACcMyqrbsBZHlkPmgkXUdGgwAcVOmQQUoyBFy7hZPVQ0
awC/8wFP3eOMalROPsfMYSAioV+piMh5ISkH2HRQIYiqpTGdMqxXglBhk/IM
QqZWyDBIOS3/lbMdGhFmg4NOecytSqMQaLUJGzuiIQQVI4BTv+A4yu5AaIcc
lANACO2w42+KychxmJo0sOJWVtjOCLqZIEL7w/xATIrF5aFki99C2Z8vBOJR
t89jAdiaXQqjU6aziWGzQG0RgvwMUrQtqPakTJEKEqm7A2WbK6e1p1S2pMIW
kbuzWl/RiOQNjrzeWTTbiiZDRqtLqRVRqSTElwY4kgBL7KNJMQYUZWtik7oI
3hSk2Xx8l0eOuTURlz7m0gXtCr9dgLq5aEBgx1gqhCC0TQidOIp6uJdx8Bju
80Fm+6Sgd4LfR1aMC2w0uYct8dJFPqIkhJcmcNL0OD8xwI52MTw9bOBxwVFJ
eAJIgI2yPQMMZz/F2s1yDYqDU8oUSZ2jqQt0IFWB5iyxXFWWs0ozlyb1+SFV
5rg4eoiJfk60f0S0fkKx7GVY27iOPqFzUuIkiu0khYUrs7DFFpbIyhC7WMqQ
0JhX2ppq+6wSWW49VVKeGWX521nYQXGsXZ46Kkh8zo18zgjspXr303xH2cF+
UXxKniGhq1rPnCa27l682ti5tb11aff8zdsPX7z7+tnrb15+BfTu+Ztvnr/9
4fX7n96+/+HVm3dPnr19+PD13Tsvbl99dPXstZ3VrZnibDaykcdWM+h82Fpx
q7IWIQjMJTOnbuMBzToFc4iwYecDrfiVZ3OO6w0M6EzWvpuyXK54r9eD54qe
3YzjdA45W0RP5dwbcSvwLKDFsLHpUwMvA+H5UiNxd7X8cLMORmDEO1lsNe4+
XYqcKUd3C61Fwb/dOXl1oXhxJntnLX97NXdrJX9vo/xwu3Z/s3Z9MXehntxM
++YCdkAKiNA3l6q3lhqPt5dXor6CXb0Qsl+eyVyfz58qBE4Xg2txRwxmWRlD
0/v/hXX8L8L+vfM+1XrUiHAGXdyhkJiaUfNzWmFBL6xaZGmY42ZNWMh9ERk5
qWIUDLyaTTLnhlYw3VrQAApyw6UA/PrEeBt7XEsZVE73qogDOuakmjamJo9Y
ONNxvWDWb1yOWJeChnm/NmfTxnXSgJIXhPgpvaxoU5fsmrxFBep5xgyF1RKX
TGDkMbUchlUq9uu1mF6QdEJRq8IhZxp4ZKuEaxKylTSSgkqEGXQdh63jsYCM
Qq5DKUIB1w4J6ldHw/qwT4HZuT492QtPeuSDLuFxp6Ddxt1vZu/Vsz7VMv6s
ZnwAZOUOuKTjQS0hZqUlnPSUl5nFuNmIqJSC0nFlNKKKxk2JjDeW8WNx1BlA
NBaVzqbUIFLYw1egTBB6gW/Kw6CvaS05k6vgxEpopIyGck5PRGdDZa6QxhWF
PQnIk5Z5c1Igd16G5JSQl6NEhQqPWGTnCqwssZOpQFlwgKsLcMwBgQMVOWxC
t1kSsMnDdpnfzrMYCUYb3ujBG3xEPUpSI0SlGS/V4aZEXVOiE5PC4xPiTpzi
BEXXx3WOC32TIj/Ac1KWmFJkppXZKUlqlBcB5ttF9xxj+U5wA72i0IAw2HqU
OtPVS3N04w3HqLY+rn9CFierskxNgaMpcYFsRZajzLCVqabilCY3CGW7RNHD
gF+C7UOC+S8E016y8TDD3M02D/PMk1zjlNTIFOppHC2ZqSfy7TR5gG/IKSx1
lWMOcizIjXWWODHM9LWxfYcEoTaAsDC2hxX8jOz+C86+B28/QEO7+JFxWZKg
K/GQpiq+4WleKKxfXdm9ee7q/Qf3nr/57qt3P7z7BozfvHzz/sXrb1+9/e7l
2/fPX7x/+vSrR4/e3Lv76u71Z9cv3T23c35tFiC8EEfmY87ZoLmOasqIvGIX
NRHxvFuy7FNsBFXbEc16EAbwgvFU2nqp7LlW999oBgDFYPtc3nkq6wT8nkzb
zxXRCxUMCIB8poCeBRsV7FQRvdqM35hL3VsuPd1qPtude7TVABEXJOors9mb
S6Ubi+XWqoFy7HwjfX2pfGsV0Jq6sZS+vVp4sFV9stt8uN24sZQH/C5HkYxZ
GYR4q3H08kz+2nzp5mK9ibaIXkt4tjL++YC16lID1dzwjFcDwvDYnn/gdH2m
mmxbCmgAvwBeA6kzCbEyam5Oywf8lk0SoKJRkNfzcjpu1SoG5C6i6r/B29IK
pgFmHVZSW6eFGSMm5piONgqwVVFGBOMnlPgBKxcX0/HrHvUCZmi4IRC/Abxh
WNg6BS1hYjJ2COJEIW4Y4kf/ttMjYXtkfK9S7IFlAYMmZrfGbPKgUeKBuXY5
0yJhmYQsNYsiI+NhJlXNpms4DJhFgxgUDZdmkfLcapnLA4VDxmTcmghoQk4h
ZqR7VVNu2ZBT2OXgdVg5h4zsL3Ssz1XUjyWEPwqm/qChnDBz+1FoMmKmpBFm
3scphoXluKycVmWTqkRcE0uYowkHFkUQzG5xmdVmmcYh03ukWn/rRQDKIEMZ
aT3V2ZLX2AoWdxEB/AYLbl/S4gqo7R6pDeTqgNwRljrjIiQhQNJ8R1poS4kh
P0fhFYgdXI6RxjKQ+NbW6wPUQY4hJLCFJU5M7kbkPrsi5IBCDjnqENjMJJOT
CPjVowSNl6By4OUWvMyAI0r7iPI+snKAph5kGkd4jgkpSlAEScooUZkgKNNE
ZXpalpoURodYgW5QdRmefUzvAY6/jevv4Pg6me5OmuM42Xocpz9KtPSxPJOi
MFWZ4sB5kbogBjJkaOY8w1ik6PJTcHZYnunlR47QvHsJjk/xls9whr0E3QGy
7hhN10fXjTA0ozwNkaacJEhHiMpRpokoC3A0WZmxonDOqy1NEZQlcwK9NHc7
y3uEiwEd4gU+p3s+xZn/PKr786h+D8F+lO0fEkWn5AmSaxZK7Xgrp5MLl2bP
3Dl/8+nD28+fv/v69bfffPX9+3fffPX2PWi/X331/Zu371+8/PrpkzcP77+8
fePp9SuPLp+7dXrz4sb86fkq4Hcx4VqOO5ei1qWIaTWs34zqT8YNuwnjhZzt
atl1qYiA7Y2Qej2s3Yq19l+voTfqGLDgtZDmZNIMKAb+eybvutoI3lpI3pxP
XJ+N3V5M3VvJ3l/NPVxt3fJxZyH9eL3y+sz8m7MLj9Zr1+Yyl5vpW8tlkKvP
VZMgTq8m0d9W+l+eBQ03fWet+Phk4/mZuccnZ26tFC8108B/Ab8BJXctgf5t
LVLpdCmetaiWo26AdtEBR9X8uLalpJ7f9Kjh6c6eD/4r+8SnVnrfWsSwETMF
ZdNafEfFLC0aRA27chaBQRGu2aQL3tZlr1mXErjtdsy6GTH+Bu9qQLuIqvJm
sVdM1JH7gfkCWh0CspGDA+Yrme61cPBBmJuxSMGMAZwX9OiEmgGcF1Nw/VKW
R0jz8EluHhGMXgHZK6Y6uSQnn4Iq+SB1R0zakEkTMukiFnnIJI3aoLTbELbA
FjFHySAqaCRguAYBR81jKpgkGZ2g4lLMcp5LK/F4NZGwJRO3J4P6iEsaMLFQ
GI9IR5zifjv/uJnXbua1GXmHVMwv+LgPaSP/yB/eryB0WPmDwIJTTlYRE5TD
kkpCXk3DpYw2lzIkEsZA2OhCdSYHrLVCSqtA65IYAlJDWKiJsuDWa1C4+qzU
WtAiJZu35PIXPGjS4QrqHR6lFZGaXVKLR2L1CWwhnj3KtSc41gTPmhQBq5W5
ORwzlarBUTSTLNO01EvVRjiWqBSJQWhUi/m1Ia8u5tFH3LAfETmdTIuHYkQJ
WhSv8uCUDpzMjJMYcCztGEc/wTdNi+x4uZuk8JGVAYoqRDFkGNoMFU6TlIlp
UWSEg/XQPJ1kpIPq/hPN8xHd+wnD+znd/SUNOUSxtxFtnWR7DxUZZXnxghBL
lhAqUzJ5WiZLyaEEWZ2haLIUZWYSRF9pup8X6QRZl4jsw9v24oxf4vSHiLqj
ZG0PRdMPwjxZNjIl7BvhdU1KBxgm3P/Hb0lubUDqPJsfGqe5uihIB9PTARBm
eQ6z3J9SbZ9M6T8eVX8yrvkCZ+6gu/p42KgoPG0q8bFFQ2LNW9hKLF1YPHPn
4qWHt548v/Pq7ZOv3r949x6A/PaH79//8M3X3371+qtnT14/vP/01rWHly/c
OXvyxs7qxdXZMws1kJ/Xc/6NjHc9hWykWk4KcvKFvONsxnq56LxZB6j6zufs
gN9FnxJoFhEBL96KaIFBL3ikWxH9haILmPKVKnprPvZwLftgNXN/JftwvfB4
swT0CtjoSv7ufPLBUubZRvnZVvXeSuFaM3VjIXdvrXZntXq2kliMukC3PVtN
3dmcvTqbvLGQubdWenqy+eL03NOTs/fWKjcWCqAXL4UdM6jlYi39YH3mciO3
GESSOtmZchzAG4Z5aaM0Z5FlzdKYhuPmT0tHDnf+63/hdn/u4Y8B/51DoShE
1BOPVa0SoNWAYTtmm3O3rlYveGEA70bYcDrtOJtFtqKmlQAMtIyp5r3ypFHk
4OPkk93i8eMwddQmJCMShkNEs4soCaOs7NaWEFUFgZoeVckqCivIrfuslLyA
nBOUMQNSBiam+IQkL59gY4xbmJNuATWiEWfsrXc2Ja36qEWbcmlLAWsj5ikF
7AGj0izhmCVcJyw1SXl6ERviUqUMvIQxpeCRjBDbaRAjDlXAZ4wHLXFMH0GU
IavAr6W5lVNOybCF321gd+o4RzX8Ywr2ITb+L4ShfyV1fswd/lJD6/LIJ+NW
RgEVVELiUkRST8G1rL6UNSUTeh+msSIKrUWiNklkdqbGxzfHRaa0QJ9ia1IM
fZ5nLsotBdhZtHqKiDflcIaMFrfSYpdYHOLW6JSY3XyLj2MNsawxljXBsaWE
2jBP6mGwzQSabpKqHWOZgW8StTGWPalGM6ZQyhaO2OOYNeG3Rrxan1uKeLkW
lKbzEWDvtNw1JbNPSi2tlwLLbCS5nax0UpVuKozS1BgNwihKjGhIMbVJqiqK
lwTHud4+OtJJdRyl2DvIyO8prn8ku/6FjPyJgnxCcu4jOw+TnMCXRxjeKRZK
4gc44rhEllRKE5AkrhRHydI4GQRacWJSlBgRJAdBiab52gnIAZxt/6ThwJTu
8JS6Awcfxym7puRdI7zjg+yjg9xjk/J+pg0vC3LVGak2J1XnBIIQiWTvw5mO
Em1Hac4OOtLBQNpo1k8pps8Jhs9xAF7dEZKlk+7oY7uHON5BATqmjJKteYm3
ao7NB2dOzezePnvz6cUHr289f3f/1btHr98//frdi7dvnr96/ujNk4cv7999
cvMq4Pfuud2bJ9eubi5dWpk900icrEQ2s+ha0rmWsG0lLKcztnNZG/DZ08m/
WXDFc7nkallwRAesedEjmXHwm3beglu8hMrXAipA+u2Z0MOV5LPN3Mud4vOd
8ouTlden669O1Z5tl15vFZ+vZR8vpR8sJh8spO8vpm/Pp27Opm7N51pBuhpf
DCM5O5yxqGbDyKlq8tpc6uZi9l7rHunG81Ozv0Xu++vVR1szoDufLoYvVFOX
G9ntdKDuNjY8pouNTETNT5tkyxFn3irPmCRxLVcyfITX+8XxP/6voP+6uCN1
RJo3ceMwGVRggCoAFvjs6TQCDLfplM4gAGHoTMYJGj2Yi8DHXPTJlzEl0JxH
ElLzjMwJ5kAb7ugeen8bTBt3yVlBnThqkJW8hiZmLjmggkVSc8jLNnEKpoGq
C2aSuFaY0gqyelFaywvJqF4+zkIdcrAmwwo2KOwNn7WOORqYqxny1CLOZtyb
9ZocCh7MJpvEbEQtc2sVchZJQsdxyeMswhCLPChkjakkJD1Et5qkXgcMnCvk
gQG/MackZOFgOioinzCLBtTcExCnU87tFDLbKLi948MfEo5+zOzbqyAcc4jG
ogZazs0vByTlsKyWVFWzmmJGH4+pPT652S7SWgUai1DqpqiCTFOabylwjAWm
Lk83FLjmktSUg2wZozNlcYTMFo/GaJWZzGKzVQRGo5mvtzH1TpoepZhDVEuC
aUsLTEmhws/i20kcG4HrwAmcOAVGNiTZ7qwlUHBGc+54wpMKu1MhJOo3oh6F
yy+0Ygytn6DwTkld4xLHpNQ6LbXi1S4GjNBhhKr20HU+hi7I0AZoMEaCAgQl
Ni1BR3nOfob1BNXcQbEepdk7CY6/Izj+G97xO4LjnwnOjyjufTRvBx3tZfnH
6b5pOgryLVsUE0uSEJAopmydUo4QeVE8OzTGjo5w4yOsSD81cALvasfZ2yZN
h8c0h8ZU7cPStkHB4T7uoW7GgT724RHRcYJ2hIuQpQGOLMoD4ngJBPPAMNQ2
Ah/BGdpJFlC3j9HsR6nGPVTjl1TDQarxKM3cxbD0Mex9TEc/29VPs51gO/pB
FzCnpWjNVt7Jbd/ZuvR098aLczeeX7j2+Py1hxduPbh06+6V69fP371x5d61
y/cun7934eztMzuA3+uby1fXF66vli/OZ0+VQ5sZ92/+eyZrB/xuR3WrfsUa
pjyTtgB+QYq+WHIDk70MvDioWvJKf2vHmyH4VNIEPPrlVu71bvnNqcqrkyUw
fn2mCRAG/L5YTb1cS79czT5ZTj2YT9ybjwMjBqH6zlLuYj0OqmvOqvJIGQ4+
JaQVV1DzxXoUWPDt5fzDzSqw4Oen5gHCwIXfXli9v16/UEsATtfi7q20D4xX
Z/Lna6m8DVoI2XfzwaReGFQyQxBDNtpOPPynjj/8L7j9/2Km9jTdAC5hwyWp
OoQXi74rFT/w2e2YGYTkspmf1dGBz4I6f73hu1hC1kLwAipbBZ/RL687eE4J
TUEYmj66t+vTfxnY/zF3vMcmYYaMioQVKnr0Va++6ITKdnnTrQQzQ80mqnv0
rXUKFnnFpmwgqrpdllazAiJ8AqIn1ZySRT7rNS4EWksv54LOxYg3iejiDg0C
CVRMvIZLtUFCYLts3AgDN0SfHqRM9ZKnu2nEHhZjUMAbFQvHjDq+wyTx2GQ+
qxiziUJ2fsjCap3F0uEdqgmTfFgjG1BKB4S8E2TK4cmpvcQTnzIGvpTgjpp4
IwEdGfBbCcqqUUUtAZWTqmwcioYUbo/AbOfpgGwCaZAIxSj6HN1UZpgqtNal
0gJIqjx9QmKIwMaAVu9W661Kg0lmNEmsFolJL9Jp2bCWAhmmVbYpkH5NMaot
zbEXJOowW+ylSFCqzE+V+0nqKMWa5/iKznDJmygGEiksGUWTIVfEb3Z7FQ5M
aAowYYwgQyfE7nGRa0LsmJLYcRqEATspKidF46Yb/ExjkKnH6LCPLLSOCGxD
fFs/09RN0XWQdR10cyfb3j1t/T+mLX83Zfn7KdsfCM4/U70HQS9mh0e5ERwz
QKD5iEyMzovwBDEBLyzgBLjsIJETIjKD0zT/GDU4zIyOMWMj1NAAxd9LcHdP
2Ton9MeGoY5e4YFjjD2HiX/poO7p4R6aUPXRbdN8L5WH0tluCgMhjME9PaLD
x7h7+0QHAO9T2naCoYNiOc4wHGIYjjANxxjGLpa5j20d4tgHOc4BgWeQ7+nj
ufqF3lFtgh2at9bP5Zavz63dbGzcmFm50pg/U10+09i6sHL28s6Fi7uXL5y+
Aci9cO7u+TN3Tm3f3F69ur54eWX2zlbj2krpQjNxuhw4XfKdK3qAB4H8DLAF
kDZs3FUMamXpkutqzXdrNvRgDrtZdV3MWM+kTEDnMpYrJeRmw/96p/DuTPXd
uQagGBgx0POtPBgfz4WfLsSeLSeeLMbuz0XvzsXuLaTuL+daCyjmMpspNGuB
7HySlj7pVXCKbsNmynW6iAGE76+Xn+3OvDi98PLMIhDg9+5qeTePAZNdCNpA
nAZ2/PLM8qVm9mQ+uJXxr8ZcRbsyrGIj/Gk9qY/TvWf4098Bfi203u2kdTmo
3YwbdzO2m83w49Us4HcF04A6XzSxg5LJBVRxqQxaAHoub18JKBdQKRibiCAJ
EwwcvGCid+jgX4588A9dn3/AGOkyCeg+jTiglUT00oxVAfJz64wZiOIuRd0u
BvCWnao6op5HdUuYfhHV1GySvJaz4G6xXLJIq05l1aUuO9XAiIEwndSnkQJ+
gf+6YIkDFitYRNJwF3BeLnWMxxjjc8ZFogmJZEIqHRfLxvUww6RlmrV0k5ps
hQlODc4OA2yHbPCIRT1i0o4bdOOwZlSkGKDzj+MYR/Dde6h9X3DHjsCMXg+E
Tzm45YC0FoOqMagQUyRCrUuuNoRtsDO0NqbWwZLF8YoUAc6R9BWyqU4zVGia
LBWKMtQRoconVTmkkFmqNkoNJrnFJLeZZRadRKfmQBBBBo/JjKNqz6Q5TrPn
ud66UpfgyjGaMshQhRlwmGpI0d1VAVb2RCtYshgC/MYjvnjYE8TMLhSyYQLg
rcBVZf5JsXdM7J6UIFNiB64Fr4MMpHFR9F66xkOW26ZaD5FW97J0vWxDD0N7
gqLuoGqOsk3dAvvApPl3E6bfj5v/acLy73hkz2/3UPET04I0hR0l0wJ4BkZk
BcmcIIXhI1DcU8wgHojmnyCio2T/KD0ywYiNU8MjzMgkNTBK8gxNWXtH4M4u
wcFD1M/2TX8Ixm4hcNghtofM89FYLjLZMoXTj57gtbVR9x4mf3qcvW9IcmRc
eXRa00kydrGNRwG8TMMJlqGPYxriWEZ49hGBc0jkHVAERyS+AY6jCwrhIyvm
6vlY+Uy8sBsu7ITTq1hi3p9djC6crJ++vHnl+rmrV87fvnbpwbUrj65cfHj+
9O2T69fWFwC/AN5LC7lz9diZSvBsBbtQRs8XEOC/IDav+ORlI2PGKQReDBD+
refem/E9XgyB8XzWCuAFBfnhYuT+QuT92drPVxd+vb4CEH6ynnkAgF3PAITv
N7AHzeD9meC9ZuB2I3ijHrxeD1+tRy6WQzspL3ArVMqUTHSz+9rV1PGwTjLv
128mnJfr0QdrpZenZt+cWfpNT7eaVxvJlZAtpuIsB/9fnt4zKK5r0db98er9
eXXP3W+fc3byDva2LW9btiVLQkIBBCLnBhronHPOeXVcnXPO3eSccxAIhEAi
CVAOzt625bjvPbde3d9vYr96VaNmzaZFCaT+1hhjrbnWND+a7dsbybxcGd2b
6Hm0OLyQ9vY7tbNxO0izenKTkdzkYLeJmq/92n+3+/0LceNMWLOYMADbPRiO
gJA86hJv5G3DDmFUilqMaQG5AOG1jHHCKx51CcDYZaB6uPUqGprZWg2ct+j0
GzWXPmAga/U8ik3GMfLIsIDsVbCyFhnov11mQUbLSmnoSZ0AHGGGXdqZkGn+
ZE2aYcannXSrRu2yTi0rJiXFFdSsngd6egoSxrX8vFOfgNURoxKUX7tCcHLN
l08zADsWkJVislpBhXRMgxmIrjOR1XqCQo5Wy1FKCVImqJfza5SCKhm3RMi8
LGBeFgmKFfIqubZBom1kyWsJ/PIOVnFb5Ucd1eeJTYUCXLlJ1B41MfI+UW9E
2pdQ5CLisJ/jcNAMVrLaQlDBJAVMkmRwkgxGlseoe3H6QZKujyxPE0728/Wz
pHaeyMCTaPgqrUivl5iNUsCvVSc1qLkKBUGkaJFALWp3hzlJdvRyAmNKQ5Yr
DZBkQbIqQtVEKaYM3TskDPX6Yn2hZFckngjEwp5oyOkPmO0eucHPUQcB7Fhx
oEPgRfJdSL69Q2hDqa1EFQx+NpzKTgASGzto0mo0p5gqq6IpaxjqOpqqiiwv
JykqmFA9H0agLO82ql+vVbzRZv6IEqgAeZiV7OCkcLwcmZej8jIUVhTQ2opz
1OHt1QRHNcndRnC2YuyN7bZ6lKMR60WQQm3UKIoexwFRghicoxWhqa7gFV2j
nL+E/xBM6iRl7VAj2Yahu4gA3iZJbRmj+Cr2wmX02WL8+Ur65XpeUaOgqEVS
2q4op2krwBEGHGrYxpZfH+zJNjXxbU1Cd6PE30A1FuG0hZoELr1o7rzpTszZ
QxOWyKQ9Me3OzoX7F3OTq0Mrm7N37q4dH+29fPLgs8cPX+zvPN68dbS6sDs/
8cuGYvm7k533xrNbw/FbPb7llAV8toHnAv8FhK4mIFByfzlPpVlNm1eSxrt5
6+Gw/8lU7MFY6GDQezwafDqT/GQp/+3m0A87kz/tTX+9OfxsPnt/JLo/Gj2c
SABy7+Zt21n78Ujk+UzuaCSx3eO/3eXbGU4spt19Dg3gl4Mow1y/wG+rCah4
c1EbgBS0Y0AowPP+RPbFytATkKWXBsC3TAROljmBCQD8VqcPvHt/uv94buBg
qmd3LL89lJyKwBkDP6FmKlHlhOvvgf7r5iLHvIpfzpDb5mPQzaRlLW0FXQD8
LgNWXq+ZDdLypE+6ENX0w+xhB2/KLwWxGagfZkWkSHZbLabyau3FD6ovvo+8
Uchqa9SwyXYZ36US+IAF68VRvSisZLsFOJjeaiDV2zg4kOFBDR9wKOYipvWs
cy1pmwtqh20gzIj6zIIcxAGN2MpAWlkov4QS08u8Sh4soOo5ZKOABkvZNhUf
1ghMGo5ezdBp6Hojy+oU2D0Cs5MFwRSzhWwy4Y16FKRpVsurpcLrQt5lPqeA
yfiQL7osUpbylTeYqnKqshwluN5AL0DWF7TWn8MgLnEI5WYZOmpj5/yifEjU
l1blErJwkAs7yVoLTmpGy2C83E6kBpqEGbR2kKofomj7icpOgjiO43sJTBOB
qaXQJGSmkCZTCsyg9Ti0DpsS1kqMGp5SSZSqO9TWDkuU7OhkWLuYzkGhc0Bq
6RJq40x1mGpOsZxdfG+vINLjC+Y8waQrEvUC/40EHR4vZPGI1W661IuXBFHS
KFoew8tCOIEDxTG1suUNUkOHwU3VuygCCInnlWE518miCraqgamqp8lrqLJq
lrpeYGoFYusaMdaLzdDZJugcyn6dEmliplDcLInfSRf3soVdDAAyJYDA2Mvb
TVc6TJfRpkIsXIux1LSZKpGmyjZrHcaFIPg7KGEsOYIjh7AEHwZlb23RN9Qq
KqrEZRXCUjBp0tZ2mFpxNhTO0tGqaqpkl14nXrnUca6w/WwRDvB7rY5T0sAr
aRKWIGUVDH39ifPqETxTO9+M5hiQXFOL0IYQ2KqFriqOtUToqbH30gJjUme/
yNYthrukxqzY1qmOjXsAv9O3xm7vrh4/Onj65MGLxw+eHx4A/wX8PtpYub88
c2dy4Ff/vT0YB/67knfNxwygDPabWQthNYAXJOTlmA7MTy4ndTlA/wWG+3gy
+nI+/Xw2BcgFtRfEZsDs9/cmft6f+df+/Kt7U6D5PpnPP5rNPp7LHQ5FVpOW
Gb96JWb5pXsGdwajoPxu9kSAXYLqCrNwpMrLzZfe4zVXRtSCMa9+1ANt98f3
R7PAc/fH0k8X+0/ufZjvBfNf77bYHgivZByzUdNWf2i9N7EzlgcW/HJt8vHi
IOjUQx5NWEaRtZXSKs6Km69FZPhRj3w2AgH/HXFLgP9udrp2B4JzIR1Izm42
AkToSZ98yi/rs7BGnIKZoBxQDPjtNtJ8PIQE1wwQxlZdqy388MbZU/VXzzPb
G/V8ukctAQhbxQw9C6sgNqsITUY60sHHwSyMV0yNazh5s2jYrZwO6meD0IRb
DhAec8kGYFGXiQecOq5ipCAuSAtJvTSs4oPuYBczbBKmVco0SRmQmBpwqt02
qdnEgwxMrZGis1D0VpreQTfZCGYYZzC36fQNGk2lQl4kERcKxef4knNizVWp
oVSoL2PrQWArxyhLEYLCjo6r7W2XMO2XWdQKnRwVsLPSAVE2Is0n5ZmENBTh
23x0rQMvtWKFNozQiWNEkMIsXtVH0wzQ1D1kZZ4siRK5LhJRhSLLCFQhmSWi
yzQii1XldOl+4VcG/Fcux0tU7Wobypamuns5zgGub0zmH1O7B5RwTgin+a5O
cahfHumXhTqdwawzlHSGoy4Ab9BvcbhVBqdAbMEKnWhhoEMaxwB+pUEs8F/g
ViIdUgy1AfHVzSRhZQejCM0C/FaxlI1MRQNdVsdQNggMbTLw8xvbwbzDWoS0
FLVbS7G+emocTU8T2Xk6v5sj6ufx8jSQijHOilb9JYT6g1bN6Xbt6Vb1tRbV
VYTqGkJd1AzdaLfUol0teF8HIYAlBPBYLwblQCFhZKupBajNgmw2NYOXKBuq
w9yGUDdVcSuKiFcuoy9cRJ4tbD93g1BYxyxt5Nxo5JQ28ktbJZUMI4JuQLCN
SD6M4ZlQLKiFq0cI4Xq2oZRtvMYyX5X7q00ZtCLUxrHVnxR/F07kJhkS4uS4
f3Stf/nu3O6Duy8+fvrxy+cfP3z06N69o9sbDzdWH99eOVyZ3p4e2JvtvTOW
XesNr3R6l7IOkDNBGQT8TvtkSxE1SMh3Om23cydntEB4fjSdPB4LP5tNgbb7
2UrXl+sDr7bHgOf+tDv7w96JvtuZ/ufW5GfrI8+X+x7Pdz2Yyd3pCYDPcB8s
/nU59GrOA2Lw8Wwv8MrlrL/PqbVzifSaIkzJeQ2ptcepmwlZFmL2w/H8w+me
z29NHk3kjifzu0MJ8L0LMctSwrrZ7d/uC00FoG6TYMR9cv0XlN+Tp9/kg6B4
dlqkWaPAwe6QtF5nVJ2Tt5UAfk8WpTglY17ZqEc6bJeOOqUjDklYhFG0Fumx
FTkddTqgBL/1gJUz6hL+etp52MHvNTPC4raEWW7hkxiIChChQX5uK7/GRiGU
DKKQ0C4ho2UUlBCLAAVZ2FGnpbXbhGS3mBZScZOQEFhwl1k0YJOCXjxkk8yH
oWm/dtKrHvepQVnutogBv0kdB6RoYN8+CcMjoXsUbL9O4NOLPXqxDeLBBp5B
z9boaEotSWOiGJzMk5M8NpzeitbD7Xpzk85Uo9GXqqAipe6y0nRNYy1VOsol
9kqerYpprSGaKjDaGyROFZ52A0cpYbKqVap2j50ZD4syCXkmqYgnJcGE0B5h
6/wUsRvHd2G4bgw7SZTkGYoelqqXqe5mKLIMYYDMggloUTtBiCcLaGwpRwlJ
YYfG5lSZYLFZK9UoOBIxTqhAqhxoZ47hHxH5x8SRGU1s1hidMoWGoGC/Nj6o
Tw8bssP6QNYSysDhBByO2AC8bqfOYhNrbSwWhOTYWgX+9hN+49hf+QX+q7Bi
uJomkrAcYIukXgHCckqpkhpALlPRxFY1C6B20I5VdpLIgKJJ61vgIqT9BspT
iwshSQksNUWmZRnsTjYzx6TFCTgPos1c2qQ61yR/r0X2DlJ+qlF8pkF0tk74
Ua3ofJ3sSqO6FGGoaTE3olwdGA8W68Fj3Di0CwsE5ngfscONPfmKA9diQNZI
aotp1y9jCws7Ci4izxWhLlVRrjdxKxC8csAvglfWBvg1t9BNzSxTB8+MZes7
GKpGkPl5oKobbvBMxWzDJY7pMt92gw5dJyiLGIZKGtSqDLCCA5behfT81uS9
h1uPnj94/vzp5x9/Avh9vLNzvHn7+NbK0er8/uIY4Hd/rg/4762+COB3Oee8
mbHeTJlW4hDovMtRzXrauNPnBtruduwPB0Ew/vU60ac3e7641f/N9sRPB/P/
Olz8cX/hu905QO4na0PPbg48Xel/tNhzOJPbHT+BdCIED7qh8aAFtNTVrvDm
QPLeaA5oJR/s/6X/ittqeIhyJ598skISlo979Zvd4bv98RdLwzuD8c3u4ErK
uZKygzoJEN7s8W31BaaCOmBknUbugNswHoKXsv6MQcxHlMhR1SDKGkiN7NqL
2GvvMCo/MpFrg2JMWkvrt/GB/wJ+E3KyjdqkaitVt98AFANbnPAoANSgC484
RaAXj7lFE14J8OJuI73boQVUkmqLqs+9U33hNLryOgfdLCJj5Ayiik3RcWla
DkXHIRl5VKecE4QkgPesVZ13aHKwPG0U5gz8vJHXbeaPeVVAAN4xj7rffnKz
YUzNDCsYJ7daC0kws8NAbYM5eJeM4YeEAYtUycUqRXiFjKhQkVQ6stpI1sAU
nY2mhjFqGK2ztuttrQZ7o8FRY3BUGJzlBncZ5K1Ueysl7iqBu4brrme4GiiO
Bi7URpc3koTVDFGdXNthd9LCYWEyKU9llLGMwp+WWuN8dZghDpL4ISIvRBRm
efIugbpPpO0XaXuEyjSX66aQtDiUAE0UUugStkAl0piVFqfW5FBojRyDSqSU
MgUiDFfeonCgHHlmaFwamlLE5wzZJUdu0Z2ddufGnd3jrr4xR++wLZwxRNOm
SMIUCZv8HshhlxthvhqmsfWtXEeLMNgmS2AUCZwijJd5cBIHBvDLVNR1MK62
kC8CeFHMYqKggiFvpIhrOeoWqQmvslG0TrraThNCGLoU0WC+0uoux4WbSIkO
cppEztDIGQY5zcKHiVgvqt3a2KorQcguNArfa+C+2cD+Wz3nrVr229WsdyrZ
75ZzzlQKL1VKiiplZfW6eoSppd2Fw/rJhBCNGKaTIgxylE6KMsEE56G0mDoq
RbXXyNcvoQsvtV+8hCwowV6pY5S1Cmua+VX1rJIm7o02cTUTRjLhdjaM5liw
TF0bRVYPmjtbUy62VGh8NTJHKRMqYEGFbMN1pqGMD9crPPToiHV4NTu22rO4
NfPo4+Mvvvr05fMXX3zy6edPX3x89ODpzr0H6zf3l6bvzQ/vzA8ezPfvzvRs
jaTWegKA35NlVP3eo9HQbr/n1zNU93pd+4M+8PJgJPR4JgWC8cuV3s9uDX61
Of5qZ/bnw+Wf7i99A+C9N/Px+sijhb7j+Z7HywNPVk6eWHt/pnOlJz6fC81m
AmByezh3b6wbaGeie70/ORX/5eKRgKLGNymxDR4Rpdeh6TSIhhxq4MLTQfPx
ZNfecPJgNH0wmnwy172ctA275CcIeFVdJk5UTvAJOrqs6mGfEfALqrSR2uri
4wEXemID+caHjWf+1Fbwughx2UiqcXFag2IU0LhblVLSXEykndYclRCBIc6H
Db0mfifEHIAFw3YxsOYpv2ImqAIg91k4CWCIMrqK0Iy6UVB36X1U5TUpBQPL
BR5IZVVJIBFHw6VBAqZdIQwYlFFYl3MZOl2GvFOXsSrjkAAQGlbQ4ipar0V0
co3JpQTwdpqAO/NBVOhxKBNyipeHtlCatYRGHRmhByDz8AYh0SClqiVEmQQP
oqlcTZBpCEIVmiNFgo8r8BqQeCEn2uBEGl2NRneNwVVp8lXrvFVKT5XEWyvw
1HO9CLYfyQ2iJD4Cz9bB1DWzNQhQJM0uqi8iiKRkqW5tpFPlzcnMyZP9AUUx
uiDBEKZZspxC06szDkHmIZ2xT61KS9l2OlaOwwgJJDGTrRCKdTLIroP9BpNL
rrZw1HKeXMrgizEcRYvM1g5nacB8Ab/JBVPnTU//zWj/QnhwJjwyHR4ZDw4N
u5Od+kT2ZNFXJASFvBqXXWaGeRobRWpDCz3t4nCHPI5RJ/CaOFkToqj9ZB7U
TBJXtDGuAGG4pQRhBUVSB45IZHG9yIjVe9gmPw9ys5RWmkiP56g6auALrd4S
fLKJksdQuyjUTiYxzcREKM1OVAvc2gjVNClKGwQFtaz3qsivl+H+VEt7rZr6
5wrK325Q3rhOPVVMf7+Idf4a53Ix/3q5qrYZRmMDNHKMQ0tyaRk+ED0roiX5
hCCrzYKrkzffYFZcwxdfQV+5jrlaRSlD8hvQUgRSUAP4Bf6LktXxPFieBy/y
kkVOMseIpika6YoaHlQlMZcbgw2Qr0psviq0FIttFWJrrcyJiA7BY2uZua3B
idX+m3fmXn7+/PvvX335+VdfffLFl08/+fTBoxf7ew9vr+wtTewsDB0sn1w/
ur8wsDfVeXsgcrPTvd7pBD4Lii3Q4bB/p9cJyD0cCYLY/GAyDsz301vDX92Z
+PbeDID3u4PFH49WwPjV9uwX2zMv18cAtk9XRz+9M/PF3fnPtmZfrE/cmRxa
H+1bHepeH+3Zmhrcnx+5vzh2uDCyPpiZTXmBu4UUHDsXb+PgwgpWj0016TMD
eEdc2qyOv9EZ3OoNH45nny/27Q7FJgNawO9sxDAZUHca2X4hSk+oyhhlWZMU
gN9tVeZM4lG/oRcc0slNtIqPms/9BVX4pqTlKuAXuLAOVyZtveLnYoN8fFJO
z6rZPUb+tF8HlNUwwiJcnxnwCwK2eDaonfKpug3slJKcMwmjGraR0cFqLiPX
FfOxzaD8An6NUr5exIckAotK5jXogrA+YIG8Rk3Uog6b5GGDLKIXB9Rcj5jk
4mM9QnxSwxhyKRYS8GLSOhbQ9zkUOYsEGHRKQYpLiBExPiwhhuTUgILulFHN
YrIL4hmUNLkIB6KpTEVUQmSpjihS4zRurtbF1rkYkIuoc7RrHQitrVZlr9S5
q+XOcrGjXOSq4XsbOd5WXggtipMUCbo4SOQ7UXy4HTCi99IcEZ4vKY516wKd
akdeDqV40jgTwMvPsPh5jiJvgPph65jLPuawDFh0aS0PBCMVjSBh0OR8jlom
Nar1Lj0cNBg9MpWVq5By5AqWSIHjqJBiKxJKEj3DguCkPLNs61kLDq+nxm5m
xxcyUzPpqYnExEioa8CU7dInE5p4WBMLaEJepcMtMLroGi9RGkCJQm2yGFqb
IuqTNH2ErvWRacoavKgMwy8BI1laA0STNTAUTRxNm8pBs4SFcFii93BVVqbE
QBZo8WWm9xt9V7CpOnJXB7WXQulmoOKUJjeqUt9UpaqrEN2o5F2tYhZUUT6o
xL5Z1v7XasK/VxL+owz/u+u4PxXhXr9MPHWZ/MEl6rmrnGulsppGSwfKTycl
ALxCRk7MzIvIKSExxsMGGCgHpUWPbZC31nDqKmgVdfTqNgGCpEZTIQxWjmgV
VnVIa8n6FmWSqUpydEm+JsqTOik8PZKvb1bATTL45L9M4ypTOkrVrkqJtUIC
V0MB1NBifGQ5PbbcObs+une89dXXn3/33Xdff/7Nly+/fHn05OHdHdB/76/O
31sYuzc/uL/y//G7P911dzS5ORC6OxC4Pxp+PBX/eDH38ULm6XT8wXjk0WTs
xXzm4+Wul0udX92dBsD+dHwTkPvD4fJ391f+uTP/6ebk51uzn2xOA3K/2ln8
9mgd6Ivd5Zd3Zu/NT2/NTNwaH1gb6bs12rc5MXhncmBrond7vHe1Oz4asgIA
vWKqW0CKqdndVvlsyDYfcYAU7eMTAMjzUXg14743ENno9AJyb3d7H85k7vR6
x33KnJ7uE7SlDVLAb8YoyRolg27teNAESqUaU82svtB28Q180T/kbcUGYrUO
V6FoL+LVn1e2lrkY7b/evADGEbty0qvpNvCAKf+6kBJ48ZhLMWQTJeQAK2xI
SraxO8TtFeSqQlpjqRiPBLWXhW7R8jkmhcQPmzNBf3c8mo8EYm67z2Kwyfmw
hGWTsfxq3sljNGR0gLBPTIyqGINO+XzKuph2Tkct/W5NAuKBt/JqSl5N69Qx
eoy8HlgCoI5AfLeKbZbTdDKyWkZSKSk6PUsPc4w2nt7OUTgEKgdf5WSrHWSN
Hau2t6isDUprtdJeLYTL+JYynqOO72nm+toFYaI8zVLlWbIkFSAs8mBlbjyo
unCY44gLvFmFMyeHs1JdWihJcjgJJjvNYGWZihxsHPDYxgL2US/cZ9OfLDpX
C6xyNiTj61VCvVZm0mgcWr1Xo7YLRAaKTMZRaXgKAw3UT6EVqY5i7f0c/5S8
c801uBmb2uqeWe+dX+ldXOhZnMnPjadHJh09fcZ0Qp0IqVIRXTKqC4akVj9H
FyDK/CiRv1UaRUEZsiFF1wYpMjuGpqkDCNNVdUxNAyiPNEU9U93MN6BVDqrB
z7WExOagyOgX6dw8hYUu0BKL9G/Vus53JCrxna3kXiKxi9oawlaamq9KK6/w
b1xjXiumXionn68inqnGvVuJeqsc+9/KMf+9BPN/X0P/7ir2z5dxb10ini4g
n70uKClX1jfBmA4fjRDlklN8akZIy4rQIWZHgN7hpqGdVIyNijYR25WoFnFL
hxhJ1uC4MI1vp1EhFEbRSNS2cOxYfY/I1C21dCssObk2yJHZcDIrCnK3G7wI
jbNSbi3WeSoMgXqJuQzw60rTRpaTuRF/fiS8uj33yVfPv/vhm6+/+uaLj7/8
7NlnD+4ebC2tbs3N3Z2f2Jod3p7t3/kV3rk+4L97k9n9yfTRZBL47MOJKAD2
q7UeoOdz6WezqS9We/55e+jL9YFv9+Z/frD6X082/vVgHcD79e7C51vTz2+N
A7f9fHvun7srr443fnh055vDWwDeBysjW/Mzm7MTaxPDK0N9iwOdC73Z2c7k
VCq0Pphb7IyMBOG4VgizMCD6ugWEpI63nPBs5MOzYbjLKN4ZTN4biAEdTWS2
eoOLCcudXv/OUGjELYsrCUk1CYxZk3wibJ1PeeaT7qWMZ8ijs3NQQkQxyM+I
j/7cfvENXn2BDFkEKAb8Av910juScuawTdVvluS13FGHaiFsAaF6xCFfSQDb
UaRVtG4Dt0vPiUoIcRnp5JIQs81AaeG1lFHrrrOQNQJ8G5+AtsglNq3abTJ4
LSYw2nQas0phUspPLuCyT64E+TTCuEkKInREzYqoGWk9L28WATc/OW2l5+Zh
aadVljaJ+iAaQDitJCcVlKiCEgCHCyFRz8VouVi9lGyG2LBFYLEKTVaewcqF
bFyhmSe2cGUwU3ESpHEaR4fG2aJxNkotFVxDCct4g2uv53taeX60KEpRZnmq
LqY8Q5fGSNIgUe4naoNUc5htjfFsCZEtLTFnJdqMUJzmspNMWpJOTVEVWYex
3+8YCduHfOYehzFn08fNar9Z7jQq7bAcNknNWqVVpbRJRUYGXY6Sy7laSKiF
2VILDvCrDKNtfWzfhKL3tm9sOzN7r2/hzvDy6uDq8sDqfO/SZH5mzjswYEon
lMmIMhuHcilDLK5yRnjaky1aWgXeZsCvIUMxJekqN56vb+GZW4H4ljaeGcnW
NgOEefp2uZ1sjgjMIYHRLzD4+OagBEhl5/C0hHOS1yps76ESl6jdV3j917k9
JTjfpWrFh9Xiy2Ws6yXUshJqxXVK6RXixUvEDy6T37+IPHce8VFBy4UrqGtF
2OtXcUWl1JIaQVm7vh4N15PcrYwwjhGh0oIMkoeFczDbYWaHldVmYwC12qkt
NlKLjdhqw5N8TFaII4kLZGEOF8YxtEjwD2KN8J09eme3xpuXh3KieJIVC+AC
1ga3rtSjKwmZKwNwtdtaZ4XrVFCFxlLvTdGGe30Rr2ZkKPLyk3vf/fzis1eP
H39+uPPkztrO0tLG9PLa5Matma2bM3cWJu7Ojx8szzya6dwbjv+yv23g/lgK
1Eygk/VRs10gtX68MvhyeeDZQi+Yf7Y28vWdqf96sPQ/jhZ+vj/38/2Ffx0u
/3yw/N0uyM/z/7x389v9je8e3vvm0e5nx/ee7995tLvxcHfjwcby5uzYTG9+
KJ0YyCSG89nRrux4Z3YsEx1LBsaizgGXBpBiJ9dGOM0jBtpMxDwbtcyETADb
3f7YYgS+nfPt9EWXotbN7pNNlIB5DXo1WViQgvkDQc2YS5lUUJ2sNp8QH5HR
rSyUEFlGriyoPfPX8nf/0H75HVFzkaj5mrj5io1Wl1QSUgpWRsWZ9hnTSraP
g1tLuQ5H0rNh87hXl9Vxkyp6HywGAmnWwUS62O1eUaODjzAxETJ8E6e9iYvu
kDEYOolYI5d4HFaf1+n1ekPBmMng4rE1Qp6BR8brpUKvWeczaa0K4cn9CAKK
SUBySekeCTWooIPmC4z45Cy0S95nFWQgloON1JFqwV9hYjfLCJVC7A0JpVpE
qVIJW2CI5LGzvS6uw86ywDSzhSpRNil1SI2hQ6NDypVNYmWdQofQWJBCqJ6j
q2ZAVVRjJd1exw62iNNYWRdJ24NT92AVebQw1caKtjAirZwEhpsmyvu4si6O
tJMtzbFFCRo/TBFGaYoUB+pWmAd0znGLZ9zpGLZbus26tE4d06jDKk1ArfYo
ZDaBSM/kqUg8BQFIodWrLVpzQO1Iicwpki6FtPRgAhO8rjUb4Hdhd3xxa2rp
zuzN27NzS8PDY5meCVO8WxlIS+M5KNdnS3ZbfAm5NcjWuLAqb5vEhQDHH4G3
RRrBi8Mklufk8ZgyM5GnxTEUWJoCx4WoMidHG+SqvDRzlGlLsKwhhtXLsHk4
VgffbOZckP6pxvYuPnmJ1X1NMFDC77qOdRfUSE9X8y+V0q6ArlpEKC0mXb+C
LyjEvV+If/dS20cFrR9dbC243HH1KrqoiHC9llfTrkVQXCimH8OLE/lJGjtK
I3qobSYCQodF6MmtJhqAF+Vko71sjI+F9bJwPhY7LhKlJOqcXJMUST00gQWn
dtIccZEtr3J1qoPdqmS3PJ3lJUKEkLXRC93wakoCxgqPsdxlqraYa1Xaci3c
FEwzsglzb7d3bX34xWc7L78+2H+xuXh3sm+hq3ems3siOzTZOb84sn5zamtl
+t7SNAjSB+Oprf7QSsYxH7eA8e5g5OFs54uVgU/Whj/fGPvqziQQmHy2Pgom
396b/XF/5vvdqe93Z37Ym/8J9N+9xVf3lr7cWvhye/nrg40fHu9+/+z+P58c
fHq88+zg7uP9rYd3VrcXpueHeia78+M9XWPdnb0nO255+mLBwahvMuGZjtsG
bNK4FJsUo3o15EG7YjponPBBJ/vxdYfudoeORtL3esI3E46lXx4UPx02zMTN
Ax5lwsAOQ4ygABOXkRNySkBIsLPaNfgGTkMR5vqHDefeqD79R0zxu5LWYuC/
qvYiJ7MxqcTltfychrccc0y4tSkFY8oLrcTtkx7dgEWa13NTagZAOCojuzkd
BkKdqqNcgy9SE0o1xFoVuVVBwcqpZMCvlM2SCXlquUSllOp0Oofd43XHvO5k
yN8ddlkTflfK74674DAMBQxKh4Jn5JHlxGYtDekWEQG/Q17VuF8z6JB2Grlx
FQ2mN8tQZTJ0uQJfJcFViPEVMkqtlt9qkmPdJobPyfM6uHYLw2gg6yEibCNa
7SSLlQAZUIBfkbRaKK8Rq2vFUB0XqmHqK2nmSoajjhtqFafRsi6Cphej6sbI
cyjALzvWyowiuUm0MEOWd7MleZYky5SmmaIYlRMg8oNkSYyhSYlNXRrnkNk/
4fKP+zxDblev097lsCTNlpjRENTq3ArVL3vLnjxaxy50+8KBWCje402PwMEh
ob2baOsleEZYgN+p3c6145nV/YXlrbnFtcmpuf6B4WT3uDHZq47klYm8Ptlp
CmcgT0xmD3MhL0HlRvLgWrqpkutolEaI0ihV4D9ZEgb4FRvJAj2Vb6CLYZbC
zQP8GiJsa5rnTHPtcZYjzHaHRC6/2OYQXZP/vtH+D0qqgN9bLOkr5mevYK1n
agT/qGSevY49fxlZcK39cjH6yjXUuUvt713qOHUR+eGFlg8LWs5far90FXO1
jFbRrmqju4jcMFmcpElzLHGGSQ9QOkzYOhmynN9UJkbWKDFNRkq7nYnxcQgh
ATUqYiUkil5I1weZ+iFzlwqKCbVepsnPdcallqTElVdEe9XZPkU2w0sE8SEr
IqivBPwG9eVuXZkNKjfpq9S6KoOtJZbj5rrda5ujR8/Wd5+u3jqcHbnVExry
wGm9PWf25GyJvuDIdOfKzfHNW7N31xZ21hb3J7I7o6mN3tByFuRP1+2+8MP5
3s9uT366MfHl1sw3Owuv9pbA+Ovkh/s3v9ubebU7/Wpn9uT81e78t/fmv9ya
+/T2/Ne7t14dbf/47PCnjx+9evnw88eHL453H9+/d7C2tDEzuTDUPzc8uDA2
Oj040JNMxNzOTvBZD7qGwo6puOvkyVFu5YxXsRrV5SAegHfcpZkLmk72wx3N
vJjp3sp5V2LwtFc77detZV0b3b7JiD4H81NGdkSI64Y4nRAHEKfH12uwNez6
a60XTyHOv9Fw9q+k0g8U7aUqVCmEveHjIJJyrIXQaMLV95nEIDknZLSMitVr
Eoz+sjh5wqOe8GnBwQSAnFTT3Nx2Ha5KgrokQV+VYSvUFKSORYa4bAWHI2Ex
FWKBRMgB/FosJpfLEw6lYpHugDeXjYbiXrffZvLDxoTbmvM74jb9yZMkxVSr
gGTnE7wSMujCKT07Z+Bm9ey4luHgdSiwleL2UsCvjtFk4LZC3FaHiug10EM2
XtQtCrmFAGEnzLSZaE4b1Q6TYTPOqEfpoDYd1KrVt6pNLXJTk9hcz7XUMK1V
bE89P9IsyaLk3XjAr7oHLe9EidJIXhLJS3cIs3hpF1XWxZBk6eAjKo7TBCEK
14PneQmSEFUdEZsyau+gPT4ZyswlsnPp7EwmP52LD8cjfeFAzuuKW50Rizdm
iWRd6e7AwODYyOTo1PLA1K103xIcGee7BmjOfkbnCjyz333n6dLG0dLi5vTU
8tDIRK6rP9Q1Zkj1aeJ5VTyni2agQFzlikhcUb7eR5Ram+lQGUl9nQmf3JWj
iNElYZrcQpRbSAorQ2nnqNxCjVesDQh1Ia41I3Dk+M4sx5HiuJICX0rmjSld
AdkN1e/anG+zMwWyvmuKnmu8aAEGerea+eYN/D8ut7xXUHu6sP7steZzV1o+
vIQ4dRHxxrnmd842nTqLOF2AvFBCvN4oaiKaCNwAnR+mgVgiTtJZIQoWRjXI
W8o4DdcZdQXUymuchgppe50O1wrTsH4uPS4R5FSGUSs8ZnWMWJx9BmtaDuI9
HBI4IiJLlOtKC8M5aTIjjIepEVdHyNwY0tcEtOUhqNKtKbdqymF9LQTVWOzI
ZCd/cC699WDx1uF090IsNGo3ZZViP1sW4atiEmNS7eu2dU0kZldGbt2au3Nr
afvW0uFsz9FcLxj3pzp3xrNgfLQ0+HJ94vna2Keb0//cWXx1cPP7wzWgH4/X
f3qw8ePR8g+HS9/fX3q1fwI1SM6fbS58vDH/0+O9fz07+tfHj3/85MnXLx59
+vjo6dHug4OdZ7t3jzdv76zdvLt6c3t1bX1hcXZkdLgzD4x4LJecSEeABY/6
Df1Wya978HVBfOCJAKXlqOVup3+/L/JgMLEWgYdNwh6IM+3VbHZ6lpLwgF3S
b5eMBbXLEcOkR5GSU2Byg5FYbyI18BuvtZx/o/XC6y3n/0YrP6PsKNFhSs2E
ch+3KSxoTUjJYQFu1C4fgiUhPtbDbHOz2qISIhDovCcPoreJc3p2VE5ysFoh
fLWJVaOn1aipjSpKm5pBggRco0xmUisNGoVCKjCbdCBCO53uYCCWSvT5vemw
zx1w2Jwmvcuoj7psXRFfd8SdcZsyLn3MIverOG4xxSMmBeSUuIaVNnCSenZQ
QTYzWwC8EK3RKcV5VCRYgnEoCG4tJWBmRRyCmEsEKI64hGGnwGEmWQ14C4SF
jVinleh1U7w+iitAMrraVc4WiatR4K7jB+rFyVZlF1rTh9cOYDT9WGUPStqF
knSigCMreqmafqamnyvPMURxijBCBjYnAPgEaNoY1xxVu7OW5EiwbyE/dmto
ZmNybnN6YXNu5tbMxNL4wFR/11AmP5DqH81NzA0srI3fXNlcX1/fuLt0a3d4
ZivatQSFRrnOPlZ20TS9n998PnfrcG56fWhktqtvLJEfCOVHoESXIpiUhJLK
cErrjyk9YQnovxo7mq+vJcmL8IoihqlW7MfKIlRJkK6CSUorReNgQh6hMSA3
RRTGmEQf59s6RfY815Zn2bJsd07kzSo8GZUrrm40/A7ve1uYu6Dsu6zIX2Z5
P0TK3qggvVbc9rfC2tfPl//9YuW7V+oAxe8WNpwqbPj7GcQbHzb9/UzTqULU
+WpmBUqDptnILDdZEKHzQmSmF4c1tzXK6srZ1cWU6mvEmg8x18+Ryi4za4uF
zVUqVKuVQokIhXk14Nc+ZnOO2AC/9qzSFpPYw0J7UGCNsJ0xjifM9PiIbmub
29Dg19eG9TURqCZiqPVpqhzaKrux3qSvszna03l+91yybzntH7Aqw3y+j0ow
I3HmZlGMLgzT1UmRs8eYGg2NzPctr05vrK/cWV89nOv/VQ8Whx6vjD5dHX+2
NgH0cmP6s635r/dufn+08eODzf9fPz9c+/nh+o/Ha9/dX/1m9+bXO6tf3Vv9
cnf9f3/+7H99+vznj599+/zJZ48fPj++f7y/c7Cz/XR/9/HOzv07mwDe1YWl
+cnZqZGJqcGR3lR6KJ0aTUeGw+5uhzatFwDXG4BFIw45gHfSrd7O+3a6gytB
02rItODRxnlYP621S0Wb8aoGLPyMmjpoFc6ENXdzjnGHOMxHWUkNVkojCL28
usL2S28CfpEXAL8fKJBXtR1FFkKZm1HjolYmpaS4mNClYwd5aDO+1kFFgG90
0JsDfDSI4jEpMa6kBERYKx1hpjSA0avo8MgwNhFWz8Vr2BRIKLBrtT4bbDfr
IY0UhnVOh8VogLzuQG/XcF/XRHcu25PPdWWSqWgoEfBmwr78LwhHLOqoRRk1
yyJ6UUjLDatZQFENM6xhhNR0pwhnYLSYuO1eJcWjpJj5KLMIY5XiXRpqwMiO
2oRxh/hXhexsn4XuMZG9VnLQw4iFOZEoOxBjuCJEawQLhdsU4WZ5rFmZRWp6
UdAQDkg3iNUO4DSDRO0QGRqmG0bZxjGeeUSo7mSKYxRxkCQNUJQhpiklcner
YnlPfjA6Ote7uD61fm9l6+D2zv27e0c7u4c7W7t31jaWF5ZnZhfGl27O3N5a
3tnf2N8+2tvZ3zu4vXV/5uZe5/imOzevCY2IMwvmybvJmw9G53dGxla6BmbS
fRPxrqFQsk/pi/NsPqYzIADme+K/QZHFxxBBzXTFDYL4ClFRzLI0ijxYsY8k
9lG0dqrKRlXbGTo3zxiQWmIKOCUzZ4S2biHcxbZ2Me3dXHeP2N2tcHdpPJ1Q
u+13lNDfxZ1n1b2F0uQ5MnyqkfvHEvR/Xmv+46XqP18of/1ixanCqn8U1rx9
pf5UMeIfBR1vXUK/cwX7YSn5CkJUR4CwVCuJYsXzAjS6E4vSNdYKy0poxZdx
xRdRJQXtpe+jis7iSwooFYWMmuuCxlodGu9hcZMydQ9kHjS5hq2uXoMzq3Kl
FJ6EzB2VeBIcV5gGuzAmQ5NRVQMrKnya6ghUF9XXxwwNAV2tT1/ntSAsxga7
FRlPMgMDLkNCxbWTqTCaZGvrMNRirA2CJJnhQytSHPeAITURGJzrmr85eXtj
dfv2xvHS2MHc0O50/+HCyLP12S92VkGN/VWvju788PDuT493gMDku+Otbw83
fzhe//7o1neHa98erH2zf+vVwe0fHu78/PTwf3/5yX999vLV8yefn8B7+PDg
4GDn3r27W7vrt/Zvb+5u3L59c21pdnFucn5+amF5bmliaGS0u6s3GkraDGGt
OKETDbg083HrL9v4SgctYsDvvZxv1CQaM4vn7MoeBdVLaohyOoaNnAE9a9DM
nXLLhm2Cbg05JcYGOK1OaqMJXyVrLmKUncFcebv1/F87LvyVUX5ahrioRl42
40vspDJ9R6GuvdSErQR/WNVSpEIWu5nNDuB6DERMivew22Bak4XaqCfUqFBl
emKtm9dh5iOswg6bmKDnnTyQSsagqwR8vUJm0qksRrXLZXS5zEaD1qg3OW1e
nyPUmcsPDQyODA/2dXWmY+FUyJ+N+Dtj3hCsDZmUPp3ILmOYuHgjGw3z8Q4x
EQAb1DKAPAoykB/kdgXZIkA7ZUQw8WvoISMnbhUm7eKETRSDBUETM2CiAUUd
rFSAn02IshlRKseL5Tm+LMWaxuqTSE2mRdPZquvrMAxj9MN4IMMIwThOhafZ
1hmufZpvneBbx4RQJ0MeIyvDFF2Mbc1Igv1QdsI5MtY5Ozu4vj6/u3v7+Gjv
8aOjp08ePX/2BIwPHxzt7+3c2VrfuL26eWdtd2/r/vG9h3tPHh4cHx7e3T1c
unM0uryfGVizJaZUyVloYCM4dS83fjs/tJwamE92jUfSfR5fimPykDVmrNFO
dwbErqDE7GRpYCJbVkMWlxAlVxmaCr61WejECF1EoZsCOekaK1UBU5U2JuQT
mGNSc1pqyQqs3Ry4h2kfYLmHBa4hkaNf5uzX+AZNWN9/MuJvSLo+UPZc4EU/
QOv+WkH/7VXkb64ifl9Y95fC6jeu1J4qrHkH8FuMeK+i46MS6rvV3IJGUXGT
qKJVWo/TdVDMeKoFQzZ3tCtrK5lXrmA+utD60UdN5z+sK3i/5tJ7bZc/RBed
J9y4QL5xiVF5Q9zUasKTvWx+XKzt0tgHjIBfd14T6NRGu6BYJxTJ8Twhihlu
1SqrIEk5LK3wqmrC2roo1BA3NIX09UETwm9Fwvp6s7EhFCLZOiGBg0oytJHN
rThLPc5aQ/E1scNIhq9F38WNTdl6F+LjC71Ly9Obt27e3dg8Xpm8vzi2Pz/y
4ObUx9sr3x5v//R0/+dnB7/qX8/v/yrwxe8f7YB3vz1a/+bw1j8PVr/YvQlg
/+b+HQDv//Ppsx+fP3715NHnD45fHB0+Pjw8Pri/t7O7vb19/87W4fbdw529
ve3d7Y27t1Zvr66sA60trc6PjfelEgmbOQjJkiZ5v0s3HrSM2JU5LQuk3IWA
4VbUOmwQTJjEcw75pEkYZbSk+KhRA2cAoo/DvHEbPyZo07VccRKrvLRGE7Zc
2VokbboM+EUVvIH86DVUwd+YZafFDeeVLZfM2GIYWySv/9CIKXNQ6oJcpAVf
DZNqvWzwz19lIdWq20vkbcX8hkJq+RnyjQ8YVef4jZdFzdf46GI+tkyAr+Og
m8gtDaj6+taa6qbaKhy6hc8hq5Vcg05qhFQKiZjH5ArYQq0WstkcgUAgEg7G
w6FkJJiO+FJBV8ZvjzuNXp0E4hLFBIQIU6+kNBs4aJecEtSx42ZhwiKKGvlg
7lXR3eBgpaL71IyAlhXV85JmERCYBDUspxwEbGLAQI072J1hcW9G2det7BmQ
Z/uFkR6Wu5NozqKgbIu2s0Xf164fbAfmCyzYOEq0TTPdCzzvosg9K7BP8qxD
XChPVcdIUJzpyInCfdr8hGNoIXxzcWJzbfFoZxMkqE+fPPri2fMvn3/8z5ef
fvLo+YtHT548ePjg/gGgeG//7v3DneMH+0/2Hz85ODoGHn1/5d7x9NpB9/Ca
OzKmCIzIUnPm7iV316Kvay7QMx2O9zudMY3Rg1OaO8Q6pMqA11sZOgtNrsMK
1UimpIoqLqHKS3nGOqG9TeBAA36lXobOQTu5q9GIl1koWg/HGBGak3xDmqXP
UkxdJNsQ0zUusI8ITL0CuE/hGTPjI/9Bz/xF3Hta1nOeFXofqf5zCfk3F5H/
Vtj8+8LGv1xufPMKiMoNpy7VnSpGflhNKKwWnm3TFuNMdR3aulZpLUrVTDKi
aTC2WVJVQSu82PbuB/Vvvl976v2aD96tOPN2yQfvIgrOtF89jys+TygpIJdc
41TWKlraLTi6j6FMy239Blcv5O3WRvuM2SFLbhgGldYfJptNzRpFJeDXKqv0
quqCmsaIrjFqQIT1TQFzc8DWaoFqDPpqj6fdmlVzrDiyHkHQ17eqizHmMrqv
Hm8rF4SQrkFJ/2pw+lbXws3BtZXp7ZurO6sbO3Oju/Nj95enHm8sfnzv1leH
298+3H31aO+n50c/Pjs8OR/1/OjnF8dg/OHp/e8e7397vPnN4cZX+2uf3V35
dPvml3ubPz4+/K9Pnn15/+CTg4PnBwfP7h8+OXpwfPhgb+9ge/seIPbu2q07
a+vrK7fmZ5eGBscy6a5wKG4xwS7YFnY68iHPeDoy3xmdzfonY/YuozAsITvp
bf0m4ZwPGrWIZ52qBZdyQMUI0xA5IXZIS8sIUXkJNi1G6ZFXJdVnrdiTzTdP
dkupL9C0l/BrLzR/+Ie2c39GX/orq/w9cf1HquYLZuw1E+qKqOodatEpYc05
C74SJlS5mU0eVosWdcNKqcdde5tZfR4IXfQOEL3mPBCq+B18w3lM7fm2ioLG
kkuVhQVXzp45887bp974y9kPTlWUXWqoK8ag6iVChlIikPL5BrUWjSFQaQyR
WGowGHxedyISjAY8foc57rGlvHDCZfAbJGYRRcNEq+jtWhbaIsa71fSoRZhy
yGImAWDWo6SB0S4iAHd2Sck+JR1gG1IxvVKKQ4AHBdmnIkWMzJSTnw+JupKy
7rws3yPuHJLEB9jebjKc69BnWqB8C9TdYuxr0/ahoQGseZTknGH6l4SBZZF3
TuCa4Jj7qLo0URcnWTOsUI8iM2IenPVNLke3Vxf3b68/2d/97OHDfz578c2L
T799+dmrl19+9ugF0MdPnj1//OjRw8PjBwcPHh48eHz/8e7R4/2Do4Pt3YOb
d49mVvf7+pfcnj6BrYvjG5KEx7XxcWNmypEZc3rSOpWdpYBbRVCTUNMi0aGl
OrxAiWJLm1mSBqashiq9wVRXCC0IsR3Ft2PELooyeLK0UmYmiA04qZmsdjH0
YY4hxtImSKoEWptHWwYp9gm2eYgDugDUI7KN6cnZ3zM7/8Lve0/YdZbgfadK
+LvLhN9cxvxnEfZvV9vfuIJ8qxh1uhx/vopUWEksLMMVIJQXCNZylq+V6UGR
zW1YbQtK1dQur6vjFJeTzxcCfmtef6f0r28Xv3Gq+NQ7xe+dqv7g3bqzpxEf
vdd87v228xcIV0q5FfWKRowFK4ryrH264KglNmbJTtjz49b8iCXfL4kk6FZr
K+DXKK9y6ZrCxraYqT0JoyOGFr8e4TMjXJYmq7kOttTZ7I2mhEDmJtINTXht
BRYqxZtKGe5qUbhZk8T7B6TDK8GNuyN7u4v7Gyv3FpfuTC0crs48ubP8yd7G
5/fvfHG49c8H9354fvg/P3sM9K9PHv788QMw/voSzMFbPz659/2ju98cbX65
Dyi+892D/e8eHb56eHT/5vLznd1Pjh8+3j/c3969c3traXF1dGxqqCsPlIpE
jDqIxWBjMcQ2JBrRhKypqm2oqW6uqaSiWmApN2pS5J3asV+eoWFnoszU5pSC
MQTLRq2yAR03IyBEWW0ubFWM2dopwQZpDV5ytY9SY2i7pm2+7KHUBtkIC6Zc
1nhJUHuBcv3dljN/BOGZUvIOv+aMpOGcrOGsoumsouGMrO60qPY8r/IMt+qM
qP6CDFEob7l2cnYaX6lEleFLTwNyO669U3f2NcSlNzClp5sL/1524S+F7/7H
mTf+44PX//D2n/7wp9/+5g+//e3f/vS7P//xN3/7y2/e+8cfC86/dfHcOwVn
36spLSZ1oCgMNo5ERaGxeCJBKpU67Baf2+Y062CtzKIWOXXSgFnuhUQAYYOA
YJPS7AqaU8XwQdyQQQDkUbNgIQFidQBrNnEwNiHRq2D4lEyXiGzj4e18gkuM
dcnwXjUpZKLHnOxkkJeIc2MpVjjDdKeIlkSHPt6qSzRqUo2G7hZ4oMM2TodH
qUD2CYZ3jueb53um2Y5RhjaNUkXbdFGsO89JDmm6JyzDc+7Zmyf8HmxuPDvY
+/zRo2+evnj1/ONXzz/99tknXzx+/vnj5588evz04dHR4e7B/XsHR3f3H9x7
tLe/f3dz9+7a3v3VWzvjAwuhyLDWOyg1ZChwN8PZz/MMSJydEmNUoLDThUYS
U1nJhxq5mmYyvwZNK8czqmiCeoaknsgrZSiqVC6UwoVmm5pVQaYlq5B4mDo3
7ddLSGonXetlKtwkhQ+nDKMMOay+G2Xow0B9OF0fWdvL0vaLoAE5MfdbWvdr
3L732PkzGNc75aI/XiX/7hrxtVLSWyX4t0vx71XTzjfzrrcIKhrYpVXUIqT+
As1TKYqj+CEczdqO0TYCeJHSqkZuUTW9oAT3fkHjW6fL/3Kq+K/vXH39H1ff
/kfFO+/XnD7TeOaDpg/fa/rgTMe5q7RrlcIKjKmNH2KYupXuQV1gGIqPmtLj
pvSoMdcnBvzaHB2g/9r0CL8ZFYaxURidsuNjVnTI1u63ttjNdUZDpcla7fA2
wHG20ovjWpqohgoiVEo0lNCtlXx3g9jVDCeYXSO2lZWunfWp/eX5nZm5e2Oz
e4tTj2+vfHH/7ndPDn94dgz04/MHP798BAQm4OVPLx7+j0+e/M9Pn4IRzH9+
tvfdw+0v9tY+37313YPdfz178M393YdrKw83Nh7c3ty7tbGxuDI7Pt3d2efz
hnSQiYhq6WiqrywtKrxw/vxH5woKLp396Py7755+88033337rff+/reLp99u
LCkg1Bfz0LVGLsYno598SgUkt4Dg5eFjYnKEj7Ph69ykJiuqIkBtjLGRdkyZ
sfUaMF953TkLutTUcV0HknPDRX7NeXbFGcr104Sr76Avvk4rPQ0glTYVyBEF
wILViHPKxrPihgJe9VlO5Ye82o9EDZdEiMvStiI1pkLQcg1z/b3WK2+1XH67
+txfmi6/1Vr8bvmZP5360//x5h/+z7f/+N9Ovfaff//D71/77b//x7/927//
5v/60+//7S+v/dupt//9w9N/+uC91979+x/+8cZrH7719/OXrhTfqKiqq6+t
r0MgEEQCRsRnaeRCnZRnVPCdkDgEKyOw0g8J3RqOR8s1CokWCcWpYvn1gpBJ
HNQLPWqOXUZ3SGigJkNMQDHOwiMY2VgtrV1NQcoIVXpWs0uBBxU4aGP4XTS/
l+YOkl0RoiWEhoItunCTNtZkSDdbujrs/RjHCNM2RLcN05xjdM8kyzPJsA2T
LL14bapdG0UaE7hADzc3qu6fhscXPPOr4c2bs7ubK4/2tl8e3f/04fH/y9Rb
B8d1Jeq+OWfOZMKxY4iZQRYzY0tqBjUzMzO3mhnU3FK3mMmWmSkMdsAQO5yZ
TDIZxnvve+/PtzU599at+mrV7i2pSiX1b3/ft/bqtb9//PiHJ09++vyrbx8+
/urBp08+vvfJ/Xfe//DOO+/feuuDG2/du/neW9ffuH3pxq2NK3dWT1+fnDob
Sy1bw4tKXYpgyOEtBYolRwOIU/upUhtJaCLxTP0iy+aH7ikiEJbdTeD10UVg
mmSAIe8VmMAaP94QpZoSbNeYxjNuMiYVAL+bW2AFuZYw3xhi64NU8wjFUaR6
Z+muWaJlekhbQqrGhtRFqm6Kb5yTs6a3Cub2AvwKS9X4wIl+1YFu0cEB8Umo
uGJQcAoiqsJpOtkOJM+FpxiQaNkAbrhaMDKgn6Co8zROAEs0QbCagSFlD07V
jVN1oSWtA/SqZtTRyt69ZR37T3UeqgAdr4GW16OqqxCnyuDHK4fK29jNg4pe
ho8kS3Gtk0r/gj6+YsmcdoyecRZOD5fmVZmiKJKgh0PURISRjXILUV4hzB2L
cfNRRiZKjYWxXi/Y7u71RsDRHMZf5NpTlM11LD4Y3wViObrZw31CN0zmxjgT
vMl5z/VLUx/dOf/4zvWn128+uXITgPfbe2//8emnAKH//O5zYPz54PefffzT
449+9+g+MAJfBVgG4N1E+/N7f33y4U+fvPX9h3f/8OkHf3364PsP371/5eKj
O3ffPH9hY25htlAaCcf1WhNgtcBbGNbbAu5p6Wqtr6s+deL44YMH9+/atXPL
lldef33Hgb07972+9cieV2sOb288tr3z1C502wnKYDPQDT0yhp2L05Ogbg4W
yNI2Yr8F12NGd/oogzEuAmB2GN/hInbZsa1eWp8B0STtr1SA6wDzFQ/U8nsr
eaAqcssRIahSjWo0DDUD/deCb7bhm81DdUZ8uwrZIIPWSGH1MniDBNYoBn4c
3Qa4LaLp0GDNHlDVnt7qPdDmI/31h6r2vbBryzP7t//i4OsvHdixZd/213Zv
27Z9y6uvvvSrHdt+tXf3C0ePvFJ+cntD1f7G6kOVR/ccen3L8y9v2bln79GT
wCXqVEXFqZbmejgERMYhWUS0lE00y9legzgxrMp5DRmPNm6X2+V0p4rlNwhi
djlwJufTA2PKpY6YxHYJVUVHamhIPROjY6CBP4uSDFPT+20idNBIjw1zIm52
wMPwhxiBBMsexpuDGF0QZojCrZkh7zg5ssBMrHDDS5LQojC4IAit8MOrPP8S
wzlFtIxhTDmkLYvxjlHS8+KpM6bF8671S4FzV2PXr67dvX3+g3euf/L+3U/f
u/vo/bc//+iDrx98BBD9yftvvv/2jbt3L964c/bynfXzt5fP3l46d3Hm7IXp
pY3ixEoqvxhOLrqCczrnpECWQMmTMOUITBGFS3xIoQPNt2AFRjzXAmIZ+kmK
bgy3A0lvHwIQ5oOIwl6OFiKxo5Q+nDnJ9k9pvZMGU1plSKrMIY45xAPgNQXZ
Gi9F7cOZEkR3ieqcwNknUIYSRF2ASLMwSWZImqcoihze7Hbp4kHlQqVgtJbg
LYdqj8NUFVhNI1bViJBUw8VVJH2H2IdThGhcO4GgguGd1eL0oHmGpi8yuMEh
onlwSNOHVXVTDP0s6wDXOkhWdkJolS2ww/WgA/V9hxoGjjVBy5oR5bXw41Ww
o3XYsl5hG8YIFibo8jTLUBR5F7QjZ22jF92F8470afPYnCo1Jowk2fEEN5MS
j2ZkxbRsPCMfS4oyMWY8QgqGUO4g2BnuD6QhIxOY0CTTNUY2p3HqOFIcgLAd
IKYNxHXAVG6SOy6ZmPZfOz/1yZ3zX75167s37nx35y4QmP/w9CMgGwMJ+Z+/
fvI/vv/8f/3w5f/30ze/f3If0E+f3QNG4BuA5PyXrx4A3/bXpx/8z28e/Our
T37/6bs/3Hv7x/vvffXWnXuXL1xbmJ9LpqN2p0muZlOZEBC4tbmjqbGNTYZr
pQyHSSYTMQdBHUeP7N++49Vt2199fddrh/bvPHJgW/mRHU2ndtcf3VKz//m2
Y69WHtgKb6+SUxF6Dk5NgVuZGABhI6HfSgCZh3qclMEQFxnhwINMiJfZ76b3
WYfaNfAGJaRei2zTD3WqUO3CgTpWTwWx+QhAsRLVrMe2GrEtVkKbldBixTXZ
aP06XIcC3SxHNQHkcsA19N4Kam8l4LkAuR1lr7ee3NFdfWCw6XhL+e6Dr/3H
kb3PHT/wysFdr2x78blXnntu+5atO7ZueeXl57Zs+a99e58/dvSV8rJtbY2H
IL21oNbK+rIDz7308n899/wvf/Xslte2Hjt2pLGhpr2lvqOxEtRWixnsYGIH
pXS0Q8FMOlWb/Folbg3Xo+UFjKKYXZH26HJ+Yz5gAsa4TeFUsLRsrAogl4kB
9POBVYyxy3FODXHYQLQZiVYr3u4mDwNt0YlQDEOkjgGFe9CaxEam2dlVSeG0
PDInDc+KQ7OCwBzPN8McHicaswhVHKRN9JtSMO8oYWSWW1xRTp82zZ+xLp5x
LJ4Z27g4feX6yvUbawDLN66svXH97Du3L7558+yta6evXF0+f2Xu9JWppYvF
qY10aS0xvhCaXI7nZgOhUYc7b3AVdfYxiTpNlCSgshREkQLL4xCJHyZyooU2
vMRK5joGqYY+jKgVwmyGMduxvF6yBEyVD4osaG2Ioo/RHQVReN5kySkEXpYy
KjcEWYDtAjL4N3eu0/ixphjOnhvSJweMeZCpOGgch6rHkLIsRpTC8pME+dIe
7coJ3UKdKFdPdddgDbUkfRvD3EvVtQ1Ja1HCCrKqWexCqQJUkYNE0yDp4QZV
EeZYYpkmWbwwhmgeGNIA5tvFMIPEbpgqgJIMD5IkzQPEsi7k0Q740Q7wiQ5Y
WQfiZBPsWAPyWDu1Bq0GMbxYeZYtTTM0oxz3kjJ7xTl23Z29YI2uarLTymiO
B1xgoylBJqcYzatKBc1kUZ/PiKMRqsuLcAUgnjgkkIVGSvCRWUxkke6bItuL
eH0GIw0j2c5BlgPOd+J1Qa4rrsoXvaeXc2+cm79/6fTDSxsPL5z5+sO7QPP9
8dEHAKE/U/yv3zwFKP5vWv8vAUX4798+/h9ffvT/fPPp//zyk788fO+HD+4+
vX3lnfWl88XRlN3mVqnkTCYeAmuprjt24MjJ42UAwnh4m1KA99rlBi0PCe8+
enT3a9uf37b9pZdf/sW2rb98fesvju19oaX89bbybU1HX+wse/XEga0Np/aT
ET0WCX1YzrQLKWbmkArb7+PhvWykmwkP8TAJKT4sQDppIDu5R4dssRC6rYQ+
AF4dtttEBMmR7YyuCkLTYU5flQLZosW2A55rJXZYSe0WfKuFBgICs2KoHQjM
Mkw7B1JH6D4F+D7guX21Bzor97VV7u1vPtHfcrLh5O6DO3917OBLxw5s2bfj
xRef/c9n//M/Xn7+hVdefvGF5/9r69ZfHjn8alXFztqKHe2NBwa6Kroaj1cc
3vHazh0AvM/8xzNbt75aV1sJ7u8e6GnrbKrqaamEd9dj+5tp8A4FHeHVsgF4
IyahV8f3AZXBJI47lBmvfjRkKUSsgDIBY8ShcOv5dhXLLKPpRSRAwIFZitGL
URoxXCNH6TUYnQmrtWAUZqTUBBWZ+/mmHqlj0D5CSi/KJs4ZJ87po1NyoOGG
J4W+cfbmhT2DUsf6pIF2VbjbnBz0jg3FphjZecHoomxsXj46JxuZdOfmwuMr
IzMr6Zn5kemZkbnZ5MJ8enkps7SSXVrLLpzJTJ2OFZZ9sVl7cMIYHzckJi2h
MZN1RKmLi7UpkTxBYwch3AhImgSpsoOaDFQWhgPIbD5JwUwE3pAEbQeE39DP
aISwO7DifqoawTaghI4hY5xlywlc43LPlE4S5NAsJFlEagpz/rdYlgjTGiNb
E0PmEah+pMeU7bEUQeYSWFOASVJwXhTBCqFMa0esa5s3j6SpBqargW5u51gG
RDYIV99DltUP8SuAUWyFqFx4iQXPUiI5iVbVONwyR1GNEhleCNbQjVa0o2Ut
LCsISLDGBNYQRgnMvQRhHYJSDiWegqCrwEPVg9iqPmxlL7kKLmyl2KCbj2XJ
sqQZmrbE8Z/W5G4MA4qd1foWJdExoXuEORyhh9OidEGVK2jzo7pSyTCSFHoC
eLMLbPEPuJLgYBEanUGMLKGj6zTfEsk6hdVkMcIIguVBcDw4WZBjz+r9GWtm
1Dc7lTi/OHprZfLtlel3lqffObf80bWzX7xz88cH7/882/zzPPMfn3wEvPzr
lw9+nnz+P3PR/++3D/722fu///iNHz+88/UbV99anpkLeqNapUchdSuUWi5v
aABccejY7m07Th0r6+3uA3ecRIPrqLgeCr53oK/+1Mk9O3e+ALz5t+/41fbX
fvHaS8/s3fZM3fFX28u3dpRvGazbWXXqwOH9W7ubK3QSRtypj5jlTgndCHgW
G+PioO00iIeLTCmpUTHWxQB72GA7qd/HQrgYMO1Ql3aox0qDagkDbFA9oeU4
p79OhekwEHp+XoI1TO2xk7sMFBBArhTTqsB2yrAdbFgjrqsc3nKiq3IPqP5I
Z83BjprDvS1lzdWHj+/fcmjXiwd2Pbd/z4t7X39lx9ZXXnvl1a2vbtny6ssv
v/SrPXtfrqx4vaPtSG/n0f6u4wOdpxor9hx9/fnnXnj+F7/8r+eee/bAwT2t
LQ0wcA8S2oMe7ET0taD6mlC9tUO9tQxEh4oOd8hIHjXdpeMBkPrN4phTlQ2a
SonhiaRrMuUejdlTfkNkWOk1iWwqll5M1olIRilVJYApBRC5CKpVYUxmosFG
kJuQfM0gTzfINw4KTANKF8Kf544DfnrJOX3GEhtXRUvyUFHozTPtabwhBlEE
uyTeVm2ky5YB+0vY8AQxNk5LjDMTY4zIZleVWpPy4ZTGk9L6R/TBuA4oQ9G4
YSRjzY46CtMA3a7krDU4qXUVFfZRsWdU4i5ILGmpJsqXhtmiEIPtH6K4+9iR
Hmm2T1+CmYsoTRIp8wL+iwX4JVt6kMrmQV59P7sZxu/GiPvJagTThOY5MLo4
01mSOsflurSQ5SQz7FRZTGFJCKwjQntCaIvznEmeO8MaTuPMiUHXGMRZGrQX
+wyFXnkKJIj0swJghh/qPF3mXKuxTDfK4k18ZxvfBhJbYWIzVGwEsRXNVFE1
S94kNw9q7FipEctVIDkjzfKxQe04RpJG0dyDeFMvXtuF17TznAOaMHI4S3Rl
SYYgUmzspUubSYIGKrOTwuokstvxvA6irIduBHM9GFGMKElSlAXG8JJs5Jo1
f9s5csUcPKPwrUmHEwyDn2j2U4JpcbqoSxU0yawqO6YJxjkOP9bgGjQFQPZU
v6c4GJ6DJNdQkbMU9wrOMImWZRDsEIzuRfFCdPWIwltyB8e8ybHQ1ETizEL+
1trEOxub+2C8cXr2g0urn71x+TcfvfmHzz7845N7Pz16/7efvP39x2/97uF7
f3p6/y9ffPznzz8CzgMCXv6vL+///v7t79668vTG2Ttzo+NOS1Am8svFGZtl
PBTMeXxSGrOpovLAjl1lR050NLcje8ugXSdhfZVoSCNkoK658fjhI6+9vuuF
o4dfO3LwlQO7nz2699mGkwC/W7qrtiJa99TWHtu5/bljh3awKMiIS58PWGIW
mUtCUxPBdhZ6mIX08jFpLSOuIAeE6LSWFpMQwkIc4Ms2KtTJRrn5eBMVJkK0
U7oqhdBmLbHXQh1wMAa9HIiPC/WwB8xMsArfLUa2iFAtfFQrdaAO1XES3HS0
q2o/qOl4V93RjvqjHQ0nAM/d/sp/Htz98v49z+/b9dL+PVuPHNh76MDBfXv2
7tn9+t49O06V72tsONjVcay/58Rgz8meliM1x17bt+UZwHn/69lfAO0eMN9+
UBcK3o9HDlAwYBKyFzvYguypGeqpIfTXsVFtWgbMJSO7NXy3ThgwyxIuXSFs
nxjxTGX809lAacQ9EjD57QoXUIR1fL2CoZFStTKaUgRTiGFKGUKtGdIacWoz
TqxHcNQDDGUv3wCROZDmCDk1o16+7F++7B1fNY0U1bExRbggdKfpljhGFxpQ
+jvlvhaAX3sW8F+Ut4D2ZlHe9JAzjrYFoQI3mecgcqw4gQUvt1H1TpbZzbV5
eMN+oS8hj+S1oVENAKw1y7fmebYxgb3ANSQZQJ0UBxl8H43hxlFcUIq3lxPv
kRX6zNMw69QQEAUV/iGRHfBf8pC+DaZohEpaELJujHxwSAbBK6E0PVLoJmri
DNeEwlGUCnxUmg3P8/MBfk0JviMtAbT58IUYy5WiudJ4RwrqH4f5pyCeSbCt
NKjNDYhj/dzAINMH9p4p96zWWMYb5OFGwXCHxAaWWpFSA0xhBAtUbRx5g1Dd
rrZC9HacQo/lyxD8dJuiCAb4BRI4L4zg+BB8D0rgQYj/bb6+IjU0znBnSAYf
kHD6+OouqQwqlkOFSqhIBxdbMWIPThoiCqMEUYKgG2eHLhqKb/tH3/TELukC
G4rwWZUhSFA5MTovMZARZ0r6kYI2llYmskp3iG7zDxl9UFOo35LodRR6/LOD
I6eRwfPk4RWMZhwmSELoATDVg+JHWbqc3l3y+AreaN5fGk+cWRx749zsR1dW
Ht5Y+/TmuUd3Ln7+9rVf338DABZAGNDvH38AIAwc/O2rT//13eN/fvvoH988
BAQc/O3RO7/78Oa3b17+8MzspMdkomIdXFrJMzwfi1yantqYmHCoVN2NTQd3
7j64e2/Z0ZPI3hPwXsCCa0hD7VhkW1dnecWpPQDCu3c9e2j/C0cPvFBx9KXW
ytc6q7b01mwd6trf3Fq1Y8eLu3a+gBhod+gk2YAtYVc7RFQ9FR6QUUMySlRO
zuhZERnRL0KP2XijBi7Ar4uFCEvJGR0/omCYGQgZppsJqpOiu0xUyDAL7uYi
AdjDIlRQgHAJMDoyCICXA29iQurx3RWQxqM9NQf7Go9COir6Wk/1tlZ0NJ3c
t/OFF3/1zKF9W44e2rp390v7dr927ND+o4eP7N97YP/+vcePHWxpLW9qPNRQ
t6uxdkdTzY6q41v2v/bMy//xzLPP/fLVV18+dvwQqK+LTMDQSUM0PIKOhwK9
ggTtwIEaiAONlMFGJqJFQ4f61TSPXuQzSsI2ZdJjGI04xpOeybQP0ETWD/Dr
tcpcFonbKnWaxTY936zlArFZLUPKpHCRGMKTDLClA2x5/+b2btIugF+1G+/O
8Iqrto1bsdXLgdF5/UhRGx9VhnIi9wjVHEFpg4MAv8pAmzrUZk33uwpQRxps
jQ6YwwN6b5/S3kW1ofA6KEbWh5eCmCq41EzQOmgGJwOQI8j3pKTOtMD07ycQ
mXIs+4TQVmAoowSBB8v3klheEsmBIjrB9EA/M9IuyfXoJsDGElw9AuRnBM+M
5hsICG0zQtWMUncRDVCyHoVTwnEKCEkDU4aZ2gTTPam0jEnpDizZhhOFxcKw
RB/l2FPi4YzUHGHrA0RLBD+cxDozcHdhIDAJCS3AQ4sY5/SQNo8SReEcP8Sx
3macb5aO1XMS9Zxgm9DXL3chtWasVUc0i5BWLiQgQ6VM+KQNEzIOerRd5gTI
NzqUmKDHMoxwiB7xMJMeUdYjHw2oS1HtRFo7MaoujImiGbIjDNa6O3TOTouz
2+sAJawDWTMkY4JELWDnMMQYQngX+clb5vxbwxNvOmev26dW1dkxlseJ12gH
jR6MK8sypujmLMc1KrZE2J4Iz+mmWh0YiwdqS0Hs04PWtR7jRod1ia+fZMoy
BGEMJwzgFUHqcFIaL1nHZ0OTE6Gl6cT19amPbmw8fevqt/9et/zN27e+/+DN
P3z6wd+ffvqvrx//j28++/vX/33b969A4f3us7/95smfv330+68//cM3D/70
3aN/PHgb0LdvnLs+ER91yJNG0XjAvDoaOzdburCydHb1TC4zzeWZKmqgr+5s
eGFbfUPNTiBhoqHVWGQNCnwK3HWgp3F7Z82rlfufaTz6q/ZTr3aWb++r2Qtt
OoZsK0e0ljeUVe56eev+7bvbGlpsRns4GIuGY3azRSWR+K1mj1o+LOLkLZoF
r6VkEGfl7IJDnbEAv4ZkRCeIqJheIdHOgFvIA1p0uxHX6aIPRvjIhBAZ5cFi
fHhKhAIit5M+aCL1KVBtQMDGt5VB64/1VR8aaDiF6G6Cg1pwiL7WpsqtW38F
aMfrLx3e/8zxw8+WHXu+7NiLVWWvNdXu72g63t5cDh3o6G5raGusa2morzxZ
sXPrjud+8fyv/vO5X7yyfce+I03tXWQKns8mcchQLqFPRuuXkns4iGYCqBrb
W4sDNZGgPQIyVivi2VQcv0UWd+sSHn3MpQXGlN+UDpjDDoXPLHZoOCYZzSih
WOR0p5brNQoNWrBGOSARdfG57Wx2G5vbyRH0cUVgoQyuMpK8YcXEXPDcldKF
axOL68nRSY9nQuosihw5jiVNMyWI+jBG7YMq3H3GMNQUgZhjYFO0Xx/qVXjb
RI4GrrmaIOvHinsJom6KBLAbCBDOtRa0zopx+KhmJwGIndphojnEcaWlnlGN
r6hTR+XSAFvgHhK4oHwnjGdF8U0kkZWu9jM1IYxupM+Qb9fn2qTRDqq1HSVv
G5KXoeUVdFsfP4AnDaMRZjDcCoLb2/l5pGoCa5jAy2NwrmWAo0JINHS1Xqj1
ECxhqi1GBkKsLjBoG4F4R5GBEsqdh8ZnSZklbnyK48+znSNsc5CucVFsq036
+QbpWC0v2cgLd4j8YOkwUqnHaGVoIx8xLETFtYSCk5Z3E0cc8Ih10JWDxSdJ
+VluviRIj3BzUXEpqpmM6acT5tm0eWHUPDdpnJxWZkrsQBrjiIFdMZgvAosF
EDk3YtSOyFvhcRvU7YJ506TomjRz25J/w168ZZu+bC4tSEbSFLsFoTMMWn1Y
W5yiDmOB656zILJGgfDMtA+TLHb0z/zapgbMKz360x2aSZo0i+dFkfwgWhIk
6OJsf0GTm3YtrqbWVnNXz03du3Puqw9uAW77w8dv/fTJOz/ce/unj9/786P7
f//iAcDvP7/97B/fPAbg/fOXnwL8/vM3T//145f/+O3nf/rm4Y9P73//5MN/
PXr39/duPbi4eCEfmAkY5iO2ixMjd9Ynb6zOXllfvXD63Nz02rBjBIkWHisf
2Lan5dD+VypP7GxrPDzQVQ6kaFh32WDbYVDjntbyLX11u6CthxFtxxGtJwF4
Yc0n+2uPHHl9/7YXXt316vb6inqzzhL0RyKhqN/tcZhMdo3KJhGENLJpr201
NLzkNi45dVN+c9Gly1vlGZMkqeNFlcyQhBQQYM2EXiuxx80AA/wmxWgAYUBp
MTokRHrZMCsVpMK08wYbyF2VqJZT0KaTsNZqVG8LtKcZBe6srznxwgvPPPfc
M8+/8J/HDz9XcfKVmvLttRU7Gqr3trec6OuuAXU3DPa19rQ3d7Q0tjQ0njh8
/LWXt7347EtbX3pt3/HKqqZWGArN5tBFPCqfhgD4FRK79VyEmjYowHVToa3I
zpqBlhpEbzsNg1By8QDCQZsi7FABigyro04NMAJQe4zCYS0XKL82JdOuYg1r
OJtl2U50WHAmHUolh4pEIL4AJJBARHKETIszDbMiGePsWgK4tp69Nj6zGs9O
uHxTcoBfC3DxHyHrozig06kDEKW3T+XrVXp75O4OqbNN7GjhmetZ+mqauhwn
6cP9m1+qrPdnfjXWTX5Nw3itdUhlxWjdZFuU786rPKNa56hGHhSLfXSRFyvy
wHnDULYJztHjBWY634yTuGDqWK8m3apINHLcjThtE0zc1M85gFXXcVxgQZBA
8+DQNhjC1o/zgbgpqHJ8yDhJUMYQLGMfTTLIleJkCrbeR7JGaPY4xRzBmKNw
VxaAFxOawATH0cl5enaZl5zlR0oCf07oinPNPqZ1tU47VyUZrRKkG4WxboEX
zDNCgYublAvXcVE+GSFrZY372EU/OeNFj3jgkSI6P8eYXBJOTEtKBel0Rr2Y
s6zmh9cKzrWia33KubrgWF42TixIM1OsaJEQGyWO5AjZBL4UxI57hooudMaN
DvlRsSIjsSZJXzNmb5iL14yTZ7WFKX48hjfrB6wW6HAAZwwOSd1wTZhgS21u
nKKzYU2WIbMNYfHBrEmIZWLAsNCrWekA4OWE4UAT5/hQqhjdVVCk55wz64kL
VyZvXF+49/b5Lz+++/3Dd4B6+9uP3gT4/eOje3/+7KO/ff7pP74EEvImv4D+
/u3jn+ef//bt43/8+gmgv3z98Icn97799J0f3r3x1a3z9zdm7s7lbs+l31op
vn164u7pqXcvrd09v3HrwsWr567NzWzYLAkonHuyYmDfzl37X3/9+P69taeA
alnR21zZ03C8o+YgGDC+jjJI63FQw6HN+Fp3uKfmUGflJryvv7xjz7Y9NeW1
NstwLDIyEk8X0nmP3S5lMeQMcsysmQ0OL4ccZ2Ouy0nv2oh3MWKf8hpG7cqs
SZTRc0fUzLic4qRDhqn9AL9RASorxwHKyLBZKTYuwwApGuBXiW7jDtZSe6oJ
XVVDXTWAJ+LBXfC+VuRgV31N2csv//LFF375wou/3LPrF0cPvVxRtqOmcm9j
3ZGejhpIfysc0g0D9/X3dHa0NFeXV+zevuvl517ZsWXnscNlPQNwNJ7E4XHF
Iq6MTxWzMCLyAA/bpaQPqhhgGRVCR3T2N5U3njzYXHGyr6UJB2sHGDcpWW6z
5GeKQ3ZlwCr3GMWA3AYBwKxDzQYQBizYJKUOm8mALHq8WoES8AfYnD6uACKQ
InRWmjMky095Vi8Vzt+aWrs8WloMJcZs7gmprcA3pqjqGFYVRqhCYGVwQBXo
k7jaRPZmrqmOpa9l6mromhqqsposryRJegGRxb0MOUigBf/Mr9aG0WzOcqOU
VqzBx3CmZJ68xpHTmJNyqV8o8tKEniGhB8KxD9B1YLoKzdQQSDII2zgg8XXK
ok0Cfw3JVAWTVPWxqjsou+jWLkkEJ4iQuGEqzomAWfpIITArAVGPD1mnSao4
kq7rJvN72AKURE4zh+m2OMMxQnOkiK4cPjROik6RotOE1CItt8jKLwoys6LU
lDRelAdSouEwx7JaqZ4tk4xVCDNN3Gg33dZDlvaRmX1cGlTNQntklKyVU/Sw
c15CyofOhFHpSXxpgTm3LJ6blsyMyebzmtWCZT0/fH7cd3bKe3bOvbHkWl+3
Lq5pJpbEo/PckRIlVSDlk/hiGDcRwI77h8ZC+HScEM1To/O8kQ159qJm/JJ+
6rS6UOTEQ0NWfZ/HhfSECUYvUumGGcJEU5iismMUepjaCDPYoSY/zJKEGMcG
NJPdipkOfgxDcQ/grb1sF8qQ5EVnrJOnY8B/8+bdlbffOPPpB9cAfr+6dxso
vF+9c/3XH97509OPf55Y/ttXD4Hk/PNdYED/+s1TgOI/ffHJz/d/Af32wXtf
fXDn04vL9zbm3loqvbk4em9j5sGV5Y8uzN9dHf/o2pn3Lm+8ffnSezffvHPl
zZmJdZ3ai0Hxak91HNtfs3/HscO7j1UdrWisqG6pqmypPlVfdrC99sRAa+VA
azlAdGPZnmM7n9/xq2e2PPvKwV2Hju47VlfZ4HL4UiPZbLqwMD3vGx6WsBgG
Iafgtc+HXetRz7VC9NZY/EIhfDYbWIkNT7o1YxZpzshPqugxCdHLRgD8uqgD
AL8FFbGopYxpyKNKYkqBCwnhFkqPHNXEHaxh9FXT+hsog80kcBsR2gPvbYGB
OhtrKna+9uqO7Vs2te3ZQwe2lpftqzi1v/LUobrqky2NVW3NdS3N9TXVlceO
HN21c/eWV7bt3L67tqoRDkHzRFK1Rmc06DRyoUJA1QhIWh5GQYeIyb1yGlhK
g5Bhnd11ZacO7T6+f0/5kUPNlYeQoGYxE2vTCPw2VdTz30Ea8F9AXpPIYxAA
zgvAaxCTtQKCUYo1KwlGFUEpRvFY/QwGiMWD8KUowzDHn1SPLwXXro2euVma
O5dMTzsCWQ0ArynL1CWJ6gRGHYdrYmBVtFcV7ha5m/n2OqahmqatYmjqmNpm
pqaVoW6lK0AAuUxFP1fVL9JCZEbEJr//dl4AXrWTbAnzXVmVu6AzJ5WqkBjI
zwC/HAeM4wCxbL1UDYgghuAEcDS3nyDrZJqbOa46pqMaq6kEccpbiae66AdF
AaQ6RRfFKNI0m+TFgPWdBC+Il4TrJ4m2aaoqhmBqu6nCHoFsSK1j2xJse5Ll
zDB9BVZkkpWYYyfnGYlZanGNX1jmZue4mRlhdlKaKsrCaZErxLKsnVTPHpOM
lQnS9XR/65CqFUZrRmI7qNgBMQnpEJLjBkbGTk25sNkgppTClWZI80vslWXx
0rRkviBdzqvX8qbTOduFCf/5Se+52X/zu2ZbPm2YWVOOL4tTE7T0KDmfJhSj
2PHgpsYiuEwCH0kTw5OMkVVR4axqYkMD+HUuTYt4kW77QCQ8FIriHYEhWxgP
BAmdCyvU9su0g0r9oM4ONgWh5jTcMApRjPWIRjsYXhje1ItRdzFtcOOIIDHr
mDmb2rg6cfPO6pt3ztx7++LDd68/fOPKw9uXvnzrxm/vv/3Hzz8G9H+WZwDM
/gzv//rhS+AAOP+7hx/8+OD9X99/69ObF26vzlwoxM6kgytx93rSd2Mq9dG5
ucfX1x5cX3/v3PxbG4tvnl1/9+rV92+8eW3jaikz7bGGySh1Xyu5/HD30b0N
xw/UnjpcW3Wiuq6ipubEydqy49XHD5Uf3lN2cGfZoR1Hd7+677Xn9m47UHmi
tvxYdU1lk93iSo7kCrni0uxiIZWKeVzj8dBGKbuRjV4eTbw1U7g7nrw0GgJ0
NuNdDlk291W2SdMaZkSE8zBgdnLfMBkE5OcxNXXSyJjQ0UoaSlqFC4vgDlqP
GtMshNXxoQ08RBsP00uFdZLhfZDOZlBHU035yde3vbZvz979e/cdP3awrrai
taW+vq7q5Ikjhw7u379vD/Cl13fs3LZ1+2tbtr2+Y8/xo2VdHb0MKsegtbhc
Lp/X7bSZtTKejEPSAMSJ8EByM/AxBiFOzkJRUT19LdWVxw8e3PP6nh2vnTiw
raelkkWCGRRsn1UZ95pG/JaE3wi4MGDHfosE6LxuPR9AGIjQVgXDKqXaVUy7
hmVQkKUCNJ8PE0hQEi3O4GJ6U8qxFd/y1czy1dT4uj82bvCkZeYC05SnGfMk
0yjOPIo0FiD6bK8m1SHy1fCGq5nmKrapnmdpF1j7+MZBrm4QyMw89QBftSmh
Biw1wJQWFFB7FZbNJx3ofSxrQuLK6YfzRuOIRhWS6keUQg+FZu6jm9sZli6K
phfF6R0k94Ap3RBGE0JQgVWfIuor0IrKLvqpWuRRsLBSFsZpMmx5iqkZEzHD
eKhxk1/5GH5zw4FJsjKC5Or7eCqw1kQZdkmBtOnIcN2j/Oi0KLkoTi8J04uc
1AKztC7MzrH/fduLlRwVxLICf4zrDDBMK0dVs0ekxVP8VB3B0TDAq+7G1kEQ
7UQ0WIBHmrmkkJaRtFNSXuzYCH5mjDw/T11f4Z9ZkazPSFbHZOtjmo1R80bB
dnHcc27SdXbGdWbReXqTX9PMmmp8WZqbYeXH6YUcuZgklCLY8fAQADLAb6pA
SU4xsyvisXX5+JIMMN+RCC7sgEb88GyaMpIk+WPESJbtSzK1wyiprn9zyyPL
oN4JNoXhtizGXEQpCgP8VBfR2I+Qt8NErWQdRBPkREqWybWR05cmr11fvnNz
7YM3Nvl9+u7NL9679f3H7/z16Sc/ffEpoD9+8eDPXz36y9eP//btk5+XUG6u
ovz26d++evzHJ5/87pMPPrt99Vwxm7ToLEyCW0hL6MQzfsu1iZGPz88/ub7+
+Orq7fnCzfnitYXJG8vzd8+cub1x/uLSmZXxudDwnIIXQA+I2uqxFSe6Du2t
Obi3/NjhyqMHjh/Zf/jQvr1HD+ytPnW8q7UR0tsO7esAAOrrgDTWddZWNRt1
9mxqdG5mcW1xdX1x8cLy4q0zK3fW5q/NFG5O5+5O5wALvpDxXR0NXxkNbCQc
KyHTz8/bHZGSnFSwjdAD8BvjbfI7YaCPa6lFNTmjxsalCDcLZCS1q7FtClyH
gtSnoEIFuAEeAYECdYLaWypPnNi1fcfRw8fKTlQ0N7eCwVAsFo9AoDo7u2tr
GstPVZ88UXHk8Injx05VV9V3d4HwOIpErLRZXX5fJOgGurrVpJaKmAQOAcoj
DkqoYBkdapWRzWKynI2hDQ1A+9raGmsrTh47eGDfiUPbu5sr6HioRsIcNsqC
Tm3UbYi49D/zG7BKAxaJ3yz+3/r3bngaLkC0VcvSyIky2ZBEjZYasToPzZ0W
ZxYts5eCs1eDpY3h+IzSNyqwTdJtk1T7NNkxi3fNoR0zYPNEl2GsVRQu5/kq
ea4akbtN7h6Uu5BiC5KrgwqVA4D4chBP3stTgsQ6iNKG0bkIqmGC1sc0RYX2
lNqe1VszBlNSp4trVREJ14mjGLvollamtZOk6oTQ2jvRrYDakJXtuEMg9kGU
rAwprelhVNajy3CaTkmYpMvxjCWxcVLKiRFxzn5mBG6aZVhn6eZRgjIE31xf
YcXY3RxfUG7L8IbzfP+EJLmkyq2q0oADLgrSC7zMHDdapARShMAIOTRC90dp
7iDN7aUZlg4qZw4D/HJH6jDm2i5aeSemAYbpo5NwUhrZLmbFzbysm50NEYtp
/FSRuLJA31jmnluSnJ6WnBmXnyvpL4xbz5fsF8ddP/ML+O/pVcfyumV2FYjQ
ssIcrzDNKZVYEwXaVIYyk6ZMZinFPKU4xRqb448ti0pLEqD5plOUET827kQl
YuixMUYuz0hmmNmSOJTkmJwYixtr82JMboTBB7Um0K4S2TFJUueRvDgILe+C
8lvB3FaSAqxwsYN5y+Ry8syFqes31t68c/bBB7d//ejDn/69NhKIzUDh/f1X
D//49aM/ffP4z99+Buiv33wGUPzXrx7//jMgVz8A4P3p0w+/e//N9zdWx1w2
JQGDaqrgQLs9IvpcyAGkaIDcR5eXPzw9dXs2f2M6d76YXM+NnBnLXp6duba0
dHl+fnH8djq87NCnJDwHDiXobEM2Nwx0tkOOHalqbOhAwId4HKFOo7fozUqp
jE1ncBgyLIre0dpfXdEsE2ty6bFzG+fPr5+5snH6zsWzd86u3Vyeub04fn0y
cz4bvpAJXcp6bxTD18dCF5KO0xHTalA/ZRUlZWSAXIBfN7kvzkcVlOQxFSkv
x+dkuKQCHZPAvZwBK63bSO7SUXoM9EEDG62gIWUMLA7SB2ptPnX0OFBpK09W
N9S2DAygqVS+QmFSKs08noxC4eDxdByORiQyaVQ2UHPlMo3RYHPYPS6nf1NG
vVEhlrGpHBKSMTRAQ3VxsX0AwjohTivACxkoArIP3NPS3rIZv0+eOFZ+dHdP
azV5CCzlUYxKntMk99lVQJD22eRAC97Uv/n1mUReo2BzU2gxwyFjOBQMk4qq
U+EVGoxMhxCb4foA0Z5hxOflxQuW6euO8YvG9Ko8Msv3LNLdi2TnAnZ4AeFY
6LfOdRqnGvWlWlmyTBqrVESatDGQKY7WB/BiC5qlgPLEPVxRN1vUyRR1sCVd
AiDmObCGAN0c4dpTUlde68gB5Gp1UY02ptMnDCwrYL4IhrWH6+xkO9oJitZ+
UnMrrLm+v66u/1QD/FAn+RBUcAola4QK20CsVp4LI4tS7ZNy/6rJPCVlhTDU
AFSaxQ8vCewzTH2WoAggVG602U91Brkuv8Cc5joKouCsInvamDutSy5IR+b4
mQVRaJTiSgzZg8jhIMYVxLu8eLeP5AvSdQub/EpKpzjJBoShupVyqgPTiCJC
xTy2XijwaaRpl3w0JMzHKPkktlAYWpmlnllgn10QnJkSAvxemNBfmrRfnBg+
P+E6O+U+O+c9u+w9c9q9su6YXdn8kHVuhpef5hUnOZPjnNlx9sI4Z36SOzvN
m5zjjS8IxxdFpTlRbpSVjJPTIVI2QEomMeMTnLEiJ1cQFEuqSJxrcxOCI2xP
jGQLo4whmD095Jmiu2eYujxeEIaiRD0QThuU1U6WwZXDnGDGNrWUPndx7u7t
cx++ffXrh+//5ddP/+cPXwPZeHN66quHfwKw/e4JcPKvv376l++eAPwCRvyn
zx/88ODD3z2899v77379zp0nt67eWZxJmrQ82MBQSy0b3GPjUSY8pjtzhceX
1x5fWbl3ZvrdldLd2cL5fGQh4pyLus/kEhfG8+eL+fW5y/OlMxP55dHUjN+d
1KgcMplJp3OaLH6bze9wAH4VjYazmdR4JlmKR3IGjYuE47Y19Z84Ws2g8oD+
e/XClfPr61fPrN8+t3Z5YfLy7NhbazPXJtLrCe+VQuR6wXd3InKrGDwft60F
dMte9YSJnxDjHKS+YUKvl9qfEKBzcmJORkiJhlIidFwMDwnAXna/jd5tonQa
qX1GBtjARkrIEDEVjR3o7mqoP7b3wM5Xd1adrGtr6MITBXKlwxfIBMN5hzOm
M7jVartKZTGZ3Farx2H32W1uQAC/Djtw4LJrFGoBR8ogSOg4EQXBJQyIqFCA
XIOYpBORBHQkCtLR1lRZVX786JFDe/fuPnV8X2drDQ49yGfgVGKmRSdyW5Qe
q8JrUfxcgQF4/12B2XY53SKhGHkEo4BgEhMMSrxOi9OY0SobXDYM1kXRthw+
tMguXFJM3dJN39QULoiT6xzfOtG9gnEsQixz3abZZv10tXq8TDl2XF04pc7W
6LLtthzcmSOYI2SJGU2XDrI4bYDonFYqp4UqaAeytNKJM4VZnlGNf9IUnHI4
R626mErmlSn8Kk1Yh5HBCNpBjhMkCfbyXJ1YWUMfsb4N3lrZWVPdU9kIP9FF
PgkT1Awp2vCaAYIGro6z1ElOcMmYueQxTgipnkFGEKIepXhWxLYpljaJl/tR
Oj/BHmYOB1hmF82Q4dhHReEFbXbDmj2tj81LYzNAhJYNJ/GWIMLohlq9KLsX
Y/Og3T5CMEJTzx1WzZwUFk6RAxVwfQ1C3klT4eV6id89nA14p0f882n7VEpZ
SNIzaWwmi1qeoazO0NfnuGfnpRfndZfnLFfmXFdmvRdnvJeXIldPx8+vh1aW
XNNzxvFZ7cSCPjsrKMwKi7PCmVnh7KxwflYAaGaOPzXPn14UTy5KS9PCfJ6d
jFNHguSkn5TIYbOjtLFxwWhRlslKR5LikZQkmRd742RbHA3AG5xlpTcUyTNa
e4krDmNpajSY2kZXDRkDMqWVa/dr55ZGz52f//D9m08/ffd3Xz/62/df/v37
L4CcDFRdQAC8gP76m8//8dsvAYT/8PmnPz6+/+PDe7/+6N1Hd65+dPnse2dX
AXgvlvJ5h1lNwlJB7SYmqeA0nM3F3lmZ/PLmuR/eu/a7d689ubzy7uLYhXxo
Le5ZjrkWoy4A5NmIq5hM5eOJydzo0tz84vxScWwynRnN5CdG0qVsfrY0sbq8
dOnSxbdvXvvw4rk3V+avhnwZLIpx8mgd4L8sKieXzF84vXFxdeX80tzlpenr
y5O3lyfuLhRvTGUuFsJnk97rOQ+gc1HzrF0CkAsoq6SEWHDrUKcaXK8G1zoJ
3VEOHFCYBQVGJ7Xbzx4I8MDD9F4jucNEA5lYYC0DIiIOiogIIhTUWV978sDh
Pdv2AB0cCcapdT7b8EhsZHq0uDJWWs3kZlOZ6Wx2OhLJRkKZgD/udgWcwz6n
w2O3Ok0Gq0UmtsiFRhFbziRw8WAGpoeF7eOTBpnYPiahn4odwMC6utvraqvK
gDZ9/PjRnyfEwP3tVCJSyCXJ+FSFiAZkaZOCY1FzhrV8ICq7dDyPluvV8Xx6
vhm4FABVWjJk0eHMliGtHabzw61JtH0U5ZsjpC6wxm4Ixm8Ji1fZ+Yv0zDlK
YANtW+hVFWsl2ZPC3CHx6EH1xHHTfKV5ts443mgsdFhzEFMcKXdAuap+uriP
SKwhk+vwlFoMqQrHbODrYOYI2zOmis7bk6v+0Ix7s/YGFeqQWuiQ4CVEhGiQ
YoTw3CBZuFfk70SJqppgxzbNt6+lDlRfDy5vGTrRz6rAKjsZVpTATVOGme5J
dXTNGlzWmYpsdhDCCgxox8juBZFxlC4PD8m8Q4YQ1RHj2ENsg4sM8Ouf0yTW
zYk1Q2rdlN8wR2eltiRJ60eqnRCzH+0fofpiFKsH7Y2Q8hNSw1KVcalBM9Mu
zvWwQoNcL1ETknvizlIpszxROD+bOzcTWR43ThR4hQIpP4ZfmCEvzTJPLwjP
LckvLhsvL9kvL3ouL/ovzAcvLUUursU2ViNLS96pefv4nGV8zpSaFKanBYUZ
QWlOPLUgmVkQzy6JZpZEcyuSuRXZ9KJ0bFKYyrKiYXLIRwi5CdECIVlk5Cck
Y0X1aE6bS2vSWUVyVOJNkl05vGeCHF3hpc+qE2s6Z0mqjbPZagKSARLqaYG0
3RuzxLO+jXPzt29ffPDR2988+fiP333xzx+/+edvv/7Hr//9UcHvPvvrb774
63efA/rLt0//9PVnv3/66Q+P7v/w4N5399/9+NrFW8tzZ/LpyYCn6HakzPph
AcenEIz7HReKmVuzY28ulu6fmX98ceXxxaXPr669t1Q8k3CP2ZUpvTCpFyb0
oqiGDyTAzfUJfvNkIT4/MzozXZqZm11cPb1x/tqFS29cu/H+3Tceffj+N/fe
/+bOjYfnT789ml0QsdWN1Z3NtZ1ijmQ8M3pxde36xtrVldkbq7O3V6feXJ18
e3n87lzuejF6Meu/lrRfTznOBnXTJl5BSc3KSFEuCnBeM7rdgm4F4A0ywBE2
zE8bAI4duE47qdPDALkZICu5U49vN1C7jcxBPRMqxPVJqUgBGUNGwvtaOyqO
VTRVtRIxdJ0xPOzOxpMzo2NrpYl1QNNTp+fnz44XF/K5iUQ8Fw7EPS6/xWTX
q3RqmcoqExqEHDmDCLRpOgpEgnYQIC14SAsF001CdQ9BOyB9TR0t1fU1ZVWV
JysrTtZUn6qrO9XRWgcD9+AxYAoBxqagRSy8gkfSiClm+eadX0A2GQ0wX0B2
KVHPR6r4EI0CYrQgLAHU5l2VWbJ7BhVZJxSuM2feESy8J5x5g124gk9tIO0L
neqxal7iMCe+l5veK8zvV0wc089UmGcb9MVGdapFHemROXtYijaAVgy5Fgkr
Q6PLUdhKNKmGzO+QOXCuggKAN3cu7J2y6EeU+oTGkjJpglq6ig6lQwF+6Ra4
NARTj4AkoQ60pKIFebwJ3NgG7WsGdzTBalux5QOsaoKmh+/GKcJsfVzgnVAH
57SuKaEmQ2R4uunuLkVqyDBG02ao6hhFGaJoAjRjkGEKMIx+umVM5J3ThFdM
4SVdaF4TmAEaMUvhQ6m8KJUHbgwOuRIUN6AoMZpjF+dVlpV2+xrItoowzuI0
YzRjQeofd+ZnkktLpfOrU1fXSpeXEyvTlomiKD9KyY4Rp6fJ8/PMtSXR2TXN
xdOWS6edl1d9F5ZD5xZDZ5cip5eja8vhhcXA1JyrNGMbm7FGi7zEhDA9JcrP
S0qL0okV2dSKFND0qmxqSVacFWXHeFGgjwfJHi/J7SG684RgnpYYFWYK2kLe
lMsa0xlNPCv2ZKnecXJ4iZXckGTO6eIrxsCEzpFRKa18hoRg8agmFnMTc7mp
2cKVKxvvvX3r80cf/fbLz/7y/df/+t2vf+YXsODNdRrfPAGw/dOXj/74xcM/
fP7gpyefAPD++qP3Ht659sHFjbtri2dL+Qm/Oz9sTVuNQZUsqlfORDwXS9nr
U/mbU4V3liY+Prv48PzSZ5dW761NAoF2xmcEEC4Oq/N2RULPcyjwDhXBb+Hl
E7bZ8djSwtiZjZUr166+8/5HH9z/7KNPvn708Ienj//w6JPfvffGV9fP3b+w
fjPkTg1ByajBIZ/Vszo9c2Vl+a2LG9eXpm8uT7yxOv7u+sT7a6X3lvNvzqVu
T8RuJB2ANnyacQ1zhD8U46AAn/VSQC5iT4gJifOQgOcG6INuUq8d22FENNkI
XS4qyEXvt5K7jcROgF8zE2ziwLRshJKJFpBQZCQU1NpWcfhUR0O3mK2Qq1xW
RyKamCqMLY9PngbgnZvbWJzfmJ5cKWQnUolcOp6JBeNuu8tmsNiNVjWHKabg
mWgYGdpHhHTjIR1DA83wvno6rh+P7IT0NXS1VDTVnaivPl5bdaKm8nhjU01d
bUVtTXlTU1VnWz2ouwk52EFAg9hkuIgxpBGQTFKqSUoxColaLlbFRgLmq2QP
ilk9cilIawXbokhvERtcwofWhhIX8MW7jKX7gvVPRIvvsUavYBKr/dqxKn7i
MNW3gxbcwUnuF+WPyoqnVMVqbalRlqjju2uZhlqCqBJKONYHPdjTf2ig7wgU
UgZHV6HI9XRZvybA8E8aE6vuzPmwIaMS+XmGEa0laeQZ2QgGbBAPggkG2Q60
ZgRtyA7KIh0YaVk75kQ7og2EhfegIR3o9g58DZhTR9b3SoIEQ5pvT8t8JZWz
KDKmyfIIjO5oIVobeIF+SRStTlD1SbY2ylH4qDIXSeujWqIcx5TcPacOLOr9
C7rhcak+yZL6scJhhNwzpPYNGYI4a5zoTtMArLJz0rFllfccyn+e4DtHd65y
LbNCx6QmMuspLCSm59Kr89nzS5mN+cDCpL40JswXGYVJWmmGMrvAXl6VbJwx
nD/ruLDhObvmP7McWFsMrSxEFuZDs7OBqVl/adqVn7BnipbgKD9cFMYnxcl5
SWZJmluS5FckhSVhfl6Ym+anipxIhumL0dxh6uaTmoN0fWrIkiK5krxoSpVK
mVIj5lhc6U/w3DkqYL7BFUb8nCRzQZ9as0Wn7IG8zRuzmV2a9Gjkyq1zN+9c
vnxl4427Nz699953Tx//+NUXf/7NN//44du//+ZLAFug5/7xiwd/fLqp33/2
yU+PPwb048P7X3/w1qO719+9cPpMKZd12+wirow4ZGDTIgZ12mGOGRQln30x
HlhJBNdHghfziStjI5dzsUu5yLWxxGZ+TrjWRtwbOd/KyPC4R5O0MeMWZsop
Ko1Y5kuR00ulyxfWb9+++cGHH3/88ZMHD755/OD7Jw9+fPrJ7z5+95t3bjy6
unE3GyvRh1gkJDHmDCyOjs7nkpdmS5dnC9fncncXc++tjt4/Xbq3WnhvMfPO
7MidtOPmiHXDoxiTkwBgAVQBt41xEQC5WSk+LcYCJwGcgfP/bcH4PhcV7GVA
PMzNh5rZmYM2DsTKR5qFWAUDycQMYAZ6W6trDu/a31LbqhCo5aphhzORTM8U
x1emJtenptYmx5fGS3OTpfl8ahSAt5DK5UYycV8w7PICo8+gHVbJzRK+Qcw2
STlWBR9IwkYFUyEksilQNLitt72yo+lUS0NZc/3Jxtrjbe1NdfVVFZUnKsqP
V1ccq685AbgzuKeJjBlgE2Ey1pBWQNCLAM/Fa7hoNQupYELl7M3PH6m1MIMT
bo4hgeTsnEFGz+Lil/CjtynzH7BPfyxcfo81dgkVW+rRjFYKYofogd3c6CFJ
tlySrxZlaoUjtexANclUjhQfG6Qe6EHsbe3Z2dKxq6NzXz/oBARSAcfUYOlt
LBVcG+K4xvX+eZt7xqpJyRVRiS6mFNm4MPpgH7oTSQYPsHvZjiFDBmfKD0rC
TRjZyW58WR+uF04lQEiYflI/iNYMFzRRjD3iAEafZnqySv+ozJpiqCNIaaiP
5WwimWsZjg5JCKmMUXVJvjYmkHjpgmGi3E8zj/AAfj3zmuCK0Tev02W4Ag+W
50RLA0SZn6AKEtSh/5+k9wxqLEu0Nf+/v/Pem3dN39vd1eV9ZVb6JPFeICQh
JBBCyCAh77333nvvhRXCe28Tm5gkvamsrMqu7urbfSdiIubnnKyOWHFCwBGI
gG+vtc7R3hvKs8J14V7PAM1doBrjGPsCzjbXZ5wiyof7BMk+QYSiivBtUUUw
qsvEjYNp/VBKmY5xolESUFQjWUIo1x0fwGVHqcPjvNEJ6cioamBQlctpMmlt
KmVIJAyRmC4Y1XjDSodPZHHxND6CLkAwRommJMmcJZqzBHMGa01hLHG0Odhl
cHeqrQipESHSdwr0XUCK6Le00MwwvhGjMFL0Ro5Bz1bryBI9SuqCi0JgWbpd
P9LrKnHdIwpHQm3yqaxuvcWuyRbiewcbDy8fnD44vDw7ef3s8Zunj9+9ePbr
D6/+/sPLv79+BqTlf/L7l4cP/np5+svFyc+nh29P9l/sbx0tTC0OpFN2o5ZF
oSAgqAbgj3CXAGkWE3uVNKKsD61nEB18RkDKyxnVEz4HgPCgRTNkUpbcxim/
ZSponYs7VrK+uZSjGNAN2gR5Cz/nEA/6dcWkZ3okszI/vbW5frB/cnJ8eXry
9PTo2cPjl49PXj85fnVx/+ne8nHSl8PCscjmdpNYEbPZ4hZdKeqaSbgWk471
rHt3wLs/5NsveLZSttWofsHGn7fyxrW0BLvLgQWZUHWALOgGJ67FS4QAR2NX
LYCwDQcCoNYgq6SQalVHnQ4NMmBbNZhGKbpW1FMr6G2gI6sJsGpUSxW0vrLs
6pUP/vV3333+HbYLJ1dabY5IKFKIxQaj0Xw0kgHgDfljyUgq6Ap6bK6A3eUx
2yxKrV4qM8oVWi5XxWErWHQZkyyh94kYBBEDJ2LhxRwcgHAntApAuLHy+/ry
KzV3v6u89fX3QPv9+rOPPv7jnz78z48+/P3nn/zh6jcfl13/srXuTgeoAtfR
QEG3MDFgwHwBflmYFnJ3M72vjcOAcAQQrhIssLVKwxBlps1QhBpLrc4ZaGQN
WdjFFjZ7ojNQ12CdOHGD6f2m3/EFxfMdPXCz33UTrbsKl35bT/qwHPWHa6B/
+a7yf317839+c+V/3rj+b5VlH9ZUfdbQ8HUz5BoUXYbhtjHNOGGALoxw6K5+
qr2fYiLipOg2XEMl+GY16FZLe1VVd3mvHMLztnG9FX36b8GUj6qQn9cja1u6
Ea1oZEtvC4hQ0Ua5jeSX4dR1FHOb0kFSOQkCM5SurWaYyvt1t9DS79CyW0wH
nG7pppuxdFMfWYftU6OAsM1z98kSVG2eYxoWypN0ogHRIajvlrUwrGiauZNu
RtJMcJ4TaQCssMjSJTBUfY11hmyYJCmGcKx4N9nTRbajuY4+pYPuCUtiUXku
ocjHRYkIPRLpjyRJMSAAjxASxf7MBGtgUlAYl2ZHZIm8LJpURBPqGABvwhiK
6b0htc0t0dv5ajNb6cKrvH2qEEEd61Mn8co4WhHtVIaRmhBS5emQWdtFBhhP
B3+/nbGmEwgSveaWPmM7Td/DV5OlcqZMQhXJ8FwlgmeDcnxNgnirqoCyDjNc
A3JHTGvxaDV6mcWuy2Tj2zvrz589evPyxU+vXv31p59+fvHyl1cvAX7/8QbI
z+8t+NeXD399dv6Px5eA/vbw/N3J0Q+H9x9vrq2PDA74XAoqqR8O6QE1EKCt
FGQ7D9fDJ2LpPZ0SPErZ32tkkAB+ix7rZj65nU8tRL2LMd9c2DkZsE4ELRMR
20zCMZdxz2WcCwDOQct0yD4bDwDDwub0xOHG5oP946ODB6fHD89OHp8dXp4f
XD45efri9AWgx0cvMoEcBtIDq2kW9VM9CnncrJmMOBYTrtW0c6fg3h/yHA56
djO25ZBqxi1etPGXHcIFK29MRU6yu3xEsAPbZO9tNnfX2zBNANGAXPhWB6HV
hG5SwavksHpVR5O+B2zCQ7S9IDGqmtdVKeipA/jFQcphtTfrb1+5+tknf/g/
//L9F9/2IHrMNr83EA+H02532GH3etzBoD8S9IR8Do/b6nQazHaNwarWmOVK
vViqEYh8BgMgt1ZjUUo1QraUQxYw8DwahorvwKGaEW0VkKbbbY23wA03W2re
5+pvgCb82cd/+OA//vDH333wx9998uF/fPvln+58/3lDxbW2utvdbVV9yAYg
GNC6QYD5AiJ0tfZjwWRSG4ne3C9q5ljaJGGYPAOVZ0GKfINhBOSd6UivYQpr
2ORcZ3gMYhhslCUquIG7TO/dfnt5l+pGM/ObKvznV9r+86u6331x91++vPGv
X1/51yvf/a7s5of1FV9VV31V13AFBL0Jx9URxECg7RcGWZwgg2TDEwxYlBjR
2tdQ31neCC9vgpY1gO40EepJOqQo2A7wi9d9BaF91NDzbSsGBMV2d/T1dlJR
neyWLn5Vt+QeVl1FNNRLDT1ySw9X00xVlXGtlVxHJc1U1m+sEQbQDCum34Cj
W6hMG51uJbGcRGGAos6yAHiNQ0J+gNQtb4Xx6jEqGNOB43oJLBeG7UQBT9Rm
iNosgWyua6Z+qhjAirI9jBASa2/r1rf06toZ5h6Zo98V5EciokxM8n4+QpgW
jpIjGXJikJaeYWTnWLk5fmFGkp2QJYZlkYw0EJcGYqr3U37S1nDC5A5oDA6x
ysSV61liG0bsxEr8OGkYL45iRFGUMNgh9LULHG18cytH28JWt7G0cLoOSdGi
iJoupL6pRwcjqXto4j4Gm8hg4BjsbpoIyjC2MDwN/ARYln+/46opybcG1TaP
Qa4QOZzmdCa+uDDz6PLi5zc//Pz69S+vf3j34uWfX774y6sX//X6xd/fPAf4
/dury7++uPjH5cP/fnT519MHPx7c/+H+7pOtdYDfvMdh4DLxkBbQ7evNd28g
G2sYmC4Vm6bmMYDymzKr0yZ1waqbiQBpNrM7kFmKBefDPiBOp3TilF6SNEni
RnHWpSzFrFvR8FY8tp6Ir2bS68Oje3OLx+t7p7snBztHp4fnFyeXZwfnF/tn
T44vXp09eX3+9GTj3Kl1Q2pa62+W49ugCjLRLeGkjZKlhG0j47g/6H5Q9D0Y
8d7P2VaCqmmHcMkumLdwJ3X0YVlfmtsdpXcA+m2NyhZAnr42HwkK8GtANWgQ
NYAMKCggIwZmwsM0GJCos0bQVSPGNvJ6G8jIOmjttbJvP/nsD//+H//rf3/7
yZftLe2Ao1qsLofTZzLadVqT1exwWZ12k82g0th1RptGa5DIADlUKptCoRMI
AIrVfL6MxRLRqex+fD8GiW5vhrdUwZrv/ZNcSNPN9ubbsKZbkNprLZXfXQPi
8jdf/umj93MTf/+Hf/vgg3/74tPf3/j2Y8CdW2tuAvwSOxsBeAGEgZfXj6jF
wEGYzhZ0dwOaUEvkg9gWGOB9DG8d1VPODJRJk7WWkbbIHCq72Jue6Y6XOp1F
uDrTzPVXksxlCMn1mv4vvu/409ctf/qk6veflf3xq7sffX/nsxs3P7157ePy
G5/Xl31XW/NtfdO1FnhZZ38zRdkr8LGEYR47QMcZezqlHa20hnpMeWPnvRZE
eSusHNRyp4vXCbikMoHi+cr7DN/A2Z+0Eq7B+sBIEq6H3o/n9xFkSLyiGa+u
JhpqKZZGoRIp0nUwpNVkyXWetUweqJUEmsUBmNDXQzf3ko19HDdHFBTxAlx+
iCFNcvXDAvOYRJXn0Ow93fK2XnUH3YHnB6iSKEMYIgvDRHGMIIr1kB3NIPaX
V5H/lyiNYUdRJDe029SC0rbiTXC+q08fZHoi/FhMlEtJc0lhOsFOppnpQU6h
JBhY4Q8sCweWpYV5WXpSFhuSBtJiT0zijSnDaXMy54hk7M6gRmcTAvBKtQye
oZtvRQtcvaJAryCC5odR3EA7zwOl6uuoqlqqop6ubGFpO+iGbiA/kAxoiLq+
Uw3GylAEbm9fP4ZA6OrrhxG4IKquieltFAIDb6FLkcKrgyyjV+70mE1mXTwR
HhkuLC7MPb44f/fj259e/fDj0xdvnz57+/TJz8+e/PXF019fPfmvV48B//3L
8/Nfz04BvTs6fL2zDfD7and7b7JUjATMAg4JDoFXlwPw9nVAxDSiWSawKkR5
h2HIZR52W8a8tpVM9Gx6/PHi9MOZ8bmIr2BWxzXijEWRc6jSVvlQQL80GDxM
5w/S+d1MYTM7tDlU2p1c2lvcur+6d39j/8HB2eXp48uTy0fH5y/OLn989OTn
R0/Pti9dGje6BdnZ0EpHoQxsWlgtTOkEcxHTWsp6MOC+KAUfjgdOhpybce2C
TzJnZBXlxCSzE3BeNx4U6IdkeOiisj/OQoVpiBC1I0But/Y0KiD3lO2V1t4W
JwFtwyItuA4zoV3b2yLuqhV11ymIrVxMPQvT3AurBpVfv/H1Zx/+7t8+/f0H
ZTfuUGksuUJjsTotZofJaLOabVaDRadQWdQ6j9niMhh1IoleKHSq1QC/SiZL
zRdKGCxefz+XTOJRiXQCugcOamu611BxtbnmewBeRGtZF6Siq/VeR9NtaP21
6vq6G3dvfvHV5x98+Pv//P2//v4///WTD//9u68+APgF197CwGr/mZ9p6CZS
Rw0eWoFuB6M7QN2oRlw/iAmw4OpmOMA9mpsozXc4y/ecwD1dHhQY70xMY1KT
PYlil7vUqU63spyVaMWNBspX38P/8HHtv/+x/D8+vPvBZ3c/vVrxTVn1jfLy
a/dufFV+7cvam9/UN1xvarkJ6azqpkFoOoI4yAX4ZfppSAUcwm0FUeqacFUN
yLKGtlstbXfgHTUkNVEZY+lzWGGwimj8Gsn7HNp/C0GGoWkkPIdOllIpmh6y
Dkw2NtJsjSxXC18KFyihFGE5gf8d13RHHWnUJaH6DIbnfh+YaWaKKCCRJ5TS
uESaEKjyYlNRDPArTdH7zJ0YLZzhIQJQA5KlONIkU5amS9P9DH8HXHbrFvbf
P237H6wUgRLpxXtQeGd3nxNLc/dz/SxJhK9PS615hWdI7h4QOHM07wAtPsEZ
XJKm9kTRdU5okRFeYIWn2d4RtjPLcSTEwYI5PODw5+yulN6ZVdhzAnkISzGB
ZBqiUIUVaLrFlh6FHyMPd/P9UKqzHmu816MtQ6vu4tS1VFMb24oCLJggbsPI
EV2iDgQTASV3gvEIMBGK4MMwemifp4UUbWSlwcIMCuj4Cr9UZTWq9Q6tRhGP
RebmZvb2di4vL3/68e2ff3739vUPAMVvnz1/c3n59uHZu4enQOf9++MzQP/1
/OyXR0c/HG283PttSfbNmQdT+Y18MKbiWBi9gq5WDgKkJKBsPIpXwvVIuVEd
L2OVDvsMU3Hn2lBsbyK3VcqtDKVKUV8p4h8Ougf97lI0sljIb44VN8fHV8eL
88MDE9kUoNXx0vHa6tnOzsnm5oOtncdHp0+Oz873jh8dnr15/PqnZz++vHi+
M72q5coJ8G4xhalgsSwyaTERLiUCYxHnSiF0UEo8GIuejoTOBn1HScu2X71l
oy/p+ooSVI4Li7MgKR5iQIUfMzOiAhQgP6vDQWyxYhvt2AYrps7YWWmlILQ4
sAzVIO2ql6Dqpd0NCixYTerQvl+NGS8k9yBba29f/erLT/70+WcfffXl5who
B0Cr12I1qRROvdar1wCDmF0hdGnEFhnXIGICMkk5ZqXAKOfpJGwlmyHnMIS0
fgqmE9vR1gNr6YI0IFprW2pvtzXcQUCqe7tAaEQ9FHS3qf56c8ONxrrylqZq
UH1lxd2rX3/+x4/+8//++Pf/+6sP//32lU9AVde7oXW4jiYsvB6PaCR0NGJh
de2dVZ24eiwNRBbCuLourhlJUtUjeN8jBN8STXdF0WbdAMwx3uWbxQQWMP75
HvN0pSJXRrVdQ7C+qUN8cbfui2tln35/85Ovr//xRuWnlZDr1Yi7NyF3Pmu4
+UlD+Zfgxmr09fKea0306i41nOTp42f5kqyQ4aWgxLC2/joQphKMq2tEV92D
36roKm+htHKd3do01TRAlSa6qc7GDtnVNt7XXfI7vYoqugkmcaBlNrTK3KW1
ILQmqFLTzJNVs8RVFO49Mqeap4Yb/Ax7QmKOS1gmIstG5LgowihTmRfoi2LT
uNQwIbYvcSUDOKofRvG0cwM9ohBREaVqE2xdkmfJi6yDEnmcRrK0t/Lu3MZ9
/HXHvwgHqOw0iR7BU3w4qqeP4e3nBhiiEFeTEBkzYmte5CjwnAVGYJSRmuEN
rkjC6+zAEt0/R/FO9TtG+i0ZojXJcKXEoQGLL2P2ZW3BYYd/RG/O8iT+XrYT
JlER+AoMT9UtMKKknh5JAMX1tgG/eK+hrEt5q0t+C6+toVugTAuCoob1ScAo
CQTBAbf1t4KwrU2YtpY+cKcQTjDDaeF2dgbCL8D5qU6eDy+ycTV2s9UZctjN
+VxmeWlhf3/v8ePHAL/vfvr5zctXLx8/ffnw8tX5+ZvzBz+dn7w7O3r3YP/n
k/t/eXz888X+68N1gN/Xe0uvd+Yfzg/vDsemguasUezgELX9aCMN75Wygdg8
5LHknepS2Dqf8S3mgoAW8pG5bGg6FZzPxZcHMqsj+dWRgY2x4a3S2ProCEBx
KRWdyiXnBvMAyIcri4/37z852D/f3T1YXT/Z3D7d2T/bPbg8OH1++ujVxdOX
58/WSgsymoDZS7JIVV69PuFyTmTiC4Mp4KdsjsSPSsnj0fCDId/5oOcs5zxK
GI/8wj0Pd8VCn9b2jSiwwwp8yUifdQsGNP1pGc7PRFpxIDOm8bfLWWBvX6uD
itBgmoXtFRxoGa+9XNxVpyKATfQuG7/PKqIoGNgeSEP59W+++vTDzz764JOP
PwQ3tcoEIofp/TZHFpXCJBdrBSyjiG0Us9RcioSGF5B7RVSckE7gU3Gcfgy3
n8Aj97H6sMBIQOiEYRGtKGgjHFQN8NvacBsOruyE1ba33gPVXQf4bWu5CwU3
wNoaoS31TXVlAMJA87199bO7Vz+/d/2L5spr7U33kKAKJOgeClwJqAtUDm4v
gyLvdeHrSFzwP9djJMiqkPyrvYrrTGe1Kg21Fjs9072heXx4gRCcw1km6hSZ
Cpr5Fop1raX7anXLlbuVX924++mdis+rQN+1dJeBCbW1mJqb8PLv22tvdYHb
KNVgajVKCqW4+3hJjnJYLsuLaU4SSgiB9ddDsDUwfEMzuroCcaeup6adDZcE
8PZhnn2UJY12kS21KNk1hOgqVllOVNZxzHClG6tz9xmcvQYHSm9pV+pAfGUV
V1HFklaz5A0yM8oUptsSAkNMIHJT+G6ywE9VprimMalzVm2flVmmxJpxEj+L
ogWhdH8HP9QjChPkEYomzrIWxAC/2hSL78f3maBQUXkl+asbmD+qx7iKEY44
x+DEKKxgPztABfjl+xmSMEsZYWrjDGuW6R5mRyZ5qQVhYUXsXSS7Zvqckzjr
CEafRauj3cYExZ2V+rI6e1zrSVtiJW+4ZDWkuAC/4kC3XEsWqQl8VQ8wePKs
CI4DxnS2UhwNgP92Km6iFLf7TY1sRzvTAqdooGQlBMl/v8BIE7amvgtQXQuh
CS2GUewIdgwuyMPF+Q5mAEbUwqjyPrVR7/cnC/n03Ozk/v3dhxdnP7x6/Zc/
/wLopx/ePL24fH5+8fLs7M3Z2duz47cn+2/2d17tbbw+2nl5uPFsd+XZ9gLg
v6+25y4WRvdG4lsD4aWkt+jWA332fYI1q8eCzoVMbCrl2RhLHc4P700NLg/G
ZzPBmXQI0EQ8sJBPbIwObI0NbRaHFweyo2F/0maazCYWhvObU2N781PHq0vn
2xvn21sPNjZ25+d3F5eP1jcfHZwA4fmHy+dvHr0AFDZ7e9u6AH7NEmXIYhmK
BIfDnsXBxOpg9P5Y8mwydTEeezgSvCg4T1Lmg4h23ys+9Et3PZIlM6ukJhdV
5Akza94pfr+7mYYe4WHc/e2uPmiQggjTOoP9HW46Qo9tlnRUCKB3BbAyEbJS
gWnS9cOM9G4do1dE7EK31VfduvLN5x9+/MHvP/jjf1TeraCTyGat1qJR6aVi
wFsldJKKTdEJ6CoOWUonAPxyiWgqFonvbANQ7YVDMO1t3ZDmztYGVFsTUFe7
YU0IcM1v/N6FNJdBQffAjbcA5wXgRcJruhBtCKBmt9VDWmpaGitAtXcaKm/U
3bvaXH0TXH8X2vBe8MY7iOYyQO0Nt4Fw29hyHdZZRmK3cjRwprqFrKwkKu9w
HDXKRJtzrCc0R0osUdOrjOQSIzZPdU3CdBkQ115DklRj6fWAd7fByxuarzeC
r4GRt7r6azAsEJze3Iivq8E11fa1dvNb0CIwzYqVZwSmktY6bdIMyGi2vk5u
K7y/AU6oR/Q1gzE1dV3lYGITRtyjiJB8E1JPiS8JIsiG6j5VGVF5j6lrBF6Y
2NylcxONnn6Tm2B09mjMcJm2RaCvERhqRaYmqR2mC+AAszMlWL/dEaZLglRZ
jG4YFLhmlL4ljWNWYhhn8zIIRgxGD0FYYQQ/2iOK4mUxijrBsA9LNEkmx4Ml
W5E4E7hLUwcR32ngXDVNiy1TUt2oUJJh8CJUToDC9pPZHhLPSxZ4+6RBoi5N
dhc5sVl+akmUWhI4ZnDmUrdmEK7KwhSx9ytL62NEZ1pojkgsEZU9afQWLO6C
3pDkKyMkWRirNbHlBipfiwPKC1kN7tc3A6We4mwk2qrR2ttAhKa7WkWBLo69
g2GAMo3wDk4VuP9eI+ZOA6oc1F0F7WvEiNoo1nZerEOSQwKiuyEYMaiP263R
qWPhzOLCzM72+vnZ8fNnT96++fGvv/zll3d/Bvh99vDRs7PzZycnz4+PXh7u
v9jfebq99mR9+XJz6eHG4sXa7MXK5KPVyScrkw9mBrcHY1sDUUDr+ch8yjcV
dU9EPJOJ4PvpRYOJvdnR07WZo8XxjVJ+aSi5NJheHsosDqQ2ioW9yeL9qbGd
8ZHVodx4NJB1mCfTkYXB9MoocGZ+caSwMVm6vzB7uLS0v7QIUPxw5/6To5M3
l4/fPXv1/MHFweqmnq8EwrNeILXKlD6DYSwZy7gtU0nfxnDsaCL1dD7/ajH3
fCJ8lrVu+6XLFvamQ3zfp9zzKZes/JKKNqqhTVkEi275pE08ZuIPqBlZMTkn
JmdF/TEGxo1vN2MbNF2Vio4yRWe5ClWpRtdqe5v0RIi0t0WEhbB62nDtjeDa
u+U3r3z35aeff/ynq19fQSGQaqn0/a6+cqmURRNR++QMEgDvPyVnkYQULKUX
AcALWDe8qQZSV9FUfquh7Aa45l5nWz3Abxe0HlR3u7n2FqjuJrjxDqS1vANW
hULWY7qbe1BQFKIVAWuCgesAhCFNFa31ZS31d9pBlbDmin/yC2ssgzXdgdbd
bKm8WldzrarmGzDsJpXTJjN1iS0wsaNFGWg15xDBSXxujTW8IxreloxuSQfX
pNlFQWyO6B7CaINIub1HaSYC9sERYMhUWG9fPZHRyHg/NwFJU3dgRBAkt62T
B+uTtpNUSEmAbh/T+hcdgSWXcUBBN+NRLDCK0tzT39LTD+7AN7b11nUxYFQN
UR4mBqbkvnGB1Atn6mvZ2lqetkGiA8v1HSpjj85CAKQx9yr0nSJNG0/RyLdW
i+wNCm+bIdZtzZLsOZo+TpYFiLIQSRmn6vIsW0nompU6poX6Ubosj6dFW2gR
MDMC5UQR/BhaEscrU1Rtlq3LcQF4cTooVttGtMLJbnifA9prabZPy52zSvO4
VJ5l8UL9bD+JDaRoJ47lwjKdaJ6nW5UkOIvM8Dw/PM8JzDBN40h5FsQN1/CC
taIQSBbuUIV7dRGawsM0RZWmiEbpFSl9XH1CoEu8n0z9/hK0lsKSY4giKEbQ
gJHVEM2NdE8L0VHfayrHm6qYnlZhsIPn6WDZoBxreye7DEq53Ya7DcVWtONr
uqiNeEkrUJAFYbgsg5CmkUwHFC9qofIwRoMuE81urC4c7G5dnJ88e/r4h9cv
AYTfvP7h9fMXQH4G/PfRwcHFzvbFxtr52tLZ8tzp0uzF+sL52vzp8tTpwsTZ
0vj54tjxVGFrKLaWD60Xwu/frDicWh9KLw8mgYQ8nY7MDabXJ4Z358a3posb
40NrYwOrxcLKcG5lOLs2klsdzi4NpJbzyZVCCjDryag/7TAOB12lmH8s6i8l
gouDufuzkw/WVy62tl4eH786efB4f//F8enr04vtmfmkyxs0OT1ay3R+OOH0
RCyWuXx6KOCcSwdOpvOPFgberA6/XSm8mAwfJ/XrDu6coX/Hoz6OmI9j1k2v
et4qWnDI1wK6rbhl2a9b9GpmnYpZm2zWppgyAjWO4icBre62uO17EfiqvP2m
FlVpxDXYyRA3u0tDhCgIMFFfBxffQeqCwEG1lXev37jy9VefftlYW8el0wF+
rWqlis9WsKkKNplP6gHE+00sYjfgv33dMCwS3AsHo6GgjuZaaH1le3MVUH4B
hAESAXgbqq7XV14FNd5GtNf2oluxPWB0V3NXR0snHATw+5sFV8FAVe0t1R1t
NdCmcsB/W2oBF74Nqb/TUn2j7u63lTe+KL/zTdndz8HgG3QuWGtDG/1djiQq
OIpNzZFGt7izx8r5E/3soWFmzzy+aRpZ1g8sC+PjLF+W5k/x4zlNKmsKRpRO
F1up7dVaeq2+PmecZonRlEDVtfXyLHixFS929JnS4uicI70ZTKz6rQNKhq4X
x4YSmBAyEw4IS4agyOA+UTffTFdGKcFJuX+Mr/QiRYZmqa5ZqmqSy1qNWrRe
3aNR9sgV3WI5kieHsmQghqye66wR+RrVMbi1gHeO0qwDNE2yTxrCyaN9hhzD
NSHxzcgck3zdYL8s3SOMdTLiYFYCxk108OKd/HiPNN2vK3BNwyJhiEw0IpHy
pl49lBnAClNEQYYkyPTZJ2XuWZVtQi5L07l+PMeHY3uxdCea5kDRHQi2FyFL
YsyjFPcM0zlFtYwRFIUWdriCZL9Oc97h+etEQYjY3yXzEWQemiGiUPslLB2Z
YSAqQ2xlhM62dzMFBKYYSxahsJxWBLsGKajA6eqpHjDAb5+9BhDV1cTxgHke
KMcBYVjAPfyyTtbtTkrZ+yURmA0EfjNNBWbZIMA53OD7nZqpxhayGMqXEB1m
QzaU2t5YPjncffbo4vWrZ29+eAXAC+jt6x/e/fDjmydPHx8fnW1tAjn2ZGnu
weLcycL06cocoOOFyf2Z0aPZkZPZ0f2J/PZQAnDe5VxoKRteGYitjWTWRoFi
m18cysyNDi6Nj76fylcaXRkf3pgsAlovDc68j9bhUtQ36ncCSXsmEVhMR+aT
oSG/bSoZWCgkAQEevVkaOl6cPV9ffri5/uro4NXJyeO9vcd79883t6ZzeadK
G7Z5ByLptfGZjM8XtVqnM4nJhB8YRl5uTrxeH327NvR2KfO85DtJand8gi0X
ezdoPMt4LguBo4RjK2TcjVsP0s77Gedh3rOTsK8GDQDImyHLesA0aRCn+f1O
XK0OcVvS8q2w+WsJ5Jq6q8xKbPaykR5uj5HWqaR0yijdXBIK6K3NNXfLbl4B
/Pf29RuYzk69XArwa5AKDWKumkdjE1D0XkQ/CtqHBPehIFRcJ4+Kk7D7eWQ8
j4JlEdHkXsQ/iUa01v7mvO/9t6HmZkvTHSS8DuAXgLcdUgXU3maA08Z74OYK
QNDmSgBhOLgasOCmmpu/pejbgBoqrlbc/OLu958ABbns9hdtrTfoDJDW2uWM
okOD2PQ0fnSNPn0gXD7TrJ1alo8cS/c989u+6TXf2LKyMC1OjwgLRfXEjGtu
PjQ55R0pmiIxXjTBTg4ICuOK3LgiNiT1ZgXujMCfkwLtLzJhHFgPjezGC+th
54CWq8MxxCiOAM0XYgSiXja/myZAc9UkhYNryLADEwrfIFfrQalNUK26VSlu
VPFANnm3Xtit4HVKhV1CKZKraGeroTwDlOtvEIZbVBmkrUh0jdOtIzRthqRM
9BnzTOe4OLSgCszLLKNMRRorjnWLY138LFKSR0vyvaIMTpIhqgss46jYNKrg
hWh9ZnSP7rddh1IMxRBPUxS+v95Vknmm1cBRlqCyvb0cH5Yb6GV6uqiOdpoL
xvK1S5Ld+mGCuUTUj/SqCih+oormv0VyXKN6bnEDNfxgs9APB3xWHeGow2Kh
g0NR91E0OJ6dyLH3krQwIrObIuilSXoJIngnp6GDV9GtqiZYG0juRloARPM1
k511dHezIAAT+KEMa3OfvBwrKMOwy4jcWqoIxFS2Cc1wqR/J90FYzmaKqYGq
aeWouvUGXsTjBP7zdzeWzoBu++rpX37+8Zef3r798Yc/v/3pb0CK/vGnH58+
e3x8AqTW/YWF+7PTe9Pje5Ol7YmRrfHhdSDfDqRWB5KA224MJQFyF9L++VQA
ML65bATgbnkkC/jscrEwNTQ4VxydHyvOjg4vjI2uT5Z2Zqd2Zic2J4YBNoHv
A3yTjeHMweQgMBQcz4zsTAwezZdOFieA8WF3cuT+zNjJ0szZ6uI/EX66t/Ps
/v2T1dX5waGUy+3RaNP+cCk7MJ0fHAyFCz4P4NpLuRgQCZ6vjr1YGvxhOfd2
Kf1yInCe1R9FpYcRyWbQcJr3PR6Nng74j7LOo4J7P+vYjBkPCq6dtHUtbAC0
m3QAmndrBhWsOAvixFWr22/IwFdkbVeVHbfN2HoXDern9+jI7cLeVj4eziF0
Aki2N9c0VN4qu3Pvu6++bqip5jKoOpnYpJRYlGKdkCmhE4DaS+6GYeDNPe1N
+C4InYDi0fEAxXwankPuBYgG+MV1tnW1N7S3VgHqgNYBam+rgUNqEfAGGKQK
1HSn/M63FXe/q628Dmoog7ZWAwJqcn3lNcCsa8uv1lV8D1DcWH2j6vY3Zdc+
BXT36tfA59uhZRRqo9IAc0e7Y8OY1GTv8HL/1A536VC1dGBc3nOu7AZXtuJL
G/GpFXVxVj40KS/N6JdWvZs7kY3NyPKKd2RUNVxUjE3r5lbsi5ve6RXP2IKz
OO8amXNmJ80DC87SdnRiL1XcikdGzAozVa4mqtVkvYqi19JUGopCR1FZmHqf
0Jrne4ZFtjjZ4EBZrZ1WbbtZCLbx4TZel5aJUDCRSjFGpcMr37/jF6eJEvjR
NmEcqsx3W8epzmm2tcjSDwCxmeGfVQbn1eE5tWdCZMjTFHGcIo5VJfHKIZJm
lKIZpasGGJohnmlMbilpDSMadV7JDbLpXgo/ypEVRMohsW5MYZvV2UYl3im1
Y0wmi/ezvGhuoIcf6mH7kVQnhOJuZQYholSnahCjHsHIBztF2XZOtJweuA0g
zA6Vv0/R4WZRCC6L4sw5sSLEZ1toVB2RqiNQ9T0kDQKnaCWye5lSEk9Hoal7
e8Rt7bwquLQCpauieFu4cTg7CiE566juBkm0XRrpYNgbyZrKPmkZnn+HLKxi
KZpFBojC3amL9ajiKABwurmVY4CrbZRwyDCcjgH/9puAnx7u/PjyPb9/fgs4
7yuA37//9dcfnr0A+u+Dnd2dhYX18fGVkaGlgcJCITObTc5kEuPx4GjIXQp5
puP+2cT7wlsKO6binpl0aD6fmB9IArF5bjg3P5IvpDJj+cGJwaGxfGG8kJ8v
jmxOT+zNA3V49sHy7MnSNIDqw5WZp1vzzzbnH6/NPFydutyYPVuZvj89slUa
3JsaBfg9X1t4ursJUPwbwnsbpVJQr9dwuCaReHt+8f7y6vLY2EqxuDIyMJUM
bY2kn6xOnEykzyfjL+ZTP69k387FLgfNR3HlQUy6FjGeDAUeTyYfjkfOin5A
93OWpaB8PaZZCSuXgsr1mAFgeT/nnvOosgpagAyyYaoAC9YibhtR9yzYWg+l
LcjtBCK0HAtiIGqZ3S1AhAa8tRfR2tnW2FDX+Pmnn9269n1fL1rO5xgVYpta
CvCr5lGljD4WvguHbEW21cJB1fDWGkRbHakHDgjXBe6E1CHANd0dTbjuNkIP
tBsJwmNghN52FKIZAq4Ct1S0gsqbGu5Ul39fde9qffUNaGsVcE5XR1Nz/Z17
N78sv/XVnWuf3b3+ecXtr4EPb3z30bVv/nTzyseVN6+Cau90I6qp1EaFps0V
QcUGe+KjqMIMrrhGn90Wz2/rFjbty1vhta3M2mZ+dlUzsaAYn5HOLGrWth27
h/7dg+DWnm9+2TK3aF1e8+zeTx08GNg/Ht49GNrdH55a9Q3P2YYXXBNb0Zm9
9NR2KjPuNDk4JhPLZmA5jRynmWuzcE02tsnNMwdEtizfkebqvTiDuctjRfv0
XT4ZMiLrNdE6NL9tMGFQ9lmdDEv4/YVf5yiPn0AKkp2KAbx1ku2cEVnHeKYR
rmVEkFyzxxZNvkmVZVCgSVBVMbImSdZnaPpRrqkkMpUkhlGpqai2T5qtJatu
wOCY8qgLeklSIc9rlAMaWV6uGVHbZy3mIRGAsGlQIIkS2R4UJ9ApiHQLoyiA
XEYAzIq0CdNw2QBSWkAA8PJSEMB/maG7/e5rJNf3NN9dXrhRHEdIYr3SKEXk
Y7BtVKqBRFL3EBQIgrIdrwSzpBSmrJ8ux/fLu7EyGFoOQqkbUNoaWhDKTyF5
iXaKt57mqRdGYcIQhGKtEThbuOZGmqq6T3iHwL1NlVQKLC2KAFIVR3PdMLoZ
LHPifHHFWDG6szh9sbX95Gz/+aPTt6+e/PXnN//1l3d/++XPgAv//ObH3+4f
PX764PTB1tb27OzC0NB0JjWZSozHokMBT8pujhrUYb0ippcnTaqsXTPoMY6G
nAsD8b3ZscPlme25iaXx4fni0GCmkImlEqHIQCI9VxzbmJtdnZqYHcwvDOcB
g96eGD6cG79Ym31/N2p/9dX9FSCT704O7E0Bnx8DvnR/urg7VdybHnuwPP/8
/vbhwtzFxsb62JhPo/Hp9BGLdXZ4eKlYXJ98PyYASRt4yl4pvz0Y2x+KnJZi
lxPRp9ORpxPBw4xuP656PGpbipkORwIPp+Pnk9EHpcBJybudN82FpNN+wUJE
vpJQL8VU8yHlpEc6YOTEZKQIC2H5beNgJfwu0H9NvXUuKiQkQHt5GDURIuuD
6Tl4HY8EtFoarpNJROOxBFBT842rV8BN9WqxwKqRa0Ucm0as4dMAftkkNB3f
ScEh+jEdOBSkB9HCJHWz+tGAqH2dfRhYDxLUCasHDBfZ3gAc26G1yI7G7q6W
TkQTuKWyrubmvdtfV9270tJYhu5sIeI6erpa66quX/n6g2vffXT9yse3rn1W
BoB84wvg8Y2rn969+VXFrat15dfaWm/h8JV8abPRDfVlENHhzlSpOzeJH55j
lhZkk4vGmUXP/FJseTkzu6wozQiHx1lj07yFNeXmfdPWkX1j3zGzbFhYtq9v
Ro6ORy4fzT16uHR+uvDgeH51Lza54ikuOqc2w7O76bHlcHLQHAgrPDaB28Dx
6DlBmyjslQaDcm9E6oxInBm+PcFxhWnBACXpJadspJgGGxJhnAyUW/B+X3K/
gxeMiyMjivC0PDgr0RbpqmGKvsi0z4itk2LdEN9alIaXzPEVR2rFGZ42GzN8
qb9fHqRoYkx9kmUelron9d45q3PSYhk1m0dttjGvbTxgLfmNI279kFM9aJVk
VIKEFKDYNmM3FPjGAYE6zeT60BSggXra+RGEIIHgxWCcWBsv2SbKwqSFDnEB
zs9AOMlWbqyCEbwD8AuI7r/LjdQLYjBhFC2NU0RBOsdFY1pIVCO2X9tFVLcT
VG10CZGpILF1/SwT8f0bxqydRHs70dXGiHYw4+3cZDs3DuPFIbwImBMAsTwN
0gCM7wDRNFV44U0c7zpZWsYxNYg8EF0aKwl1Cz1oY5iZHLTOzeYON+af7O++
fHTy5tn5L2+eA/z++u7tX37+6c9vf3z349u3L18DFvzy4eXl/uHhyspaqTSb
y40nYqORUMJidkiFRg5TyyArKHgNFW9gkuJm1WjEtTE+eLQye7g6vzE7Plsc
HB/IxIPRsDcIqBBPLYxPHaxvnG5vP9hYXx0vro2PbIwPbY0P7U6N/kbr2MHs
yOpweqOYA8Lz6fLU2crs8eIUULcvN1cvt9ae7+8B+fnxzs5soQDAm3S6ZvKF
+ytL27Mzm1PjhwszF+uL50tTQKSfDtm2CoGz8fijqeSjycjD8cBhwXqQNz2e
9G8O+Y+nEw8Xsw9mYkcTgYOSZ3PAPBeR5Iykoos1HRRPByQTAWnJKx11SQas
/LS8z8PoMOCajPhmEwEEyE5p93K7g1Kik4e18fvcCqZTydEJGXIuRcGn8flC
ZAfi1s3rVffuELFoGZ+pFDA1IqZOwlIL6TJOv5BJ4FJ7WWTMP8Vj9ALi0rFM
MpqMRwDO29vdhkGBATy7kM3IjqZORHMXEoSAN7a0VNbXv59RCKq7iYTW9eM6
6GR0HxbeBqoAoAb4BXT7+hf37n4L6M6tr8rufFNdea389vfV5VdbQDfQ2Aq2
uEFtB9vCMEcS4s21h4ZQyVFirsQdmlAVJy0T0/7pudjUnKQ4ySkUyYPjpOI8
bWaDv7AjX9jWTC5pZleda1uJw8MSQO7l6cr50fLpwfLKdmhyyTE8YykteafW
wsU5f6ZgjYY1EY88ahOHzIKQVRTxSENBqT8icUfF7pTQk+QFY9xMUlBMiqZi
kgmfoGgXDJr5OYs47ZKl46rcqD43r48tKvzzAsuU2Dwpsk7L7NNKc0lmHJE6
x9WRBXt6xZdc8vhLJl1cIPHSlH6mIcY3J0WuMVNg2hWc8bpKLuuQ3Tbqc03E
fDMp61jEPBowj/oMRcCIjfKMWjdkdM64tDm+KsPiBwn9VhhWXw80U8B2AaBE
aagoCxHnoJI8DJAoD+WmWpixZlaonOZ7zy/RfY0auMuK1LEjrewQQhQn8UIU
jofKtJOYVjzdhCbr4SQtlK+lSSwslU+kjYpVSb40RRcm+jgJDCfZzYzDuWmk
fKhHXugSxCC8UKs4DlPEuwReCM1YQ5Td6ZPcoqjKmaY6tqNVEuriejqFXpwl
KcqV3IvLA8c7i08Ot948efDzq0e//vTi13c/AAi/+/H1ux+B49sXj578dgvp
4bPTs0cHB6ebm9vT00sjI3mv1y6WCPE4elcHEQLqaazBtdbTkJCAVjaZDAHO
e7G7erK1srsyvzhZGitkg66gz+EJuHzZSHJquLi1sHiwvnaytXF/cWF3fgYo
wvvzE0dLUw9WZ8/X5s/XAQMde7/W5c7qi/1N4Agk54v15Se7m5dbG4DenJ0d
LS/nfP6o1TaZyV5s7706PX52tP/4/tbzg62X+5uP1ub2RrOLCc/hWOrlytjr
9dHLmdSDUmh/yHV/0Hk2ETpaGD5fG3u4Nnq8kN6fit4f960PWWbjiqKPPxOT
L6a1c3HNZEQ1GdYCKoV1E0CK1nFCYpJfgPPyel1stI+PjSopESUtquMkTJKY
RRa1KgJmldes9JiUDoeLwWCAW0E1FWUQUAObQlCL2BIWScIiAhIz+wB4GUQU
GYekAEZMRJGwMEDEXigeDe5BNgG2i4DVA0dcL6y3B4pGgQF+YbB6MLi6ubm8
sbEcgLe9tQLX3coko9gMTD8BCZzfVHf79s0vbt/88p/M1lRdr6j4vqrqen19
WXX1rfqG223tZVhSLU/epna2G4IwYxhsibU5Uh3+HDYySE0NiwpF7fC4Y2zC
U5oSDZXY6RFiYrgnVerJT2MHF8jDi9yhOcnUsn11O7W7P3Z0uPBgf+nB3vLx
9hIA9ci0MTumHZg0jc66h8ad2aw5FdGlvJqEXR4xC8MWftgjikZkkaQymFYE
UtJIRprJyceGtEtF00bRtj5gXkmbZ6OGYkhbiGjyOX1hyphZ0gTnBPZJmmte
618xBVZM9imVuSh3lFS+GVNozg7AG5m22wtKRYAjcdHUfo4lIXXl1JEpPyB/
yWMfcJjzDsdI0D2e8Eyl9IM+04jfPh5yTgWt427DiNkyZnFNO1Q5njhBpbq6
0doGhKKsW3eP5KphhhoFmRZJASwfgv6mdukAVJAGs6KNjMA9qvdOn+s60X2D
HLhDC1XTgg1UXxs7hKF7cWQ7lmzupZgxdEs3zYSgGttlNo7GL7alNa5hvW0E
GDQE0hyNn8bxshh+rkcyiFGNAJ0dI8uhFLlOTaFbmekVh5FsB4huqmWaati2
epa9iWlvodohVBuC7yFYc/KB6dDy2vDx3tyjo/UXFwdvn50B/P79z28Afn95
+wPAL1CBn15cPj67eHp68eL84tX5w6eHh4dLy4ALR0wmDYNJRXRgW0DI6grY
vVtYUL0A3x01qWfziePVuQfbq8fba4fbq6sLM2ND+XQoDmggkZ0aLq3OzO8s
Le+vrR+tr2/Nz67PTGzNTN5fmjlZmz/dWDzbXLrYXgGwBfTqcPv10e6z/c2L
jZXz9eWL7Y3LnR1A7x49BtJyyGybzBaOVtb/+vzVT4/Pfn1x+d+vn/z65OzV
wRZQpc/nxh7OFx8tjv31eO0vR8tPloZOplJHE7HjyfjFUvZ8Z/nR/ZVHuwsP
1kpHi4X9mfj6qHcuY1wZtK+PuNaG3Is5+3zWsZj3zecDMxnvdMyVt6sDSrZL
TLVzCVY2ziehpo2iiJZbcGlGQpa835T2mrIBeybkTPiskUhMo9FQKf1toMaa
8jv47g7Af/k0vIJHASTjkSUckoBFYFN638OLR1L7EDQiEhCF0EHAQnvRrUAk
BswXg27r6W4DnBcKrWturmxouAfACzyAgu51tdcBvAP80iko4CkAv0Ccriy/
Ul72XWX51erqGzU1t6uqbr4nt76svrmsqbUM2lVFYICEOqTGizaEunThdnMS
4cigPXl8eJAeH+ZnR5UDJcPIhH2kJC8UhelRSnykNzyCCBThwSIyONYbKzFH
FgyL28mtvbG93em97Znd1anNxRLg3elhaXRAnBpR58bM2UFTMq5LBNQJhyJu
kYYN/KCBE3WL0ilNbtiUHjEkcppMQT8yYpwdt21Mu3enPFtj7rVh53TKNPx+
yq0qVVAlxuSBKa5jkmKawPmWDMltV2LL5ZrRAMnZO6ULzpkCU8bgpNkxoFSF
OWInWeqk6cMCAN7wsCk27gsMO60Zkz6uN6YsloJLn3fJE2ZhSKvKWewT/sBC
2L/gd83Y7BN6QKqCUBCj9ju7UNp6uOIuQn2j13qn31fOSdRKCi2qIlQ1ClON
wpUjHZIChJsAsYI1NN89ovsmwG+/7w45UEny1vS5GkmudpwJjlbDMCo4QYug
mpB0cwfdAhWbGSov35RSOAbVlhGFeoAnSpPZSSw33SsfJSqKfaICWj6AMY2T
7FMUY5Egz/VJkxhJBCEJw2WRdnkULg6184JwVgDFDuAUSZ6/ZCmupNZ3SscH
c5cnqxf768/P99+9fPS3n1//+u7Hv76/ivU+P//8+s1v+fnxi7PLp8cPTtbX
F0dHR6Ixv0anZbO5mF4yvL23pZEABskphKhJMxr1rYwN7C/P7i7N7KzO726s
LC9Mjw7m/TZ32OUfjGcXS1PbCyub8wvrs3PrQOKdnV2bntycmzlcXz7d2QAs
G9Dpzhpgow+3lk/X5h8CmXl34+HOJqBHu7uvz05/OD9/fXoxGEskPL7T7fs/
PXnx3z/98suzs7+9uvzHq0d/efTg1cHG++2ZdpbfHW6+3l7470f7fzvfebo5
eb4yCuhio/h8f+bx8dGTk6PHR/cf7q2dbs4dLo1ulhILA96FnHs27ZhI2CeT
rsXB2NbEANAFFocyo/FAzKozi1gKKkFA6BLikQZuX0gvzLo0E0n3wkB0IhUY
irpGEv6hZCAXcUejcZvNJhYJ4JDW69991Vxzj0nE8Kg4KZskYhAEDDzAr0xA
EXP6af1oXA+MRuxg9CNZlC4auYtEgL+/yftbcm5rrWxrrQKBKgByAR5ra++A
QFUwWGN3Rx2uG0QhtDP6uwD2gfM7oHXglop7d78BMvPt21+Xl1+rrLxRUXWj
svpmTd2datCtBshdGLoKz24VGNFqP04fweqjKGee4BkkBYapoWFGbISXGBVn
S+rCpG5gxJQfVaVHedFRYmC0yzUMsQ1CLPl2ewGXnpZPb0XW9wY3t8c210aX
53LTxWg0ywqkGMEUN1qQpQa18YwmGlYlvMqMW51zqFJWScwqTAXkgwOm0UnH
4KQ9k9UNFIwTY/bFac/GnG9r2rs27l4adRbTxkJSm0wpInmJZ4BpGsCbihjr
DCawoM3sOLO7Lu+syl6UBme0kTmjb1xlK4jVUYbQQRBYCUof3ZqUBAd18TFL
oGC1xzUan0TlkxoSBkPSzPNIelX9fUYaLyg0F83BZW9k1eVfNNpLMsMQVzMk
ESbpFC8KZ2vpNlah9LcwlptEzx12olo62KwpQlQjgKDaIkIzipTmIfxYMztU
S/HdA+DtD9wF+CV4q3Guhm5TY6caBJc2IaTNWHUb2QijmqAUYwtLixdZqaoQ
z5AR6/IiZZ4jylJ5GQIz1SMZJUmHCdx0p7TQ45hneZc4lnGSYpCsKJA0AwT9
EN40hDMOYjWFXnkOrxpgAOxbitrEQmBsI7+0NbK1UzramzranD+/vwYg/NPL
y1/fAhH6x19+/PHnNz/+8tPPQAV+dfnk6cn5+f39bSAO53Lv77GaLD611ioU
qWhUKYmo5zCSNsNCIbU7MwY035ONpftri7trC9trS8vzM2PFoaDNE3F6B2Kp
hbHJ9ZmFueLYWC4/mskOp5KDifhYLrM6Pbm/tnK4ufJgd+PR8f0358dAGH6w
vnS+tQrU8ycHe08O9p8cHPz06NHri8v16dmQzVXKDf74+OXf3vz51x/e/b/v
nv/95cWfLw9/Prv/14vDv1+e/OPx8T8eHv4/j47/v9eXf3u0/2xv4Xx98mi5
eLg69hCIHKfPLk8eXRw8ONu7f7y5fn9hem2sMJePzuXDE0nvSNgJDEQLA9n1
8XFgvCqlsiPpVNTtNCtkMgaVhUezsF0aNjmgl45EXHOF2GoxOzeUmMhFS/no
WC46mAyk0tlAIKDVqNDdyBvff3Pryped0CbAf1n9aBqhk4pHcigYKZ8sEVCZ
1F5CLxyPbsFhWgFhupuR8DpIa3lz492GulvVld8DSRiIwQCPFRXvk3AbpBHZ
CenDgElYCBkPAwS4cA8KBPALwH7j2qfffffRlSsf37z9TVn59+WV1yurbtfW
3atpu92ELEcQG/vFCIEVpw1TzBmqNUdxDdM9wzTfKCMwwgqOsMLD3MSoMDUm
zhbcyYIxWpAGh6i+0R7HaId5GPJ+vZ1cd3RKXFr3zW+nVrfyq6uZ2cngUM7o
jfa7Iv3uOD2UFcfzqmhCGQspU37taNQ6HrGNBg15n2ogrimO2otTzvy4KR3X
DOaMk0Xn0ox3fd63NuNZGHfOFh0DGV00JvNGebYYVRPplkTAygGIZQYVnFem
N82AAjMyV0kQnFbEFrSRGY0xw5T7+3hWtMSFM0RZnpwsOKQOj+htYakxINR4
+Lqg1JTUamJKsqG/jQnuknXSnCTtgNQzpwst6X3zUvMIQ5HGqkekogyLGcHR
g0iyD4x3VhHcd8n+u/xMrWIEpBkDSwtN0gII4Nc8jjYUuxT5DlGyFai91OA9
Suhef6iK6K8heBoRumq4oq5dUt8pb8FroQC//foWgqauX9ZJ12J4dqLIRxWF
KYIYmZsgclI4egLNTHezU128TJdq5P+n6j2A2srT9N3duzOzPR2cU9tttzu5
nbMNJuecc0YSCJQlgkAEBYQSygFlCSREEoicwYAJxiabDCYn586zs7uzO3f+
P3pu3brX9dapc2QhoIrnPO8nnQAH/Eq60gXNmMKGdFZjWlEzgd+E4TciQHiN
KLB5cHR3W6GsU2Ts19cPVrY/qXr8xDw0UDM+0AEQnnnevzo7vr+xDPrzP/kF
Ct5d3wT8ghF4YXxivH+gr6EZIFyn0YFUSmVaNkfDYlbKRG1lJb015ZOP26af
9ACBAgyBfJ/0dnZ2tLS1NrbX1DdVmMFysL0b7AQ66uotZSZzqYFPL+BQyCI2
s1ynabWY+9pbxgb7F6fGf9x8ub84szE9sT49sfFicm1qcnVy4uXU1Or0zMzT
ZwqeSFjIHu0bfruxB/j9ae/D3z/s/GV35f3KwW3Ef3k5+9f1xf9YW/jt5dx/
bS7/ZX1h78WzxeHuqSdtT7vqBjpqJ4c6ZqY2x58tPu2fHOge7G/t7rTUNxmN
Fo2ix1zRXm5o0GtrtTqAbUt5bbW2XCdSl6j1xUIxh06nZhMzkKn4ZAiZgBAX
5JZKOFVqcYNR1VKpB2muLm2qKmmsKqmsMhsMBqGQT8wkhAb5Prh91dXuPgoa
lZOWQsTCALygPNNycXRKBiUXn01EolIjkCnhydCguGivsGAXfx9bLw8rT3dr
DzdrF5eHjo73HBzuA4QBiQGBnuERAUC+0FjfhCgvIGJQpCNC3YIDHAHyNtbX
79+/DGJjdwfA6+pm5+bp4OXr4hlpHwRxjyeEYGjxOSIEcBa/MktaRxLVpklB
LHhZLb7YjFPU4DWWdH0DscSoUuh5En2O0IgS10DFjbGChqgiSxSnOl7dRqrt
FzYPqLoH9f1PSlpbxVUmilSHEGtSxDqMwpilKSNrS6gGXWG1ntdkEHcYZa2l
wloNq9bIAvzWNPJLa+il6oIqA6upRtDZLO1ulbY3ChtqOTVVLH0JRSDD0wSw
PFEMURpEVPpQqwIEXTH6xzTjE0ZpH13RSpI0ZCjbcoy9hRUDbGEVgaZKzpXE
F6oR0opshTlfVpkjLiOxpQSuKltUQpaaCsUVDIaejC6ChxMDovNDUEIIxYQv
asgUg3LejGNUQ/L0oYV15LyKDKIBQTTCMkoiMSpvoFS8zvlAvo3B9PpAkskz
u8yLWRcuaEsUtEKZlnhqZTix1BevdcPp3NBad4TaM0XhF8lwDaN6RpJ9EgqD
Uosi0EWhKYXeiWTnxIwgGCkshRqFZMYhubEIUUyqNAahiMKWxMOVIQhlcHZ5
IrsZzW/H8VowgF92aw63PUfYQRS04fnNSBBhO0HcnVvcz5b1CtT9iorhsoYR
c/uQuW/Q/PRpHYB37En72EDnHJg6l2df72wCfve3d354++7d3qtX61vby6ur
M7OAnWedPf1NTY/NtX21dR2milqlyqJSdlYYe6rLW8q0/fVVQ+2N40+6p0cG
hvt7OloamxotgN/WaktNSZlZb2ypqm0z19YYjEalCkQrkcp4RUqRwGws7Wxp
HOztnpkY3Vpdfr2yuLc4tzM/s7swuz03uz4NyJ3enJtbGB0f7urNxWeIGNzt
xbUf9z78/OrHv//2P/+xvwzy2/bCjy+n382Nv5sZ+3FhCvD7fnZ8d2J4/knH
VG/L1EDn056mp73NC9NDY883Bvrm2puHmmu6GirqzTqTqVhZKhI3GwxNpaUA
3mqlvlpVVqk26cQ6CVNWQGXk5VByMklEPB6TDIPHRuOTE2gZ6KL8TBE9Rytk
Vmul9eWaRoCw2dBmMZnKK41GY3GxlMMuRCOSrO5ev/n9l+F+rgDedFQiLiUW
h4hLx0AyCfCs9NSsTAQWFY2AhwH5hgU7+XhauzmDGfaOq/N9UJ59fA7efXJ0
PFAw4NHL29nP3z0u3D0iyCnIxybAyzrQ29bP28bbwwrI2tX5gZ3dbSBfR+eH
oDa7ezl6+jh7+7m6hD/yh7gBfpHU2HReMlmBYZsyxJYcoTkdICypIUhrcDIz
WlGDVdcR9A0ZGp1WrOAypZlMdQqvEipuTpC0xYuaE/j1ME1HdlUft75X2vlE
3TuoaWsXVpbnFZcA/6YCfotLM1WGPMBvuYFdb5I0lAjbDdJ/8ltjYNZZBFV1
bFV5fqmSVlnKbKjmt9YLW+p4lmpmuZFSUpKv1ucXChAZhRFpnCCiNDBX789q
CFU+gZQ9oRv7C3Td+bIm8GPjlS1Z5U8KG0dFxXUZ7JIUmhLKNWKVtbnKmnyh
MYOjxTKEaLGOpDWz9PV8eS2bWZqbLkRAaJEJ1BC0OD7XkMqoRnHqEEV1cHp5
FEnjn1eLJZkRpEo44ChdH4GV+6Vr/cnloZyGOHZTLLUmmFDihit1y7EEUVoi
8xrDWBZ8fjkiXQ3DKWB4dSpem4JSQuDSyEimW2C+VQTVFsL2SOUE4nkxWFZc
Iik4FOMXiPL1SfXywfgGE4Oj6VEQUSxcGQdVhEDk/nBtEKE8jlSLJNdlMJso
/I6i/HZUZj0sqz6poANDb8VSahGcxjRNb6GpX1jTr6jpVFY1qIBHRwZ6Jp8O
jvb3DbZYRrpaxp88nnn2dHFqYm1x8dXBWQwf3r15/2rv9e7m1ubKyvrCLGi2
YD4F4+3Lwc6JFstAtfFxhb6tRFWnAvtYzUB9zUhz0/P29sHmliZjmV4oUXNF
FQpts6m6obysw1LT19LU01hvMZZqJWIFn6cU8FUicalCWVde0dXSMtTbP/70
2fzUi7XF5Tcb83svZ1ZfTKy9eLE9v7o4OjfRN/licK6r9nE+Lo+Tx5gaHP5x
d/Mv77b+97e9//p5/f9+t/vXzZXf1uZ/fjn9fuH5j8vj75ZGV0d7x7oaZof6
+ltaepq6BrpGBvumx56tDfTON7dtVJin1frBYlWPVNkhkDZwxTVFoopibb1U
beHLKpn8Uhpbk0OTodOZCXBSYBAsJBjq7x8dEBARHhYdERYeGxOOQcJgCaEJ
UX656alaGadKL2urLu2pr7CUKsu0kiqDQicXSLgMem52aIDPnetXrO7eigkP
ScehMwhoVCoMi4UjEAkwWAQGA8FjI6CJPrHRbglxQKZO7i63nOyv+3g+DPC1
CwlwOfgIONgjJMA10Ncp0NcFJNjbI8DT2cPZ1tn+voPdbSeHO84ud93c77m4
33Z0ueHgesPJ67aLz11X33tuAQ+8Q20C4/1Ck4Oj8OEJ5Fg4H4JSw/EVyAwL
IrcFl1ULTy9PJBmgjEqUuDZTXZerrcsrNhCKFAiqOJkmx7BKszlVZEF9gaSF
VtxBlrdlaVqJFR15jV305tZCSxW5Qk+SVWOFRqSwFC03ZqgM2UptrlZLNZay
GmqK62sk1VU8UxmjopJRXccsry3QlmXJSrFaU2ZFNdlSTa+tpFWb8ioriBV1
mQxVKFHihhLbYpWumaX+5KpYbitG1Z9v6jUY+0pLe5XqboG0o0DanacezDeO
F4q7CdxmNLM6mWFKZZdhiwzpXF0mW52hFPF1cl5lhbiuiV9mIRXp4vKkPrkK
36xin/Rin2xtOPgSwC+tApJbGp1vjKXUEwDCudWp2eVQgjYMU+yboQugVUUw
LdGgM+dXBWC1zmidU2aVD6k+KLPGj1qByNRBkOLoFGEMUgbFqpMxahhKFZPA
8wmn2UYV2MOKvFC8kDRRPK4oAZIT7Al1cIfYuyc5eyM8gomB0fQIqCAmSRaJ
0segSiLQpeF4U2x2dQqtLp3RlMtqpOBrodiqeEx5LM4Ui9JH4XSxBbUYVU9h
1ZDM3K+q6dI0dhof9zWOjvQ+H+of7O4caLUMdzQ9e9w5Mfhkbnx0ZWF+e31j
HzTord2Ntc3VpeXl2dnlF1NLk+MLYyOzzwY2nvXPPW593lTbW2mo18gqJfyW
Eu3T5vr+2poWo9EgELGysgmQJHRcIgWfXszk6qXiMqW8QqMyyGVyLkfEZMiK
OIBik0YL4O1pbhl58mTq+djc5PTy7Pz60sr+6szmwsTL6fGl8fG5kcnpwYnR
nrGhtpGiPD4mAc2ncqaHnn7YXv+P99t/+2Xnx/35/9xd+2V98eAexMuTb+dG
Xs09XRpu76rSVsoFNVpFp8Uy9uR5b9tgZ+vTZ8MrzfVPK6qmpMXdeRQjPl2G
xgmwafyMbHEuVU5lqKgMZR5Nlp7NReLoEHhOSCTawzfxgZXHndsOt27ZPnhg
7+To5u/rFxLsHxrkbXXvsrPNbSQ0QlJEKVMJQXnubaxurSqtNipryzVlWplG
JuAzCuIiQ+/euHrj8ncP79wMDfSDJcakJicSCAg0GgqFhqekxCTD/ONi3GOi
XBNivWIi3QJ8rb3c7/t6WYEuHRXmFRPhAxIR4gkQ/ucBz+72Ngf3EX541/re
DesH1+1sbjo533Nzt7J1uPHI4aqd8w1HTwDvQzc/K69gu8Ao18AEz0hkYEJ2
NJQanciKhAqiELoEfGVSVh2SWA0nmpJyy1IYFThBNVFmzj1ooUYCW3nAL1mK
LNCkM40kfi1V1lKgaDswYLEFp7EQyuqI5dVZBn26uhjHM8ABv1ITvtiYIVET
BBKCXJ4D+K2rlVr+yW85s7KK+U9+daYcRSlBbcg0mvKqy6lmE9VUQtJpsTJd
ElUalCnzTFO6ZZT65FSG02og/DY84Ld6sKJquMI0oFV18flNeUVN6dKebO1T
sqANU1SPoFdAaaVJdD2CocMwNWlMZVqJUmIqldXWyqrrOcpyfKEi4p/85moC
sw8+YI1iVCVxGzBsSypAOM8QQ6lPp9bh88xIYlkiVhGElHgB/xZURxfWRNJq
wkgmH7TSIVVlhzO6EUweKINLuio2VRSawDy42E6SMBqjhOF1cLw+MUkcGFXo
APiFcjyRvECCMA7Nio3N9LMNv2kXddspwdob6RJK8k9gRiWJYuDy6HQTNLMy
Mc0UgzdGkaqghY14MPnmV2NhJVEgEHVYnCwwQRKI0sYw6zPVfRxxHVVYTpZX
suo6SkfGel68GHkx+Xzi2fDkk+6J/q6x/p6p4cGFyfG15aW9rW1g3r2d/a2N
7bXllZfz86tzMxvzs5sLc1sLM5vjw0uDvePtTd0VhnIRV8MurJZL+mrMvbXm
yuJiLomEjU8IdnZxu/8gzM0TlwAVMehasbBKp6nUqjVCoZBRWESlgMn3wLyN
Tc/7n8xOTK3MLQByt16uba+uA35XZ56vzUwujo2N9Q5PDYyPPR5vMrWi4tA4
CNZYrF97Mfvr693/+eX13/+yD/j9dWPp57WFn1Zn3y2O7714ujnR11er5+fi
4v3cIrzcC4jZj5u7H7cOdLWNgNqsUdQVK7vJNCMkieEXhHX1hLl6QnwC4QDV
kEhUVDwhOiEtLBrjF5zs7pNg5xx+/5H/tavW589fuXDh8veXb9y9e9/H2zMo
0NfW+s7FL47bPbiGS42X8wtNanG9Sd9hqWytMrbWmVrrKuoqS8xlOr1cikel
2ls/uPzNxa8vnHO0tY4MDULAIUQilkhEY7FJOBwMmuCbGOcdH+P5e7yjI9xD
gxzBFBwa5Bwe4vq7f92D/Jx8PGw8XKzcnR9a3blz/9b129cu37xy6faNyw/v
Xbe1vQM69kPraw9trts63nF0t3L2fOTsbeMZ6BQY6RUIc4lLD0gtiElhRscX
BsUw/ZNk4TgDNMucSqpGkc04ujmTY84V1FDEZrqkplBiSmOrkWRxEkkEz5Gi
qJo0XmWeorlA3U6RN6SLKxFCQ7KsJEWqThFKkrm8JIoshqNNBvyK9XgGP4nC
gHEFOJ2OXl0pqKrgm0xsg5FurKCXmWmllfnqsmx5SZqyJLOkhGQqzS/T5eoU
6UIBlMoJJQn8gCJzDIEUc3RBXQKjIVXUmakZLLSMmC3PKiuG9MpOHqcum1mL
47US5P3ZQL5sSwrNBCXrIBR1coEayVDj2Oq0coPcUquua5SBb8dVJoLdAkXh
R9EE0gzhVEM01RTPrEkVt6UXd2UW1SMP+K1Np1rSyGZMZkkCShaIEHunawMB
v3RzBLkqOLPUAym3S1XYIDUOCK1DstIGzgs4+KSJ7BZd4JfMj8Kpk9P18PQS
KFwaGEm3D6dYxxW6JDG9EawQCDkwEOVsHXrJJvKKc8JdH7RDVH4AnBeDU0DT
9LDMMhjAllgel1YakVOVyGnBMBvRJGNirCo8RhkWXRwWJw1D6hMp9ZnizkJF
DydfjQXjD0WYVlavGJnsXVyefPlydn1taXt+6uXE6OyzIdCfgWcBRK93996+
fgcq9Ov9N3ubu1tr66BCby0v7iwv7Swvbk48X346MNHV1lVRbhIJlYX0UgGv
XqfpqqoqFQhYmZnpEEi0p6fH/fvBDk7oqBjAL/Bve625u76+sbzcqFSA/ixm
sVtrLU86OqeePl+YngG1eXd98/X27pudvffby2sz42BHsTo9M9E/Mjfy4lnX
cwVHDQtLIqZm1htrXr1c+68f3v7t59d/+3nv17cvf9lY/mVj6ae1hddzY9uT
g8vDXTUqPjo68OF3Fy6fPe1t71gq10+MzI4+XWxrfsZhaNEYbmxcrqdX8iPb
sNt3va9cc7py3fH6Lafb99xs7AOc3cIdnEOsbPzvPvC6ccsN/O/ly3dPnbp4
7tw3X3196dtvLzk62Hm4O3/71RfnTh3xcHlEycaXyIUVOmVNqbbeZKwrMzTV
GCwV+spSZUWJSl0sJhKwLvY2F784d/7zM7evX/F0dYqKDEEgIABeEDw+CYmI
AIFBA6MjvUDiY/1ioryDAhxBggOdwNLf187DzcrB7pb1wyv37353++r1G99f
ufLNN99/9dWV7769efX7e3dvWlnfPYjNPVsHKwfwe7g+snW1dvZ28A72CETa
xWf7oFgRyKLIJFYAhOOHkIQTdIl5VRhabQanMV/QwhC38CSNQmmDWNogEVdl
MPXoXEkSkQ/L4sPJMgzflKNpphs6CjQNmeLyVK4OArjgSBMK+fE0djyRE1RQ
HM/TolgyeDY9JjM3qoABlxRnA4RBkdZoKKBRq0py1YZsRWmmTJcm06SpdNlg
4C1R56mlRCkfw2QlkOgBJH5grjqUZo5lNEILm1LYrXhZL7lkhGN5Vl07UmEa
VGu6ecKmPHYdoagRL2jDFzWhgEPpFUlUPRTwS9egOPp0vjGrukre2KyrbRIV
63FUYWie2LdAG1xYFsEoj2ZXQzm1qaLWNN0ApewZQ9KellsaQ67JKLBkUmsJ
2UYYThmOVwaTDJEFNXEFtdF5FYEErUuqzAZebJ2itIUrbCCyh3GFbhEUp/B8
V+BfpCSeoIUDfgm6+FQJ4Nc2jGwVTbOPpbrEU7wjMz08kqzsoy87xF11g94J
wNkn0AIwkoQsPSKvHJWuTSSVwbLL4jNKIslVidxWFLshBXzrBFVCTHFMjCQK
oU2iNJBEPSx+c0FBGTFPjsMzkkgsjK5C3Pe0ZWZu5OXLF3t7az9ure8uzy9P
js+NPl+amt5Yfrm/vfPm1Vsw/wKKAcJgE2hxfWlpfX5hDVj49zP4pvr6Bpqa
WsvLzWp1jUpVr9NVyeX83FwAb3JISLirs7/tI0iAHxmNZOaSNCJBndHYZja3
19R01tf1NDU/bm4B8I4NDM6NTYKxF/gX8Ptu782HV+9+eb2xtTC9tTC3PjP3
YmjsxdBkg7ERk4B1t/KAhkIMMt3W/OJf37/9+dX6h53Fn18v/7K18tPG0oeV
2Z3p56uj/TP9bQYhIzHA4/LnJ746fuziqdNoKLLZ0mnUWzLTGFHhqPv3/W7e
9Lh8xeH7y3bffmf15cW757+8+eVXN7/57u6NW3b3HrjdvO343SXrLy/eP/fF
7dNnrn/xxbeHDp84dfqLM6e/OHr06KXvvrl548qRzz46dvhjXw8XRn6OViYu
UynKNepK3cEV2xvNxiqDqkwrL9UUK6VCam52eGDgjSuXv//m69vXr7m5OoLx
GfCblobMysIAC2ekJafhYcmw8LAQ95Ag15go39hon7AQV5DQYBeA8O/8PrC3
vX7/7jc3r5+//PW3ly5+/e2Fi998efHS199cvXzl9q0b9+7dsbJ68MDq/kNb
q0cONo8cbW2cbZw8nbwCvQLR1tFEl6QCXyQnEMkNRgqCcJLINGUcxYQtNGfx
mwulHUJ5p7K4Qy1r00lbdcJaIsOAzZElZ/BhRB5o0WihgaSvL6hop5c0Zikq
UEI9jKuGMOSJNHFiPj+RxAujSuLpUmh+UXw6OTw9J5JMh7H5OKEkUyDOEEjT
xYpMiTpTrMILVFgQkTxNU0I2Gug6Rb6ES+CxEEwmlMyKzBNH0gzxrMYUViuS
0YIuas9Q9BeWPhcC+ZqHjeVPVNoevqydxqvPZFSD6RUGZlhOLZJVmVpQmkTV
JDF0KF5ZprQqv75R1dSuqqhjFClhJK5frsS7QB9SaIpkVMbxGpCyTqJ+oKB6
gm+e4sk6M0j6KIo5g16XXWjJzK9AkgzQXFM8rTqRUZcI+CWVBaCVTnCJdbLU
Gig4Wf4IJgN4OgN+o6geUE4wVg7J0Kaka6FYZVSS0DuiwCaM8jCSYhuZZx+Z
6xKa4eKWZOUKveGedMcPZR1OdE1mhWbIYflGLL0qjaiDkwzJ2XpIlj6OXJFY
1JDCqU+iVkRhDPgkZUqSPDmtlMCop7FqqUQ5Bk6NIXKReAo0pxCl0he1d1U/
H+1ZWhjd3Vr6bX/n/dbaztLC2uzM+sLc9urqgQRfvfvw+j1Q8I9vfwDrAOHN
1TVgyZfzi5tzC2uTLxafjb0YGB5/3D/U1tZdU9taXqEuKiKj0fG+3t5WDxyu
XnG5eSPWy40Eh6anpHApFJNS2WAyAX7729qf9fY97+ufGBpemJheeTEHJl+g
4K2XG292Xr3dff3z663t5bn1uZmV6RfTw2NPWvv4NKGbtcflL64Guwcr+cXg
8V/fvHq3/XJ/ffaH/YObMb1bmX29OL05NbI00jfe3WwQsRGRQRePHrp44sTH
//JvD67dxyOJoYEJ1y7bXr1s/xUA9oubX5y7duH8jQvnr509e+ncue9BPQaS
/fLLa999d+frr26dO3v1zOkrp05+f+LY9ydOfn7o8PGTp86cPHn6s88+O/v5
6a8uXjh++NPzn5+KCQ/hMukaidSgVJWpdUaFplytrzCqNAqBSiaQi/kCDoNO
zk2GJAKkrl767trVy8DdMGgcDovIysbnkdOJ2RhiRmpGGjwVHh0R5hXo7xwa
7BYe6gGWAN6QIOcD//rZeHk+cHS4/uD+1zdvnPv2woWDXPzy0tdfXfv+8s3r
N+7fvffw4cN7D+7funP75t079x89sHGyc/Jw8Qrw8Y8I9sM+DMmwi893TWH6
YXgheGH4QQSReVok1ZDGNJMFTTxph0LapRN36kUdekEjiW7C5ShSskTwPDGS
KScUG3KNloLqZprRkqkoRwp0UJYmsVAFoSmTqMpUpjKJqYRTRZBMRiQ+LzQ9
PzKHlphfCCvgIAs4qQweqkiMKyrGcGRIjgzBlaMA0bpSWoWJq1PQxJwMHhPN
KULSeBCKPL6wMrmoFctuxzFbCdxOUnE/Wzcsqh4yVA7qyvrk6i6uuJHCqMCQ
dAlp8nBGFZxZncKuQjCMqQUlKYxSjKgqW1lPa+lWm1uEyvIsenEMSeSbW+xD
LQkpMEWwaiCSVkLJEM08KaibkZieM7kNqEx1WJ4JT6vOKKhJp1ahKZWp9NpU
Zl0KvTaRZo7JLPFJkdrChFbJYquUYhsQuOxRHNM1usAlttAziRuKk0PStUk4
ZTxCGhLHdA7Jvw8SQbEOJj0Ky3YMJbp6IW380Y+C8fYR2S6wwgCCJC6vBFFY
kc42ZzMqM2ll+Fx9ao4Gml+aWFCRyKmBcC0Qcg01y5iVqc/IN5Lyddm4ohRY
dkQ8NohATiKRU9hcYplR1NVeNf60a2VmZO/g4KW1DxurbzfWXq+93F99+Wp9
4932zodXb37+8MMvH34G+eHNh/2tvY2V9ZcLKyvzoNwurUzNL4y9mH06MTnw
dLjzcafZUm8wqDhFrKwsQkJcgp9PmLM9CDTAhxAfScJgJExmlVZbX1bWXFnd
3dj0pL0DUAya89LUDOB3Znx6duLFxvLaq629/c3dt1uruytLYGeyPDkz+2y6
zdyShcr6/ZQa6zQ4vrmqYX128ce9HcDv642Fn16vvVtf2lua2VuY2p4dXx4d
HOtprVJJ8jCpVlcuX/vyq0P/9uevz33jZONx9dKDc2euXDh/64uzl8+e+Q7k
/LlL5z7/9tTJ8ydPALd+efjQKbAOHvn89LenT35z5uSlMycvnzp+6djxkyDH
T544fvz4sWPHTpw48fmZU4Die7du4tEYhViqU6jKS8qqS8vLtYaqEpNcwuGz
CwQcehGDRsnJyicR0akpnq4ugPoL5889sr4fFRkKhcWhMckZmRg0FpaThSUR
MWk4eBIkMjzU09/X0cfLzsfL1t/Xwc/H9iC+j7y9Hro433hk/e3dO+dvXvnu
5rWDyffeLUD07UfWD21tH9nb2957cPcaKOg3r96xumfvZn9g3uigCEhkYLpd
WLZzAtUHwQrCcsPw3HBcURiGHZYtg+UoEBR9BrOaJmwVibuUwm41r1PNa82l
VeBJqtS8YhRDQeBrDj7VNdXQymtyteVYkQbCkEVRQJQJVF0K3YATGfE8PZYq
guEpoUiiPzo7GJcbgc+JzKTEZZBjSfREGhdOF6bQBLACIYwlSxXKiHoDs7Jc
oFcxigW5Yh6Rw8Pk8yA0VTKrBsPvSC/qTGd1EPldFMljlry3SNcuKemWlnRL
5M0MVnk6SQHBicOwIqDUZE41kleDK6rEsExobgVBVp+n72TWdUlU1XlMBSxf
GkZWBgF4gXxZ1XGCJqSih1QxWtQ4r6iZEhd3kvKNcThZAFGLyCvDUipw5Aok
rRrJrEcx6lMOrrFcHZOm80kS2STyHgKEAcipMjsQSJFnHMM9juEBKwrCyOII
SgimOCpVFBSa/9Av62Zgzi2AcADxflCWbXCWizfWPjTDLYrkCS0IxIli8nRw
RgWuyJzNrcmRNDLYlblUHSFPhchVwSi6BFYFVNyAFDQIWdVslonBMtKzuDgI
ITwuJSAVE1FIx4n4eeV6QVeDabS3aX6kZ316ZG9xcnNmandh9u3q8ru1VYDw
wTWfwcrG5m/vfvj1w48/v/vxze5rAO/izMLs5NzMxOzC+DzIzLMX40+eD7Q/
bjc3VusMJSKpsqgIKFjNPvjEVJiXzc4k0PFIKiZFweWWq1Q1JSXlKk2FWtta
UzvyuHdycOR5/+Ds6MTi5OzU84kXY1PrS6sA3t31bQAv2I1szC+svgCtfqG1
uhkIys3aLT44vlSmnx+d2QHPXAXwrrzdWvlxf+3N+tL24ov95dnXL+fXwQv1
dzcaS/gUcqCz8/WL337yf/376SNnLp69dPLoxdMnvvv0k/Of/vnEoU9OHD/y
+dnTF0BOHj9z7MjJ40dPnTl17vzZr86f/ebzU1+dPPoleP7xwxcOf/LFp4c+
O3To0J9//wdWPv7440/+/PHJ4yesHlgTCZlKqUIj15rLzI3mxrrKuqaapmqT
3qhTlJeqSzUKiYBbLBZxWUx4UvLD+w+uX7vi7OQQnxANT4GkZ6CpNBIpJ41C
yQLJz88EjTo+PtTLy+HgmA3HO94+dt4+Nj6+tn7+B/H0vu/ofN3a5jvbRzcO
zi2yvfv7cR3Wzk62zi52Ti72Vo/uX79z9fKNS7etbzh62vmEe4YmBEQnh4Vk
ecTm+8OZYZiiaDwIOxLLDMUyw7NFiUQJNFuJoJVn8ZqZ4h6xsFfC7RZz2/Oo
1QSSBpGvxBRpibLSPL2JWllNM5gyFfpUtjQqhxeYyQ/KLo4hl6QClRRXZglL
0wG/6NxACN4DSvBOTg9ISvNHZIWAYPPDs1mJuUUQEjsulxsPniaSkfSl7HKT
UK9hq2Q0mZTMFuKJrDiyOuXgvalOYlFPFqeLJOgukHQxRW0MoZmmaOJo2rii
GnKeOhXLiwQtIl0SwTAheGasuC5DZEnnm9OEtRnqdlpZf1FZC6tIiyRyg7PF
gbSSCFZlTFFtIr8xRdqRruqnVE2Km5Y0FaM8di06TRGMFnln65DZOkROCYJs
QtBr0IUWBNUMzauIzS4Lxaq8oHybhCIrGN8mRewAkiSwTeS4xRQ6xxa6p/CD
01WJGWpIqiAopsDJJ/26T/oVn8yrgOKgnAchuQ6hua6hOR4RuX5xtCCMMDa/
NJXXkC5ry5G1kqUNVHFdgayOxa8syFfg0wUQkjyRU46UNRJkFpGhQ6uukxZI
sjPyUwkZEFI2nFeYVVsqa6nQPKkvH++on+tvXx/p258aeTc3vjM39Xte7M7P
7C3OvVpeerW68np1dWd5CYgYUAwQfrW9v7q4tvBicfbFwurcxtz44ouRmWe9
I42V9QqerJgtNMrVNdqSloqK7pqarpqqripTZ2VZe0VJi0EDnNtRW9deY2kw
VdQZTW21lv7WzqHOx4Ndj6dHxmdHp8aGn89Nzrzeev3Dqx9213bfbG28393+
6dXr1xu7mwvrDRX1sKgkHydfaCQMrK/OrLxa39pfX915ufR+b21vfWFvdXF/
benN+grI9uLs7PBAX2NDY1kZOS3D38Xr4qkLR/984sShs4c+PfvRH0/98Q8n
Pv73Q3/4148Of3r8i7Nfnj555ujhY8eOHAfL40dPAITPnjl/5uSFU8cvnDx2
/sinZz/+08lPPvnzH//4bx999NHhw4c/+eSTP/3poxPHTl67chOamFxYwDLq
ysr05QZtWVWZua66obayrt5sMpYoiyV8mZinVytMpSVyWTGzkBEaHPLIyvr+
/bsRkSHZpPS8/Kx0IgafjkwjoAG5OFwKGIrj4kL8/V2dnR88enQDIOzqdh/w
GxBo7x9g5+P7yMPrnqv7bQ/3ewdxe+DmbuXmZu3qDmLj4m5j72pl43Tf2umO
g+dD73DnCJgfFBuZkh4TT4uCM+NQRRAMJxHHjk/jxKWxo7GFYTkSaIYwNkMS
n6dHFdYQOS1kblehsJ/D7yRTqvB5enRReY7SXKitoOvKKKYKskKNEiuhdEEo
juYGzXOAM7yJKgj4QkVlDk+Dz2LHwjK8Q5PsgiCPIlKc47FeCTjvpAw/ZE4I
hhyKzg8CwVKCCQVhXHGmXE1TqgtVykKthiWTU9niNJaKIKrLKTCjKRY0pytb
1Esuas3nNpLFrSxlM1taRz84yVeFyBAlpAliiNK4XGWiyJIpbybJGrOAf0Fk
jSRFS56onkhXpebL4rMlYSR5CM0QyamDCFoQgjac/HFOyVNW3ZyqaUmn6SvI
UEbCmM4pXDfw64NOm1+GLKjCMC1Y0J/zKxKzDBEZ+mC0whPKt0/k2CTxHVJE
zqkCJzjPIZHjEstwiit0S+YG4uVxeHlMUpFfBNnGn3jTP+tqQPa1oNzbofnW
4VSnCKpnJNUnnh4JZUcBU5MPrrVFUHZnqTpzipvzpXU0eQNXVstjl5JJElSW
OIlRipI1EA0NqtI6BU9ZkEfDUGkEUVGeQcZtMqiGG81jTZbplobZjsal7taN
gZ7XY8MfZp7vzo7vzU3sz0/uz03/PwEUL83/tL31w/b2u63t/bVNMJxuvtzY
XtvZ29xfX9hZmHw5PjT1pH2gSl8pLOTRs8nMHLLFUNZtsTzr6pzs7Z3o7R7t
bhtsqe+xVHXXNwJ+AbkmpRqkptTUWGFuqqxpqWnobGjtb+8ZHXq2MrvyZvvN
z29/Bvmwu/fj/qufX797tb6zMb/WWNmAgqCjA2M0Yu3S5OIvr3/6y/sff337
7uc3+3/96e2H/c03W+uvN9f210FzWN6Yn515+rS/paWposqk0qESU29+e+P4
Z6ePHvoc8Pvnfz8J+P3oj5/+67/88eOPPvv89BeA3+NHj50A7B4GDB8Dm5+f
Pnv65NmTxz4/cfTskc/OfPzvxz77DDD7h3/ye/jw0UOfHfvq4ne21o4YJKGI
JTAAePXlOrXBWFJRbqwu1ZnkUp6yWKAsFillYo1CrlYppGIJh8X29/V78ODB
vXt3QkKCcAR0ZjYhLRMscSgUDA6PT0yMjIkJiYjwCwry8PS0d3K6b+9w28n5
HkDYw9PK08vay9sKxNvH2tfngbcvyEOw6enzyNPb1sPH7iD+9q5+tq5+jzxD
bUMS3RPQgSnECFROFISemMpKRnGSUSwImhUPECYAfpnhOZLETFEMsTiWYkgG
4mM3pXPaMrkdWazmbKaFyKwicityAb8GC8dQSdeUZskUqVxZXD43EE11geU7
An7BX2++CScqIdIlCCwlLBbjEgSzCU6yjUK5xKV5wbIDUvJCkKBUU0IReQEp
OX6IPH8UOTCPheDKSFIlTalh6g08uaaQLc9k6ggccya9BlPQiGG1pbHbiEXN
uaLWAlUXV95YCP7U+ZU5dN3Bu2rZEmi+MrlAh5TV54AA7XIqsJwKNNeM41Rh
6MaUdEFUhjAyqzgiXxfNqIZwG+H8VjS/Da/oo5Y+49XOqs3TCkkbCS8LhRQ6
Qpn2oEVQjMjCSgy7jsBtIoD+DPjNLInAqwMRUg8ozxHKdUjmuyKE7qkCN3iR
cwLbGfAbz3BP5vqjJREYUTiE4RGeaxWaczsk71YY+VYE7WFUoV00yz2W7RfP
CUniQ5KFcThlLLkSIuxAqvoJqm5ccXO6pJ4kszCKLVxxNYeuIeVIUYwSvKqF
Vtms0ZiENGZaNgkh5VPqjareGtNoU91id8dKT9dab/fq466XPe2rjzs2B7r2
Rvp2p5+/mh1/Mz/5GlA8MwY292bGX81NvlueBxTvLS7uvVwFyttZ21qZfwkq
9Ejf+ED7cKu5w6QuF7NE5Ix8LAyVFJVAwqYJCgrBnNvTWP/7tV77J/sfP+tq
H2jr6KprqC01GopVpTKlQa7WSxUKnkQlKtZKlbVlVcO9w8szyxtLG/sb+0DB
v7798Mub97++/fHd9qu9lzu9LY9Z+Uw6qXB8YOwv737775//A/D727v3v757
85cPbwG8b/e29jZXt9cObpgIOsPLFzPjT4aB4rvqWzViFS4lzcPJ76vz1z76
0/F//ZdDf/rj8X/y+9GfPgGq/eLs+bMA2ZOnjh45dOzo4VMnTp45dfrk8VMn
jp0+fuQ0cPTH/34EFOY//OEPf/zjHw8dOnLi+JkL57+xemgXGhJDITOLZdpy
Y01ZaXWJtgyQq9cY5VL17/yK1AqJRiHTqJUqhZJXxCXnUUJDw21tbe/evevh
5R4bHwVJioMmxyPQsFQEJD4hIiTU1y/A1Rc0Bh9HF7dHdg53rG1uWNuAwnz9
ke0Ne8c7Lu73Aa0+/nY+fvd9/B76+FkBI3v72Xr72nv7O3gGOPiGuHiHOPqG
2wfGOUXBPaGgwZJCMfnhyYVQwC+CBYMXxiOZ8XhuYpognsCPBRbLlESTlLH0
CniRBcWpQ9FrkgvMSQXVeG5DjqiBIjZTNRZWZbPQaGZI1XihAs4UR2UxfZBU
5ySqC5Ljn1Ycl6VHsOQ40JChaT5AvoHQR6EIx5g0z8Qsv1RKCJp+cFsuLCMC
SQ1OzvVLyvFJzvVFkiLzOChucY5MW6gv4xWXFHJUmeBPt6AcU1iHpTehqfUo
qgXNayIpO5j6br7AnCOoIhWZMgu0mHwZHIShw/BMGapGirQmi191UJ6LqrEF
hmSSJj5LFUsQRqWJIzPkUTklsQVmGLcZLexIE3VlK58wykal1dMa/SCfXo1F
CQMS6HZxNOscDZRcmsSsQguaMkTtRG4LlloNIxqi0IqAVIknjO8G47qm8j1R
Am8EzxvO8YhnO8YxHROYbnBeAIAXJQyGFnpE5j6MojyIod2LZTyMZ9smcl0T
+b4wUViyJAouS4YXx2O0kfnmKH5XnKI/sbgnQdwCFdahikwZvHKytIrDLaPT
NVm88tzSLm5Nq1ZTxivkpLNZmWZj8WBr7bPmurGmuvn21rXenlfDQ6+fDu0M
PAYIL3U1LXY1bY0OHBTpmTGQ11PP9ieevpoceTMzvjE2tDb6dG1y7NXy8oed
XUDTy/nl8ZGJ4a5nPY19tUYLECLgl0Nh56fl4JNRUragTKkF9Xiws2O0H0De
P9zd+bi5sa+5FZRnMCNrhFIhnVWQlUtEEdCQFBwcRcvONypLhx4PAX63Vrb2
N1693/vwZnNnb3Vr9+XmyvTSzLNp0JmZeQwJW7y7svOP//zH3//y3//54y//
+eNPv71/+5cP7wC/ayvzKwuzK/MzGyugSK/vrKwtT85NDY33tT7ub+trtXTI
RVpYAubeHYczp787cvj84UOn/vBvn3z26YFGL126/PXXX587d+7IkUMgJ0Az
Pnny+PHjR48eP3b0FFDtnz/6DPALOvPHH3965vQX31+6bvPIOToSlpVJlctK
TEaLpaatuqqh3GQ2lVXrtAapRKGQCflFDAaNzGIWyKRiUJ4LCxhoNBaJRHt7
+957cN/e0S4w2C8yOiw2IRIgnIpMSICEh4R5A3KdXa1t7e8+sLp6594lkFt3
vr15+5vbd78DjwCiXdys3D1t3D3vHsTjvrsX2Hzk7m0L4gqWfnbuAbZeYXYB
sY4RKS4Qgm8qKQC01lRWPIKdkMKMgzNikKA8S2BEeRJRAU2XxWTIo/O1iZxq
pNCC4VQlU/TROaowMKaxqtLFdWRFA1PfzDM28TWVNKEax1PCaaIIAsMzleqM
YHgSRGFZamiuDknhI3D5UdFIlwCIdRDcLprgkUgKSCIHIRmRBF4CSZoEpJnJ
i0fRQwC/iUSPWLwPoSCRKsRzlXkAXr46jyY/uKhsnjGFbkHRGlJzqhIpVXBh
M1HdRpc3UAu0aJrm4ILPOWJYliAxX5rMKSFIq3NV9VRxdZa4Nuv32pyRXwLN
VEWRdHH5pchMZSJGHIqTh+WVQzgtOElPjuwxTdHPNjwvLnsul7TTSCVJSIE/
FGBIt04Th2XJoylGKMeCEbSmFTVjKGZoljEaWewHF3sl8T2SuJ6pPF8E1x/J
8Utl+cQy7QG/BwdZCQKxkjC0IDiJ5RFLsQEvBWE9gvHskgTOMLFnkjQALo9E
qhNT1FCEJhZnDMlr8Of1BsgGA2S9/qK2EFFjIsOQBHZKAhNVVMXkmaiSGnpJ
J8/UWKw0ctj8LLGE2lJX+ryneayjaaqtaba9bb3v8atnT18/f7o93LfS17H0
uGWxr3VzuGdv9MnbqaH3L56+nx5+Ozn4ZnLw3fTI7tjQy5H+peEnG1NTb9fX
f9p782Zzb31p9cXwi+HO4ZaqlkpNZZW2or7MUmeqrdJXDPc8GR98OvN8fG7s
ILOjY+NDA0M9XX3N7S1VYPhW0rNyk6PifBxd7e5YWd+45+Xohk1ClxTrBnsG
1xfXf3z903/8+FeQ//3r3/7y46+gSINZeOnFclt9u1KsaqppXp1f++tPf/31
w89gHv/p7fu9jY3djdWXC7PTU2Mg8y+mV5cW9za29te21+dW58dmX4xMv3g+
N/1sfrhvrKaylUbhBQTEXLtmde7zbw9/dubM6S+vXb196+a9y5evXrhw4f/D
73EwDx89evTYsWOgLQNsP/30EAD57OcXbt287+HuD0lAgpfSqitrqtuaG3vb
W/ubGjstdc3mmnqD0aRQqrUauVTCL+Iw+Lwi4F+TsUyl0hQV8QoKCqNj4mzs
bB2c7EPCghOhcdCUxGQkDAILT4CERsX4+we6OLkcHEZ19/73AN4bt769fvOb
aze+vnn7u3sPrlo9uvnI9ra1zS1bu+t29rcAzvaO9x2drB1dbJ1c7Rzdbe3d
rZ19HrkH2x7wC3eDELyRuUFYWiieF4PjxyCLIlM44UjgJgUkQwNNUyXiiqPT
FdHkUpigFiurIxQZk8iycGKRH0kByVfBge80TeySFr68qkCgz+Lp8IVyaDYv
CEVzSaY4oljemZLIHCU0V4MgsZKQ2aFRCNeQZIdIjCskJzCVHg7gTRcl5qkQ
DGMaqyw9X5GCYUUkZntG4h0j8O4oWjSJn0qXENgKIk2CzRbCcpRJuUYYuTYp
zwzJLIumViZJm4jFdVlsPSanGJolScjkx6VxYjK5cRQZQlBKVJqpxTX50uoc
RROl9DFD3poDACTpYwoqk8hlOJwsHlrknyoKzjElFbUThd1kfgdV8pitHZJo
BsVFjXmZmkSk0BeU4eQiOyTbGysIyFSGU0yQwlp4QW0SyRSbpgtLlfomi7yg
XA8I2yOJ7Z3M8oEzfOF0v1imLajQyTwvtCj4d36DAL8JBfYwlh2cb58qdk6V
ucFlPinyYIQqBq2HJesSEYbI9JpASrsnd8BF8tRROuAo6fKQtkewK2ILdHCO
MVtspv9+8BtdVl8gKaMzi7OzCxAFLEK5UdzdWDnSVj/b27nU+3hzaHDv+dPd
Z0NrQ30rg91rz3t3pobWB9q3hrv2R3vfTQx8ABRPPXkz1g82d5/3bjztWx0Z
2JqaAC16a35xbmxy9MnTxrKGCmW5mqdS8uTlqrKuuo7xgdHFifnJ4dHp0cnZ
iRfzUy8OjmReebm2vLI8Pzc58BQgbJSrSRiCn5Pbja8vXzr31bWLlzzs3FAQ
hFIg72zqXJhafLf7/ue3v3zY/2FvfW9tYW11fnV2fPbZk+fmshq1VDPQPfhy
bvXX97/+9PaHX97/BPjdevlybXFx4cXkwuLM8tLcwc0jtrbf7u6/3t7fXQEI
r20v7eyuvtlc2pseXehoGVApTDhcrr9/9KXv7p058+35899fv37/xs17l76/
dv7LC0ePHzly7PDxk0dOnDr6z3WwPHz0CPD0px8fPnn8zNUrtzw9ApJhWCqZ
q1FVNtT1dLYP9/Q8e/x4pKOjv6m5w1LXYCqv1Op1FeWlVZXGygqj0VBSqi8x
GAxGo8lgKBMIRMnwVCcXZ0dnp6Dw4DhobDwsNg4aExntGxsfGJcQFB4J/OwA
EHZwuufofB8we+fe5Tt3r967f/2h1a0HD2+C9Rs3L90Fj9y7dv/BrYdWd61t
rMAOwcbB3tbJzhaA7GXrEewUEOcaleqVlBGAoYRlsKIzxaHp4hC8MAQlDELL
wgjABZpYpDwCXRxFUMVRDaliS7rcksnXp5K54ZkUH6IgmiiILVChpIARM52l
zaQWoxkadJYgEsv0TiI7gCCZXgRBaLooOk0Ql5YfA88IikF5xGA8oMD4jJg0
fmK66OB6jPSytKIqIqs8PUeenFoQHJnmHIx8FEX0RLNiScLUfDGaKsNl8+E4
TjRBEpVVGp9dEUcsj8goDaGWJwgtOF4ZiiKOI8kSMoSxBE5EOic6RwRlKrEi
Y05xZb6sIk9SlaNppgF+FW05BeXJuaVxlEoIVgZJ5kUkcoIw8miaBQvg5Xbk
F9RnCztZkh6etIvLsuT8k99UnitK5IIuAvz6ZciCcnRReaa4nN/hRcn9D+Dl
eyaw3eMK3RKoHhCKF4TiAyX7xLHsIFyXVKEvRhyCFYUCLycdPMEGXuSIEDmh
i91RCs9Uud/BuYGaWGwpLEEdnloWktHgS+1xLhq0EgzdEj25Le6xFrZ68moj
iipTeBVESQ0NzMKiGiq/KpehycrmohDZMYRcqERKqylXdNeVT/S0Lg32bz57
ujfxfGt8BIh1eeTxxtTA7sLzjSdtIDuDba+fdX+Y6P8w/nj/aedmf/NaX8vq
k45VYOqRwbmhoeHO7pZqS1WJSStUCWhcJonOJbNVfAXw78TA6P7q7qvNV4Cd
vc3d7bWtnfXt7c2dtZerC3PzK5Mz4/1DQMFiBgcRC/Nz9vR2cAvx9E+OgeGS
MWwyExA6OjgG8NxY2lxf3Nhc3lyZXQEIL8+sTD9/AfxbX9WwtbIN6P7H//zj
b3/5r3/899//8T9//+2HH356+/bNzs7W9hpYvNrfffPq9VtQErbfvNp8/Xr9
zf76mx/2f329/cP06FJTXQ/gNz+fA4enXb9m+8W5K+fOff/ttze//vrq+Qtf
n/viwolTJwGwAN6Tp48dPX4I5NiJA5A/O/wpmIK//OIbextXYF4Ar1JuqjV3
dHU8fdwz2t8/3t8/2tn5pKGxtdpcaygzanRqhVys16lKSzRKRbGAx2ez2Uwm
u7CQmZdPiY1LAPAChAPDgqITomISo6PiIxKgQdDkUBg8LAESEhHlExAEpmAn
Hz9nMAU7OFrZ2t3/PQ+trO/eun31ytVvv7/07eXLl65du3bz5u07dx8+eGjz
4JEdeJ61g52tu50rGISjXcKSPCAEPzQ5PIMZS+C54QXuWKEnWuyDVQUTSqPR
+ii4IixVHo4H/JahpHUkdW2eSIulMqOJJH8sIyijKIoMxkw1oUBJyBUjswRJ
mcIEJMMfXuCWRHNKKXRFs30wnABEYQAs3y8lLRiC843HekMz/FEFkRnCpBwF
IleDLDASCox4SgkmW56EZIfH53hFEJxCsfZx+b4EQWKeAk1T4KlyHJEPQ7HC
Qd1N10YSSkLxJQHp+oB8QxSzDMYEk6kwKlcOyRTFZPCiScJEhhLF02cc9AFt
prQ8V1xJktXmgP4sbsiglSena8JwikC4IDaZH4WWJZDKkezWHGEPjdNGoVly
eB2sohYmt4kO+M3SQVN4XoA4rNQtXRKQIQ0kykNIugiSIZpYGolVBaVIvGEC
j0Sue2yhWxTFOTrXOTbHPT7HIyHXO4HjAIZihMgPKwkF8oWzfSA05ziydQrX
CSVxwSo80Uqv/5dfjAEWVeyXXOqb3uBJ6bFhDtxgP/mG1/cdv+cWu95WUB8q
siBFNUSphVrcwJBYqNwKErM0N1uETs2NIZCTxDJKuVHaXF0y1Fo309e99mz4
1czE/uzE+sTw0mjf8kTf2ovBA377mgCw+8Nt78d63o12bz9pWu6sffm4aaGr
frK1brChtstsbq2sbCivBnls6ajVVh6c2C7RmhSGf/L7buvN/sb+663Xr35H
eGdrF/D7cnn1xYvZpfHp6aFng+3d9WWVUiY/F0/MQqdRMnLIGXmAXxIuy6A2
As8CBYOGvLO6C15nY2kDjMOA6Kln06A515Zbtl/u/PTmp7/99rcfXr8H7fp/
//pfv7z///G7v7ezu72zu7EDWjeYo19vgtH4h9ebH9YWdyaeLw71T7Y290sk
eiw25/pN+8/PXT15+tvPv/ju5JkvT5w5d/rcFyc/P3P4xJHjZ479/mnw4cMn
Dh09deTIyaOfHv3s81Pnb1y9FxwQCWZeRbERwNvd8XzoyUzv47EnTyb6+p63
t/dZ6pqAfDUlerlGIRRwJGK+VCKQiIVioYjHE9Bo9MzMrPgEiJe37yMbOxc3
1/CYiCQEDIFNReERWEIiGhePQMckpYAiHQJ0HBTi7hfgGhDk7u3j4uZu7+xi
5+hkY2P78Pad61eufnfhwsWLF7/+5uvvwTB+7dq9W7esbt+zufvA5r6NjZWT
rYOXvVuwvX+scxTSE54djKNFpdAfpLKsEVx7hMQVrw1KK4/GlcWkaiKT5WFY
dQLNBMozWVtLkQBaC+NIWUFIsg+JH0uTpZAEyRlFsAx+choXgmCEJtG8kulu
KQw3TJE3juuPYvnBcj2i05wTkN6xSK8EnE9yTgiBlZhTjKTqcDQDnmLAgek4
XQqBM0Pjcr0iM1yiM1zjsz0TaP4ZMliBDs/QZzC0aUQRDMkORYtCcMpgjNYf
q/NL0/lna0Mpqki6IpYujs1TgP4cByoBWZbM1RNEpSSOKo0mRsoqyAITkWfK
4JvTeDU40H7RMv8EliNKCsErk7KM6AJLZlF7Hr+LVtROZTZRuG1sZj2dVUcD
/GbrYUkcdyjTFvBL1tvlap1IGg+iOjC7JDazJCFZ5h/GtoniW8UI7sTzb8cy
b0VT7kRnW0VnOsZluMeRvVI5oRnF8VnFCTheaHKBd2K+W2K+C5oTgOYGYvmh
OFEEXh6TpkzAFsemiMLjpQEoQzipPorWFcLo9WL3OzEeW1Ha7rG67RjtroWt
3szWsMKm6IL6eEYjlNuO5FYjaLpEmhLK1+HVxnyjkd1oVg601j5vb57p710d
Hd2entyYnliZer489XR5euTHqf7N/sbF9qq1HsvuYAsI2FzvbQT+neuwPGuo
GKgpH2wwj3W2zwz2Lz179qJvYqpvfKDpcb2xtqHcMtw9uDq7tL26ub95cMvg
N5s777Zfvd969WZ1Z3t+dWNqeRHMpsNTT7uGOi3ttaVmvUQrZgiLyOxcHCkN
jkclIHKw2WUKw9TgxM7iFsjm/Muf9t592H67t7I9PTQJnq/gKsb6xt5tvPlp
94e/vP3lr+9Bfvpp/9XmwvzMs5Gnj/unR0ZXZxc2F1fW51dWF1Z2Vnfe7rwD
Ft7bePNyfmPy2dzI0FR/z2h1ebOQq0pNwNvcdT515Oypo2fOnvkczLxHT3x2
+vzxQyc+Pn7m6LEzJz49duSjz45+cuTU0eNfHj/59YWLN7x9o7JyWeJiQ3l1
axvozINTHX3PHz8Z7RsYGRgc7u3tbWyorSjT/x+e3juqrTRP1525M90zPV3V
1bGqOld3tSs7JwyYYHISCOWchRKSEMpISEJZCIEkkAQKSIDIOeeckw3GYJyz
XanTzNwz6677x/3oOud6vf7W1rYMXrYfPe9va2/tpqC3PVLf1tLY6PfVOR3O
KkBxdbXDXq4u43JYBQUQ0HjPnf88OTUOjs6mFaE5fAKTg6FSkWQynECA4nD5
GEweCBZbAFJYmAmBpGdlJaekxF2/fvnKZTCtf/r5Z6c+/OMHpz7808enPvr4
1Ccf/enTzz45ff7spcuXrp0HT4m7ei3tWkL+9XRsch4zEyXKxykQeEM6yZxF
qcyhOvNYDTBBM07Yguc2ooCFJRGqprXYOaD1D9usQblYTy8pp/JN2QJzjtAC
EZggfCOUqytgawqY6nyODgEGVZASC15kJbC1hcjixFza5RxpQp40GyZH4fUo
ngeibEsq77ymCKeJarBsLZ0mw9EU2YzyeEZZHEOazSjFyMycmrDeGtDKHCWq
OkmZt4RfReHXEIRujCJIktXjpXX48gZ2hb/UEFA5msyVnhpDTYWmWqyv52oC
eL7jRrEzVteebxvEqltgjmF27YRY6sOxbdBiB4KqzeY6qYpwib6zrKJbZR7Q
O6eqqketho5ya4fW0qKqjmpcEa3OxuWXwJUKQp1Tqm64rvanKP25J/5tJIuD
FKYLhjQmIs0xWNslUtVlkvUqQXcVo4gF/GJLUvCaDLYNJvUSlfVkkRNdZMgG
8OIViVRNGl2fyTDnsO2FXOfJ/dEYdhjJAqHUFgpbsJoRkmkGbZ7JMc4kVUxc
1Q5frhiN1Q0m6vozjYMI0yBB30us6CYbeun2dq4xRLeF2MHO8t5h18hQw/RQ
0+p431xPx3J/3/b42J2lhePNlePt5dsb8zdXpkBbfjDdczTWfn+y6/Fs36OZ
3ofTPY9m++5O9RxO9t6ZHLg9PXx7duLgH7cvOVhZ3JvburNya39xZ2V8YWVy
cX9jF1Dz8Oj+yeD58OmTowcPbgPvHj68dfxo796TW/cO1vcBhquTy4DfNn+0
1uIyyCsAs3wqj1iIh9zIReUgdBINmKMBvH9/9dcXx4+/ffbm9YMXTw8f7a/e
AmiDf7/h9uEXd599+/Trv736M6D7z89ff/v8xdOjw/31tVtrm3e2b97bO7i3
d3j35sHhrQPQvYHHH9998vj4+d39B2D+3dm8s7NxND+92ds5XlsZICIZH//+
i5/96Bc/+8nPfwZ+/uLH7/7yhOK3fvLDH/3snZ+++947P33vB2/94u13fv3e
Lz/KhxJFYp3b29zcOtIztDA5vw34HZ5aGZ9eGZmcHxqb7Ovra4o01rmqaiqN
riqzxaADMVVojDqtQa/TacvFolIGnZqSknwaAPjFR4k3ruUXZmAIECwxH4pI
xeML/v8AbNFoCBKZC4dno1D5CEQeDJaTD8nKzLiRcD3m4oXTX3z+0ScfnwLw
fvSnU6c+/OjUhydV+ovPz509d+nClasX46/GpMbE5cYmIuPTScl5rDSoIAel
ScYZ00n2HJoLwvbDAbwlbXiwFjdiZS0n7xY5BzQNw2ZLUCo10mUGJuCXZ8jm
6XOKDRC2NpeiyCBKMkjSbICtooZe5mLJnHSRnUSUZxVw4hCCpDx5ElSeiyzD
UExYoQ9aFk2URS4K3HFUTRZJiiGL0VR5Fk1xjSqPLZLnFpdRNNUiW1Bj9KlU
bqk+oCrzlHJtZG4VttSDV0do5WGaLlxka5XYo+rKZn1te5Uz6DbXGdQ1IqWL
KnZCBdUpYl9yeTTX2IOq6EBb++iGDnqpFyVvIJaH6YIalMhXVN5SauwpM/Wq
bMMVNZO2ykF9eYvE1KaytJTZm8oq/VK1mSFRYo2momCgXFOfpA1k6oIwTZCg
DrNkITbHRcCashAV17GW62T7dWplItmYSFAlYaUpWDGwdmaxE64MkMG3k3tx
XBuEoknBKxNQ0liMPB5ffgM8gWLOJZqy0bo0uDqZ7kHJO2mVczznCs02X2CY
TNKPXdMNXdH0x6o6r6s7Mgx9SHM/xdRNqWijaKMkS4Slb6DbQ/yWPuP4tH9+
Kro42r4y3D3bFZ3rbFvq7dqZHL27Nn9/Z/n26szW3BCoygfDbfuDzYcjrXfH
2o/HgYg7QYUGRj6a7D6eGbw3N3o4N7Y/+93tTsb3F7aO1/fvb9++s37zYOMm
QBUAC6gB4ru7f3hne+/W6u7N5e3bqzfv7Rw93XsA+N2YWRvrGonWN3tstVW6
Slu5BURAKy4tKikXqYCOO0Pt88NAaasA8yd37j89fHB35w4Q987CVqO7UVOq
qdRU3lq+9fTO468ev35578mr+4///OLlm0cP7+7uPDw4+ZDqo929vfWd7aX1
9YX1zaXNndXdve3bB7t3b+8c39o8vH3z4f2jl8d3nu/t3F+Z2KmzB7GFlNMf
n3//Z7/88Y9OTsD6xclhqx+99aMf/ujH7/z0Z++9/fYv3nrr/Y8/upSdhbFX
hyItQ4Mjy8OT62MzW9PLexMLu31ji32j8519I82tXaHGk0/LMZsqdOUKrVpa
KuDJxSVKaalCIhaXlvB5xRQSGQ6Hx8fHgvYL+E1KiYXCs/DkQiIVhsLlwpE5
UFhmXn7qd50ZBs/FYAuJJBQaA8Vg4Tg8EgSFhkHys1NSE+Pir549e/rzzz/9
+OOPT536+KNTn336yenPPj/7+RfnLsXGXEmMjc2Mu15wPRmdkEZOzmalQvgZ
MM0NnDmTUg2h1RUU+WHFzegTfltxJVFCWSfT0M2vGVDVDehMfpHCSldXsqQO
OICXrc3mVECoykw4Lx7KikWVpIKiq/bwdH6+2scV2AhwYVIe+xqpLKewLBmm
zEOr0FQLpqS+UNGcLKw/S7ecR4jiUXwooQRBkWVRZfE0WXxxOVxuKq5wSTQu
cblLammscLRZAb9FJjzHjlUGaRWtbEMr29oucPWqq9u1lrAW+Lc66DB7dOUu
gciG5lgypb4cTbRAEcnRdCDAf3tjD10RwakiRGtPsbWbpwjg1U38irZSQ5fU
1KuoGtFWj1Xou2QSP6uiRWSJyswRsdbFUpqIFTaG1y/v7LLq6tNMwXxLhGBu
ZhubROWNYmEdm2pDYyqy8aYMii2Tak2nmtJpFRngFYmizmVVQ0rqEMoQsTxC
kTVg+Y58mj6VoE6Aia5AS68USmMQZQlwVUKBMi5PGpsjiy2qxWh6OZ41uX9b
WLOMtkylGUav64euq7tjlS0JZU0ZFe0ISzfV2sE0gJfTCNUeLrb6uc6QqKXT
NDzsmxmLLA63rQ51n9wmu6ttubt9fah3b3bszvLk/uLI1kz/7kDzVldorc23
2dFwqy90PBJ9Mt39fK4PUHx/qhsgvD/auTvUvjnYvjXcvTvWd7Cwdndt5+E2
QHjv/s3bj24fPbh9Ir797Vsge2s3txc3AbAb06vbcxt7C7ubs+uLo/MjHUPt
gdZIXSNIa0MLKNJAx93hzgaHD/Drs3v6mnvA77q3e/evL7/9y4tv3jx8+fr+
y0f7D4B57Vq7QW4YiA4AnB/dvn/v5h3wTb9++uzNo8eAX0Du7U1A7ura7NLS
zMLi1CLIwvTSytzG5vIuKM9AvoDfB3dfPXnw1aN7b+5sP16dudXU0FFcVBp/
NeEPv/ng3Z//4l2g4pMzKU8uUPjROz9/++33Tp06TyLy62pbegfmJ6a3phf3
x2d3R2d2JuZvjcxsdg3Nt/ZOhKI9vmCzpyHorvVUVlpNRp1Br1HJJZoyuVol
L1PK5TKJSFjCoNHRaHR6euoFUJ8vnknNSIIhc8h0JLuYVMTFs3k0BotEpKDR
uEIYMg8Kz4HCwZoHRxUgUIVINAyDQ4Ig0QgorCAXknMtLubSlYtnzgFmz5w+
A77iZZDT5y9diIu5nBQTkxkXD01IxiSm01LzijMLSnPghnRCVT7di6DXw+gB
GCuM4LagQKSd5PKeIn1PcWWv2NEp03hYUgtRU83SNVBKbFCWLpulzcWLb2RQ
zmdQLiAEN0RVZEOjyNwildcxaNqCAn58XnEcSZuDUCfD5ZlwWT5eW1DsypU1
JpZ4LzDMF5El8SheHrY4nyzKpEkTmfJUYTm2zFwiNrOFRqbaKanrrvH0OZV1
IpaZKHCSdC08UztPH2WbW4urOhTGkFReIywDtblOo/codV6huBorrM6taMOa
ewnChnRDD9E2zNL30DRtFPsw3zUpNnUxZAGkoa1Y18Ipb2FXdAhtA3LroFwV
5Qo8pPLmYlObSB8sltoJCiu+xi9s7zMOjjmMvqzKRpQzyqxpK7VHy0yRcoVP
yqvhkI0YogFKMOSQTVlMMO/bC05m2yp4cR1E4C0QNcDE9XChO59tz6QYbuA1
1+Gyq/mlFyGiS/nSq3mSK1mll7IkVyDKOJYbp+0u9q4oQ9sizwrJPg0xj6aa
BpM17QnKxiRFILOiCWVrY9ha2bZmDki4Rxfu0rV0Grq67UN9numBxrWxzr2Z
4Y3B7o3+7tWe9pXu6Gp/dG24dWOsY2uyc7svstzinWyonPbb19s8x6PNT2Y6
n810vVzsezbbe3+y42A4utPftNnbtNXXsj3QujM1dWdp6f7W9pP9/WeHd58e
3QX8Hu7sA/MCeLcWNpcnl+aG5mb6pmf7Z+YG5ueGZpbHFwHFW3MbQK+zg9OA
XIDzdP8kcC7YA/aD4RdU5fs3j58fnbx7++jgwaODhw9vP7i1utfd1GNQmIWM
0oi3aXly5cH+/ft7x8D4J2d1HoHxfW1jfml9bhHAu7awsrWysbu2e3P91s76
zeXZ9Y2lne2Ng5tbx4DfuwfP7h0CBb/Y33x8vPdqb/NeX8eYRqEvyIN/8dnZ
937x/jvv/OTdX/zqvXd/8+67v/viixgigVtX2zo6stY7sDg4vj40sdEzvArS
N77RM7rS2jfb2DHii3TW+pvrQ03+xiZ/IOQ7+eFxuxzOGru90my1mECMeoNM
JmOz2ZmZmSfX58ZczMxJBZziKAgam0BlYSlMEoNDOzmQJeJyhWwml0GiE3Fk
LAqPhGMQUGRhAQJaAIeB5MMKIYXQlMzUhJTEa9dPjjlfu54Qm5Accz3p6vXr
F65fu5QccyUz9ho0LgF9PYV6I5uXkS/OgZmz8DUF1Hok3Y+ih+BFEQS7Gclp
hku7yWU9dE0nQ9fONjSzJDU4gRGurCJZm9jSaiTgl6rOhPHjkvGfppDOIEqS
uRa0JSoxtYqLzAiYNKmgNA4mTcCqUxCK+AJRYm5xUqEoiWJMLKmLK/XEFNsT
8JIEJCcDzkjDcpMppclMaQZbBi9W0ChSFLMMr/OVBUfr63prZK6SYjtN7mPr
WwS6JrY6QNEEi4yREoWLw6kg87R0hUNQ4RMZG4Xlfoo2TKjsp+k6cSx3Ss0U
zzrE1nRQTP0s74KsdqZE301UNsM1EYasniD24coidGOPABQMeZjO92AB0YYo
X91AF1eiNE5SsEvZN17ZO2K1eLJqwpi6NnZdm6Q6Wm5r1muDGrlXzrQwiHo0
VpNLNOTwamBgMFcGCWV+fLE3h1uXxXFncGoyWFUZDGsKqSIBVx6PUcUWSq/k
Sy9DFbEFythcRQxUk4CzZgq8VF1HsXOqtG6B55olVE1CrcOZxt5UdXOSMpCm
8uebIsSqKNcZFbqjpbWt0v5R1+Coe2TUOzroHenxzfSE1obab00M7Az07Ax2
bfV3rHRG5tr88x3+tcHI7kT7Zk/jfHPdSJ1ppNa4HK45HGh8OB69DyiebAMb
x8NNdwYie/2NW12BlahvIVI7Bww+MgBm4Se3br08Orkc+GBjZ3NhdXN+fWli
caJvcrB9aKhtZLxzYqZvFvAL4AWE7q3cBIQCigGzoEsPtQ0MRPv6W3pBepu6
gYjBOtU3ARR8f+/e4zuPXt5/8eLey8Pto6n+WV+VX1WiafV3bMxtvn746uun
X755/OLN42dPju7tb2zubd38Lge7+4c3D49uHd25dXRw83BnbQ+Yd2/3+ODW
ozt7jw/2n+zfenRr98Hu1pNbO0/2dh9vrh8ODcwaDfbMjLxf/fL3b7/105/9
9P333//g008vI9EMuyMYbR2PNI2Gmkeb26ei3bPNndPN3TOtffMt/fORnpn6
6JAn3F0XavM3dUZaOyPR9nBLtKk52hqNhBv9dbU19kqr2WgqLy8vLhbg8cSr
12JOnz1z9dqVfGguhoiiFBGYPCpAGEvBfhccFUcCLHOLuCXFfLGQI+QxuGwi
nYom4hE4XCEa/d08nAfPy4HmZUJy03Oz03JyUjJzEjOyrqenxabfiM1Ois1P
ioMnJOCT0opSIaJcuBJaYMpEVReQvEhKEMWIoDhtWG47mhNFiDrQ4jasKIyS
BrGgdvIrT5xbaoNXhCil1YVF+kxiWXI+79IN0scZjLNIcQLTXKBv5YMJEV2W
nCW4AFPGocoTYapYmCQmX3gtmxMDKb6EU13lVl0rrb1eWp1KlFyHsZKh1ATA
L0OSyZTkkovzCUwoSpDHUBNszcbQWL0tapLUCKR1PHWQX97IUfmp0jo8QAzw
K3eyizQEloosq2IaQiWGcLG+iVk1wLX1M6SN0GJfVnBDZRosKmslgtU9J3LP
8qwjRE1XodBRyDLnsCshiiDJ0MXTdXBljZSSelx5S5EmXCSrxYurkJYAu3mo
omPEGGyVmWoznCG0t43laSt1taiqmvTmsF4T0HJtXKIWhyrLIxkgYh9W304z
ddP0bQRBQzbXk8FypjCrT06KZthSKYYk4F+c9jpSGYtUx+ONKQRzGsaUQq7O
KQ6gy8I8bSvX2FNk7CNYBhC24QLLQJaxK1MRSFLVZ+kD6OpmVl2ryBdVNETL
gu3awQH36Ej9zFjj7GhkbjAy2x2abQ/OtQRXO5rXu5rXOpuW2gJzzd65aO1q
t39nOLzeFVyMnvh3tM4wH7TtdngPev373d67ff69Ls9Om2unvQ7s3GyrXQhW
jXmMU23h+Z7W7Ymhu6uLAIbDzc3thZXlqfn50dmxnlGgy44Q4LG3v3l4oHm4
LzII/Av688rEEliBc4F8QSZ6xoCIJ3vHgYgBuWA0DteGwBQM0AYGv7mye7Rz
F2R74eb0wFzI3awq0TVUB2cG558ePfvzi2+/ff71189ef/fZtg+P/nfuH9w/
3j8+3Lt7wu/u3Tv792/fug/Me7j/5PDg6Z3bT/duPtzdvre1/XRu/mBicnt6
dmd0ZKm62l9YiP/ww9NvvfXuO+/88v1ffXThUjKRIjTb/LX13TV1Hb5gP0C4
qWOquXMm0jEd7poBaeyc9jYP1YZ76xo7Gpq7AcK+YMTjD3n9IX+Dp95XW1Nd
pa/QSqVSFosDum9aeuaVq9dOnzkXGx8HlIqn4OhsKnAuW8AQyEtZJTw8gwzD
owowcDgBjaNTyGymQC4plkq4YvCrQnoxj8hkIYlkKAZXiIeDZ/7jychsWGEa
JO9GTnZiVmYiJCuxIP06/EYCNiWVlporzEWp4WQzrsCWh3RC8V4E4JfZguF2
4gC/rGZoUSSvKJDLcGdyanNLPFC2NZOqTeVZ8iS1BaCmsi1p5PIEuPhyXvGZ
AtFlrCqRXZWvDJG5Lmie+HyW6AtEeQy6IhahuYqSxaCkcUhJPFoaS9HGAvNK
XDfE1ZlEaTyGl4jnpbEU+WI9FpRnOh+GoebhpdCSSlZtT5VvqFbtU0idQm1A
enIZbD1D5iFIXFhtsKgyKlHVcYs0uCIVQVpDMYaLFR68KoBzjQuAZAUNORW9
lOCW1jjE0fYyLGPsqkl23RK3ZoYsaUrByuNRkmtUXZoyQLL1lug7ePIwVRKk
qJtZsgaysBoJmoYzKoqOGYGCTS6q0ZlWHYB7ovTaKL+mWWJvUlkjOkNIV2zj
kjRYhCKHYoYowgT7IKNqmGLqRYqCefz6LG5tOlBwsTubU53FsKSSKpLw2iS0
Kh5XAbjOY7kKGK58nh+laKcbWksrolxVBK8IQ8vbcky9eeaebH1rpsSTqPLk
WoNEb1QYalOFWsrDLbrWNnN/p2u837841rw+1bk10QWq8njY0+eyTfjdU0H3
dKh2OuSeCjlmwo6FFtdyR+1Ke8NaW8NCxDXVYJ31W9aaqrdbndvN1Ue9vput
NWsh20qjbaO5ZqPFuRSyT/mM64Ntq4NtG2M9e/MTh2vLd9bWbi2v7iyur06v
TA/ODLQOd0f6OoO9zZ42j6Xepqpq80eBagGtAGHgYuBfsP0dvABkAOxw+yDw
73enYoKde2v7tzcO7u89eLD3+M7mve2FvYHWUZumWi2qCNc1b87tAISBnV/e
f/760fMvn7w82rtzd/8QkHt37+7h3tHR/vHxwf17R0/uHT27s/9wf/fkI38O
D54Bfk/8u/NodefJ8NRuW/dctGsqGO4rU9tyIbgvzsT+8O1f/ujHv/3lbz89
d/FGVj6JwSuvsAY8oYH60EA4Ot7aM9/Wu9DcNQvIBQl2Tnn+wa+7scsT7nT5
W2xOr9nuslQ5tZoyo0FrNOpVKqVAIKBQaIUwVEZmbmZWXlx8QsKNFNCBQTHG
ENEUJpnCIhOLqFQuky0q5svEJUqZUCEFGzyJGDBbJBTwxFKBTMGXyosEJQRG
EYJAQpLRGBoOSyMiSfg8JCIVkpeUnZWQnR6XnRKTmxQDTYhDJSRTUyAiCFaP
YTioiOpCTB2K0IAiB1FFUSzglxVFUINZpPo0ojsZWxlLqbrBdecybGlkbSLL
ksGtSubXpBZXp9DM1zHqy6iyy1jNNZIhke/OE/qgRNP1bPFnebLPkboLqIoL
GMMlQlkcVZvE0KcwjTd4ttRSZ5bMlSOtziPL4ymSJI4qt8xONtYWqytZXDme
xC5gVmBVPlH9sNPVYxdXC0F/NjWp1A18pYcB5Ch1Y4xhdk2XvNzHZWrQFAUK
4KYLMYsr84S1EPcEX9uBBQb0LUt8awrzCMc+Kaie5VsnaPXrPOcCker6Ipd1
Jod1hqi+oQ4xHAMyU3eJsokpCzFUTWxRHYFrRchcpNpORcuoyRkRSSrgwL/2
ANTVTHCEqVZ/kSUkrG7XeQccZfUSig5NM8JKQXNuwpj6sVUTWE1XlqoNJY0U
ioNQRSNSHkSV1BYyrVkUfTpJl0rQpRCN6UxHvrABLY9StX1s04gADN3ljUxR
HbTEk1nRUeCcwNj68mW+61zLFaE5WefGBKLS7gFrb6+9q93a0WLuCFQOt3lm
exsXwdA61rE/2b/e0zLW4Oqq0g86LbMh93q7fyXqmWiwDNfpxuuNQ27TbMi5
0V6/3e5bjVQvBqxLDaaVgGnZb9xpcWw12afdmkG7bMylmfYaJuv0i92hsUjt
ykDrzemRuZ6OqZ7u7fnFvdXtg83bK1Oro10TPU2DYXdLdYXbpnZU61wtviYg
VsAmCGjLgNbRzuHv1u9EDBQM+AXPAQ9Bfz7cPT7ee/T8/puXD795dPjy3t6z
m6tHkwOLLmtDNNg9O7p0sH30/MGL109eP3/w/MHhPZDjg3t3bwNs7z04evT4
3tPHD16CPHn45sWTPz9/+ucnj755/PBrsD64//XR4avNO69nV48Hp7Y7+her
66JUhjgmNuvDUxfefuc33/u3d9//9WeXY7KyIBSuyGCsCusrQ/7QQLR9qmdw
ZXBie2Biu2f8JL1T251j6819c/62kYaWfn9Ljzfc5m4I13iDTleVo9pmsZgM
BoNeb5TKFHAE5vyFK3HxSVAEmisQlcrkRcVcLBmPJmLxNDzAEEsjE5g0PIMK
zEssogNsBXIAsrxYIgP8ghUgXCyRs4SlNC4fxySiaTgkBYem4NE0EpxIyEHA
k/OyLqcnXMqMv5QXexURl0S5kSvKQWmRJAs+35oLrYSgXAXkAJIdxfE6cNxW
OKs5nxHIxNbEw8yXkcarOGMcwZhANd9gVWWLfCkgNNtVrO4c2RxDtcZSzLFF
VUlsVyrZGoepuITWXcDoz2P0Z7Gm80TbZWDqYnumtBYiduXy7elyd4HKgyix
ZRVpE0vMWcYGqq9DBQpUuZ3LLyPwFDixu6iyU+seqHR0W2jlBJlLUO4rUdQW
aQNsZR2xzEswhJn1wxprs5ggheAlEK4pv8iYhZZdUoWRNWMsUSBb142N7JY5
54XuRZFjpljThyvvQ9bMkfRDefiqP2UzziBE8RxLoTbCqRkqqxlVW/rk2jah
PFhEMxbSKwoMIX5wyOBtL6twMuVGrN6dafLlVjaiHM3kygjNHGLZW6V1/cbK
dpXIRSupJaoiRFUUWdEDNQxky6LXVFGMtBFAXQBKS3ENhG7KImtSyZp0vDqV
qs8Gk7I0QDr5HJ5uTkUfxzDAM7UJtU0MeQCpbMy3DaA9s0RbX4G4Lp6hPS8w
JBvc+MZWZV9f5WBPdV+7faDN0VVfOdxUO9sVXBtoPZgefLg4cTDWtxT1j/oc
M0EXgPf2YPP+QHghXN1dKQ+pOaFyQbtFMVlv2Wz1bEbdc/WmMYdyyCaedqsB
xcC/k7WaHrO40ygasCtH3dqJJtdIqGa8ydvtc3qNuma3e2l4Ymd+487GCb+D
bSNN3qjP3uA213lsvkANmA+jgE0QsNERbBts7QeSBf6dGZgCwAKQwSwMdgKc
gZ3BmHz/9pNHh8/fPPnLty//683jvz4+fL04se13RUtYCpPa0RrqWZ7eOLp5
7+m9Z18++/Ivb/7y+tmbl09ePXv4/OmD588fvXz+5PWLp1+9ePrNV6///u3X
/wPy9Zf/683r/3796v9+9vRv9+99BfidWz/uHFhyeTuVageJLEpOKvjs45jf
/PKzn//kj798/7MzZ5Nz86lCicXujrobeoKh/qboaFfvQv/I+tDkzuDkTt/k
du/E1ujC7YGZne7x1Z6xpb6xxe6R2bbe0ebOwcawPxD0eTy11dXVFmulXKFG
Ywhx8cl/+viLcxdjMsGXLuJIVSqFRs0Xi6gsJoZKAvyCgA2Q7/jly6QAYaBd
AC+3VAICNoTystKycq6smC4owheRAL8IMh5GxBbgULloeGxOytWcxCv5sddQ
11OZafkSCFqHIJiwUAuk0JaHqMoleEBnRnGjaE5zITOcS61P+9/8mmMw5nic
6eTKdHpVFs1xgem8SrFfINnO0x0xjOo4SuU1elVCkSMR4AygxlWcx1WcBSGa
zlFtlzjWNI4tWVKbqfLnq/0IYyPV1MgocyPEVVnlvnx3B7txSFsXLS+v4pVo
SaV6oszHrh2xOAfNmqCMqsbKa/lyN0dgxcvdZIkTparDGUP0+sEyU1iIKU1H
CdOp5anMijSmMdnUjjf1YHmepIpeRHCr1DHLcsxyDMPkkkiOKJKmHyoo78mg
1HxEUKYyKnKFDrQ6VGTvU9RO6KtHNaYeqchLY9lQQge+MioN9uurw2K1jSTW
IMprc8qcmTpvvr2ZUNlCNjaSrVFu3UC5b9RgjJZqm9mGDnp5O1LdkVnWcV3Y
eFoRQpf6YDwnhFWZQ9WlYxVJaGkSXplO0eSwbQipl6xpYlV0cAw9XNMAzzzI
tXTyTR1sQzvZ1I1xjhPqZvDGzhyhMwYn/bhIdU1lhbm8/EhI3RkxDEQrJzrd
s52Ny73NK30t6/2texN99+aGD8Z71jvDiy31AN6bfU13x9ofTHXe6gsNOrVe
Kc3EQFqK0EEFG3RjUJLn6g3DlbIBi7heiG3XcAG8i0HblMfQY1W0m6U99rKh
ettEo2us0R2y6Wyy0pCjenlkcm95587GnZXJ9a5wb7XBpZXodRKducxs/cc5
0kGnH4y3je5gszfS19wD+P2uRU/1TYCJGGC7Pb95a3n3YH3/7vbhg4Pnd3Ye
7G8e31q7e2f74YPbr1ambzY4W5gEoYApc5jqgIJfPHj9n9/819+//k/A79++
+fu3b/785YuvXj198+Lpm1fPv/lH/vzqxd++fP1fb17914vnf3v65K+PH/35
7tHrm7uPppfujM/cauucqXI0qZVVfLYalk26+nny2//83jvf//W7b//xiz9d
g0JofJ6uTFVjMvsj4f5wZKglOtbRPdc7tDowvgUsDBAemd8fmrs5NL01NLMx
NLXaN77Q3jcWae8PNTYEg36fz1PjchpNFrFEgcNT0rMgV2OTL11NuJZwAwJD
FfEEkrKyEpmMxedzSvkEJqUQh4QTsBROEVskKBIWk9kspoDPFpWwS0qZfCGF
zSWzODRuMUsoYonYdD6DyCKf8EvEFRIwIFACJhWenQhPS0DdSCGl5xTnIpVw
nAFNtGCR9gKYNQ9my8I68+gBGK8JyY3AikI5NF863pmItsdi7Nfx9hv4yhRy
VSatJgdn+wxn+RyEXHWB6Yrj1CaxXEms6iSi8QpedxGnvUCouETSXcJrzhK0
58j680WmGzT9VZEr0dgCt7ZRbK08WxNf20DQBqBV7ajgWHHjmLqqUSIxUQU6
jMxGUDXz/PNVlu5yXhWVYcApPfxiC4leni8ww0SVULUXa47QfaD3hjhIYRKc
n0hWJAF+FT64vZdSWg9eYc4b+qF1iwzrON40jJU0Z1GqL9Pdl5Xt6aquNG7D
BYEdXurClLgwpR5iRbvAM2PwzZnsQyqeEyeowWn8HFen0t0q11RThWUFfFmu
wlUgtKaJHRmGRrS1haBrxFhamb6xsvCcqW5UUzVw8jHRui6Mqj1D2hLDb/xC
7MGcXHNkzCKpM7DSFJggoZCfABfcoJVDeRa02EWUeEjyAEnTyrAMFDvGSux9
gupBfvVwUdUIwT6CsvTnl4WTuI5LWNkJv/KKPKOZVG3jBJyS3pBxutO1M9J1
a7z35ljP5mD7zmDb3mjX7bHuW8PtG13h7e7GnZ7wneHok7n+x7N9oDAP12ir
eDgDucDBRfdXKpZClbM+/bBDARRcVVToYCGCcsZgtWrMY+yqVDXrpS1mRatN
NeC1jYZc3XXV4Sprl69hfmB0a3Zta25rGcioqd9pdlXI9XqZTi/XasSqKl2l
x1YL4AVFuquxA7RlYN65oRmA6uHmwfHO0cO9+/d27+4sbIGdJ28Ktw6PDcxt
Lt2+d/v5m6f/+e2r/9lYOHTZGiV8rV7laPJ3Lc1s3d45Ptq7/+T+s2//D79v
nn/17PErkOdPvgTyff70mxfP/gLy5PG3946/BLX54Pbzrc0Hiwu3pya3x0fW
u9umAu52m8pdSlEUxCMu/ubKb773+89/fuaL98/HfZqMz6PzyNISlrpC4fDW
Rus9bf6GzlDjQHPrBBicuwaXe8fWe0bXwNo7tto1NN/WN9nUMeQJRh0uv81u
ttjMBpNeqSpjsblg+E28kXHlWlJ+IaYAgYOhiQgsGYUnYyg0UhGbzuNzxQJ6
MQtMwYBiCodB47EBxaBOk1gMKpfD4BfTeFwcjVGIxefCkVlQWA4itwALRZBQ
gF8kCVuIQ0MwiFwUNBdfmEeC5tEL8nkFhWIYRo0imbBUOxFXVYi05MBNGdiq
bEY9lNsI5zRCGQ3ZdF861ZNKcqWQXGkkZybFnUurK2B4CynuS3DTx9CKj/C2
c3RnPM+bxvdmcWrSEIrzaMUFQvlVqi6OpL6KkpyFCz5BCD/FyC9glJ8LXDHm
Dpitg2YMcysCPHU93hCBOvthgQlGXR+/zEljlsHZGqjMgdZ3CXxzFmUjj2ZA
iZxF4poivDSLIEljlGcILblaH+CX7Okv1QdoCGEcXBDPLM9m6TL0YYKlA0sx
nqZYPzENQexTCNMwVNOdx3RfQVScojsvAD9qu7Pl0SRRLUrixfJdcGYVRNZI
rp0ur1/Q24elLMfJSY/mFl51q0jnpvCUWfTihCJBkrgGyTJlc20ZZQ1wXQRZ
HkJYOqiB6bL2TUd0tco3rXEM8c39FE0nRNocLwxfKHXiWKYCojIDVZpSyEvM
ocdnEq9mEK6gS7JoqkKuGcW3o0trcdoWZuWgwDlRWjMkqB0XuiZYtkGMtjNT
Go4vrrvAtp+j686XWtL0VWirnWI30evMvGaXvD9gWGwL7Qx23JkcuDPZB+Dd
G+s8nOw9nhnY6g1v9jTu9kYOR9teLA2/WRt/PNVzsysIEI6Uc5vU3Mm6is0W
54LfNFKtBAj3WiROHraCCKnmkwC5rRZ11FreUVXRZJK327X9dfaRkG+4MdTp
re/whQdaeofahiZ6JsZ6xntb+roinb0t3V3h1ibviXnbA61Au6AnA/MujS2s
Ti6vTCyBUXdtamV9ehVkcXT+u8NZwMjri7fWF/a2V+7srh3f3QNF+r8fHX49
M7Lpq4kWkUUZSQU0Arc13H3v4NHXL//y5Yuv//z13796/eeXz74EzRnA+/LZ
1y+efQvyl2//n6+/+p/nz/4KOvOdgxe3bj5dXjmamNyeH1rrCQ3VmxsrxQ45
UUG+Qcz9NCPld9fxV5H0RCL6Mgx6Lo+QhKdm0jiFHA1bq1Pbbaa6OnckGOgG
Im5uHWvpmI52z4LxuWd4uXd0qb1/qqVrJBTtqatvsjpqnW6H3VFpNBtkCjmR
REtOzQLaBcnIhqHxDA5fxi9V0DhCHI1JYLCAUrEULLOYKZAK2EI2jkKAY5Fg
ZfI4JAaNSKcSaBQ8lYohkaAoVEZeXlJ6enzqtdScFAgCgiQgwQSNwGHy0Ygc
ZAGUiIAz0Rg+DlOKRojhSAWUUIGi2QgYQy5Clw7TpaBNaZSabGZdHqMui+JK
IbtTKbVpZHc6wZlBcGaRaiEUTyHVA6fXXy/Qf1xQ8TnFeZ3jyRA2QPiefJIh
EVpyASW5SlHfYGrSiNJ4KPN0Bv7DdNwf0+i/gwh/w3detHRBjS1Ela+ozMMu
q8cp/amWrjTnEMIcJQmsGJqygG+Caxtw5oESy4CEVY0maiFlDXy6Bp5COANl
XyVJE/imTG09yhDEVbUxgYgRJVcx4ut8A4yhSq0I4MqD+RjVB9zaM64ZaM0s
1D4J0fVnUqq/gGl+x/Nd0/Xk6jqz1W1pUj9CHkTzaiE0e7rIj6gcFVRPSiq6
ijhOSFkIb42yDAGysCKTxLtEYl1kCeJ4dkKRGcGxF0jrEWVBWFkQau4geSYk
fXu1fbe8wQVD1UCJbahI34uQNiWVNsVInBSOCUmQ58CL03Kp8TfQlxJgFxLh
FwuYNyiyAr4FJ3VRNCFGZY/QNSZ2jpbUDPMcw0XWAZy2I6c0HMfznimq+azI
fppjvqx25VU3UF1utsNCr9HR63Ssej23r7ZyrsW/P9Z9PDt0MNF7c6QdZH+0
faOncbXDDxC+P9X7ZnUS5Ml0//FIx3Zb3VyDZbbedLPTe284st/tXQ5Vgil4
2msMyFlmJsqj4A55K+ejDbOtgakm/2zEPdXoHgu4p5tDM+1tXR6/3+Zqdoca
7PVt/rbR7rGlicWthY2d5Y31mYX50bHvjjYDML+rzd8xCzozYHaiZ6wn0gUA
B4L2Vta1NrSAKXhr+WBv896T46+/fPZfrx7959PjP++sPOhtnclLw+JgLHGx
xmlr6G0fXV/cfXj09Mvn3/7lm//85su/fvnq2zcvv/ny1V/evP7Lm1d/e/3y
71+9+e+XL/7+4P6Xe7eerKwdTk3vdnbN+AO9Ddp6A0sngHI5mTT2DQovkVyW
xXNgy0McR6TY6WVYrFiVBi4S5bC4GbSSPDaPKZaLtBaDy+dpaYoMgCINEA63
jjZ1THT0z5/It2eiuXO4pX0g2NTu8gYBvza7VW+sUChVJBozLTMvKSU7KxeR
D8NjCEwmp5QrUvJKFWyhlF0i5ogkJDqRQMWDEGmEkyPSTDKBSsSScCg8GoqA
5xbkZ0PywJoHLciG5Kdn5yRnJQB+s6FZUGQBgB2JR4PACWjAL4KBxgiwaBEK
LiqAinMRSghWA8uXJkJk1wsU1xGaRJwpmWBJxpgTEPoYtCUeY0/E2JPhliSY
5QbCnoWpycc6C0h1iXm6LzBVcaJmuCiMKmlAsqoLCktjYSVxOGkKsxzCVkHw
xclZ6NOJkA+T8v4Yg/lpDv9XwrrL5u58XRNO4WEq6zhyD5pTdV7ReMHYmaJp
hAnsSPB/Xl6LtbSSK/p40jAZp89AqTKVDWyEMOUq9A/Z1DMESRzfnF7uhanq
oBVBrMxZiCqNoahTxGYsXZ6m8aHUDdkMy2f6zsTINia0ifKswConcpnuL1D6
P5QG4gEdinCKMpJa3oZRRVElgbwid6owkKftJuh6yLIIQuTLA3888GKicuez
FTFU/jmO6IpYmcCyULh2iqiOJPPjpAGYLJCvbcHa+zkdW46ubXfdePnJ/Qr7
2YZerKw5VdqcIKlhCK0Upgb8VedkEuITCy+louIglDSqBFVipml8fFOTyNEt
9U6ovJNyx5DQ1k/TtaNkjRnCQJwgcJlXf47tPg34La6K0XmgriDDXctyWhnO
ClqdjunTMhsNZR0O/XjQtdQeXOsJg2z0hbcHm1c7AxPB6ulG58Fw26vViZdL
Y4+mBx9PDhwONAJyQY6HwifnbIy13OkL7HZ4xmp1YOBtMyunw7V3ZwafbSw+
WJnbnx17vDD6ZHF8d6Bjvq15ob2r3x8OVLrDNX57OejJnq5I98LYHIB3a3Fl
dWZ2eXLiO1q/O2AF5Pudbce6RiwqE4hda6u1uEKuABA0+KVH+w9Abd5dO9pe
Ocna3MH6/J2NhbsLE7eGuuYj9b0mjVMhqqix+eYmVl4//fp//v7/fvvV3wC/
QMEA3q9e/xXA+/L5yWHnw8Nnt/efbG4cz0xv9/TNNvh7tDo3h6sW5jJFOUxZ
PqcCIa4hlDdxqsdVTWvW/lVjz6KhC2wsWrv7lYEA22JBSUrTqIg8LAgeSS9m
y/S6aldts7ehw9vQ5Qv1RtpGmjtGgs19oaaeSLQ33NzpbYjojVq5UlZSKuLy
+HA0Lj4xNS4hLSsPSaYXk+kCCoNP44jYQjlXdBJAsUBcTKTh8+F5cEwhnU3j
CNgA5Hw4JDs/JyM380ZGSlJqSmLKDbAmp6WCpGYnpWbdSM9JzYXmwDEIQDqW
jEeRcQgyGk5HIVhwRDEM8AsrzS0QZ0LEaamc81mCKwXSOITqOlIThyiPKSi7
CFGeLSi/CDfEQvWx2ZprGeWxeYaUQlsOrBIChmKI/iKzPlfbV1QaJnBccLoN
WihKAsahl0E5GjRLDkcxbmQUnkvK/iQl7/N4wruF0t9L/DGmrlxNGKP0siVO
FtuajdV8wHV/oIxcKQvkiKpRgkqstBataYRLmgh0JwRenlggSZTU0ZCiG2mk
szDeZVpZotSeU1EPk7ty1J5CSTWEpIrn2/LkVhJLlWMKkS1RRHk4uWEe1rGP
bz/A1a/mu+cg/PozOOMfShpipcEkfl2sMpJe0YtSdxSKwpm8+lR+KFMSzZe1
5JeGcuWNEEMbytyMVtZkCDQxInWMxnTDUpVNM9L5TrYswJY3koG7JX6IKozU
t1ECs7rwgsXaLVYEyYZupqGHKGvKVERTJQ6muIopMFKIpYXZhMRkeEwhNZMh
walrRNag0tmmdXapvMPljbMV9dMqx4DA1EOUBrOZzqus2gsloculkcv8+nOs
qtNST7I5gAL81jgZgN+GSl60RtLlVjhK2NVitqdMGLVpRvyO5U7/rdG2u7N9
y+0N3TUVnVWa9Xb/k/mh5wtjz+ZHv16deTbT+XA8enew8bA/CFag4KOB0H5P
w3zQNtVQORN2bfdHH65Mvb61/nJv89nO+pvNub8fbN6fHZ9pCU81Rf/Bb129
tdZaZqnWVzf5IjNDU1uLa+tz86uz0yefgvUP1QLzgg0w5O4uboM5F2i3t6kb
MDvcPghYHmzt7wi2Reub2/zRhcnN4Z6ZicHlldlbq7O3V2dP+F2ZOQAKthvq
cXBmZjKUz5IOdo8D/7568tV35n394uvvjlyByffxwzf3j19tb9/d3DhaWtwf
HVlpah6xWP3MIkVOLpGXSqqilvdqg/NVvZvO4VuusR3b0GJ525KqdVRQPyEJ
TKsiXQJ3hGV14cqkSeSkyynnPrn80QdfXDx7HV5IFpfqDaY6s63e6Y36I32B
pl6vv9XT0BwIdwTDbXW+Rl9DHfCvRqeVSOU4EjUpJTMhOTMPikXhmERqMYsn
40vUAmk5p0RGZQvwNDavhMMRsJhcOqAYTUAicSdvDQMdp2alAX4z87LSstOv
JyddjYu9fC3mSuy1+BsxIElpCdn5WQhQtsl4DAkHw6NwRQQkHQWlF8C4UJQE
hpZD80sz0nnXk+lfZPEuwaTxGHUiUh1fqLyUJzubI/siV3m+QHsFor2aprx0
Q3ElU5uYZ86GWHII7jSoOa44gtIN8bleNNmaz7AhscocugbJ0eL5GlKRGIkk
p6XnX0rLOZ8DvZpS9HuM5hNlOM4I6msIpfCw+DYqRhELlb5LrfxFqf9zaX2a
sBrJtaK4lbnF1TdY3ny8NRWmTsgVXRO5yGRVDl6WSlOmcirS1e5CUxAld2Wp
PPlydwFTn6L0YNRVzBI97OQOxQPUmkFo2w6xYx/bcQdbu5hZO58n9J8F/BbX
XQbwcpwxumierhcmb8sRhlK5geTiUIognFYayRCHs1QtEFMHwtwCL3OlSk1x
usobNR6Izw/nayFyG9rko1uDLF0dWV6NKaslmBqZvmGld1ipb2KWuJGyerwq
TFUESfIAUVXHL7HRaGokVppXWJIBXiRJBrTAU2Tu1VSPmr1zVZ5Ze/WIwdKr
NnWXWbpVqjaBookj8BCY9nxeZb64Bia1Q0S6dFMVqqaG6K1hhpz8Lq9qOGQe
9Jk7HdqIvszCoRqLCEGNZNhj32hvvDPcdTjSvRDxeGU8G4s4WGO6P9H3dG7o
eKzr7mjnm9neJ6Ot9/qbjvojd/qabvZEwIx8c6D15nDHxkDbUl/r5njv8fr8
y6PdN8f7L45ufvvg4N7GwvbU0PJQ9+JA5/ro4NJw30BTo9ugKyvmNdjtO3Nz
6xPTvU0tEz19N5dWVqYXbm/sPbjz8Pj2w73d4+3Nu2urh4sLtw9uv1yav11d
GXBZA2VCbSlDrBNqm93hgKepLdIz3Ds9M7ayNL29Mru7PHNzYXxrdmS9Izxk
UtdwKCIxW9lY27K/dvT31//r79/+7ZvX3755/iXQ8fOHX96/8/zo1pO7e09B
D99Y3F+Y2ujrGDFqrNlpORfPXEpLSrVqtCaVGqyyYj4yNy8/Lb0gPSPpytXP
//DHzz74A1jPnvro3Ecff/r7Dz54971f/fgn//HWD3749n+8/c5bP/35zz48
9af0zIwSkbjGWeeu9TX4w8FQc319xOtt9Pubg8FoQ0NLfWNjbUODsbKSLRBA
4PDU7Ow8GAxLJpOZTLCHxeeDeRZNJFJZLI5QCPZgqBSmgA+CIpMKMGjwkMQq
IjAZuQh4RkF+YmbGtRvJVxITLidcv3Q9HuTz2I/PxJ++khyXmpsPRdEIZAGV
ISYXCcgcNpyKOLmPYgkkn5+GVuTClTmx5LOXCZ+nsGOgskyMOh+jzEeIs+Gl
WajSbJw8FyXLREhSCkrj8kqv5MuvADvjTIk83xWs6RTHG6vtRZaE84mOG5jK
VLgxBW5MRVszMbZMqDY+RfRZPPe3Sbzfppf+MUN7ltl0Xj72ibD3t7zGK0If
nmOj4FVx+ZJ/p1n/r7LQR6WOZJEZr3LRBLZrbNt7UOWvkOWnYKrTFEuaNEDj
OMg4DYxpI4q8dHWYKWlAcKpvCFxJ0oaUsmC6PgpRNuWaulj2fqF9BAOc23VE
j97kumbz9UOfe9euK1svlwYSaI5TbM8feJ5zJd7s8roUdV2ywhMv88SIfZfE
/nPi0BlJ02lZ21ll5wVN92Vt11Vt+5Xy1iua6BVtS4zYAFNX4S0NrKrGYmM9
U+nAyBxogHBNt8jZU6oJUIvtUIETLvXhJF4sAFnhYgmtpKIKFF2HoOtRXDtJ
ESwGtAJsPbO22mmLY1hn6JSVNwvUTXywljXzpY1FXCeaasyhV6TzTFkCfTq/
LEWqzjAa4G471W/nttRI+r36Ub9ttMHeUan3yPlehaDbYZhv8t0caNsf7tzs
CE/UO4JqkZVNrJNwRtzW7c7wnaG2o5GOByOtdweaDvvCAN793vBud/hWf/T2
WPfR9MDd+dHdyYHFvva10d57W8svD28+u7394vbW0ers7szI2mjfQn/H5vjw
zuzEyuiQXaWKej1zAwMzfX0dDcEmj6+1IQDWyb6RvbWbx/v3dtf3tzcO7h6+
OLz9YnnpTm/X7EDvQkt4wOto1MstxRSBUWaqM7qKORKD1tHe1A/QW1/YW57Z
mRvfnB3bWJzYXp7anRpc6QgPNNV3DnVOHWzc++rxX75+9c1XL7/+Evj3yVfP
Tu7G8BLwe3v70a2N++MDC7WOgFSoKsxF/vG3f/rh999676fvnzv16fmPPgP5
8P3f/PwHb7/7w3d+/eOfg4333/7JL/7jRz/797fA+t5bPwZ73vnXf//hP/3r
v3zvX//1+98D+d6/fR8gfPbcBRQaK5Yoqhwury8QCDbV1jVUVdU5HJ7a2oDP
F67xeGw1NWU6HYPLhWEwAGEkHk9iMOgcDoFGo7HZJTIZt6QERSCA/Uwejy+T
skUlFA4bkAvFYvLRqO+IRhAJ4GEOHJaalwsojktNiUlOAiCfif/8XPy5y0nx
SZk5eTASmsgjM0U0jpDCY2FZKEIJEi+FomU5NAMCX5GfyLgQSz+VITiPUCcT
9JkEbSZGmYKSJ6MVNxDS60h5PFJxDa64BFVcKFSdQ+sv4SxXi1xX8ObPme4r
yo4ccTSL6opHmq8UVFwDCGNtuUQ7BGlIzZafSxP/KVfxJ3jFJyhHLL/rimr6
E9nQB8LIJUEdushCwKuu5Yr+hWz5Z2XwVLE1nlGWJzDC2cbzXMevYNpfY00f
k21X2M5M8GRONY5dRZDUs8vCPGWIwnXkUoxxPEey1JupCuYa22C2QbxztLR2
QuqeJjasQyK7mNpZtKYzoazzI89qYkVPcnlr3gm5oU9LAudF9ZmGQKbKkyh2
XhU5L5Z6L8pCF2WRi5LIGUn0LIiy7YK2K8bYc72iPU4evCis/azMgtVWkSw+
dlWQb/KxFJUYgb6Ap8+vbOI52oQqL5ltgnAtEIEDBiJyIkssWG4FnKmFgom+
tIasDnJt3QrXmL52yuQYKTd2S9RNPFmQLmugKgL0shBTHuScvPVciaCcXH6Y
wtVmlFTkSDTZgtIkjSq/xkyut3FbHNIBn2Em4l5u9U811vY4TW2V2u4a46jP
sdoeWutoHKuvngq6R31VLaYyj5QbKi8d89pXW/0g2631W231u52BE/N2h7e7
I7v90f2x7sPZ4WdbS482l7bGB7Ymh57cXP/m4d03xwePd1fvgrl0aXpjfGC2
p3VlqG93bnJreqKzoWF1fGx/eXlpZKQnFAk63c3e+uH27t2ljcOtvTtbt7eW
djeWbm6vH64s7U2Mrk1PbI4MLnVER60VrkptjUFuCrlCFqWZQRGo5KZwoHNm
Yn1xdmdyaGmkdx7U6eGeua3lw4eHb+7efLY+t788tb23fvzk6M2bV1//4/jz
1w+OX9w9eHZ0+9nOxr356R3QC+yWemQh5fL5xA8/+PwH33/nn//p5EYK//ZP
//KTf3/7ne//8D/++fs//cGPfv3T937zs/d/+/Nf/v7dX4MN8BBs//GXvzv1
mz+AfPir3//kpz8HeftHP/7+v/3ge9//95//4r1z5y+nZ+TIFWqLtcrj9btr
6622apPZbq9yudw+k92uqqjgi8XAsEC1OAoFYAv4BaoFDwHRYBVKpVKVilJU
lJGXh2fQgW0BwiVKBbGImZKbk54PAXvAfhydhqaQYXhcHhIBdiZnZyVkpF9O
uXQ5+eqV5OvxKVkZEDQMwyDQ+VQOj1JMIwqxNDmKroGzrWipj8GqRmfwryZy
f5cl+QSlu0owxmN0sQjl5ULJeajkbK7wM6jkNFx5Gq4+Ay//DKH7DG36Al95
ll4ZT7JeplSdEUXi1L3JQKkI68cFFafR5mRiZQGlCo0zQWDqOGj5aZzlc0bt
GWp9XGnf5fKZjxTDvxNEzrFr8qgVMGzZFcAv5R/+ZZuuYEqSSbIUgvqTIvuv
MJbf4StPsepiin3pRc4sgQelifLMPWJDWzGwG1mfTNbFi9152jDK1IKv7mHU
TjK8k9KGGUVwhRregdSv5Bp6MoT1Z+Utn/iWM409uZpoIdd9QRT8WBo+p4xk
2lvz9MFUpTfu/+PpPYBS2xJ13b7vvjrd53TY3bt757X3ysG0zDlnEUUFRUki
CAoICihgBEUEMYGoKGJWUBAVc8Ccc86u5Mpr593hnHPvqXr3Ddtbp+qvUYPB
xHKt8pv//885mTNL5cJv9yjo8srVunDbbOl1D2nK+wyVeWabk6jbt0DrnVZl
nVB4U1CCBxLJSMU11CJFEk+CpueGJ2dBihtSKjSsgjpSqhhOF0XSiiKThVBK
YRiFH56UC03ih6VKkdnKxMLWFHEnU6Jn5zaTuSo8swqVWhmbXoO6up9AI1HQ
lMipSWLLCCmS2KQCGK0gnCOGC8pixeXo7CxoYU50eT6uoZhhqMqbaK5Y0NSv
djbtDHYt6ZrGGiq7ygpai7KN1dJRtVxfUdhfU7LY1bje2z7ZUj1cWzbVXA1g
n+9QrekaQCPe6G7a6uvY6Gmb16onW+sm2urGWlWr/d27k8O7U6MHsxMXa0sv
ttefbqyALH24YDqYNwGopw1dC/09AN7V8ZH1iYnj1ZWdubnF4bHZ/qHBTt2Y
wXi8vn26tjvdPzbYZZwcMI32TbSqO5WKlma1vrtzZGRgbnRw3qAdGtCPD3QO
d7caWGRWsUghLaoC23R1DPZ1Txi6Rvt7pk2jq2NDSzur56+e/Pj66U8nuy+3
V86AyV4cvv3w9iegy2cfrr5ktAt0OTe1rW0d5rKKoiMJD+86fPyHr//0+6/+
7dcfA4Q//fONj3/757s37t38/NbXn35jZ2HvZu8ORgcrxwc3H17r4a1Hlvet
bM3trB/ZmN+1uHP30b37IFk/+PSzr377uz/+7vd/+uLLbx4+soyMiiEn0fiC
QmlJhaS4rFBULCqSgkl2Pp/JzSCnUImUJBKNAoRLJCCxaGhUBJ6c+M8rJ+Nj
MKiEJBKYJ1KTgcmC2AxoZXA5wHYBqr7/fEY4IBedSLwG+ZpiYM0gVPtFBPqG
BXlDQnwgMMBvZCwhDk/GJifiGfEJ6bGEbDhNHJPbmCTtYaarsGEZTqHch1F5
j1FFLmiRS3SufRjLIoB61y/plg/pRjDjXiTXAkRZBN8SkW8RW2SFLrYhioNI
Jd4YsTlNZSYZ9xIMOuKrb8VIHuBK/Qhl0YRSDFYEj8nzii2wJlSY0dUWRJVt
usEid+xGpvGLlIaHicV+6JygaK5lePr/Syz5l+wWM5rUFZXhi+Z5x2XfIxZ/
RlI+xJbfItfY0lSeZLkXtwVZPpxW3s8SdSZn1MaSRP6MUmhJJ7m6P62qJ1Vp
ZJUPYuVDqXWT7LYNQvsetHrOL1fjSVVY8nWO9YvR+dqodFCoCx+QKz/PaDYr
0AWV6cIkHcEFrT757d7CTp/8Tk9eixOoydRqs6TKB1SFObfBWdgZLNQEZ9S4
JUksJeXJohKSqIxcLKcC8aV4jjCWxUdI6xiKNo6kLiVDgmKKECkCGIEXhOcE
UHMg1LzQVGEEtxx19dzSVqqwOTmnHk+RhCUVhSaLoaDkcqvj8tR4gTqBX4/n
ySkZpQRmEZpdFJdZjMkvi5fKCDI5qbgQI8pGSjPRDeLU4XrJvKZ2vq12Uq3o
q5YOqSoG68pbirLL2ckKHr0mO01CJ4ARrB9N9F0umy5mh8HkdGrg6fzo07nh
48mrM8Wb/dqZDnWnrKgykyVikKtyuTX5Obpq2dJA79H89PHi/MnSwtONtZPl
GQAv8N/dmTFQfrdMozuzU8ujQ4tDQ0crK+uTkyZDH+i/2/PLi2OTM4Oj/S1d
VaLSkmyRuqIOOKxEUFaQJS6X1JSIqw1dI736MdPwwmj/1PL0mmlwWlmham00
VJY3SAoVFSWqhrpOnWZodHBxcXZvf/v52dHbV8/++u7lv79+/renp9+fHb4/
Pfjw6sV3r1/8+PTs3fH+JYB3dfGoRd0H4LWz8n101/nTj+9+9Nsbn/zp1qcf
3/ry03tmD2ydbLx83SFgtDZzBpMgH5ibg5+rva/ZXVurh4425i62Fq6O1p5g
xeGxh+UDBwsLexsbF3t798ePne7ds/zm5j3A8v0HFhaWNq5uXpFRCBI5mclK
z+DwuJm8zOwsOpsJmI0nEQGbKaw0GhMU3oSIGAQsGh6OiAIgA3Lj4rFgjiHg
eXk5AFsQmAGwoQg4mAALBqiCzAxABhOAMFgBugYZKBp/dcFVJBqYMhAuIg6P
wMUjiXHYlGhcejg+C5JaDi/pYShGM9gqZDjXDpHvGSvyxRT5xwp8YBnOvsnm
rtg7DrFfO6Nv+ZIfhbLsInkuoPxGZDtG8p2ihW7EQhj56hFdD0lVN6Umh/J5
J5b2HrHqUaLMh1iKiC+MQ+ZEwDPdkXmWhJJ7tJrbSWozTs89/uiXHMOfk2tv
J4jc4nheMOYDWPq/xkt+ndVixaz0IReGJxWFYYVWieU3Od2u+Kp7WPk9UrVN
Uo0zrx34aXxOK1LQjslWI9MVEcJmfPN4bpupoNrArtDSS3qR8gGKeorZvoFp
2fKWm1wymx0p5VZSY2DjQkJ+KzpdgUTl3ccW/Zau/LxA5yrVBYk6fHOb3Xn1
Duxam7Sax/QaK3qNdWaLJ6fRg6v2yGkOBLW6SBMpaA7Lrg2srMkok6eVylLl
1elyZUaZIlUio4krqGVKVnUzT1rDyBbHc0QYVn4MOQNCYAbSsiGMvDC2CM4r
jePXEAobyCBjZ8jiaOIwIHoxLL0MkaWIy6vB5Fajcyvj8sqpXDExQxifIyEU
lpKKSohF4nhJIa5MiBfz4kq4uNZi9mSzbLWrcb6ldlwpV2SndpTlj7VUD6pl
zZKcWkG6jJeSR0ZVZjEM1cW7Y4Z3Owvvdxcv12bebC38fLr93dH6q635k7mR
1YHOHpW8lJdKj4vChvgmw8MTYVAeKUFTKV/qN+6YJi5Wlr8/Pfvu/OD1wear
/Y1nm6tHCzNHC3O7c9PzAwMzfX2mnp7x7u6FodGt6TlArr6prU1ZL8sVSjl8
CZdfWVCqKlOqymsrJQppQYVMWtNU1yHMLW6sbe/vHt5a2VuYWjGNTGlajaqa
jnJpXVlxbW1VW6dmcGRoftq0uTR/sLp0fLD76uXzv37/4f/78Pa/Xjz528XJ
jy+f/QD0/OLbk4PXa4unnW0jDArfwzn8y08s7t9yMrvn8tjM09UxyMsNEuAT
AYfhEnCpeCwjIgzn4wkL9ENAgmJ9vSLcXSCP7jtZW3o62vm7OgUH+MLhEQnR
UcTwUExQEBwKjY2MxEZEoIKDozw9A52cvOwdXO/eewRkaWXt6e0Fi4zA4NCk
pEQanZpIJeMS8VhiPJgw0tNSWAzwMiIGkBsHiYD6QwJh0ZF4MoFESwLrMZhY
CouZzEwDYAJvBW03NgEPmIVj0CFRwINjwUvwFuA3gUpJpKcAgybSUxJoKdgk
ChKfFIUmhMeiwlDwcEwoIikIzfLH5/pxauCywZTiXnJiqV9ohnlkTlBUbjA8
Oyg83c+f6uaKs7ZDPHoccc8Vbe1PcoWm+cIyAqEsnxCmVyjHJyI7MD4nnFAY
hCu0JJTfyDbcL5myEQxYpzXbAq+MF4fGZIVHMAMjmM4x2VZ40T1y2c3U1kf5
w2aiiW9Y2j+S5F8nFrvH5/nB2WZRnD/FF/0R1M8MJYRREQuCJUXmxai1LZqC
UVpssZX3E5VWKWrn1AY3Ro0HqcQxvx0h6cRKNHiZjtIylt08mlPelpxfg5UN
xKnGU1vmmI2LEdWzVpJ+C16DfUqFnWIkunmOVtSeLGxKIUvs0cJfE0t/ndX6
sLw3qFDrxVXZ02SPyNL7lAoLltIpq8m7SB8u1MLy22CCJtjVE4EbEfkNcIEK
Xl8nqK3JrVVmq9WCpiYhGJWqXKUqW1HLq2vMK6tiCcQkoTQ5vySZm49j58am
8xE8YWxmEYorRmWXxguqiHmVCRklKE4pOr0EmVEcA8STxmSXxuaUxQEJiqlZ
+YRMQbywOKm8IrVEkiTIRmez4JIsbEkWXlVIH6gVL+vUOz0dW/qObV37aHPV
oqHlbG74yeLY9oh+pa99ukvdpyobbq5e6us4nR99uTkH9Hxj9tXO4rfHG9+e
br8/3ny5u3wwOz6maaqX5IvTGQJ6EiUmigyHcQgJqiLRWEf7+sjoxcoq4Pe/
vn3191dP/np5/t3Z0fOtNeDIp2vLGybThmnS2Namq2/sbW5TlciyGKwMCl2Q
ziugp4tZmZV54uYKpb6+Q9egUctUFaJyRUlNhbiSkcyqLK1Zmlkb6h8rL6ks
EkqB7aprtSBgA3hrKltamgy9honhwTlNe39v9+TC7MGTsx/fv/2vd2/+69Xl
/7p8/h+vXvzy8vnPzy5+PNx7PTWxVV2pJRG4ft7RIYFoJIKCRaUmJqSnMwtz
MksFueXFRUoep4SZWphMzsagUuGRZERUUjg0wcMt4rGlr51NoINdsJMDJNA/
DodhUpNzKUk5eAKTSEonJ2ckUThEEjMOQwqLQPoHQd28fG0dnaxs7RxdXXyD
/KCRoUhMDJ4UT05JJoA0+09CaUx6MoMKWI5Ewj38vOBx0Sg8JgwOC4GFxuJQ
gF8ANcAWsJmSkY6n/N8sDWwX8AuLRUbjsIDla9sFCAN+AenkNGYiA/BOQ2AJ
EESMf0S4X6S/X7QblOgSy3Yni3zzmmPK+hNZdZAwzsNg5p0Qtg8QhOUdzPDy
o7h6EhzdsbauKJtAskc4IwDOgUZkQEIYvv40z4BUn9CMIATTD5vjQ5Q444tv
EeV/4ekeiIZdsjrdE8udY/meUIZbcLJTRKojOsuRUGhNFlswW+8VjVmJx26n
NPw+oeQGQ+afVoEgFnjGF9wnl93ObvZm1UBp5bGp1RhaVXBGq59kFsXuDiDU
2VCbHFhtrgmyh9H8GzjhfZE2smaIpBygVHQRlD1UpSFF0ojNrYysGkK1zLDa
5hmKMa+ivq9EhvtCjWduY0DDFLF1li1pS5PpctmVvqj8/4kR/YrXdLO8P1io
9eDU2TAUFmlVtplqT6EGUqxHiLWIwrZoYVN0vhqZr4rl1yJzFdGZFZFNqqKG
2sLmerGmpayzraK1ubi5UdzSJKmvz29qElVW8grF1NIKlryKW1LOFEvpohKK
uIwGiM4pSgCWWlCenC+j5JQQgDIl8RmF6PT8mAxBTLYQJZDEF5YShUJaVhY+
JyuhRJxSI0+vkKTkc1BcSriIja7KoxgUBUtd9QeDXcdD3c/GB9/Omc7nR05n
h54ujT9bnjiaGTieHTxbGNmf7D+YGXq2PgOYfb4x/3RtFgD79nD99f7qm5Pt
754e/nx5/v5s/2Bxar5fP9OjWxrs61HX9qnrR9vbFo19h7NzL7d3fjw9/8fz
SwDvL88v/nb59Mcnp6/3d98dHXx7fv7q4GB/fgE0X0NjSzqJ6mZh4/DIMtjN
N9DFm4khMuLwhamcrhr1cIehvVpdKSqVico6GzrqKpTp9Iwcbl5PV18aPT0y
PDoeQ0xJ5gLzbW/uUdW0l0uBBbfqOocG+6ebG7t7useXl46ePfnl7ev/DeAF
evf6/1w++9uzi58vTn843Hs7M7nX1jwkFav5OfISSUNlRXt5SXNFaUtjfZ+2
fayjdaSzY1wsbhIIakWiBjAyGEUpKYVEYnZgIA4KTQwNJfr6olxdo8DL+Hhu
aqo4LU1CIGYQEzlJyVkpjFxGWi6Fxo0n0KJj42PR+LDIqEBISBA0ODQCGg4P
Q4DcQkCnclKpTCqZTgZKYiQRqcQ4PGipkRHIiABogG+ILxQOjYqLAisx2Jh4
cjzIyQBVgC2g9ZpTAK8fNBQ4L4aUeJ2cwQQIYE5OZRBpjPhkOhJPCkXEeYWG
ugZ5Ooc4usDM/XFWsRxHWplfgRYp7kHjxfYeSX8JYHwTwnEAgnIcwzIcw9hX
ggGxnCPTXZFZ3nF8f0SWT3Cqow/V2pdhF5zuAkm2jeW6JZV6YQvNw3l/SlY8
EBoD+PqQhBIHRJZNYLJ5QKJ5JMMxPtubLPSjinwZ6m+Khq0KB+4lVv4eV3gj
owYmaEhiyRCMCk9mjUtee1hqFYwghpPLYpIrIdyOsPwxHKc3ktLkxezw5mg9
44puQNi/IxTdl3SFN09SGseope2xJW1IeSeqpDWqoC5EPoBomWU0zyYX9zrk
aP8o7n1YORQpN2I0y2mtMxxRU2plNz+jyj+W/z/iCn6V3XpLpPfMaXFKr7Pm
1DkIWv2l+qiKblS5DituQRU2oAtVmKJ6vLSBJFYR8+QorgTRpJS21JV2NJbr
2hQGTQ1QV7tc01Le3lRq6Kzu0lbW1xVWK/Ia1WJtR3mnpqK+XqhQZIOYq6wv
UCjzRCWp+VK6VMGprM8RltJ5fDw3B5edFy/IJwgLSUXi5MpSTlU5r6qUqyhJ
V5ZylBKmhJfAJcGY6MAyNsFYLV7sVC12qOaalQe9Xe8Xpl5tTr9YM10sjF5Z
8PL45cY0iMfAbd/sLf90sf/XF8fAcF9sLT/bWHyxs/Jqf/35/vrrkx0wPtla
frG3+Xx342Jz5dXe1qu9nQ9Hh692tl9sbrw7OPxwcPR+//Dn8ycA2w8nBz89
Pfvf71//49Xl28P9y7297588fXVweLS81lmnJiLirG/dv/PJjce3Hzmb24Y6
uiVFIUu5OV1VdcNtXcZmTYusRl4gLuUX5XNy2NTUjsaO8uIKBiU1iUQlE6mp
FG4mO5+fKc7OyM/k5BcJS6vkqtqalqGBqZmp9Y318/29V0cHH85Ofrp89r/e
vbvi9+2r/3zx9K/7O683155tb7xYX3kyO7U/aFzq7poy6KbHhtdNY1sDfYs9
+pk+w1xd3UBtbX99/VB1da9Q2JCVVcVklhAIOTSaKD4+My6OjUKlE4m5YF0s
buHz6/ILavL4itw8WX5BlUhcU1Ao52UXprIyiWQaCpeARKMwCVhgu1gCJg6H
BKIyKTQWNYVNS2KQ8UnxaAIqDh8LFBIRHBgW4B/qB0YoPDQyNgKBhgMBQoHJ
AniB7QJ+AaFg5b9PJF177nXGBnPwFoGSGocng9gcFBnlFRrkFOTqFGrtCn/k
G3+PIHTntyOKe1HcphB41gMv8l8CU2+G59yF8G6GZ92JBZG41JFa6Z5W45eu
CgIjQ+GXVO6BFTvECu2QBbawHPNA9u0YjkOyJIAs9Y/NsY3gPkRkPwTOm9cZ
RZV7hrHuehG/DCbfh9FsYtM8E3jQxMwIVvOd4hG77K57sfm/ieR8Ti7051UR
AcKc6kh2TWBymXeiBJJcFpdUjqRUwbhtiIJRaro+lqOHszVB2fqAmPzPorP/
nCS9X2lE1I/g5boYaRtM2RtX04uQd4c2jsc0zeEGD/ilBkRm0z2x8ZsC3X1Z
f+TAvqBnm1fRQ8irI2dU4NkKb1LpH5CCX6XW/EXc7ZvT4lyo9VMMxVT1o2R6
VHknTtqCFdVh8ivRxSpydRsLSNHMKqml5khQLcrytjqZtqGqu7WuT6M2ahsM
HSp9W62ho3a4p2W0r82oU/V11Q31No0YW4z6+m5NbWdrlU5ba+xtBtJ21ra1
V3Z0VterpbLKXImYLS5kykszlZV5tfK8qrKsmmKeUpqplHJVJbzGsmx1CVeW
Ry2ko4WU2Ho+09Qk3zVqtnraQPkFCK9rGk+mjGfAdmf6DyeNQMB8Ab/fHq79
/OTgF+CzT49/enL0/cVVhz2YNy0MdI91awa1LVpVlbZWMaxtXRjqO1ya/eHi
5NvT45+fXACEL7c2X+9sP19fe7q6Aibvj/ffHu6C8YeLs1+eAxd+8ubo6MXu
3rPtvbP1reXRyfpSOQGOsr1n8fUfP7vx0aeOt+4jfYOKmJxupXpK3zvSrmmQ
lhewMjKp9Ex6akWhxNhpqCguS6Mx01MzeJxsFjUzg56FhGGw0fhcHj8elRDs
B8lgZSpkdU0NndqOAa1meMC4tL764vzkrxenf3v57B/vX//Xm8v/BBZ8cvjh
/OT744O32xvPlheOZ6dANQet+Xxp/mR0cL1XPwekNyx16ua79AttHVPVyr7K
KoOsUl9Y1ARUJGkpKdOIxM28LAU/X1Uu6wJS1HTJFJqKyo5yeWuZrElSWpsv
kuXki7k5Agabk0SnU1LpVzk5NRkAm5yaBEagRBoxnowD2MZgo5G4GFRCHJgA
ZgG5kMiQMAT0mt9oDOL6ODNA9br5ApMFkIJFwC8YiSk0AC+dk8HgcsCEQKOS
6GlYUjICFx8WhwyMgXrDvbxjHQMSrCPSHjMUgYW6aL4WRq/2QmSbQVn34vj2
kfyvQjM/CeX+BSH4mlBqxqhxyGryytcEiruhgo4ATqNnWp0LTelMktuixGZR
/Ns4oSNdHpJSERYvDEDl+kVnX121RZD60KsCYnIe+ZE/8U/8MjTJIpTgGJ4Q
EJ0UyW65x9c/TlPfiuX/OSrjFjrTg5AXTi2KThKFEAq8kFmOGIEvTR7LUuHS
m1B5OmzxVJZwhJ4/RORooVmdAVE5n0RnfcxU2Fb2wmv64qTtYaXt0PphZN0w
VGH0aZoK6ViNHzrKrRnBFXU7lA49kvTY147hDBs5HUv0/JZwmhhKzoemyV3p
VZ/iJf9PuupWXptrptqxoD2gvPvqC4zyrvhqHUXeRilWJhbKCGU1tOqG9Go1
G6iihi4Q43RN9fpmdW9782BXx6iha6ync6RbM6Rrn+jTTQ3qgSYHdAvjxs35
sfXZkdkRg8lomBzsnRvrX54ZXZufWJgZMY0ahoxXD5zWtCpb1bLm2rLOxqr+
DnVPs7JFIWlXCNsqC5or+C3l/HZ5gbYyv7Ukuz6f1V0pHFWXr3W3nIwaQH5e
bKsbqS7tKxeNNsrnu9Rbg1cXUK0PaLeGdWcLY+/2lr8/3fnx/OCH84Pvzw7e
Hm0fL02b9O0diooacUFhRhoNgyTFRKbi0XkpyXVi4VR355P15dd7W883V4/m
p/emJ9aHB5aMPVtjw6/3twG/bw72gPP++OT8b5eXb49PDheXzte3XuwdXu6f
LI1MSTIFYd5BPvYeUQHhsQEhtFiMJIPbLleMtmvGOjQdCkWlQJBFpVHQ6Aqh
SC2vLhUW5fFy+Dw+QDgtMY2CpaSSGJyUjOhQ+O2vbt775k54SBgencCgpbPS
stlMfmmxemRofW/7w/7Ot8+e/PX1y/8Eifry+d9fPPvbq5d/f/H8l9OTdyfH
bw/2Xx8evDk+/LC18WJyYnewfwXINHU4PLo9OLxp6F1qbZ9o10xqu2aaWkbV
jUMtbeO67vm2DlOFvLOkrL2ySi+r7FKqDHXqXqDq2q5yeTPgt0haLSquFEkB
xYXszEwmNyONw7o6VMVOoafTk1ITE1MSsCRUDA4eERsGQ0KjULBobBQmMQ6s
gJdQREhYNCQyLhwsIuMRwHmvc/L12d7rA86gC4NQHROPA44MbBe04/++zCOB
TIlLIMKxmHA0IgQFCYjzDCK4hKXY4QquzFfaj+I1BxOKHaNzLGNy7IgSv5j8
h2G8ryGsz+FZ3xCKrVhKV35roEQPkxoic5r8wEu2yitD7ZdS5YYvscWIragy
N05DOKc+Nk2BpZbjMQJECMPNl2JGqfBH51v5JH7kEvd7H+xtt0gz93BnRCIy
V/+Y22FOlt2MybsRyb4fTDIPJNhGpnihuD7R6c5hadZxuV5sFTpXk5jbiRf2
EgSD6SVTmeXTaXndUSCWR2X/BZn1iaDJp6YPWaaJKmqElHeGNY4jlKMBimHn
pgVv7SbOeMBrnqMpJ8NlY06lA971k0mqCWqtCcNVuSeJPZOLArMbfXM7HtKq
/sxtsEqrtMlQOhe2Bks1UcVNMbI2Ym1HqkJNL6+miYoTpSWUSgWzqpqtrEuv
rEoVivDDOt2IXj/e0zPV378wPAw0O9A/1dc7PzQ4bewZ03eaevRrprGT9cXT
jaXdhamNqcmdudn9xYW95cX91eWdpYW5scEBXcdIT9fMUO/sYM+4XmPSaeZ6
uyY6W7uVlcb6MoOyuLOyUCsX9iiLR5orpztqZ7Wq7QHtRl/7Zm/7Vl/HpqF1
ob1uRFnaW1HYXMjrVYjntfWbxo71vo613va98b6ny9Mf9td/eXr8Hy+f/vLs
9M3+9uny/Mb48LzRMNzeXC3kJ0VHhro4+NlYhjjZpWHj2mSlJ4uzgN9rhC9W
F/enJgC8R7NTz7c2Lne2Xu5uXz2HZXPzcH5+fmBwsL1jXGfYml54un2wNjGn
lFSwSIz89NyO2paGMlmzTN5eVd2jVo9ptTPdetCp9coaWV5OGg5XLSoS87L5
bG4BNzefl5tCSklGk3i0jLrSalGWwM3a/vOP/mh1776bg4PDYxsfd9+QQBgc
hmUy8pvVA/PTJzsbb0+Pv3/+9G+vX/7HlV794+2bf7y8/AUEh6dPvr04v9LZ
6bfg912YO56e3J+bOVpZeT4zc2IyHQwObuh0cwbDYl/fSmfnjF4/39Y20d5u
6uiYbGoaaWwcrqszlpS0yau0AGF1U1+d2lBR2QL4lZQqpeXK4vIqoaQ0WyDk
5OSwM7mAX2paSjKDmpxGItLwKAISYBsKDw6JDIREBQFm4egIgDOYgEXAL3gX
4ByXEHN9hBnYLui5wIUBwuAl4Bc0YlCEAd1g5frr/FdfBCYlxmAw4K3wOHgY
KiIEFRSI8wxNcopkOyaV+Up6MaWDmFSlDzLPMoJjGcW1R+V5x+a6RmTYhqVZ
RGfYJgjcqcV+bHlIpjKMWRGAzbaBs83i+Y4UqV+ixDe+0JMo8U2pdsluheVp
8LmtKbwGJkGM8UlytkF+jchxjMm18iR+bI/4NzfkVzbBXztDrBMziKJh5/QW
M1zxDWTeHQTHwo/wwB//GMUJjE33ieW6x2S6JIr9slti+Z2YHC2ywICmNaIL
h+nymdSCXoTQEILM/hSXd6NMF1HXH1/aFl3UECbTRdYMhVf0u8rH7Ns2vNo2
Yrq2UjWrGa0rCbIxn5L+4OrR5LwWWHFfYGazHbfeL6shTGwILui2piq+ZCrt
6RU2vBrPotZwSWN0QXV0SS2hUkWTlpLkMmZBXgI/GycVJVdVMBtqeTWVqUI+
aryn39Q3OD0wMjc8vjRiWhwemzEOmgx900bjeHf3cCfgt2dzeup8c+Nia/Nw
eel0aeVsbf18feN0ff1kbXVvYX52eNCoaQWwb02bDudn10cHgdOt9fct6nVj
TY0D6vLuanF7Gb+tOKeromCovhzYK4B3pbt5Sde42NUA+u9SVz3QvKZ2urVK
X1YwWFOyoKnfHejcG9bvjXSfz4y83lh8vbXy3eH29yf7bw92LrfXL3c2Xu9f
2eizteWx9pY8Chnu6eJlcT/QzpJDxA40q47mJ1/vbXw43n1/tAP0fHP5fGXu
cnsV8PtkffXpxtrZysq0waAUiYCTsonkDFJylUhqbNUOtOtbFarakipNXeuo
fnCmv39+aGhpeHh1bGzLNL45Pjxj6BpsUmsUFUphASC6skAIsnR6cgqPzmYl
0TmkVHl+iTA9Oz4iOsLf38fBwcnSPMDDzfLuPVsLKx93v9goXCotp1Tc0KOb
X118frD37vz0R2C+b17/+/t3V7fKefP6ry9efH95+cPzZ99fnL8/PnqzvfV8
dflibeXp9ubLre1XyytPFhbPpqYPhobXR8e2xid2evsWBwZXwU6ouWVYozV1
dk3pu2c7NBM1ym5guw3Nxo7OsTbNkKqhW17dUiZXl1fWl8hqpBUKcWlFgVia
U1CQnsWjMVOvzvwmodDEmGhsBAwJCYUHhkT6B0f4BcF8wQQSFQBWwqKDwVtR
qLAYXGRcAuL69O61ALnAf6+POQNskfj46yJ87dGAbtCRYdFwaHREWBwsHBMG
wQVAiO4RDNe4HNf0eqikH8PXRcYJHwemfBNAfQBh2EQw3RHsoEiGLyzFE5Hm
HcvyRbE8UWx3bLp7DN3BB3XLOfIz//iHUalOMemeKJ4/Ph+KL7FhN4TkaDC5
HeSslhSCNNY72d4aedM14XZomnkA5ZYf8WYg4YE99CuPKPO0wgTRqENq072Y
ws+ism7BuY8hFMsIhjO9OAaR5hGf55ck9k+tCsxsCeU0BqQ3BfB1EYlKaI4B
UzaRkNMZlNnqGs37E7nwbnUPqmEgubQFU9yErOhEFmn8+B1W5aPWHbvedYuQ
llVKxzqvfSOlbCRU0htV0ktKlDrwdU4gt4v7AvM7Q/M63dlNd+OLv0yp9OA3
BPFVIQWq8OxyaHp+CF8cKy1NKhQQS0Q0DgPJSooUcLByCa2xmlNTTs3jRA13
9Y/q+yf7RuaGTAsjU3MD4yZD/7C2e6LbOK7vm+rtX5+YOl3dAPUQMHuwsHi+
vHK2tHyytHS6vHywsLA5NTE30Deu7wTjztT4VVidHN8avnri9vZA31q3ztRa
3V9b0lGSV5+frshMkWdQlNmpjQWcdknOgLJkXlu31tO80de6Pdi2P6o9HO3c
7m0Fdnx1DTOAd1C33X/1Xf5Xq3Mfdjfebq+/2Fh+uroEKu37w4P3x4cA4cu1
pc0ho7aipJhJzyLgOAmYylzehKblcHb8cmv5zd76673190fbr3bXnm8uvTvc
+nByBMwX6Hx1daClhZtIDnVz97a287Gxj/ILpqIJAiavWlTRrmw2NHf1tOhm
R4ZXJ68iB+ii25NjG2NDi336yc62qa72aZ120djXWFqaS0+j44jkODwhGiPl
8Nl4MgoSFubhGejsBHF3iQryiwkLDvR0C/X1QyFimbQMQWaxVFTX2jBoGt5Z
X322u/3q/PQHkJw/vP/P7777jw8f/vHu3S8fPvzt9eufnz4FDR609hcgQoPN
AOzrG88Xl86A5hdOJqf2ZueOgAaHVoG6dFM6/bShZ07bCRCe1HfPgEl9i7FF
O6TpHgdq6jBW12vLqhqLZbWi0spigHBltaisIlckTs/NSWamAQ8NjwmBIoIA
qtfAXk8AwkBgfg1vRGwo4BeBgSHjo0Akvr424zo2X182+d+ODCI0CNJAwIsB
y+HImJCIEEgkBBIDgaKDITjfkES3KKYzWuCap40VGpAUhYdvyhcO2D97Eu4G
UuzCGV4win94sh+M4htB8QpLdA7CWgWgzUKwZqHxZs6wzx8HfuQI+8wX+zCE
ZBtJd0WyvRGCByRQJ1UhDBWMUYfAioP8Uqyd8HetYr7wTbaM4rjgcn1jOa6e
qJsBuHtpYphozCat9R4i/7OQ9C/D2A+DaY8AwiiuVxjVliDwTZUHsZXeabVO
yQozRq0tMNwMbVR2d2TxSDS31SVFcR+e/m+MUguFLra+j1bSRChuSihqRqbX
OLNVD4oHH9evu8invBoWE5sXueo5mrQ/UtKDFuvImAJLkdFRMmJZOuqV2eqc
qnpAqf4CX3wnvTZCpscIaqFsiR+F50FK9WDzIoSChPxMQi4LR8VCk+MCucmR
xdn4aklymQDHoQQOaPqAy0z3TyyNza2aFhdHZ2eMo2M64/zgxMLQ+Lpp9nBh
7cnG3tPNfdAQT1bWn6wsH87OHMxMHy3M7c9Or44MLA70rgz3gzS7NTG0PT60
PzFyYho9NY0ejw8fDg8ANhc6VWMNcl15gYJLy8Ej0hDBqfAgQWJsiygT8LvV
377e17RhbD4Y01zM9ryaG35q6jsd69nr1063KLvLi3RlooFa+faw8Xhq/Nny
4sut9bf7e9+dHH97fPJmb//58vyThZnd0cGVXv1yj266s3VK27I2YDhbmgb8
Pt9YfLox9+Zg7e3h+rujjV+eH/309OK7s6ujW6/391dHRqryhehQqLvFY8d7
5rZ3HrqY2cC8g5KQCVl0TkVBSbNCPTU4sDo9tbM4vzE1Af6lsz2dc4bOxZ7O
VaPhYmHGpNWoisQZhEQ0JCLKD4IMhrGwiV5mNt6WNgF2drc//sj2ztcYWEg0
xB+LgCViUCwKg88TSApkMklDXZW+vXF0cGhtwrSzsnp+dPL2xcuf3r7/+/vv
/v7tD//+4ft/vHr70/mT9/uHlzt7L3Z2X+7uvdnde7uyfArqy7WmJrfn5w6A
hoeWR4ZX9DpTt36yt2dGqxnVdIwYuqd6DNMNbcbG9v6mjoFmDRiNtU1d5dVN
RWXVOcISoVQmKpPxxVIuv4DB4RGoKTE4vC/EwzvYzTPQBYz+UC/gvECB4T7X
FgzQBrqmGPAbi4dfN9/r00NA15dDA6ivqi6VArwYpGVoNAIIAo8KioAFhf8z
kMdCYLgQaIJvKNkFnuGCE3rkdcZwmiExAjMn/B8dcZ/5ksyDKa7hdL9wijuM
4h5BdQsn2wdiH/jE3PCP+zos4XY0xSw04aZf3Ge+6C+CCbdgKRaINLtotkNE
7kO0xA4jtUVJ7fEy91ixU2C6hRfFzJ1o4ZfsEJsVTC9BEgWBUMqDaOYDdrlP
Tv/91La7MUWfh/G+Qefbo/ku0BRzv4R7YbTHiUJvZqVfapVDUvktXPEnNOX9
4sFg0UhMTndw2QSM3+VCk99E8n7HkduL1OHVWoqoNqGwLiG3BkGR2tGrHgiN
liUmS/Gwfe0cXjGWIjXi87siRHpcYWdyvNimcMCmYPCbXMN9suJrQsVnyTVf
kcqtMhviSzrQTIk3IcOBkOpCpvuw2ZE5HExWKpaGhuLDvRMjfVl4aDY1QshC
5DBCaVjn4a4BU+/Y4ujc1uz63uLW9tz6yujcXL9pZ3YFaH9u7Xhp43Rl62x1
+2J999nWwavtrbPFBeCz5ysLh/NX/K6OGg/mTccLU1tjg+uDPfvjQxczpicz
prOJ0ePRgaPx7oNR3c6gBkTlbllhSSoxPRZKjwyghvtW8VImWxTL+gZTi2y8
qXTFoDoc176cHXo2aTwb7VnXN+ul+YVkHDsmPAMFFyYRWySF8/ou0GSPZmdO
FxeerW+82tk9nzadAsfv710zGo6nxi7mp46mx05mJ7ZGjNsT/atD3UuDut3p
oZMlEwD5/fEmIBfw+/35+XdnZy+2t6e7e/KZrHBPH5eHVlbf3LW+9dDDysHT
ytnTxhX8eQo5giGDHvB7urVxtLK4PDowqWsf1zRNtDeCvcSPx/tzBl29WIIJ
CXV+YOlv55Ych/d4+Nj2xu07f/jjl7/5zTe/+zezLz9xtbzn72IH+KXE49hU
Oo+ZWZBVXF5ULy9uLhU2NjUPAZccHlldWTs9Pn3z/PKHN+9/+fD93968/+nF
q+9Pz9/uHbzY3b/cPwDwvgHheW31dH5uD8SB2ZmdSdPGVS6Y3R0aXJgYX+vq
HO1oH9TrxoG69RO9PVO6rjHAb12TQdnQpWrubmzvU7cZFKp2qbyOxxfzi0oL
iiuyhUWsrFwqKyM+iQJHYwG5bn6OTl62zt527v5OPiHugGggwHJAmPc1zsCL
AcIgY4OkfX3wGWB7Dex1+b22cjABXAPnDUXAgyMj/MOg3iHB4dFhkXHhcDwM
SYYhKMFwhg8614dc6sdpDqdUe0J5t1wIH/tQ7oQyHEOpnlCqfxTdOYruCE+x
C0sy88d+5Rv3lzDil2jmw6RcW1K2NY5jFsu+j+KYE/n2xHwnfJ59dMHjuCKb
yIIHMMFdVMnjOKkNJPORX5oljOsbQPWM4UKpUjSBHxDNtiQVWOeofFM1n1Kb
bqCkN1Aic24jLL8DmyTxgyQ/hDPtksV+zEofmtwiofhTVNHv6LW3y8cCpeOI
TJ1X5Wxk2ah/ev19vODjzConbplvRQuJL4/Pq4zPuHoimA296hG/x4rfd0fQ
a141hREbCFktUSCH52txQi0lsdSep73DbP9Nct1vo4W/wUh/T1HeSCyzYVWj
c6ugCRwbJMWcxPJIy4ByMmK4qbFpxCgc1Bsd7Ar4TUMHM7H+rAS/NLxnIsJ6
RD80OzR99fie3dPDtb2FsdnJ/vGZoYmrWyKv7RxvXOl85+D54SnQk72jf15z
OHMwN7U7PbE5MbI+NgScF0yAN5l0momuDkA02OBkaQ5sszdj2hzuOZ+bABl4
rl01XCXtFGbVspIqUxI6+OmGEv5YvQw0Yq280NAgmx/Sbc4O7S3P7i/N7C5M
LQ4bB1oatFUyeV5WGjYO7u0e4+eVEhetyM8d03VszowfLM8erM4fz48D7U4O
AlTXhg3rIz1T2qZOeXFdQVajKE+Vn6XIYtcXZI+oq3eGes5nxp6tjbw/mP/+
bOPN4frJ6txYj06cm4eKRDjbONuY2T66bWbzwNrLzsPbziPIyTc2OKpWXrxo
GtqcMy2NGbV1MoUgU6so7ZCVLPf3vtnZW+oflOcVoiEIN3NniHsY1Cvi7pdW
33zy6PbnZjc/e/DJ7z//7I+f3/nimzuffeVoZhbl65uOjy/npKsL8jul0p6K
sn5ZRbVEXl2saKxqWpzdXl87W9t8vrz14vu//59nH/7r/NXfz178vHX47OD4
6enJk421zdPDo42V0/Hh5RnT+voy2IluTY2vjg7OaduM/T2mHt1oZ0eftr3X
oBsy9oz16Ic1bd3q5rbG1o76ptbqOnV1naquoVFZr5ZX1wgKhXkF+dn8vPTM
jGQ6BYkBjhgaAAl0dHNwcLV3dLF1crVxc7f39LT38rIDgkA8/QNdPH0cPfxc
/EK9Q+CQsNiI8LhI8MFYbByWGE9MoRAYKTg6FcegxbMYmFRaHDURQcRFYGOg
SFhwVEhguJ9fqKdtyGNvpGtgvDOU7Bib4YbP86QUB3LqkJy6ODTfN4hqG0Cz
DWU6Q1iOoWx7GM8RmeSIotnDk+8EJPwrhPY/sMLf0JS/p6t+w2j81yTlvxDK
fo0Xf5RQ+BVB8JCYZ0PMtQc/EJX3AJn/MUbyF4z0IYLvGsT08kqxg2RZB3Du
xpcFoIWRMVkITH44Mu8xU21HqoNFVzzENn7EGv2UO3aLbbBltXqxan1iM25R
BQ4FCgy/jJKSi+Yo4GJjQF7v7eJhn8I+H6E+uEgXxa4KAPsNmsSZJramFT+g
l9+R6Fx4TRYslZmoJ5Db4pVS7ZLXxZTP0pntbuxWX2p1RGYLKacjJrHiDq/V
kSbzJhYExXLtaGVWWQ0OSWJ7Yl4Qq+QxKfs+lvkoKcM1lRdKTQsnkUJJeCgC
6oKBuScjA7iJ8FxybEpkIDnUnxMHXzEtbc6uH6zsHa3vr8+sTA1MTPSNAn4P
VrfPtsGfzgnA9sXR2eXxOYAXsHyxtnK+uny2snSytHAwN7M5MbY4YJw26I1N
DT1q1UBL00J/3+70JIjWO1OmLdP41kjvzphxvU8719EwoZLrJHntfE6PJHdQ
VjjXXLOqb17oapzQqmeN7Vtzw+e7i88Otl4cbL082nmytQp2ESCZT+o0+toq
WW4moBgV7J+KjVOXSRZH+0/WF8+2V59tzj/fmL9YmT6cHQUUz/dq2koL86kE
lJ9bjJcTws0+ysUW7mpHggbIOamjDTXrg+3Hc8an65OnK1M7s2BPZeyoVwGf
T45PxMfgIgJhIR5BIZ6B/k7eUPdAfASqs6l2Y3ZiZ35ixqhTFuVlkuNLeUxQ
sSc7O0AMmDX0NkhlGYkMfAQWH5UQ6AKxN3e3uGNvfsf2/tfmX/zpxhcfXX2/
7/M/fPTFb39rf/cu0s+Xh8cps3m98oqhmqq+8rLyvOJqSaU4R9rbOdrdZeru
nZtbfrJ19O3J878fP/vl5NnPmzvPDg6en52+2FzZOtjeB/xOjq1Nja8vz+/N
TW2ODy8O9k3rNIO9+rGOlt4mtbatWd/dNdjbPaLvHNC09QByAcLK+kZZlbJM
XlVeqZCWVwjFEkBuZm4Om8tJTqHF4VAh4RBPPy9XLzdrh8dAdg7WDs42Lq62
Hh5X8Hp72/v7O/uC/xR/R28/Z+9Ad/9QP4BweGxELBYJ+MUQcHgKGZ+SjKEl
Y+nUBCYDn0ZHp5CjE7EwDDwUGRYcFXR9HMwP5QFLCoii+UUxPNA8z8QC/9SK
cEEbkV0dRy6OjMn0C01zDWO5R2Z6RPBcoekOGBokkugGwT2KoN0ni60zG52y
Wh+nqW9Saj4lyT/BSz5B5X0BZ38dmXIvkmYVnWKPyvSAsW6Gpv8rUvgntOQR
LMvBk2Jnn3Dfk3E7jG+GLfGGZwcG0339KXZQ9k1ajXlibSBeZUbq+Di5+zck
7R8pbWbUOrf4QnsY7ev4DMvs0uhCRQq3OCFHFVU86C0auSns9xT3Bxb1hOW1
htLLfOglPlk1oelyD7LoAanohqDdMV/rnNPmLOwOTG/wSlV55+noxeMJSfWW
tHpnahU0T5PEaw2PE32S1+maVOaKyfZCZ9mnKuy49TZEoRVFFJpWZpeQdT8u
9X4C24nKC0piQglJIQkJQQRcADbGnYT2ZSeGpcWHkuH+VERQOg6+s7B1rY3Z
1fnRmelB09LE/M7i+tH67tP90zfnz949eQH0+uzpxe7hwermyerS8cri4dL8
/sLs1rRpftA4pGnTq+t09bU9TerRLs3y6NDu3DQQeHdzamLHNLQ61DPX1TrT
0TikrKjlMspoCQ3ZzM6inIX2uk2jZnNIfzg/drA0cbQ68/p8992T47cXR98+
PflwfnS5swGs/HBu6nhhZmXI2CYrFTLp5Tm8wY7mo9X554fbT/c3X+6svtpd
A+PL7RVQeHcnh3U1FeI0KtThseudGw5ffep+52u32zc8790khPjLeeyZrrrt
Mf35yvj56vTJ8sz+4tz69PTc6Fh3m6ZN1VRRKM1jZ3Ioaan4JC45pSynYNyg
3Z4b354Zm+3rVBbmZiSgCulJldkZ09q2+R7DhLazV91cJ5FVFVaU8UsJiIQk
DBUFw0YFwwPdA+we2Zjdun/vy6++/MMfPv3Nr21vfh3h5kyPjqzOzBiokhsr
yuqzMlIwSXQsFQlBVxQpS4pUFWVtpqnjqbknO0c/7Rz9cHT+887u6+OjNxcn
bzeX9w82jkFrAfxOjKzMTm5NT6z194Dd25BeO9zVMVCv7KiSNQKEAb/AgoER
A5Zr1U0A3sqaupKKyiJpmVAszc0v4GbnZPMFvJzsVDYrnkiARsA8fD0dXB1t
newePTY3t7awsDG3sbd0dHrs4mbt6Wl7jbCfnxOwYN9AZ4CwT5BHcEQADAmN
Q8fEoKOROCSKiEOREmIT8ShKYnwaFc+koVMSAb8RWMBvKOTqxFMgFBEQRvJB
sUMxnCBkuieK64HOdicXBXHrsFe3Ha5PZijwOGFETG5wnCAInu0RQLeKTkLC
CNAoanCSEC5oThB3x2e2BFMVdvDcLxG530RybwYmf+WC/Nwh4oY7/JFfnB2C
5e5H+tKH8utowV9QYrNgtoUt7o557Kd2iX9ClVjHSa6ejOlOtLKN+yKU/UVK
7SN6kyez0zq151N866/ilP8zqcGcXOkWxbaAkG7Ckx8w+CHCyiS+ApetDhD0
PBSM/iFX71nQGyjsDk+t9k0QOjFlEH4DPEsZRCu2wRfc4jXYFxn8RD3BRb2w
3E6YQBcjMCQXDEYnKG6TaixTVZDSYUZeFwwt/kSgcyWKrWM4dthcW7bSIb3W
Kl7wiFoUwq72xAsso9LuI5m28RzvBFYggRGcyAjh5iJxeBcMxpFM8MKjXElo
7wwKnEeLvb4b6vzI7LXzAn4ByKdbByeb+y+OLj48e/nt81fvn17+N797C/NA
27Mz65Om+aHBMb2ur7VF36AGk2lj3+rE+C6oZ//cYHP66mTx3vTE1sTQcr9h
trOtt6pMmpLIQkCzUZHSFMKgsmLF0L5vGnx/svP6aPt4c+HNk6PvXpx/+/zs
A6D4ZP9ic2VtdHB1uP90ae7J2tLu1Diw463p8afba+8vjgDpr88OALyv/3mQ
+e3B5rcnu69317bGB0ba1GWcNBoiHO7uGOXmgHBzjHZ3SoGHl7DoRlXpnK5x
f7L/dNF0vjYPftSz3Z2LnZ1n+4enm9tL46Zhrc7Q2NJeVa2tqhlp1ywMdK+M
9K2P9q8M9fTWV1XlcoFapIVLPbr+BtVoe8d8X/+IpttkuDoG2Frd1N3UVV+u
LM+X5rJ4JBQuBgIN8fBws7TwsjZHB/uycEgxg6KVFk41qfoqJOV0cqxflKeF
u7OZG4eax6LmC3Kq9fpl0+T5/MLlzOyzjY13O5vvjvbe769fzo9v7q89mZnc
Mo2tXd9AYGx4Wd810trco2nvb2kyyMrrS6VKtUqr6xzQdvQ11Gtqa1qqqlWV
itqy8kpJcVmBUJyTm5/B4aWmsbi8LA43M4VBR8bF+vr7OTo72djZPraxumf+
6IGludlj88c2FtcIu7nZeHva+vs6gFASGOQSGOgaEOQaBPGCwvwj4MEIZERE
dHhkDAyOgkego2GY6KgEVFxyAhAyCYtIREXiEOGo8PC4UBgKEoWGRKV44LMg
xLwQYL7IDJfINHskx40sjhK0sIp1fKlBmNfKSa1OJBQj4NlegQxrOA1LyqNx
q3iC5swCbXpOWyJwMWSBnRv5Ex/qVz7kmw7IL8yC/2we+KUTzNwnzgVCdXGP
B/x+FFt4G1Ns5Z/6wAZ3wxb/qQfjL+Rap5hCixCWhS/VwiXhC5z4UZbGDvCY
ZTBL7/6Y1PKreNVvU5rtqYoARLpDTJodkmqbnBkAWm1hAzq72YXX9afMgV/l
dHlnafxzO6CJxS4xXGuy2DetIoQpAynCnVhkxlDY8dv9xT2RslG8bDy5fCQ5
vwebrQ9AlX2Cl92k13mDRb4+JFH+VWa7dULRI2SmJTbP8uo+G2rreMEDosAj
oyGIKHWJznwcnWEP+gWa45OYE8wURYlqEzA0+wjsAzTRGol9TKH55+Si09nR
1w/xuXqmrX5gpHtwZmhya34dwPvs4OztxeV3L14DeF+eXIAgfbq1t7e8vre0
tLu4uDk7uzQ+PtXfP9HbC8a54eEVk2lrbu5gZQVoe34emNra1BQQsOCrmD0+
PNnZ1l0lk6WnZeKQPHS0hE4eUClW+7uP5ie/f3oMgD3f2/zw4uLHV89/ev3i
2ydnb04OLzbX5o29E1rN9sT4y+2tVztXF1083926PNh9e3r0/unZh2fnL/fW
3uxvvDvcen+0DfgFI3Dh08Wp9ZE+gJssk51Dis8iYotSKfUFud2K8vHWmoXu
1u2xHtCan28uAza+vTj97uLi/fnZ29OT8/X1vbm5vZmZleHBmW79orFvZ2J4
0agDEWJvYmh9sHukUakpK+qSlUx3traViEdaW/ZnZ9cnQNKYPd/Yvdg+Ol3Z
WhufnO4b6G9vb6ioqMgXFHLYGeQEVgKqLIvdXiYyVJdMtdSt6luGq0ur2ZSk
SJyvpTvEOTgOgoX5oXPTK+Rlndr2+R7duk6zPD5ytDD9ZHn2ial/09g+tT51
ApgFmprYABT3GaY0bYOA3Ib6LoW8qahQLswvr5Q1NDfq1aqO8lKlSFheLK0Q
FZXkF4CWX8Dl5dAZrEQSJR5PIJGTKdQUQiIxDBbu7Opi+djKzML8kbnZHQvz
e1aWZtZWlrZW1nYWdvYWLi6PPd2tg/ycAn0dA/3sQ4Jcw6FesAhfGMwvDOYb
AYdAYYGQiEBIZEgIPDQYHhqGikQkxILYDMiNio+OjI+IxIVFYqBwXFgMIRzD
80wuhCQWBMZxXRAsexjDLobrTSlGSXX5cmOpylSnnlGV9IlSqwnYonCUMIgk
ThG0CcuMJQJtFludSKtFYqS+gemPXEifeVJveCR9Y4/+zAb+qQvyjn+CTSjZ
xQdv746/DWF+jS+1xEltgth3fVLuQrPN4kosWK2esWLzqFwrRI5jVLZlRpOH
eMC3yOiW3voVtek3tNbfpLR8mdbkQldA4nP8ybkhSZkBKbkhORVISVuMUOeQ
1fPb7JFf5fdCWU3evDZIgsQlnGWGzHJEZTsmFrmTi11IEnuqHIRnSMkAum6e
qV7mSfrJud3hjEarqMJ/iRH/Mb70QZ4ulKm2ISk+Z6huJUrvxRdY4QSP0uus
Be3OiUUPMVnWVGUgscI3vtgnXuKPEfqi+T5J4uCMqkhBY2xM2qNw0jfoNEsM
w5aW6Z+WC4sju/a194zohyaNE4DcZdPCweru5fGz909f/RPet99fvgERGjTf
k81dYL47i6t7K6tbC4srU9NX90YeGp4fG9+cXzhYWwc63917enB4ur0Dttld
XrnWxtTUztzs4tAQqMatFSUyXno+hSSkkoCLjTarN8auDna9PNx7cXTwZH/3
3fOnb56cAITfXpy8Pj54dbgHOAIfnOsxPFldeba5/mJ783J/B8ALyAXbPD/e
Ax76Ymf13fHO9xeHPzw5+uH88LvT/Q/Huy82ll9urZ4tzqz0dU9pWhcNXTuj
gwem0Z3Rnu3hXqCdsYH9qbGTxemL1cWLtaXT5UXw859urDzfWnt/tPNqdx18
9mxp+uXa4v740Mn0+Pnc5PnM2Ga/3lgrN9YqwK6gVpAz3tF6trR4vLgIqD/b
2Pjp8vLF5sbx4vzh/Cyo/2DnY9JpRjRN3fVVDVLhQFPNXHfLnFY901473VSl
k+bKGIQcAp0cjqYhEv1tfW1uO2XSRdnMUhG/Xinrbawb69dv9Het9LYvdNaP
NVX2jHYtdWlGdNrRkcHF3u7JKnlrjaJdreoUixRZvKJ0Fp+VlpvFE4mEsqLC
ikxuAY2SnpGexUzj0FNYKbQ0MomKisNFwBChoWEREVEYDA6DwUAgkP+fprdw
amxb1H3X2efuu9dee1kbTePu7i6BhBCSEHf3QIBggQAhuLs2jTSNu7u7u0PT
3r3W2fueOvfe9/6BNzhdr+qrUYOZyQSq+I3v+zIlbm5udnZ2NjY21tbWRlY2
ZsB6HR3tnO0dnGxdXGy8PewDfBzhELeQQGc4xAUV4onHBJIJUAIWgkH7ozHQ
UGQgPCwgBBUEQwcFo6EIQhiGgYPh4KFkBJIWhqYj0PRQDDOUxEPTRBhepp84
D8JM80BHWSEirAG/9NTQ+CppUW9+8UB5/Uzj67W2qqmKlDdxsQ2C5DfitJ6k
zJE0ZU8sv5pIKYJSiyHoTCffaF2/GF1InB4kRs8/Qjso0ggdb4uJtw+VWfkw
7QIllgSVnaDShVlkj1Sa4NQ2ohqvuDb/6BYvfoUzv8yHU+grLPFWdcHzRmG5
fR6RNU8FFX+Nef1M3moWUecqLg7ipsOY8ZDoDLQ8EyXPgaa9Cs4ZcFKPP1LN
/VAwRYhtCUzpQLMLPMNiLQhK5/B4W3a2NzvHXVYZmNQSVj7Fb1iPbd1NadlJ
U/ey1cMQQZ1ueNYPpPyfyHka0Q0OzEINYeUzcbWmoNiAX2DNyjSOq7fL6PAS
5lvQU6xoRX6MokB+ZWhkHVZchWIXQHhFgdG1sMhKH3ySPi5Bl5dlL872EGf4
UWNdfQk6gFyQnw9X90+3jm6Prr7dff7fX//z//7xn19vP/zrwzfgv19u7kFy
Bvxe7h09ILy1u7W4sjQ5szA+tT63uL+2ebqzf753+Pbs8vPt/bf7Dx+ubm9P
zr/r+ugUcP3wFMfp6bm+vsHGxqp0VW5cdGWasjRFMdBQuz87fbOzc3t0cHdy
/P7y6uvb+9vjwz/fvf10dfHx7PTb5eXW1FRndXVvff366Chwuk+np8Ar/+vj
h//18f2n68urg73zjeXrnfWPR3v/urn4P+/v/p+PD7cH/t/3d9/Ojv7r7fX/
eXvzx+nR/fbG7cbq1erS2dwMIPdwYnh/bHB3bGB7pG99qHdtsAfoYHb8dmvl
w/4GSOD/eXP6z8uDT4cb3462Pm6sXM1Nfd5au1uaO5saOxofWGht2ujvaivO
BSkafOPDqbSdjbv9nbP1FbCwvNtdA9SD8X577Xhh6uHpWzOj6yO9Cz2vt0e7
9sa61rqbphvLh8uzmtKiSiIZlYrUknilWiJnwHAwF0gMN07KkMdJMtLiihur
Boc616oLugrTXlbmtJamN9YVtBUXNBTm1Te/6i8pfMVjy+Nj1QBeHieaQRMz
6RIqWUAm8thMiUQUy2VH4DB0GoVJIlCJeAqVzACTsFB0UGBwgF+gl4c3EhFG
wOHhsBB3VzdHewcHe1tbGytDywd+bZ2dHVycnV3s3d0BvABbNwTEFQVzw4V5
U7CBDCKUTYEzySEMEiwcGwxcGIEOAHEauDAoxQ9XV9IxMAw0BA+FE2BwYnAI
AYKkQkkCFEtGFOR4ivN96KlOyCizsEgrVLQrLSU0qlSU/SY3t7M0v7cyt7sk
/U2GsjU+oyehaFypnkqM75MKGin0CgQu3z9U7RystAxUmISkWiBSLREpZhiV
DbvIS1IJYWS5QiP1oDJnjNKVXeQhrHKl5pmj0vTIeRYRDZ6J7YHMYsuYpkDF
awyv2F9c5p/YDM3oDc1r84mtNImu0U1qNZM32YornHh5PmxVYAjLIjYXk1yM
F6Z5yIqcVF12meM6mfO/5k8QFe2wzEECPdcZFmPIyPWkpDvzC/24+V5xDYjM
fuqbfWXbQUr1UnTtSmx6Ly173Jdd8Rib/QO78ldu2XNZgwk5+6fIly9E5c8Y
OU8ZWbqMDJ2oKktgwawMQ3aGJa0ggJzjT8uHCCvCRJUIXkmAoMwnss6HlW9O
y9JnZhuIiq0jSlx52S74WEsoT/98+/Tt8e37s/v701sgYL5fbj5+urp/d3YD
EP7z/iMIz8B/AcJAd8fnpzuHmwur82PTS5NzB+s7V4dnlwenx1v77y5uv91/
+vP9l0837+7Pb4DuTq/AS+8vby72j443ty539/cWFjpra+vycwZevUyLkDSW
FO7Oz32+uPhwfvnp+uaPdx+/vn1/sbcD+AV2fHd8+OXyYn18/GVeXlVGBmB/
Z2oK8Pvn7Q2g+93Zyd3J0c3RAYD3YnPlcmsVNFlQmf/z7up/3V4ClsHk3d7W
7tTYQm/nfFc70HTba9BYgZneLM992tv482Tv29HOh521t8CCN5ZAPP6ws/Ll
YAOM73cWr1Ymj2eHzhfH9of69gZ7360sHI0OrnS0bvZ2giIP7Li3qmS4sWZ/
egS0+7d7698uDs/X5t8dbX/ZX/24s/T1aP3z/vrZ0uTBzDDQ5mgPGEFo3x/v
3uhrnmupGKnO7sxVNKZFDFdXDFSUVyUry5VpyfwIKYXHQtNjePF8irSuqLW3
eTwpMltIjU2XF6ZG5SWKM+RR6ZHSpKyMMllEsodbMAHHAZ4LCUDBYXgkgggL
Dvf1hgVDUAQcE4elBkEQsMCQIL/gEAg8HIHBhIWHBsOD/CAQP39zYxM/L28k
PDTI38/Fwd7e2srOytLa3MzAwtrcxt7OydnZ1QVg7ePpFBzgjoJ6IYPdCWE+
TEIQjwrn00IFdISIiZRywvEEgHAQGhOEwUHRWBgKAw0nhhGZuIdrL/FQGDYw
CO0LCfcOJQeQBGGcaKIwzzWi2IeX405JcSAnueATvEmKEH42K7UpM/NNSUpj
nrQ4jl8gjmuIyhlILppUpU4mR3SIBa/ZEW18WhU2MNk1INERm+OPzfbBZ3kR
sr05ZdDkDmpGH0dcCYXJTfDp7sxCH3GtL6/SEZelg1A+IWTr8ivtIuo9whS6
ilZ0Ri+Tne/HK/CXVUFT27AFzWh1fZC6JUDd7i9/6Sosc+AVuLJU7l6EZ8oy
Ym4DS5jmJsy2Tm13zhm3z523zBrGKLtCc8fIeLUZRKYprvTnFfuIKwLBGPMy
VN1L7jhKe7UZn9qNyxmhp/cRM0ccSLn/jlb9IKp9Iql/HtOoT8z8q7zJQFim
gUv5EZv8CzX9maTUTFBgglNocHMsBKVh5Aw/jNKdmO7FyvPnFvmIK71jX3kx
8vX4pYa8EgNBsaG4xIaTY0NT2XIyXK/3Lx9OHu2evz9/+/X2E+AXUHx3fHlz
eP6d34+Xtx8uAMvv3p1dHa1vr84vL88uri+u7m/uHu8eHu0cnB2c3J5fg/76
DpB+dXd3cQO+BCP48uPdeyDA9UewYfdwd3llY2ZmcXhooquzWJX2prpqZ2Hh
YmcPrAwgpYMV4OP1/afrq883118ApJeX17u7y8MjrRWVJcrU9oqqpaHhu739
r1dXX29uwA5vT09OtjaPVhYPluaPV5eud7dA3v6P26tvIHifHoMQe7K00N9Q
nxUdlcTnpYpFYEzgsEGAf52fPfum+XR28uPu+tfD7YeLq/c3LuYn7jfm/uNk
6/PeCsjYi91N7aVZmZGcfKk4mUYpjoqMCkclUklN2eqW3MyjqbHV3k5QjS9W
Zo8XJo/mJw5mx04Wp97trd+vTHzcmv20NX+zMnG2MHoyO3o0N3owM7o51LU+
0DHVUjNQmTdYmTtUmT1el7fWVr3e3TTbVNNXXtCQqcqPi0nk8vh4Ei0MJyBz
B1oHlFGpZAQ9mhsnpEgjmDHR3PhoWQoRzwXF0sXJ38bKHYkg+3hBdbXNPNwC
gZydvGxtAI6g0Qb4+kC8vQI8nd3tLGwcrOwgPgGokNDQICjExy/Q29fb9eFM
L5C3m7OXq5OLvY2VqZGRrpaOoamekamJhaWjo6OHu7O/l0soxAOH8MfAvGjo
AA4hmEeCCamhUiYqgoWWMJAkciiBGAIoJhDgRDKSREERyEgcERGGfbhSOhjp
64/wDCEEAH5DyX7hbCgrw4aVac/Pc4soCRAWBjHSIZQUOD2VFFORmNqUDyQt
jWfn8GXVYlVPfP5YirwviVTBpNfy4vqTZW1yfAEBpUYScjCEbBS3gsotI8Y2
84qmkmIbGYgEF6TCDZNhRS9xZpU6hqt1AmJ/hCb+SC3UiWxwI6jNwpOtBCXQ
vH5RZheXlw/h5Qent3MqW6WvBuRt88pX87L0TiS/xI6dZy0t8aAm2DISXRKL
w6IL/FFRmvENbgmvnbPGA5I7oCXTdFUPEh7/HJtuTM21kdT4SmsDhBV+okr/
inlp15kqvQfHL3NNeA3NHMDlTThE1Gvg1D/QC/4uqX3KLPo7PffvUXV6tKzf
uIUarJwn4Qk/hUb9Ha/Q5OaYSUpsIkpRNJUvJt6ZmubFzw8UFvkIipwBsKJS
Y0rG7/KXFjF1lrwCQ36BJV1tEVHsdXd0c7V3Afi9ObwE+flq//xy7+z64Oz+
9Prz9TuALeAXCLgwoOxkc3dzeX1jaW1nbesExOnDUwDvxdEZAPbq5OLhc+T/
m9y3l7cA3k9vP3x9//nru69/fPjj8/3Hu9OL053d/dW11emp2cHB+uLi3ubm
/eXVs51dYOtgrbg/u/sIVo/ziw+XV8COgSlfbe+tjk32vGyszy+qysqd6uq9
3Tv84/ru680d2OH+7Pxi/+B8ZwPAuzs/s7cwe765dn+0//n8BIAMKL5cX20p
KeKgkTAXJ4iDXaCtDRDG24MTBs+Olo68rAEV+HplDpB7Ojt8uTgOxrO5kYOJ
vsXOxr6qgpxoPgXiHmJpbvf4kaeuju2j3500n9MgASk8zlBDHbDyqTdN462v
ZrteA2+9Xp97u73w+Wj9bnHw2+78v47WPmzM7o31zLxpGKgtby8vaC7MashK
q1ElNmYr3+SlNqrje0rS9wab94Zb1rsbJl6VvilUlSRGJQuYMhpJRCLJuYKS
jBwUBA71gkTzZFwim4FjckhcBlXg4xns6wV1sveys3bz8YSYm9g++vW5jaWT
rZWjhamNnraR1nM9Az1jc1MrS3MbG2MzK0MTB3Mrfzf3MEgQENTHN9DTPdjH
y9/d1cvJ3t3extXWysnK3NrYwExPW0vPUFtHz8DAwNLCzNHO0svZGurjHA71
JIZ609F+bByEgw8SUuAAXhkHAygm4mFAJAKcQkJQqeFAFAqGSEIDIybQ0BhK
KIIYHEYJRlACEbQAkggpKnQXF3lJS3yERb50tScmzjU81g+vQIryJSlN2arX
+dxcKSoOQ84gxDaJswYT8aVMIGFzdFxfalRbgqQpOqY1Nr4tgVFEF1fzhJWM
pDZZxXy2ok2MUvogFJ6IdC1cngmpwDI80wCV/oyUpymstZA3eRPTbLm50Nha
irKZrWikxNWRUl/zCvrjq1+nvurN6loo61jLKxziSKtceCUWsXWepERTSbaf
NMuPr3IOi9QkpRhHVPnIm0JkNd7ZA5iUrpCwJE1ChiE5xxQUbUmNt7TWL/oV
tHCSU7UgSmwNEVa4xDV6K9sDi2acxNXPkYk/YFN+YOb/DZ/+Q7jyB1beU3zK
L+z8Z6JSLWaWJjZBAxRbdpZFZLltTAlSnA3jqyHinGBxTqAgy0Oc7xJT6czI
1CKrfo9vsIqtt+LmgdRtgEvUpqvMj9YOgI7XD0H/Pd44OFjdPVrfP985AhH6
w8Xd9+s3gID5ggp8tr1/uPHw2V4gRd8cX4CEfH10DiI0GEGWPtk+AIEZbARO
ClL0H+8+//Pjt2/vvwF+v7z7dH91A+rw8db25vzc/OhIT0vzWE/3wdr66dYe
ODJYK+6Or0EGuDk+uTs9A2zeHZ2A4rwyOjHS2t5Z+7JcnTXZ2fP24PjPt+++
XN++O7+4PTm9Ojy62t893ljbmp9dn5naXpg7XV+73t253d+73t4+WFhoKSsT
E4kwFxc3ExMrTU2zp0/Nnz2y19HE+Hrmx0VNNNev9bev9bat9r6+mB0Bul+d
eb+1cLU4tTPa21ddnC0TMCCBXgaGdk+fmf/2m9Zf/4ejjjY/HF2YmCDEYiIp
hEQeozYzZW2o825j9nZ95mZtEvD7YW3sen5wvrW2Lj0hVcCKJuHEuPBEDlOI
QQlRoelibkVydFGcqCUnaW+k/XSibX+kebGtsqMotTBOkMgmSEhIPi6Miwtn
YzGWuro+Ts5iFhcNRUB9AvGh2PAQnIOFs6uth59boJ+7v7uDh76mwZOfn5jp
m1kYWhjrGGs+1nj0j9+e/fbEQEvP3NDUTEfb1tjIzcbaz8U5xNcHCQmA+Xj5
OjsGe3n4uzl6Odq421m62pg6WhhaGWqZ6jx78UL7+TMNzefPDLQ1LY10nK2M
A91tMcEeNKQ/I9yfiQkACIuooQDeKC5ewkDTqUgWI5zPJYqFVImQwWOTqKRw
LDYUjvAnUdEUFgZHR6BosFBK4IP5ykmRpYGRpQHAfDm5Hvgke7jMBhHlikmA
MTJoMVVxUVXxuCRSkCwYl4YWVTJk9Wz/5EBMIU7yWiLvlid0x2RPqApnMtN6
5axijKACL6zEpfaIK5dSkzq4aJV7aLJTaOZTZLYeJtsMk2lKzjfmVZlGvrSX
v/SnqLwkReSkepGigR1XT0h8RVa3SfJ7k2pasht7y7vnmtpXqvIHRKIqZ1ax
UWStIzHJOL4yVJzhQ1NY4uMNgkRPRSVBknIMO9chuSVE8ToIo9QmZxsRMw04
pXaiag9uqZukOlD+Ci6rC+AXO3GLrKLqHJJa3crn3EXlL0Ki/z0s/t+I6n9D
K38IjfshPPHXsJh/UNWPxWXawiJDYpIBKlofwCivcVGUIGVZEEl6QExuSGxR
aEwhJKbYL6HKi5Ohz8nWTn3tnNzsLCg0oqp0kTFPENEa0/2Tc0Mza1MrO4ub
u0tbYDxce7h44+PlW5CiAVnAHL+/f3W+c/CgvUOgq8OT7+9QXR4cH2/tHqxv
rc7Mby+tnmzv3Ryfvbu4/nx7D/rsPz9++fz288fbjyBX35xdXBydHG5srsxM
TQ72j/f2TA30Azs+2di53D18d3J9sX1ye3AJyjI4+Pcft7e0tjo2PdM9OPam
u7uuaX1s5sPJ5bfbd2A9Ab8V2A389Iu93dPtraO1tf3l5e9nrEDL3p2f//4w
yaaSUjmHSwiGBjo6ORgY2mrp2OhqmWs+8bY0lRDDq9KTuisKxhsrgeEejffd
Lk3+1/ne/3t3/s+zgy8HW7cbyzvjQ10VVQVxCRIcgQYLcTcxczE0pochSTCY
hYaGva62r5UZDx1Sn5E8/bp2Y6D1dKr/y/rE5UzPZH1JXgSbFugFs7OC2FrB
HB3oIXCEmzvc2UkQjsyQ8vNixMCI1/tfX850HY69WXhT0ZqXlC1jRZERNJg3
2tvFw9LI3dLM4NkTX2cnQhjS0drWzsIKDoGhgsL8XX1hPsGAZaBg7wB7M2tz
PWMTbQMTbT2D51paj55q/vbY4LmmjbGJq42tk4UZoDXI0z3A3SnY2w0Z5Bfi
5+nlaPVd3k6Wvi7WPs5WbrYm1kYvjLUe6b7QfPHkieaT3/WfPzXXe+5qYRDi
6UAM8eFig3k4KB8fLCCFRjIxMXxiBAvHIyFYtHA+mxAhosdE8mQSNpdBwqFC
YEE+QUHeWDycQEGgSFAk8F8qBMsP4yfSpUVQSSFEUBDAyvIgpzrjkpxwSi9S
KpSTRxaX8Nm5HGwKjppFktWJxDVMfAY0KM0dkx/EbyTEdDCUg/yiOXn6EI9R
7EvKcqblu/Er/JN7CDkTHHFDMDzFFJZsjMjRCMs2CFNbodJtSDlW3HKQb50i
KiExFVR5mSStMa6gNy69jRFRERJZjk1tkdS2Z7WPv+xcaKseLVY0M7gVToxS
gKQFRmEcXRoqy4cQ44zoaaaAX0amj6iYyMpwkVcHRVX7oRJeULNMsCo9Wr4V
r8w1ojZIXAVh5XvQMh1omRaMHGN5nX3pRGjhqAsn70Vo1C+4pN+pmX/Dp/2A
kP8AlfyEjHlGTnsiKtEG5ZeaYo2MNKcoraIqHTOqsZEZ/ux4l4j0wOQyTHIZ
WpbnL8h0JCfqkpVa0lLLmBpbfqEJHfhvkhYs6mlPU1dvc/dw++DM4OTyxMLG
7CrwX5Cfgc62gSnvgd4KUALJ+XhjB0yu9o8BXEBgAl4CG7dAI56YWRyb2pxb
ArsBskDeBsH7j7cP9fn+8v7q+ArE7NP9w5O9ve3V1bmxkeHuToAw4Bc04sPV
9dPN3Zvdk6OlnYuNo6OdvbPdh1UCeP3x+vb+wur2zOLW5Pze7PLF5h7g99Pl
LUgF9+dXIJBfnZzdHB1eHx5c7u8db27sLS1tzs6uTU2tTk4ujYxM9fRUZGXx
cHiYm7urqZm1to6Njq6jmZG1rparmSEJ6qcUsavVisH6krW+1rvlqbcr0592
Vj9srZ7PT18sL7zd2rxZXztdWtmdmhloaGwsLlOII6Q0ZrJUFurla6urZ6Oj
Y6351NVAm+DrqmQR2wtUh6Odd3P9231N7bkpCioW7+UaYm8b4uiMcPNAuvvg
/YLIQVAOEhXLooEA31qSuzXcfTU3cDTWMf+6ur0wrTherOAQ6SF+MGcbw9//
bvjkd93HvzuYmTrb2uo+f2Gkp+/p4gH1CsDCkKQwLC2cSAvHhweDgO3n6+xi
pqNr+FxT98lT/WdPTbW17EyMPe3tAtxcgz2d0UG+QGAC9XJBB3uHBXr4Olt5
2Jl62Jl4OZj5uVgFugN3tnC3NXQw07I01DfV1TLVfmFtoAPgDXS2IgR5AnJF
pFApFRlJR8tY2GgeKYpL5JAQBERAeFgABhlIwIRQcUgaHkVCh2HgUHiQfxg8
CIdDhONCQrEQJBmGYoTgBEhOAl1ShBIVhvLzIPx8f+Bo0jK4sCSUVxAmKadE
VPIk5TxJlSDpTay6XxFRz0Ik+YRlupGK/CNbcckDNGUfJbkTI6jygMVrolP1
cGojboVDYgcstj0Ym2PqHfskQKEJUT2BqYxClA7wJGesyoFd4iir941/iasc
ySvpKi7tyS8bVqg7SOIyb16Bf3QVoaZL0TVf82auSdWs4JUg+TUe/DpbRqEV
NsmGkx4QX4HGy/UoKdohkY8gIh2S0p+n9pfkB3Gy3KCSp4RUI2TiC9CseSUe
FbORqe00cWkwN8+Tnm6FT34BQHuzSc3scWRm6hMURvw8K0GxJi3rb6i4H/04
PxMVpmB7RIVhTLUjN8MLLXMIizImpeqkVcAj0j05iS5SVUBsXlhEFoyd7E6J
t+FmONBVZqD2Jrf6p3dBU9qhyW+gIMx3NrS31rQA9b3unh6YWJ1aAi58srm/
Nb+6u7RxsLq5v7Kxswjma4drWwDnq4NDoIu9/ZOt7aONzb2Vhw/JnewfWByf
2JxfON3eeXt69vHqGvRTIDAB8B5u72+vbu5tbB1sbW2uLM6ODo/0dIFxdngI
EAcq8OHS+vHK9s708jkI8zsHZ7tHF/snN4fnd4cX94cXbw/O7/bPPpxcvz++
AvpwBsr4uy93H0BEBy37w+XF/dnp1cH+wdrq+uzMytTkxszMzsLCwxUm09Nv
qqsVEgkFgfC3dwD8mj/XNNd7YaH7wtXCKDzAM5ZDAfyONVVuDXXsjHRNt9QP
VJd1lRV1lhYPNzQu9PTOd/fuzi7c7B6crm3uLq5O9g72t3Z1Nb6O4Yuhbp5g
WfC2NHfQ1nDRfoqwN1NxSVMvS2cbisbrCjrzVWXxshQuM4ZEFYUTuUg8ISA0
gSvOjE5QiiTJIlGhIq6vvvJgdvxievhotHe57dVAZVFTdlpJYkwsk0SB+tto
aej8+svTH3988fujF0+eaTx6pv1Cx9jQzNHUMjwoBA0JBsKHhGKCYZjgYJiX
l4uFhZ2RkbWBnqOZiYettb+LE9TLLSzABxviRwyDgBHu54oIcMPB/dDBXhAP
O8Csr7O5t6Opr4spxNMqxM8+NMAR7u/g7+Lg42jr72QT7G6P9HMlQb35OHgs
Gx/NwMRyCQkCciyfAuDlU8MBvKAa+3o6+Ljaejnb+ro5hPh64+AwOhbDoZAY
ZDyLSSFTMBgSAs9C43nheGE4U06LLCFKCjEAYWkJPO5leEorMaEJH1EdLiwN
l9UyE5ulyW1yZUdMbIsYJGRkig8uGyKqwWeNRuVPRsU1YTiFXqQMG1SiLipR
B5WsB/CMfQ3lVXtBEnTdIp4FJhp5JfzurzANSvSCJ/jj1H6S6mBVBzG/N6pz
5U3zVHtJd0FiPaDMjVdszS925RcGZDYSagYVxd1qYRGbmAnh1HqLXrlRixwp
ah9GSrCiikhPNSMk/YaM/cmF9tdgqQkvBcZVBZESnfw4T9EJhtCo54R0K1lt
SNtetqqDKy4J5eT4IGP0/bh/ZWfpVE+E5vR6SAodZEUQVTMivt5aXKpBV2uH
iPWoyU7cHIuIctOIUnu60hPKt/ekPXOj/0CLMWLEWQqUbpGZQUJVECvRl50a
KM0PUb7CS8v8JBUeBePk6hV+wSQlb5Ka1BnWWN5QW1jdUFo/8KYX+O/m3BoY
Z4cmJnqHV6cWALlr0/NL49Mbs4sA5KP17cvdfaCzrR3gmwcra3tLKysTU5O9
/fPDoxszcycbW7eHx/cnZ2C82js439492j5aW1hZmJpbX1zeXV/fWF6YnRgd
7+9Zn39gDeTeg8UV4LAA3s2Jhau1w8vjcyBQrt+f3369fv/t5sPXy/tPZ7dg
/Hh6A2L258v7P+8///n+y+f7jx9u34GyDCrz+e7eztLy8uTU0sTk1tzC0doG
+E3AL7k6NtlZ11CUms7DkzytbM2fa+lrPjbT1XQ0M4B6OEjI4eWq+KH68rm2
l22FWTWpirLE2KI4eZYsOjc2vjRZVahIaSgtB9iCP/9gdftocw/U/OWp+Td1
Ter4pIy4uFg2kxIUEGJnGWpjIsfBu/JSB0rUgOKltvq5llcDVQ8PrKlOzy1O
ysiLUzWX1HXWNDUVVzYXlXRWV0+0tW5NjOwP9gMtt7cOV1e0Fea+zEjPjo6M
plGhzs5GT59q/PyLxi+///7Tr08eaWg80XryWNPg0dMARxd3S0t/R0cMBIIO
CMAFB4X5+sA83IPdXGEerkg/bwzEH4gYEswID2XjQpmYEDIiEA/zJSH8qKhA
LNQT5mUX5u8Y4m0b5G4J87JCBToSQz1paD96uD8NFUIJg9KRUA4WISKiIijo
OA4hVcpM5JOVUkZKBBPwK6JiyKhgmK+Lp4O5i62pk/WDPOxsoN6exDAEj0KW
ctlCDjNSwheKWCwBhSWl0qQkkgTHiqULcvDCPKwgDyEqhsfWo5VtBKDYRqyg
NFRShY9p5CS8lsrquYxCDCETRsqBRVRHZvSq6xYrCofThMU4cqovJdWdkOwE
l5kESQ2IKpeIahS9ABoYY+cXY4dI8fFP0YOmOIUqQ9GpOHYRUfGaWjQsrR7P
bFtoL26viymUsdJ9iSpdYsYzZr6pqMwjttw1qRYVW8lm5ZLIuVBGlQ+rxoVa
4E5Rw5gqtCQ3LLLEmZT6EzbpfwZF/gQRP6fHwVgKGDneA8LVxcabwyK1Ofke
2f28ssk4aSmGrgokJ7n5sZ54M/7Ky9LP6fTJ6fGJKvVS1pEKu5nJjc7R1Yay
Mgea0o2T7icudBKXGNNUhnCxtQ/V0p2s4UL5AUL9G0r4nJvsFJEVLEyHspTB
0jxMWiNHVo6iql0Ialv1IDF3nCqq9+bWeODzrIrSC4AAv8B8jzcOQPkFk/aX
LT3N7YtjM9sLKyAYTw+MrE7NAX6BHZ9vb1/s7JxuboK+CQRsbn16erq/H2hl
YgJs+b7DycZDmt2am9tZ3pgfm54YGlmcnt1aWQH8LkyMTQ31H2ysbi8uPBxn
YXljfBZoa2z+buv4+xmo+/ObT1f3f959Avpy8Ra48OfzO0Dxp4u3YMu/PnwD
/H68ew92PtneOd3ZBSOI4qvTYE2Y3lpY/O9M/rDUgINPdfc1lVbIuQJ/B2ez
51qGWk/N9F9YGWq5WRqSYX5ZclFLvrqjOKe/qhiY70Rj/UBNTVlyilIoTmCL
oulcRWRMXXH5VP/o7srm3ckNqAOX++fnew8l4nBpdeDVq0yZlAsPovq4pDLx
IxW5q29qTsd7Pm0sfFhfPp2e2RweW+kfW+ydmOuZWOibmuocnursXxubXB8f
n+/tnu5sX+vo2OzuXmh93VdW2pSVWatS5cfFJvEFWL8ASy1dY00dUGyf/vbs
91+e/vbr019+fvri7z85GRmbPtPwsLDEBwWH+/sTgoMxAQEogG2gHxkOZaLD
GCg4FQFlY8KktIeWKqAgmVgoAxPMxoeACRbqDvW0RgY4hfnbIwMcsFBXKsqX
jQ/iEIPYBEgkgwwUxSIn8OlJQrpCQEuRMDKieWBURXHSIrkxXBITHxoO9fFz
tXOyNrY1M7C3MHK1s/B3dQ4L9Af8MnBYNpHAZ9GjI0VR0SJJNO/hWpJoOi2S
wktkU5ORTFUYOyOEkwuRlEHjmwDC+MTX+Oh6rKji4S0pWT1bVE2j5oVR8uC8
ClxBf239XFvTUntGWyZbTaGnIhlpCGyMZwDXwo2qD4925RUSqNlYWFwgXAEn
ZpHRBY7Y3CB8FoWSw4+oEWX0SMsnYqvHc5qn3sTkpeGjMLQUd2qWDkLxV4Ja
I67RP7rcXFrkKSoEAYDOq8Yxq30p5U60Ij9kvB9NicHLPeKqvchpP+JSfqBl
Pgd9kxQZzEyAs5MDERILYpItIsZIVhXyajlF2cwmpwQQEn2IiW6BXE1cjHZa
k3fZICylxUWY45ZYScppY8ir7SPK9WKr3AVZkOgSdFyNH+AXJdfwour5UG1h
IvOwmOehvF8xUk2GwhbwG5GNFKiR0nxiQi2LqvKHyy1DFaZpA6SMMSql2B6b
ZwVL1a8qrW6uax7rGQHOu7e4tTo6P/amt6emub++dXFgbGV0ari9e6Szd3tp
9XR/f3dz43xn43Rr7XRrA0AKAAEWPDc0NtDaMdEzsDAysT2/CIwPULm3vLg6
NbYwOjjVNzDe3bswMgZsEYw9TS1AMwNDwCKBgH2vTk4D716bmgFH+3b79j/f
ff7X249/3L3/dvf+y7sPn969f3t7d3N1/f7+3eePn/74/OXPT1/+9eHLP999
+nR2fbm1f7C8tbe4cb13uja5MDc4sTO/tjoxf7S6c7lzfL51CLafbR6MtPcp
pHK4N8TVwt7X0srb3MLDzCzY0VlCoVdn5wGD7qh9OdbWuTo6BtruOVgHBnrb
igrUIp4YHVqaHN9TXbE22He8MHO/u/mv6/P/fX/zn7eX73bW322tHEz09ZZl
F8dwy+N4Y9WZZ6OtAN7b+dFv28vnE8P7Q303czOnk2NnU+NXi7Pnc5PnCxO3
6zN32zNny0Pro83TneXHPe3rLS/Hq0rb83NKk5Pi+QImjoQNC3dzdHdx9LA0
s9XW0Hn267OHzxl89Ozh00Ifg/kz3ccaVgaGIDZzcDg2FoMNDMRC/Hl4TDSb
IaGSGEgkDYHg4/EyFjOGwUrg8sFhZSwWl0wih6OggX7uzg6eHi4uDrZuTvbQ
AF8MHIYNgZHDwrhEooxHihFS40SUGB4uiomOYaGTBES1jJkeycyJE+UlRqVE
CgQkPNzP18XaxsrQxMrS3NbGytnJwcfD3dfTy9vdw8/LExoYQMKiBWy6IjYy
PSUmRRERG82UiQlSAZauDKEmBRGT/Uhqb0axr/CVn7w/MHHCP2bESdptwXql
x6w2ZpfbULMd+QWQ9Dfc6pn61q3XbXsvK2ZVSW/Y/LJQdLKbj9DagWZlS3Tw
5gciE3AoBRqTgiBlhoIATCgMjGplRTWJGLl0ZgYvqlSR2VRY2VeT35rNUIQT
YwOZaUEouQMhyVlei1G2UPC5cFIRkloRji+BhxcEMSrDmOWwcKUjOs7Ck/Iz
V+UQV+VPSTMlpBlj1IbBiufMGH8Mz0GYBJXnhBMjHIlR9onl6IxGkjDbU1Lo
RVaaYhJ0uLnWgmI7QYlNfKNX3CtdSYWGtEKXk6uNT3rCzTWV17jw880jy60j
KyzZOdro+J+Q8p/JqdrAiPEKHXaaETlBC8L+K072jJdiRo8ziUh3V5ahRGl+
aJEFP907rgqm6ghlFhlSCp+Gqv5tsGdofGB8bWZle2FjZXxheXh2vm9spKkT
8Dvc0jHa1j3a2bswOrm/tn6yt3ews322vf6dX+CzwON2FpYAv0NtXSMdPfPD
4wBSgOT2/Pzq1MTccP9Eb2dfS+t3AWw7Xr7qetU02tm9ODoOdgPfC/YHqfs7
9SB1A37/4/Y90Lfbd5+u7t5eXt9eXr29vrm7uQXw/vnl6398/fYfn78Cfv98
++H98cX5xu7uwvr61CIAdmV8bqZ/bGF4arSjH4xg+8n63sX2EaAbbCnLLJCx
RaRQDAMewkKEMcC/NwaXJotqrawBBj3XP7Q7t3i2tn6/t/dud+dkfmai6WVl
ckIym1YQH/2mJH+hu+NofvrDwQ4gFyD86Wjnj9ODr4fbb9dnjyd6t/qadntf
nYy+vp7qvJ4dPhrp2hvomKyrHKut3Ozp2Bvqv56febu2dL00e7k0db06dbk2
fjTftzL0aqqj7LDrzVhpfmmkNBoXTgoMCHJ28bCxc7F2MDM0NzeyMNE3NdTW
//4EAL3HGs//8Yupto7+Mw29x09tDQ2Rfn58IkFIJDJQCFoYXEQmyLmsKBYd
kMsOD+cR8GIqJYEHrFOSJBZHMhkcEoGCQYVA/FydbO2szcxN9IEcbSw8HGy9
He1h3p6E0BAOCSGiIcVUJAcTSIK6EiHObKRvJDEkSUBKFQMjFmTFy9KiI6Us
Bjo4yNvJ2crM2NLUxMrM1NbSAsja3MzOytLZ3i7A2wOPRsgkbJUyOiNNnp4s
USZwk+LYzCQ4UwlnpcFYWcGsAj9utZe01Su6xz2m31HWa8V6qUsp1eaUWQtL
PKWl0MRagqJRWTJW2LRRVbecnT0kjW7AkTL8IJGOvkJnD5Z7kASGScRjFChs
aigtL4yeD+fVoeVvgIMzCCosJ5uvrFfnvikq7iyRZgkYSWi+Gi3MCSUme5BT
3IRFUHEJjF0aTilAkIvg+ILg8Bw/SkkwrSgAlWQbItN3wv4VF6PPz7DDxuui
H+q2DjpVjyX3Y8l9ItLgrHhvKE2fILOTF4ZIsn0YqfbCHBe6ypKg0KerTclp
+vjkF8xcU1WXmajsCT3rF1LabwTlY0GBWXSVEzfXmJGhQ1D+jkn8BxgZmVqA
a062OTPDjJqsxU7TDxH8DcL4N5TwN2aCSXIZNL0aB+owWmRFiXNUNqDjXgby
Sy1Juc9Q6T9Oj83MT8zvLm9vzK6OdQ7N9o0CfjuqG9sq60FTa62sG+vqA4n0
aHPrcHsb8Pvf8D7wC0z2cHUV0Dc7OAoY72tpm+4fBl14eXx8bmhoqr93sK2l
o6EW9MeWqppXZRWVufnV+YUA4e9leXl8cmlsApjv7uLyxc7eu9PzT5fXQN+u
3v5xff/5++MCDk8uj0/vb24/vv/w9fOX7/D++f7TH28/fLl+e7t3fLj0ACkw
3O/mO941ONzW29vUPt03ujmz/N1/D1e2wauzA+OdL1+XZxUWJykq0lIr0tPL
1erm0rLp3l5QwC82dz6cnn46Pft2fv7n+dnH/Z398eHBmvKX6pRKZeJ/32fU
tD02eLO5+uXkAFB8sTr/8WDzw87Kh+3FL7sLf+zOf14bv5nuOhluORzuHKrI
a1Ql5kn52SJeSUxkUXRkfWpyX2Xp6MvqufbGjaH2nbGOlcGm8TelPXVZDQnR
KWQ82dXZx0DXVvO5yePHWr/+DjqvnqaW7nNtIx09G2MzR3MLR1NzR2NjZ2OT
YDc3UH4djY0CnByByUYyqIDZOA5LIeAl8rlgLqWRAb9cLFZIJgFmueHh8Vxu
skQSxWbxyEQqFh3k52VlbmRmrGeo98JQR9PUQMdcX8dcV9vRzMTXySE8yJWC
9OPgoEyUHx7ihPG1owa58lH+AGEZNSyWTUwUMOIFbAmNTEGFISGBwMrtrS0s
TcFaY2xubGRqaGBuaGhtaurl6oQOhUaKWepUeV6WIic9Ol0pSlXwRckYcRpW
koERZIaysv3oeS6sUlt2tWl0p11MpzW3RpeS/1xQZiWr8BTl+fLUPnQ1NaEh
unhMVTqZlNHLl7/CMfMgaIVHuCIQEROETULTMsjkdCwtC8UvwfBLUYzyYF4l
CpceFCoP5Ofy1M2Z6qYMRUU8JgJ0SWRkAU6ch6Cn+5DT3BmZ3qxs36g6AqcI
Ts0LIuX6o9RumAw3rNolLMEsWKrtiPkLlPeYKNfHRL1ARmkgop9S1CYyNVyc
ApGmQ6nRzsE0HYzUXKDypCfZMpV2olxXXpY9JcWYkKSLkj9Fxjyhpumld5tz
Cn4JV/wbXvkz4FRSYhVZbsvJMcIqfoNG/FuI7C/0DA1JqRkvz4Sm0qemGfCz
DVIb3PmZ+hDmD37kHxgJBupaRHIpIjoHhouwI8Y4pDUS+XluwjIHSq4eJv3R
1Og04Hd7ZXt1ZnGse3BxZHquf6w2r/hlYVlNbhHgbqSre2tx6Whn52Bra3t9
7XzzuzZO19cOlpY2p2YXh8Zneod6GlqAWU/3PDxydqKrc6TtTXttVU1ednl2
LsC2pqCoKq/gZUlZZ0PjSEcXSNSA4tnBYcAvSNFvj08/Xlx9OL8Ek6+XoOde
3x2dXe0fXx4c35xdfLx/B2IzCNJfPnx8SNQ3bz9e3r47vQTmuzO7BOLx/NAk
SMiDrd2A3Pa65p7GNuC/IEgDfm8PzgHCN/tnd4cXgHTg0RNvmme6Oma7O6e7
u5eGhg6Xl+8ODj6enX27vv56cfHwcUjX58Bbb1bnNwa7Z1sblrrfbI/0fb9Z
6WZ9CcTmu82Vi+W5+83lu/X5d2uzH9an75dHLycf4D0ZfLU/2F6dGClFBmNd
7NCOthgXB7iNJdHTLQKLzJTwW/Mzpt/UrA20LPbU9zfkNhUpVDQC18/LT1/H
5vdfTH772eDXn7V+/lnj53/oPnmq+/SZua6eq6Wln4N9oKMjxs+Hi0JG0cnM
sBBikD8bFSqjkeI4jGQRL10mSYuQSEgEkKKDXZ387OzA/kg/X2oYggyFylks
pVQqpdMAcRhYsL+7i7mRnr6WhrbGY53nT4y1Nc10Hk4YWerp2Bkb+juaoAOc
ebigaAY6lhUuZ6IT2OgkLl7BwaUIyEl8SgQZQ4b5I7zdED6eGIi/l6ujg7WF
uZE+kKXJA7l2FhZOtlY+7s7hiGCpkAHyc2F2Yn5mbHZ6ZEaqJEHNlqfTI1MJ
wlQkJy2Qke5CVpsTMnWim21lTWa8ci12oba42JyTaYWNMkCJDUgKlCifklDP
jasjScvgnAJ/WpY3SeWDS/bHKoJoGVhOHpmWgaJlwtn5cEZuUIjCApnkEBRl
B4/yiizmZb9RpdQmSLKYtESENJcQXYyVFsJ5uYHUdA96hhc4YHw9VlgUzC0M
YBf6Y1UOCIU5Msk8NM44RKbjQf0xRPCYINchxuqgpE+h3J8oCr24vFBGnAtN
7sCMd8aITJF8fZLckqGwEWY4ywo9Iwvc2GkW+FhtVPQzaoq+tMg+oVGHmf13
rOIvVNUjXq6+IM9UmG/GzzUhKZ+Ex/2ETfwHO/sFP8+AkvICIfsVJv6Vl6Wb
1xGganSnxD/2p/1AjnmhrIBEZflGZEDo8Z4CVVB8BRr0bm6+k6DUHpv6YmF6
fnl2cW1hZX5semZwfGt+FcTgytzC6vxiAG/Hq8bx3r7NhcWT/Z2j3a2NlcWz
jdXvOllb3V9c3JqeWxmdWBgcG2hu62963dfYMvj69fCb1t7Gly+L8vOVimJ1
ZklGFkAYuDCAF6To4fZO0H8Bv8B/95dXr/YOQHL+/pb19f4hSMWXu4dHa1sP
73UfHN9f3Xx6+w5gCybvb+7eXd/en1+9Pbm4PTwF+2xNLyyPzQ687mqpfAns
taO+pbGsFvALvHh/aRNUY4Dw+9ObbzcfPl/eA4TBl98f2HU4P324NA9WobeH
B+9Pjt8dH306P/t0dvxwBfXV2dfjvev1hdO5sZPpkavFKcApoPV65eFZIocz
4w+aHQPl93pp+mp+5GZh5O380O1M7+1M94eF3ovp4YJIPtLe3O7RP+wf/+z6
4hlQqK0lwdtNwSS9KVSv9DUfz/YfzfasDjROvC7pyc8qEPOYAT6BpkaOL55b
PH1i8uyx8bOnek8emetoedtaIX29cAE+ZIh/FBGbI5MUxUepRJwEDlXBoydy
6NF0YhSNEM9hyFk0AiTA3cLUSkvLTEPDTPO5m4U53MuTDA0C7qyWR8l5bDoG
iYUHwXw93OwtrYx1TXSf62s+NtJ+ZqGvZWOoa2es72Bq6G9vhPCyBeYbz8Vn
y7llyRGVaZFVqZG16fL6zIRqlTwzihdJwdJCIcRgXyIs0M/T2cXe2tbCxM7S
1Nna0tXW2sPBzsfFydfVCQULEDCJybHiXHVsUU5CSX5CaUFiepY0MZUbmUAU
JqBEKSFCdQAn04meYRhVZyOpMOAXv4ioMJSWmKEjH3nh/+JP/gczBclVo9gZ
IeQUj/B4a1BLcQobgtIFLrNDxriS02CMzDDAcngicGTXkBhLX4lmQIRegNgk
PM5LXsHObE5Q1sriy/iKKm5cOVFWEhZTEQaSOSXNhZzmJqsMiyj0FeZ6RpT4
S0p9Cek2YYnG6GSTcKVxWLxugOAXjFybnmRETzDASp9BKP+O4v/KTnAMFxmh
hYbkaAuizAwjBhHaiBZnJkp3kOa4yvLdeOlWuOgXQHy1VWypW0TlU27+r+S0
n4jK34jJT7HxT8lKbVGBJStTl5Oty8vVZWfpUNM0MXFPoaJffFl/Q0f/PaHK
LqPFS15shZb+hIl4JMt25iocOQo3oSoouZLMSvENj7aiqxyia3xxSr35ydmF
qbnB7v72V80j3X0rk7OjXX11RSUAt66m5tHunvnx0Z2VpdOD3eO97Z31leO1
haOVxcPlhcPlJeC/2zPzq2OTC4MjY+1dnXUNLeVVbTU17bU19YV5BSlJGfFR
gN/SzGyQokEFBs13rAvU5FHQfEHSBhX4O7x3Rydg8v+fmdrbX17fnF3cXVq7
2H24LREAe316DnR3evFwT+L3S0d2DsBuKxMzg209Pc3tb+qaRrsGQH7oaHgN
xoXR6eONvcO1ne8Xgv7z/devtx9ujy5Otw6Ol6YPFyYPFmfO1ldu9rYBuTeH
+xe72/dHh7f7O++Odh8+Gnh/42Jl+mxhFHTV/fHe46nhk9nRg8lBYMRbY/0A
3qvlWbBlY6BtpfPV4XAH4Pfj8siX5eFvq6PbfW2AX5qve4CpnrfBC3ft57aP
fvHW1yb7uafy6F1lORsDrVfLox/3Fj7szd5tTmz3tI9Vl9UkxSuYFEZwQKCd
laO+tpW2hruFcZiPu4SMUYo4AFiVgF0slzakJ9Uoo0tiJXmRvCwpL1XAiKLi
2AgoKcifAPHzs7Gy1dO20dGxfPHC9NkzkLEfTio5OQjx2LyEuPIMFVhOFZFi
HhmPCYGwiBg8Ahrs7ebpYO1qY+5uY+FpZ+XtYBPu74QLcKGGeEpJ8FQJtUQh
eSA3Iw6oTh37MiuxOT+tuTC9JiMpSy5K5NGjxVwhi8IkYUCzxiFCEBB/mJ93
iL8PBg6l4pASLjUxhq9WRoL8XJAtL8yJVaXLEhWCiBiKJBYXocREZ4dFFQRJ
C11AqhQU6vMLtWJrzaPKzEJFf3fD/ACh/8hKCaUlBeLkLqES02CBNlSsjZAZ
hMeawyJMwqLtKCm+lDT/sBhHuMwmRGbux9eDSDUCxJoBAj1MnKskDyMrIMcU
09JfidMa2BEFcFFuoKwUxsvxCosxD40yJ6a4MlPMOCrLiCJXabErJd0cn2pM
zDDHp5uEJmj5iX4hJBvQUk2A/xIjNUNoP0IIfwllP8dJDPBSw3ChDklmzEu2
5ybZkKOM6HEmzAQzYZoNT2mJET/HSjQ4SabCNCthwWNxoSY97VFY5I9Qwd8C
2X9DyzQkeXaCbDNpgZW00IKjNqQkaeFjX6Ajn4eKNNCRvwmzTFPqvdIbfOiJ
Wijx7+xk84dVIsJSmglNqaaGS63CZZZUpa282p+WbjbU0zc1MvbmZWNNcRng
d2licrC9o7Oxaaijs6/19Wh319rczPH2BtDe5ur+1tr+0szO/OT27NTu/Bzw
3935B37n+ofGO7qbSivKMzOrcnKKVWlJUlGsgKWUiYrS0xvLy4fa2kApXpmY
2J6fP1pb+96dz7e3746O3h4fX+3tnW1tnWw8dOr/fvtrEWh/de1sZ/fq4PB8
b/94a/tsdw9MwJajjc3D9Q1g3GtTM8DHAa2zQxOTfSPbC2sgPIAIASb7K1sX
u8c3h+f3p9cfL9/+x7sv//rwDcz3ljf3Zsd2Z0Z3ZicOlx7ud7jY3QTwnu9s
nWyuHizNHy3P3Wyv3G4tny1Nns6PXK1Mns2N7I52z3e+GmmoHKwrG2upXx3s
AnF65k3D6MvKsfqy5Td1Oz2NB/1NV2Mdn5eGNnrbOouy69MS8yIF8RQsI9AL
Ym4QYmMaRUCVJ0WNN1ZuD7dfLIx83J3/drTy5WBpb7B3u69ruf01qNsVyvho
Gp4c7Bvu4yrEhaki+C9zUjvL8jpLszsLMtrz0ttyUhrT5bVJsvJ4cWmcuCQh
Qi3hcJDQYEdbd1ND6xfPLbWeu5iYuJqa2uvr+9rakmCwcF9PPhaVER1RX5Dd
Ul5UnZehjpPFCFiF6cm5KQkpMVIJEzTZEAzUHwsLwMMhUnKYiAAX4oIBvwks
rFpKz4/lFyeIgPLlvMI4QU2avK1E3VOV+6Y442VW0svyvOqi7LLc9AJ1Slp8
dJSALaRTBTRKnFSQGC1KiZeqkiLTkyNUSeK0JAFQsiIiPkEUE8eVxlJFCXhp
CioyOyS6yF9SaCcsMhYW60XXmMdUWVGSn8HFP+HkmvQEX4zUIYhp4E155kN7
HMTTQETqhMcYY+LMcPE25FRXbIJDkMgIIjaCR5lDxIZI+QuI8AlEoElKdGKr
AnExD0+5VFSRY8uQzDQ3ToY7P9sDLTcLFuohIh6e1s5IMeCkm0jybPg5lpRU
fWqGMTXLDJGkFRz/zF3wN0yqPlFpiJA8psbqkqXPg/F/CWE8IkboA+HEOsw4
c3Gao0Bpx4wzJUh1ULxnxAhdIBj9VyT3KdgIRE76iZ+lRVFowPh/D+E9gvM1
MJF6ArVDRK4LMGhOmjlXZcFMNifEGGEjjYgxFhS5ESPRRJpln1DqSUvQxUZo
sJLMoMwnCL6+SO0nSPcP5Rthos1YagdhvqOwwK6/rXNxYrq75XVLbd3G/MLB
2vrs8Mjy5MTs8FBXU2Pv6+bNxbmLg929tWUwOd5ZA//5G5Mj6xOjW9MT+/Pz
e3Pzq6MTs70DI63ttbkFOQmJOQkJiSI+A4VghSMShJz81NTe5ubN2dn95eXj
9fXbw0PALED1cncXYHu9v/8dXvDSwcoK2AeQu7u4fLi6fra1c767B4A93twC
wH4XgHprYXFzdh7AC+oziOKLYzO7Sxtr04snm/vAcFenFq4PzoDVAucF5ALz
vTu+/Hz97r++/PPDxR3YbWtyaH1iEPwJYBUCwB6uLZ1tb17t727OTS0ODywN
9x0tTl2tL5wvTx3Pj1wsjd+sTC10NdZnKlL49GgaNpFLy4uLrMlQDtSWj9RX
zLbUzr+umagpHC3P3uqs+7Y6/mlr+QIY9PzEVn9Hf0VhRWK0kkXOkXIqlTEj
L8sOJ3uvlsaAblbHgQufzg3cLs4CXcxPbQ329NeUlafG5cZK8uMjChIiXxem
jzZWzDTXzDRVTjeUD1XkdWSndGQntKTH1KfIXqbJ3+SpatMVMjIOuLa/rbWb
uQlovpiAAHxQEBj5BGxWvLxAEZciESTwWKpIcWFSfHFaUokquUStLFIl1eRn
vizOLVIrk2QiGZceyaEBrtMkzFQxQymkKXjkRB5BySepxLSMCGZVahRAODOC
oRJRwFiqkDTmKDpK1S+LsxpKcl5V5DdWFFUXZBWolNnJCdkpiblpifnpSQVq
RV5GQk66PCMlAsCrTODK5aK4BGmcQhIRy2bLcIxoODcZIsz2Feb/911yJabS
ClN5va241IKRacjOMaXI3ULYxq6o3+zh/9MV83cI6wk6Sp+UaEpKsiAqzAkK
S3iEnjv9kS/3BVxmBkwZl6AbIn6KkGpz1e78DD8Y3xjKM5LkQiILAxkpDvws
N6bKMYivFSoxoSs9sTHO3GwjXo6xMMeMpdInJb9gZhiR1Pq+Ef8IjH9sx/0L
Ik0XmaTrx/uJkWwsTDYPpf2E4WmgOU9R7CeUCD2BwooRbUSJMBAobEgSvRDq
b6H0R6G0J37hPyKZGoJEO6HCHs7/HwyFNlmugxRoUmIsGXGOlGhbbpJbXGEQ
M8GGFG3CS3HgKZ1xEnMU35QS5YIXWyFY+mi+ATPeCifRJUcbgGQOYz2FcV5w
U9zCRIahYn2s3EiY60BNM4iucgIJebizC3gu6Lmr01N7K8sA3qGO9r7Wlpmh
gc352b3VBaD9tUUwbi/Nro71r40PbU6Nbs9Mbk5OLg0Nz/T0TnX1An6LU9MS
hSKFSBRBp2ACfQjQADmXBsx3qq8P4HlzcADgBW4LBOaAXOC2gFkggDPQ7uLi
2tTDBVQAYcAv0NEacOTtg5U1AOz69CzYDsa5oRGQwMEEbFyenDrc2H24muLo
HOj/4+k9nBLL+ndf38kz3dO525xzzjnnjKCAYEBFFAygiAgqgoKIICCCimIA
A2YFVMw5p9bOPT3TMz3pfX+/c86tW3XPX3CX0/eeqqdWLWS7Qdyf9Txf9t5r
/fzy3ad3v3x8/dObyxegDzrg4V8/f/rPr3+CFvzwaHMPwHuwNHexvfoS1AJH
e28vzt5enl/u725o5jc0s/vL/9C9NPt8U3e9odmeHl4f6+uglucnR6QFecZ6
OgU7WEa6OUBDA3paGjbHhy90MxtDPTNC9mxH85ZC/FIz9vFw59ej3d+O9345
2Hy5pjvXTgP7vl6Z++ts98/TLaC/z3f+62r/f1wf/vfzA9D58/zo5/0tUGif
aqd2JpVro/K18f7d6eGDOeXe1OC5Tv18cXJfrVhTSFZ7RRoxd4pXp2RWDTVV
j7czxtpZXcBD8UVV+egSZFZ1YSG5GEvMz6cTCF1slkosHOrgDwm54qY6Fgnf
WF7cSqnsBAmcwwASMWmdzfVSDoPPqGWSy1ppVXxWXQuNBIYOIAahgABPLUqP
K0OkENGQCkQKoLi1slBIxUvqKyR1+E5qqbyJpGqj9bY3SVvru9uaBsRtw118
hYjX28HtF7d38zndHexeMUfe2dojZnby60F4bmVV0ujV+PKinEJ4bjE8rzwr
tzItjxKPbY7BtQUXtLlmt5jDWc9yeBa4LhecxAMjcE4vckjIs4hCPgvPehSK
uBed+yijwiKP4ZzHcMS1eSFotrGlz/zQd2JKzQpbI1CNgQVN9on4R4haO3xb
CKTSLjj7YWKJZQ7do5Dli+P45ja4IMgOSLJbZqU7sPUcSlhui1l+i3lJu10B
yyK/0RRNN0mtfojm2mVx7TxwX/mWfZ9AM40ue5hEeIyoNEnK/SEF9WNumQUS
Z4wqMS+pcYEWGsYj7hVUOZXV+8CLLaAFJvBiq0Tk4xjYPQTOuozun1n+LB33
BF5uk1PlAcO5QbEehTURxOZkRmd2doVHWqEtnOAKLXbNLvMvoSXiqEkVtAx4
kX9WkQe6whNV4YypdS2guaaVmmVW2mRTnPMZXmi6U2aNeS7Tpphnn9tsvDg+
DqQdHweU3U5Dt721vaTTqMcWpya2lzUA2IvdzfOdjbPt1dON5cMV7a52Ghz/
J6uLZ+srgN/t+fnlcbVGqVqZmJRxWslFRSUIRFZcdLiHMzIxStLSMDeiPFxb
eX918fPNc9CCYhOYHbA8EFmfH+ydboE9b17t7wKdbK7vLi9uLy2ebN1mbMD1
55uJzjY2jlZW9peWtjUaoJ3FRZDDAelgs6uD/XfPX/108wbAC/AE/c9Tf4Cf
AHL//PDb37/8/vk2RtD+8ur99fHFxeYKMN+LrfVXR/vgPXy4ef7LyxcvT09O
t2/PWQMLXpkcXR4bPNRO32wuni7NTHXzeRRCTlIEINf52X0X40chzjYpgb6k
XASHVAbwUbDoMyKuXt65O9xzOTPydmsVIPzH2eGnk92f9zd+OVz/43z3v24O
/32xC8gFLWAWkAv0n8u9v862wfYAc1Bcny/OHGvGD+dHzxbVLzbm3+0tnS/e
Lr94pZs4nx89nhwCCE+2NU22UQcaK3vo5X0Mcm9TXQetml1d2VJT1UisZJHJ
zTVkFrm6g1EPyB3p7BjgA3ipkqY6cWNtO5XEqS7j1RJ72I0qUdtoZ/u4rGO6
TzIs4Ylb6J3seimXwW0kt5LLQW4n5mTlJkVnRQWDMJ+XHJOfHEUpgDMJ+Twy
Tkwrk9LLuhvKehvLexrKOlk1oqZqaQtNIeSopHylhA8oVsk6RuRiVa9IKRcO
9/KHetvkUpakg97RVlPPIJcTsTmFSCQGlo3LzC7LQJESkZRwRL1vTosHkm2b
0WSSyTbLEzpgxK4Inh04yMERnoKxjkY8i8sxhpbbomsdkZTbqWZAesyut0mq
fBpR/BhS41QuSsZwosp4ntlUS0yjM5bpHVtk6AX5KhLzKINkVSUMy6U7QCpM
0RRnYH/wMi84wR+kd2ynUw7HHMezLWgwRZIeICofpuDvQCmGWc3WrhgD16Iv
I2ueBRb/EIr5IQ3/DFL8JAP9qLTaubzW81ZUr4ycZ1Gp36JxNoRaH3SJfXax
LRJrl5D5JCLtXiraDFHskFvlWET1KqzxQ5X5ZuODiqrjS2pTQUtvR1exILR2
eLOkoKULKx2hj+lEw3P8qbmeXgWL01FKrE/OKfPIrnDIqXFCku3wnIDcBrfs
OgdojVlSxUNIzSN4w+OMurtLqtGlsfHVyamthfmjFf3xxhqAaGV2cn9l8Wx7
HcTL6/1NUPOeb+jBYb+vmd1dmDxamjtfXbpYWz7VL+3MzS2PjM0rBtcnppRC
MbW4GJ0Yn+DnFexoWwJP148Pbek0gFMALyAX8ALIfXF8eLm3c324D+A9WNUD
gc7n/qZ2AfALxpDP81tuLSysTk+vT89szMwCLY6OLanVtwsCrqwAXe7v/fzi
5vf3H3998wHw+/IMVMo3H168BQ+BALyA2f/+9Pf/0R8//QqefXW4d7KmP99c
A+8ExIBPb98AvbkAFry3p1/ST05MyLvBkb8yNnSxqr1a0x1oJ/Rj/YCC3JSY
AHsLF9NnrmaG7qbGUR5uyQE+WRGhRDi0k1I10sqcF/O3hnuf63Uf9rc/nR18
2Nt8s7n888Hanxc7/7k++H/eX/zfb07/54tDwC8A+Y/jjY+7qx+2ll9uLD5f
WTjTTQNyd6YGgM6X1G93dSBdv9qcf7epvVme3lTJ5zp54CWk1Co2NouCTCKk
ReHTYovTEvKS43PTkrFwOCotLTs1FQOFVuTnMYjlICqLGuo66DUdDTVdTBpg
FrRCOlncQOnnMscl/AFeM6B4okekFLcJmVQ+g9LeWFNfVdJIwJZnwxAxEeCf
GOnuHOHmFO/nDgn1L0xPAOVDEz6PSyoU15Z01xPElEIuAckAiboin0vBdzXX
DXa0KLvaR2XCcXknQHhIxh+UtgN+RxSCEUX7oLy1v7uZw6XTGoklFQXZBXB4
AQxZAoWVxieX+KeUuaOY3rlcT0iTZXKjEbzNFilwgrCt8kg+eSQ/WIlLQo4l
BOeArfcvbPCCEk1zGbaFHMdMmkky8WlcuSGc7kEQpSAbwnLrbZEUS4AqgmwX
lns/KPtOWoU58GuKJCynzgZSapRPca1kxlQyUmubUWxxeYXCD8EyLWqxwlCe
QTHfIIruwArvpOHuplU9dcgycEIbhBGfBGDvBOZ8l1T8BIo3hqONK8neNbRA
Yo0PluASn/pjaPTXUJRZDs4JhXXIL3VH41zSUVapKCsYxiEjzy4b71RaF0Rs
TKhtyWoR4dmiivpWbB0bw+ookY/Xa7a6ZlaF/WrWhK5z+2zm4Eq3rp/RaYfF
XXXF5dHpOXbQQktgwcT24GpReE69cyrROKb0XljRV/HlP0BoD9OodzQDg8uq
kfXJyd35+cOlpePV5aOVpd1lLYAXkHsL79bqxfri6YrmQDO9OTW6Mz8B+D1b
1Z6tLB4v6fY1GvC7umEVGAemenubKioQsdGpwf6Z0SEt1WXgt4D53hwdAM8F
2AKTBdgCnM93toDAU9uL2p0lHSD3aH0VjBvrC3MgvR9trB+srYI8MNnfPyqV
Tcr7FpUjYJRYGFYCo79d0lSjAdu8Pj8D6AFOAa3AeT/z+zlCA1RBYP6v3/4C
zgtaADJogReDp96cHJ+srZ5trL85u71V6o/3P/325u3L0zMQxfXTs5MDAz28
NgmTMdEtAX/vhV778/n+h8uD0zXdcGd7dXF+RnREoLOTk4mxzaNHDk+euDx7
GupgiwgNIaQlt5WXLnSJjudnX2+uAoRv1haBpb5c13zY1384WP5fL4/+vtj+
eKB/t6F5vTr3emXhlX4e6PXWMjDf/VnViko229M+JW3VDYh2pxQnmpEz3djL
9fnn+ttJa8cEXGl9bTOuKD/SL83LLtzGONDKxMfS1NXM2NXc3NPWPsDN3c/F
NdzbOys+rhSeWZ2Pbiwt4pLLe1obuljUziZKTwtdJeRMdfEnwFAgYA+1MUdE
rdNy0biM38NjdLczpG0NbHolKe/2PFSYi5O3jaWHpRnYv5+9TYyvR0ZEYDE0
GRTFrLK8dnKRlFYK+OWUwqvy0smYDHpJNodcAl6lj9cEBgRgxP1CjlzQ0tPB
kotaBrpbh3pbB3o5ip6WTkmzUMRiMMmlZRiQolHFmVnFSUmYwKQSTwwztEQY
Dm92Tqk3h7bYZ3KdUpnWCLw7vNQNWuSSgXVBk/yxjSH5NK+MSjNUvVUeyxpK
fZZaY5haY4li+mP5KYlEn0TcAxjJDOTnZIJJeN69hBJDTJN7tSi4rM2nmOGc
X+tQVOtTx0nvVdaqZwRDI+2Vg0GQuqcYunkR0TAL/hU27x4O+xRV8DAu5zuX
NAMXuEFwyYOw4geRhQ8Tip7E59zPghkV5jsU5NnDs0xTkh8GB38ZEPxFKtQk
HW6RjXHBVgRgCH5Zha7oUu9cgi8k1wFaaIMmeJJZacq5ls3TsclFaaeioUfV
zO0izq52nb6eXdqVd8gprZ1Vw1Oi5R31/PjQ9Eg3g16QkmYfk/osLc80n+JE
EUdi2Z5Iul1ypVEQ5nu/3C+SyE/RbBs402xO1qvp7V8cHF4bV2/PTu9q54/0
iyAqn2+tgKgJcvIhKHg1t5M07kyMrioHtmbHDnQzx8vzh7r5A+3CEUizCwsb
U1MLg4MzfX3s6mpkXAw6MRZUWxM94suNxYvd7duVvk+PgecCkwUtEIjKwOgB
uWvzs0CgA7wPOPXK7PTmkm5Dq1mcmhyTy+V8fg+3bUwiBeODZnAYIAz4nVIo
dGo1qNNB7v351Ytf3n549+LNy8sboLc3rz+8fv/bTx//+OUT0L8//fVff/z7
dg6f3/4E/b9+/ePTh19fHByAKH6wsvbq5OyXF7cLxADvPt87Xp3TzqrG+0Wd
7NpaGh4va2GtqUeOFxdONxavdlef74F3Oz/e38NtoBOLirBIZHJoaJSXt4+l
taepWbCdbaqvd11e7pykc2d64nJl6c3W2suNW28F8H462wB6uzn3fGn8cHpw
e6RnZ1R+ODF8OTd5o509Whjbm1FuqhXLw10z3W2jQuZ4J3O2h7czpVgd6d6Z
GrpcnnuxvnSu00xJxMzS0vyYwAQPOx/Txy6GDx2Nnlo/fWptaGRvZulu5+xi
bedt7xjp7ZUU4AccE5saX1eQLWLUcCllHDJeyqROSwXLQz2a3s7xjtZRPlst
bpuVi6d6hUpxq0rKG5S0drRQCShUSkiIl5W1s6mpk4mJvaGhm4VFiJtrYpA/
Jj2BWoxmVxbxa3BSOr63kdBNK2ksRTBKUYyynGZiAY9aJmHWdnPqZVwGiNN9
HWzAL1C3qEkmbACSiup7JE39Mk5nB6uBRiIQMNhSVF4JNAsbnUkIKWUnkjqT
8lv9oQ0OMJZjJscljeGQCewM45hR5J5HCimiRqGq/WCVjhCiJYJukcOygtUb
ZTGs0M2eOGF8WWdmMikoBnsfwAtyZlzx05Dcuwl4I3S9A4HrXdTkVEC3L2nw
JDEiWvioiRne+vrI7JSc0BOQXv2ksNa8rNwMC79Tm29Mw1qWFxrDEHfCM770
hhh4ZX0ZnHMnrvBpXM7DwKR/pUTdT4p6GBNyJ9T/62D/r/19vwwM+CYq5mFa
hhUK41FKCsdWhKFwfoWk8AJiWBraNbvEEVZgR6iNGZ1n33xYOb7WjM2JpIMN
vC7SuIa3fjS4sN4lUdAaODiOkKwYFcwMygYlzeXFiTFRhnFpjyH5RsgKCyzT
JafBsYDtlc1wC8c99c2/A6HbFfB9MxkOM6KuSZF4SiKZk/fqhgZX1WO72tmz
9eV/4NXua6e3psd2psf3p9Xb48rVAbl+fBAgDFL01szEztzMoU5zoNVu/TM3
7FhXF5dCxmVCy1HwAQHneHnuelv/+uzo3eXtVdPA0I/W9aA93VoD4Xx7cQGk
dK16RDcxCjrrCzOgBf3Fmclp5dCQrEvK43ayWN1sNtgtSAjawaFVtVqnVKp7
enQT4y9Pj3978+rN1Tlg9sXF9edp9N6/fAv4/Tz11p8ffwfM/uf3vz+3AOR/
5vD5+Wx9a216bmNBe7V39Pbixe00BefXpzuHm9qVGaVa0tpeVVicnw6hl5aO
SzrXxsc2dVOA3INV3e6KbnV+dmF8bFqpAuritdcTqxDxSeEubsH2DtGu7tiU
lA4KZX18ZG926nIFBOD1jyebn863/rzc/utq68Ou9kY/cTg5sDrQqe3ma7r4
C50CIJWANS7mLPR1rI/1bk30rY1J9arO1dGu7cn+2yytn3t3sPnhaP/VzrZ+
ZFRU34hLj4cG+4Y4WvtYWbiYmVk/M7E2MnewdLAytrIyNLMxMnY0NnYzMQq0
Mc8M9SXC0ylYVC0WVY/P51MrgedOS/jz0o6Zzna1kAsoBnaslvFVnVzAr7yD
1VxXTkChU8MivW3snc0tncws7ExMHcyAv9uGurtlRIWWoaAMUAVXY8W1xXJG
mZJD6mbdqquRKKKVCWhlHfVEPo3IqSHw6qs7WJRODq2zjSbm0SR8WreooU/G
krXX9osZwJSFnIamOlI1EVdWnocrhxZWJVU2p1bxU4o5IchG96wm1yymG4zh
hsR7ZRS6wEv9cHUJxbQEGMErudgGQrROrzLKohul1T4G/OZyfctl6dVyTAY1
Jh73JKfeNavWPizvQRDqbjT2cTrRJIdmi2mwh5Q8xVQ5NbaldIiLh4da5tQ9
yl5REd8LSjIqqbYm462o2YbcfBugpgJbYoFFJuKBb7yBY7SBT9oXUch7kdAf
guINEgLvhXl+7e9kEOj6ZZjvD1HB90MD7vp6f5eYZJGJcisuj8ARY4pJsdVN
sBo2AlsTj8LZpSJNsovcmtrQs0vCi5eapY1+Jre4Q1Y5MNagXuBM69rV821C
GZnOKqxnlXApJeTCNEisbUTYneSMh3CsIbLSBFVriWG6lghCsO2hSdWOwcWm
qVR3BCswluSg6ZJNCoSj7Xy1SDTdLdMNK7ZnJ0FtCypc4LwbkyPLSsXayMDW
2PD6UL+uWzLT37U8NrA+NbIyrlqbGN+dn92endWPjQHzlXO5IHm21dawqytn
+qWvDzZe7q29OT9+e3Fyfbh7uLa8p9cdb6yAzpZufnlaPT86PDEgnxzsAx1A
7sKYcnpYMaUaUkjEgmYmr57Or6/vYrGGBR0zvXJw9AJphobmh4Z2ddp3Vxcf
X714dXEKsH1+enl5fA78FxgxQPjnNz8BnwX6TDHAFvALBHz59fOXe7pljUqt
HZ86Wt252j99cXL96uzF88PLrcWNWdWEmN2GQ6CSgoJzk5M5VdW97JYxhWx5
dnxraWFlYXZVM397iu3w5PLgeEOzNDmgbCbX5aSkJ/oFRLt7wkLDq7NzxsQi
tUQEPrTrjaXfL3b/uNwB/P77euc/V9u/Hi5fL05sKmUT7cxOclljXnYVNJWE
SqcWZLZVF6sEjOVhye5M/4lOdbE8caIdfbGl++P50aerk5fbW6d6/frEjLJT
yiAUUTBoPAKGTk2JDQx2tXEE5NqY29pZ2ttZ2DiYWgLf9LOxSA30IiEgbSQc
nZB7ewNgZVFnPUnVzpyV8bU9Qk13h17RpZGLdAMS7WDX/JBkdkiiEDc31hQX
QLOSgsM8bR2dzKyczK2BwD7/f4RdkPERNYXIVlKRoLpIRi9RccgjAvqYsEHV
0dDHrpU0VQnqKpiV2Jqi7KKspIqCLHplYVNtCYtO4DIrJfw6UP8qBBQFnzYo
bBoUc2Vtzez6mloStrwyu6w6g0BNLG2MwTaF5DR4I+luWfVuSIYnutwPXuKN
wAfmk6LzqqKzygMgBGfAb2LF41TK41jincSaZwD2EnFKVV9hZn1KUplJTqNb
OtE6APlDYPYdkHsT8U+ya62QNRYJ+T/mlts3taULRSXDfc3D3QJ2LRlGs8og
GOIrrGlYa0CuDOPSgbQRF7qxSlzQsEeBEQbeMQahGd+Fpn0Tkfx1StYjeIxF
nM+9EJfvwj3vxgY8Tgw3Dgt86OJgEBr2JC7ZGpnvhymLLKlJpPPyOFJ8vQCT
VWiaBH+CKnYm1ERRGDDFaOPIdCu5PrOBje5SEHuV1bLBqp6hWragBFeRgiqI
ykv0ifM1DPX8Nibyu2TIHRjmPrLSEFljDsJzJs0ZVu+TQvGOLHOOI3kmkn3C
8U4rfYpZUecolzfGF0x0STSDfYDfy3U9cNi1SdW8ontSKpqTiRd7pfMS4TiP
MwqMY6hHPz60NDKkH1NuTE0AW5xTKNQymaixcVDQPtUr7Wtja5V97463X+2v
A3JvjvaA7QLDBdgerC4B893QzH6GV9XTBQQQnlEOTA31j/V1jw30dfG4LCqF
WV3VWlvbUV/f3dwywGtfV08ACwYvtDo5ebWz/dP11Yeb568vzwCSVycXF0dn
N+fP31y/Avrp1TuA6udpMIHhApA/R2jwc7DZ1vzitEI5MzS+pVs92Ty8Orh4
c/EaaHVeP6OcFLe0F8PRkZ4+AMkSWCaloLCqtKBX1D4/oZoZVS7OTD0/Pf3w
+u2r89tJQl6dPt/ULPW0Cmg4AgGOpBZguxqZrVWk1qrKgbaWY93M39eH//3q
+H+9Ofnfv1z+frIKLPhKO7qiEPc3kqnZGVl+npFW5gle9kk+9tnRfrUYKDCy
hf72/bmBq5Wp9/tL7w/XPp4f/LPO8t6rg8Oj5dXpvuGJLuEU+MT6evo7Omrw
FfGRsW6OHs52rq4O7q6gtbLzsLKKdHcuSI3jlBf3M6n9fIa0ubarqUbJZ+qH
ZIdTyt3xgdVB2aJcPNctWOgTAX41SunccFcPv5FMQGfGJkV5B7hY2NgaWTia
2Thb2dubWVsZmrhaW3nbWiWH+JILEHxKqYiCA/yOtNYM86iA3zEhY4BL62aS
+dRyemkeITs9KcQzOzmiNAdSWQyvLEGQy1EseomAS56UNQ4L6Uohc7JbNC4V
i5ubaKSSCgKisgqKJcbkk4IK6wLyaD4Iqhu8zi270Tub4IMs9c/CBUKLA+D4
EFRVKLLaF0KyTa0yTKt9El3xfQzxYRrNsUiQVCXHwhvTsiiOhc1+EJKNH/L7
QPTdcMz9GNwDRI1FSumjlIIHRdWuNGYSj1c0OyYe6xWDYiG29FEq9lFJiSUt
36qz0GUQ496VZdeH82ktckUl3Q0JMYjLuJOeZxiZ+n1U8ncYnB0+0xcWZh7r
9SDK636sH+DXJDLwsZOdQUDAg5BIwxSoSxYmII8QRWqCNwqxdbz8HLw1JMeI
VB9OZaVC0W55uNBGTl4FJQVVFMDuyBN0Y6nMDBItBVcZD832T4Z65ia4gp0n
htxDwgzTod8nwr+A4n5MIzxMIDzxQ98NLDCOJ3rGEX0jyrwjy/0iynz1kvZx
dr20tlJGJ4M0tbswcbahO17TzI32jfYK5HxGP69eyW8c5tEULJKMjldy6dOd
bP2AeGOsZ03VvTwoWVSIwTA+IeFOdrXN9YlASTXdI9yYGLre0L3YWjra2Lyd
WW5nC1TWq+qR1fEh8NTt5UyKzkkQ23jNox3c6S7RlEyilnSOioRjneLuZhar
orwag6nFYltrqdLW1j6+cGF0fGJAuaCeOt49BJ57dXp5enBydfr8+eHB1cE+
0M3x0evzi5+ub355+erX12/+/vDrZ/3Xxz//+9e/fnv94Wz7cHlaMzcyAIYO
zbhKD/L/kubz2SvwDrd1utXZ2WFpN7OqJjcNFunlH+cfUpSZjUlKrSvEyphN
s7IuUESAVPzpZPeXg80/zw/+ujr64+Loze7WsVazPTm9PT17ML/45mDtxc7y
zfbSq921Dye7wD3/fnn5329f/uf1zR/Pr346Ojxb1oM40VRWDgkJ9Ta3DLJy
d3ti7WlkleIbXA5H8mqq5vulz9e17w5Wfzpa/3i2/ev5zvvDDeDmp0tzJ7rb
M3fXuxugulkcG+5qrqfi8oszU/KSYzJCfeK8HEPsjEPtTaAhnrV5UDmLMtfd
vqBSLk+ol8ZHNCA+Dcu31EO7k0Pbo/KVAcnqYJe2R6Dp5g+20rvqq/qa69rJ
ZeUFuYFuLlbPngLPBYHc2tDSydrZ2dLJxdLRy84pzs8fB0tnk/Bg58OtVGUr
ZVzUqJawVCKmnNcgYNbUV+OLC26nsIsKDQzwdg/2ck0ND8lJiiuFpbEIWEUL
Qy5u6uLXyTrqFLL6vi4qn13aRMtvoBY0NpTQG0trGbgqBqa8IQtLTyygR+bR
Q1NqfRKr3RKrnKFUz9wm34ImXzTVCVZpjqq2ycAbJ2KfppSaZpJskbUuuY0+
Rc0h2JaIzBrHlMpn3ggDf7RBYvkXibjvShp9sNWhuPKkckIWvQrDoxe105EN
hJAyhA0B5VgBtaVDHASZ7nKEbz/CpwftJy4OZpUFpSU/CYq9EwUzDU818gv7
MSriaWaKLRpilQu1TYt+kpFgSiwNwWODwkLvW1kbuHl+EZdmDst1Tsm2Scq2
Si+wLyD7U/lpjNb83OIQVHFQQzuiSYhAEtzic4zhZU4p+eYFVd4iBbaOmV5C
CC8vT0hLdoKmekSEf5uW+jgp+cdkyN0k2L1k5EMk3jYNawOr8EjEucSWgo/C
O7HGPZxoHUw0Ca8xmWhtHGHVKRi1wxzGgrxzb37iaGV+f3l2YlDazWOyyKWN
ZfnNxAJ+DU5cWyKpLRVRy/pbqFOSVoAtgFfXL5qXC+d6O/4ZyWXr6kEg/Ujf
gXbizf7Gu8Ots62t8+3tk7XVjdmppdGBRWUf2EzTDyrutnEhW9nGGua1jAra
xjuFIHkqBfwBXlsHra6hFF9TWFiHwzVXkyVs9kBn1/zIGOBXOzlzsncEPPf5
2dXlycWLy5fXR4ef9eLkGPD75uLy7eUV0OcFI357/f6vn377/e0v14fn+hnt
WN/wrGoQBPXFyTFQboMYsKdfOlpfPdnY2AcBdX5+QTk6DDIqsTolNCrI2SM1
LLoElkVE5zaW4DvqqCNC3vaE6sW67v3e2i9HW5+nf//t/OTd/t7Lze1XO3vv
Do4+XuwB/Xq5//vzk89rI/771RXQ//70y//14e3fL24AwruzczJWc0FqWqij
E4DX9YmFt4lNkLVjqL1jaoBvQ2kBGACvNzSvdm4t+MPxxruD9ZfbKwDh6/Xl
f797+fHy6GxVu6IeXhjq1f6juX6phEHhkgml0PgkH8fs6IAOCl7bJ1xVymYG
B/ST41vzU1ugCpge3ZlUrip7ZmW8BVm7Ti6Y62pbAkOujAei9UhHs5hOrCjM
i/TzcrY0d7W2sTE2s3xm6mTh4GLl5O/iFe7tD4uOrspDCeqIAxzaCI8+0kYd
5FIGudT+NtpAB6Nf1MJjUovz4DHht/C6Odp6OlhHeLmnBvsjYsKqUXAhhSRm
1wqbq4UtREkbsbO9UsDBtzJx7CZ8awuphUNqYldSm7GVjGxcQ2pRQ3RRYwSE
5pta65VKcYfTvQpaAovZAZgG9+waW3SNNbTMKKn4SUrJM2ilJaLWCcP0LW0L
LefHw2ud4/EP/FAGsXgDRN295NIfsol2eeX+FeQMCjmvCg8nFiVTiqPJGF88
0qYw07okw4oCsWnPdOtB+HRneoqy3FtzvOoKPRPi7wdEfx+RYRya/Mw39G5Y
yMPkaJOcTLscmENavDEsxaqiNIxQEhYfa+Lq8WV4rGFMsnkSzAaS45SCsg1J
fRKPtCylR4h6SMBzw5NNEcVejA54U2dWIcU3AW0cjzLKJ3oCfhmtWSRyApUK
g8N80pNcwYsCfpNT7qVlPopJ/S4a8n1WsU1qgRWqOiAZ5x5d6BiFc4zA24fi
zcIqTONqrabamnQS3rZSfjqnvlnT3mzpD5fnV6ZHugUtbGplVRGKmAsj52dS
82HUnAwqOp2BQwlqSoe49aCSAhgCeKdl7equ9rm+zsXhnt3Z8f2FyY1J1YFm
6uXO6uu99Vt+NzcOlnWrU2MgVANzmZF1jIs5CjZdyWsa5jL7WA19zQwlj6sU
8AbauF1NjOZKYmVODhYKLc7KqsWViFiskR65un9gVD4wPz65t7EFqt3jvaOj
3UOA8MvTk/+jz1PqPT/8Z56fs6tXp5fvr1788uLdzdEFgFfZrejt6FJ0dii7
JWpF79zI0OKkegOUtOurwH9PbheG0GzMLuxoFqf6B6uLcJmxCfkQGB6OwsOR
NZiCthrykKBNNyjfm1NfrMy/2tF/ON75/er4j6vTX8+Ofz4++nB88svp2dvD
9Z9OtgDCv10dAIT/vDn796vL/7x+/j/f31rwnzeXv56fXa6ugJhRkY2M8fB0
e2oJ5GFo6fLE0P7+wxB7G1pxHvgkj7Tqy9W5l9uL4IVuNhev1nSXq1ogYOtX
64uH2mnwOYOHAG3gzmCb3dlRMGwqWuubywvaa/BTUt7qSC8IOYvjIzva+bP1
ZYD8kW5mb3pE1985wm8a4TWMC5pAmlroFYAcBf6Vsz0CeUsdIR/E3pBwH6+o
AP9gL+8Ad5/ooPDkqHhIbGJ2anpFbi67qkzOaVCLWqbELHVHg6qNquCQQfLv
bKoSMsksagUuH5ESH+npYudgbe5oaeZlbx3s4hjj5YaOi6zJR7U1kPigTGYR
+UyCoBnf0VoubCW2t5DaONXc1ppmTjWNha+oRxbXJRfSYgtpkYDftFqP9Bo3
wC+m2Q/b4o9pdEVRbFC1VlmVxqn4x0Dp5UawaqtchmtJWyCOHZZV4xBXci84
1yCx4l9ZtXfjsd+kYY0RxR648oQyPLQoJ7EIEV6RH0LK98YjbFEQU0yaSXWG
TSvcrRPhKYS6ciAOVKhtZY5TbMxdn8hvAYlBCQ99g+8EBd6JCnqIgDrAM+yT
E8xTkyxzUN4IhGdYhKGL57cpMKf4dLuoVKs4qE1cpnVA4uPglGcwrFsdE5FX
EhKaaBgU9whZ4lHNTsDWBkTDnySgTApIvgJ5EbUpDVMcgsfHpqe4hgebJSc/
TUp6lJT2MAPxNDTuy4AYg/Rc8/hs0wycW3y+c0y+UzzONa7UOaLYPAJvGk+y
1Hd3bA/KjiaVZ5qpc/3C8eLssnpY3SeVcJoaiHg8CoaFpWAhiQUJkXnRIUB4
WEJdIUJYVzHc3jQpuSV3VMxVCbkTMuHCQPfunPp4cW5zZmxnfuIcHHIbS2cb
q0DHKzow/gOnmJQJxoStI3yWuK4SBLYBdqOsgdpJo8hZjQouW85miRmM1pqa
suxsSFhYenhEJQYj43InB4aGZN3D3T0zI+MbyysHW3vba1u7Gzsn+8fvn1+9
u7r8PB/m5f7B2c7uydb2yebui+NzoNdn1wDe9YXlIWmfrF3cL+6W8rhiTktn
K7tP1KFW9AGEgQXf3ki1vn6wvLy3uHi+uXmyujGjGJLzBCqJjEOpY5LIIMYr
BAKdcmhrZuJEvwCGpp+Od3452/90dfz75cnH06P3B7vAhd/u7f7jm/o3e6tA
gKxPl0f/eXX5P9/dfLq43fLTxenPxwfnyzqQN6pzcxJ9vIOsXYH5uj01dX1q
5GVqkuDtUVuIHha07M2NXazMvt5dfr0LnFd3saIB+flIe3uZx/Xa/E8Hqx9P
Nn872/50vgM67/dXTnUT62N9OoV0RSm/vbdCIZ3tFs71iNbnJg6XNUf6BVAZ
rU0MLg/LpqRcBYcqb6oG6iDjVPxGwK9e2Q1gHxawGFX48gJ0aW52eSGmNC+3
AIEszS0AhTa1rIJZXc1voPVyGKNizmwPb0bWMiFsHGJXjfDqVPz6Hjalra6s
rhyDy83MhiZ5udo72VoCfl2tLT2tLXztrON9vdEJMQxSSXtDlYRDETUTxexK
KY/c1VbTziJxWVVcNqWFXdPYXE5mYAg0aHFdUjEtDkb3h1J9oBTPbLo3cNhC
lm9+g8tnfuHVIDkbw4hGkMpn6SRDZJ11QYtrBtE+vdIiruRuKMYgFmcQhzOI
zjVIKTRMQdukQN1SU71RmWHlmDhKSUxFnndBhgUs7WkOxISYactEubZne3Bh
zvRU67Jkk4pcx4TEe75R3wUkPvCL+dEv5IfgoLuhfj9AMuyhMOd0iENisk1c
gnVQmKGb14/2rt9GJdkmZriEJVr6Rj2NTLNKRjpFw2xCU01gOe5orH8K0s4r
/Dv3sC+jswyTcszCIA8iIY9ReA+WMBtXGR4WbRwdYxUaYubt9Sg24WF03I/J
aY/hOWaAX+9Qg6Qsw0jI00ioWSLaGVUZWsJIAskko9ItscQyiWB+Njm8P9a/
Pti9pJDpRxSbU6Mrk6MLqqGhTiGHWkNAI3OTE+GRYZAAP2igb05EaHqwV15S
JKUAKair6ucylULuiJinEvEmu8Xzgz2789Pnq0u72tnPJ6GAzjf0l1urV5vL
B5ppzUC3sr0ZYAvEqyyW0kg9DGpnHZlfUwkQljY1yJiNgN8uFouGx0OjoiER
kXUEQr9INNrbJ+MLFJKuadXY2uLyztoG0OHOAUjRoNr9cPMC8AtsF5B7sLZ+
sLp5tL59c3T2+Y6GnaX1kd5BMaejRyCdGlIPybqE7OaWulpeY6O8o2NyYGB5
ampXpzteXQXkHutXjpb1N7t7L/cPrnd2QbupWZofUYMBZEmt3l9avNrZ/HBx
/J/3L/5+fQkEEvIf12e/XR4DC/7l5BAIkPXr6RYg6+fDTaDfTneBPi+R9uns
4Pezow/72+e6+fmeLl4VkQCFRLv4BFo5eJmYB1jZxHl65MTH1JdgpEzaxsTQ
uX4OjAA/n2yDFowGL7b0wIXfrs//vLP4y+7S+23t282FN+sL1ysz5zr1zsSg
bkACKqAlZa9uqFvdJRjrbAdpRzM6uDKpAmPy/GD3RHf7eBdnsK1e2kjsZZFl
DFJTKQr0Fwc7F5VduiHprFw41isakrTLRa39YoG0vY1TT2fWUvhNTUNdXSMy
yYhUNCbhq6WtU9LWEQFd3lIpqsYMtpDmpC3zcr6ys7mVXonNyUiOCfFxd3Sx
t3awMHU0N3U0M3ExM/W3t4/x8fnnrhYMv7Faxqntaaf2C+t7+XRRC6WNSW5j
UVvZ1JZWSiOngtqMqWIiKhgZKEYEsj4YWeePovvnN/pjGrxA/QuvssgkmSDI
Zjl1lnl0awTFFFZlCKea5TPtk0rNUsqMwzFfh+cbxJcYxBf/K7Hou7RCoziY
aViMWVycU1FubG15RhU2qiDTITvZJB3yNDvTFARpOtqFhXZpgjuQ082xSU+J
WLdUyNOAuO99Y773jvg+KOJeVOTjsMAfE6H2kGw3RL4fBOkZFGXq5HXHzuOO
g9ePzr4P/CJMfcON/KONU5AeMIxvWLK5g++38RDLDLRjKsLaP+auc5CBZ8SX
frHfeUV+5RryrzS0bT0HVlAa4uj6jZ39lz6+T3y8n4ZE3IlJfJieaZJTaJcA
eRQU83Ui1DAy+Ul4sjEsz5vUCGV1Yut4WfnkgIxiuwyc9Zqic3VAsjIgXR2W
78yMHekAevMrU5MTffIeHo9Ho7OIRCI6BxUZk+bnBw0IDHOyTg7wLExPaMAX
SZpogNwpuWRO0Tt5+6WobH1m8mR1+WBJC3S6vgJ0uaW/3l55vrUMnB1UvgpO
o4haISQTOIQCPgkvpFR21BDbqsq4xLJ2UBzV17FrKJLmlrY6WikKVYxAsGtr
ZTy+mN3aQqOLWrkjff3amblV3dKmfvVk7+DV9c3759dAoPK9Ojg8XN/YWVoF
2tOvn+8cnW0fAngnB0clXJGwhT8kVegmFiaHBoXsFhqxklFd3cnhqLq7taOj
G3NzAOHn2ztna2t7Wu3VxsZPJycfTk9BCxI48HGwc+Dvby8vPlxffHx5+efb
m7/f3/zx6vLT9emvV8eA39+fn4IgDQTI/ev5ARCwxZ/2119vLZ9qp9ZHFfsz
46famYul25uIgY7mplaGFRNiASW/MDc+KdLZ1dvUPNDGGhYWSMPm97IbZ+Vi
YMHAygG8nyn++WT33cHmb7vzP61N32hUlwvDN4vjN0vqfXW/tkcwIW6dkHBH
BOyelgYJgyprru9vax5oZysl/Kl+KYB3Si4C/E7+c4lIP7t2RNAwzKOxK/Il
DZUA3iVl96Kqe2W8b3VWuTKt0oz2L4wPaNVKVU9XN583IBEvT4wtq1ULQz0T
3QIwCIyJm3qaia0kNLcMzq/M6aKVDvLqRjpbpK20iqLs5KjA2DA/P09nRxsL
W1NjGyNDOyMjZ3Nzb1vbUGdHZFwUrRQjZpL72ukDHY19HY09PEYbg8Kur2E2
kJmMKmYLqbEVX8fG1DBR+Y3xOfVR2bUhCEogosYni+QKIVgnYY1SSw0BxYUM
J1yza269dWa1EaAYw7CDVllDKowD4AYR+QYIysPsmscIomEK5lki3Cwd7lJQ
GFVDyiKXpxcifVFpNjkZ1knQJ1lwE0y2VTnStgZpR0HYlkPMclOelOHc0mCG
gF+P8K88w76JjH+akmwaE/44LM0yDu6IwAVnFgX4xhhbeX5n53PP0f+hicMX
Nh4/eIY+TYJ75JRGJMKdnfx/MHM2CIq5FwcxSUVYRaUbekd84xhg4BRoAIzY
JfiLJLgNrRlWVpPo7Pm9iYWBh/cjL68n3kFfp2ZaZOXY5RY7ITHA058kQ02i
Ew2jEs3Ts9xx5XE19dBycjwi3yUlC+zWWMmhzYg5ekXXlnoIVHYHmtmtmanF
UWDBqrlBpUY5ujCglDQ2F6VCYl08wmwdfa1Mwl3sYBFB5dkwDpnYz+NM9Uo1
QwPqXtlYd9fimGpvUQd86lC/fLaxfrq+drOzcnsV1qr2bHl2c3wQhOfOuipe
ZUlLaUFzCYZdhmuvKudU4BtKCpsIxe1UMoNEam9oEDAYLRRKE5nMrW9sZzCb
62g0IqmtiTkEIvT4uGZ6enlBe7C18+LiChS8L09vVxW/5Xdta0unX19Y3NDo
gdbml6aGxjpbhW2NHFm7ZKxPNauamlGNiFu5YG/1xCpeY1OvQDDR17c4Pr42
NX2s158sLx9oteerq9cb6zebG2/3915f3Px08+rj63cfX7/59e3rX9+++vnl
1dur009vrj/enL4/2393vAP00/Hu+4PtN7sbLze1r7cXb9YXALZAZ7pp8MGC
HDstFYDCf6qrY7ZbvD2herO9+vF4993u+vbkdA+rpSgtNdbDPcbdJTsmvLYg
p72WON0j3pkZ+fwdPqh/P6dx0P65O/dpa/rj+sSHtcmPW/MftzRXmpEtVbeC
VdtJI7IIhdV5tzNyULF5LGIZj0qW85tVUj6Ad6pXON8v1o92r412Lw2K53q4
873tnfUVA1z6xmT/0kiPTtmzOaPSqeU6df/UoGReJd/STC5NqCYV3dqxId3o
kHZEMauQgkFgqqdtspvT20JiliG5pXB6bnIVPLY2P72NgutqqQUWXFWajy9E
wVLiArzdnaz+QdjY5POlIM7PjKI9PfFwKJdS1sUiA0nZVMBvB7OumUquqyqj
kgkNjRUsTiWDXVrXjClhZRY2pOZS47OrwrMq/dNKXBMwVlFowySsKZxkj23y
wrG8QJxOAYUw4Qm8xiyjwgLw659lEFf0dT7dNLfWGF1lnpL7NAVhDpyOXAOt
LEvJyw7MgjghM+xzMu1iYY9TEUbwLJMcmEkR1ASfZQFaZOrj/Dzb+PRHPlFf
A9P0CP06PtUUmmmbEGvkl2YUDDXLKPHLJAT7pZjZ+t+xC7hr7f2DicuX7mFP
ozIcsgoCs3HBMek2boF3XQPueId+E5NmmIG2S0JYBsT+6Bxg4BL4L2DoPhF3
I1JM8NWxFZQU/9Cndi7fhcfYhEZYuvl8kY1xReY7IvLtCvBumTnWSWnGMfFG
oMoODTOJibaBQNwyMpzjE0wio++DpK0fEG+PyvenlbtTqp3p8UPtHDh6LzY2
dxZ0W3Oa3YXlNfWstKkVHZccYGnvYWjuZvzU18rs9uuIxNiawjwBva5fwBuV
SaYV8jGZTDs6AuAFWfRsY+P57u7Fzs7NzvLpytzRIiiu5040k9r+LjmTxiOV
NeMKaRh0IxYDnLe5opRSmEPFYlrJxFYqvZXe0MFqAbYrbWsXMJtbGxqBGsg1
Qk4r8N+5iQnA79L8/N7Gxs35OcjMoOwFaflq/xjwu6FZWpnV6We0C2PTM0p1
b4esmdrEoTf3i3vVitGRHuXiJAiJElYtvaGKwqJQwfgga+WNyGRgyNqamdmZ
AzWm5mJFf7KkuVxZAqn49cXzDy9u11p6fnR8eXz87uX1rz8BkF/9/uH1zy8v
3p4dvDzYfLm3fr2pP9cvgPp0b3pkZ1KpH+4FURaUoscLE0fz6o2xgdtv7UTc
fnYDSCBLg91vd1b+fn78+/n+q+2t+b6edko1m1gOyv85uXRxqG9BIVsZHThb
ngfAAngvVuYByC+3l0H/0/rEn9szv29OvV8euVkYeqEdebM6DUL1OJ9Jw2Qj
IoIyQvwzwoJgkaHlKKSgkX57Z5+oVdXJHenkgL98a3rgbHEcSNPfsaKSKlpp
YxL23sLo0mjf/KB0bWZkfkQ2p5IqZbzxPuHm/Pja9OjcUK9+QjnRI57sFQPz
BfwuDIl0w6IhQT27Oq8hN5kMjyOkhxFg0fWl2Z1NVf0dzXIRR8hpIOELUmIi
PV0c7a3M7UzNbE1MbYzNXI3MIlzdi9LTmomlfFoFl4JvryuXttT38thtdBq1
ooxSWdpYT+S01ra2k1ncCko7nsTBEhjooroMNCkehg9OLvCIzbFLwTohiJ7Y
xuDCBt+MMqtI9P0I9N1E7OOovPuQMpMw1FepJfeyySaQ0kcIvGlqjmF02hMM
LgBfFpOR4R4TaZaebIuEOWakWkRAH8VnPUuGPU1Pe5yV/jg30xiVaZSR/giG
MIlIuusZ/oWTv4FXyDfJGZZwhHNigkkgwtg/0yiV4IGoDg5BWDlH33cI+9HU
+0sr32+S0O5oQnhGnlcSwjExyz4GYhGVZgZeNzHTJBVpkZRpHgcxjkp5Fhj9
o0fQN17BP7j6fZuS5VSAjwqNNQuIMEYVhMNzgx09DfJLfOD5TukIs0KCZ3ae
Q1zSs8ioZwEBj9xd7rg4fB/k+zQuyjw2yjAq7MeosLtHc6rj+ZFjzfiJZvpw
YXp7emp5dHRucGh5fHJfu3Ki39SPTsma20jowtSAUD9LO28LE7uHPzo+fZgU
4EPKy2mrrelp4wB+p/r6pvv7F1TKrYWFi62t6709gPDO4uLR0jTg92xl7nRp
5nRpbnN8uLuxjgiHAnKp+blkdDa9uLCRgCPloary0a3UaoCtTj05qxwZknUD
r1T29LKodTRSFauONijrnh9XqweHxoaGVrTao52dw+3br6o+L+xysXsIYjOw
3dW5xX/O806OypWKTnmfqEch7hvqGhiTj8wMT6l6BngMdmN1HZvWxKLQKPgy
ZlWNnNcO3r92eHhjQr03P703O7U/N3m+rHm9sw4GB2Du755fv7m8en56enly
+OLy7P2r6/c3V68uj68Pd6/3NwHCzzeWV8eHR0XtynZ2Ry2JV10OOvrhvnVQ
fir7V1V9gFxpI0VST1a2NwOcX24s/nK0BXS2tLA1Obo9NXazof94evDz8d7b
vU2gN3vrt1dOHu98ON56u78G+D3WTe3NjbyYkb+c7TsZEW/0cDblvMNR2bZK
uiDlsfGYwsSoOC/nCFf7YEfbIAe7tLCwitzcNnoVi0zg00mjkrZlVc+aWr47
PXixPLEx3qtViIY7mnpb6SOSttvLYhfU6zNjyxP9urFe7WiPdlQ+PSAZ7OAI
6slMYgkZk80iFosaq+Tc+rEujlbZqVOJZ/p5wy3kpqKsClhMFSqlsSRbQC/v
EzQNdHK4DAqTSqrAYSDJ8T7uLtamphZGRtam5i6G5r5WdtCw0JoCNNghoxzD
o1Yo+C3t9bVCZlNbQwO9mlRVjqurxbM5ZL6Qxuioq2gowVHyyhsKcbXojMKo
KLhnLMoT2F8OORxdHZSBd4XgHRAVLpAS60jko+jchxnl5jE5d5OKHqRiH8Wh
76blPwuI+Soly4xAiiooCg4Le+bndy8k6GFk+JPUFItIxNMwyINY2BMI0iQp
7WFI6L9Cw75ITH0AzDcw5jvXIAOv8G8BdGlwWwjMLjnFyjPzQSjGLLHcJZng
Fpln4ws18kk3CoaZR8BtoxF20Vm2UVDLWJhVYpZ1bIZ5WPITCNo6LsPQO+yr
wOi7aUib6FRjN/9vvEN+NLE1sHIy8Aq6H5loFRRlbOf5rb3nD6B8Doy8l5Jp
GZn0ODblCRRlCUVYJqWZ+PnfiY0y9/N67Gz7vb/XY0iSE8gPWRC7ApTL+dLE
89W5F+u3pyf25if1I6rZ/v4JWY9WNXY7f7tGv6KenVcM93H5BAQ6yN7Z7Puv
zX/4xv7RvRBHW0RsdB0O29vKnlP0jUqlE729GqVyfXb2YHkZWDBod7TanYWR
A90koPhkaQ4YCjhQB1vZ9UUF5ZmZpTBoMSQdC0kvyYIR0EgWmaSSdmr/mW5a
Mz41NaycHxvv7hDSq6oBvBJeu0reN6VUTQwPzk6M7ayvnB3unezvXO4dvTq9
vF2scPdwd3ljfWEZ+O/S1MJI7/BgVz/gF5ALBBDuF8lBK+J0gEQNfHlI2qcQ
dYvZbW20Bi4V1G6d0/KeJeXw2phqc2Jkb2r8cG4CjGkgRVwfHLw6OXl1dvri
7OT67Azw++r68nZCv5PDs9u7qJb3F+dXxlVKYbuAWl2Tj8KmJxWkxIMOt7pC
3ECRcxhjne3DAg7QuIS/rOoHQ9nr3ZXPXyy/2lm9WtNdbywBWt8fbr3YXAEg
A35/vzz5HVTWF4eg8gXOe7I4vTk5qB/p3e1vW5c1z3ApKkblFI++Khfo5cJp
EbuxGJ0TGx7pYg/+L/621q6mpr62tnEB/p+XQaknFMq5jQuKTrCHTXXf3szQ
2miPStjCIeNpJbksUqmkpWG4q0PdJ51X/n+aUYjkbQxGeSEWmgCPCcpNjixH
QerxucAxe1vrpuV8jbJzblCo7xf1McmC6mJhLUHUUClroSgEoCphStoY/GYa
nVyWj4RGBvo52VrZmJnZWVh4mtoF2rkgYmMZFThpc52EWQPUx2NJOc38RmC8
VZXYokp8cQONxOZQuW21LR3sWialqrGK3FRFoOIQuAxYUSK6EpJdkZRHTskl
xyLLgxFlfmiSP5rkCy/ziMp5nIgxikY9SMI8Sy8ySck1TEA8ASTml3oTKbE5
+T6BwQ/dPL5x9/jKw/Pr4JAHgen3I7OeJeVYQPIsU+BG0an3w+N/CEv4ITjm
e5/wrz2Dv/IN/z488WlihlUqzD4lw8Eb/cgP/TgwzzCiyDK22C62yD463zYK
bZOO80jIcQyDmISmGUVBTBOyLBLhlglZ5mGJ94EFe4V87exrEJHwNCbZ3Cf4
vmfAjz7BD/zDn8Wm2kGQnlGp1s5+P9h4fuUWfA/wmwyzCIm9FxjxXXTyg4R0
QyjcJjnFJjTU2MfjYXS4TXF+bFV5GjYvCA13yUe7XepnXm4vvjtYf7GlB9aj
GVCMdXUpheIJmVyvntqcXQAt0IxigE4oi/T08jQxdDV64vT0obvJs1gvtxIY
lEel/HO3uGhSLl8aG9tZWDha1h/rVw71eoDwxpxyb3HyRD97sa4DIRPk0jl5
r6SBUYFAYSHQzMjoxMAgWGwsuRQ3LOvaWV68PDg+3trVz2mAVua1cnFnayOj
r1MCbBcIwDuvHrudUu9w7/r85Or06HZJtcubtxfX5ztHW7pV4LxaMOCMzoBq
d0iq+IxtD18mbBZw6zkcWktHi1A9ML46C4aIOZVM0S/oFLPYrbXUfh5vrFM8
Ke2c6BKCEnV1uH97fAjoZHnxbG3t+fbtXVTvri5/enH97sWLNy9unp+fATs+
39/dX1len52ZHeyXczkg/1cgs3LiY6ChQVkRocjoCFRsFC4jhVqYK2PW97Yw
VEKudrBnf37i88lcMKCdLE4eaiaOtJNAOzNj6+PKg/kpQPHfNxd/XZ8DhH85
3Xu1oz9bnt6ZUa6rFVtyrkbQMEDDy2qKR5trV3o71oeki3KxrIFSCYcm+niG
ONj7Wls7GRm5mJj62tvH+brBooIrcrJEDZSZXtHqmGJtVL48LBsWtDSVFeYk
RkHCA2Ax4bnpKYT8XGo5QcgkS1tpg0IWkIBOAsxmhPrEeNgn+rpkRQYUpkVX
5kBaqorBswvDXYujsoVeYX8LrZtRM8BtULQ1DgqYKglnUNwCEJa2M9uaaqtK
C0AhHObn7evq7O3mHOHuH+Xpj0xIYBJL+3hNAx3M3rb6Xm5TH79V3MxiVNcQ
i3HlJVhqTUVzc20br54nbGdxW5pam+jshgoaMa88v5CUX8kkIPDpyLJUOCEW
VhwKKfKDlfjlVIYUUSJj0UYh0PuxKMPUfMusYvusIgeAT1j8A1SBWx7WJyPT
PjTioV/IPa+AHzz9vw+KeOQe820Y9GlirlVSjlUi0jQebhye+gCUve4hXwB4
QXL2Db8TGPUwMsEsEWKXluXik/PQJ+exf86TYIxxJNYmHucUj3WKL3ROLnSJ
zLIKg5glouwgec4JcMuQxEe+UXdsPQxC4x94Bn9t4WDgE/xjQrptVLx5UJhh
SJRZeKxlMswlM983KcvJJ/KxU9D3HhE/+ob+APw3POG+X9iXQVHfRiU+ROQ5
52J8Q0KN/fyfleJSlcPsTnEVEunl7/uDs5MB8ALgAq931262Vg40s4vDQ+ou
6XCHaJDfsTAwtD49szY1rVerZwcGOpubqoswwFwSfdy9TJ95mxnHebrl/r9d
nfdTW1m+7T3dPe12t9s5EEzOGSEhQAEhJCFyzslgk0wOJucgcpaIklAOKKGc
QGREDs5uz+25c2fe3Pum3j/xtqbfT69q1a5jm6JwcT7ftdbROftE498WF5Aa
6tfGx/iUeQ2Hc6BQnG9ughP+zGg0a7UGKWtXLTwxKi5M2muTAZRrLZvLmSaP
Nrc3FZWlRUZjAoMTsDjQcPUb8ivz4dXJxdHOgVGtNekMO4ZNEZfPXF1VSiQK
4bqYw5Jw2QbFBqDm3anZcvMzsMLjyy8X7z+d3Rxv7eulKilbKKBxAbxgZZDp
y5OLSxMLgN850hwQeYQsXFvfVGztqnd5K5yJnpGRtt7p3qEF0vDy8DBzcmJt
bJjS1bbQ1cqdGNKszhnWFrb57AOZ+GpT98l88OXiDCB8c3Z2eXp2fnxyYT45
29vf1xv0EgkIHszp6fm+vp7Kqqqs7BwCPiEsNNLfL9TVBenpGgUNKE6MrcpO
7aspX5sgGfjMY0CuSrIr5YuXLZdz6WM9tNFeYND8+Qk9Zw1EdxCk/2LeA/AC
fT3c/LSnBWP2ekv2QcnZZ83LJvv4w+0K8uihkH6tFl9rNw6lgqWB7tLURGIw
NNjNzfeFnY+dHeA3xM0JB/HLjca3lxVRR/qkK/NCytTqcG/3m1fZBAzCyxnu
4Yrw9Qnx8UEFBkah0KVZ8dWFaT2WqNwAkm19flouDpkYEhAL9cnEhBTF4wDR
vbUltIn+DdaiRkADNWG6tWGitZ7S10rubwXpem26nz4zsDhuuR1rYcJyR1ZT
5etXOek5KYnZyQl5cRmZxPj8xIS3pYXjXXWUoWbyYMvsQOtsfxeZNDTVP9jT
3FJXWV5XXdrV1Tgx0Ts2MU4aGe4fHujs765rbyipLytvrqjvr8urycqsSEwp
iUoqQkXnBsXk+meUhZU2R+Gy7SBRvxCyHRMKPbPLIPllMAzxGS7GGh9rQ0yw
i060B002Kt4eTXiGjHwG3NAn/DYE/2tI7KOwxKeIpCfIpCfw2PtB+J8hEXcC
0T8FhN0OCL0ThHwQhrXCxjgTkzz9M+8jXtpEljsDeMPy7BE59ph8V+JLn+hC
v/BUp8h014xSeG4lMjrTLRB11w3yJ2ffW5iYp6GRD1x9b0ERD/DRLhicYxj6
RXCYVTDyeXiUAzHVMzLJKSjyoQ/6TkDkL/7B3yWkOxITrdCEu2HYH1H4X1Jz
3HOLYGFoGyj8eVtn0f6RUCKfqa6PS0jzwMe+MKtFpzrphUF5YVAdKWV6Lke0
uMSYmuLOzwsXFxUs1pZUZJKJNUK2kkfXCJlz7c1gzieFQJNDYTlYdD4xsjYn
c6iuenVkkDU1KadRDzZk73e3Px8eXm1tHSqVRjl3Tyc9M2kudgyA6H2lSscV
ri+vsWaXJzpJtcWVyYS4lOiE4b6BbePm9bkFXqAdg8mk29zbNG3rjTqFAkgq
EEiFPN2G1Ly9dXNyBPj9A+Hrw7MPJ1fvzBcH+m2lQAqwZS7QqbPLDAqNOrMC
kjPgdIOzoRPrdlQ7ZqPZvHm6Kd8GFFNGgc/0DTR1THUNgGG1QhpmTU4wR4dm
25tG6ypmm6vpA+2c0W7VEnmPx7rRq78c7n48PLzc2wPMnuwfnhwcnx6egB91
S6VVCdZF1DX61DSlf7D9jeURvCxidAI6HAeFwt3dAx0dIc4Ofva2aH+vwqTY
8c4WJYd2pN3YV0ksV4dWxqmj7RNtlROt1SukLsDXjoh3rlV82N78uGMEQRqE
asDvb0fG38x6oH8c6N+phLvsZQN1zsRcPpHyP26qfzfv/rZn0rLWJttaq3Jy
UrBYtJ9/oLOzr709yNIIT/foYMjr5PiRxhrayACIAcMN1TXZabEh0ED7F0HO
znBPTz8nFx9HV5iXXwIGlhIBf5VCBMmZ1FDR8jKrKAabiYbn41A1mYk9lcXj
rfUg7gpWZmXMJQljkT0zMdXRMtRQRWqsAn0WoD3aVjXZVbcw0rE63cekjDIW
JlZmhmeGe0d7O0hdrR01b99WVIO41VFTQmqvmuipBRrtqOtrqiJ1tI339Q53
93S2NLW+revpeTs62jU8PDQ42N/b39PZ19Xa09rQ9bauq7G2t64CzKPG3Oyq
pNTX2Pj8kJjcwNRieEFNRHiqnX/EPXy6W0Kuf2ZxSO6rsHCCLS7GjhBtGxVr
FZ/mmJzlio+3DYt8jMA9Cye+CMT+6hn2Z/ew7/xxvwRE3fPB3Qki3gtPsQmP
fw6PfOAPv+0Nue0P/xVk3TCcPZLo5Jv8AFFoH1Xhgy/zjnjpHpHvhc3ziczx
SSoJI2T5EbP9s8rQeZXYuKyAUIJNEOYJiN8xaU6RcS9gyIdIjE0oyjog8AEU
9hQCe+oPewQJexSKswohPPEL/8kT+b1X+PfQkB/Ssp3j020xxLshmB+Cw/9M
TLZNzPAiJLgHo2yr3mZs6FdowqGajqRXddjyZvypdgPoTKcAAuHWtC5U0GkC
MsUoFIqWF7kL80rOmkHC1a4zjVLuoVFmZNE446TZ1saR2jedr1825GT0lL2i
9HZwZyaF5Fk1g2ZWKj7v730zH70zbYFjEGrP93Q3ZpPlKSSj0SRTaPhSOVMk
WGLTZ1fnh2ebq94WZhUO9Q4a9Zvnpxcm/dbe1u62waRTare0+gPTDvBiAYvF
odMlAu6mVnW2vwOK58Xh3vnB7qV592zn6HL/BKwgPIPYzKdygPmC8rs2T2Mt
MKQsMcD2cu/y48nHrxdf/+PmP26OPknZ8lkSeXYITJCFpZE58sAopZ9EHRll
TY5xJ0fpQ72zzbWkyuKhioLhypeMnlbZzPg+n32pUVxtWS6qXx+Z351fnh2d
nh2dH5osb1fc4Iq4C6vg+5Ca22oLi4uS09JwUQnoiJgwFGgcwW7uECcnL2vr
AEe7SGjg6/SksY7m9dUFo5i/IxcfKphq1jywYO4sScNatlxz3jF+Pdj97XDv
/30gZbnzWXGuk5zp1oGuFOt7XJp2ZU61PKdemdfSl0FVv1DLd0QCNZPBI5NB
kAB1viovPzEcE+rlS4BC8UFBSUhEZWbGeHMjdXhwebBvur2lIT8nPjQkwM4O
OLW/s7uPo7uvk0eQZyDC1wXl45KECm4ozBqqL+8uK6xOi38di6tKjSNVlwO3
FS3NyuiLEvoikzxBHu4DvaO3pqa+ML8qJ6M4ObooiVCRHVeVl9jTUDzcVkUm
tQGE12kg9iywl+bo85Pk0enZ4ZGpgZ7JgbbZobezpKaxnuq+t2XNFUV1JUX1
ZaXt9Q19Xe39fZ0DAx39g20kcGYMdPf2dXT3tfeQuntGu9uG2wG/5W2l4ORL
K4uOy0cQs4KiMnzx6R64NFdY1LOAiMeoOOeoVN+ELFhyJgxLcMbiXgB+I/CP
8HHPI+OeBaEsxgqLeATHPoNiH7gF/+AS/L0v7le/qPtekb9A45/GFnpFpjkA
xn2CfnL3+8EX9msQ6jkUYxsYbuMT/xiW8QJV4I5/5Z9YiUirxca8CkWmeCOT
vMOT/GJzQrPLo3IrCHGZMATBJQhtC0H/gou3w0TbIrBWEXinkFArX98HISG2
vgEPvPzuekF+DkTdg+IfBBF+DSDcDoz6MRz3a2YeKNpPw7B/DkLcCkQA+34S
Ef+CmOYThncuqIqdWeseotTlVGOIed7EPPdjrexULz83qs716mO1fFciNvJ5
Og77UCnXcFgi6qJ0bUnOWd3gLG3wl7TStUv1xrlSuitgbyzOMUcGwNnOGBnk
TIxo6Ctg/m+v80/Vivcm44ed7UuD/lilPNvXXZtNH84OAL/7Wq1OKFWwxAqW
REwXcZY4fJpgcXqlt6N/ZYm2t3u0f3Bs1GxqFRr1hkolUwKE94ADK9Vry8ur
FMo6l2VQg4FgODIZgQ5NuoMt7Ynp4I/9Y0HzFTEEQKDYqgQKzbpKL9Ee6vc/
HH8A2H67+vb57POn00/nuzcSloIytrQytcJbZguWWOy5JebUHH+ezJ4a502N
CWdGmaSuqYay3tfZ3cUZ46UFlMY37MEeCXlatUbVC4UmlfrAuGPeOwYC/JpU
myqhnLNIn+4d7qysL8vKz41LTsTgiaHoSCgc6RsAQmyAkxMM1FI312APVyw0
EJTNnoYqFmjZIu6Zjn+q5Z1o+JdGyed9Ayi8oPn+8+byH1fnfz01A/8FNXlf
xtsU0HTcRQ2bYmQsS+cn+FOjsoVZNXVRRV3SMeh/wAu6j3xtTcFgSGj05dGx
ptclGYSoVAw2DYstSU7pq65a7O+jDpNoI8NrY6Od5WVZOHyws6u3rb2vg7uf
s7e/q2+QJwTmYhvq4ZCKCe0sLyJ3tUw31w68edVf9rK/4vVKX6d8haxmURUM
Kn9pfmF0YLDtbVtlZWFiUhIGE4cKw8H88FCfmDDfmDDv3Fjkq1RcY0kWKNSc
pQkZa1m8tshenmEt0xkLiyuzE5TJ/sWprqWZjqmB+p7GktqSXJCx89JSSgoL
m+qquzpb+gc6SCNdE2PdY2O9gyTAb3M3qa1nrLOV9Lam682rt4X5telJr/DE
bFh0NiQ2xz880SkAdc8H9QBOtAshOGHjvYmJAYRYX2KsT3iELTL8cRD8h2DU
T1DUbffAW97wHyDhDzyD73jDf/IOuQMsGxb3PCjBChL/FJluF1PgjYi1hqEf
eAX+6O77ow/0XiDiuT/K2gf53CfmKSzVEZ3rjSsKSqhAp1bh8fmh0GgPT6Rd
aLRffG5ExuuY5AJcRAIEinb2hln7hNwOJ9og8dZw1DMMzhmJsoPBrDAYNwjk
qW/gfR/oXSjmISLuKTLpUUjC3aC424Tox9l5rlFxD0MjfgCCR/wQHvMQjn+M
SXRDxXtklhN65utG6C21pKz0OlRCBeRAKTrRyS+3NJdGLeAXpN9D+Qbgblcm
OVBIdxUivYil4K2oBCs6GWNLxbY85qCWgtgGTh7d2opZKtwTckTz01tc5o6A
sydZP5JLzQoZEDg43JAcbivP9vSXh6Zj06ZeIluncXjLLCGVpxVqOEs8IV28
zpEy6Vy9znR59X7LtKdT6sV8kYi3rpDIDWr9/rbFf9k0GmV6mseka+TSLbXC
pFHuGlQ7euWmWgb4Bc13W2UAJiik8wC8m3L9gW7vYvfscu/848n7v77/698/
//33d79/Of8C+D3eujDIttfXJKwFFpNM5y9aXrNo4ItUDCaIEOzxYQl5UjI3
utzVMFpdNFxZOFiQPlCUNVxaOFbzZqqtebavjzwytjA5Z1QZt3Tb27odk2pL
K1bxV9iA37byupz4tGRcLD4UhQyAwjx9A1zcQDT1c3LydXSEerqjIAEEBDwl
KrKiIGe4s5k6O765vgAQ/nas/8fN/n+/P/2fDxf/+nj9fz5/+N8fbv7r4vTz
3tapRmZaZ6qZCzLqFCjLIP+ASSKenzKy1443xGaZCNTzE5XyRP3vvQTZbCWD
pWRzuJSFgcYmkAQSkeh0LK46O2esuWWhr3emo32uqxNQTGpoLElJiwiEBrl4
Qt39gr2DoF5BgF+0rxsB5leSEjvV3sieIFEHusltDZS2t2sDPVLKjIFFB/xK
Vhc5lJnl8ZHx3s7STMt+HegAf5SfN8zNPtDZGuryLNDxYbi/AzHEMzcB3VVb
zJgbtlgAe0VIJQvWOKzllcWp0ZmRroXJztX57pmRxp7mkprXOa9zMwC/eRkZ
Rfk5lW9KenpbZ+dH5mcHyXND4+M93f1NbT31bYNNjb215S2vQfgray/IqY5P
eRWeWY7Or8bE5vpAMPc8Qu+hQdTEOWJj/fCxgRicZ2IKLBxjBwu56xNwKwD+
XUDon1z9Lfz6hP781PmWvcctf8RdRPwLZKp9aJo9Kss5PMc1MtMlAPPAD/6L
Z8CPnv4/+cLuB4Q980NaeYdZeeCfILK8iCXwqOJQbB4MkxUcmuDvGwF83xeX
FpaQh49KRyOJAbAIz2CMByzcHYL+NTrFFRvrAA17jAi3QyIdYDAbBMIRi3UD
fwzBWCGJ1pZHnJIeBUXf9sTe+oPf6MRHWOIdfMI9bNz98LjHgeG/phQFxxeG
Jr7ClHZmdJCrmmZevu6Nf9VLNInpZjX/ekd5tasxG+T7GsteMeZNzeX+1vGW
dk8t29pY35TwTBLurpS/JxPsqqQ7StH2hnBbytvb4B1scLeFdO0aRU2bPxCz
zpTCC430Sqc43BCBHgcGwvG25sCoMG+pTEqJiL7EJk/zKfOcuRnJ6qqSydTw
+Lp1y9uBjwybh0bLfs4qIVfMpAnpKwo+d1ul2NNpdFKxmMWkL5DXWQytTKJX
KjUbG0qJRCWVgl4MAAcyGYxK2YaIL5BLpPumvfeX70A5vT67+XD18dPN5y/v
v35+9/Xq9OZo9/hke0cuEPLpayIWd53D21gXa+VKlXRDLhCJmCwpmyll0Jhz
k8uk3sn2xq6K4rrUxMbM1Ibs9Kq0lFcJ8RXpGd019ZTBMaNYvilRbG+odxVa
cCClM5dHJ0bbLJ+AFGdkJUbi8cEIuIcv1NUrxNMv2NXb74UzwtsvNjS0IC6m
sSi/q6pkrK1+bYpkVG7s67U3+3u/n5/+893Nvz59/NeXT//99dO//vbbX75c
nZlNBvm6cIUCeiutr3utt3tpbHRtZnKDvnIgX7/SS9/pRB/1om87svc6/jvg
4zKGnk0RLo5Tx/vGu5q66ys6qqs7a2p6amv7aqu7q8p7qyum29/SRwcF81Pk
nvbS1MQIf2+0jxceBotBIlNwuMLo2OKYmKa8nIWu1n9vUE/WUKdVK+O7/KV9
cKrIOWal5dEnFYu+Njk+2dVVlx2biAgI83aBeHm4ubg7OLo6Obs7OzpBvNwx
Qd7Z0ciW1+mT7ZVLpFb6VA9znsRcpPBpq5yVZcYChbG4tDQ9N00anx2ZbKl/
W1ZUkpaQFB9NzEpLrnlTNtDbMTM5MjU5PjxE6u/t6+3t7+8f7Okd7Ozqaelo
r29prGx487IyN+t1AnA9TKJfYIStO/y+M/SOfcD3wE/D4p8GR90PT7LCpzoE
YR66+P/o5Hnb2fOut/9jCPxZEPyxT+BP7j7f2UDvOITdDYixRqU7ojPtCPmu
0fle6EQnCMbWP8zaB2btB7WGImyRWIeIKMfIGMeIxGDAKSodhsgMRBUEwbI9
YZmuuJe+qGQHBNHa0qkJtpgoOyTOPjTSIRTvCIn8BRnzDIZ9arlN2vdRGMoD
jfEOgtknJEMTUvzh6CdQxANAd2SCC4ro4I94Agu/k5zrRkx5gSY+DsE9DAq/
CxK+R8iP2BTnvBp0UWNkQUNEaXt0fhMmrRIO1h0pA/B7sbVxblKebAKpzneN
78y7Vwemsx3DkV4JgAW07sj4gF+gbYUYmPKOfB38zb6cD/g1CWhq2qyEMqpj
LGzzaftizpFMuCvm70uFFwbNvkG+q5Pt6WQqIZs2M7Y0OsiYmgASLCxs0OmA
X71IZJTJAcIasUTCBu2V8semHOtrNI1IqJdJ5HyugE7jUFfEHJZSJFSIxXKR
CKwGlWrXaDw/PjkzHx/t7W/pDTqVGqzn5rOvH75cn119vP4EyP364bdvn/7y
9cO3m/P35r2TLaWKS6XRyBQejQH4VYjBEFCpwQ+g0uplGwYwH0QC6doKbx4g
3DPRWt9fWgycd6alcaa1eaKleaa7mz41K6Gzd+SaPY3hyGAyG7cPNcZNyYaC
xRWt0jlLKxO9/W3VtZV5RWn4mKgQFDYoBOEVAISDwhOQyPzY6KbigsHGquWR
XiVrBdSB872dL6fmv99c/c+H90D//PDuvz7c/PXT1furo4MdrXKdTZsaHW6o
bS/IfZuR9hY0xErLmxTo44PSpUn92tyBYOVCwfyyJQa6UvOM3EXR8qRgcVJE
I0sYS5wFCptCZs7OAtyWSP1gLvFmJ9TMFSOfwZ+bBCUyw/LupIi8uLhX6WlV
BfndFeXdpaWj9dWccZKBtbTLW93lr+wJls/krAuN4EovvjTITjSyTRFHsECm
kAbaitMysHCUn3uAh5uDnaONrYO9g4uDnb2Hw4tgT8fEcEhNbhyp8fV8X+Pq
eCdjboi9vLjOoAvX6OuMNSmXx16hAXgnBkYaqupeFxQDfuOIUenJCeWvi0BH
H+rv6uvt7unq7urobG/vbGlpa2hsqa1rqK6vq6yvLq0uySlJj82MCCP6+aFs
vcKeeIY+dITctva+BfqsX8SdgIg7yPinkcl2ICo7+/35hct31g7fO7re8Ql8
EAh76Au5A/i1DvrpD37DM51x+S5RBW4R6U6B2CcBaGu/UKsgpCMS64HAOoeg
bfGxrlmFwcmFhOSiKFweEpkFgWf5eifae0Y/D06xh8daB0c+CQHVG2cdQbQP
j3JCRbmgol1hhHuYBJuwKBsPyD3ALzzMFYXxhoc6E2P9AL9ovG1Q2H045gkc
+zw4wgqCfo6KepiU44qJeRqM+QXwC498EBr11A/5Mz7dLacKWVgfkVcXXtyM
z6pFxBT5xr8OOFLxAL/HOpFZLz02Ks63tdeH2x9O9oH/An7NBhXg1yQTbIk5
W+tsIJNc+O9XMEhA8D5SrR/KeYBfFXWGPd7DmxqUUMYVq/Nq+pKSvmzgMixP
Q2il2xrJtlosYVFBY5of7FkdHV4eHqKOjfHI5D/2g9WKQGNd59Poq7NzixMj
S5Oj1NlJ9tKCmLkm47IlbKaIyfjjwyMgIZu9zuEA/93b3Lw8Pv5wfXNzcQkQ
PtzdAzo9Mn+4ev/t029gBfD+9vEb0B/8Av892D4Ss9jzY+NTQyQ6ZUnI5gLn
Bf0a8GtS6zYVlg1s1XwOaP1rE6TZ7pbhxqrZ1kbQ8aULc2oGTcu2bLRrkin2
tcZD/dbx5s75zsHZ9j44ONIaDtQ6oF21VsxgUWfmJrr664pK8+JTkiIIBBgi
KhgZHYokQKGxofBXyfE9NWXsubEjteTd2eHny5P/fHcFsAX++/ery/+8PP/L
5dm3d2c3FwfmfYNRIQJ5oLeyvAQYU0hociQ2nRBZlBjbUJg10lBGG2hWLIzs
8iiGtSmwbrHJIsrwykgnbaJfTKfoxZwdhXxTKtIJecAxxatk8fK8nks3K8Wg
VpvW2VTQYRurRpobpno6Zwd6F0dHeFNTa8NDrDGScmV+j08/FNGPpWvnCubp
xtq5mnupFZ5qRMca8a5UIKMtUyfHSLVFxQmRoPkGerrb2dpbWdu9sHOyf2Hn
+sIa4voiFuFXlR0z3FSyONTCnO3nLY3T5meBBVPnZldnZ8AUnSaNttQ0Wjax
K6koznuZmZyalpRYmJtVV1XR29U6Ntw/0N870NcPIG5tba+pqSstq3z1uvTl
61elVeXltWVFVXlJeQTAry/Sxgf5LDDC2gvxwCHwBwfILRf4Lc+w74AFA/vz
R/7qDrkD+H1ic8vG/nvvgPvBYc8g8Hte/n8G/Dqj7kPibLE5btHFnsB/YdFP
naE/+iKeQVAvcPGQtBwM6NFwlE1ktPPLMnRuRVLOm6SYYizgF5Lq4UR4aoe+
60V4FBxjBcM+hmMeWS53xzpFxrphYtwxcR6AX3SihV/PoPtuPg+hcCcE2jM4
xMkf8iQyyiUqwRUZaRWKfRYSaRUSaYMmOsem2acVeKKiHkHRd5DEp5g4a1yK
YxjxGTLOJjrXO67AL7bQL6UUFvfSF5FiFxxvdapbP9YIDtWCA43oUGfZLvXY
clFId7G3CQ72NRsGCV/Fpas5VC2HZuAzAL8HaumpXn6mk59ppacq4baQCvwX
8Ls23AEQli1Mi8hTQsqUgrYEEN7VAf+V72nlCj6TMT9Jmxqnjo1MdrQNNjRM
d3VRJyb5y8tCGo2ztLQwMTne1z8z1Dc3PEAZIy1NjlNnp8HvWkCngvwsF/IB
vAIGHXRhAYsFIvTJ/v6n62vA79XZ+cnhkXn/AMALjgG5n999+nj94fO7L/9O
zpb14/Xn08Nz0FjpZMpgR2d/WztIbgIWB/gvyM+WVSrXSWUbXDZ3kbwyThpr
qW8tKWgoyCR3NHMmLe/v/ved4Zozo/F40wRs93hr17y5c2gwHei39rRGgO22
Um1SqHRiqeVp5Tny3MBIa0VNSUYuQDgtMrooKaM8K7cqJ6ep+OVEezOPMgUG
4N+uj799uPz94/Xf3l//7eri99OTb+ajbyfm385P/vL+HPjv5enu8bZOwaaP
Nze+SYgH/IYHBmAC/fBB/sloeFkyYfBNPnOoRbU8Ip3v32TOAKPUMOb4lFH+
wsQGaxnwuyUTG8RC/TpXx2eo2Ktq1uquhHOh3wC/O5CENWyqlEYB/wS+AAwu
rZC3xWWracuq1QUjexmY7zZ3YV+weCqj7gkpR+LVI9naoYx1pOCD9K7h0jlz
U9Otb6qy4hPCQ+D+vo72TsB/QYQG/utmZwP4jQnzrcyKHnlbujLSziEPrVOn
hWs0MYvBXV1hLi4wl5YpE9ODHb29LZ19HT0db9uaauoaa2vamxuHB3rnZ8ZX
FueWFinzs3MjpOG2NlAFaktK3xS+LM7Kyy0qe1VRV17ZXFpck5WQh0XGesHw
DlDcC2S8MxRv5Y36GfDrArvli/4Rir0XgLoHQT1x8/3FxvEH4L/QUCsswRmB
ee4L+Qnw60OwCktzwed7xrzywmTa+2Du2vn/ycHvDjTcPiETmVsUBfiFhDwN
Rj6NSfZIL4rOKI2LfRmBzoEGpXk6457YIn/2xD34Iz+j8Vb4GEfwZdHJPrgE
78hE75Doh4BfBNE2EPEcGuaAifQDAvzaOX6PirDLyA2KS/UkJLrg4pzhWGtU
lFNipktmoQ/gFxb+MyrqSXisJf+j42wg2AfBhCfBxKdhcbaRmW64LPfgOBvv
iPsnWiHg90gj/IPfQ93GrmZjWyUF+RnwC9KygrsmolIkVDL41QN+QXg26+RX
Js21SWX5XEMj2lsH/XdePEtiDXeK5kd1a0sby7PSxVk1Y1XHpgN49w3KQ4PK
IBNusNZkDBp9YqyrsqKuoKC1tHTo7dv5oaGFsbGZwcHB9raO+rqxno6Jvi6g
sR6LZoeH6OQ5ELcAvyI2k0tbZa6uAgsGLfj86Ojr+/f/n/len1+8u7i5Ob/+
dPMRkAvKL0jRYH1/+RGUX53SsDg51dnYBATOHB6DJROCKC4Fq3JdAvgVMejU
qXHyUG9fTXlVdkpVVvJUeyNzkqRmUXdl4D+uPtuy9PRtjf54e29Pv7mp1AAB
7waxXC0Sg/y/TmcA86WMjgP/bSp5A/gtTs0qiE+tyCroq29aGRnZoFPNavn7
PePX453/9eH89883gF9guF+ODt5vm4DAwbeL08+X5ouTndOjrdNdg07Imetq
r0lJzkOiwny8Qzzdgl0cwtwdEkJ8a9OJ040l7JEWxSIJ+O+5gn20wdpcp+v4
NL2IZZTyNEK2RsjUg+wk5myKmFsiJqDvelO+L+PsSlha7qqWRwWTBMxkMJl3
lJIDscDEZ26yqSbeyiaLol4d09HGdrgz++vkY9mqeYN+KGMeq/mnOin4huvL
c5PN5bW5Sak4FBIKcXV2s7MH3dcN+K+zzXM/Rys8zKM0FTdQV0QZeAv6L4s8
zKOuKAQ8tWhdIxZppTIZT8ins9eZPAGLx6IyVsgL5Jlp8szkEnmWvrrApC8L
BTw6lTY6PNLU1Az4fVNZC/w3Mzcn52VecUVRaX3R67qcjNcxhHRoCNEZgrXB
Z/jg0j3h0c9cQ245BFoQ9kP+BJItgmAXGPLM1fuel98jdKRzbKIPBv/CJ/A2
6L+wRKfIfN+oQm/gv2HJVu6I2y6w24+dbgUgbIjJwVHxQTDkC6+AX70Dfw4M
uRedjkosxMcUYiLy4SA/uxOtLP6Lf4jNcMXE22OjX8QmuadmBSRnQ+MygmIy
IJhUG2yqfXiiU3ise2xaaGYeIT4JEYZ0c/e6C/y3qBSdnOUXk+xOTHIPCHkA
QT4jJNik5nqgCRb/BQgHon4OIzwOITwKIT4DCAdg78OinoFZQcjxjEh3gRCe
/F+oSJay
     "], {{0, 213}, {320, 0}}, {0, 255},
     ColorFunction->RGBColor],
    BoxForm`ImageTag[
    "Byte", ColorSpace -> "RGB", Interleaving -> True, 
     MetaInformation -> {
      "Exif" -> {
        "Make" -> "Canon", "Model" -> "Canon EOS 700D", "ExposureTime" -> 
         Rational[1, 320], "FNumber" -> Rational[28, 5], "ISOSpeedRatings" -> 
         2000, "DateTimeOriginal" -> "2014:08:18 16:34:53", "Flash" -> 16, 
         "FocalLength" -> 250, 
         System`Convert`ExifDump`ReadFIDData[
          InputStream[String, 4], {136, 0, 0, 0, 0}, True], "GPSLatitudeRef" -> 
         "N", "GPSLatitude" -> {51, 54, 
           Rational[147, 100]}, "GPSLongitudeRef" -> "W", 
         "GPSLongitude" -> {8, 17, 
           Rational[667, 20]}}}],
    Selectable->False],
   BaseStyle->"ImageGraphics",
   ImageSize->{159.62890625, Automatic},
   ImageSizeRaw->{320, 213},
   PlotRange->{{0, 320}, {0, 213}}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[2]:=",ExpressionUUID->"ea56458a-8bbf-4fe9-a587-89886a67aeaa"],

Cell[BoxData[
 TemplateBox[{"\"cheetah\"",RowBox[{"Entity", "[", 
     RowBox[{"\"Concept\"", ",", "\"AcinonyxJubatus::3g535\""}], "]"}],
   "\"Entity[\\\"Concept\\\", \\\"AcinonyxJubatus::3g535\\\"]\"",
   "\"concept\""},
  "Entity"]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[2]=",ExpressionUUID->"9381a61d-18c7-4bd1-8a73-3b495db30069"]
}, Open  ]],

Cell[TextData[{
 "There\[CloseCurlyQuote]s a general function ",
 ButtonBox["Classify",
  BaseStyle->"Link"],
 ", ",
 "which has been taught",
 " various kinds of classification. One example is classifying the \
\[OpenCurlyDoubleQuote]sentiment\[CloseCurlyDoubleQuote] of text."
}], "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:6",ExpressionUUID->"64556c5a-367f-4a20-b2c9-495c1011cbbd"],

Cell["Upbeat text is classified as having positive sentiment:", "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:7",ExpressionUUID->"5264f021-7031-4f18-99af-269cd70f8453"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Classify", "[", 
  RowBox[{
  "\"\<Sentiment\>\"", ",", "\"\<I'm so excited to be programming\>\""}], 
  "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[3]:=",ExpressionUUID->"5fc2416a-d360-4661-a79e-aba0e1e9dd8a"],

Cell[BoxData["\<\"Positive\"\>"], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[3]=",ExpressionUUID->"72107f7d-3625-4cbe-9558-459c18c54c8b"]
}, Open  ]],

Cell["Downbeat text is classified as having negative sentiment:", \
"CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"1d5ebcfe-6d55-4a43-9754-ce3932a1e852"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Classify", "[", 
  RowBox[{"\"\<Sentiment\>\"", ",", "\"\<math can be really hard\>\""}], 
  "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[4]:=",ExpressionUUID->"b0230faa-b374-4124-9aff-85a68cb86728"],

Cell[BoxData["\<\"Negative\"\>"], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellTags->"LastCellOfAPage",
 CellLabel->"Out[4]=",ExpressionUUID->"f5c551bb-c180-43f0-ac95-e6da62a064e8"]
}, Open  ]],

Cell[TextData[{
 "You can also train ",
 ButtonBox["Classify",
  BaseStyle->"Link"],
 " yourself. Here\[CloseCurlyQuote]s a simple example of classifying \
handwritten digits as 0 or 1. You give ",
 ButtonBox["Classify",
  BaseStyle->"Link"],
 " a collection of training examples, followed by a particular handwritten \
digit. Then it\[CloseCurlyQuote]ll tell you whether the digit you give is a 0 \
or 1. "
}], "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->{
  "p:124", "i:8"},ExpressionUUID->"f273b17e-d96c-4ee7-ac8e-4b9925d7c7c8"],

Cell[TextData[{
 "With training examples, ",
 ButtonBox["Classify",
  BaseStyle->"Link"],
 " correctly identifies a handwritten 0:"
}], "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"552a98b6-1d30-4bf5-b969-81787f41d5f5"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Classify", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      GraphicsBox[
       TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRJI
mQgQCwLxfyg4NdWR1xjG+X9muSUbAyMjZ+9rCH8+F6Nc+qzjDeGM5SDu39WM
rPmfQazfGQKngFQXI+NMmF7FoP//bzEy7oUbttX8//9iRlE4//82yVePhVkm
IwS+yPaeYBT5jwTcLU8whiILCKudYFyBLCCkeoKxFIm/m9nyAnsSksA2xob/
qsiGrmdc/l+V9ylCIEbzy/+djIpw/hGFwP///2Qwpj+H8NeogT33SJJRrPj4
rVvLJnPyHQFLvO6TYmEEAfNDcM1bYmwYzTrfg5gAPlYFyw==
         "], {{0, 20}, {17, 
         0}}, {0, 255},
         ColorFunction->GrayLevel],
        BoxForm`ImageTag[
        "Byte", ColorSpace -> Automatic, Interleaving -> None],
        Selectable->False],
       BaseStyle->"ImageGraphics",
       ImageSizeRaw->{17, 20},
       PlotRange->{{0, 17}, {0, 20}}], "\[Rule]", "0"}], ",", 
     RowBox[{
      GraphicsBox[
       TagBox[
        RasterBox[{{255, 255, 255, 255, 219, 87, 139, 253}, {255, 255, 255, 
         255, 119, 1, 1, 212}, {255, 255, 255, 255, 62, 1, 46, 236}, {255, 
         255, 255, 218, 26, 1, 94, 255}, {255, 255, 255, 177, 1, 1, 206, 
         255}, {255, 255, 255, 68, 1, 1, 206, 255}, {255, 255, 255, 68, 1, 1, 
         206, 255}, {255, 255, 255, 68, 1, 15, 215, 255}, {255, 255, 255, 68, 
         1, 103, 255, 255}, {255, 255, 213, 18, 1, 138, 255, 255}, {255, 255, 
         165, 1, 1, 200, 255, 255}, {255, 255, 74, 1, 1, 200, 255, 255}, {255,
          239, 51, 1, 56, 244, 255, 255}, {255, 205, 1, 1, 69, 255, 255, 
         255}, {255, 205, 1, 1, 69, 255, 255, 255}, {255, 155, 1, 1, 118, 255,
          255, 255}, {255, 80, 0, 0, 193, 255, 255, 255}, {235, 45, 1, 1, 193,
          255, 255, 255}, {211, 1, 1, 60, 252, 255, 255, 255}, {232, 40, 89, 
         218, 255, 255, 255, 255}}, {{0, 20}, {8, 0}}, {0, 255},
         ColorFunction->GrayLevel],
        BoxForm`ImageTag[
        "Byte", ColorSpace -> Automatic, Interleaving -> None],
        Selectable->False],
       BaseStyle->"ImageGraphics",
       ImageSizeRaw->{8, 20},
       PlotRange->{{0, 8}, {0, 20}}], "\[Rule]", "1"}], ",", 
     RowBox[{
      GraphicsBox[
       TagBox[
        RasterBox[{{255, 255, 229, 134, 121, 2, 2, 0, 58, 242, 255, 255, 255, 
         255}, {255, 226, 47, 3, 3, 3, 3, 2, 3, 14, 218, 255, 255, 255}, {133,
          22, 3, 3, 3, 3, 3, 96, 57, 3, 67, 235, 255, 255}, {42, 3, 3, 3, 68, 
         216, 145, 255, 182, 54, 3, 69, 234, 255}, {63, 52, 3, 3, 162, 255, 
         255, 255, 255, 186, 13, 3, 189, 255}, {220, 188, 3, 33, 231, 255, 
         255, 255, 255, 255, 70, 3, 91, 255}, {255, 188, 3, 43, 255, 255, 255,
          255, 255, 255, 187, 11, 48, 242}, {255, 174, 3, 43, 255, 255, 255, 
         255, 255, 255, 255, 55, 3, 176}, {255, 55, 3, 43, 255, 255, 255, 255,
          255, 255, 255, 55, 3, 176}, {255, 55, 3, 43, 255, 255, 255, 255, 
         255, 255, 255, 55, 3, 176}, {255, 54, 2, 42, 255, 255, 255, 255, 255,
          255, 255, 54, 2, 175}, {255, 55, 3, 43, 255, 255, 255, 255, 255, 
         255, 255, 55, 3, 120}, {255, 55, 3, 43, 255, 255, 255, 255, 255, 255,
          255, 55, 3, 162}, {255, 98, 3, 9, 134, 255, 255, 255, 255, 255, 229,
          39, 3, 176}, {255, 188, 3, 3, 30, 255, 255, 255, 255, 255, 139, 3, 
         3, 176}, {255, 237, 52, 3, 24, 232, 255, 255, 255, 235, 34, 3, 14, 
         192}, {255, 255, 90, 3, 3, 128, 255, 255, 238, 136, 3, 3, 147, 
         255}, {255, 255, 235, 67, 3, 8, 95, 164, 56, 3, 3, 60, 231, 255}, {
         255, 255, 255, 217, 15, 3, 3, 2, 3, 3, 57, 233, 255, 255}, {255, 255,
          255, 255, 242, 59, 3, 2, 60, 136, 236, 255, 255, 255}}, {{0, 20}, {
         14, 0}}, {0, 255},
         ColorFunction->GrayLevel],
        BoxForm`ImageTag[
        "Byte", ColorSpace -> Automatic, Interleaving -> None],
        Selectable->False],
       BaseStyle->"ImageGraphics",
       ImageSizeRaw->{14, 20},
       PlotRange->{{0, 14}, {0, 20}}], "\[Rule]", "0"}], ",", 
     RowBox[{
      GraphicsBox[
       TagBox[
        RasterBox[{{255, 255, 255, 255, 157, 22, 154}, {255, 255, 255, 255, 1,
          2, 39}, {255, 255, 255, 223, 0, 67, 205}, {255, 255, 221, 36, 1, 
         163, 255}, {255, 255, 162, 2, 1, 163, 255}, {255, 255, 151, 1, 23, 
         255, 255}, {255, 255, 47, 2, 98, 255, 255}, {255, 255, 47, 2, 139, 
         255, 255}, {255, 255, 47, 2, 234, 255, 255}, {255, 191, 6, 2, 255, 
         255, 255}, {255, 69, 1, 1, 255, 255, 255}, {255, 70, 2, 76, 255, 255,
          255}, {242, 51, 2, 118, 255, 255, 255}, {208, 2, 2, 212, 255, 255, 
         255}, {103, 2, 2, 232, 255, 255, 255}, {92, 1, 94, 255, 255, 255, 
         255}, {93, 2, 94, 255, 255, 255, 255}, {93, 2, 94, 255, 255, 255, 
         255}, {187, 2, 94, 255, 255, 255, 255}, {229, 33, 146, 255, 255, 255,
          255}}, {{0, 20}, {7, 0}}, {0, 255},
         ColorFunction->GrayLevel],
        BoxForm`ImageTag[
        "Byte", ColorSpace -> Automatic, Interleaving -> None],
        Selectable->False],
       BaseStyle->"ImageGraphics",
       ImageSizeRaw->{7, 20},
       PlotRange->{{0, 7}, {0, 20}}], "\[Rule]", "1"}], ",", 
     RowBox[{
      GraphicsBox[
       TagBox[
        RasterBox[{{38, 78, 255, 255, 255, 255, 255, 255}, {39, 2, 143, 255, 
         255, 255, 255, 255}, {39, 1, 41, 229, 255, 255, 255, 255}, {39, 1, 1,
          142, 255, 255, 255, 255}, {189, 18, 1, 41, 230, 255, 255, 255}, {
         255, 159, 1, 1, 190, 255, 255, 255}, {255, 176, 1, 1, 146, 255, 255, 
         255}, {255, 176, 1, 1, 60, 255, 255, 255}, {255, 198, 15, 1, 60, 255,
          255, 255}, {255, 255, 52, 0, 14, 200, 255, 255}, {255, 255, 149, 1, 
         1, 153, 255, 255}, {255, 255, 197, 12, 1, 53, 255, 255}, {255, 255, 
         255, 58, 1, 53, 255, 255}, {255, 255, 255, 58, 1, 18, 203, 255}, {
         255, 255, 255, 58, 1, 1, 160, 255}, {255, 255, 255, 72, 1, 1, 18, 
         202}, {255, 255, 255, 228, 39, 1, 0, 160}, {255, 255, 255, 255, 72, 
         1, 1, 40}, {255, 255, 255, 255, 195, 1, 0, 43}, {255, 255, 255, 255, 
         195, 1, 92, 214}}, {{0, 20}, {8, 0}}, {0, 255},
         ColorFunction->GrayLevel],
        BoxForm`ImageTag[
        "Byte", ColorSpace -> Automatic, Interleaving -> None],
        Selectable->False],
       BaseStyle->"ImageGraphics",
       ImageSizeRaw->{8, 20},
       PlotRange->{{0, 8}, {0, 20}}], "\[Rule]", "1"}], ",", 
     RowBox[{
      GraphicsBox[
       TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRJI
mQgQCwHxfwj4yLj///98xtr/cFDExLYrVy2QxQQuksPEOO/F2x+20negAt+8
mBg/AWkXJkOoSBUTk8I3IL2WSewRRIk3E9NUEOMkE9MUsMhBJiZxMOOdBUTk
jjwTM0TqfyBTG4g6xMTE/x8mIgYkbysyMYXBRUCKTRkZpWHuCmAAitxRYGKa
AxWYzMZ78P8dDSamiK8QgWfaTLL//y9kYtL/BFUykUkF6AtzJiYLqMB+Xia/
//9fiDExzYIInHNmcnv1/389E5PBKxD/2lwuJlcQi4+JSaq6PS4ujoGJyfn1
f4gIBDDwt78Da+4Ngwh4tv2Emg8AlT70Eg==
         "], {{0, 20}, {18, 0}}, {0, 255},
         ColorFunction->GrayLevel],
        BoxForm`ImageTag[
        "Byte", ColorSpace -> Automatic, Interleaving -> None],
        Selectable->False],
       BaseStyle->"ImageGraphics",
       ImageSizeRaw->{18, 20},
       PlotRange->{{0, 18}, {0, 20}}], "\[Rule]", "0"}], ",", 
     RowBox[{
      GraphicsBox[
       TagBox[
        RasterBox[{{255, 255, 255, 255, 160, 1, 57, 88, 189, 255, 255, 255}, {
         255, 255, 255, 250, 52, 1, 0, 1, 90, 246, 255, 255}, {255, 255, 255, 
         237, 1, 23, 180, 6, 238, 255, 255, 255}, {255, 255, 255, 140, 3, 184,
          255, 205, 90, 255, 255, 255}, {255, 255, 232, 10, 56, 255, 255, 255,
          42, 217, 255, 255}, {255, 255, 143, 10, 204, 255, 255, 255, 148, 92,
          250, 255}, {255, 239, 30, 19, 255, 255, 255, 255, 221, 13, 220, 
         255}, {255, 183, 1, 92, 255, 255, 255, 255, 255, 33, 184, 255}, {255,
          131, 2, 196, 255, 255, 255, 255, 255, 118, 68, 253}, {255, 72, 28, 
         255, 255, 255, 255, 255, 255, 220, 13, 211}, {226, 15, 54, 255, 255, 
         255, 255, 255, 255, 255, 35, 211}, {211, 1, 116, 255, 255, 255, 255, 
         255, 255, 255, 36, 211}, {211, 1, 116, 255, 255, 255, 255, 255, 255, 
         255, 36, 211}, {211, 1, 116, 255, 255, 255, 255, 255, 255, 244, 29, 
         211}, {211, 1, 145, 255, 255, 255, 255, 255, 255, 141, 9, 219}, {211,
          1, 104, 255, 255, 255, 255, 255, 213, 15, 100, 255}, {246, 45, 28, 
         255, 255, 255, 255, 238, 34, 34, 236, 255}, {255, 198, 8, 196, 255, 
         255, 209, 27, 39, 219, 255, 255}, {255, 245, 76, 6, 71, 71, 1, 34, 
         244, 255, 255, 255}, {255, 255, 237, 83, 1, 62, 116, 252, 255, 255, 
         255, 255}}, {{0, 20}, {12, 0}}, {0, 255},
         ColorFunction->GrayLevel],
        BoxForm`ImageTag[
        "Byte", ColorSpace -> Automatic, Interleaving -> None],
        Selectable->False],
       BaseStyle->"ImageGraphics",
       ImageSizeRaw->{12, 20},
       PlotRange->{{0, 12}, {0, 20}}], "\[Rule]", "0"}], ",", 
     RowBox[{
      GraphicsBox[
       TagBox[
        RasterBox[{{255, 255, 255, 255, 255, 255, 229, 39, 20, 210}, {255, 
         255, 255, 255, 255, 255, 202, 1, 1, 164}, {255, 255, 255, 255, 255, 
         255, 202, 1, 1, 164}, {255, 255, 255, 255, 255, 255, 81, 1, 37, 
         248}, {255, 255, 255, 255, 255, 201, 7, 1, 158, 255}, {255, 255, 255,
          255, 255, 81, 1, 1, 170, 255}, {255, 255, 255, 255, 255, 65, 1, 1, 
         170, 255}, {255, 255, 255, 255, 255, 65, 1, 38, 240, 255}, {255, 255,
          255, 255, 202, 13, 1, 47, 255, 255}, {255, 255, 255, 255, 189, 1, 1,
          147, 255, 255}, {255, 255, 255, 200, 48, 1, 40, 235, 255, 255}, {
         255, 255, 255, 155, 1, 1, 80, 255, 255, 255}, {255, 255, 240, 43, 0, 
         11, 196, 255, 255, 255}, {255, 255, 155, 1, 1, 80, 255, 255, 255, 
         255}, {255, 255, 45, 1, 1, 190, 255, 255, 255, 255}, {255, 202, 18, 
         1, 41, 230, 255, 255, 255, 255}, {255, 159, 1, 6, 148, 255, 255, 255,
          255, 255}, {250, 37, 1, 80, 255, 255, 255, 255, 255, 255}, {162, 1, 
         3, 205, 255, 255, 255, 255, 255, 255}, {162, 1, 146, 255, 255, 255, 
         255, 255, 255, 255}}, {{0, 20}, {10, 0}}, {0, 255},
         ColorFunction->GrayLevel],
        BoxForm`ImageTag[
        "Byte", ColorSpace -> Automatic, Interleaving -> None],
        Selectable->False],
       BaseStyle->"ImageGraphics",
       ImageSizeRaw->{10, 20},
       PlotRange->{{0, 10}, {0, 20}}], "\[Rule]", "1"}], ",", 
     RowBox[{
      GraphicsBox[
       TagBox[
        RasterBox[{{255, 255, 255, 255, 255, 255, 255, 255, 255, 47, 2, 
         191}, {255, 255, 255, 255, 255, 255, 255, 255, 210, 19, 3, 160}, {
         255, 255, 255, 255, 255, 255, 255, 255, 102, 3, 34, 255}, {160, 255, 
         255, 255, 255, 255, 255, 217, 15, 3, 118, 255}, {244, 255, 255, 255, 
         255, 255, 255, 208, 3, 3, 118, 255}, {255, 255, 255, 255, 255, 255, 
         252, 85, 2, 2, 180, 255}, {255, 255, 255, 255, 255, 255, 210, 3, 3, 
         62, 247, 255}, {255, 255, 255, 255, 255, 255, 117, 3, 3, 178, 255, 
         255}, {255, 255, 255, 255, 255, 255, 117, 3, 3, 210, 255, 255}, {255,
          255, 255, 255, 255, 255, 64, 3, 3, 210, 255, 255}, {255, 255, 255, 
         255, 255, 244, 0, 2, 71, 255, 255, 255}, {255, 255, 255, 255, 255, 
         139, 2, 3, 72, 255, 255, 255}, {255, 255, 255, 255, 255, 139, 2, 3, 
         155, 255, 255, 255}, {255, 255, 255, 255, 255, 45, 2, 3, 186, 255, 
         255, 255}, {255, 255, 255, 255, 255, 25, 2, 45, 249, 255, 255, 
         255}, {255, 255, 255, 255, 255, 24, 0, 48, 255, 255, 255, 255}, {255,
          255, 255, 255, 195, 11, 2, 70, 255, 255, 255, 255}, {255, 255, 255, 
         255, 131, 3, 19, 230, 255, 255, 255, 255}, {255, 255, 255, 229, 31, 
         3, 120, 255, 255, 255, 255, 255}, {255, 255, 255, 185, 3, 3, 192, 
         255, 255, 255, 255, 255}}, {{0, 20}, {12, 0}}, {0, 255},
         ColorFunction->GrayLevel],
        BoxForm`ImageTag[
        "Byte", ColorSpace -> Automatic, Interleaving -> None],
        Selectable->False],
       BaseStyle->"ImageGraphics",
       ImageSizeRaw->{12, 20},
       PlotRange->{{0, 12}, {0, 20}}], "\[Rule]", "1"}], ",", 
     RowBox[{
      GraphicsBox[
       TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRJI
mSAQiwDxfzhYefPm4/P/kUHXMyYlpXIZyxq4yLEw+XomZiBgki/7ChWLAXGZ
IUQcRKg3gYmJiSG9uLi4yJeJqR8kdB6s5MkfEHsVM7MQkKqWYWIW8D4B0QIU
Y/7/9bA8M5PPPphts0BiIIn+z3AXyIHEcpiYHBHOZGAC2SHHLAtTtWdVDBOz
WMbndk7mXqi7p/MD3ed65f//BGbmGZ/ePz0cFgZ20OrjQNk+IMPJhB/iBeF+
iBeYQF5gYvItNi4uvgAx5bMXUEl4RPm3/x8Qtr9ZMfPEf1QAAMkk12Y=
         "], {{0, 
         17}, {20, 0}}, {0, 255},
         ColorFunction->GrayLevel],
        BoxForm`ImageTag[
        "Byte", ColorSpace -> Automatic, Interleaving -> None],
        Selectable->False],
       BaseStyle->"ImageGraphics",
       ImageSizeRaw->{20, 17},
       PlotRange->{{0, 20}, {0, 17}}], "\[Rule]", "0"}], ",", 
     RowBox[{
      GraphicsBox[
       TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRJI
mQgU/0eAw3vsGRkZtt9BElrNzwQGtnehAj8fWIoB+dw8rExM+yBCT71AKhT9
Pv9vZGVqAwt98QHrygKxuZiYQPre+IFE+PY+AXI+cjIJAKnNIBGe8IMgVTeM
web9BJvVBzG4F8jc971eFUh53/4JFroGtFzgaDlIEedUqJPOMzFJrP3PABIT
hbk7gonJ+v//J0/uysLE3t8UZGJ6DGZuholNB2rx+YUi9hToDv9n/5HFsoAa
g77+h4nxbv7/qdcMqAomBPKHtI8LyKxn8IA7Ig0JONNupNDcVgISCvj4Hxn8
2ucvse85nAsAzOUDGw==
         "], {{0, 20}, {20, 0}}, {0, 255},
         ColorFunction->GrayLevel],
        BoxForm`ImageTag[
        "Byte", ColorSpace -> Automatic, Interleaving -> None],
        Selectable->False],
       BaseStyle->"ImageGraphics",
       ImageSizeRaw->{20, 20},
       PlotRange->{{0, 20}, {0, 20}}], "\[Rule]", "0"}], ",", 
     RowBox[{
      GraphicsBox[
       TagBox[
        RasterBox[{{254, 146, 22, 2, 2, 145, 240, 176, 146, 192, 255, 255, 
         255, 255, 255}, {130, 3, 3, 3, 3, 2, 33, 13, 3, 111, 255, 255, 255, 
         255, 255}, {34, 3, 3, 3, 3, 2, 3, 3, 3, 95, 250, 255, 255, 255, 
         255}, {65, 3, 87, 3, 3, 2, 3, 3, 3, 2, 96, 214, 255, 255, 255}, {172,
          112, 203, 44, 3, 2, 3, 3, 3, 2, 3, 122, 255, 255, 255}, {255, 255, 
         58, 3, 3, 33, 76, 24, 3, 2, 3, 8, 121, 255, 255}, {254, 156, 13, 3, 
         3, 130, 255, 177, 3, 2, 3, 3, 3, 255, 255}, {254, 3, 3, 3, 87, 255, 
         255, 239, 147, 2, 3, 3, 3, 171, 255}, {254, 2, 2, 18, 193, 255, 255, 
         255, 255, 145, 2, 2, 2, 110, 255}, {213, 3, 3, 40, 255, 255, 255, 
         255, 255, 146, 3, 3, 3, 17, 225}, {111, 3, 3, 143, 255, 255, 255, 
         255, 255, 224, 28, 3, 3, 2, 220}, {111, 3, 3, 101, 255, 255, 255, 
         255, 255, 255, 38, 3, 3, 2, 220}, {110, 2, 2, 23, 208, 255, 255, 255,
          255, 255, 37, 2, 2, 110, 255}, {111, 3, 3, 3, 147, 255, 255, 255, 
         255, 161, 8, 3, 3, 111, 255}, {130, 3, 3, 3, 44, 234, 255, 255, 255, 
         146, 3, 3, 3, 214, 255}, {254, 3, 3, 3, 3, 48, 235, 255, 255, 64, 3, 
         3, 3, 255, 255}, {254, 64, 2, 2, 2, 0, 2, 85, 2, 0, 2, 2, 64, 255, 
         255}, {255, 240, 75, 3, 3, 2, 3, 3, 3, 2, 3, 14, 178, 255, 255}, {
         255, 255, 234, 75, 3, 2, 3, 3, 3, 2, 14, 153, 255, 255, 255}, {255, 
         255, 255, 239, 65, 2, 3, 3, 3, 64, 178, 255, 255, 255, 255}}, {{0, 
         20}, {15, 0}}, {0, 255},
         ColorFunction->GrayLevel],
        BoxForm`ImageTag[
        "Byte", ColorSpace -> Automatic, Interleaving -> None],
        Selectable->False],
       BaseStyle->"ImageGraphics",
       ImageSizeRaw->{15, 20},
       PlotRange->{{0, 15}, {0, 20}}], "\[Rule]", "0"}], ",", 
     RowBox[{
      GraphicsBox[
       TagBox[
        RasterBox[{{255, 115, 1, 0, 54, 167, 255, 255, 255}, {255, 116, 2, 2, 
         2, 4, 144, 255, 255}, {255, 116, 2, 2, 2, 2, 101, 255, 255}, {255, 
         116, 2, 2, 2, 2, 101, 255, 255}, {255, 116, 2, 2, 2, 2, 101, 255, 
         255}, {213, 20, 2, 2, 2, 2, 101, 255, 255}, {205, 2, 2, 2, 2, 2, 101,
          255, 255}, {205, 2, 2, 2, 2, 2, 101, 255, 255}, {205, 2, 2, 2, 2, 2,
          101, 255, 255}, {205, 2, 2, 2, 2, 2, 101, 255, 255}, {205, 2, 2, 2, 
         2, 2, 101, 255, 255}, {205, 2, 2, 2, 2, 2, 101, 255, 255}, {242, 87, 
         2, 2, 2, 2, 91, 248, 255}, {255, 116, 2, 2, 2, 2, 2, 190, 255}, {255,
          137, 6, 2, 2, 2, 2, 190, 255}, {255, 255, 25, 2, 2, 2, 2, 190, 
         255}, {255, 255, 63, 2, 2, 2, 2, 47, 255}, {255, 255, 189, 2, 2, 2, 
         2, 12, 174}, {255, 255, 251, 138, 4, 2, 2, 2, 43}, {255, 255, 255, 
         255, 116, 2, 2, 2, 117}}, {{0, 20}, {9, 0}}, {0, 255},
         ColorFunction->GrayLevel],
        BoxForm`ImageTag[
        "Byte", ColorSpace -> Automatic, Interleaving -> None],
        Selectable->False],
       BaseStyle->"ImageGraphics",
       ImageSizeRaw->{9, 20},
       PlotRange->{{0, 9}, {0, 20}}], "\[Rule]", "1"}], ",", 
     RowBox[{
      GraphicsBox[
       TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRJI
mQgU/0cFfy4pMs1HFbrSyczM7IskcGlnNCcTM7PMbITQGVugGqBYPEKXMg9Q
yLxMh3ky1OR5ikxMDExGr/7/z2Dq+gMSehkKVKJrUP0MyJ7DrPsZSB0zYmI2
LfoJ0bKRWeb9/3eL5Jm5Sj5Bjf1my9wBNACobxvcqs3MzHP/P2di4mqEC+03
BVm0l5m/Bi50s5iJe9L//4rMHnChN8rMTC1AWox5Gcz4XmVm3bnvgCwm5l0Q
oalezMxJL8FMUyaQcR9OlPIw63W/gkibMcu0X5ioAnSQHtxcR2ZIaMhsuA8X
++AHFOOK3/QIOWh/vewqe4Ua2gDMqh37
         "], {{0, 20}, {20, 0}}, {0, 255},
         ColorFunction->GrayLevel],
        BoxForm`ImageTag[
        "Byte", ColorSpace -> Automatic, Interleaving -> None],
        Selectable->False],
       BaseStyle->"ImageGraphics",
       ImageSizeRaw->{20, 20},
       PlotRange->{{0, 20}, {0, 20}}], "\[Rule]", "0"}], ",", 
     RowBox[{
      GraphicsBox[
       TagBox[
        RasterBox[{{255, 255, 255, 255, 255, 255, 255, 255, 255, 253, 103, 0, 
         221}, {255, 255, 255, 255, 255, 255, 255, 255, 255, 168, 2, 2, 
         107}, {255, 255, 255, 255, 255, 255, 255, 255, 249, 47, 2, 2, 155}, {
         255, 255, 255, 255, 255, 255, 255, 255, 108, 2, 2, 2, 173}, {255, 
         255, 255, 255, 255, 255, 255, 246, 50, 2, 2, 74, 243}, {255, 255, 
         255, 255, 255, 255, 255, 186, 2, 2, 2, 218, 255}, {255, 255, 255, 
         255, 255, 255, 244, 94, 2, 2, 59, 242, 255}, {255, 255, 255, 255, 
         255, 255, 192, 2, 2, 2, 113, 255, 255}, {255, 255, 255, 255, 255, 
         255, 105, 2, 2, 59, 242, 255, 255}, {255, 255, 255, 255, 255, 183, 
         20, 2, 2, 173, 255, 255, 255}, {255, 255, 255, 255, 255, 75, 2, 2, 
         92, 243, 255, 255, 255}, {255, 255, 255, 255, 215, 18, 2, 2, 200, 
         255, 255, 255, 255}, {255, 255, 255, 241, 80, 2, 2, 24, 217, 255, 
         255, 255, 255}, {255, 255, 255, 168, 2, 2, 23, 194, 255, 255, 255, 
         255, 255}, {255, 255, 177, 14, 2, 2, 110, 255, 255, 255, 255, 255, 
         255}, {255, 242, 58, 2, 2, 100, 247, 255, 255, 255, 255, 255, 255}, {
         244, 71, 2, 2, 22, 212, 255, 255, 255, 255, 255, 255, 255}, {230, 2, 
         2, 2, 51, 255, 255, 255, 255, 255, 255, 255, 255}, {230, 2, 2, 2, 
         109, 255, 255, 255, 255, 255, 255, 255, 255}, {242, 50, 20, 146, 253,
          255, 255, 255, 255, 255, 255, 255, 255}}, {{0, 20}, {13, 0}}, {0, 
         255},
         ColorFunction->GrayLevel],
        BoxForm`ImageTag[
        "Byte", ColorSpace -> Automatic, Interleaving -> None],
        Selectable->False],
       BaseStyle->"ImageGraphics",
       ImageSizeRaw->{13, 20},
       PlotRange->{{0, 13}, {0, 20}}], "\[Rule]", "1"}], ",", 
     RowBox[{
      GraphicsBox[
       TagBox[RasterBox[CompressedData["
1:eJxdUDEOwjAMtJgYEeID/ILRjKxFPKAVoWIJUoqEmPw0Py04cRvsWnKUO93F
OR+HV/fYAMC0laPrP+eU+u91J+AWp+cYw/0S32EM6TQU2UF6L52XYgDKtoTw
lEAkxJWAEBxRC7lZRFE0AOynkFJ2LNU7zdK/3BAFUEbzb3W5n86MM6GwRsJr
E9VdYGMYNT3rO1wjaCzU1HY9S3K7Li7JG/oBdlL2Qg==
         "], {{0, 20}, {18, 
         0}}, {0, 255},
         ColorFunction->GrayLevel],
        BoxForm`ImageTag[
        "Byte", ColorSpace -> Automatic, Interleaving -> None],
        Selectable->False],
       BaseStyle->"ImageGraphics",
       ImageSizeRaw->{18, 20},
       PlotRange->{{0, 18}, {0, 20}}], "\[Rule]", "0"}], ",", 
     RowBox[{
      GraphicsBox[
       TagBox[
        RasterBox[{{61, 230, 255, 255, 255, 255}, {69, 52, 255, 255, 255, 
         255}, {197, 12, 255, 255, 255, 255}, {220, 43, 182, 255, 255, 255}, {
         93, 4, 156, 255, 255, 255}, {118, 0, 156, 255, 255, 255}, {247, 36, 
         62, 251, 255, 255}, {255, 67, 1, 178, 255, 255}, {255, 147, 1, 100, 
         255, 255}, {255, 249, 1, 100, 255, 255}, {255, 253, 79, 100, 255, 
         255}, {255, 255, 99, 2, 233, 255}, {255, 255, 99, 1, 146, 255}, {255,
          255, 99, 1, 133, 255}, {255, 255, 99, 1, 42, 255}, {255, 255, 192, 
         1, 42, 255}, {255, 255, 202, 1, 14, 213}, {255, 255, 247, 96, 1, 
         193}, {255, 255, 255, 232, 4, 127}, {255, 255, 255, 196, 2, 89}}, {{
         0, 20}, {6, 0}}, {0, 255},
         ColorFunction->GrayLevel],
        BoxForm`ImageTag[
        "Byte", ColorSpace -> Automatic, Interleaving -> None],
        Selectable->False],
       BaseStyle->"ImageGraphics",
       ImageSizeRaw->{6, 20},
       PlotRange->{{0, 6}, {0, 20}}], "\[Rule]", "1"}], ",", 
     RowBox[{
      GraphicsBox[
       TagBox[
        RasterBox[{{172, 62, 53, 226, 255, 255}, {24, 1, 1, 56, 255, 255}, {
         24, 1, 1, 9, 255, 255}, {45, 1, 1, 9, 255, 255}, {188, 1, 1, 9, 255, 
         255}, {188, 1, 1, 9, 255, 255}, {188, 1, 1, 9, 255, 255}, {188, 1, 1,
          9, 255, 255}, {188, 1, 1, 4, 158, 255}, {188, 1, 1, 1, 100, 255}, {
         233, 67, 1, 1, 100, 255}, {255, 98, 1, 1, 100, 255}, {255, 98, 1, 1, 
         100, 255}, {255, 98, 1, 1, 100, 255}, {255, 98, 1, 1, 100, 255}, {
         255, 98, 1, 1, 100, 255}, {255, 98, 1, 1, 100, 255}, {255, 189, 4, 1,
          100, 255}, {255, 255, 7, 1, 6, 145}, {255, 255, 7, 1, 1, 25}}, {{0, 
         20}, {6, 0}}, {0, 255},
         ColorFunction->GrayLevel],
        BoxForm`ImageTag[
        "Byte", ColorSpace -> Automatic, Interleaving -> None],
        Selectable->False],
       BaseStyle->"ImageGraphics",
       ImageSizeRaw->{6, 20},
       PlotRange->{{0, 6}, {0, 20}}], "\[Rule]", "1"}], ",", 
     RowBox[{
      GraphicsBox[
       TagBox[
        RasterBox[{{255, 255, 41, 83, 255}, {255, 255, 2, 3, 255}, {255, 255, 
         21, 2, 153}, {255, 255, 103, 3, 153}, {255, 255, 41, 2, 214}, {255, 
         255, 2, 3, 255}, {255, 214, 1, 2, 255}, {255, 173, 2, 3, 255}, {255, 
         153, 1, 2, 255}, {255, 153, 2, 43, 255}, {255, 153, 1, 104, 255}, {
         255, 153, 2, 104, 255}, {255, 52, 1, 205, 255}, {234, 32, 22, 225, 
         255}, {183, 2, 52, 255, 255}, {103, 3, 52, 255, 255}, {103, 2, 152, 
         255, 255}, {22, 3, 235, 255, 255}, {0, 63, 255, 255, 255}, {2, 144, 
         255, 255, 255}}, {{0, 20}, {5, 0}}, {0, 255},
         ColorFunction->GrayLevel],
        BoxForm`ImageTag[
        "Byte", ColorSpace -> Automatic, Interleaving -> None],
        Selectable->False],
       BaseStyle->"ImageGraphics",
       ImageSizeRaw->{5, 20},
       PlotRange->{{0, 5}, {0, 20}}], "\[Rule]", "1"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   GraphicsBox[
    TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRJI
mQgQCwHxfxh4sz/TkJHB/SVc4JoKExh0wQTexgB5bNJMTHwfoSIFQAH5yRuA
5CIw/1MsKxNT+I3/N/hgIvZMTALFf4EMaajIDqCKXLAUVOStDBOT939kkW6g
odfBAn+lmLg+/P9/mpOJaTlEyWwmJkUgFcnEZP4WLHBKl4mp5P//+cxMTPch
SmyYmHiBzGImJsvvYIE8VibODWAJ1q1ggcmsTNztQPoRB5MMiP++A6i7AMRa
yAQWOZDBxMQZ/R0ucriCn4lJYwPEfKAIqyob0M9G76DBcIcdHFBS1W/ggTdT
lokpdu0TOP8/ADHi5B0=
      "], {{0, 20}, {18, 0}}, {0, 255},
      ColorFunction->GrayLevel],
     BoxForm`ImageTag["Byte", ColorSpace -> Automatic, Interleaving -> None],
     Selectable->False],
    BaseStyle->"ImageGraphics",
    ImageSize->{22.86328125, Automatic},
    ImageSizeRaw->{18, 20},
    PlotRange->{{0, 18}, {0, 20}}]}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[5]:=",ExpressionUUID->"098c6067-2243-4f03-bf08-f8dc5bafcc24"],

Cell[BoxData["0"], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[5]=",ExpressionUUID->"ff2099a0-3b78-4211-a972-ed7962a4ea7c"]
}, Open  ]],

Cell[TextData[{
 "To get some sense of how this works\[LongDash]and because it\
\[CloseCurlyQuote]s useful in its own right\[LongDash]let\[CloseCurlyQuote]s \
talk about the function ",
 ButtonBox["Nearest",
  BaseStyle->"Link"],
 ", that",
 " finds what element in a list is nearest to what you supply."
}], "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:9",ExpressionUUID->"d24f88cd-2dda-463f-a5e5-b5478525e3e5"],

Cell["Find what number in the list is nearest to 22:", "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"df31b2c0-0bc6-4346-bed5-81351ccac965"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Nearest", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "10", ",", "20", ",", "30", ",", "40", ",", "50", ",", "60", ",", "70", 
     ",", "80"}], "}"}], ",", "22"}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[6]:=",ExpressionUUID->"f29e4422-4e76-4108-9fbd-a0d7f4142db5"],

Cell[BoxData[
 RowBox[{"{", "20", "}"}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[6]=",ExpressionUUID->"921432e9-c2e2-4b11-b98b-546f7b1a946b"]
}, Open  ]],

Cell["Find the nearest three numbers:", "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"fc40ab71-e432-44b4-9d32-d9dd88440e84"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Nearest", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "10", ",", "20", ",", "30", ",", "40", ",", "50", ",", "60", ",", "70", 
     ",", "80"}], "}"}], ",", "22", ",", "3"}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[7]:=",ExpressionUUID->"b3569762-0301-45a7-9c38-db5874ac6aae"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"20", ",", "30", ",", "10"}], "}"}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[7]=",ExpressionUUID->"9dd1f2b1-9a74-4ff0-bf7d-249bee98a5a2"]
}, Open  ]],

Cell[TextData[{
 ButtonBox["Nearest",
  BaseStyle->"Link"],
 " can find nearest colors as well."
}], "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:10",ExpressionUUID->"e6019b5f-f7df-4c82-be2a-83183974b3c1"],

Cell["\<\
Find the 3 colors in the list that are nearest to the color you give:\
\>", "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"577882fa-0a63-4ea8-b829-bfd8e9cbc8b8"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Nearest", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{
          {GrayLevel[0], RectangleBox[{0, 0}]}, 
          {GrayLevel[0], RectangleBox[{1, -1}]}, 
          {Hue[0.], RectangleBox[{0, -1}, {2, 1}]}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->Hue[0., 1., 0.6666666666666667],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "Hue[0.]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = Hue[0., 0.5, 0.5]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["HueColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      Hue[0.],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{
          {GrayLevel[0], RectangleBox[{0, 0}]}, 
          {GrayLevel[0], RectangleBox[{1, -1}]}, 
          {Hue[0.05], RectangleBox[{0, -1}, {2, 1}]}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->Hue[0.05000000000000001, 1., 0.6666666666666667],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "Hue[0.05]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = Hue[0.05, 0.5, 0.5]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["HueColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      Hue[0.05],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{
          {GrayLevel[0], RectangleBox[{0, 0}]}, 
          {GrayLevel[0], RectangleBox[{1, -1}]}, 
          {Hue[0.1], RectangleBox[{0, -1}, {2, 1}]}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->Hue[0.10000000000000002`, 1., 0.6666666666666667],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "Hue[0.1]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = Hue[0.1, 0.5, 0.5]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["HueColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      Hue[0.1],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{
          {GrayLevel[0], RectangleBox[{0, 0}]}, 
          {GrayLevel[0], RectangleBox[{1, -1}]}, 
          {Hue[0.15000000000000002`], RectangleBox[{0, -1}, {2, 1}]}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->Hue[0.15, 1., 0.6666666666666667],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "Hue[0.15000000000000002]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = 
           Hue[0.15000000000000002`, 0.5, 0.5]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["HueColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      Hue[0.15000000000000002`],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{
          {GrayLevel[0], RectangleBox[{0, 0}]}, 
          {GrayLevel[0], RectangleBox[{1, -1}]}, 
          {Hue[0.2], RectangleBox[{0, -1}, {2, 1}]}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->Hue[0.20000000000000004`, 1., 0.6666666666666667],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "Hue[0.2]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = Hue[0.2, 0.5, 0.5]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["HueColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      Hue[0.2],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{
          {GrayLevel[0], RectangleBox[{0, 0}]}, 
          {GrayLevel[0], RectangleBox[{1, -1}]}, 
          {Hue[0.25], RectangleBox[{0, -1}, {2, 1}]}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->Hue[0.25, 1., 0.6666666666666667],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "Hue[0.25]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = Hue[0.25, 0.5, 0.5]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["HueColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      Hue[0.25],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{
          {GrayLevel[0], RectangleBox[{0, 0}]}, 
          {GrayLevel[0], RectangleBox[{1, -1}]}, 
          {Hue[0.30000000000000004`], RectangleBox[{0, -1}, {2, 1}]}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->Hue[0.30000000000000004`, 1., 0.6666666666666667],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "Hue[0.30000000000000004]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = 
           Hue[0.30000000000000004`, 0.5, 0.5]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["HueColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      Hue[0.30000000000000004`],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{
          {GrayLevel[0], RectangleBox[{0, 0}]}, 
          {GrayLevel[0], RectangleBox[{1, -1}]}, 
          {Hue[0.35000000000000003`], RectangleBox[{0, -1}, {2, 1}]}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->Hue[0.35000000000000003`, 1., 0.6666666666666667],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "Hue[0.35000000000000003]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = 
           Hue[0.35000000000000003`, 0.5, 0.5]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["HueColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      Hue[0.35000000000000003`],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{
          {GrayLevel[0], RectangleBox[{0, 0}]}, 
          {GrayLevel[0], RectangleBox[{1, -1}]}, 
          {Hue[0.4], RectangleBox[{0, -1}, {2, 1}]}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->Hue[0.4000000000000001, 1., 0.6666666666666667],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "Hue[0.4]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = Hue[0.4, 0.5, 0.5]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["HueColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      Hue[0.4],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{
          {GrayLevel[0], RectangleBox[{0, 0}]}, 
          {GrayLevel[0], RectangleBox[{1, -1}]}, 
          {Hue[0.45], RectangleBox[{0, -1}, {2, 1}]}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->Hue[0.45, 1., 0.6666666666666667],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "Hue[0.45]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = Hue[0.45, 0.5, 0.5]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["HueColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      Hue[0.45],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{
          {GrayLevel[0], RectangleBox[{0, 0}]}, 
          {GrayLevel[0], RectangleBox[{1, -1}]}, 
          {Hue[0.5], RectangleBox[{0, -1}, {2, 1}]}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->Hue[0.5, 1., 0.6666666666666667],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "Hue[0.5]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = Hue[0.5, 0.5, 0.5]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["HueColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      Hue[0.5],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{
          {GrayLevel[0], RectangleBox[{0, 0}]}, 
          {GrayLevel[0], RectangleBox[{1, -1}]}, 
          {Hue[0.55], RectangleBox[{0, -1}, {2, 1}]}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->Hue[0.55, 1., 0.6666666666666667],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "Hue[0.55]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = Hue[0.55, 0.5, 0.5]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["HueColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      Hue[0.55],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{
          {GrayLevel[0], RectangleBox[{0, 0}]}, 
          {GrayLevel[0], RectangleBox[{1, -1}]}, 
          {Hue[0.6000000000000001], RectangleBox[{0, -1}, {2, 1}]}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->Hue[0.6000000000000001, 1., 0.6666666666666667],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "Hue[0.6000000000000001]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = 
           Hue[0.6000000000000001, 0.5, 0.5]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["HueColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      Hue[0.6000000000000001],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{
          {GrayLevel[0], RectangleBox[{0, 0}]}, 
          {GrayLevel[0], RectangleBox[{1, -1}]}, 
          {Hue[0.65], RectangleBox[{0, -1}, {2, 1}]}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->Hue[0.65, 1., 0.6666666666666667],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "Hue[0.65]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = Hue[0.65, 0.5, 0.5]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["HueColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      Hue[0.65],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{
          {GrayLevel[0], RectangleBox[{0, 0}]}, 
          {GrayLevel[0], RectangleBox[{1, -1}]}, 
          {Hue[0.7000000000000001], RectangleBox[{0, -1}, {2, 1}]}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->Hue[0.7000000000000001, 1., 0.6666666666666667],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "Hue[0.7000000000000001]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = 
           Hue[0.7000000000000001, 0.5, 0.5]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["HueColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      Hue[0.7000000000000001],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{
          {GrayLevel[0], RectangleBox[{0, 0}]}, 
          {GrayLevel[0], RectangleBox[{1, -1}]}, 
          {Hue[0.75], RectangleBox[{0, -1}, {2, 1}]}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->Hue[0.75, 1., 0.6666666666666667],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "Hue[0.75]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = Hue[0.75, 0.5, 0.5]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["HueColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      Hue[0.75],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{
          {GrayLevel[0], RectangleBox[{0, 0}]}, 
          {GrayLevel[0], RectangleBox[{1, -1}]}, 
          {Hue[0.8], RectangleBox[{0, -1}, {2, 1}]}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->Hue[0.8000000000000002, 1., 0.6666666666666667],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "Hue[0.8]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = Hue[0.8, 0.5, 0.5]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["HueColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      Hue[0.8],
      Editable->False,
      Selectable->False]}], "}"}], ",", 
   InterpretationBox[
    ButtonBox[
     TooltipBox[
      GraphicsBox[{
        {GrayLevel[0], RectangleBox[{0, 0}]}, 
        {GrayLevel[0], RectangleBox[{1, -1}]}, 
        {RGBColor[
         0.8727094319714808, 0.9066617343162084, 0.09569669807641734], 
         RectangleBox[{0, -1}, {2, 1}]}},
       AspectRatio->1,
       Frame->True,
       FrameStyle->RGBColor[
        0.5818062879809872, 0.6044411562108056, 0.06379779871761157],
       FrameTicks->None,
       ImageSize->
        Dynamic[{
         Automatic, 
          1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
           Magnification])}],
       PlotRangePadding->None],
      "RGBColor[0.8727094319714808, 0.9066617343162084, 0.09569669807641734]"],
     Appearance->None,
     BaseStyle->{},
     BaselinePosition->Baseline,
     ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
       If[
        Not[
         AbsoluteCurrentValue["Deployed"]], 
        SelectionMove[Typeset`box$, All, Expression]; 
        FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
        FrontEnd`Private`$ColorSelectorInitialColor = 
         RGBColor[
          0.8727094319714808, 0.9066617343162084, 0.09569669807641734]; 
        FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
        MathLink`CallFrontEnd[
          FrontEnd`AttachCell[Typeset`box$, 
           FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
           Left, Top}, 
           "ClosingActions" -> {
            "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
     DefaultBaseStyle->{},
     Evaluator->Automatic,
     Method->"Preemptive"],
    RGBColor[0.8727094319714808, 0.9066617343162084, 0.09569669807641734],
    Editable->False,
    Selectable->False], ",", "3"}], "]"}]], "Input",
 Deletable->False,
 GraphicsBoxOptions->{BaselinePosition->Scaled[0.1]},
 CellLabel->"In[8]:=",ExpressionUUID->"1f74ce26-c56c-4c63-8162-1aaa120a7067"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   InterpretationBox[
    ButtonBox[
     TooltipBox[
      GraphicsBox[{
        {GrayLevel[0], RectangleBox[{0, 0}]}, 
        {GrayLevel[0], RectangleBox[{1, -1}]}, 
        {Hue[0.15000000000000002`], RectangleBox[{0, -1}, {2, 1}]}},
       AspectRatio->1,
       Frame->True,
       FrameStyle->Hue[0.15, 1., 0.6666666666666667],
       FrameTicks->None,
       ImageSize->
        Dynamic[{
         Automatic, 
          1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
           Magnification])}],
       PlotRangePadding->None],
      "Hue[0.15000000000000002]"],
     Appearance->None,
     BaseStyle->{},
     BaselinePosition->Baseline,
     ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
       If[
        Not[
         AbsoluteCurrentValue["Deployed"]], 
        SelectionMove[Typeset`box$, All, Expression]; 
        FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
        FrontEnd`Private`$ColorSelectorInitialColor = 
         Hue[0.15000000000000002`, 0.5, 0.5]; 
        FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
        MathLink`CallFrontEnd[
          FrontEnd`AttachCell[Typeset`box$, 
           FrontEndResource["HueColorValueSelector"], {0, {Left, Bottom}}, {
           Left, Top}, 
           "ClosingActions" -> {
            "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
     DefaultBaseStyle->{},
     Evaluator->Automatic,
     Method->"Preemptive"],
    Hue[0.15000000000000002`],
    Editable->False,
    Selectable->False], ",", 
   InterpretationBox[
    ButtonBox[
     TooltipBox[
      GraphicsBox[{
        {GrayLevel[0], RectangleBox[{0, 0}]}, 
        {GrayLevel[0], RectangleBox[{1, -1}]}, 
        {Hue[0.2], RectangleBox[{0, -1}, {2, 1}]}},
       AspectRatio->1,
       Frame->True,
       FrameStyle->Hue[0.20000000000000004`, 1., 0.6666666666666667],
       FrameTicks->None,
       ImageSize->
        Dynamic[{
         Automatic, 
          1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
           Magnification])}],
       PlotRangePadding->None],
      "Hue[0.2]"],
     Appearance->None,
     BaseStyle->{},
     BaselinePosition->Baseline,
     ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
       If[
        Not[
         AbsoluteCurrentValue["Deployed"]], 
        SelectionMove[Typeset`box$, All, Expression]; 
        FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
        FrontEnd`Private`$ColorSelectorInitialColor = Hue[0.2, 0.5, 0.5]; 
        FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
        MathLink`CallFrontEnd[
          FrontEnd`AttachCell[Typeset`box$, 
           FrontEndResource["HueColorValueSelector"], {0, {Left, Bottom}}, {
           Left, Top}, 
           "ClosingActions" -> {
            "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
     DefaultBaseStyle->{},
     Evaluator->Automatic,
     Method->"Preemptive"],
    Hue[0.2],
    Editable->False,
    Selectable->False], ",", 
   InterpretationBox[
    ButtonBox[
     TooltipBox[
      GraphicsBox[{
        {GrayLevel[0], RectangleBox[{0, 0}]}, 
        {GrayLevel[0], RectangleBox[{1, -1}]}, 
        {Hue[0.25], RectangleBox[{0, -1}, {2, 1}]}},
       AspectRatio->1,
       Frame->True,
       FrameStyle->Hue[0.25, 1., 0.6666666666666667],
       FrameTicks->None,
       ImageSize->
        Dynamic[{
         Automatic, 
          1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
           Magnification])}],
       PlotRangePadding->None],
      "Hue[0.25]"],
     Appearance->None,
     BaseStyle->{},
     BaselinePosition->Baseline,
     ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
       If[
        Not[
         AbsoluteCurrentValue["Deployed"]], 
        SelectionMove[Typeset`box$, All, Expression]; 
        FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
        FrontEnd`Private`$ColorSelectorInitialColor = Hue[0.25, 0.5, 0.5]; 
        FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
        MathLink`CallFrontEnd[
          FrontEnd`AttachCell[Typeset`box$, 
           FrontEndResource["HueColorValueSelector"], {0, {Left, Bottom}}, {
           Left, Top}, 
           "ClosingActions" -> {
            "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
     DefaultBaseStyle->{},
     Evaluator->Automatic,
     Method->"Preemptive"],
    Hue[0.25],
    Editable->False,
    Selectable->False]}], "}"}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 GraphicsBoxOptions->{BaselinePosition->Scaled[0.1]},
 CellLabel->"Out[8]=",ExpressionUUID->"2c77c9e8-890d-4352-bfd9-41b0556ac4f9"]
}, Open  ]],

Cell["It also works on words.", "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:11",ExpressionUUID->"de178ca6-fe13-4505-aeec-c3274b10a730"],

Cell["Find the 10 words nearest to \[OpenCurlyDoubleQuote]good\
\[CloseCurlyDoubleQuote] in the list of words:", "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:12",ExpressionUUID->"a6804c3a-3f69-4365-8e31-c6d0ad1209bf"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Nearest", "[", 
  RowBox[{
   RowBox[{"WordList", "[", " ", "]"}], ",", "\"\<good\>\"", ",", "10"}], 
  "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[9]:=",ExpressionUUID->"ab298494-4b2f-44fd-8bfb-cc458346e773"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"good\"\>", ",", "\<\"food\"\>", ",", "\<\"goad\"\>", 
   ",", "\<\"god\"\>", ",", "\<\"gold\"\>", ",", "\<\"goo\"\>", 
   ",", "\<\"goody\"\>", ",", "\<\"goof\"\>", ",", "\<\"goon\"\>", 
   ",", "\<\"goop\"\>"}], "}"}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[9]=",ExpressionUUID->"34e30938-258b-48b8-9cb0-1ba4bcb23bad"]
}, Open  ]],

Cell[TextData[{
 "There\[CloseCurlyQuote]s a notion of nearness for images too. ",
 "And though it\[CloseCurlyQuote]s far from the whole story, this is \
effectively part of what ",
 ButtonBox["ImageIdentify",
  BaseStyle->"Link"],
 " is using.",
 " "
}], "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->{
  "LastCellOfAPage", 
   "i:13"},ExpressionUUID->"5f4570cd-f219-4dab-8e0a-c292afbd8d35"],

Cell[TextData[{
 "Something that\[CloseCurlyQuote]s again related is recognizing text (",
 StyleBox["optical character recognition",
  FontSlant->"Italic"],
 " or OCR). Let\[CloseCurlyQuote]s make a piece of text \
that\[CloseCurlyQuote]s blurred."
}], "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->{
  "p:125", "i:14"},ExpressionUUID->"f8cdde60-2827-4b95-bea5-ce8d66806581"],

Cell["Create an image of the word \[OpenCurlyDoubleQuote]hello\
\[CloseCurlyDoubleQuote], then blur it:", "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:15",ExpressionUUID->"4147d05f-fc3b-4923-9e86-648743da6e32"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Blur", "[", 
  RowBox[{
   RowBox[{"Rasterize", "[", 
    RowBox[{"Style", "[", 
     RowBox[{"\"\<hello\>\"", ",", "30"}], "]"}], "]"}], ",", "3"}], 
  "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[10]:=",ExpressionUUID->"f9286690-99fd-4b9c-a76b-6937a69d1f30"],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJztmOlTWmm+x7vmvrkv779w39yXUzVTt2a6p6ump28qmSxtVMQdWWVxAfd9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    "], {{0, 38}, {63, 
    0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> False],
   Selectable->False],
  DefaultBaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{63, 38},
  PlotRange->{{0, 63}, {0, 38}}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[10]=",ExpressionUUID->"330a2bf0-8806-4e3b-b9f2-44bbc08ecb44"]
}, Open  ]],

Cell[TextData[{
 ButtonBox["TextRecognize",
  BaseStyle->"Link"],
 " can still recognize the original text string ",
 "in this",
 "."
}], "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:16",ExpressionUUID->"e449994e-0a3b-4897-989b-bae9f0288e34"],

Cell["Recognize text in the image:", "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"a87fef7a-4389-4a6e-84bb-b11f9d7bcff0"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TextRecognize", "[", 
  GraphicsBox[
   TagBox[RasterBox[CompressedData["
1:eJztmOlTWmm+x7vmvrkv779w39yXUzVTt2a6p6ump28qmSxtVMQdWWVxAfd9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     "], {{0, 38}, {63, 
     0}}, {0, 255},
     ColorFunction->RGBColor],
    BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> False],
    Selectable->False],
   DefaultBaseStyle->"ImageGraphics",
   ImageSize->Automatic,
   ImageSizeRaw->{63, 38},
   PlotRange->{{0, 63}, {0, 38}}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[11]:=",ExpressionUUID->"2336e457-2fea-4171-b22e-6e392a8846b0"],

Cell[BoxData["\<\"hello\"\>"], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[11]=",ExpressionUUID->"4427443f-0366-4809-8642-afacc5753e15"]
}, Open  ]],

Cell[TextData[{
 "If the text gets too blurred ",
 ButtonBox["TextRecognize",
  BaseStyle->"Link"],
 " can\[CloseCurlyQuote]t tell what it says\[LongDash]and you probably can\
\[CloseCurlyQuote]t either."
}], "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"c89cc995-90a4-42e0-867d-ca15c00ccc81"],

Cell["\<\
Generate a sequence of progressively more blurred pieces of text:\
\>", "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"bcc5002e-e705-4a3c-b37c-f3b0344df360"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"Blur", "[", 
    RowBox[{
     RowBox[{"Rasterize", "[", 
      RowBox[{"Style", "[", 
       RowBox[{"\"\<hello\>\"", ",", "15"}], "]"}], "]"}], ",", "r"}], "]"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"r", ",", "0", ",", "4"}], "}"}]}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[12]:=",ExpressionUUID->"56beddf4-14b2-43a3-9504-1075f201a0bd"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   GraphicsBox[
    TagBox[RasterBox[CompressedData["
1:eJztlK1uwzAUha2NDE7aA0x7AePRwKFKncZCWq2pRrqonTSFmhmamQUVGQUV
lRSVmISUBISUBBiYGBRk/km6pm26kKHtSo6Ob44+X9tXfhi+94MrAMDsRn/6
g09vOh1Ez7d68jKZvY0no9enycdoPJo+Dq918k6Pez2MLv+jJZSUatfZvTP2
M/p8SAIBxLwjOyUeAESc6DY49YBHOsO1G1J5oi/C09+DQ8QSEgATHlnm9a+C
4QDabIAT8QP82+yHNKuyMvZtCobxnPSM6nFzS4rZ1ULKkhjZVXk7vDL7eM5o
ZGloW1cOgtgVJtZYY9ayVJtYW6LF1lWQxXpZXLTAnblH1s6cJ4aPVkV15rQ6
c5lSDefSCeCFCCMdODS7g3rRs3BnTvK6oRXvVTttdMsR3EeE6iD2S1muLsDh
ct+UKvU7wAk/7oXU7lM1tTOHLDuAgDDJ2uBluUXm7iFd8DzfJCREbKOz3Ny5
v9qqpq7NyzTjzHaFn6ryBB6bbnH1Co6sz0U05/pMixW2rZmUTa3NkVdbob/I
Lrb//vykKApx+PgoUYj6STnUpjZh5t0fqr8ZX+BApvc=
      "], {{0, 19}, {31, 0}}, {0,
       255},
      ColorFunction->RGBColor],
     BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> False],
     Selectable->False],
    DefaultBaseStyle->"ImageGraphics",
    ImageSize->Automatic,
    ImageSizeRaw->{31, 19},
    PlotRange->{{0, 31}, {0, 19}}], ",", 
   GraphicsBox[
    TagBox[RasterBox[CompressedData["
1:eJzVlG9MG2Ucx4m+8aWJL3xhdMG5tL3e9fpnxCUmBhYzlaAkGIeDMtNlHcom
aEGWmWxZAmN1dkX5M0oRmGIWIW5RtzllVgbUBVzUZRhKrwUKHb3e9a53pdeD
u+vdfKBsVscc+kp/yXP5Pk++z+d57vf88svdU1Oy74GcnJzah8CnxHKwwGaz
HHrlYTB5tbr2zcpq694Xq+uslVbbtj0PgsVHwNgExoq+9X8OBcS/tN9nq5wW
4wvzOLuU3sgBSnqZJebnGFGSlSx9L3uKmunenf+6y0tx0n3ZUio+1rk/P78n
SKSELH2ve6UorLMMLm/9geLEDcCpkQ4zUtgZIAH8D/13cDNc1uIJEzEcRJTm
lqRMIsGP80l2dRVnk3xaUUQAdFUgL7nX4Le18mczk+BA2jJwV7l6e90J5zFb
ntGEQKXO/mss4Msig//yqb2m2KjfajS9/X7fJLm4xK0Pl2+bXzboTXrDG/Ut
3ikSvGIqjrksjz26WWUorj9uP7ozV6WBrKNzdIIK9Nh0JhNSa29pd7xnzMvb
5RzCCXx4HXiSo4EZ0aHQviMnP2yq08Kotqjxp0gC3Lxtlwo60Hx1JsrGo9cG
GiCofHDqZnCsV697av+pi/65SGTWd66pFDU6rgdDQ3fBMZwKjffq4M1l9rMh
gl2kI56eg2o1cujLiUzOS9s9JCeCnAaGXTBi/t437xtu25T7eGHNUafzo2aH
/d29agQtufyb39NxFzwSw0baNFrt6bFZXlJuKQKJXSpTqV84fhnA3Wa4on2l
WhQpFRhxw0gFgE9eac198gnz4Q/c3b2nu7q6u0593HNu6mZ4CMCL3cE78OIM
vAOCdwzciCyDkldEOuixqDTPHxtcg7f9BR72eztR7ZbDZ0ZCUTrBMnSMiMWT
/GJsJec72wMEJ3BURvsXyOCPbkSjfsc9FGX5ZY6+ft4BbYGr+sbXg+/2BAga
/7WxCDHodpz85OvRUc/nrqauSxMMTV5ptaqgyoHxcDJBZ3T/eIhc+LmhCNZB
zzn6vvruC5dZg8Bw1WCA4uMznx0oeKvXG09JisTPjvUXbK/3zjKCyBMTFxot
qAHVIgi8Ne/pE/1X4wlm8ttm1PTMsw3fRCnat6YvEgwbvXHhyGuoXqfV6lB9
YdWZYSwppBVZSjEkwwmrVa9IAk+SrLDaLpS0AJ4+FPT7fP5QGBQW8Mgin5ib
DkzjjJROZ2kZmBNUZBrDfNh0mIzz4sZ6lSKDyG5+YOVOM8zWK1NwvPyPeux/
NH4HKWunEQ==
      "], {{0, 19}, {31, 0}}, {0, 255},
      ColorFunction->RGBColor],
     BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> False],
     Selectable->False],
    DefaultBaseStyle->"ImageGraphics",
    ImageSize->Automatic,
    ImageSizeRaw->{31, 19},
    PlotRange->{{0, 31}, {0, 19}}], ",", 
   GraphicsBox[
    TagBox[RasterBox[CompressedData["
1:eJzVVNlTmlcczbQvfexM/4BO/4u+9rGv6bSTLtNGWzWbguyLCopbCIgaJQYJ
yCKrMYgLiIBsEtlBxYhhEVARRAThk532Q9KpaZPmqQ/9zdxvzr333DP3nvl+
54tmyM3Wj27cuAH/BPzcbEJ/BYM1Yb/5FJx82wG/29bR8tvXHYiWthbYl80f
g4ufgeNzcNTx7//bqlbKxXy+UCxVqrXaB7i1Wp1dyF8Wy+VKtVIpvcHvPQlk
klG/LxCNZ4ACqP9v0tVKEbhIREK+V4fJs2wuk45f4bMUUCpX33nkeN+5OssQ
rGy8Pkrl38N588ZyIXUUMC9Kp5+uOT2hiN/XwC5vLHtZfue1DrZ0otGeUZ7c
4Yskz7MAkG84VLsyAXz4JZADAAD0rVTIxUPbCv4EcUist7za97pWrrDRGU7n
itUGOZcD6aDLlSuXQx41jwzve8ySqw0ms81m2wmE41mgUNdKJyL+XY/d5rA7
9vzhRPI0+tol59BwAwLt5q5vx97AOkfwLJPLphNhkGyz2q12717gJHmRL1WC
bhWT1HoHicb1klCoLjR8aJqn2g0cJeKRHatCwKAOdeMIPYQxpkBj8ex4LLKZ
Edzgn+JcGojXbfvRw4Nti4I/RenHYfBY/MNR5oLWEYyng24FvevH727fvoMk
duMJnb/ch0Cpi9pN2+YqawyJQtwn9BJJfT0wNH7wiVSlXhMzKdjr4gP8NZPL
aVljj6EQ8Ac9vSRSH6EdgoD20iUbu0H3KoN05x5xiCVTqlXKGRoZChngv1iR
zTFg0GYoYYDJmxVyp4d7kHDUmFj6gvfk4XVxbD93WW1SLrDRyLt4yqRcrTeu
K5+ND7bcQ6BZKtBz7iMEiSEwbfkCr3dVUjYKOcyRyGZnKD/dvtWM6h6hTzHo
tKGeDjSGJBCLOfRhzFviHLlyXSamQ+HQSYli9+AoFvUb5JzOtvYfSKKQRzNL
xVC5Mrc/chQN6BYFGDSZI62L/9z0/V08ic7iikUCIZ8lFM5pNEohg4wZ5Gs3
vXtvxNkLCq1MNAWFo5/Oa/cP46exkHmJD29tv9UrPPBoBCMYGm/B448cN8Qx
j/jzS89FdOiDX9H9VNGC0rix8dJssjvd207z82cUZB9zWe/2eqyyGSqSOCVZ
Usul00hoO2lsRmO2u6wG8RSlrRUGmVwKb+skjwmTwuXt4GHsMGRUzBGIE89X
DUbtwkQvDAGBkmkTXB5PJBIodZtu++YLFq0TRWXLjHabRcYe7UQ9YkhW1xTz
4wQ4AgIjj4zTaRT8AxgERuGoXCcBp0Y6Pbe2Af59yUTM81LHfCYzOvZCgVdW
legpGduFheNw2EEydV5l8nq3dMtC0vD4Y6nW6nJrl+p4XKKxOB3G5Vn6IAaL
giGQaCxxhDuv94ZP89nUSdgfiSWyl4VCIX9+Gvf7o4nUBQCAPRTd37a+NOkN
BoPF7gxGY+fnqVg06HR53PuR+GnyOBK4wtHEWersJOLbspqNer1xw+L0Hhwn
c/lSo22LYPTUex5MvXKhUAIzr1qr74D9fJFJg3WRzdWT8yoJc2Bdgi1c/guX
K5Vyg5xJZy6yYIaUK7UPpmw9DWt/p12fvr31T+5/V38AFh+o0g==
      "], {{0, 19}, {31, 
      0}}, {0, 255},
      ColorFunction->RGBColor],
     BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> False],
     Selectable->False],
    DefaultBaseStyle->"ImageGraphics",
    ImageSize->Automatic,
    ImageSizeRaw->{31, 19},
    PlotRange->{{0, 31}, {0, 19}}], ",", 
   GraphicsBox[
    TagBox[RasterBox[CompressedData["
1:eJy1VFlvGlcUjtqXPlbqD6j6L/rax76m6g9I1DTqS6ImlapKadomcRbs4ADD
gAeYYQZmGDwsw44BY2N2MKtXvBE2s5odG2Noe7Gj9KXOU/tpZnTOme98V/fo
3u+L2/dvfv/RjRs3Hn4CPjdv/fzVgwe3fvnmU5B8e+/hD3fv3fnu63s/3bl7
58GXtz8Gxc/A+zl4p/Ff/ycmk/H44mI8Hk8mfwJ8gDn9PWVf0S9xcfmMJ9c1
Ds8G/W631xucDUcXU9q10kB3BNi9Xrfd6/cGg/6g1+l1O/3T0/PrOlv148Lb
o1yhVG92Toej8TXqQBsod5uNUi5/tJ8v5MrlQil/9DZ7WCxXWv3B8GL8L435
/XQs6A1G47uH+dpJe3B2DnZ9NSIwg4uL0eh8CqDc7zSP3x6kIlGfJ7oe3dxI
pCL+sN+b2Nop1Brd6cbfk0fvJDKJNZeZMZitnlBsK3NUOK41W93B6dlweHba
77ab9Vq1Uq1W6/VapVTY20x4HA4D63S5An6P12G2G02rwehurlhrNlutE0Aq
VyqVeqPZ7Q3AapthO6tCpBhKaViL3e31xza3DgqlSq1aLuYOdjbi6+FgJBxJ
JFMbG+lYyGc1GGjaZLatrrhcRh2rZkBPcjtzcLif2U7HosFAMBCKJTb2ssVq
s5v0G1Wy15y5l5x5Ph+SSGVq1rAcDMdTyfXAmt2ko0gcJQiFWqMz2xwOu02j
XlSQrNHidjkceo2WpE1Wpz8YCq6tALKKJDBcTlCLrHUltL6bS/hYJfJq5sWT
p6/mOLM87iwsFik0epPZpCUJkVAwy+VyuPNcPgRLUKWKVisJUq7QT8WdQFyj
IHU6o91iZlWkVIJAMAwJhUK+EBHiGsoVTQZMtJzHE/JhmRzDCASWCHiIDCNQ
VDT3emaGM8N5PTv/hvuGy+XxxSgqR2VyGaEzWC/FGUZOqCm1jqJw0YJALJMo
VQDkAoK84EtnCHs6ZNPTEjml1JqtAGpSJYIQ0YKEL5h7/OTRr8+evuJyIUgA
QzxYKMZQDJVhMlxruBoLs4hiFKGkMUzChyGUos1LDqfDplLgz2bhH3mazciS
RUswrN7p8fp8XjOrlyygYkTC588+/uPRb8+fz0NCFMMoJaGiKEatInBcijM6
k3PJbteoaYlMgeKUVIbwICGmWrQ6l93OJVpBPOPA9+eZnfVlh5E2Wq3eUCQa
DTtsVkJOYrhCKhFyODMv52ZhRELRaqPRYLNZbRajmqJk+OIia7dabQwNzhkh
wykUlQogAZimmtHqwHYQ6Qsu8rvUvJ/2eRwGp9sdiSdTyeTayopOA46YSa+l
MUQA8bkwDMsJhY5ll5xOMAtWq8GVjFpvt9iWtAyDylWESkvTFCYRiWEIEYsR
kRjiLwgQWm4OFA83UlH/ejy+s3cAkEqkvN5QIBSNhHxuO6uj5QpcRpKkwWRe
9frD4dCqe9lgcVhcXpA6nS69yW5acruWl8FBZEg5jkplUrDvRb11zZ86bJ+U
jwvZQqlUrTcAjkvH2Ww+ny+VCrmjvc1ULBjweXw+XzQW38nsZ7PZvUwmtbGd
3t7L7B/u7Owm01uX8f7uVjoeCfjWVlc93kA4vpnJFmut8+HpoN/rDwZn4MYP
h4MBsL1+H1gdqHaajVr5uFQoFoE7VU+arU6n0261GicnDXDZ2x1w5esNELfb
0/pJvVouFQuFYqlcqTfbPWCDwJ4ml948ucJ48j4BZj06Bx4zBVh3BPzoEsCY
zi+T0VXwrjz6hzz14A/Y93+DvwHTnayu
      "], {{0, 19}, {31, 0}}, {0, 255},
      ColorFunction->RGBColor],
     BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> False],
     Selectable->False],
    DefaultBaseStyle->"ImageGraphics",
    ImageSize->Automatic,
    ImageSizeRaw->{31, 19},
    PlotRange->{{0, 31}, {0, 19}}], ",", 
   GraphicsBox[
    TagBox[RasterBox[CompressedData["
1:eJx1VVdv21YUDtqXPhboDyj6L/rax76m6A9I0DToSwokBYr+gBZo0kzbsWNb
g+KSRGqQFEltybL2sGQNazjRtIatYW3ZlpL20I6zmnw4vLwkz/3OOXd8/Ob6
r1d//uzKlSt3voDm6rXfv7t9+9ofP3wJDz/euvPLzVs3fvr+1m83bt64/e31
z+HlV3B9DZfUf/XyEq8k/PtpSJ9fnrsv3rE3Iz82dH52eoGz+XyxePmpABLx
YjE/Ozs9OT2Znby1k9OzM2ngeYgPR03Gw+GgPxgOx5MpOJ7zf4QamIF3Op4M
+4Pj7nHv0o57w9FoOptJqf1/ZPeo0TioHtTrraPO8WA0mZ1AIm+magGYz6G6
k9l0PBz02u1m7aBSrJYvrVpptFrdfn88lVKbX2BxWUmtlMumE6lUKpvfL9ca
R+2eFGEm1TybTifj0Wgkldbrdo6ajWqxmEvvJWLJeCyV2EkmYqnkbn7/ebXe
aHe7x4PBEHwBI5iFmRQrnw6HfC6327XtD8YS6VyhWKu32u1Ot9vpHB22GvX6
Qa1WKZeKL/bz+fTubtgf3HL5tlx+j9vvcfm83uhOIpsvFMvlSrVarVWl9qDe
POz0joeTZNTlMBsMBtrAcKLF6dkO7SQyuXxhH7iyKUguFg1HwkEJgYDXs+2w
2gXeJooOi9lhFu0Wq2fbG45E4/H4zk4MnCORCIRLZQrFYv0oFjCbDLhKJZMr
ERTX0joI4fJ4vD6vx+20mkWWY40sYzAaGY7jTZzAGDm93sSwZt5kZhmB4Sxm
q9PhdDrsVotZEAWTiRd4i8PujfiT+1GfwOoQuWxtbX1jY1OpUOAEqdPrjXo9
rVGjCCJTKGUKBRiC4aRaTWk0tFpj1BsEjhUMeobSsVCy0WjU6bQaLanRkASp
xjR6nLFRzihkzjM4KmWuVChRuQyRy1GlEtqN1bWlx8uPlp8ura6urK49k8mU
KhWO42qc1OsMPMvyOtqg1ujUWoogCRSqx1CcxFEM30TIp5hxmXYlwnabSNMU
qaEgNAXf5XJkY2Nj5enS/Yf3/r5/9+GTRysrwL8qkykQBENRAiNoSscZGZNW
S2O4BsUIJYLIoWiVilCTGE6sK7CHMu1fiJiKuT1OjucZk8CbeJ6maBTFZTLZ
BfndB/88WVleX38ml8sxmBdSTZIanNRJ5EZOq6FUmBpBMahappBfkpNA/mBT
+6dSyCX9IZ/d5bS5ttywI0VB1OkMBAH5b66uLi2tLK1vbqhQhCTPV8IAc2vQ
UkaYFiPDU5QeJ7TAhqCoEoG5VOEEgWHEppJYQfSP1fZiPp7cCYRD/rC0iyLe
ba/N5uB53qCnSEKlQhQ4jlGUBpZMEEWLxSqKZpYTOcEmiDaW43UGloZlpWH1
SQLWgyQJQo0SNKozE+Zgo1p4Xkjv7aWzuVw2m0vupqLRnVAwCDvRYRUEE8Ob
WFEU7HY7bGh/IODz+d0en3s74PEG3FvbdpfH4dpyOBxWs8BzsG8ZluFY3mp2
BbdiueNO87BZg2NYr8NpbMAhK5XKL56/KOSzmVQ8Hg1FI8FoNBJPJNKZvVwu
DzmkM9nUHshALpXZ201lkulMEk5bPCadtQAgFIrGE5n9QqU5nYAg9AcgjBKG
/X6/1wO563baR4dNiFmpVkqVSrlWqzWazdbhIRjcG61DeGg0W3XoS9YA12q5
VCoCSuXqQaPV7vZHc0mj3wNI9Mlr2QLRgrASIDBI2Hg8GU8m0II0jcfvdsYX
+naBgSRdknK9evsr+hAXansO+CNc6OliLr193xavhfnS+excdSXR/Q9HSrCw

      "], {{0, 19}, {31, 0}}, {0, 255},
      ColorFunction->RGBColor],
     BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> False],
     Selectable->False],
    DefaultBaseStyle->"ImageGraphics",
    ImageSize->Automatic,
    ImageSizeRaw->{31, 19},
    PlotRange->{{0, 31}, {0, 19}}]}], "}"}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[12]=",ExpressionUUID->"8a347353-d51a-471a-ac35-360753685dc8"]
}, Open  ]],

Cell[TextData[{
 "As the text gets more blurred, ",
 ButtonBox["TextRecognize",
  BaseStyle->"Link"],
 " makes a mistake, then gives up altogether:"
}], "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:17",ExpressionUUID->"0d8cf8ca-6514-4324-9506-a4501cf7fbc6"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"TextRecognize", "[", 
    RowBox[{"Blur", "[", 
     RowBox[{
      RowBox[{"Rasterize", "[", 
       RowBox[{"Style", "[", 
        RowBox[{"\"\<hello\>\"", ",", "15"}], "]"}], "]"}], ",", "r"}], "]"}],
     "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"r", ",", "0", ",", "4"}], "}"}]}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[13]:=",ExpressionUUID->"d0046048-3560-4b38-9fcc-e96956060a11"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"hello\"\>", ",", "\<\"hello\"\>", ",", "\<\"hella\"\>", 
   ",", "\<\"\"\>", ",", "\<\"\"\>"}], "}"}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[13]=",ExpressionUUID->"171ddbff-dbb8-4f77-ad63-9ce3d3cca163"]
}, Open  ]],

Cell[TextData[{
 "Something similar happens if we progressively blur the picture of a \
cheetah. When the picture is still fairly sharp, ",
 ButtonBox["ImageIdentify",
  BaseStyle->"Link"],
 " will correctly identify it as a cheetah. But when it gets too blurred ",
 ButtonBox["ImageIdentify",
  BaseStyle->"Link"],
 " starts thinking it\[CloseCurlyQuote]s more likely to be a lion, and \
eventually the best guess is that it\[CloseCurlyQuote]s a picture of a person."
}], "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"9b3c3fa5-066c-404c-8d29-b8e285ff744f"],

Cell["Progressively blur a picture of a cheetah:", "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"eb5f0825-0a0e-47b5-8998-1e34360954e4"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"Blur", "[", 
    RowBox[{
     GraphicsBox[
      TagBox[RasterBox[CompressedData["
1:eJxMu1eQLGd6pkdJN7rUjYKxHHLIGQyA49u78t57X5Xlvcny3nvvvetqb47p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        "], {{0, 213}, {320, 0}}, {0, 255},
        ColorFunction->RGBColor],
       BoxForm`ImageTag[
       "Byte", ColorSpace -> "RGB", Interleaving -> True, 
        MetaInformation -> {
         "Exif" -> {
           "Make" -> "Canon", "Model" -> "Canon EOS 700D", "ExposureTime" -> 
            Rational[1, 320], "FNumber" -> Rational[28, 5], "ISOSpeedRatings" -> 
            2000, "DateTimeOriginal" -> "2014:08:18 16:34:53", "Flash" -> 16, 
            "FocalLength" -> 250, 
            System`Convert`ExifDump`ReadFIDData[
             InputStream[String, 4], {136, 0, 0, 0, 0}, True], 
            "GPSLatitudeRef" -> "N", "GPSLatitude" -> {51, 54, 
              Rational[147, 100]}, "GPSLongitudeRef" -> "W", 
            "GPSLongitude" -> {8, 17, 
              Rational[667, 20]}}}],
       Selectable->False],
      BaseStyle->"ImageGraphics",
      ImageSize->{83.03125, Automatic},
      ImageSizeRaw->{320, 213},
      PlotRange->{{0, 320}, {0, 213}}], ",", "r"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"r", ",", "0", ",", "22", ",", "2"}], "}"}]}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[14]:=",ExpressionUUID->"e09a9f25-33d7-4eee-9d6b-9ccb6815485b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   GraphicsBox[
    TagBox[RasterBox[CompressedData["
1:eJxMu1eQLGd6pkdJN7rUjYKxHHLIGQyA49u78t57X5Xlvcny3nvvvetqb47p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      "], {{0, 213}, {320, 0}}, {0, 255},
      ColorFunction->RGBColor],
     BoxForm`ImageTag[
     "Byte", ColorSpace -> "RGB", Interleaving -> False, Magnification -> 
      Automatic, MetaInformation -> Association["Exif" -> Association[]]],
     Selectable->False],
    DefaultBaseStyle->"ImageGraphics",
    ImageSize->{83.03125, Automatic},
    ImageSizeRaw->{320, 213},
    PlotRange->{{0, 320}, {0, 213}}], ",", 
   GraphicsBox[
    TagBox[RasterBox[CompressedData["
1:eJxUu1eQI2uanreSbnSpSzGWa2Zn5pjuru4uDxS8995kAkgg4W0mvPfeFLwv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      "], {{0, 213}, {320, 0}}, {0, 255},
      ColorFunction->RGBColor],
     BoxForm`ImageTag[
     "Byte", ColorSpace -> "RGB", Interleaving -> False, Magnification -> 
      Automatic, MetaInformation -> Association["Exif" -> Association[]]],
     Selectable->False],
    DefaultBaseStyle->"ImageGraphics",
    ImageSize->{83.03125, Automatic},
    ImageSizeRaw->{320, 213},
    PlotRange->{{0, 320}, {0, 213}}], ",", 
   GraphicsBox[
    TagBox[RasterBox[CompressedData["
1:eJxcu1eTI2t+p0dpb3Spb7BDM+QxbcsXvPceCWQiE0h4k0gg4b33Be9dobxv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      "], {{0, 213}, {
      320, 0}}, {0, 255},
      ColorFunction->RGBColor],
     BoxForm`ImageTag[
     "Byte", ColorSpace -> "RGB", Interleaving -> False, Magnification -> 
      Automatic, MetaInformation -> Association["Exif" -> Association[]]],
     Selectable->False],
    DefaultBaseStyle->"ImageGraphics",
    ImageSize->{83.03125, Automatic},
    ImageSizeRaw->{320, 213},
    PlotRange->{{0, 320}, {0, 213}}], ",", 
   GraphicsBox[
    TagBox[RasterBox[CompressedData["
1:eJxk22WTXGmWJ/je3Tf7cr/C2kxTVoIoFOTMzNfhkjMzMzMzhHs4BINCISkz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      "], {{0, 213}, {320, 0}}, {0, 255},
      ColorFunction->RGBColor],
     BoxForm`ImageTag[
     "Byte", ColorSpace -> "RGB", Interleaving -> False, Magnification -> 
      Automatic, MetaInformation -> Association["Exif" -> Association[]]],
     Selectable->False],
    DefaultBaseStyle->"ImageGraphics",
    ImageSize->{83.03125, Automatic},
    ImageSizeRaw->{320, 213},
    PlotRange->{{0, 320}, {0, 213}}], ",", 
   GraphicsBox[
    TagBox[RasterBox[CompressedData["
1:eJxc21d3I2ea4PnenZu93K+wV22qVFJ6QxLeew9EIALem4CLQCDgDQmAIOG9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      "], {{0, 213}, {320, 0}}, {0, 255},
      ColorFunction->RGBColor],
     BoxForm`ImageTag[
     "Byte", ColorSpace -> "RGB", Interleaving -> False, Magnification -> 
      Automatic, MetaInformation -> Association["Exif" -> Association[]]],
     Selectable->False],
    DefaultBaseStyle->"ImageGraphics",
    ImageSize->{83.03125, Automatic},
    ImageSizeRaw->{320, 213},
    PlotRange->{{0, 320}, {0, 213}}], ",", 
   GraphicsBox[
    TagBox[RasterBox[CompressedData["
1:eJxs3Fd3G+easOmemZM5nL8wp72Dk7LEgJxzrICccyxUoQoZIAJB5JzBTEpU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      "], {{0, 213}, {320, 0}}, {0, 255},
      
      ColorFunction->RGBColor],
     BoxForm`ImageTag[
     "Byte", ColorSpace -> "RGB", Interleaving -> False, Magnification -> 
      Automatic, MetaInformation -> Association["Exif" -> Association[]]],
     Selectable->False],
    DefaultBaseStyle->"ImageGraphics",
    ImageSize->{83.03125, Automatic},
    ImageSizeRaw->{320, 213},
    PlotRange->{{0, 320}, {0, 213}}], ",", 
   GraphicsBox[
    TagBox[RasterBox[CompressedData["
1:eJx829V2XFm6sOnd3Sd92LfQ57sq2U6jKFgQjGsFM9OCYGZmRoUYLbOdUFV/
7dp30PfTc66QnM7ao3uMNzWkSNuZqdQT3zenQv+3zi0w/e//8R//4f8/wRuB
ltzy+bRB4f8FPhC7/Fazy2hguzCj2ej7Wfd/gAf/H/DX5v/2H/8B31d2nis7
T9H2z2jrEdr6EW1+jza+QxvfoPW/IrW/IJW/IOX/VBT/U57/T1n2L7L0X6SJ
v0pifxWHvxEFvxUS3wqx74T+74W+H4TeH0W+R2L/z1LsqYx4rghuKCNb6jhN
m2IYsmxTYc9aPrBXec46390Qepoib0vsb0mwthRrSfGWjGjJiSZIQTYQAlRH
8SqKVVB/CfEVFJ6s3JWSOeISa0RkDggMOE/rPVA791AbW2Fiygx0iXZHrN4W
qrYEyk2BcgPEV70UaDYEug2hYVNo3hJZt8WOHbGLJvHSJX6GBGdKCKaYZIpI
lpBkCggmn2ByccYBRt/z03d9NI6XxvHQ2G4ax03nuOi7Tsaek7nvZHEdbJ6d
zbdxBNZdoWVXaN4VGjlCA0egY/M1LJ6KeYDS9xU7u7JttmSTKXpJF7zY4T3b
Oniyuffzy93HL9g/PWf9+Iz54zPGD0/p3z+lff+E9t2TnYfAh/Tvn4C/xfzh
GfvH57s/vdh/9JL7eIP/85bw523xE5r0KV3+jKl4zkKfc5QvdlUv9lUvD9Qv
eeoNPviP1WwINZsizaYYtgVT/5FItS1Sg3ZAYg1NrGNI9EyZkS037yK2faWD
q3bxtV6h3i82YhIzIbWQMmtAbgMF5faHHCGYM6xwRRF3HPUmVb60BsvpiIKB
LJuCVUuobgs17KEmLNiwkXUrXjP5ywZPUevMqWxpxJyUGWJiXUSoCfPVIR4s
zNNE+LqY0JAQm9NSW07hLKm8VS3eMATa5nDXFus7k0N3auTJjL3ZsS879udG
/uzQnx34Mn1fuudNdT3JjjvRdsXbrljLGW05oi17pGUPt2yhlgX8IWTbRLYN
RFuHd7RYR411VVgXxboI1lNgPTnelxN9OdmXBwYgRXCAhAZIeICGB8pwH6QK
9VShrioI6qgCbRXZUpFNJdFQ4jUUg1+liL+s8JUU3oLck5e5s1JXWuJIim1x
kTUqNIcFxqDAQPJ1OF+L8TV+gcYnVHtBIrVHrPZI1B6p2iN7CLwvUXlEKo9A
6eGh7n3EzVF4WHIPXebZlno2JZ6XEu8zsfeJ2Pcz4Cby/6TsPFO2n9z7bT74
rX+L1L5Bqn8FfhXlvyiKf5Hn/0L5/as0Cfx+I4l8Kw59JyK/ExHfi7AfxNhP
YuyRBPtZij+Vk8+RNd4YTZtc4921lA5sVZ6jznc1hZ6WyNsW+9oSrCMF4R0Z
0ZaDyJaCbCFkEyEbKPBL1FD83i+y9msHfsMiU0Cgx3haz4HKubv2KwV+dTsi
zbZQvSVQbQpUGwI1/GIWaDeE+k2haUtk2Rbbd8ROmsRDl/oYUowpJZhSkiUJ
sMQBlijAEgaYfJLJIxiA8D5FeM8HFNN3vfRdD33Pw9hzMw7cTK6LxXOx+U62
wMER2jki267IwhGZOSIjW6hnC7QsvprBVdL3kZ1d+TZHuskSbzBEL2iC54Dw
NvfJ1v7Pm3uPNziPXrIfvWD99IL543MGDFh+Rv/hGXwH0n7O+uk5+AW7j17u
P97g/rzJf7IlfLojfkaTPmfIXzCRF2z0JUe1safe2NdscjWbPO2WQLcl1G2J
dNti3bZEty29b0eqvU/yRzSJFny66FKIlyU3cRSWXdS+r3JyNW6+bu0Xl5ge
/Fopv/eEKbyOsMIZRVwx1JNQelNqf1aL5/VEyRiomIM1a6hhCzcBHHuoZQ82
bYGGhQB+KwZPSevKq+wZxJKSGRMSfUyoiwq0ET6Qq40CvAJ9QmRKSSxZmaOA
uMsqf01HNI3BjiXSs8UH0G965MlSfnOU39zQR/n13vvtuhMdN/TbdkZhjkjb
Hm7bQm1rsG0JdExkx0h09HhXi3c1lF8l1kOBXxz0J7/y4EARgoTRcB+FfnvK
e78dVbD9Z79gytTWfpGv/Tof/FoiAlOIbwjw9ARPh/M0fp7Gx1d7+WqPQOUR
QqdusdotoZLe43WLVW6h0s1H3VzEva8Aft1MuZsucz/49TwXe5+KvcDvY5EP
+H0K/bYeo62foN/GD2j9O+QPv39VlP6qKP5Vnv+rLPtXWfobafIbafxbSfQ7
Sfh7SfAHSeBHCfmTlHgsI57IyWeKwAs0tKGKbGviNF2SaciwTfn/gbcj9nUk
/q4U60rxrozoyomOnOwoyLYi0EYCLZRsopAw5Rf72m9MYgF+SehX4wFfcruI
FYwP6Feso937VW/CNJsC7aYA4DVuiczbIhsYvjSJe42XscYrDbAkQZg4yBIG
WQKKMJdgHBCMfZz+RfE+yMs48DK4HibPwxK42UI3W+TiiJwcsZ0jtnHEVo7Y
zBYZWUI9k69l8NT0A+XOPrK9K99iyzZZkpdM0Qu68DmN/2yH93T74Mn2/pOt
vZ83dx9vch5vsEGPNliPXsIevwQfggd3f97Ye7J58GSL+3Qb/C7we8UvGNKX
TPkGG9nkKDf31Fv7mm2udpun2xHod4SGHZGBJjHSpEaazEiXP6QAGejydXq6
7D6GzACi8JrZEC8cvgdqF3hKFOh8IgMG/a7nrwX4pfDaQhCvPQzxOqKIM4a6
E0pPSuXLaLC8Di8ayIopWLOEGlYgNwzh2ENte7BlDTQtRN3or+q9ZY2roLRn
EWtaZkpKDHGRPibQUenjAkNCaEqJLRmpPa9wFZXeigav6wMtU7hjifXtiYEz
NXJnxtBvDvr13fuFhL0U4Qe/HVe844x1nNGOI9Kxhzv2UMcGngQCXTPZNRJd
A9HV4T0t3lPjPSXeQ/Ee8ie/VMG+IgRDQn001AMpQ13YF7+BB79E/X4Ef+3X
Rfm1J0TWmNAc4RuDPD3J1RFcLcbV+LlqL1fl4ak8fJVbAJyq3CIK7NeJlG6B
0sVHXQeIa0/h4shdTJmL8uvelLgpv56n1AgGfh8p28Dvz9Bv8ye0Af0i9e+R
2ndI9Vuk8o2i/A3wK4d+v5HnvpFlvpWlvpUlvpPGvpdGfpCGf5SFHsmCj+XB
J4rgMyT0QhneUEcpvKl/wysAeN1tCm9X4u9JsZ4U78kImJwEdRWBDgJro5Aw
HMFKuEKX0LVf54Nf44NfJeVXZmZKKL9C7bZAs0VF4dVtCgxbcPhaqeFLbc5S
P0OKM2UkSxZgSUNskCTEFodYohAgzOQHmLwAg0sCwvQDnAoDMbh+Bs/P5PuY
Ah9L6GWLvGyxhyNxcyROjsTBkdjYYitbbGYJjUyBnsHX0nlq2oFqZx/d3lVs
ceSbbOnGWjFD+IIheE7nP6dzn9EOntH2n+6A9mDbX9p/tnPwbIcLvAP1Lxni
DaZkkyXbZCu2dtHtPfDHamhcLY2npwsMDKGRITYxJGYm+CTILUyFhYVYWCiV
cp2ZhZqZMBMTgbFACjMLMbMRCwe1UpOXwqvxrIevaD18zRCvDOC1UnhtIYU9
rLBH7vG6Ekp3SuXNaPw5LVbUE2VjoGYONqyhlg3i7ayzBdvAr5loAL86b1kN
YDpyCltGZklJTEmRMQEWZpgxKTKv8ebkriLqraiwmpZsGkJtc7RnTQwcqaEr
M3Lnxt78xAcb+2EjX+4rv6mumyIM/Loov85I1xHu2kNdW7BrDfYsgZ6J7BmJ
np6AfjV4X4X3lXgfwfsK4t/9yu/99hDot4tCvx3gVxmk8FJ+VQ9+ldBv5U9+
HSmxLSG0RAWmMM8Q5OrJAy1+oPHvq337Ks+B0sNVurlKFw8gVboAVaHKJfoS
+JDCy0OAX+euwsmm/NKkrq/93q/QgDA1fH9Gm4/WfpH6D0jt3q+i8i3l9xt5
8Rt5/lt57lt55jtZ+jtZ8ntZ4gd57Ed59JE88lgReYJEnikjL1TRDU18W5eg
6dNMY5ZtBmfe0vrMC/F6AN6u2NeT+PtSrC/FBzIQ0ZeR8FOnCPRASKALCFN+
m8p7v+W1X8XXfnUYT035Vdgov0a6SE8TgmEECGu3+CDdFsArMG0JLWD4Upuz
my6hNmcZwQR4ZUHKb5gtCbPEYcpviCmAhBkUYTqXoMLpPJwB4mNMAcYUYiyR
ny32sSVejtTDkbo5Uhdb6mBL7CyxlSUyMwEogYHO19F4QJl650C5DRTvAXry
rV3ZJtioOZJNtmiDLdxgC16yQPyXLN5L5pf4oA2WYIMl3GSLt9iSbY5sZ1dB
2wNnahWdq2HwtEy+HjxRsEQmtsTMkVo4citHYQMMd5X2XZV9T+3Y0zykte9q
1tl21VSqP9pT2ffVQC5cm8Hk5et8QgPAi/0ZLyXXRsm1RxCIN36P15NR+x7w
kjVTsGEJtaxgXwVTL9K1g0NruEMtri0T0dD7a1pvWeUuoo683JaVWjMSS0ps
TomoxJa0BDwI/pariIBfBvE29KG2Kdq1Jvr21ND5BW9h4i9SFcb+wsifH/py
9yu0J7UewV1XvOuKdZ3RrjPSc4DCPXuoZwv2LYG+mewbyb6B6OuIPvCrpvyi
gDBBEf6T356CCqHwol/wfu2XbKj+p193TubMSOwpkTUuNEf5xhBXHzjQEvsa
bE/t21N595SePaV7H8xW1MVFnTylk690CqiEVOAdPngcdQK8+wrnrtzJkjsZ
Mifl10X5db+g/D6999taD99HaOMnpP7gt/q9ovIdrPydovStvPidvPCdPPed
PPu9PPODPP2jIvmTIvEIiT9G40+U8Weq+At1YkOb3NanaMYM05RjWwp7tvL/
B96BFBtK8aGMoCIHclAAEO4jFGEUjGCy9XA/8JVf25/9opRfKfTLAAsk9Kvb
5sO2+ACvcVtg3hZad0QO2tfDF2zOAK8sxAJ4pWHWvd8wE/oNMfhB4JcOI+/j
kwwBwRASTBHBFBMsCc6WYmypny3zsWVetszDhoSdLEBYYmWKLQyRCYxFukAP
FNP5YFCqaTwVjaukcVEaF6FxFbQD+c6BbOdAunMgge2L/5yEti+l7cvoB3IG
F2FyUSZPxeJr2AIdR6TfFRv3JOY9mWVfbjtA7Aeog6t0ctUurgZsv26e3s0z
eGDGL7lBXAPIxdVT6b7k5uk8fL1XoL+XKzbhf1xbWYOKe7lhZC3XEUMh3uQf
eP1FHV42kFVToGFe4wUzF+CNALxda6hjCbZNYIzidZ2/qvaWle4i4szL7Tmp
LSuxZsRUQK7EDr7mCwqg21dR4TVtoGkIt00xCm966MyO3PmJtzDxFaf+0hSD
TbDiGAQJfz2Ckz13AuaK91yxnjPad0b6jnDfHhrYQgNrcGAJDEzkwEgO9MRA
SwzUxEBF9FHi3/z25EEY5bdL+e1Qfttf+1WTTTXlV/W1X09B7spJgV9bUmSJ
C0wRMHwPdOS+Bt9T+3dV3l2lZxd176KuPdQJ2kcd8P8g6uChDr6SCoXxEAcX
cewrHHtyB0fuYMkclF8n5dcF/Uo8zyTepxLfE4n/Z2XrsbL5GG08+K39iFR/
UEC/3yvK3ytKMHnxe3nhe3n+B0XuB0X2R0XmJyT9CE3/rEw9UaWeqVMvNKkN
XXrLkKGZcgxznm0t7torB44az9Xgu1tCT4fC25f4KbkQ7whGwGTkUBYYwns/
ePUHCaNgBJNteAqmLgdQXxHx5Ci/cYk5LDLc+z0AfuXAr4UJdkjgF5wEQXz9
Nt+wzQd4TdsCy47QviNy0sTU8JWsT75gc4bDl3WPNwL8Mim/DMovHcQLQsJ8
KkGAIQwwRAGmOADvu6QkW0awZThbjrHlfrbcBwnL3CyZkyV1sCQ2JqUY/Csx
RUamyMAU6ZkiHYgl0rJEGpZIzRKpWCIlS4SyRAiVAiZch7BhKEek5IhUu2LN
nli7L9EfSA0HMhNXbuEprHzUDv5HC9QuocYt1HpEeq/I4BOb/GKzX2zBxFZM
YsNBYhi2TgSy+mEWv9B8nwiGiWG4xPLltpliaw8hgK0jgsKiqDOmdMaVroTK
nVR50mpvVuPLA7z6L3iDLUu4baXw2iI98NYa7lpCHXOgZQSTFK9r/FWVt4y6
iwpnXubISe3ALBV4H4gGrr0lpb+iJuq6YNMQaZvjPVtq4MgMXbmxB8gtTf3l
GVaZ4bAprDzBS4AwHMF+MIIB4XTfk+p7kn13ou+O910x0MAZHTgiA0d4aA8N
bcGhJTg0B4ZGcmgghzpioKEIK9eEwQZIUngpv4rgPV7k3/AGW2qAN9Bc+1VT
flVYFfzLo94Hv4602JoUmmN8Y5irD+5riT01xlH5OEoPG3WzERcHcXIQxy7i
2ANIEccBcq/4PvC0jNj3FfY9hZ0jt7NldqbMQZc6KL9O4HeD8vtc4n0m9T2V
+p9Qfh9Bv/WfIF7o90dF5QdY+QdFiapIVfhRkf8JyT9Cc4/R7M+q7BN19pkm
+0Kb3dDntoz5HXOBYSmybOVdR3XfWee6m3xPS+jtiHy9NV4JNpRglFx8DCOo
SEB4RBEeQsJwCndREhBuoXgdxargmY3ym6b8RkSGgECL8VResIHsye1gh2SJ
zdTIM9D4hp01Xj6FV2DbETpoIhdN7KGL4feMGBIS+GUCv5LQevIyKbwMYRjg
pYMov7SH6IIgXRhkiEIMcYgJfgv4jbIgWx6AKUi2Amcr1oq9bDlUzJY52TIH
+JyzpWCxt3JkFtCu3LwrN+0pTPsK477CsK/QHyA6Ki2V5j4FjKvQchU6HqLn
IQY+ahSgJoHSIlRZRWq7WOOQaF0SnVuq98qMPpnJLzdjCiuhsBEKB4k4A4gr
iLiDqAcUQkBe8DYIUoDcATnIFZA7qRx/pHAEFY4Q4gSFUWdECXJFQSpXTOWK
q9xxtTuhdifVnrQGHHjh2M3rwNqMVwxgbaYmL8QL5a7x9u7xBtvGQFNP1LVY
VeUrwy9vd0HmykuduftceZm7oPCWEH9ZhVc1gYY+3DLFOpZkz54euHKjtVzI
tjonanOyTlWbwapT4oEwtiacuSfsTg7ciYErPnDFhs4ozBEZ2cMjW2hkDY7M
wZEpMAJ+9eRQSw6pETxAyXu/60McxBvsIsEHvKH7zVkN8AZbmgCoqSFB0K8a
+PVXlV/+A53geSktsiQEpijPEDrQBfY0OEflZyu9LNTNQlwshZOlcLCBTYV9
l2oPaKXM3qew7Stse3IbnE0yG0tmZ0jtwO+O1AH9Sl0bUvdLqee5lPIrw54C
vJTfnyi/PwG8lN8fFeWHSlTFnxDYI7TwWFn4WVV4oi480xZe6AovDcVNU3HH
UqJbKyx7leOs7bkaXE+L720LfF0hwOvvi/3DNV4JNpbg6yYSAjSWkIDwWBoY
ywKjNWEEECa7cATjDRSrIb4y4skrnBmZLSE1R8SGoFCL89S+A9QNFwyplQXm
ndBEFxhpfOMOzLTDN+/wrTsC+47QSRO56SLvH34lAaYkCDAyAUkgF+INPeAN
0f7AG6KBR4QhOvgF4jBDEmaCeS0Ls+RhtiIE4iBBDhLgIAQHwTkIxlH4OQov
R+HhKNy7Ctcu4toD5xdwilE6uCoHT23nq+0CjU2gtQpBOosIZqYyrRPDzFQW
ic4q1dukervM4JAbnHKjW2HyIGYvavGjVkxpw1V2UuUMqF1BjSek8Ya1vogW
i+rwmI4AxXXkH2lBREwDwmNqPKrGomp/VAXy3af2gmJUcc19CS0sCfOltL60
zpfR+XM6f16PFQ14yUBUjIEvZ96OdS03SuGNdC3hjjlE4SXrWryq8oMTEDWb
3HkpCEwo8NZTkHmLCn8JxStqsqYNNQ3RtjnRtaUHTiC3OPGVp1h1RtTngcYi
2FwGW8tQaxFqgubBxixYnwaqE7IyJkojvEARzg4pwgNPauBODt2JoSs+csVG
zujIERnbw2NbeGwNjS3BMfBrDIz05EhHDjXkUEUOlCRF+P741kOCoC4a7K7x
qkL3eDVUYL2HkU0t0dDgdTX24NdTVIBnJEdWYgOH+jjfGOHqQ/sacleFsZU+
FuJhIi6mwsmUO5hyOwtmYyts8O4CaP1zuxAvePK3smQ2ptTGkNpoUvu/+X0h
8z2X+Z/Jsacq4LfxSFmHflHo9yek8pMCVP6q0iME9hgt/awsPVGVnmpKz7Tl
F/ryS2N501TZtlRpthrTUWe7Gnvu1oG3zfN1+P6e0N8XYQMxNhRDuRCvGIRP
/oiASUjYnwiTPYTsIHgLweqIr4J4CgpnVmZPSi0xsTEk1BF8tZ+Levblzl2p
nS22MoUWhsBM55toUC6Fl2/bEThoQhdN6KGLfHQRxhDjDDHJEAcYYjBSqakq
pIRSY/eeLS+4wwdBvDRhGOCliyMMSZQpjTLlUZYiygYhEQ4IDXPQEAcNclBy
FyV2UXwXxfZQ/77Sv6/yHah8XLWXr/UKdF6w4oqNHonJIzV7ZBa3HGR1KWwg
Jwj5KvQ+l9LuVto9KrtXbfepHX6NA9M4ca2L1LkDek9Q7w0ZfBEjFjXiMRMZ
NwcS5mDSEk5ZImlrNAOLrctaYhlYNGMGRTKmSNoUThtDaWMwBTIEqMiHiDTI
uA7PUGWpckaiYCSKJrJkClTM1FWzJdRc31YBtnYqG5Ul0jGH28YghZeoquD1
RVHhLcg8AG9OAvLkpN68DDyIlVCyqg7WdZGmKd6xpnuO3NBdHPvAelyDbEOt
ZbhzGOmuorBDqmW0s4y0FuHmPFSfBmuTACQ8XhP2ZYfezNCTHnpSI3dy5EqM
XPGxMzZ2RMf2yMQWnkC/obE5ODYGxoYA8DuCI5gcQMKBProu2KOivmEE8XbU
obYm2IZyqXSBJoxsAL9acDTAampfRektI9TpQGoHh/qU0BTnGSIH2uCemuAo
/WzUy0TcTIWLIXcw5HYQU24DQcJySHiteFdhBWyhXLmVDfFamVIrwEv/N78y
90uZ94Xc90KOPVfgz9TNRyrKr7L2h1+k8khRvg8pPwah5Z/Rys/KyhN15amm
+kxXfaGvvjTWNs31bWuDZm8ynC2Wq73r6ez7ulx/j4/1BdhAiA9F+EgMG1NN
xNhEBJuK8IcImPjfCMOVpovgbQRrIL4q4ikpXDm5PS21xMXGsEgX4KsxLurd
B8NO6uCIbSzRmrCFzrfQ+FYa30bj22kCJ03ghn6F0C9dhNNFBF1E0kUBuhAE
1+M/2H4d9BumCSN0UYQuiTKkMaYszlLE2UicjcY5IGVsVxndVUZ2leE9ZWhP
FdxXBfZV5IGa5GoInpYQ6AihARfDu1xCDlZcO4E6cKULV7lxtQfXeDGQ1gfy
a/1+3R9hehgOMvgJo580YgETFjRhITMethARCxm1BmK2YNwWStrDKUc07Yxl
nPGsK5lzp/LudMGdKXqyoJInd587C3NlQEVnuuhMFR3JAsieKNjjBVs8b4vl
bVGqCMwapgqBClRFa6hkDZWtoao1XLOFG7ZI0x5t26Mde6zniPfX2eN9W6xn
jXYtkbYp1NQH6lpgEy+j/qLCl5d5c1JPVkIl9eZk/oICL6GBiiZc18da5mTX
lu27CiMoFwxcyHYV7R3FB8fJ4XFydJxaNzxKDlaJ/mG8u4x1FtHWPNyYhWrT
QGVCER5j+ZEvO/JmRp702J0cuxJjV3zijE0csYk9OrFFJtbwxBKaQL9B4Hes
D4y0gaEmMFQHBipYXxkEPbxaI9RVhzoaWFsbauuA3GBLD5YKuFeAGjpwNMBr
4GgP/XpKiKsgB8d5W0ZsSQqMMZ4+vK8J7KpwNupnIV6mws2QO+ngJAv2YZkN
xJStCVvZVJyHgFy2zMKSWZhSCwP6tX7td0vm2pR5NuS+lwr/CwR/gRDPNc1H
6sYjVf2RsvYIBVUfAbxUjx+CctHqE2X1qbr2TFN7rqu/0DdeGhub5uaWtbVj
b9OdHaa7y/H29nz9A2zAwwZ8fCggRkJiLFqHT+7DJkJsChKsw6dCfCYkZhTh
KUV4AgmTFGGii2AtxF9HvBUF/PxkZdakxBQV6UMCwETpP1B49mQujsTBFtmZ
QhtDYKOD1nj5DprARfn1Qr9CjC7E6UKCLiTpApIG4oMCOzwq7kNf+wV4xTGG
NM6UJVjyBBtJctAkR5ncBakSe6r4niq2p47uqyMH6ghXE+ZpQ3xdSKAPiYxB
iTkks8KLINQZUrnDYMXV+cN6PGwgwiYyZAqEzMGQJRSyhGHWr7KFw7BIxB6J
OmAxZyTujCZcoFjSHUu542lPIutN5XzpvC9T8OeKWL6EF8p4qUKUq0SlRlbq
ZHVdA0SAKnUQXoZhpbq/WPMXar581ZerekHZqidT8aQrnlTFDUqW3YmyK1Fx
xddVXfGaK153xRuueMuVaLsSXVei50r2XcmBKzkEOZMDRwIQBn475kjLGGro
AlUNUVZiBcSfk3uB2YzEk5aAt76sFDxCFNFAWR2p6eMtc7rryA885TFWnwG5
YNoCtqnRSWZymp2d5WZn+flZfnYKyk1PspPjzOgoPVgle8tEZxFrzSMPhMnS
BBD25+GrK72ZiTs1cSUnrsTEGQd+p/bo9A+/oYmJIqwPjnQPhDXBgRrWV4dA
PQ2sqw11daGOLtTWg4ItAyjQhJENAwHv5XRYTQuv1itKdwlxFuDVujUtMicE
hhhXF95XB3aV0C9T4WHI3fQHv3TK7wNhK4tqrZgau1/wWii8VprUtiO1bwO/
MuDXvSn3bih8Gwj2EiVeKMkX2tbjrwg/VlYfoyCK7TogF60+VdaequrPNPXn
2sYLffOlsbVpbm9ZOzv2Lt3ZY7r7bO9g1z/cx4YH+IhHjPnkWEBOhOREBCJg
Qhz0h1w+bAYS4DBImJyJyZmUnMrIiZwcKciBgugheAfxNxFvTeEuyR15mS0t
NcfFhohQG+CrcC7i25d79qQujtjJFjmYQjtDAHLQYdTwFXhoAi9N4KMJ/DQB
RhPgNAFB4xM7IB6xw4Vtc8mH1n6/DN8oQ7LGm2QjKQ6a3lWm91TpPXV6X53a
VycPNAkQVxvn6WJ8fUxoiIqMUYk5KrNGFfYY6oqpPXGtP27AE6ZAwhJKWCMJ
ezThiCeciYQrmXClEu40VSbhuS/phaVAvkwa5M9k/NksBsvhuTyeKxD5Ilko
kcVyoFwJVqqhai1cr4cbjUizGW21ou12rNOBdbtfinao2t1IqxtudcLNTqjR
CdXbwVo7UG0FKi2y3CRLTaLYJAoNPN/Acw0MlG34s01/pkXV9me6/kzPn+nD
Vx3DFz49DLvMyJ0GhPv2RNcaa5sjDUOopg2UVUQBxXIKX0bmTUu9KQnIl5Zi
WTmRR4MldaSqTzQtmY6jOPBWJwTYh7uH8eFxanKam58Xlhelw8vK6rJ6RLW6
qByel5dnpcVpcXaSnxxlR6t0/zDZXcbbi2hjHq7NgpUpWZrihak/N/FmJ540
IDx1JqeOxNQen9qiU2tkaolMLGHKb2gCR/CaMJU2NKQaaMOgvg7W04e7hnDH
EOoYwXE+1DIFW6ZAE2QkG0aiblj79VXVnvW3xgpyW1ZiSYtMCb4+ytWG9tQB
DvCLPPiVffH7FeH7RZpSvN6Z/8BroUsttC9+ZcCva0vu3lR4NxH/BopvKMmX
quALXetnbfOxpvFYXX+sqv2sBFWB2TVbGJCrrD8DeNWN59rmC33rpbG9ae5u
WXs79j7NOWC4hyzviOMf7+HjfWLCJSf8wFRAJQSRVASYs3DaPsid8rDZOj42
5+NzATEXEnMxOZd8TZgYIHgPwdqIr4F4qgpnETzFwVfvGGMiXVigDvCVgLB/
X+7dlbo5Yhdb5GQJnUyhkyFwMQRuusBDF3jpAh/9i18+tsPHd3j4DhffBh2s
I6jI9fyl8cGJOMwQRZniOEuaYMtTHCS9i2b2VNl9dXZfkz3QZLnaDIinS/N0
Kb4+JTQkRaakxJyUWRMKexJ1JdWelNYPT5TmYMYayThiYMXNetJZbzbry2X9
+SxWhOGlHF7OEaBKjoTlqQoBULUYrBZD1RJVOQyqVSK1aqReizbqsWYj1mrG
O61Et53sdVKDbmrYS4/6mfEANhlmJ6Ovy4xh6dEoPRylQINhsj9M9AaJ7iDe
7sda/WizF230IvVupNYNV7uhSjdU7gZBpV6w1A+WBoHSMFAaBUpjsjgBEUWI
BStM/LmxNwsIDxxgDQbzNFo3hCraQFFF5BAsI/enZL6kFORPSrG0nMgiwYI6
WtYn6+Zs21nq+2pjsj2P9FfJyUl2fl4EZo+v66c3zfOb1vlt++KmfX7TPrtu
nV41jy/rR+fVw7Py/LQ4Pc6PjrKDVaq7TNwTngcqM6I0wwozX27qyUzd6a/8
xqbWKPRrDk9MYcpvaGyg0sNG+vC6oT4yNEQGhkjfCOuZwl0zdR0HC7bMgaaZ
bJqAX7xuwGp6f1Xrq0C/riJCvTRFYk4LjQ9+VV/8eqn56/qaMENmp87C94Rh
EK/1D7wSkPUrv85tuWtL4dlCfJsotqkkNlSBDXXopaH9RN96om0+0TSeqOsw
VQ2YpdjW7seuqvFc3Xyubb3QtV8aOhum3palv20b0JxDunvE9I7Z/skuPt0n
ZgfkjBeY8YMzQXAmBAWoyJmAmIL4+FrulOef3YfNedDvQoAvhMRCRC4k5FxK
zmTkVE5OFOQIAYSxLuJvId464q4oHAW5NSs1JyWGmEgLCfNQgqvA9uW+PamX
I/GwxW6WyM0UeZhCD0PoBVF+/SAa30/jYTsgLrZ9QLW/Dt/eJ3Yov+AgTOeH
GcIIUxwDeDny1C6S2UOz+6rcgTrP1eZ5ugJPl+fr8wJ9TmDICo1ZkSkjMWdk
1ozCnkGdGZUno/VlDXjOHMyB46QjXnCnir5sCWy5RLFElkuBailYK4Ua5VCz
HAa1ypE2qBIFdUDVGKwWh9UTXVADlOw2QaleK9VvpQft9LCTGXWz415u0s9P
B/n5sLAYFZfj0nJSOpyWV6AZ1fy+Q1hpCSsu5sX5rDCb5aez/GSaG0+yo0lm
MM70x+neKNUdpTqjZHuUaI0SzVG8OY43QJNYYxqrz6L1eQRUW4Sq82BlTpYB
mYm/MPJmB6501w5GaqxmCJe1wYKKzKJ4WoEl5f6EDEvI8KSCTKPBnDpa1Cer
5mzTWer56qNAZx4drtKz08LhReXkunF+27m6612/Hty+Ht6+Ht3eDW/uhtev
+lc3vYvrztlV6/iisTqvLU7L05Pi+Dg3WKW7h4n2MtpYhGuLQGWOl+b+/Myb
m7kzM2dqak9ObfGpNTa1RCfmP/u9L0wVAY1ApihoaI4OQJZI30J9OwzescOf
g6Bezk3CV4Sa8LoR+PVVtd6K2l1WOouIPS+zPvjVRcF5ivJLsBGMqfAx5J57
wmCLljvo8CLL8dV1FrzRoiay9eHMa4V4Jfd4d2SOHejXva3wbiH+LSW+qSI3
1cENTXjD2HlmaD/Tt57qmk+1jaeaxlN1HaaqU3KpsQvwaii8+u6GsbdpBniH
O44R3TVheKcs/4yDz/eI+X5gwQ0ueKEFP7QQhBbC0FwYnAO/AhA541N+eZRf
rn9GNedCv4sHv0sRuRSTC2lgIQvM5YGpgpwgxAjF+yjWRX0t1FNDXGWFHRDO
SE1fCAf5SpKL4AdAscy/K/VxJD622McCiXxMkY8h9DP+8Ovf4fp3DvzboP11
0O8O5ZfGDdD5IaYwwhLFOJLErjy1h2QOlDmuOs/TFPm6okBfEhpKQmNJZCqK
TUWJuSC1FGTWvMKeR515lTuv8eX1WMFEFq3hoiNWcqfKvmwFL1TJci1Yq4Ub
tWirHmvXY916vFdP9OuJQT05bIBSI1ATlB63QJlxG5SddEA5WBeUn/Ty015h
1gcV54PiYlhajsqrceVoUjmeVk9mtdN5/Qy0aJwvQc3zQ6rVQ0fNs6MG6HRV
P1nVj1e1o8Pq6rB6uKwsluX5ojSbl6bz4mReGM0Kw1l+OMsN5rn+PNtfZHvL
DKh7CLCkOqtk+zDeOow2l+H6Igi/FTv2FwaebMeZalrjVVO0pAvlNYGMkkyh
RBIhEgoigZApZSijjub1ybI5W3eWOr7GMNCdxUaHmflp6eiifnbTvrrr374Z
vX47ffNu9vbd/O27xdu38zdvZq9fT1/djW9uh5c3/fPr7slla3VRX55VZ6el
8Ul+cJTurhLtw2hjGaotyfICK869+Zk7O3OmoV9rYmKJTczRiSlCFX4wGx5D
y+sHge7o2BKDWWMja2xoA0UH9mjfHulRPwfRtgVbtkDTSjYtRMMM/PprBl9V
56lo3KW1XznlVwT9xoDffXVwV0myUYy1HsHUFs2Qu6icDMVDXyCvr7bghfP6
2Avx0taXV8Cv3LWj8Gwjvm0U21YSW+rApia0qY1smLsvTJ0XxvZzQ+u5HgzZ
5jNt45mmAdg+yKXwaim8ht6mabBlGW7bxzTnhOGZMn1zNrbYJRb7geVBcMkL
LfnhpQAG/N4TfvA7e/A7+x9+lwJ8Sfk9lJBLaWApCywUgTkSmKHkREmMlHhf
iXWVvpbSU0OdZQQSzspMKakhLtZFRZqQQLVWTBwo8H05tifDdqUYR4KxxRhL
hDHXhL/2e4/Xv7OP7ezjtAOCziUZvCBLEGaLoruSxL48dYBkeMo8X10Qaksi
fVlsrEhMVam5KrVUZdaK3FaW28uIo4Q6Syp3SeMt6bGSkShbgmV7tOJKVL2Z
Gp6vB8qNUK0ZbTbjbbDrwumZGrbSI8gzM2lnp+3srJObd3ILUDcPWvYKsH7x
cFCiKh8O11VWoFHlaFQ9GlePx7WTSe10Wj+bNc7njYt583LRulq2rw/b16vO
zVEXdHvcg51QnfZuHro+7V2ddi9POxcnnfOT9tlx6/S4eXLUPDpqrFb1w1V9
uaotVtX5qjpbVUDTo/L0uDQ5BvOuMDrJD0+yg+NM/yjZXcXby0hzFqxNiPLA
V+i4s017qmqJFw2RnA5oDaZUgaQykFAFk+pwWhvNGpJFS7bqLLV89X6gO4mN
l9nFSRmM1Iub7s0dkDt793754cPq48ejTx+PQR8/HH14v3r/9vDtm8Xd69nt
q8nV7fDiun961Tm6aC7Pq7MzivBxunuUaK0i9cNgdYmXFr7C/Gu/5hgQOjZF
qDn7BW8EBF2D0QyAW+MTG5U9PnbARk74CpC+M9qDPwoR6jiCbXugZSObVuAX
q5uAXy/l11VS/clvUqCPcbWRfTW1QqNwBD8QphQr3F/lonJC0UDxeruGL9i4
lwuTOWgyJ03u3lF4d1D/jhLfVpHb6uCWNryli23aepuW7oa589LUAbs0ON6C
E/ELLYS8lvtc2wZ4X+i6Lw29DWN/0zzcso52HBO6a8bwzln+BQdf7pGH+8FD
buiQFz4URGDCyFIYXq4JCyjC0C8x4+EzLrZuTrXgYUvolzgUEodiciUJrGSB
Q3nwEAku0eBCGZypAhMVOVITAzXWVftaKk9d6aqgjiJiy8nNaZkxKYU/Dw4U
h4XqEF8JNmoAmTyQE3syYleKcyQ4W4SxhBgkzPPTuH7agW9nHwTw+mn7GP0A
Z3BJJi/AFoQ4ouieJH4gT/GQjECVF2mKEn1ZaqzKTDW5pa6wNRB7A3XUUWdd
6ayp3DW1B5yAqnqsaiSq5kDVFq45YzVPqo5lG2SxGaq2oo12vN1J9brpQTc7
osborJufA6qU08NecdUrHvVLoONBGXQyrJyMKqej6um4Bjqb1L+qcTZtnMOa
F7Pm5bx1NW9dL9o3i/btsnN72H216t0d9V4f918fD96cDN+cDt+cjWDnY9gF
1eX4NWx0dzF6dTG8vRjenA+uz/tXZ/3Ls975affstHt62jk5bR/DWkenrdVZ
c3XWODyvL8Hiel6Zn5Wmp4XJSW54lO4fJsAC3JwEa0O83PUVmq5M1ZYqmuM5
YzSjj6S04aQ2ktRFU/p4xpTKW7NlZ6nuq3cC3WFsNM8ujson583L697t3eTt
28WHD0efP538+vnst88X6379dP7Lx7NP708+vDt6+/bw9evF7d306nZ8cTM4
ve6sLpuLi9r0vDQ6zfVPUp3jWHMVqh2S5aW/OPfkZs7M1JaaWIDf+NgYheux
gYralqFf871cuGPbE/Cw7ITBi2tXYuyOj9yxgTvad0V6rnDHGWw7Ai070bTi
DQvw6/vKr6OIQr85qTkjhn7jPG30AK7QcARDwmAKo34m4qPyMu7z3Le2TM1l
6oAMXzBJKXY84HXRFB4a4qOh2I6K2FEHtjWhbW10Sx/fcgy27f1tKzjSdjdN
HbBObxjAqG2/1AGza7kdiFffe2nsb5gGm5bRtm2y45zS3XOmd8HGlrvE4V5g
dRBa8cIrfmQliKyE0O+hKLIUracw9Dvnk/d+HwjDyfswfCFeEYVXGjiSB48U
oRUaWilDh6rQUhOaa4JTbWCsJQZavKv1tzXehtpdVTlLSrC42rKIJS03JWWG
uFQfFWsjALJABSAHeUjgQE7uA8USgiPCAWEmH2Pw/HSun36wDmMc4EwuweIF
OILQnihyIInz5CkBmhGr8lJtSW6oKEw11NJQ2poqR0vtamvcbY2npfW2dL6m
3t804A0T0bAEGrZwwxltuBNNX6ZF5FvBcjtS68Rb3WS3lxn0c2N4SoVL75Ka
qqtB+WitdVA+HVZAZ6PqOWhcu5jULyaNy2njcta8mrVg0Gl73TXVDWjRuV10
Xi27oLvD3uvD3ptV/+3R4O3x4N3x8N3J6P3p+P3Z5MP59MPF9MPlDHY1h13D
3lO9u569vZ69uZq+vpreXU5eXY5vL8c3F6Pri9HVxfASNri47J/DemdXndPL
9vFl8+iyfnheXZyVZif58SozWCS602hrGKx18XLTW6i6siV7Km9JZs3xtAmU
SJuTGUs6Z88V3aWqv94Kdvrx0SS7OCwfnzYvL/uvXk3evll+fH8MtP7+y+Xf
f73+x683oL//cvO3z9e/f7r89ePFp/dnH96dvH27ev1meXs3u3o1Pr8dnFx3
V1fNxWV1cl4cnmV7J4n2caSxClSXWGnhyX/xOzbFR8CvITo0RNbBD01wYabw
QrkzZ3LmSs7cKdDUkwRNPImRJz70RAdu4DfUdQG/JPRrA379D37dwG+Z8ltQ
WHMy6DclNFArtDYCCYMten0QVuIsJc5EMSo/iAHzwdaWFZ6vrrm+CjyicNMR
Lx3105Q4TUXS1MEdbXhbF9vWJ7bcI7pzSLMPdmz9bUtvywwUdzcNQHHnpX4d
hdfQf2kcbJiHm9bxth34ndE9c6ZvycYOd4nVfmDFDR3xwkeCyJEwuhLBgN8v
hOf/g/Cc97A5r4cvwCsOHAG8suCxInSMho+V4WN15EgTWenCh/rwQh+aGYIT
Q2BoIPp6vAPs6Hx1LfXspwZnT3tWaU0jlpTClICQdRCyUB0WKENQsYzckxC7
IpwtxFh8jMnzM7kgjMnFWTyCzSd3BcF9UYQriQnkSRGakarzcl0JNVZVlrrG
3tI623p3x+DtGnw9o79nwrsmomsmO5YAvNawh9vOWNudaPvSbSzXIYudcKUb
a/QS7X66P8iNhoXJsDQflpej++33eFg9GVZPh9WzITR7MapdjGuX4/rVpAG6
njZvZi0g9HZOCV10Ycuv3i66d8Dssvd62XsDOuy9Pey/XfXfrQbvj4bvj4cf
TkYfT8cfzyafzqefLmafL+afLxefr5afrw9/uTn85Xb1+aFPt4cfYcsPN8v3
N4t3N4u314s31/PX1/O76xno1fX09mYCurkZX98Mr24GF9e9cwi5eXxeOzwt
L44L02VmOEv0RtFWL1hv4ZW6r1h254vObN6RydqpHLm8q1D0lit4vRHqdOPD
UXY+Lx8fNS/O++APf/t6+fHdCUAKtP7j19t//vbqn7/dwX599Y9fbv/++eb3
T1e/fLj89P78PSR8dPdmefN6dvlqfHY7OL7pHF41Zpfl8Xl+cJbqnMSaR8Ha
4b3f7MSWGpsTI2N8aIgO9KDIgLphHgK/ZnDaBQtzAu7YztTMlZq703NPeu5N
z3ypqS858SXGvvjIGxt4In035de59os9+PVU9e6K1lVWO8AoKSDWvMySlZjA
Cp0S6O8J70PCoV11kKMKsFUkS0WAmDCcqcQZMAxCRkA+xsMxmU5BpiayGwYe
RHx0FKMrCbo6QNOEaNrIji6+bUhueSds95jpGjEcQ7ptQLP2t829LVNv0whO
uzCwNsOM/Zcm4HdE+Z1SfhfQL364S64OgkfALx/iPRLBVmLYoRj6XYqoESwM
zAXknE9Q4fDOmbq2ovASKzF5JLnHe4KGT1SRE3X0RBs90ceODbEjY3Rlii7N
kbk5PDXDl8ANzIGeiWib8KbRXzf4KnpPSecuaJw5NQUZNScVxrhMH5NoIiJV
WIAGefLAgZTcExO7QpwjwNl8GIdP7ArIPWHwQBzmSWNCeVKCZuSaPKIvqUxV
rbWhd7SN7q7Z27NgAys+sJFDe2BoDw0c4YEzAk5GfXcc/tiaL93Dsj2y0AuW
e5FaP94cpLqD7GCYH4+Ks3F5Oa6uxjV4Yh3XT8f1s3H9HJiluhzVr4DcceN6
0rgBcqet21nr1bx9t+gApEDo68P+m69b3vf2oXeHsPeg1eDDavjxaPTxePTp
ZPL5dPr5bPbL+fyXi8WvV4e/Xq9+uzn67RZ0/NurdSe/3h2Dfnl1/PnVEejT
q6OPr1YfbmHvbw/fgV4t375avnm1ePNq/vrV7O7V5PZ2dHMzuLrunl+2Ts/q
RyeV5aownWdH42RvEG13Qo0GWa1i5bKvVPQWC95iHrz1l0t4tRJo1iPddmI4
yM2m5aPD5vlp/+Zy8uZ2+fHNya/vL/726fp//fLqv369+9dvr//12xvQf/36
+p+/3P3j86u/fbr57ePV5w+XH9+fv3t38vrt0as3y+vXs4u70eltb3XTWlxV
p5fF4XmmdxpvHYEVGi8vvAXo15oamRJDQxzg7etAkb4+0geWjdGhOTayxMe2
5MSRmrrA2IVy577M3Jee+9Mzf2rqB4TjI19s4F37DXSgX5zy66ubvDXjn/yC
A11BYQEj+A/CPF3sQBvd10b2NOFdTYijDrLVQRYswASpAgwVyVARDCXBQHEG
ikHFCkoxvK+mgudlL6QNjAPsKuA3SNeEabrojj6+Y0ht+2d7vinHM2G7xkzH
iGEf0qyDHUt/y9TfNPXBgRcE8RoHL03DDQv0u/W1X+xwj/LLC62HL/Qrjq0k
oOihhCIsDi++JiyAhBcCGHVndX/s/YL3VBU51UTPdLEzQ/zMmDgzJ04tiRNr
4tiWWNnjS3t87ohNHdGRPTKwh3u2YMcWaFnJugWvmvxlo7eod+e1zqzallZa
kghQrItK1BERGuIrAjwZeSAh9kXEnhBE7gsDB6IgTxIWyGIiRUKqTCs0eaWh
pDFX9faGydW2ent2bOAkR67g2B0eeyITb2zijY/hM3Nq5E8PseyQyA3IwiBY
HkSqg1hjmGwP071RbjgqTMbl+aRyOKkdTeon4Og6aZxPGmA3vhg3wLSFA3dc
v4Y1bgDeSfN22nw1bd3N2q/nndeLLpitcLAeDkDvvg6Yva8Hev/Qh2X/4+Hg
42r46Wj0+Xj8+WTyy+ns1/P5rxfL3y4Pf7ta/X599Pvtyd9Ar07/drfu7Pe7
U9BvVL/enfxC9Rl2/Inq493Rh7sV6P3d8t0dgDx7fTt5dTO8vupdnrfPThvH
R5XlojibZsfD1KAX77YirUaoUQ3UK2StDArUy8FGNdyux3rt1KiXn40rq3nz
7Kh3fT55fb38AJ5A3p7//uHqH59u/+uXu3/9+ua/YW/B23/98uafn+/+8Qn4
vf3t4/UvH64+vr94/+7szbvju7ermzeLy9eTs1eDo9vO8ro+uyqNzrO9U7BC
h+uHBPQ7dWbH1tTQlBgYYgBvTxuB6SI9YNkYG5jiQ7BaA79O4Dc982Tm3szc
T4WlZxjl1w/8Rofe8INfAvq1+r/2W9W5KhonWKEpwta83AJOwVmxKS0EhA1J
nj5+oIvt66K72ihHG2FrIyxtmKUJM2EhhhoUZADISvJeMXKvmAnzwuCR2Q+3
brB+A+/Qb4Sui9H0CeiXWICj6L5vtueZclwTlnPMsI/o1uGOZbBlHmyCmQuC
eAcvzf/m94/9+SCwWvuFeKNHEsqvNHYoBYQjS0l4KQ4tRMGFMLAQkgsB+f+P
90wTO9fFzw2JC1PywpK6sKUvHOlzZ/rMnTn1pI896ZU3vfSm5t7k1JscexND
T7zvjnZdkbYz1LAHala8YvYXjZ683pnVAMXmBKKPyTQRiTIsQoICeYAvDfAk
ML4kJJCGRfKoBEnIVWlUm1MbijpL1eRoWN0dh7/vJobe4NgfmWKxGZ6YE6k5
mZmT2VkgNwvkp8HiJFSahCvjaG0ca4wT7XG6O84OxvnxpDSbVBbT6mpaP542
TqdNeOM0bV5Om1eTJpi2cOACuSPYzRjUuJ00Xk2adw9+3yy6bwFPOFuh2fcP
vVtSfhe9++Zd0Pt1i+6HRe8jpfjTavj5aPzLyfRXSHjx28Xy90vo9283J3+/
Pf37qzPYHegc9Lf7gGXYb1S/gl6fgn6BnXx+ffzp9dHHu8MPQPHt/M3N5O5q
eHPRuzptnx81jpfVw1lxPs5N+plhN9lvxbuNWKce7dRA4J1Er5EatLPjXnE+
BJ+T5tlh7+pkfHcBNvajT+Af9/by7x9u/vnp1b8+v/7vX96sA3j/6/Prf366
+8fHV3/7ePPbh+tf3q/9nr99d3L39ujmzfLy9ezsbnT8qnt405xdVcYXuf5p
8t7vHPh1ZEfW1MCY6OtjXW20q410qLrAMhBtig8siRFYsJ3pqRv6nfnWeL/4
Tdz79QC/wa6L7DiAX+zerxn6rRkov1pnReMoq+wl1AYIF+BFliUrNmeEpjTf
mOIakgeGxJ4+vquPc3Qxti7G0sWY2iiIoYkwNGGoWBVkKCnFKMFEcCaCQbNU
LBCKwbOzEmzdYHCHGNq13+SOIb0dOASUwFH0wDff88w4rinLAQnTrKMdy/AL
YTB8gd+XltGGdbxpn2w7pzT3nOFdsP3w/oryuxKEV6II8LvGuwJ4YZRfSWgp
DkLCIoqwkPyC91BCru+sjpHwifIe74UxeWlOXdrSV47slSt35clf+fKX/sIF
XjgnCmdE4YQsHJGFQzK/IHMzMjchMiM8PcCSXV+87Yk0XMGanShb/UWTJ6d3
pDWWpNIYV2ijMnVYgobEipBIDhPLIxJFVIYmFOqUUpvVGIsGS8XsaNg9bRfW
9wZGWGRCxmfB1CKUWYZzy0jhMFpaRsvLWGURqy3i9Xm8MUu0ZqnONN2bZgfT
/GhanE7L8yn4eq4dzRons+bZrHUxa13OWlfT1vWkCQN413JHNar6LWjceDVu
3k1ar6ft17POm3n3LeC57L9fPuAF74APF/0vbN/NOu9m7XdTUIuq/X4G6nyY
Q8WfDinCx5Dwb2eA8OHvl0d/uz7++wPhf7w6/8cd7O9/bs35d9DrM9BvsDVk
MJTBjr0C5+X3N7O3V5O7i+HtWe/quH1+2DiZV1eT8nJYmPVzk2523M4MW+lh
E7zNjFq5cacw65UXw/rRpHW26F2txq9O528vVx9vwLg///3N1T/e3fzzw6t/
fbz716fX//3p9b8+3f3Xx7t/fnz1jw+3gPbv769/fX/1+d3/S9ddd7eRponf
f1X77G92Z7bTMYcTx8wgZmZmKFJJJZWYWZaZKXGHk4aB9/Ncd8l2p3tnz/ke
HdlxMn/0fHxdd5Usd44PkN+9gwbyu1/u7hVaO5naNlPeihW6WKYdQH6rVqKk
j+RVwazUxwrdSZ4zsW6Pr9noVeug+LotsWFneI6k0MmK3WmpJyv35ji/eQ0X
+NW4wG9GbU+rrCmlOSk3JWTgVxcTg181KVQRAiXBR37xDfkt4RUpmsKLktC8
GAgHZoT+KYFvUuB9yfc857mf8tyPN12PNl0TG87xDefYunN03TG6Zket2kZX
LKPL5tElpHgMCC8CYd04uvGkRXgXdeNLcHCG47NpDL5y1Tayht4fcmjD89BU
nTJWJvXll9rSc3XxjnB2VJwBwg+F7AMYu4D3e7/i7I/S3JAcjeDB/aOnhvIL
U/mVGfxWpq0gtzKLKqOs5RnOL0e49NqIXqQx6A94zYC3sQJrM4dX6O6KvT2Z
f0sZ2FKH+tpwXx/ZMka3zFjPgnVteMeGt+x4047X7XjVjpUBlDWcs4QyJthm
vQmdi1bbSIUJk+rDQlWAJ/Oui9wrfMfShn1h1Tq3bJ1dQs0t2eeXnYur7uV1
3xovyBNFhDJCqoopdYzWxBpsWbOrYPWWHIGyM1xxRatuvOohqx6q6qUr3njZ
myj5mJI/VQywhWCmEMoVIoVCtFTAKwWiVqAaBapVALl0N0/38rFeLgZLMoza
rYFcFsK40HMgvJ3+nfBePr5f4CYsIpz8Ti5zkE/s5+L7OXo/G9vLUHsZci8N
EfC4nyEPshQHeaAYBnH6tJo9q+fPgXCLI9ytXfca11uNN/0mChTfdf1dV3+e
y7Bg18+3a2f9Krrq1SsedvP77cxOk+3XwCPdLlKNPFGDkz4bKSXDBRi1iVAe
Bc+jpSReYalaNt7MJzuldL+W322WDju1k17zfLt9tdt9s9e7Oej/dHjbzWH/
7eHWm4Pe9UHvcr97vt853e8c77eP9lsH+83d/fo2mr/lzm6hifwmwW8e/LbA
rxv84kV9JKcMpKXelMDFbDoAb2zVGluxUlwxsAyiNx2MwJkUuVipOyP3ZBXe
nMqbQ4Q9ubvDb0ZlTyutKYWZkRsTUj0tAb+agV+S80vwFPeEMTSF0SIdWZSG
5yWhWXFwWhR4LfS/EvpeCLzP+N4nfM8jnmeC5xnfdI9tuEc3XKPrrpE1J2Ac
QYSto8sWIDyGCBvGF/WI7aJuYtD/5ddSnzHVpgzVSV3lpab0TFV8oig8kuXG
JNkRcWZImP4R/Ao4vAL2bwPC4vsRnB9ToddvPNGXnhvLL03l1xY48FZmrL/j
RVnKM+DXhJoyAttbvAO/s8bqvKnGXbNqrtnR2iy4xdtXBbe14R19dMeE71qJ
XTu164ztuOltT7zvjW/5Ej1/ouNPtPzxhi9e88YqHrLownP2SNoaTJq8cb2T
UlsxhSEs0QSECu+mxL0ucK7wHMvr9qW1Qc7ldffqpneDH+CLwyIZLlNRKn1C
Z06Z7Fmrp+Dwl9zhiher+cl6IFYPxhtBph5K1UNsLZSuhjPVcLYSyZcjBfQS
JqxcxKtFsg7/Ty7GWsVY++6Oz1ae3uLwwpBF23Kak5uCondh/RTeZ3EgvJOh
dgEm8MwnkNbvG8jN0nuZ2G6a3E0TOyy+k8J2ktG7sN0UvscS+xnqIAuKYaOG
QcwRruXPGxzhdvWqU7vq1geKuZqo/p+7GrQNNS77jYt+/aJfO9+qnvbKJ93S
Uadw0MrtNdI7tVS/wvRK8U4hBseERoaopfEqi1dSg4gqyE3TjWyilU91i+mt
cm6nVtxvVo7atdNu43yrdbndvt7pvNntvoX2UG/2Ote7navd9sVu63y3dbrb
Ot5tHu02D/Yae3v1nb1af6/S2y21d/ON7Uy1z5R6sXwHSzcDTN0VK1vwgi6c
VfpZiQeExjfssVUbtWIhly3EMnokQTGI3rDH+Q5G6EqK3UA4LfdklJ6sCnJn
1a6sysnhtbEKCwxfRmbg/Gq/83s7gtEUvlWswNbk2Ko8uizjCEvDM5LQlDg4
KQq8EAaeCf1PBP5HfN8E3zfG845uekc3PCMb7pF1NyK86hhZsQ8Ij3GExznC
EygdelwyTCwb/+x33fOjtTlnbsyY6gPCL9SlZ8riY3l+XJoblWSH4LQLYAd4
+cjv34Ts/4gQ4R+l2SF5bkSZH1cXHsP6rS+9NJYmTeUp0Gq5lTsHWZDfWXN5
Bvwab/3e450xVuaM1QVzbcmCrlltOODM2xF50ORFeCM7BmzPQuzbqX0XfeBJ
HPiTB8HUfji9H8nsYdldLLuNZ/t4tge7UzTdDKdqQabspwseIuuMpKyBhMlN
6ey4yhSWaQNipU8g9WyKXKB4jQe51njuDb6XJ/QLJCGxPCpXEyo9rTMnTY60
zZN3BUveaCVA1EJ0I5JoRlNNLN3Cs00818QLDbzYIEp1olwjKlWyWiFrFapR
hpNdrFWiOyW6W4z3inHuNhDdz8f6OQpOuP0MrMoDvNGtZKQHMehxKwkfRvug
+M+E40gxsL2buXswndPUDkvspPBt+CtMpJ8Ib8VDW3QQ6sdD8OE2EwHInGJY
qmEQJ49L7EklcwqE68WLZumiVeEUo1nMVUf1QDTq6n91yXXRq130qufdylm3
fNIpHbcKh83cQSO7V0vvVFL9crJXTHTz8XaObsGSnIk107FGmm5CmUQry7Rz
qW4hvVXKblcKe7XSQaNy3KydtutnncZFt3nZa15t3X3H6N9+uzjv10/79ZN+
7ahfO9yu7W/X9nZqOzvV/k6lt1Pu7BRb27l6P13ZYopdKtuOsg1/ouqkSmYs
rwulFT6AmeA7Yus2AEssWfBFM7ZoxpfMOEBetVLrthiMZoGTEbmSEhcrA8Lu
tMKdUboySmdG6eDwWlNyc1JmZKSGuERHi2/9UuB3EBC+HcRKYlMJhPE1Bbaq
wJbk0QVZZE4anpaEJyWhl+LgM1HwiTDwSBCYEATG+P5Rnn9k0zey4R1e9wz/
Ttg2umwdWzYD4XGO8MQtYc7v0p3fFRt88fCa6yH4tbXmLc1ZU2PaUH+tq77S
VJ6rSjCCJ2R5GMHD4sxDYfrBnd+/QveEJZkfZdlhRW5MlX+kKTzVFV7oi69g
PQanZo6wBeGdMyO8s6byjLE8DXFyp/Qo5NdQnTOi5XnZ2lizN2H4wuYs9cHa
3NeEObzkviN26Ekc+VPHofRxNHtM5I+p4jFdOoqXDxOVA6a6z1R3E5V+vNyL
FdtkroHBZEwWA7GsB085QgmLlzI4MI05rNAHpGqfSO4RSN18sZsvgrwCsU8k
DUoUEbkaV+spnTlhcqRsnqwrWPBh5SBViyQaWKpJZFpUrg3/fqzcpittutqi
6026ATXoZp1u1eh2Nd6pxLuVeK+c2Col0AuiivHtAr2dp7dzse0stZ2BDRmG
LIxahHeLCfegBBcT3mIiA8LbYBNmKyzGQDhLc2y5mQtywTXoRnKxfiICbHt0
sEv5O6SvQ3qhLunrUf6tWAAgbzNR+Mq9NLWPBjFzVEwdlzOn1dxZrYAGMVJc
5iD/qervdVAXt1XOoXblrF0+bZVOWsXjZuGokTuoZ/ermb0Ku1NObReTWwWm
l2e6uUQHykIMKpfs5thePr1VyG6Xcrvlwl6leFArHdXLx43KabN61qqeQ+3K
IPQ/0ea+RXRgypcOu6X9bmmvV97dKm9vlfv9cq9f6vSLrX6+0c9Ut1Klbjzf
JjPNSLLmo8sOomCKZDWBlNybELnoTTu5ZsWXQa4pumCKLKDHKEBetuCrVhII
8+y0wMG916UzJXWyMicrR++9w8rtrBzwWpIyE+BNSPScX01MxPkVqchBv0NW
EXwVwVMRG0p8TYmvKLBFBTYvj87IIq+lkZeS8HNx+Iko9EgYGhcEx/jBEX5g
hOcf3vQNDwivuYZXnWgEL9vGuBH8Z78wjuEzMJrhmLxiha8cWnU+XHP/aGsv
WFpz5uaMsTGlr01qqy/U5afK4iN5YUyaGxZnH4o4vwhv6r8HCdi/AmFx+oEk
81CWHVHkxlX5x5r8Mx26MTRpLMI5F6btLCd3zoTwzho5vzBz9Xd49RVo1lCd
N9YWzfUVa2Pd3uI72yJPF4avOrStj+7C5EV4meMAexLJnhL5s1jpPFE5T9XP
083zbOss1z7NdY5znaNcez/T2k03+slaJ15qUvkqxhZDiayPTLnCcauPNDox
rSWsMgTkWr9U5ZUovGI55JMoAjJVSKGJqvWEzhwzORibJ+0K5nxYMURVook6
wTapXIsuthPlDlPrMI1OstlJttvJTjvZRS87RC8n3qozWzWmX2W2oQqzU0Yv
sdgtxncL9G4+tpODUy1MVXybw9tPgtbQViLU+0OIcB8Rxn8nnIkhxZkYtzCj
sbsNazYT3QLyt3K9bdzTwlzNqLMFYa427u4QHgQ5BuMYZjG2y5J7Gfoglzgs
pI5L6ZNKllOcP6sjyH+uWUI17uI+PLvrtFk8bRRPGoXjOpQ/quUOqtn9Smav
nN4tsTtFIJzqF5L9fHIrl+zdltrKsVv5dD+f2S5kd4q53WJ+r5TfLxcOK6ij
auEYquVPavnjWg46qmUP61n0naGe3Wtkd5u5nVZuu53vd/K9bqHbLXR6+VYv
1+hla10W/qPAN1VYith6KFHxUEU7ljOGWbWfkboBJrlhw1cs0SWQawzPG0Nz
xtC8MQyQF81RILxmhS+gEGF7XORgxNwbiUi5N65E9/ctSamZkRoTktvhi/wO
5q/4NhIScQnVpEBN8tXkpppYVxGrKnxZiS8osFk5NiWLvpJGnksiT8SRR6Lw
uDA8KgiN8IPDvMDQpn9owze07h1acw+vukZWHCPLNm6FNo8vfr9C67njsGEM
XaM2jyxbh8HvivPhqvuBrbNgac+bW7PGxrS+Dn5fqivPlKXH8sK4ND+C/GYe
CNJ/u/P7X1z/LUj9VYQI/yjNDMmzY8rcI1XuqQa9sOrV4McAjYMfQyjfZijP
cHiRXx1qWvdnvxvg19WReHuKQB+OvSZ8z0YduBNHgdRJNHtGFi7ilctU/Srb
ui50rktb15X+VXXnsrZ7Uds9q+6cVLYPS1t76JV1zW6y1qSLVSJTjDAZP5V0
R2ibnzC5onpbWGMKqvR+hdYv10ABhSao1IU1BkxnIU122upJOgNpbzQfpEpR
pkqk67F8M15qM9VOqtFlW1220033uumtTrrfQa8f3mmxO012t5Haraf2aqm9
anKvktwrM3ulxF4xvleg9/KwDANGIAmzNbqdDPcR3iDUi9+HCG8hwqAbA6RA
lTvhUugKVZobu/d44+FuLNChfG3C08RcjYijHrbVQ5AVHhthezPiAMgdwtul
Alt0eDsBg5jYS8f2s/HDfPKoyCLF5cwA8v/Vyf/q+K4jrsNK9rCSOShn9svp
vRK7V2R3i6mdAmo7n+pDuftYaDuX3s5ndrh285m9AmoflT4osAfFFLRfTO4X
mb0iemnZTonZLjP9SnKrmurV2G493WmmO61Mq51ptjP1TrrWZivtZLEVzzXI
dD2arATokovMW6NpfTCp9MYlLopvx9ct0WVTeAHkGoKz+gBXcM4QAs4wkVfM
2JqF2LBSPFtMYKOFtrjIht6Lj/uZI/TG7xITwivWx8W3yzPyO8AruQ8+w4Xu
K2lIvgYIk2tqYkVFLCrxOQU+JcdeybDn0uhTSfSRODIuiowKwyOC0DAvOLQZ
GNrwc349Q6uu4Tu/gHRs4HdBz6WDxzHwuwh+TSNLluFl28Nlx48rrgfWe79N
8PtaW7vzW0R+JcjvD0LkF+Hlpf7CS/6Fn7wn/IM4/VCaGZFnx5W5x6r8Mw36
efxJXXFKX0Q/SWQogdxZPWoG8CK25SktVEF+dZVZPefXdOtXwPlVBvu6yA4M
Xyd96EueRDIIb6JyxTau8+23pa2b2s5Nc++mfXDTOXrbPX7TPb7qHF+0j04b
B0c19PrYfq7TYeuNRLlCZvORZDpAMe5ozB7Aze6owR7SWYIaU0BtDKgNQbUx
pDVF9Fbc6KAs7rgjkPREMn4yH06U8HSVytfj5SZTa6eanXSnm+l1s/1udqeb
3e1m9zrZ/XbmAGqlD5rpgwZ7UE8d1lKHleRBmTkoJQ6K9H4htp+DTRgwYjss
OIpsJ0N9BvAGtuKBHkRzcYS3BiOYAeMYiNu9JUzCAN0dHHjvJi8szC3cAzO3
HrbXQtZqwFzxm6AqFDDXgtZGCBQ7YTR3SX8vBofi6E4S/kFqPxPnBjEoTh2V
APKfO7rrsPjHSulBB9+1X2QhkLtXSEG7UD61A+WS24Oyqf53bWfuS+6gmJ1M
Yicd30nTO+kYnPq3M+gSXx+9moXs5chunuoWYp0i3S7HW5VEs5Zs1pONRqrW
SFWbSfjvUmzE83UqU8NSlVCi5KXyDjxjDqe0/oQC/SQjsWmNrprDS8bgvN4/
q/PN6HzT6NE/ow/M6YMLhtCSMbJiwtbM+IaF5FkoviUmsNBC9NO+cTH3i5PE
xrgY+aVv/XKEASwkvU+LkmgpdGtJSwm0FE9LrmvIVTW5pCLmlMS0Ap+U4y9k
2FMp9kgSHReD38iwIDzEDw3xAg83/A+/8wswgSe6kbRoHFsY3Au+Tz+6YBhZ
NA4vmoeWrA+X7T8uO3+wdObN7TnTrd/JW79l5FcGfnPf+wW8/28QP/kXQeq/
ham/idgHkvSQNDMqzz5S5p6q8i80hVfawmttcVpXmrmtjNKWp7kGfgeEkV8D
59dy61fq7amCfViereS+O34UZE+w3DldvmTrbwBvZeunxu679sH7reP322fv
d87f717+tHt5s3t5vX1x2Ts7bR8fNQ72Kjtb+W473aglyiUym40kU34q7o6S
9gBm8USMzpDBHtRZoZDeGjbYoyYnbvFQdn/cFUn6iHQwno+mSmSuSpfqTK2Z
arXT3U5mC8nN7XXz+938YTd31EEdt7PHrcxxM3PcSB/X2eNa6riSPCozR6X4
YZE+yFP7OXI/A+fQ6G4qspOEY2mwz+Hdivt79KBbwmATTrV3fnHk967bq1V3
azOavAO8QQuwLXsNJY++5NHBY9mjr/iMVb+5HrRxgxjW6cEuDd86cG6XRoMY
FB/kE3Auhg5uu79QltiDsvG9bGLQLpRjoD1Uci+P2v2+3G07KGYny2xDGVQf
SnOxUGIrFUcl6a1kbIuhthiix+C9BNZLRLuJSJcJd5hwOxlup8ItNtJMR5sZ
rJEjGnl0Vb9epmuVeLUar9Ti5Vq8WKPzVSpbwdlymCn66bybyNiiKWMwofbG
ZC5CaI9uWMIrxsCC3j+n885oPVOaQd5prRcUz+kDiLABvia6ZsI3TMSmieSb
KfR29CZaiH55Ey0y0CLAi/wivBIuKZfsLrkuJuNCd4d1MaGO4uuoDS21piGX
1OS8iphREpMK/IUcfyrDHkmxcXF0VBQZEd753UR+4SQL59mhFfsw7MawIS+a
gOoo+J3Xjc1roVGUbmReP7xgGFowPVy0/Lhke7Bk/8HcmTO1Z42tGUNzSvd/
+xWw/3Xn9z+57giz/yNif5SkR2SZcXn2sTL3TJV/qS5MaopTmuK0tjSDQnhn
NOVprilUBZrWVmZ01Tnwa/yzX0N010btexJHofQpDF+mepVtvi31AO/7zuGH
/snHvYtPB1efjt58Or75eHzz/ujmp8O3b/auL7cvT7unh83DncpuL99rso1K
vFwgsukww/ipmDtKOIJRqy9idoeMrhBANrrCJnfU4sVtAcoZpj140h9Lh5M5
LFukivD/Fvie32C7rUy/nd3p5PY7IDd/1M0fd/InnfxpO4dqZU+bmdNG+rTO
ntZSJ5XkSTlxXIofFWKHefIgS+xnsD02spsKI7+JQD/uB7xb9B/8bt35Rded
Bn7vCcM6DUs1jGZYs2FzJr0ttDYP8BpLXn3RrS24NAWnGiq6NCW3ruwxVH2m
Ogzi8B8JM4PJTu6lqcGx+vfzNbo4Ru2gUza1zZL91H3UbWwMlaa3UXFU5r4E
TNLt+7g/7UMsaisFWuleMtZjqG6C7MaJLo13YtFOLNKmQm0q2CIDLdLfpHwN
ygvVY9467asl/DUmUE2FqulwNROt5NBd9XKRLJWoYpkqlKl8mciWsXQxkiwE
4jkvlXHgKXOY0flppYeQODC+NbxmCiwZfPMIr3tK436tdnG5p9SeaY0XvRmX
DnQHEWFDZM2IbRjxTSPBM5J8IyUwxoQGlEgfE+sRTAmX9E4rsFVA+tvk+hh6
daUefb1AH9vUUWtaallLLmjIGRXxWkm8VODP5PhjGTYhiY6Jkd9hwZ3fDeT3
Ied3CPwumocXjSML+pF53eicdnROA42gtPCZ4Xn90Lzx4YL5x0XLgyXbD3d4
p/UN5FdTfXG/P3/n96+cX4R3M/n/QbeEU/8lSP1NyD4Qp4ckmVFZ9pE891SR
f6HMv1IVXquLU+ritLo0gypD01xTqAo0ranMaKtzes6vubFuawqcbam3y/nd
Ab9e5iicOaWKF6kabM431f679j7g/bR/8fno+svpzZfzd18uPny++Pjp/OOH
sw8/Hb+7Pnh7sXN13D3bbxz1y7vtXLeWapToUhbPpkJM3EeRbgx3hKO2QNji
C5t98Bix+KO2IHySdGG0l2ICDBtJZ/FCgaqU441qslNnt5qZnRZsy7nDzq3c
M6idP2/nzlvZ82b2vJE5r6fPa+xZNXlWYU7LiZMifVygjnLkYRbfT0eR32Ro
hwn+W78I792tn+2727i7LLqTu8cCZHSHdxu2azrYo3wdwt2MOupobYbJC3hB
ripvV+ZsCgieFByqolMDgxgI1wLfEYbjcJw7DnPfHwAyug81GO5wsk5C2BaD
9RgYhdFuPNr5PQyVwLsQQ3QZspccRG2loNgt7ftSMfjkFvxpkurBF/9uFmtT
kRYZbhHBJu5vYL5G1FOPumtRVy3qrEYdFQhzlHFHmXCWKFeJ9pTivhLjL6WC
xXS4mI0Uc1ghj+ULeK6AZQvRdCGcygUTWW8s7SJS1mjCGKQ1PlLuwkT28KYl
uGr0Leo9c1r3NLBVOSfveq1yTand0xrPrMY3r/Uv6oLL+vCqPrJmwDYM+KaB
4BtIgQG91dW9XwmXVE/L9LRcTyu4lIbfUxhouYGWGmgxp56nj63rqBUdtagl
Z9XklIp4pSSeK/AncmxCGh2TREZFnF8++PU93PA8XHM9XHUMrdiGlixDiyYY
ssMwbQEssJ1VDxqe1QzPaYfmdA/nDT/OGx8smB8sWn8w/I4XDr+vwK+q/H/7
TQ38/sct4dRfuMvRaASL0yOSzLgs+1iee6bIv1QWJpXFKVVxWlWCZlDlaa6p
Qbd+K3O66oKhtmyqr1ubfEdL4ukqA1t65HfPyxxGMqex4gVbvy52buo777uH
H3fPPh9dfT27+Xb5/tv1p29vPn998+XLmy+frr68P/90c/L+6uDmbPvqsHO2
Wz/slXaa2U6FqeepIotlEkEm5osRbhxzRCP2cNgWCltDEVs4ao/gTpx0UzFf
PBFkU5FcBi/lqVoJjl3JXo3dbqT3mtnDVu64BQN3IDd/0c5dtnKXzexlM3PZ
SF/W2Yta6qKaPK8kzsrx02LspEAd54jDDHaQjuynwt/77XN+70J++wlYrW9v
3QLYvdQAL/K7l8J2Ob99mNSUt4O7mhF7PWip+mFt1nJ4FVmrLGvhssoGihFh
t34whZthRxsR9iLCdKgfHyzqt20lIr1EuBsPd+lQhw61Y8EWFWxSgSYZaJDB
u0JNKgy1YpEWHW1Df0Td+1MJohvHoQ6Nwajl2IaaRLCB+etRby3iqYVd1ZCj
ErSVA9ZSwFIKmIsBUyFoKoRM+bA5H7XkMVuecOQpV5725BO+fNKfZ4O5dCiX
CWez4Uw2nM6GUtkAk/bGWReVtOMJc4TWBUilF5M6IwJbcMPsXzZ4F3TuWY1z
Su14rbJPKu2vUI5JpQMRVrln1J45jW9B61/SBVd04TV9ZF0f3dTjvDvCIlQM
SEo4mzIOqcIQVxrjKi41l8pIK420wkjLjLQEtm5jjG+IbehjqzpqSUfNachp
NTmpIl4o8acK7JEsOg5+xeERYXCY7x/i+dDLqNacD1fR8B1aMg8tGodgT57T
Ds9phhFb1fAM16x6aFYzNKt9OKdHfudNPyxYfkByG1PaW7ywPD9Xlp8qirfX
n8Gv+N4vC36B7X9wfv+DB4RT3AhGd4QfiNLD4syYNPtIlnsqz79Q5F8pCq+B
sLI4rSzNoMrTdw0IT6srM5rKLPjV15ZM9TVLg+doid0dhb+ni2xbyV1P4jCc
OYkVz9n6VbF7A8vz1tHH/fMvJ2++Xbz7+c2nX26+/PLu28/vfv72089fbn7+
eP313cXnN8cfLvZvTvpX++3TfvWgXdiuse1ivJYhislIhg4kSS+Nu8ioE4/Y
sbAdg8eog8BcFOGJx3zJeDCTjBTSeDVHNYvxTpnpV1O7tfRBI3PUyJ40s2ct
mLm5ixawzV41M6hG+qrOXtVSl7XkZZW5KCfOS/RZMXaaJ49z+NGd371kcJcJ
gN/t7/3GgTOHNxHeQXijCC+L77MEKg2P+D58BoZyIvSdX1s9aK749CUYvg6Y
vCBXmjFLMiYxPGbN0pxVfkvY8z3hwUVpPyzhaJRzdSHYyWOBNuVvkr4G4avj
3hrmrWKeatRTiXrv8lUxfw0PQHUCcR6IRpxhDaajnT8Fn0TrcfiebSPqq0c8
1ZCrEnSUA7aSz1L0mgpeY96jz3l0UNajzXi1GZ8u49dngoZM2JSJWjK4LUM6
MjFXJu7JML5M0p9hA2k2wLL+FOtLsp5EyhVj7GTcgsUMYVLjx+SeiNgZ5Nn8
a2b0BlzzOueMxjGF8NpeQQrIPqmwv1bCJ10zKvec2rug8S1pAyva4KouvK6P
bOoxngEXGAihgQS/CK8xJjXSciQ0rjTFVaa4GpXQmOIaM0ptRp+EP0I/42+i
xUYa1u9NQ2xNj/zOa8kZDflaTbxU4c+U2BN5dEIaGZeERkXBEYF/mOcd2nQP
rTuHVm1Dy5ahJdMQnHDndUNzQFU9NKMamlHeBc/VD2c1D2d1P84ZwO8D8Kut
vdbUYG1+pa68VFUGw/eJovhIhl6Cha4/g1/R4PzLgtb/RIRTgPc/uCfIL/ei
DjA+JM6MSrIT0uxTWe65LP9KXnitKEwpitOK4oxiQLh0T3gwi2fUlVltZV5f
XTLWVi31TXtT6GrLfV1teMtC7Ljj+6H0MVU8SyG/bxu777aOPx5cfDl9++3q
wy83n399/+3XD7/8+vG3Xz789u39r59vfvlw/e3m/PPV0fuz3beHvcudxkm3
vN/IbpWTrVysmsILiXCG8idxTzzqikWcVMTB5YxhrjjhSVK+NI1eaV9m8XqW
bOfpHnp3C/S+Foe19HE9fQp7ciNz0YCBC2yR3OsGe11nr2upq1ryqspcVhKX
5fhFKXZepE7zxAnyGz289RvaZYI7yO9gBAf63+Hd/hPeNHFw1z6L/O7Cl8Gk
Rn6drbCtHjBVvLqSS42GL+A1idNGUdoo5B6R4pxVVrArS05NxaOv+U0NIByx
I8K4u8u90qMLqzjla5O+FultEp4G7q5h7mrUVYk4y2FnKeQoBiFngasYchVD
7lLYU45wlu8414lAA5ZhEgq1KC54Ah+iDTnATVvEthZ2V4POSsBe8lmLXnPB
bcy79FmnNuNQpx2qtEPJOpQpyKlMulRJjzrp0yYDulTImIqYU7iVJe1szMnS
LjbhYRlUKulJMu4E46QTdoq2EJQhSmpDmNIfkXpCQod/0+pdNbsXDa45nWNG
Y59S2Ti/Vs6vbeB3WumcUbnm1J4FjXdJ4we/azruN6Lqo3zOr8hIio0Uwmui
AaYChIJTc0JtTmgsCe13wYdqC/xRXGGOy9A73dFCU4xnjK2jX/NNLejIWS05
pSFeqfHnKuypIvpYHpmQhsbFgVGhb4TvGd50Da87hlatQyvmoSXj0AKccGFP
hmnL4Z1WcCkfQjOqhzOaH2e1P87pH6ARbP5BXeHklqEXytJzRfGpovBEXgC/
Y9/7FaZhT/4Ln/1P/sBvauAXPvzLnd+HovSIODMhyT6Rgt/cS1l+Ul6Ykhc4
vxzhu6YHkJHf8qwGVujKoqG6Yq6t2xoCZ1Pq7ahDPRO+7aT3AuwhUThN1i4K
nTf3fmF5vv7wy09ffv3w82+ffvvt899//fyPnz/+4+v73z7d/PLu6tub008X
B++Ot9/stc+3aketwm413SskmmmywkQLdDBD+lKYh4m6EhFnPOJMRFxM1J3C
PWnSl6MDpUS4msKaGaKbi/UL8d0Sc1BJHlVTJ3C8rbEXdRZW5Suu63oK5F7X
ktc15rrKXFcSV5X4ZZnm/JJneeI0hx9zfg/Y8P7A72AEJ77HG/oTXo4teZiB
iEN4zmL7qeguA379W5Sni/xa6wFjxastwfIMw9csAbmsQcDq+SiDABRn7wm7
7glbmmF7K4oGcRtHr/Ro4e4m7mpg3PEz4qiE7aWQrRiw5f3WnM+aHeQdPLHl
/PZ8wFEIOItBVynkLoc9FZinsAxjPqiO+7l8dYzrdkl2V0NONHD9aOAWPKa8
25Bz6jIOTdqmYq2KlFWetMgYizQBWaVxmzRul8WdirhbmfCqEwEdEzIwEVMS
syQJW5Kyp2KOFO1Mxp1M3JGg7XHaGouZSdKIE9oIpgpGZL6Q2B3gO3zrNs+K
2bVocM7p7DMa25Ta9lplnVQOsr1W2qeU9mmVc1blmle7FzXeZY1vVRsAvxv6
MA/5xYRGQmwkJSZKaorJzTTAVCKkCY2V0XLpfi+htSLCKgt8DfIrMaPL1zzu
lyWtGKhFPTmnI6e1xGsN/lKNPVdGnyrCj2XBCUlgXOQbE3hGec6RDfvwmhW9
Mc6SYWhBNzSvucU7g/A+vO0PfrkV2vxAWUJslUWQ+0xReCoHvPnHstyENAfL
MBxpwS/sxv8DfoUsrMr/b0CYC558P3+RX1FmXJx5LMk+k4Lf3KQsj/zKCzPy
4iz0nWJEeHA01pTntOUFfWXJWF2z1HiOhtjdUgY6+uiWjdrxJQ+w3HGicp5r
X9e2b3pHH/YvPsP8Hfj9+Avg/e3LP3778s9fPv/z28d/fH7324c3v9xcfL06
/ni6+9NB72q7cdopH9Sy28VkNxtrpPBKPFygAlncm8bcbNSViqDYqDuDe3Kk
rxgLVOKhejLaTuO9LLmTj+0V44elxHGZOa0kz6tJOOHCnnzFhcyiEqhKHLoq
01el2GWJuiiS55zfk2z0KB05BL+p0O0IRqfgQSAXHXt3kpHdVJTDiyO8mQFe
8uiWMH4Af8qEdmh/H/l13Pr1aItOZd4qy5jFaYMgpeendLxBrP6WcN4qLzqU
ZZem6gXCRo4wGsTNqANqRB31iL0WtlVCtlLQWgxY8n5zzmvKeExpt5GFXJAJ
5TanPZaMBzjbcj573g+Q0XQuhVzlsLsCTiN3wfOwqzJgCwPXDwOXk+syZEGu
XZO2qlIWRdIsY0yShFEcN4poozBmFFImIWUWUVYxZZdSTnnMraS9ajqgjYcM
iYgxgZkZ3MKQVoa0MZQtQVnjlIUmTRRhIHEtFlVFwvJgSOILCD2+TadnzeZe
tjgXjI45vX1Ga5tChK1A+LUK8No4vI5ZlXNO7VpQu5c03hWtb00XWNeFNvVh
viEqNGIiEyExkVIzJbfQCoBpjasBqY3R2hidPam/z8ZAOhu4TqityC98PfgV
cb+vYcNErRqpJQO5YCBm9cSUDp/UYC/VkefK8FN58LHU/0jsHRe6x/jO0U3b
6LplZMU0vKQfXtAOzavv/T6clv/J78M7vz8umB/IC89QeTi0PpXln8hygPeR
FK3BY5IM+B0Sp38Up/9HlP6rkAXCfwHCAiB8G3AG1Jxf9qEQ/KaRX3HmmST7
UpqblOamZPlpWX5GXphFIcKzg3GMzsXo6taMujSrKc3ryouGyoq5umGrCV0N
ma+tCXfNRN+d2AtnDmOl03TzstJ/2z54v3v+6eTN16v3P9/5/fvXf/729V+/
fv3Xz5//+fXDPz7e/Pru6ufr08/nB++P+m932xe96kkjv19m+/l4hyUbiWgl
FiwSvjzmyQLbqAuCJ3ncUyS8ZcpfiwebTKTLYv0MsZujDgqxoyJ9UoqfwcG2
kriADRnNWdTA7HWFRpWhGHRVoi6LnN8CcYb8Yr+P4FvCoZ3bwju/48W+x3uU
pbiA8Hd+4//LrwP8wvIsYg0Ib1K7mdRuwCMibBDA53MWScEmhzFdcd8ShoNz
I2RpwL8QttbC1mrIUgmiy0cFvynnNWY9hrRLn3Lqkw4dA9kH6RmHIek0pu4g
w1CGAZ332wp+ezHgKAHV+8AsYmsr+qwFrznvMeXu5dru5BolcYOI1gtjegGl
45N6PgEZ+LhRgJuFhEVM2KWkU066lZRXHQto6ZCeDhviUVMcMyVwVBw30rgh
humoqIaIqLCQPBKUBP1Cv4/n8Ww43at255LVsWC2zxntM3rbtM42rUGKp9WQ
fUZtn1U75tXOBY1rSeNZ0XpXdf51XWCT+x2LAmNUZMIlZkJqJuWWmMJKK21x
NQi1M1o7o3Mk9Y6k4T6kGPyCa/CbAObgV2pBfgXm2KaJWjNRK0Zy0UjMG/AZ
PTali05qIi/VoefK4DO5/4nU+1jsnhA4xnm2sQ3L6KpxZFk/sqgdBr9zqqFZ
xWD+/r5Cw/kX+dU9nDM8nDehu0jS3BMULL3Zx6jMI2lmQpoZl2TGJOkRCZxq
0w/FaTSCReyAMID9y13w/L+5nyvk/LLIryjN+c28lGQnpdkpaW5alpuV5Wfl
+dmBYgVqRlGYVhamVcUZSFOc05YW9KUlY3nNUuU5amJPUxloG7CePbbtZ/eJ
wnGyfl7oXTf3fuqffji6/nLx7tvbz7/A/vz5t79//cffv/0LCP/y5V/fPv7z
87u/v3/zy9vzrxdHH092f9rvXvfrZ63SUTWzW2S2MlQ7idXjoQrlL+HeAuYu
RF35qAsei5i7THirlK9BB9qJUC8V2U5je1niIEceF6iTYuwMtuISfVGmYUNG
cxaocmC5qNtKFPi9KpKXRfKiQJzn8dMcdpKBERw9ZBHhPXQQDu9yIbn3eNMI
Lxq7t3Kp49vIozR+yEb34a/EA9uUp4c722FrI2CserSlP/hFeBnNehLSbrB6
HgzlrFkMX1C0K8ouFXiv+oCwoR40QbWgqRo0VQKmkt9Y8BlyHn3GrWOd2pRD
w9g1CZs6blXTKA0Ut2oTNgQ56TCknMa0y5Rxm7MeS85ryYNTGLIAFh7heAt7
Mhq45rx7IFefsWvTNjVrVSbNcsYkTRjESK5OQGl5hHYT12zi2k1MuxnVbUb1
vKhREDULMasYt0txp5zwKEmfmgpoY0EdHdbTEa4oPOpiES0VVpMhJR6UYwFJ
2CcKevl+z4bXveZyrjicSzbHgsU+Z7LPGm2zetuMDoJZbJ/VOua0jnmtc1Hr
WtK6V3TeNZ1vXe/f1KM33hcYIyJTVGzGpRZCbqEU1pjSRqvtCY2D0ToYnTOp
dyYNzhRkRI+IMHDW2Tm/Ns6vFfkVW5BfnplaN5OrJnLZRCwY8TkDNqOPTuki
k5rQK3XwhdL/TOZ9KnE9Fjke8W0Tm+bxNePYin50STuyoB6eUw3PcvvzbbfX
r4Zm4WgMB2TDEPJreSjJPJKkv28CxY5L2DEJi94OS8wOidkfxewDEbpP9Ld7
xcJbvH/lfjrpwcCvkB0XsY9F7DNx+oUkPSnJTEkzM9LsrAzKzckhDrIiPwMp
89OQqjCjLsxqCnO64oKhtGIub9gqAldN5mtqwh0LueVmdiPZQ7pymm1fVnfe
do/e719+Orv5ev3x53fffv30K+zPf//2z9++/evXL//6+dM/v7z/x4ebX28u
v12dfD7df3+49XanddmpnNRzB6XUTo7usUQ7EWnEAlXSV8E9ZcxdirrKmKuC
u6uEp0F5W7S/mwj2wQsb2c9gh1n8GDbhAnlWIOFUe1GkLhFSctD1v4vzSwz8
3o9gIHwA/yAb2UuhdlGDM++f8R7nYtAJCvk9hhHMYgfJ8B4cnGNe5Ddy59f5
R7+adUazBsET+DBt4GdMwpxFXLDJSk5F2a2ueoGwrubX1wKGasBQ8RtKPn3R
q897dFmXNu3UpOxqxqaKW5S0WRkzKynTIFXMrKIt6oHipF2fchhYpyHjMmYB
KVCFvFywJ8PAdRtv5Tp0abuGRQuzMmmSJ4zSOODVCSmtgNTwCPUmpt6Iqteh
iGY9rN0I6zbDel7YKIiYRVGrBHPIcJdiQJj0a6iAJhbUxEKD1FRQSQYVRECG
+8RRrzDs4Qfdm37Xmte54nYsOx2LdvuCzT4PhM1IMQziOYNjXu9AvwxC71rS
u5b17lW9Z03v2zD4Nw0BvjEoMIZFpojYjEktuMxKKqwUhzeucSS0Tg6vK2lw
pYzfBYSRX9Bt5/zaOL9W5FeIXpBJbZjJNTO5YiaWTPiCCZs3RmcNkWld6LUm
MKnyv1R4nstcz8SOJ0LbY555Yt04vqofW9aOLqpH5lUjc0ogjJpRDu4fcbeA
dcNzhuF549CCeWjROiRKjd81IUaN3zUmSYHfke8Ji9kf7hT/TYggo58lFKZ+
EKR+FKaGhKkRYWpcmHosSj0Tp16I2UkJOyVJT0vTs9LMnAzKzslRs/LcjAI1
DSlz06rctDo/q8nP6wqLxuKqpbRpr4jdNWWgacA6drrvZ/eI4lGqcVbcum7t
/7R99uHozZfL999uvvzygTsC/3GF/vTTb++uf3lz9uX88OPR9k+7nete7bxZ
OK6k9wuJ7TTZheMtHWzAqkx4qsAWc0E13NUg3C3S04n5tuL+bSYIs/IgHTnK
RE9y2ClIzOPnBRxUXkJF4uqu60GlQf+G8OktYewwjR2ko/ssCtgOQngzd3hz
CO9J/q5bwsQR/EVQnwjuxLxbhKsTsTVheno5vzZp9tbvBvKrXoOSmrUUN4Iz
RkHOLCpYJUWHvOxSVhBhDRCGKj5d2acrerV5jybr0qSd6pRdxViVcYsiZpZT
RhlplBEGSA6RRgVABsVxizph1SRtMKZhWOsz4BQCsINchnu5d2MX4WXu8MZ0
ogFeHPCqNqKq9YhqPaxaC6nXoaB2I6jjhQz8kEkYtogjNknUIcNcctyjJLyg
WEX5ISXlV1B+OemXkT4J4RVhHkHUzQu7NoLOtYBjxedY9tiX3PZFp33Bbp8H
wlbHvAV2aceCybloci0ZXctG94rRs2b0rht9G0Y/zxjgm4JCU0hkjkjMUakF
k1kJhY1U2mIqO61xxLXOhM7FILzuFGS8D/y60ET+N36tt355FnLDQqxZiBXL
7Y8xzhsjc4bQjC4wpfFPqryv5K4XUsczke0p3/J40/hoTT+xohtbQm/2PooI
c83Co5p7CRZ6CeXIvHF4wTy8aBlesg0LmVEhM3bXuGhQclyMGvtesYR9+J3i
AeQfAK8w9UCYfChIDguTo8LkuJB5LEw+EyVfiJKT4uSUJDUtSc1K2TlIlkbJ
M7PyzAzXtCIzBSmzU6rstDo7q83N6/NLxsKatcR3VqTeuibcMhNdN7Mdye3T
lZNs56K686Z7/A5G8OlPX68/oRH8EUYwIvwrdxXrK7qKxa3QF98ujz+d7L7f
773tNy7bpdNa9rDE7GZj/RTWTYTaMX+T9ILZBsjFnU3c1QIapLsX8/bjvh0m
sJ8KHrKh40z4JBs5y0XP89GLPAZdFlBXXNdFCIfelCCC68+Ez24vZKF7wdzL
OVD7KPz/wEufomKoHHWCRjB+mIrsM8Ed2of8RpHfGrp/xPk1i9J/8LvKIL/r
rH4zY+BnzcK8VVy0S0tOjrBHXfFqoLJXU/JoCm51zqXKOFWsXZG0yRMWGW2S
UkYpYZDgei6dFNdDMtIAqIE2AFclrOqkDYa1lgWncLZ16rO36W7lwti1qVNW
VdKi4PDK4gYJrQe8QlLDx9W8Ad6wcj2kXAtCqrWAej2g2QhoNwN6ftAoCJlF
Yas4YpfeEnbDLi0nvHLSKyO9UtIrITwi3C3EXfyoczPiWA87VoP2lYBtyWdb
9NoWPbYFl30BCDscC3bHos25aHMtWV3LFveKxbNq9q6bfRtm36bZzzcHBOag
0BwSm8MSywAvrrARSjulssfUDlrjjGtdCb2b0buTBk/S6Endxlm+96sBv/bf
/UqsMZGVElgpvpXctBIbVmLNiq9asWVLdMkcWTCF5g3BWZ1/WuN9rXS/kjlf
SmzPhZanPNOTDcOjVd3EsnYcCC+qOcWQhks3Oq8fXTCOLppGFi0jS7aRZfsI
P44SxEe5xoQJaFyUQIrFDFIsQYS/VwyzGEEWQWjsot9FKEwOCZhhQWJUkJgQ
JB4LE8+EiReixCtR4rWYmRYzM5LkrCQ5J03NySB2VsbOyNlpOTslT0OvFagp
ZXpanZnVZub1uWVTfsNWFLoqikBdH23bY1t+dpcoHibRCL5qHtxwI/jzxXt0
Cn7/86+ffvv18z9+vb8K/f7vH97CCv3z1cmXs/0Ph/2fdlrX3cp5I39cTh3k
6d000U9GevFAJ+Ztk25g2yKcbcLZIV09yrUVc+/EvXuM7yAZOGKDJ+nQaTZ8
lo2c5yIX+chlPgpdFVDXKET4zR/9fk/4osBdyOLuBR8D4Sx+mEEd3DbASyK8
g5lboE+5zgoDwtRJjvMLUxtdgvZtke5O1N4MmWowQF2qArp/JEobB+df2J9X
Ob+rSe0aq9tIG3hZkyBvERVskpJDVnYpKm4gDGdhddmjLrpVBZcq51RmHIqU
Tc5YZHGThDKKSb0Y14kwrSiKEkOYDixLSYOMMsppkyJuVjJgE4TaNWnQ6tBm
BqEPNfdjN2m+xyul9Wj4kloBoeFjal5UtRFBeNcBb0C55leto9Qbfu2mX8cL
GAQBkzBoEYWs4rBdEnFIoy4p5pLibgnuFuNuEe4S4k4+5tyMOtYj9rWwbSVk
XQ5aFwPWBb91wWdd8NoWgLDbvuByLDqdS07XssO9Yves2r1rNu+Gzbdp9fOs
Ab41KLSERJaw2AJ4I1IrwisHvDZSZafUjpjGSWtdcZ0b+QW83/s1QG60Ueuc
6GgMflX2OPJrA7+xgV8hELaRPBuxaSM2bPi6DVuzRlcskWVzaHHwU1Fa74za
PaVwTkrtL8XW5wLz003jk3X941Xdo2XtxBL6rSvji1ru7SjRzx+NLRrHFk1j
S5axJevosn10xTnKiw3xYsN8iB7h06MCekwYH4dEiQlIzEyIkxMSpJiDzN5t
1KkhSJRCcoXMkCABeOGbwJiAnhDQjwX0UwH9Qki/EtKvRfSUKD4jjs9KEtCc
lJmVJqEZWXJalpySJV/LkpOy1KQ8NalIvVamptXsrDa9YMiumPM8R1HiqahD
DRPRcTH9cG6Prh5nOueDEbx3+fHk5svVx283X2GLHhD+5dM/wO+X938fXIUe
rNDH2+/2Om+2apetwmk1fVRM7GfJnVS0nwj2aF+X8gDbDunsks4e6dyiXNu0
ezfu2We8h0n/MRs4SQfPMqHzbOgiF77MQ5ErqBDh8EbfFCHsTQl7W8Lflgku
Enpzey1rcCGLuxeMCBNoGb4lTKCyxB1e6h7v2fehETw4AiO/u7S/T7q7GPg1
13x65Ncuy1rEaaMgpb/zq7n3u542bGZN/LxFWLCJSw5pGUawGxEue1Rlt7Lo
VuZdiqxDnrbLUlZpwiyhjWLKICJ0QkwrjGoEEZQQimqAsxjGMRCOcYQTQNii
hAkLcxZK29XAFslFN3YRXu5Ss5wxyWBzpg2SmF5McX5xzm9EtRlWboDfgHLd
r1z3Qap1n3rDp9n06Xg+Pd9vFATMHGEbEBZHHOKoUxR1CjGnAAO5js2ofSNq
W4tYV8LWpZBlMWheCJjn/eY5yGeZ81rnEWH7osex5HYuu90rLs+ay7vu9G04
/TxHgG8PCuxBoS0ksoXFNvQr56Q2TGbD5LbB8CVVjj/69YDfW8L3wUSGvRqO
xhoHg4avPa4Y+LXFJLaY2EaJbJTQRgrsBN9O8Oz4ph3bsEXXbJFVS3jZHFwy
+hf0vjmNZ0blmpI7JiW2l0LLc77p2S1h/aMVGMS6iSXuzeuWbt9/Y3zZMr5s
HV+xj604xlZdY5vkw03qIY8a4lHDPGqEHxsVxMaBoTA+IYo/EiceiZlHkiRX
auJWcWpUDCVHRLAzM8NCwBtH9vn0GD82wace86mnfOq5gHwpoCYF1JSQmhbF
ZkSxWTE9KwHI8RlJYlqSmJImXksTk9LEK0gGMa/kzKQyOa1OzerYRWNmzZoX
OEsyf1UXbdpiXR+7gxcPmMZpYeuysf926/T9wfWns3ewRX/76RsQ/uXjbz9/
/Pu3j38Hv5/A7/XPb8+/Xh6hFfqge7PduOqUzuuZkzJzmKf20thOMtRP+Ldo
D5jtUSDX2aec2zHnLu3ai7sPGM9R0nfC+k/TgfNM8CIbusyFrvJh6Brhjbwp
Rji80bcc3psyRNxUSOhthXpbpu4ID+4lkWcDv7eEB3IJdIcIeOYQ3tNCDOEt
os4HIcLcCEZH4Ch6BQi6hQR+HS3w69eX3eqCXY78mu79rv3uV3/rN4f8iooO
SckJI1hecSsAb8mtKLoUeac865ClbdKURZIwiWNGIakX4FpBVMOPqPnh2wQR
9S1hQi+hDNIYjFQYrGZFEhFWskgxF3quZH/Hezd87/wSWiGuEUQ5vyHVZlC5
EVBucH43vKoNr3rDq9n06nhePd9nFPhNgoBFGLQKQzZh2A4JInZ+xM6L2Dci
A7mW5ZB5MWSeD5rmAqZZv3HWb5rxmWZ95lkg7APC9kWvY8nrWvG61zzedY9v
0+3nuQMCV1DoDImcYbEjIrFHpPaozH6H187hRcOX0ji/93tPGAXPYSLr3IzW
xWicjNoBw3fgl5Z951dsp0R2UmgnBQ5C4MD5DozniG7aI+u28JoluML9eNSC
zjOnds0oHFNS26TY+lJgfs4zPdswPl03PFk1PF41PFqBjFzmiRXLxIp1YtU+
seoYX3WOr7nHN4gHG8SPG8TDTXKIR47wqFE+NSaITQjpR0L6sSj+WJx4Imae
SJjHkuRjDvLE4GgsYqBRYQIt3ghvbIxHjfPICR7xmEc85eHPefhLPj7Jx18L
iCkBMS0kZ0QQNSOOQdPi2JSYnhTTr8T0SwnqhZR+KYu/kscnlYlpdXJOxy6b
Mhv2vMhTUgZrRqLlTGyFsrtU5SjdPivvXLWPbnYuPhy9/Xz+/uubz0D45/e/
/Pzht28ffvvy7jfw+/7655vzr1fHn8/2Phxu/bTTfNMrXzZzZ9XUcZE+yOJ7
bBi9GiruhYHbj7lA7g7C69yLOw8SriPGc5zynrK+s7T/Ihu4zAWvcqHrfOi6
EH7D4X2L5EZvSthNGcJ/qhA/VUhUlbqpoEAxEL69HYz8kqd3hI+ydyG85AkI
vcPLyY1zoefg9+zWL8bdQuJuAWOOZthy69chz1o5v4bNpG6d0XJ+tatJ3b1f
Xs4iQH7tkrJTWnbJKm40hTm/8rxTlrVL0zZJ0iJOmIQxg4DU8XEND4iFYUQi
ZfAEAs4CTCOEvZrUS2JA0ihLgFCLHE64qQHbW7wKwJsyy++G77/1C/8aD/wG
VJt+5cYArwdSb3o0mx4tz6PneQ1AmO83A2FB0MoP2vghGy9k2wzb1sPW1RAn
N2haQHKBrWHGb5j2DTJO+0CxGfn12Rd9jmWfa9XnWff5Nnx+njcg8ISEnrDI
HRa7IhJnVOrAZJAdl9sRXoWdvPervvVL69xAOM4Rvk0HuRNwLta4EmpnQuXg
8NrR8B34RYTtyK/YQYogJyF04kInJnBG+Y7Ipj28YQ2tmQMrRv+S3rugcc8p
nTNy+5TENimy3BE2PV03PlmDTI9XIfPjVcujVeujNfujNcejNefEmmti3TOx
jv2wjj9Yx3/cwIc2ieFNYpRHjvGpCUHskTD2WEQ/EcWfihNczBOuxzCRRQxs
17Bmw8IMMxe+fgz+1iYxvolPbGKPN7Cnm9Fnm9EXm9FXvOgkLzrFR788d1qA
o4RgmZgSkq9F5CsR+VJEvhCRzyEx9VxCvZDGXsrpSWV8RsMsGFKrlgzfmZf6
ytpI3RLreFP9aGE/UT/O9S5qe2+6Jz/tXn04vvl88eHrmy9fb759e/fL13e/
fvnp1083vyC/F9+uTz6f73886r/ba73dqv7/jN1ldyNnuuj9T3PO2TB7D4ep
02myxWAxk8VMxVViZsmSzMzMbrvddtuNYZxkksnMfj7Ic1fJ7nT27AfW+i8v
2XE6efPr67pLUunB4uj9mfbhRH1vtLTTzW0PpTebCbAtb9RIIJfGWyN26sRu
k9xvUQdDsaNO4n43eTKcejCSBngfjmUejmfPAF5abh7IfUTLpfFeTJcvpitM
1UfT1XPQVPXhFP3U8MsRfPjrEQzav/YLhu8vY3eifkzXG8H/f/zaGb+mK7+B
V/xGaL+jjN8J3Ab8TjF+GcKucdI5ijuGMXsHsbUgayNiqYbMpYCp4DfmvAZm
v+3VU2wGG3UxMFgKWithsGk76lFnEziFXQBsG2GC3Yxf1yt+HfVf9mcb+HeL
zGYOxnrGZ0p5TUmvMeE1xpgon5HyG6mAiQqaYmFTPGKOR80JyJSETSnEmEIM
aUSXhrVpWJ2ClKmonB64AGxInAiJ4i8Li+OAMBjBjN8koU5S2mRcn0wYkylz
Ij2YyFrjOVssb6cKDrLgJIpOvOjCSy4G70u/1/tz1U9WAeEAdaU4GKO/Bpj8
ZN1H1L1E3YMzeOnoD7NzYNVedrxiJ0BlG1kCWcmXhLNGNKOH07oo/SYpZSAm
95FSNz7gxEQ2VDAI880wzwRxjRDHALH1IJilR1h6lKXH+vV4v57o05N9BqrP
ELuny7+rK7yvK3ygL3xoKH5kKN42lgBGeg22VFiDVfZgjWOt09kaILa1wbI2
wFzuAws2WLPN1btg7BrLQO5dQ+GeId+nz/Xrcyx9lqPP8vQZviEjMGRExqwY
ZMqJzSCas8hSEFoKAkuBZylwLQWOpcgZLHKsRY6txHWU+a6KyFuTBhqqyJAe
7Q5SY+70VLg4jzeWU8MbpcmdoYXDsbWTuZ2z1aOL7dMnB4+eHT95fvr8+dnH
z88/eXb+6dOzTx+ffvLo+MXpwfPjHXAEvtxeOl+febg0fjLXPZpqHoxX9oYL
u53M9lByuxnbalDbdXKbnrzEboPYb5IHQ9RRO3a/Ez8ZTj4YSZ2OpgHes/Hs
+UQOyH00mX80VbiYKl5Mly5BM+XLmcrlbLXXxUzt0UwNED4DhJlXZL26QvdO
wVfR3770WwVgAdtf+pVfen9mXoJFLV37naB8o1d+B4HfZsjQDL7iN8z4hUyj
yP/sd4J0juGOEdqvdQgaZPzSr6ko+Ay53sVhtz5NRxMGUxhs1AW/pUSPYFs1
bK9HHU3I2YKcNFjY1b7u2q+zBYBfEwa/XwnZysBv0JoPgDO1JeMzp3zArynu
NV3h9RlJv5EMGIFfKmSKRUyxqDEOGROQIQHrk7AuCWuSkCoJKRJRWSIiiYcH
ANhYUBgLCqjrYuAnEXEcktArNOM3RWlTcUMqaUqlLcnMYDJnS+Tt8YIjVnRS
RSdZchElF152MXgZvxXm4nOPcG+L7imuBihQzQ8iaz4mGi9Rd+N0wK+T8UsT
xqt0RNVBVuiosp0q2amijSxYibwFz5mxrBFJ66GUNpxQB1+OYFxs7xFGGMIw
1wRzjAiIbUDZBoxtwFkGgmUg+41UvzHWB9Lk3tHm39Pm39flb+gLNw3FW4Yi
mKT3TOV+c5llqbAtVc5glTtYA3GYgGiWpdoPBjQY00A6GLuG4l194a4+d0+X
7dNl+nUZli7N0aW4uhRPlxLoU0J9SmRI0xkzTFmhKSswZfmmLNeU45hybDMd
y5JnDxY4tiLPURK4KwO+mjzU1EBtEz5sT4z7cjNQZYEaWs2ObVZn9jrLR5Ob
Dxb2ztaOL7YfPjm4eHr85NmD588evnj28OMnDz+5fPDxo/svHtJ+nx5sPN5Z
frQxe7Yy8WBh+HimdTRRPRgt7nWzu+3U7lAcnHZ3miQYu3tNYr8F8JJHbYrG
2008GEmejqbOxjLnDF4g92KqcDldBGwfz5Qez5Yfz1aezFafzIFqj5kuZ2s9
wmfTV35Pxn91Fbp3IXqPeUATBqv1WAWsyvfHq//d7/h/97tK+8Xms9D0K37b
kOVXfoPaVuhXfsexQcavfYpyTlO9Fdo5QTrGcPsIZmP8WhoRczVkLAUMBZ8+
59Fl3Lo0yKV7STjnNYFzMRig5ZC1GrbVI+DI7GD8Ol/1yxB2DjG0ab9RZgRH
wNZtv7qyHbTmAoMZvyXlNyd95rjPFPOZKJ+ph5cuaCRDRipspCKGWNQQh/Rx
SBeHNHFIFYcU8agsFpHEwmIqJARgySCfDPAIJvpxSEBFRLHoQJz2q2D86mi/
KdpvKmtN5m2Jgj1edMRKTqrkJMsuonzlF6308tCBKUzHLNJ0fpLOd1XVS1Y9
BIj+6FgXDqo7f6nmJJjIqpMCVZwxUBn8Fx1XhHMWLGtCMwYopYskNaG40h+T
e8EIJgacNGGhFRBG+RaUZ0a5JjqOCeOYcBDbRLBNJMtEsUyxflO8X519W5N7
V5N7X5u/ocvf1Bdu6Qt3DGANpo+xLHOZA7JUuNeBxxzm8hQLADeW+sBvgrGr
z9/T5e5ps/e0mT5Nul+TYmmSbE2Sq0nwNAm+NiHQJoQ6UFKo75USGFJ8Q4pn
SHMMabYxzQKZMixzhmXJsgdzHFuB5yyKPGVJoKaMNHVoZ5AadaUnQ8VZtL6U
6K4VJrYb8/vDq/ent08XD87XTy52zh4fXD65/+TpybOnD148efDi8uRFz+/J
ztPDjce7yxebc+erkw8XR05mh+5P1Y/Ggabcfje9307uDcX3WhQtt0UeXuGN
nXTjD0YSD2m86fOJ7KPJ3MVU/nK68Him+Hi29GS2/GSu8nS++nS+xlTv9WS+
/niufjlbZ0Zw7Zf5e/UsMP1Cjr1XAoTBRD4cLR+NVWi/DOGTK7/V+8D1aJl+
7vjKb6Lnd+4Vv13E1o5aWozfRlDXeNVv1PCq3ynSPk05pmNO0FTPL0H77SKD
jF9TNWgs+fV5ry7r0abd2pSrly7logmD4zA4tzIjeLASstYi4Mhsb0IvCTvb
rwS+bb1CGOzb1YgdLN6lkI32GxzMBAZTfkvSb477zTG/ifLTfomAkQgaiRDI
QIYNZERPRXUUpI1BmhikikFKKiqnIhIyIibDQiIkwIM8PMAFYcxX8C34IRkW
UdGBGCyNY4oE2J9julSC8ZuxpHK032TRHi8xfstOsuLEKy6s4kKZkIqbfuVV
2QOiX8JR8mIlL85E9CqDPHQVN1EFuRi/V3IJOheIrLsoUM0dA1Xd8YorXnaB
/2Ks6KAKNjI/CEYwmjHCaX00pQ0lVIG4wkfJ3KTERQw4cJENEMYEgxjfgvFA
ZoxrxpkIjpkEsc0U2xwDhFmq7Fvq7Dvq3Hua3Afa/Ie6/C1d4Y4ebMLFfmOR
ZSyxTSWOqcS9jkNfmyqxwT8Cv2Ao9L2Uq8nc06TvqVN96mS/KsFSxdmqOEcV
46ljfCaBhkkb78XXJXi6BFeX4OgSbH2SZUj2g4ypflOaZcmwrVmuIy9wF8W+
ijxU18AtI9G1Jca8ualoZZ5oLadHN0rTO63Fg9H145nd06Wj840HFzvnlweX
j4+ePD5+9vj4+cXx8/Oj5w/3nwG/RxuP91Yut+YfrU2dLY2ezrdPphv3J8DI
KxyOZA+6qYNO4qAdO6SjjjoM3uEe3uTZePrRROZiMnc5nQdyn8yWns6Vn85X
ni1Uny3Uni/Wny82ej1bbIKeLjQfzzcu54Df+rVf+rXQr76QcpcuB77udfOA
M+B5OAKmM5jRQDqoejJRPWEsM35LtN927/Ub8ZUyuVhA5zLRqURwnPKOYE5w
eh2i/RobQf2rfof+v/xOko5x2q+V8WtuhE2VoKHo1+W92qxbk3Zpks5e2iQg
7NaDs3D2n0fw/7PfHmGwYzcgZ50hXInYS2FbMWTLB63Z4GA6YEkGLL/4DVz5
xUMGPGwgInoioiOjWhLSkJCahJQkJCejUiIyQIRFeFiAhXhokIsGOCCE+Qq+
xUJ8PCIkITGFSGNXfrVJ4DdtSmUZvwVboue3DDZbJ0H7dWIVJ4OXDi6D3HDJ
jZQ8SNGDFj0YE/6ykpsAgcFdcTF+e2ydRMNF0rmphjtG54nX6RI1T6LqSVTc
gHAc/KVRtIMRjOcsaNYEZwzAbzipDsSVvpjcQ0ld5ICTENsBYZwmbMX4gziI
ZwERXDqSa6E4dDFAmK3MvKnKvK3KvqfOfqDJfajJfaTN39EBlcBmgWUosA0F
zq9jG/Isfb5flwP19eSqabn3VMk+VaJPmehXxllK8CfHOEqKq6R4SpIPUpEC
kJriM/E0FFdDcTQxtjbGAuni/fp4vyHRb0r2m1OswTTHnuU78yJvSRKsKKMN
HTZkiQ070+OB4gxcX4h1VrITm9W53fbK4fjm8eze6fL9841TmvD+5eXhk8uj
ZxdHz84Pn73qd3vh0fr02fLYw4XOg9nmyRTYV4v3R3NHI+mjbvKomzjqxu93
48ddcOaNnwK8Y6lzBu/lVO7xdOHJbBHIfTZfeb5QfbFYe7HUAH283Px4ufXi
uudLraeLrScLzcu5xqPZ+tl07XSSWZ6ZNzIweOn3Eu5ct9vOAc404ZEicArO
yMdjZYbwVfSpGSzY3QL4t7aaqfVabKVELOSR2XRkMhEYIz301WPY2oqYmyHa
bz2gBTGEGb+RX/xOEld+Z171i9sYv5ahqLkeNlYC+qJPl/NoM25NyqlOOtUJ
B0iTYAjTWzQ9gs2FgIW5imWrMSs0fQru+UV+XY8wfEW4FqVHcDliL4Zt+RDj
N8j4DZhjAYDXdIU3aMBDejysxyM6PKolohoCUhOQkoAUBCTDoxIsKsIiAjTM
R0JcOMiBg2w4wAQeh7hImIdFhDgkJhEphStipCoB/CYNybQpmbUk84OJoi1R
ssfAgZQ5meJVJ1Z1olUnUnXCFRDtFyq5gF+4SIcU3CgTdl3vehfj10lUnSTY
k+u0XKoJcseanjidN0HnSzZ8ybovWfMmrwmDLZos2Ij8IJZj/KZ1wG8wofTH
5d6YFIxgJyl2ECI7LrThApAV59MR/EGCR0dy6SgQIMxRpN9UZN5WZt5VZd9X
ZT9U5z7S5G5rcne1wCYtlKXLsX8pywJps/3aTL8m00ezTd9T0XLvKUGJPkW8
XxFjKWJsOcWRkyCunOQpCP7LlHQ8FR1XRXDUJFtDskBaql9H9etj/cZ4vznB
GkxxbGmeMyvwFAYCJXmkqkaaRrJtTY568pPhyizWWkyMrBWmtuoLe921o8nt
k/mDhyvH5xsPH+08uti7vDh48ujg6dnB09O9pyfbtN992u/Fxsz5yvjZYvd0
rvVgunYyWToezx+PZo9H0scjyePh5MlI78CbPAN4J9IXk9nL6dyTmcLTuRIt
d7H6Yqn+8XLjk5XmJyutT1aHPl1tf8L0MWil/WK5/Wxp6MlC63K++dLvMf1e
/l/eCLwzlAGbcK+dIUA4CwiD0Xx4Rbh03FPMBLbuo95NAIYyW43kWpWi3z+Y
g2dS4Ym4f5Rwd1Fw+B1sRkyNkKEe0NX82rpfUw9owAgeAit0xNCFjKOImZm/
1l/PX8ckaaf9otYObGlFTfWwAfgt+LQ5Dxi+PbyquEMdd2jiDm2CHsGGtMeY
9ZnzAQv9RFLYBjzWX/qlzbp6da4fgB/2CNMjGHJUo45f/IYYv8GXfl/iNWAh
PRbWYREtFtXgUTUOqXBIgUEyDJJgkBiNCpEIHw7zoDAHCrGjIVY0yBRig5/A
ER4SFaCwGEclJC6nKFUsro2n9ImMKZEzJwrArzVetsUqdpK5voRXHcwrppww
E1RxQoxfqEgHF9xw3o0woXk3lneB8IILECZK9Owmab8uquGKAbktd7zlSQx5
k0M+UKrlB6Wb/nTDn6r7UzVfjzC9txdtRAH4NcNZxm9KE0z2/MrclIQewT3C
hNBGJ+gFCFvJXjwrBeKCZOk35Om3FJl3lZn3ldkbquxNVfa2OntHDQZrtk+T
BU5BLE0a1K8GgQ051QfAXpu9p2CSx/voYv0yiiWj2DKSIyO5MoJHh/N7yTE6
BcYDKTGuEueocLYaZ2kIlpbo15H9evqqGjiVswYTHFuK68gI3DmRvyANl5Vw
TYe3zPGuIzPmL01FG/NkZzk9vl6a3W4u749sHE3tniwcnq6enG2ene88Ot+7
PN97crb35HT3ycn2k57fnYWLzZlHqxPnSyMP54dOZ+sPpioPJosn4/mTseyD
sTTodCz1cCx9tTPTYzcPxu6z+fLzhcrHS7VPlhufrjQ/Wx36bK392Xrn8/Xu
Zxvdz9aHQZ+uD3+y1n2x2n2+3Hm6OHQ533o02wB+HwC/Y9c34rh6C3B6qwlK
ga/brTTgvNfO7ndzAPjRSAFMamD2eKz33gfm7Q/D+f1OdqeV3qzHVyvkUgHt
Xbwap3wjuIt+6idqaYSN9aAe4K36NDWfuu5XNwKa3hG4GzWOwOYx1AL8ghFM
+6Wj/U6Q9jHa7+CV35ChHNAV6OVZnerhtatidOoYIOzUJdz6lMeY8ZlzAUvh
pV/I0aCFAqqMWdTVue4lYeYmG7TfGv36THspYiuErbkrv+ZE0BwLmkhw7AV4
meF7hZf2q8YgFQYpMViOwlIUliCQGIaEUJQPRbjRCCcSZofDrOvYkQgnGuVB
sABBxBgmwQk5GVNRCW0spY9njfG8OV4YjJWssbKNqtiJqh2vObAa47fmhGtO
iPEbLbuiJVcU+C24IcYvTTjnRkG/8usiK+CE64rV3fHmtdy2L9X2p9sBUKYd
pBsKZlrBTDOQpgl7mRFMr9C03zzjN3PtNyH3xmWemMRFXfntEX4lgY3sxaej
QDxp6g1Z+i15+h155j1F5oYyc1OZuaXM3Fal76p6s5XW2qcEJRitcdBdkDx2
lYzunozqk9L1SymWlGRLSY6U4EoJnhTn02FMKF9Gx5PTcRUoR4lxVBhbjbE0
OEtHsPQky0ixwFY/GOfYklxniu/OiPx5SagohypqrGGIDVnTw+7CRLA6gwwt
xEZWclMb1YWd9urB2Nb9mf2Txfunqw8ebp6dbT8627l8uPP4wc7j463HR+uM
38WLzdlHa5Pny6Nni52zuebDmdrpVPl0sng6kX84kXs4kT2byJ5PZoFccNrt
jV0g98Vi9ZPl+qerzc/Whj5fb3+x0f1ic/jLrZEvt0a/YPp8c/SzzdFP10c/
Xht5vtJ9utS5XBh6BP786To4yYIdGIxXMHx3ru9it9lI9gKKAeFdhvBBN3fY
I3yluAgeHI3kwc/32pntZnIDLM9lfBEsz5nI1PXy3IasYPgCvFW/tuJTV7wq
UNWnAoSbQQ0Ywf/jCg0CDyYI2xhmHQZ+IXMzYqyF9GX68KvJ0H5VwC/AS9Gp
KYcmBvy6DEmPMe0zZwODwG8pDDA6amA3hl1NxNUCVFF3G3V3XiWMMn4R5iY5
wC9kr0RtpYi1EB7MhSyZkCVF+zXFgsYrvzTeK79oVINCahRSobACheUIIkWQ
ARgWAZ5RiBeBuOEoGxSKsq5jhyFuBOZFESGMiRFCglFyPK4ikxoqradyxlje
HCtaqLKVqtjIqp2o2fG6A6s7kLoTRPutuaCqK1pxRctuqOh+6Rfg7fnF6BHs
Bn6Joossu6iqm8HrSbSAXG+q4093A5luMNsN5rohuk441w7lhkJZQLgBCNMj
mPZbuvabY/ym1a/4lbqpARcpfkn4l0hhL3svSgCSpF6Xpt6Upt+Wpd+Tpz+Q
pz+Upz9SpG4pUrcVyTuKxF35NVUZdUdG0knJ21Ki1x0JiLwrIe9JyD4J2S8h
WRKSLSE4EoIrIXgSHMSXYEwoHSAsRfgyhCen4ypRjgrlqDG2FmPrcLaBvjbO
NlMca4xjT3CdSb4nLfRnxaGCLFpWojUd1TQnO/bcqLc8GWnM4t3F5PhaYXar
vrTbXT+Y2Lk/e3CydHy6dnq6cXa69eh0+/LB1uXx5pXf3cXLrdmL9clHq2Pn
S93zhdbZXP1spno2XT6bLp5PFeindKevrjAzC3MZyP14qU7P3LXWF+vtLze7
gO1X26Nf7Yx9vTP+1c4E6MudiS+2Jz7fmvh0c/yT9bHnqyNPl7uXi+3zudbD
6QbwezRW3qefa86B4QvwbjSS6/XEei2xUU9s1hNgK95ppXaH0vvtzEEne9jN
HQHF14Fv9zuZ3VZqqxFfr5DLRXQhB82kQhMx+spzb/iCuVn16wDeskdV8ijL
HkXFo7wmrP3nEQzkgiYJenkexQaHEUsbMjXDxmpQX/Jp8x5Nhl6e6eEL8JJ0
atKhpZy6uMuQ8JhSPksmYM0HbcWwoxx1ViFXHXY3EXcLddN+MboO3ZXfNkqv
1oxf+z/5NaeCpkTQCPxSQQMBjr30yfdqc0ajPbxKFFEgiAxBJDAyACEiCBFE
EV4E5oZhTghmB2EWE3jACSHcMMqP4MIoIYYpKRKXY0kVntYQWT2ZN5JFM1Wy
kBUrWbUxeO1Yw4E2nAidi7n1jZu+1VXFA5U9UMkDF71wwYvk6dC8B8t7cFDB
QxQ9ZMlDVTzxmifR8CZb3lTbl+n4s8OB3HAoPxIGFUYihWGmbiTfDtOEm4zf
micOpjbwWxxEX/WbesXv9Qj+f4sSgRyUSJx8bSD1hiT1ljT1rjT1vix1Q5b6
UJb8SJb4SBa/JY3dklK3AVgJcUuC3xrAmNCPxOgtOgx0W4zdEeN3B/B7A0T/
AMEaINgDBGcA5w7gvAGcP4AJ6FAmRCBBBMDvS8JKhKdCuRqUq8W4epxjZC6P
g7O5LcZ1xHmuJN+bEvoz4lBeEi0q0IqarBsSQ4PZYVdxPFCbhtvz1OhyZmq9
PL/dWtkb2Tyc2r0/f3iyfPxg7fTBxtmDjUcnGxf31y+P1i73ly93Fy63Zy82
pi7Wxh4tDz9abD9aaD6aqz+arV7MVi5my5ezJfqJod5FKlpu7ZOVxmerrc8Z
uV9tjXy9M/rN7vg3exPf7E1+sz/1zf701/vTX+1Nf7k7/cXO1Gfbk59sTrxY
H3u6MnK52D0HK/pM83iydjhW3hsu7rRzW63MRu/+sbXEWjW+Xo1v1OJXhJsv
CWcOacVMnSz4dm8otdNMbNao1TK+lIfnmOE7zgxf+kUXYWMtoCv7NEBu0aUo
uuSgklte8ShqPmXDr26FtJ2Ifrh3CkYHe4RBEzg9fEdQSxc2D0WN4PhcCeiK
Pk3OrU67wPBVxuxK0qYiQHY1YdeSTn3MZYx7zEnfYDoAtl97IewoRV0VyF1D
3A3U00Q9LcwzhHnadDThNsbMXxTMX8e1X1slai1FBgthSy5kzoRM134NVMhA
hvREWPeLXzB8YRWKAL9yBJUhqARMVQgTRVFBBOWFUW4I5QRRNihAxwli3CDO
CxGCMCmKUANQXAonFWhahWU0eE5PFIxEyUxWLETVStRsRN2ONxxY04k1XWjT
jYAaHuYedF645oMrPrjsQ0p+pOhHC36s4APhBR9R8JFFL1XyxireOFiGG/Qh
N932Z7pAbjA/Gi6MRopj0RIdVBqFSiNQcTha7DCE6REMVmhwBHZR5Z5fE/Ab
yWpDaXUA+E3KvQmZJ37ll478p6j/nij5Z3Hy9YHUmwOptyXJdyXJ9yWJG5L4
h5LYTQl1c4C4OYDfFGM3xchNEQj+UAiBbtLBoI+EyC0hcluE3hVh90RYvwhn
iXCOCOeKcJ4Y54sxwVWoEDSACK8JC2SIQI7wlShfjfI1GF+H8Qw4z0TwLMzZ
3B7jOeN8T0LgSwkDaVE4OwAVZGhJRVZ18aY507YXRrzViUhrBhteSEys5Gc3
aks7nbX9se3D6f37C0fHyyfHq6fHa2fHa+f31x4drl7sL1/0/G5OXayPX6yO
XCx3L8BBdaF5udB4PF97Arp6Sqj2YqkO5H7KyP2Cljvck/vt/uR3B1PfHcx8
dzjLNPft4dw3B3Nf7c99uTf7+c7MJ1tTLzYmnq6OXSyNnM13Hsy07k/WD8Yq
9KcwtPObvc9PqSVWq+AkGwOtVWMM4fh2I7HTTO61Uvu04vQB0347tTeU3G0m
turUeoVYKSIL2ehMKjgZ847izg5Mb861gL7i0xTdyoJTnndImSQFp7Tkkl0R
Dqivt2iaMJjCYJEex6xj2OAoahmGze2oqRUx1IJgedYWvOqMW5VyKuN2JWVT
EjYlblPhNjVu1xJOPekyxjzmhG8wFbBlQo58xFmMusuwp4p46qi3gXlbmHeI
7orwr/3aG5CtFrVWIoOliKUQNudCJsavMRE0xGm/+iu/ES0e1WKQBoPVKML4
ReUIJkMwCYwPQLgoigsiOD8MqOIALCcAIkDcAMkLUvxgTBCKiyKJgWhSBqUV
SFaF5rRYQY+XjHjFTFQHiZqVaNjxpgNvOvGWC2u5sZYHbXnRlg9t+tFGAK0H
0FoQrQaxShArB/FSEC8GiWKQLAaoUiBWDsQrgUQtkAT7cIs+5Ga79Myl5Y5H
y+NQeQKugMaRyhhcGYXLI1CpGy20w3lwEG76U3VPouqkyjYc+C2YoJz+f/TL
EP4lN520FxjQ14FhLRMm/yRKviZOviFOvjWQeGcg8d5A/H0x9YGYvCHGb4iw
G0LkhhC+IYjeEEQ+4IPCoBt0kQ/5kZv86EcC6LYAviNE7gnRfiHKEmIcIcYV
YjwRxhdhAhEmFKF0YoQOEJYgQikilCNCBSpUoUINJtRhAgMuMBECCymwkvRW
74wJ3HGBNyEIJIWhtCiSHYDzUqyoICuaeN2Qbg3mu67yWKAxBXfmqLGlzNRa
aX6zubIzvLE/sXM4s3+0cHR/6eT+yun9lbOjlfPD5Uf7S8Dvxfbs5db05cbE
5drY5erw4+XO4+X2k6XW06Xms6Xm8+Xmi2X6wvKnq0OfMefcL6/lfrc/+ZeD
6b8cznx/NPf9/fnv7y98f7z4l/uL391f/OZo8evDhS8PFj7fm/tke/b55tST
tYmL5dGHC92TmaGjycb+WHWnW9ocyq83M2v11Eo1sVIBJ1kKtFqm1irURjW2
WYtv1+M7jcQurfhl4Fvwc/ALxGoJXcpBc+nQVNw3TriGUfsQ2JyDhh7evFOe
tUuytoGMVZy1iXO2gYJDUnJKK245INwMvDwI04s0OAuDRhAabydqGooYGiF9
NaBlhq8q7VQmHArKpiCsCtyqxKwq1KbG7FrcoSdcRspjjvmsyYA9HXJkw65C
1F2CPRXEW0N9dczXI8woBoPYTfeK3/pLv+GXfo2poCEJ/Ib0sZCeCuvIsI5g
/OKMXwz4RZUopkBwGYJLYWIAIkRRQhgh+WGSFyK5QZIboJhivECcH4gLgglh
KCUOpyWRjAzKKuC8Gilq0ZIeqxjxqhmvDxING9G0Ey0nMeTC2x687cXbfrwd
wNtBfIi+Nx3RjBCNCFGPkLUoWY1SlQgoVo7EK2FQohpO1kKpRijTCmXBVO3S
qzKYuUBuZRKuTiK1KbQ2yTSBVscQmnBvBA8Fs7/ya0HzRsavJpRWveqXIXyl
mHlwRdVLB3bsXgofkyDxB5pw4nVR4g1R/C1R7B0R9a6IeE+IvydE3xfA7/Oj
7/Mi7/FC73GDTAHQ+9zgB9zgDW7oQ174Ji9yix+9w4fuCeA+AcISoBwByhWg
PAHKF6ICISqkQ0QiRCRGRAOISIKIpKhIjoqUqEiNibW4WI+LTYTIQoqslMhO
iVwxoScu9MaF/oQwmBSFUyIoM4DkJFhBTpZU8aou3TDn2vbSiLc2ERnqjeDl
/Mx6dXFraHV3ZHN/cudg5uBw/uhw8eRw6fRw6exg6Xx/8dHu/MUO43dz8vH6
+JO10SfgrLrafbbaeb7aebHa/nit/ela57P1q8tTX++M9WYukPv90ewP9+d+
OF7468niX0+Wfniw/MODle9PVr47Wfn2eOXro+UvD5c+21v4eGfu2ebMY/oS
2djp/PD9mfbBRGN3tLrVLa0P5ejP7K4llyvxpTK1VCKXS8RKiVgtk2tlcqNC
bVap7Vpspx7bacR36cBj8BNys4KvldDlPLSQCc8k/BOUe4S+bDXYDBmrfm2J
xivL2iTpQXHKIgSlLcLMoDBnFRXsAz3C9SvC9CINzsLDkAnUhUydqHEoDPDq
agEt2MDzHlXGpUw6FDGbnLTK8UE5OqhABpWIVY3YtKhdjzmNhNtMea1xvz0Z
dKbDrlzUU4C8JcRXQX0vCTdpwmCXdreYe3rQF68QewO21SFrNTpYiVhKYXMh
ZMqFjNmQIU371SdovzraL/OCDQLS4rAGR9QYqsIwJYYrUOCXkMLkAEyKoxRY
jwXhGD8U4wXjdIEEL5DkB5KCYEoYTItCmYFwThrJy6MFJVRUw2UtWjFgNRNW
t+ANK96yE0MOou0i2h6y4yO7AbIbpLphqhuhOlGqDcXacGwIiTeReAMFJepI
ooYka3AKVIfSDSjThLJD0Vw7WuhCRbAkj9EDtzqF1KbR+jQGakzj9SmsPonV
xtEq7RcqdsKMX1+q7o5XHVTZihfNCO1X94pfhS/xC2E6wDZOdwU2AQLH5F6q
XoLE7wWJPwoTfxbGXxfG3hBSbwnJtwX4OwL0HT78Di/6Djf8Dif4DifwDtv/
DtsHepfpPbb/fU7gBid4kxv6iBe5zYve5UN9fJjFh9l8hMtHeHyEL0AEAkQI
uvYrHkDEElQsQwcU2IAKG9DgEj0hMZISCyWxUhJHbMAVH/DExb6EOJAQhZKi
SFIUTYnhtBjNSvC8jCoqExVtqm7MtazFrrs6GmxOwp1ZanQxPbVSnNuoL221
13ZGN/cmd/dnDg7mjg7mTw4WTvcXzvYWznfnHwG/2zOPt6aebE4+3Rh/tj72
fH30xfrIx+sjn26MfLY58vnm6Jf05anxb3YnmG35Su5fablLPz5Y/vF05cfT
1b+erv1wuvb96dp3D9a+OVn76v7qF4fLn+4vvdhZeLI5e7E29XBp/Hhu+HC6
vTfe2BqprreLq83cci29WEkslGILRXKhQCwW8KUCvlzEV4pAKLFeJjYr5FaV
bpuO2KqCn2DrJWQlDy1mwnPJwFTMM4Y7urC1FTbRx16P6hqvKGkWJEz8hJGX
NPFSZn7aIsi+StirbPrVQ/TlLF0nrG9HDO2wvhXSNYLaml9T9qkLHlXWpUg5
5HGbjLTKcIsMtchgsxyyKCCLCrJqYJsOcRgxlxn3DFI+ezzgTIZc6YgnB3kL
sA8QLqO+KlCMAcVgl/Y0MXcTdTVRgNfR6A1fxm85Yi6FTYWQ8dqvPhUCfnXx
kC4W1lERLfOCKy0BawhEjaMqnPGLEXKUlCKUBAYH25goGhdG4oJwgh9K8oMp
prQgmBEGs6Jgjr5aEi7IIkVFtKyCKhq4qkNqBrRhwpoWvGXt4SU7Hqrro4YD
sZFQfCQSH4ESI0hyBE0OY6kukeoQ6TaZHqLLtEBEtolnW3iuheWGsHwbLXTR
4jBaGkUrQCgYtVMM2xm8MYs3ZwgQINwAfukR3Ju/wG8gA/zW3PGKgyxZMdqv
IZrThTOa4Eu/zAimCSeu2SbkDFuFPwl+QRUApdRBOg2Tlp/4LU04/kdh/M9C
6jUB+YYAf5OPvsmD3+JG3uKE3uIE3mL732J532J53ur3vN3vBr3D8rzL8r7P
9n3A9n/ICX7EDd3mhu/yIn28aD8PYvMgDg/m8WA+HxbwYSFIAIuEiFgE/KID
UnRAjkmUuFRDSHWkzEjJLDGZNSZzxGWuhNSbkPqZD1kOJwciSTGUEiMpMZoe
wDMSMieLFRSJsjpV1WcblkLbURn21ccjQ9PY8Fx8fCk7vVqe32gsbXVowrsT
u3vTB3uzR3tzJ3tzp3tzZ7tzwO/Fzszj7eknW1PPtiafb058vDXxydbEp1vj
n29PfLEz8dXu5Nd7k9/uT4ND7l9oufNA7o8PlgDbnx6u/vRw7aez9R/PNv56
tvHDw83vH25+d7rxzcn6l/fXPjtc/Xhv+dnOwuXG3Nnq1Mni+NHs8N5Um75j
XreyOlRYqmcXqqn5UnyuQM7m8bkcNpdD53PoYh5dyqMrBXS1CKhiG6AyUwkF
rRXhlXx0KROeTwamY54JwjmCWNsRUyOoq3jV4MwL8KYsIiA3buDG9JyYng2K
GzhJEzdt5mcHhQWbuOSU0Iu0V9HwqcAgbgXpV3eAB3W/pupTl72qgluRdcpT
dlncKiUHJZhZgpgkkEkSMUkjJnnYrAxb1BGrNmo3wE4T6h7EvTbS74gFXcmw
Ox3xZiFvHvYVAWF6EHurKFinwYnYXUdcdcRZhx112F67Hr7lsLl45deQDepp
v0Fd8tpvLKKlGL8k45eg/apwxi9GylBKisQG4LgYSoiiSWEkJQinBaGMIJQV
BHPCYF4UKohDxYFQSRouyyIVRbSqgmoauK5DGga0ZcaGBvG2jeg4ya6bGvbG
RgLx0VBiLJoag9NjaHocz4yR2bFYbjSeG03kR5L54WShmyx0EqBiJ17sxIod
qtQly8NkeZSojBHVCbw2idcBVQB2lmjO0bVmab9N8MMp4Bdh5m+k2AnlWv50
w5usuWIVG1GygMMvnNNHs9pwRn3lN8X4pQm/DPyEkZsCv6AKpsFvgmGtCWW0
oQyAD9LzE/8hAITjvxfE/iig/iQgXuNjr/Pg17nRNzjhN9iBN1i+N1ieN/rd
b/a73uwDOd/qc73d73qn3/0ey/sB2/ch23+TE7zFDd3hhu9xI/3cCIsb5XCj
XG6Ux4P4PEjAhxi/8LVfTKLApSpCpiXlBkpujimscYUjoXAnFd6kIpCSh1Ky
SEoaTUnglARJDWAAb3qAyEionDSelydLqnRFl62b8i1bqcOM4Am4PUOOzCcn
lvLTq5X59ebyZmdte2RzZ3x3d+pgd/r+7szJ7uzD3dnzXeB39vHOzNOdmec7
0x/vTH+yM/3ZzvQXu9Nf7k1/vT/zzcHst4dzfzmiT7g/nCyCgfsTI/dvZ+t/
O9/42/nmT+dboL+eb/1wtvWXh1vfnm5+dbLx+f31Tw5Wn+8uP95aOF+ffbA8
dTQ/tjc9vD0xtD5SX2mXFxv5+Wp6tpSYLlDTOWIqi01n6Hunz2aguQy0kIUW
s/ByDlCFV/PwWoEpD63moyu5yFImNJ/0z8Q8k4RzFLV1ouZmUA/clVzynF2S
ZvDGDBxSxyK1/YSmH3yldKy4np00ctJmXnZQkLeJiw5J2SWr0oqVdD5V1aus
eJQltyLvkmcd0pRNEh8cIM1izCSCjaKoQRTWi4P6gaBBGjDKAyZl0KIJWXUR
uxFymhG3FfPaCb8TEE6EPamINxP1MoPYW0S8ZQSciN2gKuyqwo4qbK9Ctipz
8u0N32LImA8ZcsFf+aVHcFgL/MaiWgrSUrCGRNQkqiYwFUEocVKBUTIsJkXj
EiQxANN/sYuiaWEkKwznhGFarihUFIfKA+GKJFyVRWrySF0ZrauhhgZu6pGW
ER0y4x0r0bWTwy5qxBMf9SfGQqnxaHoCyU5guUkyPxkrTCaKk6nSRKY8ka2M
ZytjucpYtjoKylRH09XRVHU0WRtL1MbitYlYfTJWn6IaM1RzlmzOkS3QPPN1
jmzO0n7rYC6Pg/NvtNQN59tXy3Pin5dn2q8ykFIwfmnCTMxj+ofKANAN5GbA
b2pCwHtWFwanZjoDiJ/8jSDxn4L4bwWx3wvIP/DxP/KRP/GgP3PDr7GDr7F8
r/V7Xu93v97nfL3P8Uaf402mt/qc7/S73mO532d5b7B9Nzn+W5zgHU7wLifU
xwn3c8JsTpjDiXC5ER43yudFGcKQSAQDvxIZJlXgMjUp11MKU1w5mFDZkyp3
SuWl/z9VobQymlZAaTmSlqFpKZ6WEOkBMj1AZSSxrDQB/BaV6bImWzPkG5Zi
bwSPhVtTKNiiRxbSE0uFK8Ib7bWtka3tsd2dycOdqeOd6dPdmTPgd3f2ye7s
s93ZF7tzn+zNfbY398X+3FcH818fzn97tPDd/cXvj5d+OFn+6wN6T/7pbA3I
/fl88+dHW6C/Pdr+6dHOj492/nq+8/3ZzrcPt79+sPXF8eanh+vP91cf7yyd
byw8WJ05Wpzcmx3dmuysjTaXO9WFZnG2lp0uJScLsYksMZ5Gx1PweJK+cfpk
MjKdjMymInPpyEI6spgBWiPLWaZMeCkdWkwF5hO+Ht4x1NaFzEMhQ92nKQN3
dkkGrM0Ar55Dalm4ug9T3QXhqruE+h6p7YvpWAkDJ2XiZSwC5jhMKwbrNIBc
csmKLlnBKaX/BrANJAfFMYuIMAlRgwDS88M6flAr8GsEPq3IqxV7dRKvXu4z
Kv1mTWBQH7IZI04L5LaiXjvud5JBVzzkToY9YJfORsE6DU7E7iLkKtE5y5Cj
HLWVo9Yyc9mZ/pCFED18Gb/6DO1X99JvIqyNM35jjF8K0VCommT8EqQCp+RY
TIYlpGiS/lsdzoihrDiaE0UKokhRHC6Jw5WBcFUSrkkjdVmkoYg2lVBLDbW0
8JAebRuxjhnvWslhBzXiio96E2OB1HgkMwHnJrHCFFmajpenU9WZTG0mV58u
NKaLjelSc6rUnGSaKDYnCs2JXHMi25zMNKfSzalUczrRmkm0ZuOtuVhrnroO
+AXzF29MY7VJpDIGlUYihU4wNwSGrydZczLDdxD7ZfheH357fl8JyPWnabxB
ADzLyM1pw3ldJK+PFAxROmO0YBIk/02Q+I0w/h8C6rcC4nd87A88+I/c6B85
oT+x/X9ief/c7/5zn/O1Psdr9+yv37O/cc/+Zp/9rT7HO/3Od2m/nhts7022
7xbHf5sTuMsJ3uME+zhBFifE5oQ4nBCXE+ZxIzThnl8J41dJyLWUwhBXWRJq
W0rjSmu8GU0gqwlnNdGsGs6q0KwCy8iJjIzMSKm0JJaRxDOSRFaazMlSBUW6
pM5UdLm6qcCM4MpIoD4ebU1hndnYFeGVyvxaAxBe3xze3hrb25442pk62Zlm
/M492Zt7vjf/8f7CpwcLXxwufnW09M39pW+Pl/9ysvLDA3C2Xf2R2ZPBwP35
0ebPF1s/X2z/fLHz88Xu3y52f7rY/euj3e/Pd797uPP16fYXx1ufHm083197
vLNyvrn4YG3uaGlqb258c2p4dbS12KnNNUvTtdxEKTWWj41kiOEUOpyAhulP
KqE/N3MsFhyPBSfjgel4cCYRnEsG55PBBbrAQtIP5M7FvTOUe4pwjKPWYcjc
Dhsafk3FrSw6pNlf8Pbj6nuo8g6iuA1CFbcx5W2gmNTci+n6E3p2ytjbpWnF
OZs4z1ygztrEaasoOSiKm4WkkY8ZeLCOG9FyQmqOX8XxKjluJdel5DlVAqda
5NRInDqZ26D0mDQ+iy5gM4Yc5ohrEPbYUJ8DDGKKVgzWaXAidmUirmzEmY84
ChF7IWIrRqzFyGAxbCkyl60YvMbe8O35pQmHGMJhXSKijUe1cUgbg7Uxxi+F
qUhCSZIKgn4xFeM3JUXTEiQ7AOcGoII4WhRHywPRykCkJonUpZGGLNqUR1uK
6JAKaqvhthbp6NGuERu2ECNWasQRG3UnxnypiVBmMpqfQovTZHkmXp1N1eey
zblCa640NFdpz1U7c7XObL07W+vOgKqdmUpnptSZKbZn8u2ZXHs2055LD80l
h+YTQ/PxoYXY0MI13lmwTmO1KaQ6DpVHI4VuKNf2Z5reZN0Vr9jJ0iBeMCM5
A5TVRWi84CT7z35puTTejCqYZfDScrWRgi5S0EeLhmjJAJWMUMkElczC1L8I
k/8mjP9GSP2HgPgtH/0dD/49N/IHTvAPbN8fWZ4/9bv+1Of4c5/9tT776322
N/oYv/09v6732W7aL8f3Ecd3m+O/w/HfZQfusQN97EA/O8BmBzmcIJcb4vHC
fEFUKILEEkQix6QqUq6LKU0J9WBK40hrPVmdP6cL5XTRvBbJa7CcGs+pyKyC
yspjGVk8I6XxZiTJnt+8PF1UZcpaMIJz4BQ85Ch1PZXRYH0Cak3jndn4yHwG
EJ5ZqSysNlbW2xubwztbYwfbE2AEP9ydudibe7K/8Pxg8ZPDpc+Plr+8v/LN
8ep3J2t/OV3/4eE6ONj+dL75N3ra0mb/fgna/fvl3s9MP13s/fho7weA92z3
m9OdL04A3s3nB+uPdwHepQdr84dL07tz4xtTwyujQwud+kyzPFHNjRZT3Vys
ncaHEkgrFm2RoRbzMSVt5tMzhwnvKOEdJ70TlHeK8k7HvDO9KA+QO004J3H7
GGIdiZrbIUPTr6mBpRfMTasYkATnXBqv6h4wC8tvwbKPINlNWHYTkX+EKm7h
yjuE+i6l7Yszgzhp5KaYS1spiyBlFiTM/JiJRxp4uJ6DaNlRDSuk6vcr+r3y
PpeszyHrt0lZVil7UMYdlPMHFUKrasCmkdp1CqdR7TbrvIOGgM0UclgiLiuj
GMxiBxUAh2JHIuRIhezpkD0TtmXD1lx4MB+y5ENmJlM+SON9xa/+pd8k7VeX
iF4TRjQx2q+awlUkqSQpBRGX4wkZBvxmpGhWguQH4OIAVB6AKhKoJonWpdGm
LNqSQUNyqK2EOiq4o0a6WrSrx4aN+IiFHLXGRh3xMU9q3J+ZDOem4OI0Xp6h
anPJxny2NV9oL5S7i9XhxcbIYnN0sTW2wDTfGp1vjM7XR+ZrI/OV4fnS8Hyh
O5/rLGQ7C+n2QnJogfbbWqCa80RjDq8zeCsTUGksUhhm8LYYvFWA1wrw0k8b
ZfWRjDb8P+HtjV1/5hpvTh3Ka8IFbaSoixb10ZIeKhugshGqmOibw1fM4vT/
ESf/VRT/NxH1GyHxHwL0P/nQb3nh33EDv2f7/sBy/5Hl/FO/48/9wK/t9X7b
G/32N/vtb7Mc77Cc77Fd73PcNziemxwv8HuLJuy7w/bdZfvusX19bF8/288C
igFhXogniAhEkEiCDCgwKb08x5TmpNqW1rqyOl9OHwJ/sRT0cEGPFXREQUPm
1bGcMp5TJLJyeuxmQJJUVprKSWm/BWVvBINTcK5pLbSdpWFfZSxUm4Cb08QV
4cXC7HJ1cbW5tt7Z2hzZ3xq/vzNF+92ff3qw+OJw+dP7K18cr339YP3b043v
H26C8+yP5/R6DIbsz8Ds471/PN7/xxO6vz8++Pnxwd8u93+82P/h0d5fGLxf
nmzTePfXweQ921w6WZ0/WJzenp1YnxxZGh2abdcnG6XRSq5bSA1lqEYSq8Wg
KhGuYIEK6qsgnirsrsMu5pX/9FvtuqhzBHOOYa5x3EXfqJnOMYHZx1HbGDw4
HDV1QvoWg7fslIEBmgEADVyqN3kBXiBXejMq+TAquQGCpB/2FDOD+A4YxBSz
TveuboHDMqXnEDo2pmUhmv6oqi+svBeQ3/VK77gkt+0Dt63i2xbRbZPojlF0
zyDuMwywDBKuUcY3KURmlWRQI7fplQ6jxsUo9tOKmVnsHkS9VtxnJf3WmN+a
CFiTgcEU8ybBTNCcpTPRn5BCB/AaMr/41QO/KcbvL4QhbRzWXBGm7wHL+I3J
iYQcT8mwjBTLSdGCBClJkIoErkrhuhRuyuCWDB6Sw20F3FHCXRXS1SDDWnRE
j48YiVELBfyOOZLjnvSEPzsZLkzD5RmiNhtvzKeHFvKdxdLwUnV0qTG+3JpY
bk8ud65aak8uDU0stsYXG2OLtdHFygj4zcVCdzHXWUy3F2m/DF6SwYtWwR87
GS2OhfMjwWzHl255knVnDOB9eex9FS99VVnhf+W0+wpe1TVeTaSojZR00bKe
/kCligGqGuGqCa6BzAOZ/z2Q+peBxL+KqX8XEb8Rov8hgP6TH/4dL/B7jvcP
bPcf2c4/sRx/ZtlfY9lfZ9nfYNnfYjveZjvf5bje47o/4HpucD03ed6PuN5b
XO9tDt0dtvcu0z22Fyhmcf1sXpArCPPFUaEUESsxqYaUG8HJFwzfjNaT0wcK
hnDRAJcMaMlAlPRUURsraOJ5VSKvTObkqayMlksnYfyCFVqeYk7B6Zo+0zBn
W7Z8x1Uc9pXHwrUJhCGcGJ3PTi0W51dqK2utzY3u3tYY8Hu6N3uxv/D0cOnj
+6ufn6x/9WDj24dbfznb+eHR7o8Xe0Doz4/3//7k4B+gp4f/9fTwH0x/f3L4
8+PDny4P/vpo/y9ne9+c7v4K78bi8erc/uL01sz46sTwwsjQ9FBtrF7slrKt
XKKWIssxpEhE8mgwB/uyUXcu7MyF7PmQrRiyMu+Ct9Yj1mbUOgRZO5BtGLaN
wLZR2EoHDYKx240Y2wzeukdVAedWsPpahCkjD0xVUn0PA2uzHOD9MDJwIzLw
QVj8PvgK6ilG5DfBIO4pxtV3AXZc04dp+lB1H6y6F1XeDcnvBGS3vZJbLvFN
u+jmoOBDE/+GgfehjvehhntTzftIxbut4t9VCfvUIrZmgKuTCvQKsVEltWjk
Vr3Kzij2DOr9YKO2myJOE+Qyo24z7jGTXjNF3xvHnPCbkn5TKmBMB4wZOsNV
13h7TyH9yu/VFq2JwWpmBDN+SQUZUwC/REqGZ2RYToYVpGhJilakSE2GNGRI
S44MyZG2Aukoka4SGVahwxp0RIsBv6NGctRMjVnj48CvOzPhz0+FS9NwZYao
z8Vb85nOYmFkqTy2XJ9YaU2ttKdXujOrw3QroO70SmdqeWiSdl0fp42XR5YK
wz2/C8nWQgzgrc/htRm0Mg2XJiOFsVBuJJDpeFMtd7zhoKo2okyfea/W5rQm
lFIHk1d4fS97eebNqAJXeNUMXk2kpI2WdVBFB1X1UM0Ag+pGuG6C62Zp9n9J
0/9HkvyXgdi/iYl/F6G/EUL/KQj/lh/4Hc/3e677jxzXnziOP3Mcr3Mcb3Ac
b3Idb3Od7/Bc7/Hc7/M9N/ieD/nem3zvR3zvLR7dba7nNsdzB8T23GV77nG8
fVwfix9gC0O8gahABotVuERHyU0JpTWtoYdvXh+iV3ojUjbiZQNZNsRKukRR
myyoU3llKqdI5WTprDR95feKcLKoSJZVKfq5YEO6ackM2XMdd2HEXx6L1CfQ
1jQ1PJuaWMjPLlWWVpsb653drdGjncmHwO/BwrOjlU9O1r443fz64fZ357s/
XOz/eHnwt8eHPz85+sfTo388u/9fVx2Dr/94ev/vT47AP/3x4uD78/1vH76C
d5vGe39lbm9+anN6bHm8O9dtTjarw9XCUCFdy8RKcTxPQBkklIz6wPEwHrCD
wRT3WuJeU9JD3z014zXmffRn8FUCplrQ1AiZW2HzUNjcjpg7YRMI7MxDQV3z
Cq+8ZJfkB0VpEx+cailNHzjkovJbzOS9ERZ/EBa9HxK9FwbRit+PSj6ApDfA
IIblHyHyW4jiFgwmteI2pLgdkd8OyW4FJB95B266RDfsgg8Gee+buO/p2e9q
WO+q+t9V9L8r739P2v++tP+GhHVTyrkl5d6R8fsUQrZqgKeRCnRysUElNWvk
gzql3aB2mTQei85v1Qdt+ojDADkNiMuAuQ2Ex0Ax94ZN+AxJn4H+hBS/gf6c
o4Ce7ur6M1NIf7VCvzwFRxm/iJpCVRSuJAlFb4UmUnI8I8dpvzKsLMOqMrQu
R5tytCVH2wq0o0C7SpTGq0JH1NiIFh/VEaMGctQUGxtMjNtT4+7shC8/Sfut
zeDNuXh7Pg3m6ehSBfCcWmlNr3ZmV7uzayNzoNWRWRoyINwG/2hyGUzn6thS
CfjtLmbbC6nWAhjfZH0Wq84g5SmoOBHOjwWzI/50x5NouWINO1m1YiUzUmBe
akWPXc3V2E30Xq1xXc/vy+GbUwG8oYI6TOPVRMvaaEULVXVQTQfV9XDdADeM
TCZ57n/JM/9blvoXafxfJeS/D6C/EUP/KQr/Vhj8ncD3B77njzzXn3nO13jO
N3jON/nOt/mudwTu9wTu94WeG0LvhyLfTZHvI5HvltB3S+C9xffc4nlu89y3
uXR3uO67XM89nrdP4GeJghxJhC+HRWp8QE/JzAmlPa1253T+gj5cMsIVI1Yx
khVjrGKIl/XJkjZV1KQKqnRekc7J0wzhnt8kKC9NFOSJkiJRUSdqumTDmGoN
ZtqOXNdTHAlWxqONSawzEx+bz0wvlhZX6uvr7d1Nxu/+3OXh0vPj1U8fbHz5
cPvb873vLw5+fHz0tyf3f352/I/nJ/8FevHg/+rFfPuPZ8c/P7n/0+XRD48O
vnu499WDnc+Otl708K4v3l+e3Zuf3JgaXRrtzLQbY/Vyp5Rr5JLlJJkjkRQa
iUX9RNCN+eyI24I4jbBDj9i1qE2D2dQE/b5adcJJ36km59YWvLqyT1/16+sB
QyNgaAb0TeZ+7A0fWJsBXkXJIS1YxVmzIGXkXg1fxW0EbM6SD3uTF+ANCd8N
id6lFYt7iulBHJV+CIr832zdBZMd57ku7D/znZ04ZouHcTFz0+rFzMzMzDRr
UNKMmJlZFtnJduIkhvD+H+ftXiPF2d+pumtqNLarVGVdup+n++3VsmUQv2zZ
K11yS5ac4kWbcN7MnzNwZ7XsGRVrCmccQ2nHIOpRKeWomHJUSDkmoEwJKDN8
6pyAviBgLAlZq2IOVcpjQEI2IuZhUoECFqtQqVYOGRSIWY3aNJhDJ3cbcJ9R
ETArQhZl1KqM2ZQJuzLlUKadqoxLlXWpcm5VHsRD5r3fHOFXRV6FJm4kZQJ4
GvgNyVNhLBXBkjE0GX/vNwcnCsAvHK/C8QYca8GxDhzrIbEBEhuisREaW0Nj
Yyy2DgL84vF1RWJDldzQpDf02U1Tfsta2nZWd7yAW/tErLebHu7lx6crm2ca
2+fax8/3Tp4fAr97F8eEX/D1wnj3wujkBeC3R/TvuebG2RpRvqcL/VPZ7l6q
vRtvnojUjwer277SprswduZGtkzfkuwY4y19tK4NV9+f0/ggN0M+avQhhF+Y
2H8nfksTv5i/Kg/U5YEGHmzioZYi1FaEOsCvMtxVhUB66lBPg1b/P7T0X0j+
13DmIyj5sSz2iTT8mTjwudj7pcj9ldB5UOg4LLQfEdqOCW3TIvuMyDEndsxL
nIsS4lXCy1L3itS9KiFCEbsoIueq0LEqsK/y7RS+DUCm8h00gZMucjMlXjYU
4KFhoSIu0aQgQw6xFOXOisILtvKGJkIcT9WmWppMS51tqvINZb6OF2oYsepW
SL9lwm+O9JutSDNVWaYGZxpopiXPdJTZrjbfNxZH1srYVd8gpujBidTGbv74
6erpc+1LFwfAL7H/3tp7effc2weXfvf46h+e3vjT89s/vrz7l1f3//b6wT/e
Pvzn20f/evf4fR796+2jf755+PdXD4Dun57f+fOTW394eON3966+u3Xp6+vn
n146cx/g3du5vLN+Zn14YtDZaNcH1VKrkK2k4/lYKB3yxr2OsNMcsOm9JrXH
oHDrMLcW8Whgrwbya2RBrSyiI046pYxI1oQWLFjJJq/a8bpD0XQqWk5F2wnk
ylv2CV6oapKWDaKilp9Tc9IKZgL7T7+i9373CU8UzxORLPgkC17Jgke84BYv
OEXzdsGchT9r5M7o2FMq5jGcfgSlHpatHpIsHxQuHeQvHuAuHmQvHmQtHmIt
HmEuHWMtT7NWZ9nUeS59ic9cFbJpYh5DKmDDYi6hGBKpUIlWLjUoILMKtmkQ
pw716DGfUR40ycNmPGrF4zZF0q4gFSszLmXWTSjOeUCI88854Nf73u/kRrAf
TwfwVFCeCmHJMJqMEu8TTCTfr8DAb4n0W0fiLSTeQeI9ND5A40M0DvCuYYRf
grA8TkSRWFem1tXpDW12w5DfNJc27ZVtNxh0W8cjvZPJ4W52fKq0cbq2faZ5
/Gzn5Ln+7vnh3oXRHlAMihjgJSbq/fLdOAuW38rodLF/KtfdTbVOxhvHw9Wd
QHnLW9xw5cb2zNCS6pviHX20qQUrYbCi9JeIE1buHEoUbgZ2pKHJqeb9EH4h
4tgG4Rch/aLeCuarYv4aBvwSrw9uyUNtnEgHD3UVoa4y1AMhCMtr/0de/i+s
+Gs0+xsk9TEc/xSKfCYLfiH1fSXxHJS4DkmcRySOYxLHtNQxK3XOyVwLkHsR
9izDnhXYu4p4ydeieamQhypzU6QuisRJETtWRfZVoZ1CxEEVOekSN0PmYyMB
rjwiUMXFurTMlENsJcxVVfjqxEoebWkSbU26rcm21bmWKt9UFgi/8g9+wdhM
4pVky5JMRZKuSlM1WaoOp5poqo2nO+psT5cfmEtr9tq6p7UV6h9PrO/mjp+u
nD7Xugj8Xt24d+P4k9unvr53/t3Dy//95Pr3z2/98PLuz6/u/xUgffv4n++e
/OsbIv9DBhAGnP/x5uHfXj34+cW9H57d/uPjm9/dv/bN7cuvrl94dvnMg3O7
t0i8Z8HC22+vN2v9SrGRS5eSsUwkEPe7Qy6rz2ZwmdR2HW5VIxaFzIxLzHKR
BRPaMIFdLnDhAq9CGFCJwhpJXCdLGaCsCSmY0bIVq9rkNZu8bpc3bFjDhtYt
cM0sqxjB5jsZnv9ffif9K5r9X4S9ZDyiObdozimcswtmrfwZE3daz57SMI8q
6IcxyiFo5YBk6Svh4pe8+S/Yc58zZz+nz3xOm/mCOvMlZfYryuxByvxh6sJR
2tIUfWWWSVlg05Z4zFXBfyjmKyChBhXr5RKTQmpVQQ4N7NLCXj3iN6IhExax
yGNWPGHHkw7FhHDGrQKKs/t+1VkixEHoDHEWS5H24Sm/PBXAkkGM+PCrMJKI
IvE4HCfuIsFxMEKXkHgFIfw20UQHTRB+sfgQi4+w+BoWH3+IPEFEkRwr02N1
Zl2XWzcWN6zlTUdty9vcDnaOx8C2NTqZX98rb56qbZ9uHj/TOXG2BxSfPDcA
OXGuf/xcb/ssufmeqYOmHp4q9vdynZOp5olYfSdc2fYXNz35dUdmzZoamBM9
Q7StDTfVwZrCX5F7S5i7gACeoGeBVhv5YJH1fYhfZmT2LOQg/MLAr6eIesuo
r4L6q1gA+G1gwSYWIvzKQ8RxFOJECpGeIkhEqaz/H0X1V3jpI3nuN1j6EzT+
GRL5HA59CfkPQN5DkPsI5DoGuaZh1yzimkfcC6hnCfOuyH2rcj8F91NxPw1E
7qdhPhrqpSFuKuyiyJwUmYMincRJlblokIeB+FjyIFcZ4WsSIkNaasnDjhLm
Aet5QxluqeNtTbKjSXd+4beBF+ryQg0tVGHimtUHvGVxuiJOVSXJmjRRhxIN
JNmSpzrKdFeTIyrYVh27m5vB3k58fDJ7/HQZ+L1E+r1/48TTO6df3b/wzaOr
3z29+ccXd378+v5fXj/829vH/3j39F/fPP3Xt8/+hwj5/bsn/3j76O+vH/7l
6/s/Pb/7pye3fv/g+m/vXHlz48Jz4oXCe7dP7Vzd2Ti3PjzZb28AvOVCI5sq
JqLpkD/qdfrtZrdZZ9MpzSpUL5dpEZEG4qtlXI2UrZWydFKWQcYyQ2wbwnFi
PC8uCCpFUY0koZNlDHDOhBSBYgtWAZCtaM2KVC1wxSQr/9svN61gJfYvXq2G
yf03IP4FYTJeMh7RrFs46xLOOgQzNv6MhTtt5EzpWEfVjCM49RCyekC2/JVo
8Qv+3Ofs2U8Z05/Qpj6hHPtk5egny0c/WTr66eLRzxaPfbE49dXSzMHlucOr
C8coS9O0lTlCMX2Zx6QIOTQJOVGjYi4u46lggRYVGeRis0JiU0mdGplHB/kM
SNCIhs1Y1CqP2/CEQ5FyKtMuFSCc8agB4ex7vxkiyrRXkfLhSZ886ccSATQe
ROIhJB6B4zE4noTjaTieQ+JFwm+ijiYIv1iihyX6WGKIJUZYYo0kvIa+D/iJ
PLmGp9aU6TV1dk2XHxtL69bKhrO+6QN/1Xe3Y4PjqdGJ3PhkaWOvunWqsX26
tXO6vXOmA7J9pr11urVxurF+qra2Vx7sFnons+0TqcZOrLYdKm/6Cuvu7Jo9
PbQk+sZoVwf+MAcbSrC6esqoqwhUQvYsQCqxpiWWlNiSFJvfx5ICPwT/SGrP
yhw5aN9vCdn3W0MDdTS47xcLtbFQBwt1J5EHieCBLq5u/peq9mtl+TeK/Md4
5lN54nMs+iUWPoAGDqG+I6j3GOqZxjyzcs887l1UeJeV/hVVgKIOUtVBmjpE
V4cYRIIMVYCh9NNx3y9fXToJDXXTMS8DD7CUIa4mxtcnReaM1FaAXeD3WcND
DWW0pUq01amOJtPR5DrqfFuVb038YsBvnvSbq0gneFNlcbIiSlTF8ZokXpfG
G1C8hSbaeKqrzvb1haGlQtxLCvR2YuuE38qZc63Ll4Y3r20+uHny2d0zrx9c
+u2Ta79/futPL+/99PrhX98+/vu7p//85tm/vn3+P2SAYuAX1PHf3zz6K1m+
f356+/tH5OR88+LLq2efXNi7d/r49RMbFzaGe4POVqs+qBSb2XQpHk0H/RGP
02czO41ai0ahV8AaVKKQ8eViNiZkYgI6xqfK+VSFgKoSUrUimkHCsMhYdoTj
kfMDCmFETRRxGhA2EkVcsgDFaAXEDJdNUNkoLerFBa0gp+allewkziSuX00q
WEbcOZq0MNh8J4r3/QK8ghkCL2/awp0yso8ReOmHcepBgFe69KVw4XPu7Kes
6U/oxz6mHP3N8uGPFg9/tHDoo7lDv5kl8sns4U9nj3w+d+zL+akDizOHlueO
ri5MUZdn6avzLNoSl7EiYFPFXLpMwEREbLmEo4J4WoRvwIRmXGRTih1qqVsr
8+mhgBEJmdGIBYsBwnZF0qlMuVRpkvB+vKo0EWXKq0h68YRXnvBhcT8aCyCx
IBwLw7EoTByETsGxLBIvIPEymqgBv1iijSW7WLIv3/dLEJ7IReKjSVDwj5JD
eWqoyAzV2aGuMDKW1qzVsbO+7m1thDqbsf52criTXTteGJ8ob5ysbuzWNnbr
G3v19b3aeLe6tlseniz2T+Q7xzOtnUR9O1rZDBbXvbk1V3poS/ZNsa4+3NYE
m0pfXe6poK4S7CjIbDmJNSu2pEXmlNCUFBoTHyIyAQUpkjCw8MFvceIX8VU/
+EVDTTTUQkNtNNQh0yUS7GIgga5c2/qVpv6RuvKxqvCpMvuZIvmFIvYVHjmE
B4/ggWMK37TCN6v0zat8i2r/siawqgtS9SGaIcwwRJjGKAvEEGGD6MMsXYip
DTDVfobKR1d66QoPjQxd4aUr/Ux1kK2NcA1xPvGEYE7qLELeCvgdysNNRayt
SnbUxAzcUec6KtKvotAk/OZJv8QFK7DzliX7eCuieFUUq4ljdSlxBbKJAL/J
rirzC7/9nTjwe+J05ez59pXLo9vXth7e2n1x79zbR5d/9/TG9y/u/PDq/s9v
Hv0N9Ow3z/4J2P72+f/8FuAl/P7z3dN/vH38t9cPf355/8dndyaT87e3L72+
du7ZpVMPzp64dXLr8tbamVHveKexVi2185lKIpYJBaIel5/Ea1YrdDisgsVy
CQ8RsmQ8mpRDkbJXpKxliLUEs5cxzjLOW1ULqDox3SwFhLluuSCgFEU00oQO
ShuQHNiIzVjJgpUJxUiZICwrGSQFvSinEWRU3BRRwYw4+r8JByTEzusTT8Zm
onydghk7f9rKnTJxjumJ5j2soB5E/wPvx7Rjv1k98tHSoV8vHPz13IFfzRz4
9fSBX08d+GjqwG+mDn48dejT6cOfzxz9cm7qwMLMoaW5oysLU5QlkjB1kctY
FrAoYi5NxqcjQqZcwlbKOBqYp0f5JrnQqhA5VGKXRurVQX4DHDIRhKM2PO5Q
JJzKpEuVcqvTnklUICmPMulRJDzALxb3ojEfEvXD0QAcDcHRCBSNw1HSb2zf
L5ZoYMm2PNmVA7/JgTxJEEZBSLZwfAjHQAZwHKSPgI5O9vF0X5Xta/MDY3Fo
rQwdtZGnMQ601yPdjXh/MzXYyg6386Odwuh4EWR4vDg4Xujt5Do7mdZ2qrEV
r26ES+uB/JonM3Qm+9Z41xhpa4NNlb+Oe6qoqww7ijJbXmLJgp4SmlICY5Jv
SPD1IHEyCYEBEE4K9wmTfu3AL2i0Ikz4rSD+KkI8P1VHQk0k1ELCIG0k3CES
IhPsIIEOCqJvf6RrfKytfqIpfqbOfqFOfaWKH1RFj6jCx9TBaXVgVhOY1waW
9IEVQ5BiDNHMEbolyrTGWLY4h0iCa4tzrSAxrjnKMYXZxhDLEGTqA0ydn6Gd
BHwPfhjhGGNcS1Jgy4iceamnBPmraKguj7YUibYy1VFluqpsR0X6VQK/+aY8
38BydSRXg7NVWaYiTVXe462IYlVRtCaO1iXRhgz4jRP/B/f9Vseu1mZwcDy+
uZs7eaZ2/kL32pW1uzd2Ht859fX9C+8eX/3u2c0/vrz7I5iNQfl+8/QfBN4X
+/n2+T/BT94++dvrR3/5+sGP5OT8h4fXf3f38tsbF15eOfP4/Mm7e9vXd8YX
xv3dXmuzUekXc/V0ohAJJXyeoMPqMuktGqUeR1SwBJPwIQFLwqGJWCtCxpKA
viCkz4vo8xLGgoy5iLCX5dxVlYCqFzPMMo4D5XtwUVAljWqhpAHJmLC8WV60
yEtWOdiIQQuThCGCsA4Q5v9vwvAKGKRDxBGOhf11mCC875cs32MG9lEt84iS
dgijHICWvxQvfM6f+4xs3n288wd/NXvgV9Nf/Wrqy18d+/LXR78C+ejogY+P
Hfxk6tBn00e+mDn61dzUwYWZw0tzx1YXp0ELM4gWnhBeFXOpJGGGXMxSStka
iKNHeCaMb1UI7QRhiUcnA4SDJjRMEo69J5x0E4pTBF5V0qNMeBRxjzzuwWIe
NOpFIj44EoAiIYj4FKwYFE3C0QwSyyPxEpqoAr/y/+13CNoWAXLjQyg2kMX6
smhfGu3JYl1ZrAPHwbLcIRYuYtjrGgo9c6lnr/TdtaGvMQq21iLtcbyznuxu
pLqbaZDOZrq9mWpuJusb8ep6pDwOFka+7NCd6tvjXXO0bQg1Nf660lvFXGWE
kFuQWHIiU0ZgTPMNKZ4+ydUluOSrT8BXri7O000IgzpOiUxp4Fdiy0rteZmz
ALmBX1C+E791JNgg/BJ4W3C4DYc7+wl14CBIGwm0EWPnN4bmJ/rqZ7rSF9rc
V9r0QW3iiDZ2TBuZ1oXn9KEFQ2jJFFoxhynWCM0WZThiLGeC40py3SmeJ8X3
pAWelMCdEriSAmeC74jz7FGuLcKxhtmWENscYhEJs83gJzGuLcl3pAWunNhb
lPrLUKiGRBtYvIUnwfZKXEMm8OY6ynxbkW/hwG+O9JutwZmqLF2RJCvifbwV
YbQqitTEkbok0pBFW8Av6F8wPxuKI2tt3dPeCo1OJLf2Cntn6xcv9m9cXb9/
88TTu2dePbz07ZPrv39x+0+v7v8ExuN3T/9OlO8v8T4Du/Df3jz+y6uHP72f
nP/73tVvbl18dfXss4t7D84cv3Vi48rm8Oywc6JdH1eLnVy6kohmg/6o2+mz
mOw6jVEpV6MyXCqEhRwJly5krfLpSzzqApcyx6PM8alzQtqcmA4ILyHsFZxH
1YgYBinHivBdcpFfJQtr4YQBS5vwnEVRtCnKNkWFCF4lFIMihkpG6QfCYBFO
kjeCYwglShyhXP7lLO0Vz33waybLV0OU76H9yXn+cw7Yeac+oZJjM9m8v575
gJfIR0e++g3we/Tgp8cOfTZ1+Jd+JxU8Qyd3YQ5tic9cFrFXJVwKxKehQjou
ZiilLA3E1iNcI8az4AK7UuQkCfsMcMCEhizyCEk47lQmXKoEqTjhVibcirgb
j7nlMTcW9aARDwz8hv1QOAiFw4TfyL5fdOI3+d5vivCLkX6RxD5eabQvifbE
ka440hFH2uJISxJtyqJNmLjq1cRTTVWmpcu2jPm2tdhxlLvuSs9XGwTrw3B9
FGmMovU1IrW1SGUULo2ChaE/N/Cke85E1xZtm8JNXaCu9lZxsAk6itAHuYY0
T58i3nWiTbA1cbYmxiJePRYD33A0QHGCpwNdnBQYwVBN+rXm3vstAb8w4XdS
vg0k3IQB3ghIGwQKd4iEQNrALxxowebuJ6bWZ8baF4byV4b8IX3miD51zBCf
McbmTJEFc2TZElm1RaiOKN0VY7rjbG+S60/xAxlBMCsMZkWhnBgkmBUHMmJ/
WuRLCb1JgSchcMf5rhjPGeM6QOJcZ4LnSvLdafLjTQriQElKfp4VEm+C4QdP
dxSZLvCrJPC+95sj/KLZOpKpQemqLFWVJCpiEq+IwFsVhQm/0kgTirbQeEeR
6mlyA7DU2Osb3u52ZHwyffx0+cz51uXLw1vXtx7e3n1+/9ybR1d+9+zm9y/v
/vD6wc9gQgZ+gdlvX5B5Dgbpv/8S7/7kfBVMzm+un3tx+dTjcyfu7W3d2Fm7
OO6f7rd2mtVRKd/KJMvRcNrvDTvtHpPBplXpcVQFSzGxAOKzxRyagLHKoy1y
KPOc1Tnu6oTwvIi2IGGAQXpVzqOphEy9lGtBBE5c4lNBYR0aN+JpC/HWoaJd
XXGoq051zaGqORQ1O1BMrMMlYhcW5bXEKUqwC6dwZgKjxVFqFFklihhaCsoI
wj7xvEc05xTMkn6nJsMzTj0EExecv+TPf86e+ZQ+9cnq0Y+XDv9m/uBHswc+
mv7qo6mvPjoGahfI/erjowc+IfF+DvBOH/1q9tjBuenDC7NHQP+uLEwTI/S+
30UeY1nIWhETJz0oMJ+KCWmAsErC1MhYOpgDCJtxgU0pcqglbp3M+55w2IZH
7YqYQwkUx12TKGIuPOqSR91oxI2EPXDYC4X8UIj0G/4Pv9gHv6kPfgdk+Q72
8UZ6onBXGG4LQi1BsCkI1gWhuihUE4erskgVjlWxeE2RrKlTdX2mYco1rfmW
o9B2FTueUtdX6vlLfX+x7y/0/fmeN9vzpLvOZMcea1nCDUOgrvVVle6y3FFE
bHmZJScm5KZ4uuSELTDLVP1HSMXEhzRydUkAHDAXmjIiS1YC1kl7QQY2SuDX
C/xW4cAv/Eb2/UIfEm4Dv1CoBQWbsKX3mbn9hbn+lalyyFQ8YsodM6VnzMk5
S3zRGlu2x1YdMZorxvDEWb4EJ5DihdKCSFYUzYnJx3Kl8aIsXiTPsxVksbws
kpOGs5JQRhxMiwIpoT8l8E2SFvgzQuLDNAriUEkSIT7MCo4Tl46xdFue6eDZ
riLXVeQ7ZNp4riXPNbFsA83UkXQNSlVlyaokXhH/Em+4Lgk3ZJEmHGtjia4y
3dfl3y+/YHje2MudPFs7d7F77er47s3jj++e/vrhxW+eXPvu+a0/fn3vxzeP
/gKGZAAWsJ0EfP/26V/fPP751cMfX9wHeL8n197f3rn09sb5r6+cfnbh5MPT
27dPrF/bHF4Ydfa6ja16eVjMNtOJUiSU8nnCDhvwa9X8L790ARP4XeJSCcJc
yjyPOs+nLYjoSxLmCsShYnyGSsTWyfhmVOxUyHwaNKzH42ZVxqrJO7Ql4pWd
urpb13BrG25Nw6VqOBR1G1a1gFl6n3BOzc2QhJNyOiAc+wVhv2TBK553CWdt
/Bkzd+L3iJz0K176ij//BXvmM/rUp6tHP1k6/PH8oY9nD348DbbdAyCfHANs
D342NZF75KuZowdmpw7NTx9ZmD26NDc1wUtbnmOQKzCHvsSf+GWvSrmrEI+C
CCaE6UoJgyTMNqBcs5xvVQoBYZdW5jHAfhMatMhDVjxiV0QdiqhzEgJvxIWF
XWjYjYTccAj49UGhgCz0v/yWMbD/Jpsf/GKkXyRBbLtgbAbNC/AKQm1+sMUL
NLj+Gsdf5forPH+Z7y8JA0VxsCgLF5FISR4tKeNlTaKiT1VN6bol07Blm45s
y5ltuTJtV7rtTBFvG7TFmpZI3Ris6X0VtaekcBYxWx4CAE1poSHFB3MyaFuC
bZShjNJBFO+jBD8hXt3LUoM6BuP0L/3mJLa81DHxW4a9FdhP+g3VAV4kQvqN
grShSfYJt6BQk4it/6W1c8DSOGSpHrGUjlnyM5bMnDW1aE+uOBIUV5zmSTB9
CXYwyQ2n+dGMMJ4TJ4kH+mSZEpQtI9kKCAqSKaNp4okhJFmEEwUonpfFctJo
VhLJiiM54jM0IgVxtCiOliSxijReg5INONVE0m0s25HnujiBt7uPd+I3u+8X
ToF/uSpLVKXxqjhaFUdAAN6aJPzv8sWTPU12YCyu2Wobns52eHQytX26dOp8
8+Llwc3rmw9u7z67f+71o8u/fXbjDy/v/PnVg59AyYKqBWa/eU7k3bO/Abyv
H//8NcB7709P73z/iGhegPfdjfOvrpx+fnH38Zmde7sbN3fWrqz3zw1au+3a
Vq04LGRaqXgpEkz7PBGHzWsy2LVqowJTI2B+FiFCrpTHErGJCubTV3i0ZT4N
bMHLQsaKmLkqY1MRHkMuZKskPD0ssshlThXq0+ERoyph1WYd+qLLWPGY6j5T
02dq+Yxtn77t1bXd6qZT0bBjNeKmkrREHKckCGeV7LSCIJzA9gmHoKWAdNEn
WXCLiNu+ZuKe7zE14yhOOwyvHhQvHeAvfMme/YI+/fnqsc+Wjn66cOTTucOf
zR7+bObw59OE2S9nJmyPHZqbOjw/c3Rh9hiQu7wws7o4S12eo60sMCiLLOoS
GJ5B+QqYK6KJX84qxF2F+RSUIEzFRTSlhK6WMrXkLG2S8y1gHVaLnVqZWw/7
TKjfjAWt8pAND9vxiANEHnZiYScaciIhFxx0Q0EPFPTJgoRfWSgGhZMw8cHO
769fAb8psM/2Jn7R5ABOALwDSbRP4u3wAi2Ov8H21VjeCtNTYrqLLHee7clx
PTk+MQ1mJf4cFMyhoTweLqiiRU2spI9XjPGqKVGzxEHqlljdEq2ZwzVjsKr3
V7SekspVwO051JqVgQHYkBToEjwwG6ujLGWEoQjTcCJUIhEQGh4BhN/7BdWc
5GrBXpwWGDNCU5b0W5CCxdlVgjwTv/8uX+Q93n/7JQi3iISB3wZkHxywdQ7Z
mkestSlrecZWmLdnFx2ZFVeK4k7SfUlmIMUJpXjRjCCeFaXykkxRlivBhQpS
rGKlmrxUx8koQIo1vEAcWpbnylimjKRLcIp8gJdISZosS5MVKZAIPKYbcKaJ
ZFpoto3lOvJ8FyfSIfOhfJtopoGk3/uNV6WxqmTid4I33IAiTSTWlie6qkn5
lsdO4srz8fj6Xu7E2Soo36tXx3du7jy6e/rlw4vvnlz77+e3vv/63g+vH/78
9slfSb9/e0fkr2+f/uX145++fvjD83t/fHr7D+TOC8bmtzfOAbwvLu4+Obvz
YG/zzonx9a3B5bXu2X5zt1Xdqu77rURDWb835rT7LSanXmtWKXQYooKkcokQ
EJbxWGIOAygWsUCoYjZNwqbLuAyYz8KEXIVEoIHERlRmU6BuDR4wqKMWXcph
zLvNZa+15rc1g7Y2+QrOXtDcCxh7Pn3Ho2m7lE07VrfC+4eydPw8QZiVVjCS
ctoHwkHZkl+66BHPOwRzFt6MgTOlIU9bIZTDkuWDgsUDnLmvGDNfUqa/XDn2
xdKxLxeOfjkPNtxjB+aOHZwHZkHbzhxbnJ1amp9eXphdWZyjLM1TVxbpq0sM
yjKLusymrXAZK8RZDtYqcboS7L8con9lRAWvIvxVlE/BBFS5iKoQ01VShgZi
6RCOAeObFUKrSuzQylx6yGNEfGY0YJkolofsWMiBggSdSNBJ+A14ZBO/wX2/
UCRL+q2gCeIjhbFUB0v1sFQfJcsXig+ksb440vuAl+WtMdwVuqtIc+ZpjhzN
kaE70kxHiuVMcV0pvjsl8qSk3jTsz2CBLB7Mq0IFTbioC5f04bI+VDYEy/pA
Wecrab1FtaugcOTktixiTsuMSbEuLtDEuKoIWxlmKkJ0PESVBynYJCGKPEyV
E4ppRAUDv8Srt9kasBqDBTkjMGaF5pzYmpfYilJHSeYqQ54KMTz/p19k4jdG
BAKJtohEmjIwfIbrMsfgkL17xN6astdn7JV5R3HRmV9xZameDN2XZgXTnHCG
H8sKkzlxuiDNFaFCGSlVsUpdXmso6k1lvaWqt9ST1JrqalNVaSjLHyxX0VwV
yRKBszUQKFuHsw0424RzLSTXRvMdLN+VF4jgBQKvHGRSvhlyeE7V4WQNStQI
v8TzYlVJpCb9gDfawuIdZaqnJcvXXiOeAo6MTqbfl+/wxvXN+7d3n4LyfXzl
22c3fv/y7p9ePfgRDMnvnv4VsCXkPvvLmyc/v3r848uHf35+7/snt39PHpL8
5tZFsPN+TTTvSYD34anNuyfHt7aH1zZ6l0bts73GbquyVS2MCplOOlGLhfNB
X9LtDNssXiNRwSYlDgirYdDCYjBIw0IeJOBCfA4ILOAgAi4q4svFAqVUrIGl
Bgy2KDCHRuk1aMIWfcJuyrqtRZ+9GnQ0w85OxNWLOgdRB/E6obB1GDL1/fqe
V9NxKQjCxLlKSVkvLGoBYQ5BGCcIx1EK2IXD0HJAtuSVLDiF81biwOS0ljWl
YBxDqUekq4eFS4e4CweZcwdpswcpMwdXpg8uTx9amjmyBCbk2anlfbPzq0sL
1JUl2uoynbLCpK6yaBQ2ncplUHlMGp9FE4C/l9g0sOZLuFQpEQrYfyHSL0yG
UCygTIpYIWGoZCwtzNFjPBMutKjEdo3UqYPcBthrIhT7rWgAxIYE7EjAAQec
UMAlA34DPmkgICX9ysIp0m+R9NtAk2001UUneJNDKDGUxgbiaF8Y7vKCbY6/
yfTW6e4K1Vmi2POrtuyKNb1qTVKsCao1TrfGmLYY2x7jOeJCZ1ziSsjcKcSb
lvsyCl9O6c+rfSAFtbeg9uRVrrzSmcPtWcyShk1JqSEh0sb46ghXGWYpggx5
gIYFqKifgvpX0QCZ4OqEMOE3RlfGCb+aFEeb5uozfENWYMqJzHmxtSCxF2XO
MuSuwJ4q7KtNrjyj4SYaaaFRwi8S2/cLx1rk8xpNWaRBBPh1Do86e1OO9oyj
Me+sLrlKK+4C1Ztn+HPsYJYbyfLjOVES1G5Bli/BpQpaqQG5eKOpbLXV7Y6m
3dF2uro2mVZH1+zoGm1tvaWptdSVprLcUJQa8mIDKzbQAkgTIdJCCm0QtNAB
wQpdjPDbITLBS5Yv4TcN/NYIv2DeJh4WA35rILJIHYo0kGgTi7UVia4m3Tfk
h9bK2N0kPoUjsb6XP3G2dvZS78q19du3jj+6d+bFo4tvn17/3Yvb37+6/+c3
j356+wQMz3959+wvoHbfPPmJxPunZ/e+f3z7uwc3fnv3yrtbF19fO/vy8qln
F048Prv98NTGvZPj2zvDG5v9q+POxWHzbLcO/G7XCuNitpdNNhPRcjiQ9Xni
LkfQavEYDQ6dxqJSGhRyLVCMQEpIqpBJcDLgG/BLFSRTIzAwbsDlFqXCoVV7
DLqg2RizW9Jue97nrATdjYinE/P2495hwruWcI/jrnHMMY5aRyHT0K/redQd
J96yow3yuYayXlDU8vJqdlbJTOP0CeEIvBqEln3SRZdowSaYM/FmdexpFXMK
ox+DKEfFK0f4S0fYi0eYC0do80ep88co81OUhRnK4hz1vVkGdZVJo7LoNA6D
wWUxeWyWgMMSctkiLlvMY0t4LBApnykjwoD4dIhHg3hUsP8CvxB3ZRKYtwJ/
UAw2YilTDXN0KM+IC8xKkU0jcehkLgMoYthrhn0W2GeF/TbIb4f8DpnfJfN7
pH7gNygNRqShuCyclkVyUIw4/4wkmkiyjaR6SKoPJwcAryw+lMQGwkifH+py
/C2mt0F3V6mO0qotv2zJLplTS6bEkjG2ZIysGMOrxjDVFGaYwyxLmGuNCGxR
sSMucyZgVxJ1peXuDO7OKlxkHFncnpFb06g5BRkTUn1cpInyVWGuIsjCAwzM
T0N9VMS3ivhW9uNf+bffKPDLUCWYRPmmOboMT5/lG3NCc15kKZDlW5a5KoRf
bxXxkcc2Qv/2i0bbwC9JuEX6bRJ+o8BvXRauSV2jaVd/1tWZdzWX3LVVT4Xq
LTH8RXawwIvkBfGCKFWQZie1W8GqNbzRULRaqk5H0+1qez19v2/o9439gbHf
N/X6xm7f2OkZ2l19s6trdDT1trraVlbaikobL7flpTZGpIMWJ+likxCKCbxY
voX9Ai+aqiPJGpyowYTfGhStQRGQOryPt6VIdNSpnj43sJTWnLUNf2cnOtrN
bJ+pnLrQvnhldOPG9v07e08fnH/15Oq3z2999/W9P75++MPbxz+93cf7M4n3
BxLvHx7f/u8H17+9c+XtzQuvrp59cWnv6bkTj05vPdhbv3ti7fb24MZm79p6
5/KodWHQONut7bXKx2vFjXJumE910nFQwcWQP0MSDtmtPrPJbdQ7dFqrRm1W
KY1KhV6B6/H9GBQKo1JpUqksarVNq3Xq9R6TMWC1RB02UOI5v7sc8taj/k48
0E8GR6ngOB3YSPs3U97NpHsz7liPWtZCxqFf2/coO06sZYMbZmnVICrr+EUN
J69iZRWMFD5ZhClheMUvW/aIFx3CBQt/Ts+dVbNmcMY0QpuSUqaEK1O85Sn2
0jRraYaxNMtYnmesLDIpy0wqKFkahwnMsvgcjoDLFfH5YoFAIhRIhUKZSAiJ
BDCImI+IeIiIi4g4iJCNCJmIgA7zaWD5nfiVcZdlHDLcZWhfMRin6QopUwWx
tSjPIBeYlCKrWmzXSp16mdsg85ggj1nmtcq8NpnPLvU5pT6PxO+TBIISwm9C
SvjNE8//xsGfjRac7MBJEm9yKEsMJfGhKDrgh3vcQIfla9LddaqzsmIrLFmy
i6bUvCE+r4/O68ILutCiLrCsC6zqA1RDgGEMsExBrjkssETE1qjUFofsCcSR
Qh0pzJ7GbGnMmkItKcSUhAxxqS4m0kQEqhDAy5b7GeTJYSriWSWeCCAeCliG
J34DpN8IlRie4ww18W4+ti7D1Wd5xrzAVBBZimJrSWovy5wVyFUF5Yt4a6i/
jgaIj73Fwi0s0sKibRA0NiFM+IWjwC+JlxhEq1L3aM49WHB3l92tVU+D5q0x
/RV2sMyLlISxkhjsrZkynK+gpaq8Widqt91WA7n9nm4wMAyHxtHQNBqZRyML
yHBkGQwt/YG5OzB1+sZ2T9/saRtdTb2rqnWV1a6i0sXLXXm5i5Xeh/BL4MV+
gRf9BV6ExAvHanCUDIG3jk7wxtvqVFeX6ZsLI0dl3dvaCvdPpDZOFU+ca5y9
NLhyffP27ZOP7p998fjy22c3fvfyzh9ePfjzm8c/vn0Chue/vH3285unP70m
8T6/T+K98Q15vPnrq2eeXdx9fPY4mJlB7d45Prq1Nbix0QV4r6y1Lg2bF/r1
s93qqVb5ZL24XcmPi5lBLtlOxQjCoIX93qTHHQWKHbaAzeq1WNxmk9NodBhA
DHaD0W6YfA9+aHabLB6z1W+1heyOqMuV9HpyAV8pHKjHgu1EuJ+OjDKR9Vxk
KxfezgV3sv6djHcn5dqK2zci5nFQP/Sp+y68Y0dbFlndJK7qBSUtr6Bm55TM
zP4UTY0goIJXvJIlp2jRKpg38ua0nDklaxZjzEC0GTF1VkiZ5RE3thY4lCUO
dYVDp3AZdD4L9CxHxANmhVKRWCaWwFIpIpOhEIRBkByCcEiGQ1IcAhOFCJcJ
cSlfLuFiYjYmYqJCOsInKljGXZFylqXsJckknCUp4AwUCyioiIZLmEqIrUG4
ejnfpACzNChisUMncRqkLqPUbZZ6rBKPXeJ1Snxuic8n8QclgaiE8JuRRgqy
WEUWb0CJNpTsQsmBLDmUJkeS+EgUGwoiA26ox/a3GZ4G1VldsZeWLLkFY3pO
n5jVRWc1oVl1YE7tn1f7FtTeJY13Veul6nwMvZ9tCPCMIaE5LLZEpZY4ZE3A
1gRiSRIxJ2BjYoJXTOLlkXiZmI+OEHgpsHsVdq9A7mXi0R4v8LuKBSjyEDE8
K8nyBXi1aQ7Aa8jxTQWhuSiyliS2stRRgZxV2F1DPDXUV8f8xIFneaglD7fk
kbac9EsQBi1MLMJNwm/kffmGqhLP2qJnuOLpUbwdmq/J9Nc5wRo/XBXGiPMS
xOe1gh22VJNXG4pGU9VuE7Xb7+uHA+PayDRes4zXrOOxjYx9bWwfrdmGI1t/
ZOkNzZ2BsT0wNPu6Rl9T76lrPWW1p6j08Erv34T/Ey/6/8OLgBkpRtynA3gR
IgBvQx5rEniTBF5Tfmgvjz2NzVB3J7G2m98+Uzt1sXvx6vjGzeP37555+vDi
q6fXv31x+7tX9//45tEPb5/89O7pz++e/fwW4H3y49ePCLxP7gC83965+oY8
YfXswu6jszv39zbvnhjf2hne3OxdX+9cG7evjFqXh41Lg/qFXu1ct3q6Xdlr
lo7XCluVHEk41U7H62CQjoYL4WA26E/5fQmfN+bxRNzusMsdBHG6A+8TJOIJ
OT1hlzfq9ia8/rQ/kAsGS5FwLR5pJ6P9TGyUi28U4tvF+PFi9EQxcrIQOpnz
n8x4jqec2zHrRtgw9muGHmXPiXVsUNMsqRmEFR2vtF/BxBSdIA9Ih+BVn3TZ
LV6yCxfN/AU9d17NnsdZ8whjXkafF9MWhMRV8RUBgyJg0oVslojLlfAFgC0k
AWYhDEZwBFOgciWGq+S4Gsc1uFwjxzRyVIPBahQsAhIVLFJCAoWUK5cQhBEB
UcETvxL2opi1KGItiFiLYvYiqXgF4lMQIU0uYShlLDXC0WHkLK0SWjUiu07s
MIidRrHLLHbbxB6H2OsW+3xif0gciIpDSUk4K40WpWCfijdlyY4s2ZelSLzJ
kTg+EkaHvPCAE+wyfW2au77qqCxbCwum7Jw+OauNzajD06rAtNI3o/TMKt3z
Sveiyr2sclPUHrrWy9L5OfoA3xASGSMSU1RqjkHmOGQiY4zLDDGpLirWRoTq
MF8Z5OJ+FuZjEM/seKgk3lXIvQIIgwpGvCtgC5YHKXiYuHKlijM1SRaBN8Ml
8QpIvGKA116RAbwugLeOeuuYr4H5m+TTgi083MaB3/eEyUG6Rd5OakDh93iD
FYl3vOodUX19uq/L8re5wSY/3BBF65JEDUrVkFwdrK54hbhOpW51NJ2ejsA7
NK6tmcdjy/q6dWPdvrFhX99wrK87x+vOtXXHaOwYrNn7a9buyNwZmlpDQ3Og
aww0tb6q2ldWeopyT14C2Z+c0XwbzbXey20gE7kE3uoEL5EoSA2N1rF9vC1V
sqNL94y5ga205q5tBNrb8eHJ7Obpysnz7XOXR1dvbN+5c+rRgwsvn1x9+/zW
776+94fXj/789smP7579ROAlyvfHV4///OLB90/vfvfw1rd3r70hn014emHv
0Zmde3ubt4+v3dwaXN/oXQVy14Dc5gTvxX4N+D3frZ7tVE63yrsNgvAm0cLZ
QT7dzSZb6UQ9Ga/EY6VYtBCN5qPRbCSSCUfS4UgqFAVJggT3kyKTCUVz4Wgh
EivHYuC/bacT/WxylE9tFFPbpdSJcnK3nNgrx06VIqeKwb2cbzfjOpGwbUdN
G0Hdmlc1cMl7drhtkTaMopqeX9Zyi2p2HlQwmKLJO8JhmBKQrXgkyw7RkkW4
aOAvarmLSs4ixlpEmEsy5rKUuSohLowzJFy2lM+DhCJYIkUhGLAFZtW4UqNU
61QavVpjUGuNao1RrTaqVQaVwqCU63FUJ4e0mFSNiFQQnyAsZoEKhvlUGXdV
wlkGeIXMBSFzXkBkQQgsgy4GozV/FRFSMTFdIQPrMFuHcg04z6QUWNQCm05o
NwgdJqHTKnTbRR63yOsT+UOiQEwcSonDOQlxF7ImTbSkya40NZCmAN41cXJN
GF/jR0fc8IAV6DK8LaqrvmIvL5rz84b0rC4+o45MK4NTCt8U7pnGXTO4cw53
Liicy0rXqspNU3uYGi9H5+frg0JDWGyMSI1RmTFGxBCT6Qm8Em1EpA6T5Rvg
yIFfLwP10BD3pHyJ/gUBgzTqW8X8FDxIVYTpqihDHWdpU2wSL8+UB3iFJF4J
wOuoQgCvu456Gpi3KQd4Ay08SD7qG+4QiXQmisEsDdZh8jhWAwrVZaGaNFiV
BMpi/zrdv8b0D9mBPi9I3OwWRVrSeBNKAlBNeb6pKLWU1ba60dW2e7rewDAY
GUcTvBs2IHdj07Gx6dzYdK1vusYbrrUN12jdORg7+mv27pq1MzK3hsbmUF8f
aGsDNeG3ryj18CJxwfmXeBHyVtE+3n/LrSDRCoE3UkUjNSxal0cbBN5EW5vq
GrN9a3Hkqq77m1vR3onMeK90/Gzz9KXBpWubN2/t3r937tmjK6+f3fz25d3v
Xj/849snPxB4n/8M8vYZKN8fvn70x2f3f//49m/vX3976/LX1849u7j36Ozx
Cd4bW4Nr690ra20g99KgcZGUS6RH+iUr+EynAqboXdDC9eJWtbBezo9KuUEh
281n2rlMK5tpZLP1bLaWyVYz2Uo6VyZTShEpJkGyxUS2lMiAVJLpWirdSKc7
2Uw/n1krZjZK2Z1K5kQ1s1cj3rdCvGylEj1bCp8p+E9lPbsp+/GYeSusX/er
Rx6870C7VlnLJK4bhFWyggsqYopO4wyygqlBCFTwiov4tJxlk2BJz19Sc5cV
nGWMs4KwKTCHBnGZEI8DC/iIWITJZDiMEnIVKp1Ka9DojFqDWW+06I1WAxm9
warXWbQaswZs8bhRiepxSIdJNIhQJePhRAUzEAFVxiP8gtoFbPmMeT59jkef
A9+QipfEYCnmrcICkjBYh2GWFuXoca5RyTOr+VYd32YQOMwCp13gdgk9PqEv
JAzERMG0OJwXR8uSOKiYtiTZk6SGktSaODUWJceC+BovOuKEB8xAl+5pUpy1
ZVtp0ZSb16dmNbFpVWhK4Qd4p+Suacw5gznm5I4F3LGscK4qXTSVm6n2crR+
vi4g1IfEhrDEEJUaojIQfRTglWojYk1YpA4JlEHgly33MTEvnfRLBYQR9yoI
CvB6V+U+Ch6gKkI0VYShiTG1CbY+zTFmAV6+hcArIvBWZc4a5KrDH/D6Wri/
hQfaimBHESITJgIUy8NtLNxGwy0k1IRDDShYlwWqEn9F7C+LAhvswJgbGPGD
A2GIOClKnPFOtNF0W55tKwodVbmrqfW0YAzuDA29kXE4Nq+tW8Yb1vVN+8aW
Y2PLubHl2thyr2+6x5vutQ33cMM1WHf2xo7Omq09sjRHpsbQUBvoqgNNua8q
9RTFHg7w5jtoro1mW0imiZC1CxOXqqrEhyrEKnCUTKSCkEFJv/JoHY81VfGW
JtUxZHqW/NBZHvsam5HuTmq0W9w6U9+70Dt/Zf3azRN37559/PDyy6c33r24
+7tXD/7w5vGf3z378d3zn74h/P705hko3z+9ePiHJ3f/+8FNsPa+un7h+aXT
j8+duL+3dfv4GOC9ut69PGpdHDTAtnuBNHuhV33/zQfCtbMdMEhX91qVk83y
TqO8VSttVEvjamlUKQ0r5UGl0q9UQXqVWrdS61TqnXK9Xa63SvVWsdYsVBv5
SiNfbuZKrVyxnS9084VBsbBWym9U8jvV/Mla/lQ9d6aRPddIn68nz9di5yuR
86Xg2bz3VMa5m7Acjxi2App1r2Lowvp2uGORNskKrmi5JTUxRWcUzBTxmDAt
jFD90KpbuuoQr1hEK0bBipa/ouKt4jyKnEdDeQxUwEaFfEwMllmZEkHVcoVW
qQZyTTqjxWC2GS12s9VhtjotVpfF4jSbnSawwutteo1VqzSr5SYlQjzmjIrU
MKhgjlxMjND/9suYB3K5NJBZLqF4ns8gihgQln5Yh6UMFcTUoGy9nGNUcswa
rkXPs5l4Divf5eS7vQJvSOiPCYNpEfEyrIo43pQkO5LUQJIeSdJjcWpdlFwX
JMb/6be6bC0umrLzYHjWRGeUwWncNy13T2MugHcWc8xj9kW5YwV3UhQuusrN
Unu5Gj9fGxDqQmJ9WKqPSEm8E78S0q8Q+FWRfnEfS+5lYB4a5qGibhAK5qFg
XorcR8X9VGWQpgozNFGmNs7SpzjGDM+U41sKBF57WeKoSvfxNlBPE/O2SLxt
hb+jCHSUwa4y9D7hLkGYeHK/jYVaaLAJBxqQvyb1VyW+ithbFgY3+cF1YXAs
Do2k4QEU7SPxHpbs4pmuMtdTFXuaSl9bH+jBGNxZM/bHpuG6ZW3TOt6yrW/Z
17ed69uu9W03yHjLs7bpGW26Bxvu/rqrO3a012zNkaUxNNWGhspAV+5rSj1V
oafId+W5DpZto5kWkmrCyQacqJNXmKtQtEIkUobCZXiSUBkJVdBwFYvU8Ghd
GWtqEm19umvODeylkae2EWpvJwYn8xunaifOd85eXrt8fefW7dMP7l989vj6
6+d3vv36wXevH//x7bMfCLwvfn734qe3z398/XRSvt89uv3tvetvbl56eeXs
kwu7D05v3zm5fmN7CPBeGrUB3vN94LQKpmUihN8q2cL1SQDt8/36uV79TLd2
qlPba9dOtmvHW7WdVn271dhqN7farc1OZ7PT3ej01kHa/XG7v9bqj5r9YaM7
qHf6tXa/2uxX6v1ybViujiqV9Up5s1raqZdONoqnmoWzrfz5Vu5CM3OxmbpU
T1yqRS9WQueLvrNZ16mk7WTMtBPSbfpVY7d86EB6VlnbLG4YhDXd/hSdI28H
J+T0CEoLwlSvjOKUrNrEqybRql5I0QioKgFNIWDgQjYuAr0pVMikKgTRyHGd
Um3U6EDnArkOs81ltbttDo/N4bU7vDa7x2r1WMwuk9Fp1Nl1aqtGYVahRgWo
YLEGFihlXMKvEPilAL/AKZ/0y6HNcqizxFdSMVHExEZMrsOCVVRExaV0JcTQ
oEwdzjKo2CYtx2Lg2Cxch4Pn8vK9IYE/LghmhOGCKFoFfsXJLlG+6TVxel2c
3hCmNgSJdV5sbd+vl/C7Yi0umTIL+sScJjKrDMzg3hm5ewZzkngdAO8y7lhV
OGlKF1PlYau9PK1foAuK9SEJwKuPTPD+P/wqAxyFn4X7mLiXLvfS5B4a+Ip7
qbiPpvDTVEG6GuCNMHUxliHJMaa55izfkhfYigCvGOB11SB3A3Y33+Nt40Cu
v6MMdFVBEOKDcd6HUAy6GAzVWKCFBpqIvwH5alJvVeKpiNwlYWhLHNqUhNZl
4TU4MkJjQ3l8gKf6ykxfnR9oSgNdBUy/I0NrzdhZN/U2zINNy2jLurZtG+84
xjvO8Y5rvO1e23aPtjzDTc9g09PbcHfXXe01R3Nkq48staGpMjCU+rpiT53v
KXNdPNuRp9toqoUkm3CiAcXr5L2hqixSkYXLshBISRYsQWTgYBkJltFQRR6u
KaINFfEZWR1jtmcrDN2VcaC5Fesdz473KjtnW6cuDi9e27p+a+/evQtPHl19
+fTWu5f3f/fq0R/ePP3Tu+c/fvMC+P0J+H3z7IdXTybl+7sHN9/dBuV7/tml
U2Byvru7eXNn7dpG//Ja+8KwSdgEe263eq5bOUcSBrUL2IItGEzUl8BcPWxe
HDYvDJrnB81zg+bZfvN0v3WKSGdv0N0b9PaGg93RaHe0dnJtHeTEaOM4yHBj
e7C+1R9vdkcb7eF6q7/e7Kw32uv15ma9vt2oHW9Wd5vEcn22XbrQKV7q5C+3
s1da6SvN5JV67HI1fLHkP593n0nb9+LmExH9dkC94VWsudCBHepapC2TqGEQ
kFM0F0zRWSUrhTNiGD2E0PwQ1S2jOCQUi5hqFFF1QppGyFCJWEoRRynhK2Vi
NQxpMEyvUBrVWovOYDOanRabm2Dr9DlcficZh9Nvt/tsgLDJbdI7DRqbVmFR
YyYFpJeDEZr0K2EhQrqM/2+/XNIvmzqzn0kRk7O0iCC8DPEBYQoupSkhuhpl
6BRMg5pl0rMtZo7dwXV6eJ4g3zfxWxTGaqJES5zqiUH5ZsbizIY4sylKbwiS
6/z4GjcyYAXB/tukuaqrtsKyObOoTyxoI/OqwJzCN4e75+WuBbmTxOuc4GWQ
eEH5CrQBkQ7gDUsNETA5Q2TeE46Iwf6rCQvUIZ4qyFUF2Eo/S+ljKnwMhY+u
BPHTVQG6OsjQhJi6CEsfYxsSHFOKa8nwrXmBvShylMVOAq8M4PU0UW8L87Xl
PiC3S8gN9NRBkL461NeQURPpAdGgkUEvy/0tzN9EfA3IW5e5qxJXReQsCcPb
UHgLDm8gkXUsuiaPjRSJkSo1VGeGmvxIVxrpK2uG+tjQXDe2N0zdTXN/yzLY
tg53bKMd+2jHMdpxjnZcw233YMvd33QDvJ11d2vsbK456iNbdWgpD0zFvqHQ
0+a66mxXme7gqTaWbCGJJhxrQFHiNpYsXJWFKtJgWRooEfEXZWQgfxEOlJBA
GQ0SfpXRhibRmpSvo7Tmq29EOmByPlncPNPYvdA/d2Xjyo2Tt++ce/jgyvMn
N18/v/ft14++e/30+7fP//zuxY/vXv70vnz//PLR9/vlew2U7wtQvud3758i
nk24vjW4Mu5eHLXO9xvnerWz5HUqEMIvGJtB7RJyG5dHTTBdE9e1wIK81r60
1r446lwA+b903QVzI9ea8PGvtfeGk2EziJmZWsxoSRYzQ4vRzMxsDwQv7Id5
z2l5Jrm7+1b9K2U7k6mZqvz0PKcltYrppWJmqZQblvLDcnGpWl5Cq0tobVir
D2vNQa3ZR5u9arNbabRL9VYBbebL9Wyxns7XU5l6MtVIJlrJeCcZ7aXg+Xo5
HVxNB9bT/o20F366d9K5GbdvRi3rIcPKomZpQdl3Sts2UcPEQ/XssoZeUFGy
clJKio+L56PC2RB/epE75WVPYDfbeWehvjVS3mhJbxDiGznhjQT/Roh7y8eN
cXETHPw0hzjHJeN5VLKAQRex2RIeXy4UqyQytUwB8OpVasPoEjpMZVQp9QqZ
TibWSASIkKvgs2TAL4uM+Z1jkZ79kqDfF1/8ArPjr78ef4UFFX8DNurPhH+A
hGdfUOdf0gmvWeQ3HNpbHuudkDcmFo/L5BNKzaTaOK2zwTe+PftN4lxZnKeA
XyjjF6o4kKc6BwiDFdqWnzSlx/UJ7JUbiy+lnhcix498yw9c4w9s3Q8szY9M
9U9M5AUTefV87NVMcEeT1zAPJq/QTBRaSCIrWWQbRRLagGWCwIoHhPnmOZ55
hmua5honOYYJjmGcYxgDcUHGMR6Qax4XWCaEtkmxY0rimpZ5ZuTeOYUfWAPi
COoISRMjaxNUXZKmTzH0AGaGZcDYGnNcU473n3HhzzNsAwAOfjHAnqBqweCO
EpEwXhXCKYNzljrVUqNZqnRrhWkts+wltqPIcRV5niLfV+QvlgTBsjBSEcWq
ogQqTtUk6bo0U5dlG/JcQ5FrKHN1VbauytSQNKpOVdXJChIvIbGiKlJQhPLy
QE66mBX5MoKFNM+T4rhSTGeSbk9QbXGKNUb6/BwWwRgiGIJ4fQCvW4Rp/QQs
om6RpFsk66FfBuaX50iKPM/D1xhH7dmmt9wNN4bp3mppdauxvdc/PFo9P9u+
vTx4vDn5dHf+68PVH4/X/3y6AX7//Xj9r/vLf96e/3F1/OuX4bs5Gr7NL8N3
tZgCw3cIn+SN9FNhEBzB4MD7jHckN7lRSsHKaazMejm7DgZ3JbdWLayhxbVa
eb2Orjfr663mequ93u6st3tr7d5qq7fS7C03usNau19t9sr1TrHayZfauUI7
m+1k0t1Msp+JDzMxsKivZcMb2eBWdnE769vJLOyk3DtJx3bMuhkxrgd0Kz5k
6Jb3HJK2VVA3cqs6ZklNg1u0nDgiHBHOBvkzfu4UvFk0c9xGHzNR3+kpb9Wk
t0riWxnhnZgwJiSMCwiTfOIMjzTPpxAFdIqIyZBwODK+QCkSI1IZ2JnB5IV4
1WrTKMyv4YtfEeaX+7/8zgO/r/FTL+YmfpwZ+/6vfsdeffUn4bffzLz7dm7s
exwgPP0jafYnKu4lnfiKRX3NYbzhc9+KhGNS2bhCPYEYprS26We/0XlnEufO
4ReKeG+F4EPxIC8Kp7CrPGsvTFsyk8YEfNkzEngj976WOF+JbC/55pc8w0uO
7hVH+5qjecPRvONox7m6z9esjDihmSCykMRWsthGEdupYjsFiwzCLkSD4zBe
aJ0XWOYE5hm+eZpvmuKbJrEmBCDzBLxJhXVSbJ+SOqZlrhm5Z1bhnVP5cUgA
rw4RNRGSLkYBBoFEQ5oB5BqzbDhwgdw8z5Tnmwp8c0GAxYff5nlGjLAhwwYz
WpdigJGtiVOQGEkVISjDOHlw3tJgWmpMK8qyVtm2Cgd+0kSJ5yrxPSW+tyzw
lwXBijBcFUZRUawmStTEybok1ZCmGzIsebquSNWUKVSVrKriFSRWVkVLqnBB
GcwrFnMyf1bizYg8aYE7xXUm2Y4k05agWeNUS4xsihGNEYIhTNCH8LogXhvA
aRdxmkWc2g/CYxE0fpJ2kawLUA3QL9sW5ztT4oWsMlAYDV93oR1A+/H2Sn5p
A93Y6ewdLJ+cbF5d7N1fH7+/Pfv5/vK3x+t/PN4Av/96vPnXw9U/7y7+uD79
7eLw55O99wd/Dt/jXn108l0vw5c3w304g/mF+3NkkIkAzsu52MoIL8Z2s5zZ
qmS2qtmtag5M7S00v1UrbNWKW/XyVqO63apttxs73fZOr7vT7+/0hzuDpe3B
0lZ/abO3tNEZrrX6K43uUq01rNYHZbRfLPcLhUE+N8ynl/Op1XxiPR/bzEe2
8+GdfHA3t7iX9e5lPHtp527Cth0zb4b1a4uaZa9y4JZ17aKWhV83cv5CmASf
ThLjwsK5AH/Gx4UfDexgjlvoY0bqmI7yDiGPKUhjMuK4mDgpIk0LybMCCk5I
I4kYVDGbKeVxFQKBSixWy2TgwKtXqYwIAuSaYYgZUZlUCoNCivnlI0KOgs/E
5i/pr36p8+9Is9Dv/Mjvu+9G+zNgC/yOCINvsbMwRnj8O9wkJEye+4mKf8Eg
v2TRX3HZbwSCt2LpmAwZVxkmNdDvjDmA+U3hPTmCt0TwVYl+lOivgQheFO+p
zLuKc/bsjDk1ZYhNaoPjKt+Y3P1O6ngrtr4Vmt8KjO/4hjG+YYJvmILP9hrn
RCacyEwQW4gSK1lqo0rtNKmDJnPQpU74hdRBlTrg6zckdpLEThDb8GIbTmyd
E1tnxZYZsWV6lMQKk9qmZY4ZuXNG4Z5VeuZU3nkE/P8cIGhDRF2ErI9RDAma
MUUH+zC8AWyWY85xzXmeecS2CBL+NVNBABQbczxDlqvPsHVppjbJUCdoSJyi
jJIUEYI8hLM2ONY6x1rjWlGurcqzV3iOMt9V5nvKgoWKwFcRLFYFQVQYrgkj
NWGsLoo3RImGONGQJBrSREOWqMvjNXkcVcSqykhZGS4pQ0VlIK/w52S+rHQh
I3anha4U35Hk2hMsa4JhidNMMYoxRjJEifoIQRfGa0M4TRD8HefVi+Avi+XD
IT484ieo/UQN8BvE/EY5trjAlZZ6c0gQnHyro+EbAcO3v1Ze3Wru7A+OjtfO
z3ZuLw8fb04/3l388nD9++MN9At6uP7H3eUfN2e/XR7/crr/8Wj7cXf9Fg7f
Hhi+hx10twHfW7ReBssz5hfM38xzw2wM/GQlnwB7MoY3A8Y0YLuN5nZq+Z1a
AQzunUZpt1HebVZ2W+hep77fbe73OweD3uHS4HB56XB55WBl9WB5bX95bW9p
dWewsgUVD9Zb3dVGawWtL1ery+XySqmwWsqtlTJgsm+VEjul2G4psl8MHRQD
B3n/YW7hIOveTzv2EtbtqGkzpFtbVC8vKAcuKSDctPBrRk5Fxyyq6TkVJa0g
JaSEqBgXEs4t8me83GkXe9LGnDDTxw20cQ11HKFMKMiTMvKUhDwjpsyJqHgR
nSRm0qQcppzHVQoFiESskcl0CoVBpQQ7swnIVatAJkRhUskNColOJtSIeSoh
W8FnSDlU7PyLg+ff5/mL+Z1+OT/50+z4D2BPnvwygv9ji4aEpwHhsW/nJr7D
TX1PnP2BjPuRSnzBoL5ks17x+G9EkndS1ZhSP6GxTo382qM4Vwq/kCf6yqRF
lByokQN1EGmxRvRVCZ4S3pWft6fnzPEZQ3haG5hCvJNK96TcMSm1TUqsUxLA
zTwrMc9JLPClVjIbSWanyO1UuYOucDIULubnwNcMuYsud9LkTqrcSZE7SDIH
UeYgyOw4mX0eJLfPYc0qHKA5pXNO5ZpDPPPIAk7tA/MIrw0SdWGSPko2xKlG
eA9JhjnDNGfZlhzHkudaCnxLUWAtCa0lEawsspTFsJLYXBKZiyJTQWjMCww5
nj7L1WXY2jRLnWQgCZoyRlFESfIIwdbkWRs8a41vQ/m2Kt9e5TsqfGeF767w
PVW+tyrwo4LFmiBYE4TqgnBdEGkIozBRtCGO1iXRmjSCysJVWagiD5bkgSJY
buW+nGwhK/WkJa6UyJkU2JM8W4JjibPMcboxRjXEyPoodg0tgteEceoQTh2c
RwLzqkWwacwp/fNK37zKh1P5AWHoVwv8hpnmKHgEELrh8qwJl03JmisPnzP6
PHx3u/uHK6enW1cX+/fXJ+9vLz7dX/36cPP74+0fj7f/eLj5x93VHzfnv12e
/HJ2+PF492l/8357BQ7f5c5xv36AvbF3s5pbG/nNJ4aQcGyYA8XBt8sFcMhN
gX+7UcluwoH7zHa3UdxrlsDBeb9V2W9XDzq1g27jsN86GnSOl3onK8OT1eXT
tdXT9fWT9Q3Q8drG4eoGgLw3XN3pL213B5vt7kaztV6vr6PV9Wppo1rYrOS2
K5ndSmqvkjioxA7LkaNy6LgUOC74jvMLR1nXQcq+l7BsR40jwvAg7JJ2nglz
KzpWUcPIqahpBTkhI0bE+KBw3s+f9XCnnewpK3PKxJjU0yc1tCkVdVpBnZFR
56Q0nIROkDDJUjZNxmUq+FylaORXqlPIDUoFWJhNyCiI16iU6uVirVSgFnNV
ApacR5ewweJN5NNwnP/T78QP06MR/FfCr7/4/XoKEH73zez4t/OT3+GnvyfO
/UAm/Eij/MRkvOTyXgvEbyXKMYV+Qo35tQC/MZw7TfAWSItlchClhOrUUAMW
rFMDNYq/Ql4oEl1Zgj2Ft8RwxtC8fnFO651Tg4Homlc6cUoHXukgKB0kpYOs
clJVLjriZiBuJuJhqT1s9QIHhIA8bPATlYepcjNUbrrKTVO5wC8mq1wklYuo
chJUTjwCcuHVLhzMjdN48NoFvNZH0PkJ+gBRHyQZwmTsNnQ0c5JuSTMtGZb1
+fOIebYi31YS2soiW1lsq4AkIOuossRSlphLYlNJZCoKjQWBPsfXZbnaDEeT
ZiFJhipBU8Qp8hjJ1hTaGgJbXWCrCWyowF4VOKp8Z5XvqvLdVf4CyvOiPF+N
t1jnBeq8YAPED8EAZ2GoJgyhomBVHKhIFstSf1HqK0gXclJPVupKS+DnRySF
tgTfmuCa4eemMY0xuj5G1UXJ2ig4CxDUYbw6jIOX0YLwSppyEabww8O+0o/5
XSSqA2RdiGaIMC3w8Cv2ZBXwylXVmm54St1QY5jqrZVWt0fDd/38fPfm6ujx
9uzj/eUvDze/Pd5Cvw83f9xf/357+dvV2S/nRx9P9t8fbD/srN2Mhu+wBa9c
geW5Xnj2C86/GOFR4Gvwk9VSeq2c3ajmNrE9GZML2e6N2Larh53aYbd+1G8c
D1onw87pcu9sdXi+tny+sXqxuX6xuXm+uQU629g6Wd+CilfWD5ZW9gZLO93+
druz3WpuNWrb9ep2rbRbK+zVcge1zCGaOkYTJ2jstBo5rYROy4HTou9kRDj9
THgjpFsFhL2AsKxtFzcsAtTEK+vZ8EUdCC2loMRlpLAEHxDivPw5N3fWzpmx
sKaNzGkdY0bDmFXR5xT0eTkDL2MSZSyKDH6SEUsp4KpEfLVEpJFJdHKpXikz
KOVG1SgZwGtQiOHwlfAQEVvJZ4DDr4RNFjIIPNo8hzLDJE5+8UuYeYkbHYHH
v58e+27y3bcTb7+BhN/86feZ8Nuvp8e+mZ34dn7qO/zs9yTcD1Tyjwz6Czb3
FV/0Rqx8p9Bhft2zlsC8I4b3pEm+AiVQoYZq9EiDHm0yoi1GpMkI1+lBlOYv
U70FijtLdibhZVJLmGQKEA1+kt5H0nnJugWKdoGmXaDrFuD7BHVejt7H1ft4
ej+ID9KBfDyQ1svVejnaBZZ2galdYID/ROuhaT1UrYei9ZB1HhJID1ogggxe
osFHMvpJxkWSKUg2hSimCMUco1oSdGuKYU2zbFm2Lc+xF3j2It8OP49Y6KiI
HBWxoyqxV6VYMpCtKrOCKlJLWWouS0wlsbEoMhSE+rxAl+NpMhx1mo2kmMok
XZGg2poiW0NkqwttNSHwCwmjfEgY5blQnhvlemrchRrHW+f46hx/nbPYAHEB
Z1iND6azvyL0lUXeonihIPbkxK6s2JkRO1IiW1JoTQgscZ4pDu9obYgx9DGa
LkrRRsmaKFEdISARnCqMU4XmlaE5ZXBOEcBahCkX55WLeCRAhLfzCtOMUbB7
853wyrMKLs81e67lq/ajrZXscKO6sdvZO1w+AcP38uD+5uT93cWnh+tfHm5/
e7z7/eH29/ub32+vfr0+/+Xi5NPpwfvDnYe9jdutlau1wdkSvB/dAViem+Dw
W9iAfjOAKiQ8CnxdyqyW4YWpdTS/CY+3pR1sT95rVbGBix52a4e9kdzmybB9
utQ5W+mdrw4v1pcvN1avttavtjavtreutrcvt3cutrbPN7dPgeK1jaOVtcOl
5YPBcK/X2+u099qNvVZtv1k5aJYOm4XjRu6kkTltpM/qyfN6/LwWOa+GziuB
s5L/pDAi7NjFFumNkH5lUTP0qnpuedshaViFqIlf0nPyWmYGoSeVlKiMFJIQ
/CL8gmDexZuzcefM7Dkje07HmtewcAgLr2QRFWyygkNVcOlKPvDLQaBfoUYq
0soleoUUZFBiKSR6uQjg1Ur5ajFHJWQpeHQphyJmEQUMPI86xyZPA7+0kd+5
N4SZV9Dv5I9/juDPhCf+SvjN15Nvv5569/XM+Ddzk9/iZr4jzH9PJv5Ao/3E
4rzkiV6LFO/kf/rFOWOEhQzZX6SGqvRInRlrsuItdrzNBv+MNdmROitUZQXK
TH+BsZBluFN0Z5xuj9JtYYY1xLAEmZYAyxzgmANcS5BnCQosQSGWCGQOirFE
poDItCg0LvKNfp7RzzX6OEYf2+hjGX1Mo49h8tFNPhrI7KPC/FSLn2KBt+Kh
WoJUa4hqhS8XpNnidFuCYU8x7Rm2I8dxFLjOIs9ZEjjLQmdF5KyKnajEiUqd
qMyJykEOmMKOKmyo3FaVW6tyS0VmLktNJYmxKDYURPq8UJvja7JcdYaDpFnK
FMPektgaYlt9RFgAt2iUb0d5DpTrRDnOGsdVY7trLE+dtYDlhbFhNc4Cylmo
cj1lnrvEdxcErrzQkRXaM0JbSmhNCiwJvinOM8a4hhhbH2XpogxtlKaJUtRR
EhIlIhG8CvqdV4ahXwUoiIUpVgZw8Hp7kKiB9+Kjm2JsW1Lgzsj8BXWkYkrV
nYXOYm2Y6K4VVrbr2/v9Q3DyPd+5uYbD98P91c8PN78+3o38/nZ3/evN5S+X
Z5/Ojt4f7z3sb91ur12tL52v9E4GLTA091tVcHrdwvyuV7KrgHA5s4K1Cr6F
l5Tz67XiZr201ShvwxNuda+N7sNVuf4XuS0od7l7vtK/WBtcri9dba5cb61f
b2/c7Gzd7Gzf7O5c7+xc7exAxZvbZxubp2vrxyurR0tLh8PBYb972GsfdhtH
ndpxp3rSLp+2i+ft/EU7e9lKXzaTl434ZT16iYbPq8GzMiDsPcqBs7BzJ2Hb
iprXQoblRe3Ai3TdipZDWrOKKiZB0cDNaVkphBFXUsMyckBC9IkIHgHeycfZ
eDgzF2fg4HUcgoZDVHPIKi5FxaWpeAywD6uEwC9PLRFopEKtTKSTi0F6mEgv
F+pkAgwvFxEC6WD4UsHwFTEJfHD4pc6yyNMM6HeMgnv77Hf6xfwUWKHBCP6/
CWN+vxoRnh77embim7npb/Fz35GIP1CpPzLZL7nC1yL5O5l2Qm2ZNrjnrAG8
M0byZiiLRXq4yow2AFtOss1LdrDavHiTF6vzIlVuqMwNFDj+HAc+d5niehJc
d5znivFdMYErJnTFxK6YxBWTgpwxGSwqc0TljojMHpHZwlJbSGINiqxBoTUg
sAb41gDPusi1LnJsi2zbIgtkDzDtAQbIEcQK0R1huiPCcEQZjjjDkWA6Uyxn
mu3Mclx5rqvAc5UE7rLQXRW5q2I3KnHXpO6azF2Tu+sKF0zpBNWUDiw7qrSh
CmtVYanIzRWZqSwzliSGolhfEOnyAqBYneMiWba9JbU1xWAEW+tCa01gRflW
lGdDuTaUY0fZjhrLWWM6awxXHeYeVcNCma4qy1VmO0scR5Frz/NsWZ41w7ek
+OYk35TgG+M8Q4yrj3J0UZY2ytRE6ZooTR2lIFGSKkpURQnKKF4ZwSkj8wpQ
eA72DBl7pjtEUIdI2gg4LzPMCY4jLfTk5IGSNoZaMk1PuRdqLqcGG+X13dbu
4fDkdOPycv/u5uRpNHwfb6Hfh7vf7m9/vb3+5eri0/nJ+5ODx4Odu52N682V
i1X4GShHvcb+aPiCwy+ax/zm1qBZyHa1CuWuoYX1WmmjXt5sVLaB9Da626nt
desHPXDObR4NWsfD9skSWJi7YOxerPYv14ZXG0vXEO/azfbG7c7W7e727e7O
7d7uze7u9e4uJLy1fQHW6Y2Ns7W109WVk+Wlk6X+ybB7Mmif9htn/dp5D73o
VS57patu4bqbu+5krtup62biqhG7xAYx2KWPi77DnGcv7dpO2jdiltWQcbio
63nVbbey4ZBVreKSSZDXc9MadgJhRBW0oIzil5AXxCSXkOgQEK18oplPNPBI
Oh5Zy6Nq+DQ1n4EImIiQjYi4ajHwy9c8E/4SlAvWZjB54eYsYMj5NCmXImaT
hEw8jz7Poc6wyFN04gQVP0Ye+Z0Ffl9Cv5M/zoARPP791Nh3/5MwDPj9Co7g
sa+nJ76enfpmfu47AuF7CvVHBusFR/BaiPlFLNN66JfgjJG9GVqgyIyg7HiD
m2zzUx1BuivMdEXpjijVFiWbokRdGEOF0YowXBKGCsJgThTIihczEj8oLfOn
5f60wp9W+tIqWErlBSVVC0mVJ6HyxJXumMIVlbsiUmdY4gyLnSGRMyR0hQSu
EB/kDvHcIa47xPGEQWxYhO2JsjwxlifO8iTY7iTbnea4Mxx3juspwGdjPWWh
pyJaQMULNclCTbpQly3U5QsNhaehxFK5QXWVq46AnDXEUUPsqMqGqqxVpQVU
UZjKcmNZZihJ9EWxrijUFgSaPB/zK7E+++VbUJ4F5VhRthVl2VCmDWXYa3R7
jeaAUZ9DQTRHlWav0O0lhq3ItOZZlhzbnOGYUlxTkmtMcA1xrj4G5HK0EbYm
wtREGOoIHYlQkShFhflVjvxGcVjzClBkDqTEJrIqjEciBE2ErINvh2RaUzxn
VuwtKEMVfaJuy7W91UGkvZpd3qpu7ncOjlfOzrevrw8fwPB9uPp5hPfxHvj9
9e7ml5urT5fnH86OH4/27/a2AKuLtSVwPgUHVTBAwRq8DYdvcQPNr0OwsFUY
lLtWK0K8jcpms7rVQrfbtZ1Ofa/b2O81D+BFqvbxsHOy1D2FC/PnsbuxfL25
erO9druzcbe7ebe3fbe3c7e3i7X3rBgMYrBOb25ebGycr6/BY/LK8Hy5f77c
vVhqXy41r4b1qyF6PajeDMo3/eJNL3/Tzd500tctOIgv6tGzavikHDws+vdz
3p20ezPhWI1al0Km/qK+49U0XErULitZxHmjIKPjJjXsqIoZUtAXZVSvlOIR
U5xisl1EsQopZiHVKKTphXSdkKEVMjUitkbEAbMV+NVAv3yNVPA5KFcj4T7j
FTIVfLqMR5VwyCIWQcDA8WhzbHD4/d9+Z17OT7+Y+0/CwC+8lvX2T7+Q8Nuv
Jt99PTX+9czUN3Oz3+IJ35MpP9JZL9iC1wL5Oyn0O6N3z1sDRFeM4s3QgyVW
BOUmGvxUG8rN9iRY0mxXmmlL0y1pqiFN1qTxqixWkcXK8mhJHi0qIkVlBL4+
AQkX1OGCJpzXhkA5bTCnDWS1gYx2Ma3xp9S+JOKNq7xxhTcmX4jKFqJSb1SC
JfZFRb6o0BcV+KN8WIwHi3N9Ca4vyfWluL4015vheXM8b57vLQq8ZaG3IvKi
Ym9N4qtLfQ2ZryH3NRXeptLbVGEhC6CG2tNQu7FcdbWzrnbU1JhiBFOsAorN
QHEFKJYayhJ9SawviWxNKdifrXWRpS6w1ABerhllm1GmBWVYULoFpVlRqrVG
sdbINhD6nLVKtlYolhLVUqSZC3RTjgE/DS3NMiRZ+gRbF2Nro2wNKMJSR5jq
MBOJMJAITRWhqqIUZZSsjBGVMQIsjlfGcbAYaB4WxamiOCRK0MRI2jjFkKCb
U2x7RuDOS/0lJIIaU01HseevL8V76/nVndrOQe/odO3icvf25ujp/vzj4/Uv
T3e/Pt1/8fvz9eXHi7Onk6P7g92bnc3LjZWzlQFwBwYoWIN3GpWtOsBbWAdg
n/HmYejoZRil9Xplo1ndbKFb7fp2p7Hbbe71Wvv99uGwc7TUPVnuna70z1cH
F+vDy41lsDPfbK3ebq+P8N7vbd/v79zv797v74262weE9wDhm52da3AoBkfj
zfWrjdXL9eUrMLhX+1er3euVzs1K62a5cbtcu11Cb4eV20Hptl+4wQbxZSt1
0Uic1WLH1chhKbhXWNzOejdS7tW4Yyli7QVMbZ+u4VFXncqSDd4sK2MQJLTc
qJodUjEDCoZPTl+Q0txSmlNCs0voVjHdLGYYxUyDmKWXsHUSjlbC1Uo+4/2c
GsxcOHa5CDjzilgQr4Au51GlXLKYTQTDl8+Y59Jm2ZRpBmmSRhwf+SX+f/0+
E/7zWhbmd/ztVxPvvpoc/3p66pvZ2W9x+O9JlB9prBcswWs+9Dupgn5xFuA3
TvVmGMESO4ryEk1hui0GZnN9Wb4vh/UU+a4i11Fk28pMU5luKNN1VaqGpFB1
EtUkUW2yqktW9YmKAcsYLxtjJWOsaIgWDJG8PpzThzK6YFobTKkDSSSQUAUS
ykBcEYjLsWTBuDQYlwTj4lBChCUMJoXBlAAUSAsC8NPkBYt5wWJR6C8J/RWR
vyr21yT+utTfkPmbcn9L4W8p/S2Vv4WAfC01yNvUgBZADY2noXE3tK66BuSs
aRw1jb2mtqGIFYYpripMVZmxIjVWJMCvtSG21IWWGt9cg3hNKMuEMkwozYxS
zSgFvroSJVlQIsiMEsxVENFcIZrKJGORZCyQDTmKPkvVp+GLObUJhibG0ESZ
gC0CCjNVYQYWXRmhKSNUJfAbIyvjJGWcqEwQsPCq53AgJIFHEgR1gqhNkPXw
+TKmNcN15kQLRXmwqonVzdm2uzwINleSg83i+l5z72h4cr5xdbV3f3vy/uHy
09MN8Psb8PsE/f5ye/Pp6vLD+enj8eHdPiAD5t3yyXL/sN/e79R3wFStlzfQ
IoY3v1rBgn4LqxjetXplvVHdaKKb7fpWp7Hdbe72Wnv99sGwe7jUO17un6wM
ztaGF+tL4GHhams0dtexsbt1v7/9sL/zcLD7cLCHtX8P2t8HhOEg3t0FSzU8
Gm9v3myt34CRvbl8s7F0uz64XevdrnXuVlt3K8275fodRvhmULruFa+68ER8
1kyf1JNHaOygHNktBrdyi+tp70rCPYjYu0FLy2+sLWgrTqRoU2TN0pRBFNfx
I2puCGEvKlk+BXNBznTLmC4Z0yFj2mQsq4xtkXFMMq5RxjPIeHoZXwfDVmUs
DC+UC8bun3ixzVnCIYnYBAETx6PPcWgzrJFfwjgF/44E/b7G/59+x//0O/4W
+h1789UY5ncc8zuF+Z3Hf0+k/Ej97FcC/c7q3HhLgOSM07wZZrDEjaKCRBPs
zNJsD+BVFAbKwkBV6IOQQg8pdNX5jjrfVudamlxLm2vqck19tmnINozZhilb
N2dANUsataSq5lTFnCyZE0VTvGCM5QzRrD6S0UXS2khKE06pIykkklJFUspI
UhlNKaIpeTQli6aksLQkkhZHMuJwVhzOiUJ5UaggCpbEwbI4WJUEUGmgLgs0
5IGmItBSBtrKQEcV6CCBjnoR1NaA/C0tyNfSepuwhYbOg+WuA8VaZ13rqH9W
XEOsNZW1prTUFGZUbkZlo+UZDF9zjWeqcUZ4jSjNiFKNKNmEkkwo0YQSTCje
VMUbqzhjBYQ3lPGGEl5fIOjyRG2WpE2TNSmKOkFVx2lIFMxZOgQLCsEUoDBN
EQFRFV/8JkjKJFEFShFAyOfUKYImRdSmyPo01ZihW8AJPc93FyX+ijJc0ydb
tnxvAV0Kd9bSy9uVrYP2wcny2cXWzc3Bw/3ph8ern59uf31//9v7h9+eHj77
vXh/dvpwdHC7Bw6e62erS8fD3kGvtduubYPFGEzYauEz3txKJb9SLaxAv6XV
Whnzi260apvtxlanud1t7fbbe4PuwbB3uNw/Xhmcri2BB4SLTYB37frPsYvh
PXjG+3i4//DcwRfFcBbDjXrnbnfrbmfzDqjfXr3bWrnbXLrbGNxv9O7WO3dr
bUD4drl+swR26cpVv3TRLZy1cyfNzFE9tY8mdsuxrWJ4PRdYSfuGCU8v4mwF
bXW/qerRF53qnE2ZNssSBnFUJwxreAGE61dxfEr2goLtUbBdCrZTwXEouHYF
z6bgWRR8s0JgUgiNCqFBIXy+TiUTjPwiYq5KzFE+48WOvWBz5pJFYPiywPDF
celzbCq2PJMmqIQxMvA7/4bw2e/c9IvZqZ9m/jJ/J7/4ffPN2Ge/Y5jfifGv
J6e+mcH8Eig/UlgvmILXPPmYWDupxPyaA2RnnO7NsAIlXgQVJpqSdEeWBTO3
D/EWB0hxoC4ONMU+SFvsgXTFrr7YNRQ7xmLHVOyYi20LqNCyFsD/Tk1bvmHL
1axZ1JqpWNJlS6pkThZMibwxkTPEs/p4RhfPaOMZDSiRUScySCKjSmSUWIpE
Vp7IyuI5kDSWl0YL0mhJGilLwxVpGJWFarJQQx5qKkItZbCtCnZUwS4S7KqD
Xc2oQEcLWmxrF1s6P6ip8zV1XlBDt/BMWOeCfVZcV9vralsdsdVV1rrSWldY
mxJLQ2SGfrmmGtuIMo0oHeA1oGQDSjSgBAOKN6A4Q3UeVpnXV+b05XldaV5b
nNfmcZosXp0B7ohIkqSKk+FuHKEowlRFiCoHBWmwEE0epoKg3xhFEacoE2Rl
kqxKkVRpEpIBEdWgLFEDI2mzZDDQDVm6Oce05bnOonChLAug6mjDmO44igN/
fSXW28it7qI7h92j05WLy+3b26Onh/OPT9e/vL/77cPD7+8ff4d+74Hfj1eX
wO/90cHN7vbF5vrp6tLRsLfXbe4AlYAnWloDWgHbcg60XMkvV6DfFbS0Uiuv
1itrDXS9WdtoNzah3/ZOv7M36O0v9Q/BEr66dLoOn+G9xPDe7G7e7m3d7cOd
Gco9BHIhXqwD0MOXDvax9h72d+GM3tt+2Nt82F1/2Fl92F6531q63xzcrffu
1jq3q3CRvhrWLgfV8175tFM8buUPG9m9WnqnktwsxdfykeVMcJD0d2MLrbCr
FrBVvOai25BzaFJWVdwkj+olIa0woOb7VTyvkrug5HiUHLeS64LxnCq+QyWw
I0IbIrIiYotKbFaJjUqxQQEvNf/FL8DLVgiZcgFDxqeP8Io5JOFo+DLmObRZ
FnWaQYbLM4WALc/Q7/8Yvj9OT/zwefh+N/HuWzB8Mbxfv3vzFeztV2PvvhrH
/E7PfjtH+B5P/ZHMeskQvuFCv1MK65zWQzAHKI44YyHDDhT5EVQUb0pTbXm2
p8yBsQvkDjUlmLY00GHpy30DlrHcN5X7lnIPZC13beWuvdSxl9r2YtNeaNjz
NVsOtWUr1kzZkimZ0wVTKm+E5QypnB6W1aVz2nROg6VO55B0TpXOK1N5RbKg
SBbliaI8XpbDs3ZVHq3JI3V5pKmItJThtircUYW7SLinDvU0ob4m1NPCutpg
Vxfs6AJtGCTc1IN8oIbe29AvNPSQMJYLbNQNrbOhcTTUjgZib6qwlJhfobnO
N9WBX5YRZRhQmgGlGFCSoUrQV/H66jzWnK4yC9KWZ7WlWU1xVl2YQ3JzSGZe
lcYpk3hFnKCIEeQRoixMkoXIsiCI8jmqLAT9yqOUZ79JijJFVqXJSIaMZMnq
HFkDypO1ebIuT9HnqYY83VRgWoscR4nvrkh8qDJU18ZblmzPXVkKNNcSg63C
+l5977h/cr52db17f3f8/vHi5/c3v364//3DI+z9I/R7B/0+YX6vd3eA35PV
pcMB9Lvdqm0AnmhxFYAt55fLuaXn8kuVwnK1uIyWV2qV1Tq61qyttxobneZW
t73d7+5Cv4PDleHx2vLZxurF1trl9sY1xLsNVvR7KHeEd//xCHSAdfifHWCi
959ge08HO0/724/7m4/PhJfvN4d3G/2bNXAWbl8uNc4HtdNe9bhTPmwV9xr5
HTS7WUmvl5Ir+dgwG+mlgu24vxFZQAPOks+W95gzTn3SqomZlGG9LKCV+NVC
r4q/oOR5FFy3gutSQLkuFd+FCFyI0KkWOzUSh0Zq10htGqlVLTUjUpNKYlCK
dXKhRiZQS3mqP/3SpXyahEcRg+HLIQpYBD4Tx2XMscHy/KdfuDwT5v/n8P2M
Fw7fz3ih33evv3oLwvy+e/fV2PjXE1PfTM19Ozvyy35JF77hKMZFummFdV7j
IZqCVHuc4clwFov8MCqONaTJtiLTBX6R/EBdGGqKAO9QVxrqyzBDeWiswEyV
gbk6sFQH1mrfVunbKz17pWsvA8Ite6lpL9bthZotX7XmKtZs2ZItmjMFEyxv
xDJkYfpsXpfNa2EFTbagzhSRTFGVLilTZWWyrEhUFQlUEa8pYg1lrKmMtlXR
jirSRSI9daSvCYMGWlhfBwr1dCHMb7CtD4Ba+sUmzI/5/Uz48y7d0LqbWldT
42qqnU3E2UIcLZWjpbQ0xZhfnqnOMdaYhhrdgFL1KEmPEgFeXXVeB+RWZ7WV
GZCmPK0pTauLM0hhRpWfUWZnFelZRXJOnpiXxXDSKE4axktCBEmQKAmASJIA
GSQNkqUhiixMkUUpcuA3AfBSVGkKkqUgOYo6T9EUKNoCVVuk6opUfZFmKNJN
JaalxLaVeU54yV22WEciLUOqaysMFtCVcGcjtbRT2jxoHpwMzy42rm/2H+5P
Pjxd/vL+9rePD398fIIBv48Pv9zdgvPv0znwe3izB/xunKwuHw57u93Ws99q
aQVoBWbhm/5G5YflwrBSXKqWltDycq262qitNevr7ebms98+9Av28PWVs821
i+2Nq92tm73tWwzv/eHew59s/7fcI9DT8SHoPezg/dH++6O994c7TwdbT3sb
j7tr99tgix7erMNrWRdLrdNB47hXO2hX95ql7frzi0yWC6lBLtFNR9vJUCMW
QMO+UsCd9zoybmvSYYxZdWETEtArfBrpAiJyKwVOBd8h5z6n4DmUfKdK4ERE
LrXYpZW6tDKXTu7UKRw6hV0rt2rkZrXMqJLolSKt/E+/ciETDF8JjyrmUkRw
+AK/eB5znkOHfpmUKTp5gkocB8szEQeXZ9zsy/kZOHy/4J38E++3n/F+/faz
37cjvxNfj08Dv9/NEn/A0X4icV7RRW+BX6FuWm6dV3uIxiDVFme6M1xfURCs
iqMNWaKtSHVVmb46N9Dkh9rCUFfE/JYg3pFfU2Vorg4tWNbqwAYIVzG/lY69
3B75tY385ivWXNmSK5lzRXO2YMo9ZwTlCwYsfb6oyxW1uZImV4J3q8iUkXRF
laqqkqgyUVcmGqp4SxVrI7EuEu2po311dKCJDLSRIUgXGcAg4Z4+BOrqgd8g
5jeA+V1s6P2NEeHnRXqhofU0QRo3qKV2tRBXS+VsKZ1t6NfcEJigXzbml6ZH
KQCvDuLFAbxaDK+mMg3wqktTSHFKVZhS5aeV2WlFZlqempElZqTxWUl0Thye
F4fmRUGcKIAXLRKwiOIACSQJkaVh8me/VGWKqspQkRxVnadpCjRtkaYr0fQl
ur5MN5QZpjLLUmHbKjxHVehGJb66MtTUxjvmTM9ZWvLXV6O9zezKbnX7sH14
unx+uXV7e/D0cPrp6erXD3e/f3z849PTPz6+/+PDE1ihf72/+3R99f787OH4
6GZ/92Jr82Rt5XDY3+22t1r1jXp1tVoCC/MSMFvMDb5Uyg/KhUGlOIRv4K0s
19HVRn2t1dzotLd63Z1Bf29peLi6fLy+era1frGzebW3DX7zu4O9e3DIPToA
PR4fPoeBfe4Y9gQ6OXp/cvQBdvjh5ODDMSC8+/4QjuCH3bW77ZWbjeHlau98
uXMyaB7Cl3dWt+vldRTsCblhIdPLpdrpeDMZrcVClXCgGPTl/J70gjPutEZs
pqBZ7zeoF7RKNyJzKMU2ucAq5VkkXLOEA7JIORYZ16rg25VCBwImr9Slk7n0
CrdB6TKonAaVQ6+y6ZQWrdyklhlUEq1CqJbxVRKuQsSWCZhSzK+ISxZySAI2
gc/Cc8HyTJ9l0aYZlCkaaYJCBIdfuDzj517Nw+H70+zUn3gn/lybv3n3BsiF
eN/A/g57+9Xbd1+9w/xOzn83A/zSoV+a+B1bOSHUz8hsOGSBZAjSrHEW/LjJ
ojBQlYTrslhLkeyo0j11tq/JDbT5oa4w1BdhBoywsQz9QsKVEeGBtdK3Vnq2
Ctii27ZSy1ZqWIt1awG15quWfAXDi/nNFZ/95kFFI6hQNMBK+nxJly9rc2VN
toK9872KpGtIqq5KNpBEC0m0kXhXHeupY31NbKCJDrWwJR30O9RHBrBwXx/G
/IbaumALFmjCFhswf0Png2m9De0Cdmna01R7Wmp3C3G3VK620tVWuNpyS1ME
/Ta4xjrLWGMYamD4knWYX211HuDVYHjV5SkE4p1UFSaV+UlFbkqemZKlp6TJ
KUl8WhydEUVmRKFZYXBOGJgTLM4L/DihHw8DigNEcZAkCZOlwG+cokhSlWma
KktT5+iaAl1bpOtKDH2ZYagwjRWmqcoyVznWKs+OClw18UJdvthUR9qGZNea
G3gqy4HmemKwnV/br+0ed4/PVi6vtu/uDt8/nv/8/vq3j/d/fHr8x6f3//z0
4R8f3v/x9Pjr/f3PN9cfLi4eTo5vD/Yvt7dO11YPl4Z7vc4WWIkBzGp5GUxb
ALaY6xeyvedyvWK+Vyr0y8VBtTxEq8v12mqzsd5ubXY7289+V4431s62Ni93
t6/3dm8P9u4OD8CUf4Bsj/7aA9bj8THoCXRy/P7k+MMp7OPp0cfTw4+QMBzB
wO/97trN1srl+uBsuXs0aO136tvN6nqttAIeTwrZbjbdTCVqiVglGi6GgrmA
P+3zJjzuqNMRslkXzUavQefWqh2IwqqQmmUio1igF3F1Qo5WwNYKWDohSy9i
GyRck4xvUYAzr9ihAZMX4FW5jYjbpAY5jWqHAQGEzRq5EZHqlCKwQn/xK+HT
xTyqkEMWsIl8FoHHxHEY82z6LJM6TadM0kjw8EvCw+V5NHyxzfmHqYnR2P0O
jt23f47dN69Af3896vXfX7/9+5sxzO/Mt5O472ZIP87TXxC5r6Ff1aTAMCu1
4VULZH2QZomzHBmepyj0VyWhuizaUsY7SLKrTvc1mb42O9DlBvr8UF8YGoow
YwkjDBuYYX0zPAV3LaWOpdSyFJuWQt1SqJnzVXOuYs6VTbmSKQvkFr8M32e/
hVElzG8Z81vR5qqaLKrO1NTpOpJqIMkmwKtOdNXxniYO8WpjmNzP6aHf4Re/
unBH9+y3CQs0YBhhrb+h9TU0IG9TvQBqIZ6WCuRuK90YXldbZm4KzQ3+yC9c
nqFfkg4laKs4bXVOU5n9jHdSVZxUFiaU+QlFbkKenZSlJyWpSXFiUhSbEkam
hOFpQXCaH5jhL87y/bN83xzfBxULAOEAQQQ26jBJGiXLPvtFsnR1nqEpMnQl
pr7CNFRZxirbhHLMKNeK8uw1gbMu9tRlvqYq2NLGOqZ031FY8qKro+W5uHHQ
2D/un56vXV/vPNwdfXg8/+X9ze8f7//x6emfP38Afv/58cMf759+e3j45fb2
w+Xl4+np7eHB1c7O2cb60fLSXr+73W5uNGqraHmpXBwW831gNp/t5jMdWLaT
z3UL+W6x0CuXBtXKsIYuN+qrrdZGt7PV7+8uDQ+g3/Wz7a3L3Z3r/T3wm98d
Hd4DqifHj597OP6PoN+Tk/enJx9AZycfYccfzyBh4PfpcOdhf/N2Z+1qY/ls
pX80aO91GpsNuCEMivlONtNIJavxWDEczgWCKb8/vuCNuNxBu9NvsS2YzC69
wa7RWFQqo1yul0g0QiHC5ym5bAWHKWcz5Gy6gkNXchkIn6kRsvUSnlEutKgk
do3MqVcCvB6TxmPWgtxmrdOosRsQi05pVMv0KolGLlRJecCvFPMr4kK/fDaR
B4YvE8dmzLFoMwzglzxJJY2TCXB5hsN3Fg5fbHP+fnL8L2P3r3Jf/v0V6NXf
Xr36+6vPft9Ofj0G/X4/Q/5xnvGSyHtDk4yxkEm+YVZih351QbopzrJneO6C
0FuRBGryMDxpwnmX7GlSfW2mrxsRhooH+sLAACoOjLC+sdjD6pqKbVOhZSo0
Tfm6MVcz5qrGbMWYKRkyRawCyJjF+rw8G7ERbMiXQNBvrgLSZquaDKpJ19Sp
hjrZVCdb6kRHHe9CvHEMb2wkdxmkh36XvvjVhbvPfkMtbbAJCzSeW2xo/DC1
r6n2NhH4Go+WaqGl9LQVnrbc3Za52lJXWwL8mqBfjrEOD7/6GgX6xYavpgL8
zqjL02DyqkqTyuKEIj8hz03IshPSzIQkNSFOTojiE8LopCA8yQ9N8gJTvMUp
rn+a65vh+mZ5vjmeb54PCC/iRUGC+ItfuDzTkRxDU2BqS0xdmWWosI1Vjgnl
mmvYOxnrQkdd7G7IvE3lYksTbhsSXWt24C4vLzbWwPKcWdktbx00D08G5xfr
N9d7j/fHH58ufv1w+8enh3/+/P5fP3/4188f//XpIxjBvz8+/noHV+in87P7
o6Prvb3zzc3j1ZX9QX+7094AJNHqUhkCATO3m8t2cpl2FtYCX+Sy7UK+80y4
ulSrrTSb6532Zr+381e/e7vXB/u3R4d3GN6Hk5NH2Cn4Anb8Z+DnTyen709P
P5ydfgSdn346P/kECJ+Cg/D+4+HO/d7m9dbq+drS8VJ3rwseXtDlSgn8wZrp
VDUeL4QjmcVgwuuPuBcCdpfP4nCbrA69yabRm1Uag1yllcgRkUTBF8o4PAmL
LWIwhXS6gEYVUCkCGkVIp4iZVBmbruSx1CKuXiowKSXgqAsWZpcR4NUtWPQL
Vr3HoneZdQ6jxqpHTBqFHpFqFCKVlC8Xc4BfMZ8u5FIFHDKPTeSy8BwGjk2f
Y0K/UzTyJIU4TiK8I+De4OZezc28mME25y94sYX5r3L/9urF316+xHr1t5ev
//7q7d9fQ7/fjM1+O4n/foby0zzzJZH/hiodZ6mn+MY5iYOg9JI1IboxzrZm
eM6CcKEi8ddkwYYy3FJFMTWJnjbZ06Z7OqAYQu7rc1j5HlYXq6PPt/W5pj7X
0Gdr+gyqz1R06bIuVdKlirpUQZfKg/TpHCyT148uXuUKWEVDrqSHlXVZiFeL
4dWk6upkA8PbBn8MbPgONBhe7We80G/k2S92BO5Bv6GONtTWhlqaYBOroQlg
LTbUIH8D8TVBKm9LCVpoQbyetszdkrhaYmdLZG6C5ZlnrI/80oBfsDxrn/3O
qsszSPkz3gLAOy7Ljksz45L0uDg5LkqMC2PjgsgEPzTBC05wA5Nc/yTHNwXz
QsU8H5jF84JFnDCIF4eJ0ihJlgB+acAvNnyZuhJLD/FyMbx8S00wwutqSD1N
hb+FBNu6aMec6jnyw4XqSrAFluet/NpudeewfXy6dHGxeXez/3R/8unp8rcP
t//49Aj8/vuXj//+5RMgDEfw09NvcIW+eQ9X6JOb/f2L7e2TtbWDpeFOt7vZ
bK7W0KVKeVAqACYdABbIzaSbo6DiEeFiD/waFIzgxmq7vdHr7QyH+6urRxsb
Z9vbl3t71wcHt0dHdwApYHt6+nh6BoJfg45P749P7p/9nj6dnr4/O/twdvbx
/OwT9AsUg0X6CPh9ONi53d243Fw9WRns99ubrfpytdzN5+qpVCkaywZCca8/
5Frw21wek82hN1vURqNSp5Or1RKlUiiT8cRijkDA5PLoLA6FziJRmUQyg0Ck
4wkMPIFJgJ+YxqWQBXSqhM1Q8DkaicCgkFjUCrsecZm0HojXuGCDua0Gp1ln
M6jNOqVBLdMqxSqZQC7mSoWskV8+8Msicph4NmOeRZ9j0GbolCkqeYJMHCPi
3+LnX4PhOzv90/QkPPZOjP0VLyYXsIX914svQb9/g37Hv3o79c3Y3HcThB9m
qD/Ns18RBW+psnGWZppnmhM7CAovRR2iG+JsS4ZnLwjdZYkXlS02FMGmKtxG
AOEYGHxdbaKrTXa1qa42jZUZ1dFm2tpMS5tpatINTbquSaGaVFWTrKgTJXWi
qI7n1fEcVlaTgGmTWW0qq0vldOmcDkIugHTZoi5b0mXKWlC6okmD36SmTtbV
iYY60VLHMb+x/7E5Y37/Ay+8fqUNd7WhjibU1gShXzWsoQ48hyw2EH9T5W8q
fS2QwtuSL7RknpYUwytytoQOiHd0+GUb6s8Xr0Z+NZV5dXkWGQ3f4iTEm/+C
d0ycwvDGxwXRcV54nBsa5wbGOYvjHP8E2zfB9k5yvEAxRhjs0oF5zC9BGiPJ
E5TR8qzJM7VFlr7MMUC8vM94Rfa62NmQuhsKsDAstrThtjHetWb6ruLQX1uJ
dNZTS1vFjb3a3lH35HTl6nLr/ubgw/3pL09Xv3+4A37/hfn9718+/fvnT//6
+PEf799/XqGvgKnbw8PLnZ3T9Y3D5eXdXm+z1Vqr15arlUGp2ANOc9lWNgPk
NtJYz4ThPSS7pVIfjOB6fQWu0N3t4XBvBfo93d652Nu/Pjy8PTq+Ozm9B2xh
51iA8Nk9CBKGkB9Pzp5Oz6Df8/OPF+efLs5AH8/BLn30dLx/f7BzvbNxtr5y
uAR2g9ZKrQq291oqVYxEU4vBiNsL5LpNNpvWbFTptTKNSqySC+QSrkTIFvIY
PDaVzSAzaAQaBUcmzREIMzj89Dx+ehZEmJ4lzc5R5ufpQDEgzKBJuWyViK+T
S0xqhU2vdpl0HqvRazd57WaQx2ZyWQx2k9aiR4wahVYpQWTCkV8Rny7gUnls
Mhfzy2LMM2mzdOoMjTJFIU2QCGME3Nsvw3dq4oeJ8e/G3z3jBYdcMHMB25c/
/dcLrJ9Gvfivn17+7cXrv72Efr9+O/3N2Px3k8QfZmgv5jmviaJ3VMUEUzvN
M8+LnAS5j4KE6Lo425Tm2fJCZ1nsqcp8dcUiPGch4bY60tZEO5pYRxPvaBJY
yfYoOBzB4TQJjqh1VaKmSsA7PqliJWUM3mtRGckpI1llJIOVVkXTCCiWVsfh
azY0yawmmdOmQHltqqBNFTWpkiZV1qQq6mRVnaipE3Uk3kRiLSQGH0PU0b4m
Ohhds9JGlnR/NtSFQdCvNgyfAh7hVcOaCAiwfa6pWsTw+psKgNfXkntbsoWW
1NMSu1siV0vgbPIdDS5Yno11zG+NoYd+yboqUVvBgeUZDt/StKo4BY69CoA3
B/COYXjHRIkxYXxMEBvjR8a4oTFucIwTGGP7QeNs3zjbixH2wV2aB47DgTlh
CCeOEKRxkjxJUWVo6hxDWwDDl22ocIxVnhkFeIUYXskI7wL8k4O/lyHasSS7
jlx/obIUaKzGehuZle3y1l7j4Kh/drZ6c7n9eHPw8f7s16erPz7c/fPT479/
/vDfmN///vnTvz99/Od7uEL/cnf38er66ez87uj4anfvbHPzaGV1bzDY6nTW
Go1lFB2Wy71CoZPL/YdfSDjTBD/M5zulUq9SHcIVurXe6W4NoN/Dz36vDo9u
jk8wv+cPZ6CLh1PQ+f3JOeYXBiyDBxDwZ3gP8V58vLz4dHn+6fLs48UpfG/F
8cHdwc7l9sbJ2vLeoLfebAzK5UYmW4zGAd6wy+u1OB16iwkxaGQahVAp4Ur5
LBGHzmdSODQik4yjEebIuGnC3CRuZnx2amx68u3k5NuJUdNjE7MTU7jpGdLc
PJ1I5NCoIjZLLuRrZBIjorTpNS6zAZj1Oiw+p9XrsC7YLW6ryWHWWw0ao1ap
VUkRuUgu4YFHChGfMfL7/+i6C+ZGrnzx+y/nf+/epWw2mcmQ2RYzMzObbaHF
LIMsybItyUIzMzPTcLLJvpbndMsDe289Vd9SSZpJ2Unlo985UqtbLGSIBDQB
j8LnkrgcAoeFYzExDDqKRkVQyM0kYiMBX4/D1mLQb9DI7/BCbJ811EPVV2t4
Vg/5fQ75Rb1swb5CEt+gqbU4Zj2R30iRtDBUKI4BK+ggSs3AL0ML+23vF3XH
pZaUwj6qcmY07pzOmzdUCYeKreEiUNwaLbbGnoJk9eeNsQlDLGeIZfXRjD46
rouM6sJpbWhEG0pqgwltcFgTGNJCDWqDg7rgoD40qA8PGSJDkOXYMAjM5daB
ZOtAqnVgBJrX0NQeN/VnTP1ZU2zCFMubokWwBjBFK9CnvZHpNvgDI+AXIhye
heVCeNsBXuhADoC33BosAbyw3IIRKm+s3vGDzSOM11fUeYtakKekcZdUrqLS
+QWvbULUMwEvnnNCyG+W05FltWfobePU1jGyaZRoTBMMIzh42/sVL0o5iFL0
o+QxlCyCkoZRkhBKHECJ/CiRDyX0ouGAYqzYC5bTYEdMlAdJyjBFHaVpB5j6
IbYxwW1L8Tvg4ds9LoHxyr/i7cvrXHkj2LMHCh3hYk9/2To82Zee9mZnw6WF
wZnl1NJaZmOruLc7fXy4eHmyfnu+83h1+OH29PP95W+PN7+/vfvj3cMfX/3e
33+6uX1/efV4dn53dAzWsWdb20era3sLS1szs2sVIAVMutzM+PhUerSSSpWS
ycLwMGD7zW8C9psenRwbn87m5vKFxXJlZWp6Y25+Z2l5f239CPjd3j3fBX4P
Yb/HTx0cX4H2q4qPrvePbg6Obo+O749PHk5OHkGnEOGHYzCRIb8XW+vHa8u7
C3Nrk5X5iVx5JD0+ODQcDEdcXo/FYeswdxk6wMxVS7UygULIkXAYQiZ8bXAS
nk7AULEoEhqBRzZjWxrRzQ3IpnpEU31Lc31LSyMC1YTEINAEDI5KILGoNAGb
LRMKNXJZq1bT1Wq0dnX0mbuBWa/D6uuzeftsHofFZet1mLus3e09HcYOk86k
V+nVMrVCDPzKJFwJ7FfIh/zygF82gc3CMRkYOg1FoyDIpCYioQGPg4YvGvUa
iYCWzU94Ibk/19dB1YHqQcDvs/qm5w0I2C/uFZL0Bk2rxbEbiIImqhTBVKO5
Rpywkyi1UJR9DK2PbQwDv8KuuKQ3JbeOqhzjGmdW55kwePPg/3mgALIQKpjC
cJG8EWrCEMnpI1kdfKInTWhUE0yrAyMqP3RyY5UvrvQOKb2DSs+A0tMPUnn7
1b5+jb9fGxjQBgd0AHJoyBCOg9FsjCaM0aQxljLFRsDsNkbHjNGMMZoFPwL+
QdAawBSutIYnW+GjNdrCM+1fC4Gm2+HjrwDe1iDAWwY7RFOgWDVr+Jq/oK8G
8Pq+4PWU1G4Ir6KvIHMUJLa8yJoTQMM3B4avoCvLg/xmmO3j9LYxauso2Zgm
Gkbw+hQOes/qadn8Hd7oF7xBlAj2K4T8VkODKQzW0hI/XhogyEMkZYSijtF0
gwxDnN2a5LaP8DtHhd3j4p6M1JyVW3PwsnmiitfgATv3Qkeo2B0tmQfL9uSk
e2w6kJ+NVhbic8vpFejaZOWD3ZnTw6Wrk4378913V4cfb09/vb/81+PNH8Dv
24d/A8JvH39/fPjt/v7zDbwFPrsAcMCG9Hx753htY39peXt2fn1yeqVUXpjI
z2ay02Pjk+l0OZUqJpKFRCJfVZxIwH5HSkD32PhUNjc7UVgolZcnp9dn57cX
l/dW1w83tk62d8929y/2Dy8B2MOT62oHJ1dQgDAEGXC+OTy5OzoBK/mH09PH
09O3Z+AWWAYTGWycd863No5Wl3fm51Yq5ZlstpBMpWMDA96g3+ayd1m6DJ0A
L1jDgpnLZYoYFC6ZwMRjaBgkCdmMb27ENtaj6msQtW+aa143vnnV8OZl/ZtX
9bWv6+trGhvrmhFNCAwSQ8KBCU3lMdkSgVAtl5u02q5Wk7Wrs8/S67ZbvX12
n9Phc9oBYbfd0mfpsfZ09nS2drTqTXq1XiNXK8UKmQD2yxYJGAI+jc+jcDkk
DpvAYuIYdAyNhqRSWoBfAr6hOnxRyFeIlpfVZTPA+yS39qdaqJ9rIcLP6oDf
ZuD3RRP6ZQv+NZJcg6HX4TkNJGEzVY5gatBcE07YRZJaqUon5NcQ5rX1Czvj
kp6k3JJW2sfVfVmtK6d/IgwHplgQNGEMTRhCOX0oqwtmtMFxTWBU7U+rfCNK
b1LhTcg9w3L3kMw1KHMOyJzQ9/plfVGZMyp3RhWuqNIdVXliam9MA1keAHNZ
FxzSh+L6UMIQThrCKUM4DZ2wMTxuCGcM4ZwhlDeGCsZQyRQqm0KTraGpVojq
9H8UnGoLTrbCh0CbAN5AyQjhLX4D+y1ILoQX8lvFCw1fBRi+fQWpPS+2TQgt
OX53Dh6+WTB8uZ0Zdvs4s22M3jpKMaVJxhGiIYWv4tXE0epveJGyKFIaQUrC
SHEQKQogRX6k0AfnRT759aHFfugdLVmIoAgTVVGyZoCmH2IYE+y2FLcjze8a
E/ZkJOaszJqT2yaUjgl1X14L4wV79vZgoStS7B0o2YbLzvSkNzsdKs4NTC8k
FpfH1tcndrYqR7tz54fLNycbD+e776ErpJz+dnfx+8P1H4+3/357/++3D388
Pvz+cP/b/R3s9/rtOfALb4G3d0/WNw+WV3fmFzemZ1fLYASX5nP5mUx2anS8
kh4tp0aKyapiOHD/q99MbmYiP18sL1Wm12bmtxaWd1fWDta3jrd2T3f2z/cO
LyGqAO9ptauDU5gwZBngvT06vTsGeM8ez87enp2/PT+DCR/fHYPV9e759ubh
6sr2/NxyuTyVyeYSqWSkP+L2u8195raeVk0bmLwSnpzLENJIHCKWjkGSEU34
xnp0XQ3izaumVy8aXjyvff6s5vnPr5/99PrZz69+efb6xfM3r1/W1r5paKxv
RrWg8RgCjUzlQn5FarnCpNN1tbVZu7udVovHAfD2+V1Ov6vP63S4HdY+a6+t
t6u3s62z1WAyqHWQXwnwK5VwxSK2EPbL41I4HBKbRWAysXQ6mkZFUsgtYPGM
x9djsbVo1Bsk4hVYOTeB7S1YJ4NpW1eV+1NNtbqfa8GTVb/IF00Y2C+lBsOo
w3MbSeJmmgLJ0mG4rXhhN0lqoypdDK0f9jtQ9Sszp5W2MbUjowUj2F0lPGHw
TRj8oBxIH8jq/Bmtf1zjH1P70irviMKTkrsTMtew1Dkk6RuUOAbE9pjYHhXb
ImJbuJrEHpbawzJHWN4X+Q5yv8Y3qPEPaf1xXSChCyT1wRF9MK0PjumDGX0w
awhOwNOz+OV7CpMmiOrUd01CBSomqLIR4PUDucUqWJ0Pzg/3Va6vBOH1ltSe
kspdUsJ+oeFrn4CGrwX6qgLACw/fDKdjnNU+zmgbowG/xhGSIUWAjtNIYDVx
jHoIrRpEKWG88ihSFkFKw0hJqOoXIfQjhD7EE2EoMI7BjhgjDeLkYbwySlT3
k7WDVMMwozXJak9zO8f4PeMic1ZiyclsEwpH9Q3nvN6TN/rybdDKudATK1qG
So5U2T02GchPRytzQ3OLqeWVzOZ6YX9r6mR3/vJw5e5k8+357ofLw883J/+6
O//9/uqPh5t/P96B/ni8//3h7re72883Nx8vr949+T262AFb4O3DlfXdheWt
2fm1yZnlUmUxX5yrEoam8BhYu5aAWQAZrjSSLqfHnvzm8nOF0mJ5anV6bnN+
aWd5bX9t82hz52R7/3z38GL/+BKAhfCewZ1+7ebo7Pb47P7k/OHs/PH8Arye
vLuACD+end4fH10f7J/vbB2urW7Nzy9VKpOZXHY4NRzuD7n8zl5Ht6nboDTK
RSo+SwwmL8CLRpCaG7B1NcjXL5tePK9/9nPNT/989eM/Xvzjh1/+8ffnUD88
/+ePv/z800tA+M2runowgpvROAyBSqZxWFyJUKxWqFr1hu72Dltvr9Nm8wK8
blfA7QK3Plefp8/utFls5u7ervbONuBXo9MoYL9CqYRX9cvn0bjAL5vEYhEY
DCydhqZSkGRyM5HQiMfVYzC1KNRrBOJlc/OLRrDDBXMWaAVma0D/hG4hvz/V
1P9c2/is7snvqxbCGxS1FsOsx/MbyZIWmhLJ0mN47XhhD0lqpyrdDA3wG+G1
Dgg74uJuyK/COqayZzRgBD8RhvNmQTpfRucb13rHNN5RlSetdKcUrqTMOSzt
i0scg2L7gMjWL7RGhZaIwBwW9IYEvcFqQnNQZAmKrSGJLQRDjsj7wESOKd39
Ks+A2jOk8ca1voTWl9L6RnT+UZ1/XOfP6sHLhR/ahhv8ACbgWXUKmoT7+rAM
/am/ZKji9T3J1f5HT2O3ihcavt/8gsVzHvabFZgz3O6MoCvD78pwO8dhv2OM
tlGaKU0xpkj6JEGXwGvjWPUQRjWIBngV3/AiJCGEOIgQBxCiJ7xfA+MY7IjR
kiBGFsbKI3hVP1EzSNbHqcYkvW2E1TnK7R7n92bB9AcbcPDLKPryalde68mD
3TrYv7SHCl3RgnmwaEuUnOmKLzsZKs70T88NLyym11ZyO+ulw63ps92F64OV
++PNd2e7Hy8Pfr0++dft2R93l/++v/43IPxw+8f97e93t7/d3ny+vv54efnu
7PwB9nu5s3+6uXO0urG3tLo9B0bw3GplGhBeyJcA4dnsxPQ4pLgyOgb2vOUR
OCAajOaxzOR4bhr4zZcWS1MrU7Prc4vbi6t7qxuHGzvHW/tnwO8e8Ht69YT3
S0dnMN7zu5Pz+9OLx/PLtxeX7y7hLsDDM+jwksOD892do/X17YXFpcrUZHYi
mxgZDg8Av309ji5jt05hlAqUYPhSiSwsitLSiAN4X71ofP6s9qcfX/3jhxd/
/9uzv/7lp7/8+Z9Qf/nn3/760w9/fwYIP3/2+tXLuvpa4BeDx5JoFAaXzZeK
ZVqVts3Y2tPZbbdY3Y4+n8sV8HiCXk/AA0a+y+N0OO1Wm7mnt7ujs91oMmp1
WqVaKZXDfkUitkDA4MF+2WwSk4kHfmk0NIWCJJGaCYRGHOS3BoV83dLyEh6+
z+u/+f3nm6d+elP7xW/LLw2oF03YVy3ENyhaLZZdTxA0kaUtdDWKZcDyOvCi
XpLUQVV6GJpA1a8A+O1KSnuhkycrbeNgBGv64CnsAoozUJ5xrWdM4x5Vu9Mq
14jSlZL3JaSOYYl9SGQbFFr7BeYYvzfC7wnzukPc7iC3K8Dt8lfjdfv5PX5B
b0BoDgDIEmtIagvL7BG5I6Zw9itdgyrXkNo9rPEkNZ6U1pMGLxE6b0YHXjG8
E3pvHv56fglk9JWh/P+rEvyn0Lf4q3i13qc0cNrqu1VVuV/wQotn2K+8D/Zr
ywG/fPM4RKlrnAfwdo6xO8aYbaP01jTVNEI2JEn6BEE3jNMMYdWDGNUAWhFD
fcUrDSEkX/D+b79+aEUNNsXSEEYWwSpiePUAURsnGRLU1hF6+yira5zTA350
TmidkNjzsr68wlVQe6B/EbD8aA0VOqKFnoGiJV50jJTc45VAfipSmRmcm0su
L45trkzsrZePt2YudhduDlYfjzffn+58utj/7eroX9enf9ye/xsQvrv69931
H3fXv99e/3Zz9fnq6sPFxbvTs4fjE8jv7v4Z8Lu2ub+8tgON4IX1qSrhycVC
eX4CHsRPijOTY5kKkAuVqYxlIb/Z/OxEaaE4uTw5uzazsLmwsrO8sb+2fbS5
d7pzeL53fLEP1syA7fn1EdQN1MXt8cXdycX96eXD+dXbi6t3l9fvr6DeXYKH
Fw9nAPjRxd7e0ebm9tLy8tTMVK6YS44mokMhd7Cvt6/L1KNTQn45dCHY9oI9
b1M95s2r5l+e14Gx+8Pff/nrX37+8//8+Kc//eNP//3Dn/70w//86Ye//PnH
v/3tpx9//OUZ8Puqvr6+BYnAEfAUBo0t4InkUqVea+ho6zT3mPtsDo/T7fd4
gz4fnNfvcXtdfU6HzWbphf2anvyqpHK5UPLklwn8cjgUFuyXTsdSaWgyBUmE
/WJx9Wh0LfLJ74sG2C/Y8IKxC8l988/XNT+9hvz+XAOeb3wO+33ZhHvVQnqD
otdiOQ0EYRNFjqBrUGwTltdJEFlIsj7Yb5Clj3JNA4L2uKgrKekZkZlH4REM
CI9r+sY1TjjXmMY1qnaNqpxppTOl6EvKHQmpPS62DoosAwJzP783yuuOcLtC
nM4guyPA7vCz230sKC8b1OHldPh4XT5+t1/QExD2BkXmkMQSltoiMntM7uhX
9A0qnXGVM6F2JTWuEfAqoXWPa90ZrSen80zoPHm9t/qhbekp39eqbIvgL+jg
ILae7yt+qfQ1gBfe/Ja+vHkF5i/wmxFAfse4XWMw3lFW+yijLU1vHaEaU2RD
gqQbJmjjOM0gVjWAUfajFVGUPIKUhZFVvJLA//Hrh4LxgqU1ShbByGPgn8Vr
hsAcJxlTFPDi0DnO7M5yzDmedUII9uDgl3EVFO6C2gst+8H2vy1S6Oov9A4V
bcmSc7TszVVCpanY9Ex8YX5kbTGzvVI4WK+cbs1e7S7eHay+Pdr4cLr9+Xzv
t8vD36+O/wCEb87+fXvxx+3F7zeX/7q+/PXq4tPFxQew0zw5vT86vtk/BPMX
+D1e2zpYWd9bXN2eX4IviDC3ChbS5SnogghAcb44mytAijO5qfHc5Hh2cgzc
giams4WZidJ8YXKpMrM6vbAxt7y9tL63unW4sXuydXC2e3Sxf3J5cHYF+b0A
cm+OAd7L25PL+9Orh7Orxwtg9ub91c3769sP1+AWIgyW07cnp5cHhydbO2BD
vTozP1Oo5NPZVH8i4o24rO6eNrNB1SoTqjlMEYXAQiNJYNv7+lXT859rwJr5
b3+F8f73D//1X3+r9qf//vuf//yPv/3t5x9/fPEcrJ/fNDY2otBoIpnEYLP4
IqFMpdSZDG3dnT02i93V5/J5ANtAyB8IBQJBvz/g9XhdTqfDbof8dsJ+dcCv
CvIrAn6FIjZfwOR+8ctgEmjf/Lbgq34xwO+blpZXVb913/z+9PpLb+p+fgOe
b3peh3jRgH7ZhH+NINegGHVYbgNR1ERRIBhaFLsVy+8miKwkmZOq9DI0Idjv
IL99WNiZFHePVEewwjamtI+pHGAvPKbuG1VBpZV9IwpHCsiV2Ycl1iGxZVAI
5PbEeN1RbleY0xlitwdZbX5mqw/EMHkZJk81ZquH1QZBhhR3+vhdfkF3QNQb
EpvDEktUZo3JbQMK+5DSMazqS6qdKbUzDb9ijGtdWa07p3PDhD2FLxWrH+DC
fWOr/Y6t2v21IugbXjfUF7/VN5/zMsfEk1/LGK97lN01yu4cZXWMMtvTjLYR
mikFFrpkfYKoixO0Qzj1AFbVj1HG0HLgN4yUhZDS4Be/EN4WkQ/0BBnshat4
pREwrIF6sPbGa4cJYJq3pintY7SuLLM3x7bkebaCwFEQg824u6jwFtX+oi5Y
NIaL7bFi12DRnCjawfDNlP35yUhlemB2NrE8n95Yyu6uFI/WJ8+3Zq93Fu/3
V94drn882fp8uvvb+f6/Lg5/vzz64+rkj6vTP67Ofr86++3y7NeLs0/np+9P
T94eH98fHt3sHVzu7J2D7er61uHqxv7S2u7Cyvb88uYsWEjPr019UVyaBIrB
OhlWnJ/O5KfGJ6DAHeA3V5rLVxZK08tT82uzS1sLa7vLmwdrO8eb+6c7R+d7
3/kFciG8V3enV/dn14/nN28vb99d3b6/vvtwUw3cB0+CPwV///hsdx/sptfn
l+fL06Xx/Gg8PRAc8Dr8lk57q65TKdHx2VIaiQPWz00NYP42PX/25Pd//ucf
//3ff/+v//rr//t/f4X8/unvf/7Lj3//4dlPP7168bKurq6lpQWHx1NpNC6P
J5HJ1Dqtqb2t29xr67O7PG5fAOANhMJBKEA44PN63S7g12Y1A78dX/0qpTKZ
UAz8Ctl8PuSXzaEwn/ziKN/8NmFxDWhMHRJV04J43dT0sqHxl7r657V1z2pq
f35T8/PrarU/v6579qbheU3TL5BfzKsmwmsEpQbNrMPxGomSZooSwdCj2W1Y
fg9BZCPJXFSljw75jXFMg7y2YUFnUtSdkvSkpeZRmDCU0p4GKewjCntKbk/K
bAmpNS6xDInMA8Kefj4kN8LpCLPag8y2AKPVzzD56EYvzeCB0ruhDG66wc0w
epgmD6vVy2nzciHFfkFXUNgTEvdGJOaozNIvtw4qbHGlPaFypFR9I+BFAx79
GY0TejNc64LOLfktD6hQDewTQRo4tbtaQfWtIkwYAqv5mqukdkF+Vc4C8Ct3
TEjtWbFtXGgZ43enWV1pZmea2ZFmtI/Q21I0U5JiTJD1w0TdEAH6ehHwG8Mo
omh5BCX76jfw5Ffs/yK3ihcUQkrCKFkUregHu2asJo7XJQnGEVLbGKUzQ+vJ
Mcx5trXAtRcFzpLIVZJ6SgpfSR0s6cJFU7TYPlDsjhctqVLfWNmTqwRKk9Hp
6aGF2eTq/NjWUm5/pXiyPnmxOXuzs/Cwt/zuYO3j0ebnk+3fTnf/dbb3+/nB
70DxxRHoXxfHv54ffz47/nh69P746PHw8H7/4GZ3/3J7t+r3aHUTGsGAMDSF
V7bmwCBeXIcVr1SA4unF4uR8vgxWyzO5Ihi7U5mnpnOl2Xxlvji9VJlbnV7c
mFvdXtrYW90+3Ng/2T463z252Ad+L66PLm+Or2C81wDvw/nN4wXAe/f++v7D
zf3H26eA4ndXNw/nlzcnZxf7R4ebu1tL60vTC5MTlWwqOxxLhDwRh9ndaTJr
lSYxX8mkCQg4OqIZX1vT8uJ53T9/fAnm7J//DBbPf68OXwAZcP4rtHgGw7fm
zZumxiYMGkMmg1HJFonFKrXaaDJ1dXdbbTan2+Xz+4KhYCQSikbC4DYcCgYD
Pp/X7Xb2QX57YL9Go06rVSqrfsU8gZDN4zM53/tlAL8YMgVFJCHwxGYsvhGN
rUeialsQb5qaXzU0vqxv+KW27nlN7bM3tc9e1zx7XQtX/xzy2/xLHfIl7PcN
glqLZtXj+I1EaTNFhWAY0OwOLL+XILKTZG6K0k/XhJn6GNs4yG0b5nckhV0p
MIIlvYBwWmZJy6wjcuuIzJqSWZPVsxlLLHGxeVDYOwBd+6MryumIsNtDzLYg
wxSgG/00g4+m91J1HorOTdGCXFA6F1XnApCBYqYRIswGhNv9vI4ARLg7LO6J
SswxmWVAbh1S2IaVtqTKPqJypOHRD9bwMGFnrqr4KfhssRp3/mtVuSqQC0rp
KlSDkLqKaijIrOZL0DNOyK8S8puT2bMS27jIOiroTjO6RhidI4wOsDlN0dqS
VFOCYhwm6+Ow3wG8uh/35BeoBKvi/+P3W0/DFwkN3xhaOYBRx7HaBN6QIphG
Se3jlK4crTfPsBRY9iK3r8R3lUWestRXVgTK6lBJB32FpNQxVOpJlKzpkjNT
9uYrocpUbHY6vjSbWl8Y31maOFgpna5NXm7O3m4vPOwuvdtf/Xi4/vlo89fj
rd9Otv8FFJ/uAci/ne7/err/+WT/0/H+h6P9d4f7D/t7d3t7Nzu7l9s755vb
p+tbx2ubYAQfgN3r0vru0trOk+LlDUjxwurU3HJlZrE0NV+ozE2Uwcydzhan
MlDT2dLsRGW+MLVYnl2ZWlifXdlaWN9d2T5Y3zveOjzbgf0efPV7fXd6c392
83h++/YSUL1/f/Pw8fbh493jp7vHj3cPH27vwTh+vLy5O7u8Ojo92TncXdte
m1+ZLc8Wx4vp+Fh/aMjbF7R09Zl0XQqpjseWUklsDIoML6Ebn/38+h8/PP/r
X38CZsHOF9r8/vkf4OEP/3j+M9j5vm6ob0AhUUQikclgCgVChUJpMBg6Ozut
FovT6fT5fKFQEMjtj0ZAsUg4CkZwwO+H/TqsFshvO/BrePIrlQlF3/llwX7p
TCKNAaY7lkwFa3QkgdSCIzRjcGDJXo9A1ja3vGlselXf+LKu/kVN3S9vap+D
XoPqnr+p/+VN4y+1LS/qUK8asK+biDUIWi2aXY8TNBJlzRQ1kmFEszuxfDNB
5CBJPRRFgKaOMHT9LOMQp3WY154UdKaEXSOinhFx74jEDEpJzEmJOSExD4vN
cVHvkLBnUNDdz++KcTsjnPYwqy3ENAWrcql6LwXI1XrIGjdZ4yJ9Cdwna/+T
sMnLafUBwvyOoKAzJOqOSHpi0t4BmXlIYYkrrQmlLQURto9ChB3j6j7o/XCg
GA46SbvGlVNDTVRTPQXYwjnzCjBYgU0o6PBIkNpZqqaBgvCqnQWVM6/sm1D0
5WSOjNQ+LraNCrtH6KCuEXpnivaffkm6wa9+scoIRhFGy4HfIPCLlMJ+Jf+J
V1LFCw1flKIfrRrEaIZxuiTemCa0jZE6suTuCaq5QLcWWY4Sx1nmuctCb1ni
L8uDZXWkrIuVTYOljuFSb6pkGyu7chVfaTI8NTUwPzO8MjeyuTC+uzRxtFI6
W5u82pi53Zp/2Fl8t7v8YX/108Ha58P1X482fjva/A1APt769Xj789H2p8Od
D4c77w523u7vPOzu3O7sXG9vX25tn29sAb8na9AIPoSm8Ob+8sbeMlC8vrO4
BhRvzi2vzyyuTs0vV2YXS9NgtwvAzuTKQC5ceWaiMgf8lmaXJxfWZpY359d3
lrcO1naPNg9Pd47P984u/9Pvw9nt48Xd28v7d9cPH24eP94CvG8/3UMByB9u
H95d3z1c3NycXp4fnBxu7W8tby7NLE+BUZ/OJwbSYd+A0+brarfp1O0SoZrF
EBLxDEQLvq4W8fJFHVgk//DD87/97ae//OWff/nrP8EdgPenn1+/eFlfW49s
QRDwBAaNzufx5TK5XqfvbO+wmi2uPqff6wNY+yORwVhsqL9/qD82AAiHQ2Hg
1+N29zkgv93Ab5vJYNBqNErFF798IZsL+aWzOFQmm8xgAb8EKh1HpmFIFDSB
jMQTW7D4JjS2EYmub0HWNrW8aWh6Xd/4qrb+ZU39izd1oF/egDsNL2qaXta2
vIT84t40kWoQ9DoUpwErbCLKWygaJN2EZndheRaCqI8k9UJH0QO/2n6WYYht
Gua2JXgdVcIpYXdK1JOES4igS3PGBd2D/O4BXlc/tzPGaY+w28LM1iDDGKAZ
/FS9j6LzkrUeksZDUruJahdRVc1JVEORngi7YcIeptHLNvk4bX5ee0DQERJ2
RcTdMWlPv6x3UG6OKywJpTWptI6obGlAWGWHCUNlAGSQqi+rcoJy1ZTOCZAC
Kl9N7izI+6AUUNCxzSBVH/QlBSgn/IUFZ0HtzKudE6q+nLIvK3dkZA7oUr+i
nhS1O0XrStGA344ktS1BbYVOaUU2DAG/RO0AQd2P/84vWlYlHIAJ+78EcUYC
vxDe/xi+OP0I3jRKaM+QOnPknjzVUqTbSsy+MttV4XkqQl9FEqjIwxV1tKwb
KLfGy53Jcu9o2Z6puAsVf2UyMjs9uDiTWJtLby1k9pfyx8Dv6uTV+vTt5uzD
1vzb7cX3u0sf95Y/7a183l+FW/t8sPZpf/3j/vqHvY33extvdzcedjbutzdv
tzav4XO3nm9snq1vnqxvHgPCkGKwF96CFK9s7i1v7C6uby+sbs6tPBEuzy4U
p+fyXwmXp3PA7+RcYXoB+K0srE4vb86t7Sxt7a/uHm0cnGwfn++eXu6fXx9e
3hz9//l9++nu3af7aoDwWzCU317d353fXB1fnOyd7G3srS9uzE8ulnJTY8mJ
oWgq4InZzJ52k1mtMAl4CjqVh8NSm5uwNW+aX/xSCwj/+OMvQDGQC5bNYPIC
vDV1iOYWPBZHo9B4HJ5MItNpdB2t7dYes8vRF/B4o8HQQCQa7+8fHhhMDAwM
A8LRaH84FAn4A8Cvw2G3WHq7ujra2ox6vVatVsgVEolUKPzil/3kl8JgkWhM
IpWBpwDCVAwRECYhcQQEBteMwjQiUPXNiLrGlpqGpjd1ja9rG17VQL180/Cy
pvFlTfOrWsTrOvSbBnxNE7kWwahHcRuwoiaCooWiRdJb0exuLM+KFzqJEi9Z
HqSqonT4KFyWcZjTmuC2JwFhfmeS35UUdCUEXcN86LrYQ7yuQW7nAKcjBl9s
K8JsDTFMQZohQNX7KTofWesFcolqN0EFcuGV1ZxQKicBUgwPYq0bJuxhGLws
o4/T6ue2BfjtIWFnRNwVlXT3y3oG5b1DCvOwwpJUWlKAsBIQtkGE4cZV0EWO
oOscKftAWQXImQPJnRNw0IcvcAUZfEikHKqocEDfLQJ9IVyAy3/nN6PoG5f1
jUkdaTHwCxOmdiUhv+2wX1OcYhgi6wdJ8Llx8OoYThX9fgSjZIHvCAO5Vbzg
j8IoObTzhYdvHKtL4gxpfOsYoSNL6pog9xao1hLdXmb2VdjuCtdbEfgr4mBF
Hqmo+iu6wXJrotw5UjaPVxy5irs0GZiais5PDy7PJtfnRncWMgeLE8fLxfPV
ytXa1O36zP3G7OPm3Lut+ffbCx+2Fz/uVFsCfdhZfr+z/G57+e32yuPWyv3W
6u3m6s3G2tXG+uX6+vn6xtn6xunaJhjBx1DbR3Cw4q295U2Y8NrG7Mra9OLK
5PxSaXahAAhPzeYmZ3JAcWX2ye9c1e/G3Nr24ubeyu7h+sHJ1vHZ7unF/vnV
weU18HtcXT/fPpzDfq8e3n/z+/7Tw3tw+/H+3Ye7t+9uHh+u7m/Pbi4OL452
jnfW9lbmN2bKi4XM5Mhwtj+c8DjD5m6nSd8tl+p5HCmFzMGgyU2NGIjwi7pn
z978/PNrENjzvnzVUFOLaGrGYbBUMoXL4khFEq1K025qs3T3umx9Abc3FggN
RWKJ/sHU4NDIUBzcJgcG4tHYQDgc8fsDbuDXbjebezs7O1pbjTq9RqVWyBQS
MfAr4vEEX/xyaUwOhcEm078jTKJiiRQMnoTCEhBoXAsK04RANTQj6xtb6hqa
a+qa3tQ2gl7XNL2uaX5d2/K6DvWmHlPTQKhtotQhmPUoXiNW3ExQtpB1SHob
mtWD5dnwQhdR4iPLQ1RllKYZYOiGmAbozIfs1iSnLcltT3A7QMNc6CTkQ5yO
QXZ7P7s9xmqLMlvDDFOIZghS9QFYro+k8RLVHiAXr3TjlC6copoTSgmFV7kA
akAY+KXAfukGL9PoY5v83FbYb0dE1BmVdPVLuwdkPUPy3rjCnPhG2JpW2kar
KaArDEIXGZQ7QBl5X1YGlQNJ+yakfXkoB6hQTWaHktsLCpCjoHQUVHAQXigI
L5jmsN8xed+otC8t6U1SepLU7iTktxMQTlDbhqsjGCKsGyBp+wmaGF4VxSkj
WGUYowj9L8JfCsK74wga+FX2Y9RDWO0wTp+CF8/jROC3O082Q35pjjLDWWEB
v76KIFARhyqyaEU1UNHHK63JStdoxZypOPKTnspkcGYqtjAztDqb3Jwb3V3I
HC5OnCwVz1fKV6uTN2tTd+vTD+szbzdm3m3Mvtucff/UHOjd5tzbjfnHjfmH
jYX79YW79cWb9aXrteWrtZWLtdXztbWztfXTtSfCJ+vbx+vA7w7ocHV7HxBe
2txZXN+aW12fWV6dWlwuzy8WZ+fz07MTEGGAF9yZL4Dd8Re/s1W/O8Dv8ebR
2c7pxd75JfB7eHVzfH17cnN3Cvl9vLh/C/xegwUzmLlf/D58ALcf799/uHv3
9ubt/eX99enN2cHFwfbx1sru0uz6VHEhN1ZODo1HAnGnPdjd4dBpOqQiDZsp
JhNZaBQJEK6taQF74ZcvG0CvXzfV1iEBXjSGSiRzmCyJQKRRqNoMJnNnj8vq
CLggvPFILNU/lB4aHo0nQGlAeGBwOBobDIUjPn/A5XLb7fbe3h7401+DVqdR
qsDyWyKWCASwXw7klwH7pTI4FPo3wgQKHU+i4WDCaCwBicYhkJjmFnRTM7Kh
EVHf0FJX31xb11xb21xT21JTh6ypQ9fU42obiXXN1HoEqwHFb8JKmgkqBFmP
pLVDfrl2vMBFFPtJshBFEaOqB+jaIYZ+mGlMwCcvTbDbQMPstji7bYjVNshq
62e2xhimCN0YphlCVH2QovMDuUSNl6D24FUeHJCrcGFBchcGygmlcELPANFg
FgPCajcJ7Iu1Hqrue79BXltI8OQ39uS3Jy7vHYYIm5MKS0phGVFYQWk5yDYK
ktnHoGtq2zNSsGl1ZCWOHNyExJEXQxXEdigJnNT+H4qV9rzSkVdBByh+w6t0
jiuco3JnWuYckQK/XwjToBGcoLUnaICwKU41DlHgc0tChNX/i3Dwe8IoafUh
eD6CVsQwqgHo7Bxg8WxIwYvncWJnjtQD/BYpti9+PRWOr8IPVkThiixWUQ1W
9MOV1pFK11jFkqv0FSe9U1OhuenY0kx8bTa1NTe6N1/1WzhfLl0tl29WKrer
k/erkw9rU49rU2+hJuGg+4+rUw+rU/er03erM7crMzcrs9cr81crC5erixer
y+erK2erq6erEOGvfo/Xq353Dla295a3dhY3tubhETy1BJACqguFmbn89NwE
XB5sisHWGGyQF1enVyC/C5u7yzsHa/vA7+n26fnu+eX+xdXB1fXR9c3xzd3J
7f3Z3cP5/dtLsNV9fH/z9sPtu4/3Vbygj+D24/2H93fvH6/f3l3cX57cnOxf
7G0ery/vLkyvlfNz4yOlof7RgHfAbvF1tFo1yjaRQMWkC0kEJhpJbm7CNdSj
6mqRdXXIhgZMczMBjaYSiWw6U8wXqGWKVp2ht73LabYFnJ6YPzgcjo30D40N
JTLDycxwCtyOxYfTA0OJJ7++gNPlstlsPT097R3tBqNBo1UrVHKpTCySCPhP
flmwXzrziTCVzqbQWWQai0RlEil0AomGJ1JweBIGS0Ch8UgktqUF3dyMampE
NjYgGuoR9fUI8MvWgd+6HlPXgK9rJNc30xoQ7EaUoAkrbSGoEWQDitaBZvZi
OXY8300Q+UnSMFkeo6gGaJohunaYrh9mGBIM4zDDBIoz4JOQM0z9dGOMZoxS
DWGKPkTWBUlaP1HjI6i9VblYhRs260LLnN+Sg1xohQujhAmD6Qz2xRoPWeeh
6r10g49h9LNMAU7Vb3tE1BEVd8YkXQPS7sGvhOW9Cbk5KTen5BbQiAx6Jzwt
BdlGJTawVx2X2DNiO3RNT5FjAi4vsoMKT9kKYjiJrSC1FWS2vNyWV9hB0LcD
lA5o2wuvwwHesS9+U1Iz5Jfam6T1JGndSXpnkt6RoLcP01qHaYCw4Ykw8f+f
MFwQDeEFz0cwyhhWPYDTxHG6BN44QmgdJbZniF2wXwvst69Md5WZnjLHD/uN
lGX9ZdVQWZ8st6bLXZmKJV9xlid901Oh+en+lZn4xmxqe250fz5ztJA7Xcyf
LxYul4rXS6Wb5dLdcvkeqvTwfUul+6XSHVT5dqlyszR5vTR1tTR9uTR7sTx/
vrxwtrJ0trJyChM+eVpFbx+v/S+/m1vz6xuzq2vTyyuTi0vQCJ4DZufzM1AF
sCmeWyovrEwurUF+wXp7a3d5F/g92jg62To52zm72Lu43L+8OvxC+BQQvn+4
eHh7+fjuGvZ7BxbPVbwfPz1++vTw6cP9x3e3Hx6u396cP1wc3xztne+sH60u
7sxOrhSyM+lEvj+c8jqj5m63Sd+rlBkFXAWDKiDhmVgUBdlCRDThW5oJSAQJ
g6YRCWw6XcTlKSVSo0bb3dru6LH4HK6oNxAPRUdiQ+NDiexwaiIxAsolUhkw
hQeGksBvMBT1+vx9TpfVauvu6W5rb9Mb9WqNWq6US2RioRjyyxVwYL9MFiDM
A4QhxQwOraqYxqJQmWQKg0SiEQgUPJ6MxRIxaDwKiUW2YFqa0c1NQDGqsQHV
0IAGLzYNDbiGRmJDE6WhmdGI4DShhc1YGeSXZERRO9AMM5btwPHcBKGfKAmT
ZDGyYoCiGqJq4jTtME03TNMP0wxxmmGIZhikGQagq2jpo2RdmKQLEbVBgsaP
V/vwKi9O6YHlutEyFwokdSK/JgO5UHIXSuFCK90YlRsLxjTYIINtss5L0fto
/8evsOq3s1/aNSjrHpL1xGU9w7JeUELWm5SZk1JzSmoZkUClxdZRsW1MZBsX
2TMie1ZozwntEwJ7Hq4AZYMSgqwFkbUgthYk1rzUmpfZJkBye04BcmQVDmjb
C1bOVbxy14jMBX5KkmKG/fYm6T1JeneS0ZlkwITp/5ewJopXRXDKMFYZqhL+
LvAMeD6KVfXjNIPQqSn10Me+xLYxYkeG1JUj9wK/Baq9SOsrQX69wG+ZHyqL
omXZQFkVL+tT5baxcneubC1WnJOTvtmp8OJ0/+pMfHM2tTM7uj83fjSfPV2Y
OF/IXy4WrhYL14uFm8XC7WLhbjF/twCa+NrtPCh/M5+/ni9czRevFsqXC5WL
hanzxZmzpbmzpYXT5aXT5ZWTldWT1fXj1c3j1a2jVbD/3QZ495fB+rk6f6t+
VwDS5TIYwfPA7AKQC+OtDt+VyeW16dWNuSe/+6v7h+tHx5snp9tnZ7vnMOGr
q4Pr66Obm+Pb29O7J8JXj+9u3n24ff/xrur3E+T38fPHh88f7j+9vf1wf/Xu
+uz+7PD6YPtsc/VgaXZzsriYHZ0cHsyE/PE+W7Cr3aFXd8pEOh5LRqfwSXgW
HkPHoqggHIYO8NKoAjZbLhLplMoOg9Ha2e222sMu72AgnIoOjA0O5+KpfCJd
SI4WkmlAOFv1G4kNBkIRj9fvcLrMVmtXd3drW5vOoFdpVDKFTCyF/Qqrftls
QJgPCFcVM5gwZAaXRufQaGwqlUWhMMgk8EJCJeDIOCwRiyagkTgUAotsxrQ0
YZobQdimRlxTI6GxidTUTG1qYTYhuc1oUQtWjiBokCQTitr55Jfrxgv8BFGY
KI2S5ANk5SBFFaeo4xRNnKKNU3RDFN0gRTdA1vWTdFGSNkLUhAjqIF4dwKl8
WKUXo/Cg5W7AFikFORESqJZq4CFI5kLIXUiFG6V0o1UejNqDA4ttyK8P9utn
GAMsU5DTGuK2hfnAb3tU1BETd/ZDI7hrUNo9JO2OS3uGoXoTYE8Kf4yVEptH
RBZQWmgdE9rGBbaMwJbl23N8+wTfnufZoaOYnrIW+HACK1CcF1nzYuuExDoh
teakNujTXrk9A2+ioW1vdeUM4XUlJZYExZKkmpN0c5LRm2L0JJndSWZnktmR
YLQnGNC1Ub4nHCOo/4MwRhHEyIPwHfBMBKeK4dT9eO0QQQcdc0U0QYdtkDoz
5G7gd4Jirfot0t0lprfECZT44ZIoVpINltSJkn6k1DZe6p4o20oV11TFPzcZ
XpoaWJuOb82kdmfTB7NjR3OZk7ns2XzuYn7icn7ian7iej53PZe7mctCzWa+
dg13NZu9nM1dzk5czBYu5orn8+Wz+cmzhZnTxbmTxYWTpaXj5ZXj5dWjlfWj
lY3Dlc2DlS0Y7+bu4ub2wsbW3PrGDOR3FfitLC6VIMJgCi8W58EdaPhWllan
VtZn1jbnNiC/S7v7K/uHa4dHG8cnW6cw4YvzvcuL/avL7wmf3z9ePr69evv+
Bux5wbK56vfzp8dfQR8ePr+7+/Rw/eH24u3Fyd3x3uXOxsnq4u7s5GohO5se
BiN4xOuMWbo9bXqzWtYq5qk5DAmdzKfg2SQci4hjkQkcGlnAYkj5PLVMatJo
elrbHD1mv90Z8/qHQ9F0bCg7lMwnRorJ0WJqFNyC+9mhxFj/UDIcG/QHI26v
397n7LVYO7u6TK2tWr1OqX7yKxALeZBfLkfAYT8RZrGgmNWYPCaDx2Bw6TTw
EsKikhkUEo1EoBJxZDyGhEMTMEg8GoFDteCQzThovdBEaGkiNTdTmpvpzQh2
C5LfghYjsAoEQfvkl27GsBxYjhvH9+OFIYI4SpT2E+WDJMUQSTVEUsNpBoka
6I1Wogb8/xnBq8M4VQirDGCUfrTCh5Z7UTIPUupGSF1Vs83iL0ngwPMyV4vc
jVC4kUoPSuXFqL1YrQ+v8xH1frLBTzUG6MYg0xRkf/EraI8KO2Kijn5x54Ck
a1DSNQTVHZd0D4t7QAlxb1LUmxSaU0IzdBkRgXWMbx3n2zI8Wxa6Gq9tgmvL
c2wFuCLHCipwQZYCz5LnW/ICy4TQMiGy5MTWnMSaldgyUjv0ga/UMSbtS0v7
RqTOlAS6snBCbElQLUmaBfhNMcwpZm+K1ZNidadYEOEk838T7v9fhLGKp8BD
nAr8p4sRNAPQSd31wyQjdMwkuX2MDPz2ZClm4DdPtRdofQWGu8D0FjiBAj9c
EMUK8qGiOlk0pIvtmVJPvmSrlF0zFf/CZGRlamAd+J1O7s7AfmfHT2YzZ7PZ
89nsBWQzewWQzoxDTY9dTY8+NQV1CTV2MTV+Dl1FN3c2kz+bLZ7OlU/nJ0/m
Z04W5o4XF44Xl46WVg6XVg+X1w+W1/eXNvaWNnYXN3YWoOG7Obu2/uR3Gfhd
LlcJL4DbpfLicmWpOnzXZ9Y354D3beB3b2X/YO3wcP0YjOCTrbPT7fOznYvz
3SfCV0+E7+/PHx4v3767fvf+9gNYM3/8zu/Hx1/f339+vPl4d/n+8vTh5OB6
b+tsfXl/fnqjPDE/lioNRccC7kGH2d9lsuuVnXKRXshWsGliBklAI/KoRB4d
4KWJeWyFWKhTytv1enN7h8tsCfa5BnxBIHSsP56LJwuJNJBbSsJ+hyG/o7HB
ZDg66AtGXB6fzeHsMVs6OruMX/xKFTJR1a+IzxXyOAIuGxCGYn+NBeKzmCAe
k85l0Nh0CosGCBPpZDxEmACd2oeIRRIwCAK6hYBqISKbSYhmMqKFhmhhIhAc
BEqAwEiQWCWSoEORWtGULsgv04Flu3E8H04QwosieEmMIB0gyAcJikGCstoA
XgV9yln9lASeLEG0IoCS+5AyL0LqQUjdLRJXsxjkbAKJnI0gMZzE1SR1Ncnc
zXJPi8KDUHlRah9a48Nq/Xidn6gPkA0BqjFINwG/IVZrmNMW4bVF+O1RQXtM
2NEv6hgAhMWdg+KuIZCoOy7qHhZCH0AnhL1JQW+Kbx7hmdM8yxjXOs61Zjm2
HMc2wbbl2bYCC6rIslYrsC1QHHOea87zzBN8S05gyQmhy3BnRNaM2DYuto+J
7aNiR1rcNyLuS4qcCZFzWGhNUK1JuiXJsKSY5hTLnGL3ptg9KXY3dB0i1hfC
8EJ6kKIfIAHCmij0KqcCYMM4ZQgujIfwRgngNVA7QNIPkQwJsilFbktTOsag
q55BfnNU6wTNnqc58wx3nuXLc4J5fiQv7s/L43l1qmAYLbTnij3Fon2y5J4t
+xcrkdXJgY2p+PZ0cm965GBm9Ghm7GRm/HRm/BzuYho0BjtNX06CRqAqqQuo
EdB5JX0+OXo2OXY2lTmdzp3O5E9niiez5ZO5qeP5maOFuaOFhcPFpcPFlYPF
1f3Ftb3Ftd2F9Z2F9e359a25NbB4Xp9eXZuC/IJR+0S4DN1W8YLhuzYN/tqT
3x3gd3l/f/XgYO3ocP3kaPP0eOvsZPv8dOccHsRXF1XCJ3d30Cr68fHq3bub
Dx/uPn68//Tx4VfY72/gDuT39hPwe3X6eHJws7d1vrF8sDC9WckvZkYqw7FM
yBt3WkI9bX0mdY9KYpJw1XyGjE0VM8lCEIsq5jJkAo5aKjKoFZ1GvbWz022x
hpzf+QXzd3ikmIDwFhPpfDyVHRwejQ4mQ9FBbyDidPusDme32dLe2WUwtWp0
OkX1qwtSCexXAPmFCXOE32JDcUAsAYfJZzN4LDqXSWUzAGESgwoTJmEpRAwZ
jybhUCQskoRBkNEICgpBRSEYSCQLieQh0UIkRobCqVAE/ZNfmhnDcGDYLizX
h+UHcYIwThTFSfpx0gGcbAAnh8LK+7EK6BBBjCKCVoRR8hBKHkTK/Aipr0Xq
bZZ4msXuJrGrUQRyNnyf2NkgcTVK3Y0yT5Pc06z0tqh8SLUfpfVjdAGcPkAw
BEnGIMUYoplCDFMY+GW3RbhtUV5blN8eE7T3A8LCjgFRJ2hQ2Dkk7BoSdMcF
3cOCngS/J8nrTfF6R7jmNMcyxrGOs6FrZ+dYtgmmLc+0FRgga/EpSwHENOdB
LPME2zzBMee45izPkuFbMgLruABagY8K7WmhfUToSAkdSUHfsKAvzrcmaNYE
w5pkWlIsS4ptGeGYRzi9I5yeEc5Xwm2AcJxmHAKEoS2GNvaV8NfAQ/AkSQs2
IINkQ5xiTFBaU5T2NLVzDLrkaG+GaslSbTmaI0d35hjuHMuX4wRzgkhOPDAh
H57QpCaMY/mOiXxvqWCfKrrnSoGlcmS1MrA5Gd+ZSu5NjRxMpY+mR0+mx06n
x86gq9KDRs8n0xeTI7DW1Hk5CZeAKiXPyqDUaXnktJI+rYydTmZOpnIn04Xj
mdLxbAW+2P3M4fzcwcLCwcLS/sLy3sLK7vzqzvzq9tzq1tzq5uwqWDyvT6+s
TS1DfieXYMJPfcELDd+N2Y3N+a0t4Hdxd3d5b2/lYH/18GDtGBA+3Dg92jw7
3jqHFO9efiF8e3N6f3f++HD57u31+/e3Hz9AfsHm91fQh4df3919frj5eAvm
78nDyf713ubZ+tIBPH8XMinIb9g77LKEzG2uNk2vVtom42lFTAWPJuVQxGyK
mEOT8pkKEVcjFxk1yi7Ib4fbAuavs9/rT4SiYM5mBhMT8VRheAQE8ALOmf54
OjKQCEQGPP5wn9trsfd19VraOrr0pla1TidXqSRPfkU8kZAr5HOgeE+JvsUW
QZC/EqZxIMJkJkSYQKc8EaYQ0BQ8ioJDUrBIGgZJRyOZaBQHjeajMGIUVo7C
q9EEPZrUVvWLZtgxLBeG48VwAxh+CCOIYERRjDiGkfSD0NIYCDrkTxYBIWVh
hDSIkAZapP5mia9J7G0SexpF7gaRq0Hoqhc6q9WBRM46sate4qqXuhtknkaF
t0npa1b5ERo/UhtA64JYfRBvCBGNIbIxRDWF6aYwozXCao2w26Iw4RivPcZv
7xd0DMANCjoH+Z1D/K44r3uY153g9iS5vSlAiW0eZVvGWNYM05plWicYtjzd
VgDRrMWnLKACzQzK03vzjN4JZm+O1Ztlm7Mcc4ZjHudaxnhW0CjPNsKzpXj2
JM+R4DmGuY4hrnWYbk0wrUmWNcW2pjiWEa4FesXggteNJ8JJVkeC2QatomlG
aASTdTGSNkrURAjqcDXiE94YdCEz/SDVGKeaEtS2FK0jDV0muHuc1puhWTI0
W5buyNKdWaYny/ZlucGsIJqVDGQVw1nNSNY4nuuYmOgt5+3TBfd8MbBciqyV
+zcr8Z1KYm8ydTA5cjSVPpkaPZ0CIxW6mDXoHAzZMiT3rJQ4Kw2fFZ86fSpx
UkqelEZOyqMnlfHjyezx1MTxdOFopnw0O3k4O30wN7s/N78/t7A3v7Q7t7Qz
t7w9t7I1u7I5s7Ixs/KE98nvE+GVSvX+yuoUWFqvPfmdg/xuL+7uLO3tLu/v
rRzurR7trx0fwIQPN8+OIMIXEOH968vDm+uTu9uzh/uLt49X79/dfHx/9wnM
3A/3YPJCeKHhe/Xh+vzt+dHd4e7V9vrJ6sLebGWtlJ0fT5TikfGwO+4yQ37b
NWadtE3B14lZKgFdxqNKuVQJjyYTMJVirhbyC+avztLR5jT3BhyOqMcbD4RS
kf4xsAUeTAC2E0PJ3GAiMzA8Fh1MhWJxf6jf7QvZnV6zzdHZY25t79QZTSrt
k1+hVMoXiyG/0AgWcET8/0j8dIct4rGEXKaAw+Cz6VwWlcOksBgkJo3IoOLp
FByNhKUSMVQCmoZH03BoOg7FxKLZGDQPgxFisBI0ToHGa9BEwze/dDua6USz
PWiOH80NovkhtCCCEkZQoigIKQZFEBKoFkm4RRJqlgSbJYEmsb9R7GsUeRtE
ngahu17oqoOC5NZWEzlrxa5aibtO6qmXeRsUvkalv0kdaNYEENogShfC6EM4
QxhvDBONYbIpQjVF6K0RRmuU1Rplt8Y4bTEuVD+vHTTA6wAN8jqHuF1xbtcw
tzvB6UlCS9neEZZ5lGkZZ1ozDGuObpug2fI0W4FqLVLgyBY4c4EC6s1Teieo
vTlab47em2X0Zpi94ywzaIxtGWVb0xzrCMeWYtsSbPsw2x5n2YdY1mGmNcGy
Jdm2FMc2wrWO8KxguZ6GFu29aYhwF0y4fRiMYLppkGoAQoFT6F0+kiZM1IRJ
UBGyNkrRxYBusFMGi216a4LenqJ3puldo/SeMbp5nG4Zp9sydEeG4RpnesbZ
/nFeaFwYHZcMjisT49p0xpTJduaz5krOMZP3LBQCy8XIeql/qzy0W0nsV1KH
wO9k+mQyfQp3VgGNgAl7VsVbBVuIVzuBGgYdFxPHpdRxOX1cGTuezBxP5Y6A
3+nS4UzlYHbqYHZmf3Z2b3Z+d3ZhZ3Zxe3Zpa2Zpc2ZpY3p5fXr5K94vfr8F
hu/3fjfmtjbnt7cWdgDh7aX9neWDXUB45Whv9Xh/7eRg/fRwAya8c3EGjeCb
q+O7m9OHu/O3D1fv315/eHf76d0d6HMV7/31h5uLdxfQ8IUXz2CDPrs9XVzO
j82k44XBUDroHHT2Bs0mZ7u6VydpU/L0EqZKSJPzqVIeRcqnyYQMhZijkQsN
almHQdPbbnJ0d3mt1jBYQnv9w8HwSLgfTOHx/jgYu+OxOMALngHDFyye/z++
7oK5rSxh2/VfOt3hxDEzg1iyJTOLcW8xS7bFzMySJcvMbCdpmpn3/c7fOWtt
yUl6Zr5TdZfLSXfVTE3NlWetLcmxavRmhVqHypVCCcoVCBt+l7CfDd/0Oz83
jRGmvTQ934wGA37plNkZMmOaRKcRZ6gEGgUHJphCnCATxiHhqVHi5AhxAjRM
Gh8mjw1TR4enR4fpIyNzI6NLw2Orw+ObwxOcoSlBw+8gUTFIUg9SdINUwwDN
NDC9NTCz3U/f6WfA+mZhvXNY89s9sK3uOXP3nKlrztg5a+ic1XfM6joYunaG
FtTG0MBmNW1z2rZ5XduCrn1R375k6Fgxdq6autfNPRtbfZvb/aydQfbOMHtn
lGMZ51gmuRaMsJXAswLCZJ6NwrMBxVS+nQYSOGBCJ03kooncVLGHKvFSER8F
BXfSIFkaJoH/88tjBHkCr0jiFSmcIjUlT09iTciwpKkJNAmaRBNTSBw+L0Ji
4NRKQCNENEyShkjwD4EgOCSDqQVgSQo3SeEiKpxEuZsCOCt8wPU0XOcAXRGk
y4N0WZAOCQemJX6a2EcFEyxwk3guAgcItWMvsQGzoB3sqwXHtOJZdgLbQeS4
iDwP/Ju4hX74sSZJkISC//QwSR4mKcMkdZisDVP0IZopNLMTmrOFFl3hVV+Y
GYrwYhFROirNx1TlhL6WNO+nLMdpx1nGdZEFfn03ucBdLnD/M96G3wz0+x3v
/Ut3AC/06/u/+i3lr8rFy3Lpolw5L+2elaqnpepJsXpcqB0VaoeF2kEetPcy
uy/lf+zvQfHwsHR0VDo+Kp8Awse7Zye756fVi9Pa5dne9Xn95nz/9uLg7vLw
/uoIW+Gz5/uLr49Xv325/ePb/V+/P/3zzy//89fX//3Hb//nn7/9v/+A/Z8/
v0K8Xx7+8XDz+/X5l7PDu4PqRSV/lI3Dw7PPHrMZfSalTSU2ImwVfxVhzvFW
p5mLmF8GwAvCL84SV+Yp60t01toCj7kq4YIjtECDoiaFckejA4Td5h1w1QVm
wZkZfAXLC/C6jHB8d1Q6k0yllUgVAjHC4Qs32ZzVDebSKvC7Av0uLLz4fWn+
ew2/jH/zi58GfslTLxM8TsKNkaZGSZOgEfLECHV8hDY2MjM2Ojs6ujAytjwy
vj48wRye5Db8DuKlgwTFAFE1QNb0U/T9VEMf1dRHM/dNb/XOwHro2z2M7W7Q
LGirC2YGdc6aOmeNHbOGDoa+HaZrg3i1rY1mtZ9B87rWBX3roqFtydi+YupY
M3eub3VvbPcwd/pYOwNsyxDbMsyxjHKs4xzrJNc6xbXiAGGujci1kUA8G5ln
p/BBDqrAQRE6KUIXReSmiD0UiZeM+MloALgjysJEeZQgj+MVCZwiOaVITSrS
E4r0uBw2JsOSpsbQ5BiaGEMS40h8AolNItEpWASHhvFoCC8NEqQBgsxPgE+b
PXi5Gy934eQOnMJNU3imlV5wqKYr/QxlgAHuyIrgrDzIgIQD4A4+LfHRRF6K
0E3mu0hcB4Fjx7OBVjC4gK0FD7MSWDYi207iOIBxcNgmC7wUsNriABkJklHw
50aILA+RlSGyOkjRBqmG4LQ5QN8JzNmDS+7gmj/ICof48bA4E5EVoupK3LCX
2DpIWo9TjrO0+zLjvc76bqHf4D28zP5Xv03CL34beL2Y38BdNnT3t/PzT35L
pYtS+bxUOS1WToq7x4Xdo/zuYX73IFfdx6rDai817r/1OkZ4HyN8UDw6LB0f
lk6OyqdHlbPjyvnx7sVJ9fK0dnW6d30GFTcIP96cPN2df3m4/PZ888fXu79+
e/znH8//A8D+9e3/NPoDw/v14R+Pt3/cXnw9P34AN99q8aSQao6vaycEDs96
2Y5CoBdvyrnL4s1Z7gp1c4G4Ootbok8t0CcXwFcGfmmOtLpA21iZ5awvCVjr
CI+jEAu1UqlJoQKE7Xqj07jlNu14zBaYacdl2LLrTBa1fkuhMaAKcPmV80US
Nk+wweKsbGwu/s3v/PRckzBt/t9iUP/ul/Cz38YEk/FjZNwYeWqUMjlKnRil
TYzOjI8xxsbmx8YXR8dXRiY2RiZZw1PcIVzDLzpAkPcTlf0kdR9Z20vW91IM
PVRjD83UDZo2d4FmzF30rU4QA2QGdcBMHQxjO8MAamPo2xi6VhjE+5kB8bbM
6lrm9J8X9J8XDa1LxrYVc/vaVsf6dufGTvfmTg/T0seyDLCtQ2zrMMcKCI9x
rBNAMceG49jwXBiBayfy7CQQ30EWgJxkoYssdpMkXhKCvRorDQK8BHkEL49B
vMrklDI1qQR4M+OKzJg8MypPj8iwpKkRNDmCJEaQ+CgsNoZEx5HIBCw8iYam
0OCUNDAl9U9JvVMyz5TMPSlzTsocEwr3jNJDV3oZKh8DPtcKzKmCc0osoFgW
YEj9dHATB+d5cDAQAJuOxlvUiGxg1tIIfE/i2MhcO5nnpPBdVIEH7DUVrDa4
PiPg/B+gyAIURYCiClA0AarOTzP6Z7b8DIt/weFf9vjXAwF2JChIhCTZsLwY
0ezGDPX41mHCepJynDf9+oHfJl7s5gsIY5fffyd838x7D+U28MLxvW8+v0re
ldJ3ZXD/zd3A83PT71mxfFosHxcqR/nKYa5ykKvsZyt12O5eBitbxaph7cGA
4tx+Pb9fLxzsFw73C0f7xeOD0slB6fSwfHZYOT/avTiuXp3Urk+bhB+uj59u
z77cX357uv79y91f3x7++fvTv/748r+AMAh8g+EF194/7y6/NU/OlbNS9iAd
rUR8Wa+tMb52tcQk5aiFa1L2gnCdzl6mrM8TVmanFumT8zMT8zOT82CFGYTl
Ocra4gxzZZ67sSJkb6J8rkIk0qJSo1y5pdJatAabzuTQm0F2vdmmNUK8Sq0R
jC8iUwoRKVcoZnL56yx2w+/c8jLju18wwVj/4XeWOsegzNHJszMkxjTxZ7/U
H37HgV8Kbow6NUabHJueGKNPjM+Ojy+MTSyPTqyNTm6OTLGHp3hDOOEgXjyA
R/sJsj6iopeo6iFpekjabrKui6Lvohg6qUZQB83UMY01Y+6gw9oZIBOWsQ1m
aGXoW+n6z3TdZwZI2wLTfZrVfZrTtywYWhaNn5dMn1fMratb7evbHRs7nZuW
bqalh2XtY1kB4UG2bZhtG2Hbxti2cY5tgmMDiqc4dhzXjgfxHAS+g8h3EgUu
oshNFHuIEh8R8RPBYspCEK8iilfEm3hV6QllZkyZGVVkRhSZYXlmWJYekqWG
pKlBNDmIJIaQ+BASG0ZiI0h0BImMIuExEBoaR4PjaGBC6p+QeselnnGpe1zq
HJM6xpQuhsozq/LOqX1zav+8OrCgDsJUwXllcF4RmJP7GVIfHfHOSDzgeE8V
NN8fTuZayZyXuDYK107lOah8J03omhZ5psVeuNqInyb102TwyRhV6aeq/VSt
j6b3TZu89G3vnNW76PSten2bQT8nGhCmgkgupCiFtdWosR7bPkpYT5POi7T7
KuO9AX6zmN984+FV6AmEEX58IfwAgmyhXOyxlf8OPrkCk/2Ct5S8L8PXj+4q
udtK/qZSBH6vyi9+C+XjfPkwVz7Ilvez5XqmvJcp19KNKo23bVRBmSpWrQbK
7tWy9VoOtF/LHezlQYd7haN64Xi/eLpfaii+PIaEb88P7i/BBJ8+3118e7z6
/fn2r6/3//zt8V+/P//P78//C/rt6X8g3rs/765+uzp7Pj2822+cnBO1WDDv
dyYcW8FtrUsnheMrYSp4KxJweF6bZi6R1ubxy4zJhZmJuenxuemJuSZhcIqm
glM0c3WBu7EqZDNRHiSsQVC9TGFSqIHiHbW+0bZKZ1ZAvDo4vlI5HxyeBaJN
Dm+NyVpe31hYXf1Pv7RmP+GF48ugzNLJDMzvDI0wTcXTfvJLIUxQ8OMgKm6c
NjU+PTVOnxyfnZiYH59YHJtcGZtaH51ijuA4wzj+IF44gJf0E9A+gqyXoOgh
KruJqi6SppOkBXWQdR0UfTvF0E41tNGMsGlT2wwW/XvGVpgB9Bnz24L1iQH7
OKv7OKf/OG/4tGj8tGRqWTF/Xt1qXdtu29jp2LR0Mq3dTGsPy9bHsvWzbIDw
EEZ4FCq2j7PtExz7JIjrmOI5cHwnXuDCC914kQcv9hIQPwENYHjDEK8S4E1M
qTC8qsy4Kjuqyo4os8OKzJA8MyhPD8hSA9LkAJrsRxL9SHwAiQ0i0UFJdAiJ
DCPhYSQ0goRG0eAoGhhF/aNS76jUMyp1jUidI6hjWO2aU7vnNd4FjW8RviMr
sASCb9AKwnd6qAILCv+83Dcr9TIQD13imhE5p4Xgtm6n8m2wl2dx4Hem4VM4
8C+46WLwb3rpqHdG6puR+ablvmmFb1rlm9Z4p3XeGYOHbvbM7njmbZ5ll2fN
52WGfby4X5QOSPNBZTmsq0VM+7Gd44QN+k15rjK+m2zj8BzC/IafYBhh+Ag6
2CD8kPHf/wjIbTx2hnibL/4237+Ru98t3O8Wb3dLN5XSVaV8WQbn54bf0mGu
dJAt1TPFvXSxlipWU6VG8J3PzSpYu7B0FasGy+ztZuqw7H41d1DNH9UKx3Wg
uHx++J3w4cPVydPt+df7y9+fbv78cv+Pbw//AmxB35p4/7q/Btfer2dHD4fw
5HyaT9cT4OTsSbstEYvBa1CAm68J5aqF61LOomiDAQ/Pi8TVOXB4npgHeGlj
s7TxWRqAPDUPLsIM8so8bX1xlrWyCAmzmAiXKxeKVGJEi8r0MqVRrjLJ1SCj
XG2QNvEqBGB8RWIWODyDy+8mc2l9fX5ldXYJ+p1ZWJjG/NL+wy+1Ob4M8iyd
xJgh0qcJMzT8NBVHo0xRyZM//BLGqZjfadzEzNQEY3JibmJyYXxyeXxqdQy3
MYJjDeO5Q3jgVzRAkPQR0F6CtIcg7yYouojKTqKqg6huJ2naSdo2MkjXStG3
Ug2tNJCxddrUOoNFbwT9foZ4DS10PegTwIv5/cjQfZjVf5gzfJg3fFwwflwy
fVo2f1rd/ry207puaduwtG9aAeEupq2HaevFCA8AxSz7MMs+wrKPsu1jbMcY
xzHOdU7wnJN815TAjRN6cGIvTuLDowG8NITH8OIAXlViSp2aVKcn1JlxdXZM
nR1RZYdV2SFldlCRGZCn+2WpPmmyD030IfE+JAbqR6L9ksgAEhlEwoNIaAgJ
DqOgwDDqH0a9w6hnGHUNo84h1DGkcS1q3Us677LOt6zzr+gDKzpQEKYNLmsC
Syr/otK3IPfOyzxzqJuBOOliB11knwEJQTbwlQ4SORhiJ0PimkXcs6hnFvVC
8jIvQ+6lK7x0lZeu9tK1HrrewzC6Z7fc8xb3osO94vFsBDzsiJef8EkyAVkh
qKqE9XsR80HMcpywnyVdl2nvdQaO7x3EG36EL/tGXmpCxq7DwYdswyy2uXB2
Q/f5yP3LOzcey+nH3exjNf9YLTzWSg+10l21fLtbvv7htwT9Zov7mcJeulBL
FarJwi4oUajA4MeOyrBSo1KijFWBJSvF5C5WtZSqlVJ75XS9kj2o5oDik3rp
7KBBeP/u4ujx+vTL3cVvj9d/Pt/9A0zwt8d/fXsEeP8Ffvlw8+ft5beLE3By
vt2rXJRyh+l4NeLPeR1xuzlg1ji10m05uPmylLxVhDUvWJ8Bh+eNhcbhGfqd
BX6pYwwq+GZybhq3MENcYlBW52c2FudYK0vc9TUhkynhcKV8oUIkUUlQDSLT
onItqtAico1EpgJ4wcmZB26+AuEml7fWODyvrc2vrMwuLdEXF2YWXvCCy2+j
plwYpTG+//9+qSD8BA03AfzSpyZnJyfnJ6YWx6dWxnDro7jNETwb+B0kCAYI
on6CpJeA9BCkXQRZJ0HeQVC0E5RtIKKqlahuJWk+g8jazxTdZ6r+M83wedoI
mwGZPkO5jQBeA4YX+v2I9YGhez+rfz9neD9vfL9g+rBo+rC89XFl+9PqTsua
5TMkbIWEN22AcDcgzLT3Me39TDsgPMRyDLMcI2zHCMc5ynWO81wTfPekwDMp
8k5JfFNIACcN4eRh3E94pzTpSU1mQpsd0+RGNbkRdW5IlR1UZgcUmT55uk+W
6pUme9BEDxLvQWI9SLQXifYhkT4k3I+EB5DQABIcRAODqH8I9Q2h3iHUM4S6
BlHnIGof1LlX9Z5Vg3fN4Fsz+teNAZghCFrTB9d0gVVtYEXtX1b9+FF+86hz
DnHAJD+FOOdR8I/cC1Lw73jm5SDvvMI7p/TOgvO52jOrdc/q3bNG15zZNb/j
WrS5VlyudZ+bGfJwY15hyofk/IpSUFMNG+qRraOY9TThOE+5r9Iv45sPPxQi
j/DNkNHnlxqQ4TuswD8FYJuFsdkFeGMPjXdOYm9+fqrmn/eKT3ulJ/gRhsr9
3u5drXKzW7mqVBp+j3LFg2yhns7XUrlqIrebyFXiuXI8V4o1yhebFQpY+UbR
Yq5ZKRcDlXPxSj5RLSb3Sun9Svawmj9uEt67OYMT/Hx7/u3+6o+nm7+e7/75
5f5foOf7fz7e/nV39fvVGRzfg9r1Lhjf1H4iXA56Mi5rZAeMr9KukphRnla4
KeeuSDbn+asz7CXKxjz28GpmcgHu7/gstdHkHA03Pw3fy7E8S1ubZ2wszbNW
lrnr6wImS8zhojyBTCBWCCUKEarEAnJlAgkK8HIEQiaPvw7GlwnHd2F1ZW55
CRvfH3ip/x5c3sb4Yofn/+aXSpyAESZoeIh3BjfJmJqcm5xamJhaHsetjuE3
RvHMYQJniMAbIAj6CaJegqSHgHQR0E6CtIMgayfI2wjyVoLiM0EJaiGqWojq
FpKmhaxtoehaqPoWmqFlGmRsmfkpzC/A+xGG4aXr3gO/DP27WcO7OeO7BdP7
RfP7pa0Py9sfV3c+re20rAPCVoywrQMQ3rR3M+09TcKOAZZjkOUcYjuHOa4R
rmuU5x4TeMaF3gmxbwIJTKLBKVl4ShGdAnjViSlNakqbntRmJ3S5cV1uTJsf
1eaHNbkhdW5Ale1XZHrl6R5Zqkea7EbjXUgM1I1Eu5FIDxLuRcJ9SKgPCfaj
wQE0MID6B1HfIOodRN2DmN8B1D5gdG+aPJsm+Pe5MM1+pjnANAdhJtimMbhh
CKzr/Gta36rGu6ryrCjdywrXkty1JHP+lAsmdy+DFJ5lpWcJpPLAH3ev9ixo
3PNa97zeNW90zZudC9vORatz2eFc87g2Ay52xM1PeMUZn7QQUFWCulrYdBDd
OY7bzhLw8AzH92e8pdhzKf5TMfj25kL0sRB5yMMgW3jbhRfeh2LisZx6rGSe
qrnnWuHLXulLvfxlf/d5v/q0X32oV+/3qjfV3Re/xaNcYT+T30tlq4lsJZ4p
x9KlaLoIimQKWHlYNgcKZ7NYGVAomw5lU7AcVj4VLqQjxWwUQK4WwBZnDnbz
x3ul88Pq1Um9McFf7y5+f7j+8+n2H4Dw0x3A+4/76z9vLn67OHk+Priv716W
88eZxF40WPS7Uo6d8JbOo1NYFWITwtUINuWcZcwvnb1E3Zwnrc3il+lTi4Aw
bWIeHJ4BXurUPA23APzOkJcZ1NW5mfWFuc2lRfbqKm99AxAWsbkSDh/lCVG+
SMoXg4BchCsUsyFe3gYH4l3eWF9cW51bWWYsgZvvfPOBFab1e5SfIv8Y3xnC
z35pDb8k6JdGmJjGTwK82PhOYeOLWxnDr43iN0cIrCECGF9+P0HYRxD1ECTd
BKSTgHYQpG14aSte9hkva8HLQZ8Iik8E5Sei6hNJ/Yms+UTRfqLqPlH1n5qE
DS0zzT5hfZzRgz7MYHjpuncghv7trOHtnPHtvOntgundkvn98tb7le0PkLCl
Zd0KCLdu2No3AGF7JyC86ejZdPQyHX0sZz/LOcB2DXLcQ1zPMN8zKvCOiXzj
ksA4GpyQhSfl0UllfOoF75QuO6nLTejz4/r8mK4wos0PafKD6ly/KtunzPTI
092yZJc00YXGO5FYJxLtRCJdSLgbCfcgoR4k2IsE+9BAP+ofQH0DUu+g1IP5
BXgd0O+Wh7Pt5W77uDt+7k6AuxPk7QS5sBB3O8TZCrLNQbYpwDL6mXrfps67
ofWuazzravcaSPX31J5mGs+qxrMC0nqWde4lvXvJ4Fo0OhfNzqVtx7LFsWJ3
rLmcGz4nK+TixdzClBfJ+eSlgHo3pK9HzIdRy0ncfp78Pr6he4g39gTAwg8T
Jb5UkjDse/CbIPBPHwqwe1j8vnnh/QlvvfR1v/L1oPr1sPblsPZ8sPe4XwN+
b5t+Syf54mE2X09la4lMJZYqRVPFcLIQTuZDydxL2WAKlAmm0qBAKhVIJf2p
hD+Z8CXjvmQMlsJKx/3ZRBBALmaiYItrpcw+IFwHd2Fwij64vzh+vjn/dnf5
x8P1X483/wB4H27A+P5xdf7t/PjpqA7OBRfF7FE6XosECl5n0r4dMjf8SkwI
TytgKjirCHNRuDbLW5lmLTYIE1bo+OUZ3NI0bhGGXwR4p0lLM5RlBm11lr4+
P7u5uMBaXuasrvHWNwWbbCGLK2LzxBy+mCMAidh8IYvHB8fmDTZ77QXv/Mry
LMC7OD+z0MDLoM7SKf8t8kv/zS9GmEaapBEnaYTJhl/G1BQ2vrilcTwY3/UR
Ahhf9iCRO0Dk9xGFPURxN1HSSUA6CEgbAW3Fo5/x0ha89BNM9hEv/0iQfyQq
PhKVH0nqj2TNR4r2IyBM03+aBhlg/4l3Rvd+pun3LUP/ZtbwZs7wZt74ZsH0
dtH8dmnr3fL2+5WdD6uWT2tWjLANI2zv2HB0bjogYaazl+XqY7n62e4BrmeQ
5x0S+EaE/lFxYAwJjknD4/LohDI2qU5MalKTDbz63IQhP24ojOkLo/rCiK4w
pM0PYH57od9UF+a3E411INEOJNKBhDuRcBcS6kaCPUigFw30of4+1Ncv9Q5I
PQNS96AUjK8DHJ4HUNuA1Su0+oQ2v8gWENmDWCGYLSy0hYTWkMAS4u8E+dtB
3laAa/ZzTD620cc2eFl6LF0zJkjfbBPm2TB41g1u+JerGl2rJufKlnNl27Fq
cazaHesux6bXwQo4uRGXIOGRZLyygl9VCehqIeNBZPs49vP4QrwP3/FCuakv
u1iVFPjlUzn5WEqAwFH5HpaA/Te83w6r3472vh3Vvx7VvxzWnw727us14Pey
Ujkrlo5z+YN0di+Z3o0lS5FEIRTPB2PZACzjh6Vh8RTIF0/64glvLO6NxTyx
qDsacUfDrmjIGQk6o1ixkCse9iSjvkwcKI6UsvFqMd0gfHGEnaIvT77cnP8G
CN9f/wW6uwLj+/vl2bfTo6fDvdtqGfpNNf2m7GB/9V6d0q5EtqQCvYit5m3I
2CvI5gJGGKwwjblA2Zgjr8+S1hikVTppBUZeoVNWGbS12Zn1OcbG/Nzm4iLw
y15Z465t8NaZ/E22gMkRMLmNMLkczjqbtcrcbOJdXZpdXsDwYnKxF3ZhjBly
o9lGf8P7736nqX/zO02YnMFP0nFTs1NT85M4ML7LcHwJG8NgfImcASKvjyjo
JYq6ieJOogTDi7QS0BY8+gnrI176ASb7QJB/ICo+EJUfSKoPZPUHiuYjVfuR
pvtI03+c/qkG3mlM7ozuHdZbuu4NXf+GoX89a3g9Z3wzb3qzYH67uPV2efvd
8g4g/LFBeM3Wum5r27C3bzg6Nh1dm85upquH5eplu/s4nj6ut5/vGxT4h0SB
EUlwBA2PyiJjiti4KjGhSU2AY7M+O2nITRryE4bCuKE4ZiiO6ovDusIg8KvJ
9amyPcp0N/Sb6JTGO9BYOxJpR8IdSAjUiQS7kEA36u9Bfb2or0/q7f+OV+oc
lNoHUdsgah10+lFnQOoCBaWukNQdxopIXTDUGUEdYcQRlthDYltIbA2KLAHh
TkC47RdswfjmRj7eS1yzj2P2ss1eltnDNLs3t9yb266NbeeGxbFhdWzYHZsu
B9PrYAcc3LBTEHeL0x5pzqco+TXVoKEe3sLG1/EyvsE7cHIuRh/ByJaTz1Bu
+ksVlIHtpp9300+VFDgkg7WFLw9BvNg3pdRDOfP4cuf9gi3vt6Pab8f1b8f7
oC9H+08HdeAXnJ8vy9jhOZurpzLVeLIciRdC0VwgkvGF095wCisJ8sASnggo
7g7H3OGIKxx2hkKOYMAe9NsCPqvfa/F7YAGvNeizhwMAsjsZ9WcSoUImtltM
1yHhCiB8e3b42CB8e/nH7eWf4Ov1+e8Xp19PD8GfKw2/x+k4OD+X/O6M0xrb
MQWMGpdGbpVLzAi/QVjOWUWZS+KNBeEqUMzgLs2wF6dZC9PM+enNOdjG3Mzm
HH0TLO/CHBOM79ISe3mFA/yurnPXNgFh3gYLrC2Iu8HmrLPg7K5sbixvrC2u
rcyvNPDOwTdWzdGpkC18VzOMTiOBGNMk+DvT3yGT4Mu+mF/Gi98ZGg4SpkxN
k6emSZPTxMkZwhQdP8XAgfHFNcZ3ZRSO7+YQkT1A5PYT+b1EYTdR1EUUdxAl
bUSAF2khIJhc9APWe5j0PUH2nih/T1S8Jynfk1XA7weqFgYJ6z5ON/uA9R6m
fYf1dkb7Zkb3mq573fA7awSEXy+Y3iya3yxBwo0J/rhq/bRmgxO8bm+Dfp2d
m84upqub5e5he3o53l6er4/vHxAGBsXBISQ8LI2MyGOjyviYOjmuTU/oMhPY
8k4YCxPG4rgR+h0xNP32Q78Z4LdLnuyUJTqksXY0CvC2I6F2JNiBBDqRQBfi
70Z9Pai3F/X0Sd39UtcAlOsYktqHpLYh1DKE7gx5AypvUOULqX1htT+CFcWK
gVS+mMobVXqjCk9U4Y7IXRGZMyx1hECoPYTaggjIGpRYg2JrACQCWfxCi09g
8fIsXq7Fw7G42VYX2+Zk2R0sp4PltrO9Dk7AwQN4Yy5xyo1mvYqiX10J6vfC
Zuzm+/LYORu4zYfvG3gryefdJtuvtSzoC6iafd7NPO2mHytpsLbA7F0peQe/
pu7K6XvspaLHWuEZXHuBX2x8fzve/w36PfjZ7wU8PMPxrSVSlWi8CPD6wxlv
EPtwTiDhgsWbBWNYUWcg7AiE7P6Azee3eL07Hve222l2OUwuu8lph1/dji2v
a8fvsYX8zljYmwJDnIlVCoBw4WS/cnlcbxK+PvsNyAVdnYHL79eTQ7C/4Px8
VcqfZpL78XAl6Mt7HEnbdmTL4DOoXRoZOEVvoQKDmKsVsFRAMXtNygRbvCRe
B3M8L1iZ5y/P8ZbnuEugeQ5sgbO0yFle5i6vcFdWId7VDd7aJneN2YizxmSv
QrlwdpfWVxdWl+dWFhlL8/SF2Wn4qQSwuYAtlUQHUeAHA2eoRHrjl03FDbbf
IzaeX9Gn8ZAwFTeD+Z0hTc0Qp+gEiHd2CoeNLx6M7+oIHF/mIJHTT+T1kgQ9
JGEXSdRBFLcTJa1E5DPAS0A+EpAPeOQ9DH0HIoCk74iyd0T5O5LiHVn1nqJ+
T9WAPtC0/9Z7rHc07VuaBvRmWvsaNKN7Rde9YuhfzRpezRlfzZteL5jfgAle
akww5ncVTvBnzG/7prNj09XJdHexPd0cbw/X18v39wkC/aLggCQ0hEaGZNFh
RXxElRjVpMa0mXF9dvxnvMbSqLEE/A7pCgPArzrXq8p0K1KYXzC+AG+kDQm1
SYLtkkAH4u9EfF2Itxvx9KDuPtTVL3UOSB2DmNxhqXVYahlGt4fRreFgyBAK
G0IRQzhqDMeMEVAcKwEyhGH6UEIfjOtAgZjWH9P4omovTOWJKEHusMIdlrvC
MjDfziBYc8Tplzh8YodX6PAIHG6+08VzOXluB8/j4Pkc/IBDEHaIYk5J0o1m
PPKCT12GJ2fTfmT7KGY7TTRe822cnKMPP+GFcvdyX/fyoC+gWu65mnvazT5U
MvflNHxjVSl1C0vflTOY3/xjrfiEPbMC115wcm7g/Qr8Hu4/Huzd7VWvdyvn
xeJxLrefSldjiVI4mg9geN3+xodzYo5GPlAUK+Lwhe2+kM0bsHh8O27Plstl
djiMdpveatFZdrSWbZh1R2ezGpx2swco9tkjYIjjgdwPwrtNwhcnXy5Pv12d
fQNfzxt+6/d7u9flwnk+A47Qe5Fg2e/Juu2Q8LbRb9S4tQq7SmqRA8VCo5in
E3I0fKaKu6lgr8tYayhzFdlckWysiNdXRGsw4doqSLC2JlhbF6xt8GGbPCyw
wpzVTdbKJrjtbiyt/5hdxuLczAIDfh4Qfp63wZZMnCHBT+XDyAT4SwpQTPxp
i3/ghWF+6U2/uBkyDvilE6cY+KlZHG5+6vv4EtaH4fiywPj2kfg9JEE3SdRJ
EreTwPhKPhPh+EK8BOQ9AXmHh70FEdC3BOlbIkj2FvpVvqOo3kHCTcX/1juq
5i3WGxrs9bTm1bT21xndr3T9rwz9r/9B+P3yzgeMMObX0brhbN90dTDdnSxP
F9vbzfF18/w9/ECvMNgnDvUj4UFpdEgeG1ImRlTJUU16VJcd0+fGjQUgd9xU
HDNheI2lYX3Tb58aOzwrUi/j28TbJgm0SXztEm+HxNOFuLsRVw/i7EMd/eC2
Cza3IVe6MyLdGkHNI6hpJBbdAcVjO/G4JZGAJZOWZOqltCWR3gHFU9vx1FYs
tRVNmiNJE9AdThhDcUMorg/GoOtAVAO3OwymXOELyr0BqdeHer2I1yPxusVe
l8jnFAUcoqBDFHaKY04k6ZJmPIq8V13266pBYz28fRi1nsDXjCDem1zoDlx7
v+P9Lrde+N6XvcJzLf9YzT3sZu8rGbC5QG6zcuaukr1v+N0rP7/4bRyevx7t
Px/WH/b3bmvVywo4PBcOM9k9OL6xQjCc9WF4oVxPFPuITtSGfbV7Ilhhmydk
dQcsLv+207PlcJlsDoPFqt3ZVm+ZVWaTwmRUGA3gq9JsUm8DyEAx2GKvLRR0
JxqEwV24ihEGB+nTg8fz42ewvKDz4y+nh89H+w/wXl6+LOZPs6nDRKyGEc65
HSm7JWYxh8x6nwEoVjpUYIuRHanYjADIfL0QLDKwzFZxWUoOU8FmylhMKYjJ
RJlMZJMp2WSKN5iiDaZwnSkAh2cwvqub7JUN5vL6xtLa2sIqhhfM7mJjdqeB
XDId/jwc4jSRQCPgf0TE/4di4gvhH34hYRqeTsXTKTg6GUcn4RhE3CweN4fD
LYDxnYDjuwbGd4iIjS/p+/iKO0gS4LeVhLQQkU/En/wSgFzYGxj6hih9Q5S9
IcnfkhVvycq3kDBU/CMqFkX9FkRVv6GqX2O9oml+hX61v9B1v2B+f/2PCW74
/bRmb/ht++6X4+3i+rt5gW5BsEcU6hWH+5HIgDQ6KI8PKpPD6tSINjOiy44a
8mPGwtjL8mLjC/0O6gp/Pzw3xjcM8LZKAq1iX5vY2y72dEhcXRJnt8TRi9j7
ENsAuOrCA/P2MJArNY+iplHUOIoaRlNxZzrhTCddGVDKlU27shl3DpTFyoFc
oGzOmc06M1lHOmtPZ2ypjBXQTgLawHVyK5Y0xxKmKFjtmD4S0YXDmlBQHQoo
g3550CsLeqQhNxpyoWEnGnWicac06ZJn3EqAt+TT7QaMe6Hmtfcs6b7M+K5z
QQxv7PFnvPXCt3rx2z6o9BVUL32pF5/3Co+1PHxLVSULNhewvYGfTQDfwDdJ
Ar8PL36/HNS+Hu59hQ+vGpffPezwXMEOz7mDdLoWT5TB+PpDaY8/6fLGHYCt
K2JzRqyNwPfNwlZXyOIM7Dh8W3a3yeo07Ni0Wztqk1lhMMh0OlSrRTQaRKNF
tTqpHkA2q7d39HaH2eOxhkKAcDCXjVVKmZ8JP5wdPZ0dPYOA3+MDcDQAE3xT
KV0UcqcZSHgvGgIH6YLXlXGBId6J7gDFBr9R69WBE7XCoZRZ5eiODCyy2CQR
GcVCvUigE/I1fL6az1PxeEouV87hythclMVBmBzxJlu4weI3/C5vbC6tvbzI
2zgzY7NLhpsL5AKteDwVh6O8BL6n4nHfFc8AxRhhBiT8c9Avg4ZnUPEMCp5B
xjFIuFkCbg4Pxhe/OIlfHsevgvEdIWI3XxIc316SsJss6iRDv20k5LvfD8T/
xIu8JqCviSDpGxIk/IaseAMJQ8WNMMvN799gvcZ6RVX/SgNpfpnW/jKj+4Wu
fyFserVgfv1/99vO8nSwvZ0cXxfP381v+A33SiJ9aLRfGhvA/A6pU8PazLAu
N6LPjxoKo8ZiY3kbeL+Pb68y82N8wclZEmoVQ7ytIm+byN0udnWIHV1ie7fE
1iux9CE7A8j2ILI1DDcXY4vqRxHdKKIdzSX9+ZS/kA4UMoFiNlDKBUHlfLBc
CFYKoUoxCCrDAqBS0V8q+IoFbyHvyefdeUA768xmHJmMPZO2plOWVGI7GTcn
oqZ42BAP6WIBTcyvjnmVMY8i5lbEXfKES5FyKTNuVd6jAXgrGN6DiOU4Bq+9
F2nfdTaIXXtjj+XkUxMvnN2G3G8HZdBX0H75S730vFcEN9yHav5+N3cLP5XQ
9HsDvq/k7nbz99Xi417pqV553q9+ga8c7X05rDdePLqr7V5XyufFwnE2W08m
d6OxIhzfQMoN8cagXAcobHGEsW9eIDvDVmfI4ghs231mq9u449BtWTWmLaXe
KNPqELVarFSJFEqhQilSqMQqAFkn05uUW+A47TC7wQqH3YkEIBzfBYRrxdMG
4ZP9h9PDx9PDJ9DxwRM8HYD/gpXrShESzqbBQboei1TDgXLAm/e4Mk57Em7x
VnjLGDTpfXqtR6t2qZUOpdymkFlk0m0puoUgJonEIBbrRSKtQKTmC5U8gZzD
l7J5CJMLCAvWWcAvfHvz4ip8nYixtIA9Z56Bswt/gBURD5xScFPkSdAkeWKS
NDEJv5mcokxNQcj4H4Tp/4UwwIuF+Z0l42eJ+DkCfh6HX5zCL03gV8YIa6PE
jWEia5DEGSDx+siCHrKomyzuJEs6yEgbGfhFW0joJxIK/RKRd8QGXgmGF3lN
RBp+X5NAstck+WtIGCqGkH+q8TuvySrQK+CXov6Vqv7lh184wb98n+D/9Lvh
aN10tTHdTb9cfxcv0MUPdgtD3eJwjyTSi0b7ZLF+eWJAmRxUp4c0mSFdblif
HzYURhrPrED6v918exTwsfPf8IoAXk+r0N0mdLaLHB0iW5fI2i3e6RVv90u2
BiSmQYlxGDGMIHrIFtGMStSjEtVoORMpZ6OVXGw3H6sW4rUiKLFXSuyVE/XK
S7ugOGivEturRGvlSLUc3i2FdqFuf7ngK+W9xZy7kHHl045c0pZNWDKx7UzE
nA4ZUwFDyq9LebUpjybt0WTcmqxHk/fqSj59xW+qBbf2w5ajmP004TpPea+y
gZt8+K4YeygnAN7navZLE29T7reDCugr1pf98nO99LhXfKgWAFUAFrBt+oU/
YQMQBq4LYIIf98pPdfi2jWf489trjVd+wfheloun+dxhOr2XSFQi0UIgmPGC
8fXE7a6oDTNrsTezOqKwBmFHyGIPbNt8ZovbsO3QmS0qg1muNaAqjVihEkrl
fFTGQ2Q8VM6XKoRyoFgn1ZmUZovO6tzy+GyhiCeZDOVz8d1y5gASrlwe1W6O
9+9PDh5BYH+PwO0cPl3DCJfAQfoslzlOJw/gEId3Q4GS/0WxzRK3bEe2zCGT
wW/Qe3Vat0btVKvsSqVVodiRybalUjOCGiWIXiTRCMQqvlDOFUhZPMkmB/pd
2WTBd1jBt0cu0ht46VQSOBiDecXkArMTxPEJ4tg4FvhmgjSOQf5PwtQXwg3F
TbyEJl4Sfo6In8fjF3D4pUnC8jhhdYywMUJkDpHYgyRuP5nfRxb2UMTdFEkn
BemgoG1ktJXc9PuRhDb9EpHveF/BUBhJ+ooke9UgTFI0evMjJeg1iKx8BaKo
fgW9+P1//pvfNz8eYdk+rdtbNpxNv2xPB8cH/HbyA12CYFfDLxLpQaO9snif
PNGvTA6o0oOazKA2O6TLD+lBBSx4bH7Bm+1RYCdnabwdibZJwq3i4GeR/7PQ
+1ng/ixwtgrsbQJbh9DSKdzpFm71ikx9IuOA2DAo1g2JtSNizYhYNSpWjooV
o2L5aC2f2iuk68V0HexBOXtQyR7u5o5A1dxxLX+8lz+B5Y5h2eO9zFEtfVhL
HVaTB9XEPkANRJcjtVK4VgxW84HdnK+c8ZRSrmLCUYjZ8hFLPrydC5pzfmPO
Z8h5DXmvoeA1lHzGit9cC27Xw5bDqP0kDvFeZn7gffyB9/vsVr4dgnYbfT0A
R+LKc70M5hUI/e73ugTKXGOEb+DPucrf7RbACj/UyvAnP9d3QeBseluFMM6L
+ZNc9iCVqsVi5XA47w9kPN6k0x2zO6N/w2uPgmyOmM0BvkbhKNuD21a/2eIx
bDm0JqtKb5apDYhCI5Iq+YiMK5ZyRChbhHLEMi6iEEjBKOulWnA7tupt7m1P
wBGO+VLpcKGQqFayTcKHgHD97nj/4Xj/EQQmuPECda0CDtKXpcJ5PnsCztLJ
+H4sUgsHKwF/0Qsuxc60w5awWmI72+Etc9Bk9BsMXp3OrdU61Wq7UmVVKHdk
ii1UZpRI9SIEEFbyhDI2X8LkCKHfDSb22cAl+PaqOTqFTiPBHzpHwJGnoFzC
2Dh+dAw/MoYfxgLfjIwTRoHixhZDwkA6WOoZQJgCCTOahJt4Z3/GS4B4F6cI
yxOE1XHC+ihxc5jEGiJxB8n8foqwjyLupUi6KUgXBe2kSNsp0jaK9DNZ2kKW
wgkGhElokzDxb35/JUpBDcKvSPJXRNjrZgoYSfEKBv3+SoZ+f/mbX3B+Nvwy
a/x1vnl+bvpdtXxca/r9zHS1soBfbzvH18GDfjsxv13icLcE+u2RxnrliT5F
sl+VGlBnBjTZQW1uUJsf1OUHtZhczU94ZalOaaKJVxT8LPS3CLwtfHcL3/mZ
b2/lW9v4lnb+diff3C0w9QgMfUJdv1A7KNQMiVTDIuWISD4iko0IpSNCdOSg
lD8sFQ4rxaPd0nG1dFIrn+5VzuqV8/3dC9AB7PIQVLk4LF8clM8PSuf7hbP9
/Gk9dwJE19JH1dTRbvKwEj8oRfeL4b18sJb1V9Pe3aS7EneWo7ZS2FoK7hQD
2yX/Fqjs39oNbNeCO/Ww9TDqOI67zpLei0zgOhe+LcTuSwn4duV/w9uUW/12
hHVY/XpY/XIAJrXyVC8/1Er31cLtbh6A/e4XK3uDfdT3u+L7auNjCyVwML0s
5c/y2aNMup5MVKPRUiiU8/nTbk/C6YrZAVIg19YoarXFrPaYDQQJx7B/FNqx
Bsw7XuOWU2e0qnRb0K9cI0SVPImMI0RZAgQLZQtlXIlSINWIleB2vK3echjt
3h1vyBmJ+1OZSKGQ/E744rB6fbR3d1S/P6o/gA7r9/vwGXnjD5sG4dMMOEsn
9uPRWgTciP0lX2OIHUm7NW7ZiWxvh8zmgNHoMxg8Op1Lo7Wr1FaFChA2ozKD
BNUKJdAvhw/3d43JWV7fXFhZZSwuTM8xKPRpiBf+xNepCcI4kDuKGx6dGhqZ
HGw0OjU4ihsCkL8TBgdpeB3GCDdO0TC4uY0ohAbe5skZD/GC8V0ZJ6yNETdG
SMxhEmeIzBukCAYoon6qpJeK9lCl3VRZF1XWSZW1U2RtFNlnsgwQ/kiWNgj/
m99fm0mxZKBXP5K/pICRAN6GX/UvVM0vP99/sfH97he+i2MF+LVifh0tmw2/
njbglwv9dmB+O4WhTnG4SxLpRqDfHlm8V5HsU6b6VOl+daZfne3X5Jqpc32q
XK8y243h7UAB3lirOPJZFGoRBlr43k889yee8xPX3sK1fubutHK327nmDp6x
i6fv4el6+Zp+vnpAoBwUyIcEsmGBdFiADAskwwLx8HGlcrK7e1qtntVq5/W9
i/29y4P61eH+9dE+ONLdHh/cnoD2seo3x3s3x7Xro+rV0e7VYeXyoHSxXzyv
58/2cqe1zMlu+ricPCrFDwuRg1yongnspXy1hLsac+5G7Lsh227Iuhu0VIPW
vZCtHrYfRJ3HcfcpwJsOXOXCN4XYXSnxgOF93st/qRfBJRebXSj3Nyi3hrUH
+npU+wrfBll92q+A4/E9nODCTSV3Xc5elTJXRVAaK3NdbEAG65y/gR/7LVyX
85fF3Hkhe5JNH6aSe/HYbiRSDAZzPh/wm3S64naIFLBtFAPZ7PGfAr8T2bEG
t3Z8xi23zmhX63bkaiMi14pQFV8s5wilLD7KBPdMHsoCF05wZhWDc7UOUZkV
eqt222Vy+K2+iCua9KezkWKxQbhwUgd/OoL/XWs3h3t3ILC/4BZcr97Wdm+q
5SvwR04R/pHTWOE6XGFIuOgDK+xKA8I2awwjHDSb/UajV29w63QOjdamUu/I
lWap/LtfcAUG918+uPwura7PLS3NzM9RGTOkaQrES5zC/saEkZHJoeGJgaHx
/qHxPtAwaKJ/ZHIAKP5BmNwgjMc3CZMIdEwxkMsgg/6GdwE+tsLGd4wIx3eE
xB4mc4co/EGqaIAq6achfTRpL03WQ5N30+RdNHknVd5OlbdR5J8pgLAMIyx9
Bwmjb+DNF/13vwSQ7OdeEeSwH36bh+dfsefPDby/Mgy/gvGd+zG+b5d33q1Y
oN9126eN737dwG8b19eO+e0QBDuAX1G4UxLpQqLdaKxbGu+RJQDhXkBYme5T
ZbCyvfB9kmB2M93ydKc0CfC2SSDeFmHokyDwke/7yPN85Do/cuwf2dZP7J0W
9nYr29zGMbZz9J0cbTdX08NV9XEV/Tz5AE86wEMHeZJBnniQJxrkCQfPavXz
vf2L+sHV/uH1weHN4dHt8fHdycn96cnD2ekj6Bx0gnX8eHb0cHZ4f3pwd7J/
d1K/Pa7dHFWvDytXB+XLeulyr3BezZ3tZk7LqZNi/CgfPcyED1KB/YSvHvPs
RV17Eede2FGPOPcjzsOo6yjuOU36ztPBy2wDbxLgfYR4CxAvnN2G3BrseA+r
/u2lr0d72DuZq4/1ysNe+a5aBDt7Xc4Bv5fF9GUhdZFvdgkqgN8Bvw/KXhQy
5/kMfCqUTu4n43uxaCUcLgYDeZ8v4/aknK6E3QGR2jC5VlvcBrIn7C8BwsC1
xRre3gmYtjx6o0OjsyjUZlSuF6NqvljBFYATqpTJRbHAbROIVvElWpHMKFXv
qAwO/Y5nyxm0+WPuaCqQzkUKxcRuJbNfhR9zAGcfcPC52q/egOrVm73dG3AL
xvxeYEeGk2zq8McEB4p+b84D/Sbs4L+sJbzT9OsxGFw6nV2jsSpV23KFCZXp
JYhaKAb3X4TFFa4zuXB8l1cYCws0Bp08TcVTiJMAL25sdHJ4GP6lY/2Do70D
oz0DIz2Do7ChsV6guEF4HD88QRidJI2DOzIOEKbh8dPfCWMxSHgGEeKdJeDn
cHjsmTNhaYKwMkaEj61GSKxhMmeIwhuiCgep4kEaMjAtHZiW9U8r+qYVvdPK
Hpqym6bspCk6qIo2qqKVIscIyzDC0rfExsNnjDAB9gtB+iO89Fd8g7D815/8
voLPr9SvqJpfad9f/DW8mjW+AnjnzU2/y9tvV3berVo+rFk/rNs+bjg+bTpb
mK7PLHcr5reN52/nB9oFgXZhsEMEJ7hBuOuFcI882aNIgXNyI8AWygWzK022
I/FWSeyzKNIiCH3kBz7wfB+4nvcc13u24z3L9oFl+cja/sQyf2YZW1n6Npau
g6XpYqu62YoetryXI+3jIP0cST9H1M8R9nME/Rx+/2X96Gr/+Prg5Obw9O74
7P7k/OH0/PHs4vniEvTl8vLrVaOLL6DL8+eLs+eLk6eG5dPDh5P9e3BtO9q7
PazeHOxe18tXe8XLav6ikjkrpU7z8ZNs9CgdPkwGDhL+g7j3IOYBHca8xwnf
STJwlg5dZiPXhfhtKXlfyTxWc0972NuVG7P7E1vYCWi/0beTxiu5dUD4CSN8
Xyvdgglu+C2kAdvzXPIsm/ip5FkOdppNnmSSx+kEnDHAIBqphEMlzG/W40m7
XCmnM+Fw/ABrtyf/XgLQtlgj2ztB85bPYHRp9TalelumAJdMnVCi5gkVHL6c
xZUxOVImR8biytl8FU+oFSLgjL0t19g0JpfB4t92he2BOEY4Cw7S8UopvYd9
3vCkVjyrlc5r5Yta+bJavtwtXVSK5wBvIXeSSx9lkgfJ2F4sshsOlgK+vNed
cTuTDvDnjSUC8G6Z/aaf8KpU2wqFSSrTI6hGJFbywfhyxZss3uoGa3FlbXZh
cXp2ljJNI1BIU4Sp8alx7O8aGxgc6esf7ukf6u4f6uof6uwf7hwY6Roc7R4a
6xmZ6BudHBjDDU3gRyaJY1OkcRxlEpyi8Q3CMyAino7FIOAZePwsDj83hZ+f
xC9OYI+tRonrI6TNETJ7mALGVzBEFQ3RkMFp6eCMfHBGMTijHJhR9c+o+mZU
vdOqnmlVF03VSVO2Q8KKFrIcEH5PkgHCb4jS1+Da+7Nf/M/JfsE3/f76d7yv
aNpX07pXdP0rRuPNk6bX8+bXC1t/H9+GX/vPfj+zPa2cJuE2SDjYINyBEe58
IdwtTXTLko2wqy7YXCAXzG68VRxtEUY+CUIfeIH3XN87jucd2/WO5XjHtL3b
tLzf3P6waf64aWrZNHze1LVuatqZqg6msosp72ZJu1loD0vSyxL3soS9LEEv
i9/L5PVeH5zeHMK/PfP++OLh9PLp7Or54vrL5c3Xq5tv17e/3cB+h938Brq+
/nZ9+e3q4uvl+RcA+fz0+fz46ezoEUI+eDiu3x/Wbvd3b+rl61rxajd/Ucqc
F1KnufhJJnqcCh8lg0eJwDEoGTxNhc4y4Yts9Cofvyml7iqZh2r+aa/4vF/+
erALL7kNti9gfzs5+O200eFLB0Dx1+P6MyC8X33Yq4AJBifkqxJY2HQD72km
dpKOHaeiL8UaHaVih8nYfiIKGNSiYSChHAwU/ACDN+txNwinHA4s+/fSjW8A
YbDIVmt0Zye8tRUwmjw6vVOtsSqU8DmRGNEJRGqeQMnhKdjcRuB78Dtagdgg
kW5JlValzqk1e03WwI470iAM7sLhXD5WKiSqpVS9nDkoZ4/KueNy/qScOynl
TorZ43zmKJs6SCfqyVgtFq6Eg8WAL+dzp92OhAMc83fCO1uBLZPXaHDrdQ6t
xqZW7yiVW3K5USrVIwjAq+ALpByumMnir22wl1bW5xeX6LNz1OlpIsSLg3jH
h4dGB+Bf1zvY3TfQ2TvQ0TvQ3gca7Ogf6hgc7hwa7R4Z6x2d6BubGpjAD00S
RqZIY1PkCYzwFJ6Gw0/j8TNYdDyOjsMxpnCzk7i5CfzCOH5pjLAySlgbeRnf
YQofjO8QTTI0jQ7PyIbpimG6apiuHqJrQIN0zcCMpm9G0zut7p5Wd9JU7VTl
C2E5IPyWJIOECdJX8Nj8b3h/8gvHV/mKBPG+pmpe07Svp3Wv6YY3DOObWdOb
OdObefObha03i9tvm3jh+L4HeJv7a/+06fjEdLawXC1s92cOJNzK9bVihNsa
hIWhDlG4QxzplESxz/DGu1BQohNNdCCJF7lgdqOfBOGP/NB7buAdx/eW7XnD
cr1hOt5s2t5sWN6ub79d33q/bvqwbvi4rm9Z137eULdtKNs3FB0bss5Nadcm
0rUp7t4UdW8Kuzf53Zu87g1u9+3h+d3R5f3J1ePp9dP5zZeL26+Xd9+u73+/
efj99uGPu4c/m92D/ri9++MWs3x99e3qB+QvAPLZ8dPp0SNQfLR/f7B3V9+9
rZWvd4tX5dxFMX2eB5rip5noSTpyinWWiV7k4leF5E0pfVfJAryPe6Xn/cqX
Q+yei8n9/fTg99PDH50dvXTc+AYo/nZy8AUj/Li/e18rgwlu+AU7e5KJA7NH
ychhInwQD70Evg/vx8P1GKwWDVUjoYbfUsBf8HnzXg8gnHG7Mi5nxulIN7M3
g4ptKbstYfvxwMhvMLi1OodKbZErtlCpUSzRC0VavkDD46u5vEbgl+A3ge4t
VG5VqB1qwGzLZ7YFLQ3CkaQvkQ5kMuF8NlrKxXdziVo+uZdL1kHZRD2T2EvF
asnobixcjgSLIV/e78l4nEknuJpbwhZMrsngMkC5VrVqR6kwK2RGmVSPIhqJ
WCkUyvl8hMMRMZm89XXWMsS7zJido03PkChkHAE/MTUxOj4yNDIwMNTbN9DV
29/R09fe09fW09fa29fa19/WP9g+MNQxNNI1Mto9Ot47Ntk/gRucxA9PEUcB
YdwLYRxtCjeNw82ApnD0KRxjEjc7gZsbxy+M4ZdGCSsj2PgOw/EFJ2fBME08
jOEdoStGGKoRhmZ0VjsCYuiGGbohhm6Qruuf0fbNaHumNV00dTtV1UpRtpAV
H0iK9yT5W6LsDbzkgtPyf8H7Cx6MbxPvazLE+4amfTOtf0s3vGUY386a3s6b
3y1svVvceoc9cH73srwv49v0+3ETTvAnpquF5YaE2Z7PHO/nJuHvQ/xCGFPc
KYl1YLWLYw25YHY/8sMfeMF3XP9btu8Ny/N60/Vqw/Fqw/Zq3fJ6bfv12tab
NdPbVeP7Nf2HNe2nNU3LmurzmrJ1Td62LmtfRzvWkY51cee6qHNd2LnO71jn
daxxOyDeY4D35uns9svF3dfL+9+uH36/efzj9unPu6e/7p//enj+x8MT6K/7
x7/uG5C/K75uQr68+Hpx/vX87MvZyfPp0dPxAfbwtHYHLm/V0nWlcNnYxHzy
PJf4/wi7C+a20mzR+1/jnOGeDtmOOY6ZQczMtIVmkGUxmgSWmZmZmTHUNN1z
7vd517Mlp9Nzz1u36l8pWUk7SVX/tNazBYl1tbYAR9TbzeX77dXH3XX0FO3h
DizDME9hqsJs/eni+Jnqc5fQ2c/QVTy458eLE0T45ODj0d7Twfb9Lv6Isb50
vjJ/ujQLcg9nJw5mxvenx6C9eONf251C7UyOb0+ObU2MbY6NxgivDg+tDg2u
DA2sgOLBfoC8PNCHwv0u9fUu9EZjT9tMh0IT3d2jHR1DgUC/1xt1uSIOR9Bq
62pr62xt7TCbY3WaW7ssbXB/xO6Mujz93sBQoGukMzwW7J2MDE71js4MTM4O
zc6NLMyPLS2MryxMrC1Mrs9PbkBzExszExvTY2uTo6vjw8ujg4vD/XMD0Zne
yGRPcCzUNdzVPtDh7w14e7zukNvZ7bR3OGwBW5uvzeJuNTtbmm1NjW0N9eba
2kaTqU6vN2GYTqlEeEUiES+Gl4HjJVcRiOWVVaUVlcUVlUUVlYWVUFUhgVBE
JBaTySUUahmNXk5nVDJZBBaHxOZSODCCBXRunDCLK2FzpWyujM2Vs7kKFlfJ
5KoYXA2Dp6Xz9TS+kSqooQrr0MlX0kKRWqgyG1XuALx0pZeh8jPUAaa6A2Ko
OxmqTrqqk6bspCg7SIp2gry9UhYol/pLJL4isTdf5AHC2QIg7HoHhGHUxs06
v8Wb8Yw3Swx429/LOrIVndnKrhx1MEcTysHCudpwri6Siz/bmxNbm4345H32
mwt+ccJ5OOH8+phiIIwU/z6IWyZKzJNxxZZpqMQyU2yZLmqdLkQL81ReM4zd
ifeNY1n1I5l1Qxm1g+nV/emm3nRTT7oxnGEIZRq63xm6sgwd2Yb2HEMg1+DL
N3gLjO5Co6vI6Cwy2ouNtmKjtdhoKTa2FhvNxcaWYkNz8cPpzdPZ3YeL+0+X
D5+vH3+4+fDT3cef7z/98vDpX4+ff336/OuHz7/h/YpD/qr46yz+CSm+/fHm
5ofr6x9iis/PPp2dfDg5ekKDePd5EK8hxRvLV/h1JDil3m6twroLS+8Twrv7
6XgfxwsbMs42TvU81k/xGxc/X6N+wX9E91+e/XBx8uXsCP7zJxj6u5vwG12u
L50tw/F25nB2EtjuTo7sTAxvjw/hDaMm4J6RnclRvDEI/G5PAOFROFJujI2s
jw6vjwytDQ+uDg2sDvavQAN9K3HCvfgIji709sz3RHDCsWdeO4YD/kGft8/t
jjqdEbs9bLOGrG3BNkssuB2x2aIOR6/LDcN60N8+3N492oUIj4cHJnqGJ3vH
pvompvqnpgZmJgfnJgfnJwbnxwfnxwbmR/vnh/tmh3pnBnqm+sIT0eBYuGs4
2D7Y6e8Dtj5XyOPodto67G0Bm8XbZna3tjhbmuzNjdbG+tb62pbamsZqU51R
X63TGjRqrVKhkkplCC+Px2azGAwalUoikaoIhPLKytKKiuLy8sLy8oIKqKKg
srKAUFVIJBaRScVUSimNVs5gVDBZVSw2kc0lc3iIMDdOmIkTZnGlLK6MyZUz
uUoGV0Xnamg8LY1voApMVGEtRdRAgZOvxEyRtVHldprCRVd6AC9T3c7SdLA1
nWxNF1vTzdJ0M9XdDHU3XdVFVXaSFZ1EeQcQLpP4S8S+QtFXwu73fCDsygSw
3/bN5AW876Xt2bKOHEVnjrI7Vx3M04TytOE8XSRf3wPl4S+1imdCPfuNEUaK
c2v6keK6/1A8UtQ4WvT1RBxTbJ4sNk9Bheapgpap/JZJNHYbx983jL2rH8mo
HUqvGUir7ks19qYae1IN4VR9KE3fna7rytB1vtO1Z+kC2Xp/jt6Xq/fm6935
eleBwVlocBQa7IUGa6GhrVBvKdS3FujNBbqWgsfTW/D78eLh09Xjl+unH28/
/nT36eeHzzjeL79++PLb74FinPATEP4QW6pjin++e4aMK4ZZ/Pni/NPZ6ceT
46ejgwf0KgT0FMjtNiheB18QDOW7nY2Hva3H/e0PON7Pp4c/wKk2JheoIqGX
/9EvN1d/DO68+PHy7Mv5CXrd/yH8RlvwzS/Wlk6X5g7np2DCgtOtsaGNkYH1
4f54IwMbowObo4Nw/9b4yPbEN4onoNGt8dHNsZENnPD68OBajDDud2WgF/wu
90eX+qKLvT0L0ch8T3g2EppBL4HqGu/sGG0PDPt9g170WsY+lyPqtEcdth67
FYrabb0Oe5/T2e92DXi8gz7/UKBjuB2mcGi0KzLa3Tsa7B8JDY6EhobDI0Ph
0cHw6EBorD801hcc7e0e7ekaDncOhdoHuv39Hb5owB3xOYMee5fT2m63+K1m
j6XZZW50NDdYm+osDbXm+prmWlNjjbHepK816Ew6zICptSqFWiFTSMUSkUDI
43LZLCaDTqVScLxV5ZUVJRXlReVlBeVl+Xh5leX5VRX5hMoCEqGQgvyW0Gll
DHoFi1nFZhM4HBIHEaZy44TpXBGDK2ZwJQyujMGV07kKOldF42moPB2Vb6AI
qinCOor4efjKbVSFk6Z0M1Q+pjqA8GJdHKybiwUhDhbiaEJsTZCpDjJU3TRl
FyIs66iUtpdJAsVif6HIly/05go82Xwg7H7Hc0GZKHcmjved0Jsl8r0X+7Ol
7TmyjlxFV56yO18dzMfCBdpIga6nUN9TaIgWGqMF6H1G0fznfif8reLqmOL/
nMWFvyseK24ex5soap4obJ4oaJ7Ia5rIhdNuA4zd0cy6YcCbVj2QaupLMUaT
DT3J+nCyLpSi7U7RdqVqO9K17RnawDutP0vry9Z6c3SeXJ07T+fK0znzdY58
nT1fZ8vXWfN1bXlaS562NU9rzsX93j/7/fCN3y+43x9+gz5CccK/fvg6hT/8
8Vz8EFP8483tM+ELIPwBET58ONi/39+NPRFyu7N5B+1u3e9tPx7sPh3tfTw+
+Hx6BAZ/vDhDcxaoxnle/3KLd3P9fPvmX9Ddc+inrn66uvjh4vQz/rp/+J7w
EAF+T5bm4Hi7MwUrMRjsXx3sXRmILuPBDfhybbgfUG+OAmF8HOOEd3HFOxOj
2+OjW2Mj8LMbI3G/q4MI7wqON+Z3qa8HCC8C4Wh4LhKaDQeng12T3R3jnYGx
dt+I3zvkcw96nANuR78LsuM5BtzOQbdr0OMZ8sIv8A/524cCcHzuGgwEBwKh
/kC4LxDpDfT0BHoi/p6Qryfo6+ny9nR6Iu2usN8Z8jm6PbZOl7XdYfHbzN62
Zndro6Ol3tZUa2moMdeZmmuNjdX6epOu1qitMWAmncagVek0SkwlVymkCplY
KhaKhLA0c9hsJgxeCpVMJBErCZVlCG9ZYXlpQVlJHlRekltRmltZlgd+iZUF
ZEIhlVREI5cwqGVMejmLUclmEThs4lfCHD6chWkcIZ0jonPEdI6UzpXRuAoa
V0UFv3wdRWCkCGsoonoyDF9pfPhSlS66ystQ++N4td1cbYinDcfiYii2JsxS
hxiqIFXZTZZ3EWQdFdL2UnGgWOQvFPryBTHCHiCcBYpRHpTgGa8E4c1TdOUr
uwvUwUIsXKSNFOl7ig3RYmMvyoQqMvUWmnoLTHHIeaYeKBcvJ14UVd2bgyyj
69IxxQV1Q3HFDbjixrHCJlRB41he41hOw1g2Ou2OZNYOp9cMplYPpBj73hqi
SfpIki6cpA0mYd1vsa5krCNF056KBdKxQCbmf4f5sjBvttaTg3Lnal25Wmeu
1pGrtaMwWw5mzcHasjWW7IeTW3x/fvh0+fj5+umHG9zv/edfHr/866tfFPL7
K+4XTsT/wgn/Eif89DMQjikGwrfPhC8R4Y844UcgfAiE9+6Q4p37fWgX5jIs
2B+ODz+dHn8+P/3h8vxHtB5f/XyDO727xbvDe75xf/drrIfYjVvgDNh/vDz/
fH4C3wpO3NfbG+dry8eLc3uzk1v4m3ZWBuHQ2rPQG1noDUOLvWH4EhSvDfXB
LAbgsFGDWcC7O4UI78YJw+AeBr/rwwNr4Hcg5hfhXe6DepZi9UYW4TtHw/M9
oblI90yoazrYMdnVPtHhH2v3jvo9Iz73sNc15HF+E3zpHvIiwoNe34DX1+/x
93kCUXcg4moPOdu7He2d9vZ2W8BvDXjbAm6L39Xqc5i99haPtcllaXS21ttb
6qxNNZYGk7nO2Fyjb6zW1huxWoOmWq82apV6TKFDH1klV6ukKqVEIRfLZCKJ
RCCE4y6fw+GymCw6jUElU0kEMqGCUFlaWV5cUVpYXpJfVpxXVpxbVpxTXpID
fqvKconleaTKfAqhkEYqopNLmNRSFr2czajgMKs4fyBMwQlTOUIqR0zjSKhc
GZWroPJUFB5Gwf2SRbVkcQNZ0kyWtlLkVqrCAcOXrvYxNO0srJMNeHUhni7M
10XwevjaHp42wsUiQJipDtGVQaqimyTrqpJ2lEsQ4SKRv0DoywPCfC8QxhV7
3gu8KKEvW+zPkbTnIrydBcruQnWwCAsXayMl+p5SQ7TU2Ftq6iutjldS3Vtc
DYqjhYhwT74xkmeM5BojOXjoojS6Lo0uTT9fne79+uxSfi0oxjfq+uGChhEo
v2E0r2E0p34ku34kq244E3bm6sFUU38yjjdRF0nQhhOwYALWnajpTNR0JKnb
k9WBFLU/TeNP1/gyNb53mDcL87zHPNmYOwflwnNmY45sjf29xvZebc2C7k9u
Hk/vns5jI/jpyw0+gu/RCP7l8TMijG/Rv8bxfsbxwtH44y8xv48xvzjh+8ef
7h9+urv/8fbuh5ubL1fXny8vP56ffzg9fYoTPriHQYwHnOGeD8dHH09PAO+X
C8B7+dPN9c+3N7+A1nugev/r/cOvD//Zb9BjvF8f7v91fwtzGf7bL+dncOKG
x4Tr7c3ztZWjxbndmcnN8ZHV4YGl/uh8b3iuJzgb6Ybgxnw0tNgXWcYJwxSG
RRrW7N3J0b2psVg44ZHtsWEYwf+b357nItASBA8L0dACfGf4/uGumWDHdHf7
ZKd/osM33u4ZC7hH/e5Rn2sE8qJw0TCF3QNud7/L3et0RxyukM3VZXW1W5x+
s8PT4nA22e2NNmu91VLXZq61NFe3NpnMDcaWekNzrb6xRttgwuqM6hq9yqRT
GDC5TiPTos+Yk6iUYqVCJJcLZTKhVCoQS/hCMU8g5PAEbA6PyeTQ6SwqhU4m
UYlV5KpyQkVpVVlRRUlBeXF+WVFuWVEOVF6UU1GcU1WaSyjLJVXkUyoLaIRC
OqmYSSlhUcvYtHIO8lvJZVVx/0CYzOFTOAIKR0ThiClcKYWroIBfPkYW6MlC
E1lcS5Y0kqUtZJmFokDDl6ry0NV+BtbB0naxtUGuLswDufoehFcXRWmjPKyH
o+lhqyMMVYimDJLl3QRZZ6Wko0zcXiIKFAn9BQKcsMCbI/Bmo3zZQl+OCH2c
Tp60I1/eWajsLlIHizWhEm2kVN9TZoiWG3vLTX0V1X0VNX3lNX1lNUC4FxE2
RYtMPQXGSL4hkmcI5xrCOfpQtj70/vfCsVdXIsXoSldvHiiu7s+vQYrRUl03
BOXVDefUDWfXDmXVDmXWDKajnRnw9ibpEd432tAbLPha0/Va3flG3ZGgak9U
BZJU/mSVL0XtS1N7M9TeTI33ncabpUGE8dwojQvK0jiz1I53KnumypZ5d3yN
CMMIBsKXD5//QPgTIowUfw3h/QXhRX5/huJ4kd+fcL8/xv3efrkGv1cfLy4+
nJ09nZ4+Hh8/HB09gGK8x+MjQP3h9OTT+RmM6R+urn68Bry3v6Ahi1N9fPzt
8el/6enp3/EeY4TB+0/XV/AIAIP+Hvd7trZyuDC/Mz25PjayPNQfe6/ddLh7
CoZjqHM61AWKgTC4Wxnshe16c2zwq9/9qXFoD6ZwbATDCg1+h3C//bjfP+J9
LrwMYx0eFnqCC/DNw52zwY6Z7sB0l3+qwzfZ7p1o94wH3ON+91gMMhAGv27n
gMvZ63D02OyhNltnqzXQYvE0tjrrW2w1zRZTU4uhsVHfUK+tq8Vqq9U1JlW1
QWnSK4w6uUEr02mkWrVEgz42HX3mskImkEn5UilPLOGKxFyhiCMQsXlCNlfA
4vCZLB6DwaHT2FQKk0KikwhUQiW5soxYXlJVGsObVw54C3PKCrPLi7IrirKr
SnIIpbmk8jxKRT6tqpBBLGKSi9mUUg6tjEsv5zIquOCXifxyWcQ/EiZzhBQu
7pcnp/BVZAFGFurJomqypI4sbSLLzBR5G0XpoKrcVLWPrgkwsE6mtputC3F0
ER7g1UdRung8bZSL9bA1EaYqTFeGKPIgEY3gznJxR6koUCwMFMYJo3IhoS8X
8IrRZ9kVAF5FV7EqWKIJlWrD5bqeCkO0wthbaeqrrO6rqumrxEOKq2EcR0tM
PUVGOBRH8vWhXH0oRxfM1gXfa7uhrHjBLB36pMr4a6QNsevVvXkmpBgt1TUD
ubUDObWD2TWDWTUDmdUD6dX9qca+ZAPg7UnA8b7WBF+pu16pO1+p2l+rAm+U
/gSlL1HpS1J6k1XeVJU3PUZYDYQ9WX/InaV2v1O7MlWuTKUzQ+lIvzm8eiZ8
+0z48cvN04+3sQvRH3HFX4vJ/YjLjeP9Cbr/ivfhx9v7H27vvlzffr66+YT8
Xn44O386PXs8OXkAws/Bl4D649nZp4uLL5dXsG//dHsL6zeO9/FX5PTDb08f
//1tH77tw7/hFzw+gXQg/xOs6/BAcXoCk/1qe+t0bfVgYX57enJtdGRpsH8O
vTIpOBnsmujunOjumAwiwnORIOzSsRG8OToIKzT43Qe/0+MonPAOvkJvwgo9
1L822LeKz9+V/jjelT8UXkGEQ0vR4FJP90Kkaz7UMRdsn+0OzHT5pzt9Ux3e
yXYPKJ7AFeOEnUNwNHbao3ZruK2ty9waaGrx1Dc5aurbjLUtuuoGjalWZTAp
9AaZVifFMIlGI1arRCqlUKlAn/Aol/FkUq5UwhGL2SIxWyhi8YVMnoDJFTA4
fAabT2fx6Oj9Q1wanUOlsikUFpnEIBHoxCpqVTm5opRYXkwoLawsya8oArw5
5YVQdkUhjrc4h1iSQyqL4S1gEIpYpGIOpYRLLePRynn0Ch6jkseEqnhMwh8J
k8AvV0Dmisg8KYUvpwhUFKGWIjJQxDUUaT1F1kyRt1IUVorKSVV7qBofDWtn
aLuYuiBLF+boI1x9D08f5el7+ZCulwdpe7lYlK3pYaoj4JeqCJJk3QRpZ8U3
IxgRFvrz8fKePw66QNZRpOgsVnaXqoNlWLhCF6nU91QZo1WmXkJ1H6EmHlJc
3Qt+y8CvsafIECnUh/J1wVxtd4626z3WlYV1Zmk638XCoC4ILL8H3fr4R87m
GGMHZDgd92VX972v7suq7ss09aWb0HXmZEP0rb4nURfG8Xa/VHe9VHW8VLW/
VAZeKf2vFL43Cm+Cwpuo9LxVelJUnlSVJ13tyVB7cMLfBF/CnSpPhsqdrnSn
K1xp1wcXN4eXd8dXMcJP53cfL+8/XT18uXn84fbpx7sPP92jfn74iIONh5uN
s/0RukNyf7gDufdfbu4+x/BeXX+8uPpwfvF0dv54evZwcvoAhPFieGEufzy/
gBkNkxqOzID3l/uHfz08/fqIy/3wCfXx8/98/Pxv1Kc/hCsG4/96ePwFJv7N
zWd4oDg9vTs4uNreBr/7Cwtb01OroyOLA/3oZcHh4ESwa7yrYxxOpt0dU8HO
mTA+gvt7Vr/1Oz1+gJqAG2iLhhGMr9BoBMf8DkRjhFf6I7FW44VXEeHQSm9w
Odq91NO1GO78lvBMp2+60xtXHIApHPNr73faojZLyGLubG7y1Tc4a2rbDKYW
TF+v0lbL1QaJSitSqAUyJU8q50pkHLGULZKwRGKWUMQUiBh8IYMnoHP5dA6f
xuZRWTwqk0tlcCnobUN4VDaZwiaTWSQSk0RkEKvohEpaZTmlopRUXkwsLSSU
FFQW51UW5VYU5lTgeCuf8ZLLcqnl+fTKAiahiE0q5pJLeNQyPq1cQK8QMCpR
zCo+isDD/aLYJC6XxOUhvzwRmS+lCBQUoZoi0lLERoq0hiJroMibKQoLRWl7
9uunYR10bRdDF2Tqwix9hK2PcvRRrr4XpcPT9nL+N7+xFTo2gr8SLhDF/jmG
QKG0vUjWWaLoKlV1l2tCFdpwpS5SZeghGKNEUy+xupdY00eMEa7urayOVpii
ZcZIiSFcpA8V6IJ5gBfrzNZ0Zqk73qnbM/Ey8NBtTQdYzvqqGP/g6NhSnW2M
vjdGs4zRTGM03RhNM0RTDD1v9ZFv8b5QdbxQtr9QBl4o/C8VvlcK72u5543c
naBwJyncyUp3itKTBoTBKT6F/6MMGNBKb5rCkwpd7p1d7Z/fHF7cHgHha/R0
8Pntx4u7T1f3n69jioEnQI6BjbPFzT7iZh9+uI2zjcn9dI3Lvbz6cHH5dH7x
GMMb9xsjfPoIJ+KzM6D96eLy89X1D9e3P93e//wVL5KLzP7Ppy//W8+iP3xC
fh+ffkZ+b8HvE/J7eLW9c7q2tr+wuDU9vTo2ujg4MNsbnQqHYn7HEGE0gr/1
u4H73Yv5nZk4nJmAHxHh+AhGV6G/juDVgegq/FcoJHctXhjVF1rtDa5Eu5d7
upYinYvhjoVQ+3ywfa47MNvtn40p/krY5xx22wec1qi1NdTa3NHU4K2ttRuN
rVpdo1JdI1MYRDKML1ZyhXKWQMLkiRno+RkhjSOgsvkoFo/ChLhkBhe9t4/G
IUFUNomCR0YRSSwikUUkMIlVDEIlo6oC8FIrSinlxaSyImJpAaEkv6o4t6oo
p7IopwrkFmUTinNIJTmU0jxaeT6jsoBFKOKQinmUUgG1TEgrF9ErRIxKEbMK
EjIJAjycMJEX88sh8XhknoDMF1EEUopQQRWpqWIdVWqkymqp8kaqsoWqaqOq
7VS1i6rxUrEAVdtB03bRdUGGPszU97D0UTaqF+LoUGxtlI1FWZoehjpMg/0Z
+e2K+S2P+/UX4eH/HJK/UBwokrQXSTtK5J2lyq5ydXcFFqrShgn6CNHQQzRG
SaYoqboXIuIRTNFKY0+5AY7G4WJdqFAbzMe6cjWd2eqO96r2d6pAptKfofSn
K314cMOfofJnqAMA+atiWKqzdKEsPXr7wztDJNMQyTBE0vSRFH3krS6cpAsl
aIOvsW7YmV/ieL9XBr5X+L5XeF/IvS/lnldy92u5K0HuSlS43yrArztV6f5K
GFfsgzIglS9dhf4kaQpvqtybcr5zcrF3erV/dn1wfnuEBvHD6fXT2c2HC/Ry
Slwx2ASkePE5G/vy/kts2sbYooF78/Hy+sPF1dN5XO7DKXR2f3KKOj5Bxf2e
wVD+cH75CQ3fmx9u7n66e/jl/vFfjx9+ffr4G8ILTn/4P5+hH78J3QP3g+LY
RP4NXQZ/AvjI7+UVbOl3h0dXO7un6xsHi0vbM7Nr4+NLQ0NzfX3TkchEKDje
3TWOVuhOOAjPRILz0fBSf3R1qB/mL5x/YeAivLOTqJlJRHhqHD8Fx0dwjPDa
YO8abN0DPXiR9Vj9YbzQWl9wtbf7W8KLoXZccQCaQ4rRIAbC4zCCPbhfW2vI
3NTeWOepMdn0uha1ul6uMIolWr5QxeHLmRwJnS2kMgUUBp/M4JHoXBSNQ4So
eBQ2RCDjkSAWgfgcAa+KSahkVlUwqsrplWW0ihLwSy4rJJUWEEvyCcV5hOJc
YEsEucU55JJcahnCy6wsYBOKuKQSPqU0JlfMqJQwqyQsQiwxiyBiEYUsooBF
5KNIfDaJzyXzeWSBgCIQU4UyqlhJk2hoUh1NbqIp6mjKJprKTFO3UTUOqsZN
xbxULfJL1XXTdEGaLkzXRxj6HoY+ytTFY2mjTG0PE+thaCJ0VYiKX78iyjqr
JB0V4vYyUaBU5C8R+r8SLhL5i8SBYkmgRNZeKu8sU3ZVqLsrsSBBFyLqw0RD
hGTsIZl6EGETDOIowQQbdU+lIVKuD5fogkVYd4GmK0/dkaNqf68MvFP4MxW+
dLk3Te6JlRq7oYAJCJT8maBYA4o70F6t7Xqn7c7UBTN0wXRdME0XStGFknXB
JG0wUdv9But6pel8qe54ofod7/dy8Ot5KXe/krnA7xvk1/VW4UpWulKQX3c6
IuzFCX/F609T+tMU/lSFL1nue3u6fXS+c3yxe3K1f4oTvrg7vnw4vXo8u346
B4+3sbcz4O9ouH8uPmqf2V5/Zft4FmMLZs/ujk/vjk9uj6DjWHex9yfCFI75
vQC/18jvLe734elfjx9/i+3MMGdjeL9AP+HFFf8PTvjfOOFf0ZXwDz/DMgB/
nkt42Lm4Pzq+2t0/29g6XF7dmZvfmJxaHhldGBic7e2dikQmw6HJUBCC4/Bs
T3gBjrHoieCBzbHhnfjwnTyaRS+Qhh8R4emJPfxCNIxgOAVvDPevD/WtD/Wu
D0ZRAz14kQ1UeAP3u94XXOvtXo12r/R0Lfd0Lkc6l4AwCimG5oIBRLjDCyN4
1OsYcll7wW9rzK/RqtM2q5R1UqlBKNRweQomW0pniih0AZnGI1K5BAqHQEZV
kdko0nPE5wjxCFDVc5UsVAWzqpxRWUavLKFVFFPLiyhlBeTSfFJJHl4uyEVj
tyyPXlHArCzkEIp4pBIBpVREK5fQK6TMKhmLIGdDRBmelE2SsEliFknEIgnZ
JAGbLOCQBVyKkE8RCqkiMU0so0mUdBlGl+sZymqGqp6hbqJrWukaKw1zUDE3
VeujaAMUbQdF10XRBam6MFUXoep6aHh0SIuHReiaME0doqqCZEU3Sd5JkHZU
StrLxYEyhNdXjFcUS+QvFvvBb6msvUzRUa7qqlR3V2FBIu6XZAiTjJGvEY0R
gjFSaQiX60Ol2mAx1l2o6cxXdeQo298r/O/kvgyZJ13mTpO6U6WulK/JXKmQ
3A0bLOyxYCpD7c/QBDI07RlYRwbWma7tTNN2pWi7krVdSdquRKwrAet8rel8
pUZnXrQ2K/3Pw9fzQu5+KXe9koNfZ4LcmahwPvt1pariIxgI46HJi/AqAa8/
Re5/K/MlnWwenG4fnu0cXeweX+6dXB+c3hyidyTdnwBG9I6kDxfA8wZ3ehsz
+y1b/IR7CXAeYdSenN3HzR7fHEJH1wfQYSz4EoKfgin8R7+3MMq/+v0V+f3y
bxiycb8//R7Ci/zCz/7745fYSzp/wf3+cHP/+fLmw9kl/AGu9w7Pt3aOV9f3
Fpa2ZubWJiaXRkbxT9Xom4lGp3siMz0ROBHP90WXYBkeGlgfHdqaGNmdGttH
wxfwTh/PT8OPQBg4oxE8iUbw1igQHgDCG78T7tmAYniR39AG7ne9t3st2rUa
7Vrp6VzBCSPFqI7njRoRnuqAEQwrtK3P3hpubeporAW/Nh3WolLUSSUGgUDD
4SgYTCmNLiJTBUQyj0DiVhE5eOxKwv9VFbvq9zgEPOLXKtnECjahgkUoZ1aV
MipL6BXFtPIiankhtayAWpYP0cry6bAzVxSwqgBvMZ9UIqSUiWnlUkalnFml
YBOUHKKSQ1JyyJCCQ5ZzyDIOWcImi/FEHIqISxHxqGIBTSyiSSR0qZwhVzEV
WqbSwFTXsDQNTKyZibUytDa61knT4n51AbKug6zrIuu6yboQWRcm6yJkLYoC
YVCYoglT1CGyKkhSdhMBL/4SrBjeUiTXCxV9TeQDvyUSf8xvhaqzUt1FwLqJ
2iBJH0IhwiiiIUwwhKv0oQpdqEzbXYJ1FakBb3uuMpAt97+TeTOknjSJK1Xi
TBE7ksWOt2I7SoJKljpSZI5UuTNV4UqDQYmOq9409NSPP00TSNW0p2DtyVjH
W6wjEetI0HS80XS8Vre/Ugdeqvwvlf4XSt8LwKvwvFS40fDF8b4BvwpnEvLr
fPbrSvsj4TRYm5W+GN5kuT9J5k883thHhLcOznYOL3aPLveO8XcEo7cD359c
PJxePJ1dfji/+ogUX3/CQ2zx4+3Xa1MwUhFbMAtg9w+v9g4u9/ZRu3j47av9
g5ji2Ah+/P/3+xvsxuicC4R//J1wHO+P/8aH728fv8SejP7l4cNPd7jfq1v4
cz4cn90cHF/u7J2uwwhe251f3JyGLXoSpvDi0NB87I29/X0LA31Lg/0rw4OA
d3N8ZGdybA/OvIB3HvDO4CHC+Mun4yN4e2xoa3Rwc6R/Y7hvY6h3YyiK8A4+
D98BhHcD8PZ1f/W72tO5ihP+GkxkXDEQhrOwdzLgGvXCCm3paWvuaqrz1hrt
esysVtRLxUYhH+NylEyGjEYTUyhCEolPIPKqCFxUFafyf6sqHpeAR6zikQjP
we0qLqmSS6rgEMvZhDJWVSmzqoRRWcyoLGJUFEIwc1lVRTB2ucRiPrlURCmT
0CpkjEoFi6BkE9UckppL1vAoajwVj6LkUhRcipxLkXEpUi5VAvFoEj5dKqTL
xAy5jKlQspQatkrH1pjYWC1b28jWtbB0FqbOxtA56To3VRf3S9J1EnWIGEEb
ioehiBo8dZCo6iYou6oUnZXoxVeBcom/TOwrEeFyBR6oEBJC4NdbDD+F/AbK
FO0Vqo5KdScB6yJqu+G3IOlBcZBoCEEEfbBKH6zQBcvjeDsKAK/Cny33vZN5
MiTuNDEuV2R/K7IliayJ8dqSxFborcSWLLUnyxwpcmeKwpWKTqzounGK2pui
9iWr/W81/iRNIFETSNAE3qgDr9V+6JXKB71Uel8pPSiF+7XC/UbheqNAeBNj
fpXg15midOJ+Y4Txhwgl+PXC2pwS25xlvkSpL+Foffd4Y+9kc/8bwjA0YXqe
3h2hNRjOsLAVozf1o/f1451ffntVGbbiW5itiC1o3bvY2T3f3jnbgrZR2zvw
5fnOLvxUjDAawegIHDv/XsM0j51/0XsVn8+/v6ERHJ/C//MHufgrOb/ifURX
xXG/D7jf68fTi7vD0ys0gneP1zYPYIsGwjOz65NTq2Pjy6OjyyMjy8PDKyPD
q6PD62MjmxNj21Pje7Aqw8IMeBdmThZmIbgBhNHbDGcm4FyM/I7H/W7+p9+v
wzf4rd9Yq/9XK+hcjKbwXDds0TCCYYVu67W1BFvqA/Ump1FrwZSNckmNWKDn
cTRspoJBl1GpYjJZRCIJiEQ+gQDxqqpicVGVX+MRqlDEKj6RwCcRBGSigEIU
xqISBVSCgELgU6p4ZBwyqYxDLGUToBKIQyjhEkv4pFIBuUxERTuznFGlZBFU
HKKGS8Z4FC2fqhXQIExA0/Bpaj5NxacpeTQFxKfLIQFDLmQqxCyllKVSsNUq
jgbjYgaetpqnq+Ppm7gGM8fQxjbYmAYnw+Cm6b0UvZ+sayfqOgjariptV6UW
nVUrIA3UDUfXCnVXhaqrQtlZAcuwvL1cGiiT+ErE3mKRpwjACtxQwXOIMNwP
Pwu/RuYvkwfKle2V6o4qDRDuhN8CCBP0qCp9d6Wuu0LXVa7tKsU6cbwBHK/3
nRTwuhBekCu0JQmsiYK2BIHljaAVJWxNgEStiWJLkqTtrdT6VmZLltuT5Y5k
fG5Cb1XutypPktqbqPYmqH3QG7zXsVRePM8bSOlOULqgRKUzSQlyHVCy0pGi
dKSCX6UzDRUb8fjjg8KTovAmy71oc5Yiv28O13aO1neON3ZPNvdOt/bPdw4u
dkFijPDJ3dEpbKSw7gI3APvcGS735P74+A7kHhwguTG2m1unG5snGxvH6/FO
NjZPN7cA8vnODhC+3j+IjWC0Qp9fwBz/fIWuX6FPCbh/xEfwB/RGJ3wKI8X4
Lv115sbkfoP340/3H36M+737eHHzhFboczSCdw/ONmOE13YXlrZn5zenZzam
ptYnJtcnJjYmJjYnJ7amJnamJ/dgT56bOQSz6H39c8/NwhQ++n/6jZ9848N3
A8e73tu1/uwX1Qvh98PRuK97DV3dihGGLdo72e4a8dj6Ha1hS2NHY42nRm/T
qc0qWb1MVC3ixwgrmXQ5nSqlkiUUkphMFJGIQiIBEhCqIP63EasEcD+JIIRf
Br+YShLTyBL6cwz4kSSmk0Q0opBGEFKrBJRKPqWCTy6HgK2AUg5yxbQKKb0y
hhfGLsYla3kUnYCqF9L0QrpeyIB0QoZWyMCEDI2QoRYyIRUkYuH/cDhHI+di
Kp5Ww9fp+HqjwFAjMDYITM18UyvP1MY12dlGJ9PophuQX5I+QNS1V2k7KrWd
5VhXmQZVqu4qVXWilB2linaUPFCC3jwI49VTJAKqANZVwHfl85356EdXvgBV
IHQjwhJPsdRbKveVKfzlqkClur0S66iCtJ1Vus5KvAptZ5m2oxTrKFa3A948
hQ/wZkndCK/IkSK0vQW5fMsbfutrvvk1r+UVH2qGXguaXwub34haEsTmRHFr
osSSJLUkydqS5LYkuT1J4UjCMSaqXIkqd4LKk6CGvH/Mk4hyJ0Eq8A45k1UO
KAUvNZbSkYZCimFRT1W4UxTuZLknWeZJknkTpd4EiffNwerW4do2TnjnZHP3
bGvvfGf/YhdIwqH1CFbiu9iJFX/25/EUFZd7dHQLB9v9/avd3YvtbZB7AmDX
1o9WVw9XVg9WVqBDuL22dry+DorPtrZgNIP0m4ND+J7w3eCh4COs0FexFRoI
PwDh2BRGr6/GFce0fu1f8Vdfx/Gi4Xv/FPd7ff/pMjaCL2FziBGGKXyyvnW0
un6wtALH4d35hZ25uZ3ZWWh3dnZvbnZ/fvZwYe5ocf54af4E7xT9iPtdmPnD
/EX78wC+PyO8cPjFrzyja1bPeL/6xQmj0G24E/0UTOfYAbkfKcYJoy16ujM+
gqPW5mBLHYxgl0lr1apaVLIGmahGxDfwOTouS8NmqJh0JYMqp1FkVLKUQpKQ
Y5YJUIyzkIQSkYliChHkSmhkGZ0iY1LlTJqCRVOw48nZVDmLKmNRpEwQTZTQ
CWJ6lZgGVUrolSBXxqiSMwlKFvErXr2AZhDSjSIGSszEYxnELL2YpROzIS0k
4Wil6B8e1in4OpVArxEadEKjQWSqFlXXiWsaRTUtwppWQY2VV2PnVDtZJjfd
6KEafGS9n6ALVGrby7GOMk1HiQZAdRSrOoqU7ShFoEjuL5L5iqTeQomnEP/8
jXyhM1/gzOM7cv9YHtwJPyVyFYjdiLDMW6LwlSn95Wp/hSZQgbWjtKhybXsZ
1l6CBYo1gUKVP0/py5F7smSA15kmtqegsduWwG99wzO/4rW85Da9QDW+4DVA
L/moV4LG18KmN6KmN+LmBElLgtScKG1NlFkS5dZEuS1RYU9UOhKUzgSVC6V2
J8bMajxJGs9bvGSNG0rRuKBUtTNV7YDSIJU9nhIFilMVkBMt6nJXssz9VupO
kroTJJ43Ys/rg5XNw9XNo7Wt4/Xtk43t003Ye3fPd/bg3ArHWLB2ewjcju6R
4lhw++ju8PBmf/96b+9yZ+d8C2YuyF07ArPLy/tLS3uLi/GWlvaXl0HxERDe
3Dzf3r7c3YURfAvf8OTkMfYUMD6Cv9zghPGDcExxDDLex/8o/hqS+xhe3O/t
45ebh08wgi9vn3DCaAofnsAicbGzD8v8ycbW8drG0cra4fLKwdLywdLS4dIi
dLS8eLy8eLKyeBpv4XR5ARTDLD7C/e7PTOxOjW5PDG+NxQ+/+MWrr3jxa874
ZauY328KbkL9UGhrILQ1GI61OYjmNU64czEcmO3GR7AXjeBIW2NXc62/zuAy
YUDYrJY1KcR1UiEoNgq4eh5by2ECZDWTBpAVdIochFJJuGWiGA8GtATuweXK
mVQli67iMNRcpobH1PBZGJ4GxVTzGCouXckB0RQ5myxnkeRMIqSAWEQV+xu8
fKpBSAO5JjGzWsJCSdl4HJOUY5RyjTKIZ5DzDQq+USkwqoUmjahaJ64xSGpM
0tpaaV2DtK5JWm+W1FtEdVZBrZ1X42RXu5gmD83oJRt8BJ2/UhsoxwKlmkCx
OlCkChQqAwUKf77ch5J586WePIk7T+yKfX5drsCRw7fn8OL/nBke+kcJ0Z0C
R64QfcxdgcRVKHUXyT0lCm+pylem9pVp/GVYvFLMX4L5izS+ArUvT+XNUbiz
5K5MqQPhFVmThBbA+zoml9P4Pafhn5z6f3LqUNza7yFe7Qt+3UtB3Sth/WtR
w2tR4xtx0xtJ8xtpS4KsNUFmSZC3JSisCUp7osqRqHImql1JGtdbAItBnhTM
k4p50jB3mtadjrnwnBkaB549XQ3Z0lW2NCWewp6qsKfI7SkyR7LM+VbqTJK4
EiWuBLH7tcj9an95/WBl/XB142ht83gdVt+t083t862di9iJdW8PnN4eHNwe
HoDZO/Tjwe3B/s3+3vXuzuX29vnm5un6+jHMWZALYBcWdubnYMZtw5iDGwvz
oDhGGKbw2dbmxc4O+p7wrY6PH9CrOGJXsYAweiLpC34WjkGOvaYLzrbPL858
+o9+jONFIb84YZjCHy/vPqBF+urh5OLu+Oz28OR6/wgeji62d9F5HPb59Q34
M5+urZ2urUJnqJWzteWzVWgJCMf9zk8fzE6idxBPjmyND22ODsTwrg2ip33j
L9hAEvFrznG/MbDPZgfC24Ph7aHIDjTcE2t7uGcLnZoR4eWejvlQfAQPu9v6
7C1hS0NnU42/zuiu1tr16jZMgSuWwCyukwiqRTyjgKPnsRBkFv2PkMkyGkpO
pygYIJemZjM0XKaWz9bBfyLiGsQ8oySeQcLVizk6EVsrZGECoE1X82hqLlXF
oag4ZDWHrOGQMS4Frc2AV0AzCukmEaNGzKqRsGulnFoZp1bOrZXzauX8WgW/
RiGoUQprVMIatahWI67FJLU6aZ1BVm+SN9TIG+rljY3yxmZ5o1nW2CZpsIrq
7YI6J7fWxap2000eisFL1Psqtb4yzFei8RepfAVKX77Clyf35so8UI7UnSNx
5Yid2aLYh8fi/4oKz4riftPzv0uYLbDniBx5Yme+xFkgcxXK3cVKT7HKU6L2
lmhQxRiqSOMt0Hjy1O4cpeu9wpkpc6RLbSniNoRXYH7Nb37Jjcmt+45d+w92
zT/Y1dB3HBP0T67pe1719/zqF/yal4LaV8K6V6L61+KG15LGN9LmNzJcsdyS
qLAmKm1JKvtbtSNZ40zBXKla3KzOnaFzZ+K9Q7neaZ3vtI53GGTP1Ngy1bYM
lTVdaU2DFNZUuTUFTtlS21upPUniSBQ7EkTONyLna6Hr5f7SKpwQD1fWYMk8
WtuAHRgOsLAMn29tX6ATK3DbvUaK927xbvbhy52rne3L7c3zTYCwdry6cri8
tL+4sDs/tz07uzUzszUzjZqd2Z6bRYSXFg9WlmFAn25uwAiGb3hzsI9m+vHJ
Y4wwHIQvLj9eIsjoitYVdPMZ5wxzGX2SHv5hes/FXkny+MNd7DVgz4T/qPhT
TPH5VWwW3x2d4NfGD6520VH9cnvnAvZ5eDzZ3LjYXL/YWDtfXz0HxcjvIvg9
Wpw9nJ/en4XhOwbDd3NscH2kf22od3UwujoQWelHr3Ze7QtBa+hUi/vtD33D
Nm52dzi6NxLdG+3dx4Mbu6O9cP/WUAQ26tXersVI+1zQN9XhHvPZ0YUsnDBM
4fYGk69W7zZpHQaNVau0aOQtKmmTXFwvFdaK+SYh18Bj67hMjE1Xs2gqGLWM
eComyKVrOEwtj60XcIwiXrVEUCMT1spFdTDNlbFEtQphjVxQLeMbJUCbrROy
tAIGxqdjPBrGo2JcqpZH1fGoej7NIKCbhIxqMbNGwqqTcupl3Ho5r0HBb1AK
GlRClFrUoBE3YJIGrbRBJ2vUyxuN8kaToqlG2VSnbG5QNjcpm1uUza2K5jZZ
k03SaBfWO3h1TnaNi1Htpho9JL23Uustw7xArFDlzVd68hSeHLk7W+bKlrre
S5xZYkeWyJ4ltL0TWN/xrZm8NhTXkhEPbuPx0M9mAXChLVtkz5U48qTOfLmz
QOEqVLoKVe4itbtI4y7EK9C489SuHLXzvdLxTmFPl1lTpW1vxa0JwpbXgqaX
vMbvufXfcZDcv7Oq/8Yy4hn+ztZD/+Dov+MY/sk1fM8zfs83vRBUvxTWvBLV
vhLXv5Y0vJE2JciaE+TmREVrkrLtrcqWrLGnYo40rTND50Jm9e4sg/u9wZ2N
l6N3Zeud2TpHttb+HrNlaWzv1NZMVVuGsi1d0ZYmb0uVtSXDn02Crnsnim0J
Ivsbof21wPFK4Hi5vwjLJOy96NB6tLoGB9gTmE0bG2ew7sL/3ttblztbV7vb
189dwZfbmxdbG+cbaH4dryzDFrq/ML87N7sNZqenNqcmN/A2p6e2Zqd35mZ3
F+YPlpeOVldONtbhe8JjwjU8FMAoPzpC72U4iSk+wzuPccZD17o/Xlx9xFHH
Xt+FP/t8h7+AJAY5phifxfcfUHcfcMhPX24ePz9v1B8urp/OLh9Oz9HT00fH
cGy/2T+AB6Xr3V14ILqCv+MWUgyEz/APeYSz8OHCzP7c1O7MxPbk6Ob40PrI
wNpwH+BdGYgs94eX+0LLveilztBqzC9+tt2My42xBbB9B2N9B+P9h+MDhxOo
g4n+/fH+PZwwLNJr/cHlaOdCODCDX8ga9dkH3RaYwj1tTaHWeqS4sRrWaU+N
zmXEvhnHMcU8k4Bj4LFwxQwNmEUxMJDLZen5HKMQya2VCesV4kawr5E1Y/IW
SItqxmSNGmmDCiwDZL4J1mAx2yBi6QUMHZ+u49MgPYpuFMSHb62EXS/jNMh5
jUp+k0rQpBY2a8TNmKRZK23WyaAWvbzFqGgxKVuqVS01KnOd2tygNjeqzc1q
s1llblW2tCmardImu7jRIahHI5hZ46KZ3GSDu0rnKcc8JRoPKMtXuHPlrmyZ
873UmSVxvBPb34lsmUJrpqAtg9+WwbOkQ9zWNM7vpXPgHlQGuOa3AfMsofW9
2JYtsefI7LlyR57Cma9y5qvxNKg8jSNH7chW27NUtgyFNU1uSYYzrLj5jbDp
paDhe17dd1w0c4HtX1mGvzL1f2Xq/srU/pWJ/Y2F+jsb+wdH+x1X90+e/nu+
4YXA+FJoeiWqeS2ufSOpT5A2JsqakxQtb5WtKaq2VI0tHbNnwITVu94bXGA2
14jKM7rzjS4oz+DM0ztydfYcrS0bs2Zp2t6pLBlKS7qiNU3WmiJtTZZY3oot
SaK2RGHbG4H1tcD2im97ybO/2F9YOlhcgiMhHAzhAHu0sgrL8AnMyvW1M+AG
swn+397auNzGQ7fhzrWz9dXT1eXjFThCLuwvzO3OzWzPTG0B28mJ9clxvAlE
eGZqe25md2FuH06aq8sn8D3hO8AjwN4OGugH+E6ODtdHz4frWCex8Itm6Fr3
I3IdE331EbeMXhJ2c/8FH8S43w8/PXz8Q8jy0w/xcXz36er2Iyg+v0SvMzk+
heM8/Na3+/s3sF3AmrG9BYP4PPaXWl44Wpw7mJ/Zm53cmRrbmhjZGB1cG+5f
GYwuD/Qs9YeX+kJLvVBwOe4XX6H7w5sDke0h2JDxaTuGzB5NDB5PDh5PDZ1A
08NwAzqcHADCMIVhr4YtGkbwUgTfors8E+1OIDzkaRtwtsIg7rE2wSwOmutg
ow48j+O4YpW0Uf7tRg2zmAVsdTyQyzYIOCYRr0YiqJeLG5XSZo3cDBNcr2oz
qK1GjdWkgR/bjGqLQWnWKRBktbheKayV8asluGIhExTrBXQIhq9RyDCJmOAX
hm+DnNuo4DerBC1qkRkTt2olrTpZq15uMSgsRqXFpLRUqyw1akut2lKnsdRr
LI2YpQmztGgsZk2rRdXapjRb5c02SZNd2ICP4FoXvdpFMboIeleF1lWqcRWp
XPkKZ67cmS1zvJfY34ltmSJrhtCaIWhL51vS+K1pvNZULmRO5ZhTnkvltKIA
NdeSBrr5lgxh2ztRW5bY+l5qy5bZchT2XKU9V2XPVdtzNagcjS1bY8vCJ106
KJOb30qbEySNsAm/ENT+k1f9D67pb2zDX1m6vzC1f2Zif2Zo/sxQ/4Wh+gtT
9Vem6m8s1d/Z6n+w1d9xNP/kYt/zdC/4+pcC4yuR6Y24JkFSlyhreCtvSla2
pKpa0zVtmVpbFkxYvTMHtJpc+SZ3gcldWO0uNLkKTc5Co6PAYM/X2/J01hzM
kq1pzVK1ZirM6XJzmsycIjEni81JInOisBU9k8W3vOa1veJZX3KtL/bnFw4W
Fg8WQeISdLQMKpePwdrqyunayun6ClA921g9xztDXz5/EvHywuHi3P787O7c
9A7CO7EBbCfGvrYxNbE5Pbk9O707P7u/tHC0snQC3woeELY3L2Hq7e1cwyKN
FvL9G3Sgjnf9HIzIm4PYBbQj/Bp4zPL5U1zxzSe0Xd+jt1fAcfgBf4fU46ef
H9HHDkD47U84ZHSBC34letnY5TX+arFzeGSIEUa/4+5uzC/8TU9Wl4+WFtAn
LMNfanpia3J0Y2x4bWRgZagXxxtZ7Asv9oYWe4PofYKIML5C94c3BiJbCC9s
yDBwB44Q2+GT6ZHTmZGz2dHnRk5mkGIYxHtjffERDKdgfATPBn1wEIYpPOZ3
jPhswx7roMvSH4OMxnF8qfbW6p1GzKpTtj4P4hp8nQbFwBZ+NAq51WJ+rVTY
oBA3qWRmTNGmV9mMGke11lmrc9Xp3XiuWp2jRmszadoMKrNO3oxmsahOLqiR
ck1itlHEAsUGAQMyCpnV4FfCxv3ympSAV9iKiS06aZteZjUorCal1aSyVats
NWprrcZaB2HWeszagFkbsbYmrK0FazNrLK1qCyKsaLFKm23iRrug3sGpczBr
nFSjk6R3VmqdZRpnscpRoHTkye05Utt7ie2d2JopassQWtIFCG8qzwxyUyBO
S/Lvmb+GfgqAA3NBa7rQkiG2ZEra3snasuTW90prtsqarbZma1DvNW1ZGss7
TWuG2pymaklWNIG4N5K6l6Ka7wXV3/GNf+fq/8rW/oWF/Zmp/hND9SeG8k90
xZ8hhvwvDPlfGfK/MRV/Zyn+wVZ+x1H9k6v5noe95OteCQyvRaYEcU2itO6t
vCFF0ZymMmfAb6S1vtfZcg2OfKOzwOQqqnYV45VUO4urHcUme5HRVqi35uss
uVhrttqcpWrJVDSny5pTpc0p4ua3ouZEQXMCv+UNejLL/Irb+pJjecGxfL8/
B7Nm/mABNkbwuADz9Ch2VXYl3snqEt4iCu6B8QTrJUwotGFO785O7UxPbk2N
b06ObUyMro8/h/yOb/3ud/5wZekYHhDgpBknvIUU413iXWxDcO6OtX2Ovvx6
GW0fvfDjEL18GimGWQyE8SkMIzju9/HTL0+fUR++/AsP3UaKvz5H/Dth9Pz1
8cnd4dEtLNK4X3SWR8eBpcPF+f35mV3YHKbGNyZG1kaHVof7lwd7l/p7AO9C
bwhajAYX0QgOoVNwf3h9ILI5FN0ehrNt/8H44BEuF8Cez41fzI9fLExcLkzA
jfO5MbgTBvHh5OA++B2JxvyiC9GRdhjBs90+mMJwFp5od40HnDhkewxyn8MM
4xiWavzqlsFl0tr0KjgUNyvjl7ZAcbWYB3Jh7NbJEN5mtawVU1j1aodJ66rV
e+uNvkaTv6k60FwTaK6GG95Go7te70SK1RY9DGJpY5wwzySGgzML5EIm5De2
PMeGr9CsEVm0EqteZjMq7Calo1rlqFE7ajWOOo29DrPXQ1pbA8raqLU2aa3N
XwmrWi0Kc5usxSppsgkb7Lw6O7vGQTc5KAYHQeeowBylanuR0p4vt+XIrO8l
1nfitkyEF3lM5YNNENqSzG15y8FjtyR9jYNCd3LNyfDL+OZUoTlN1Joubs2Q
tmbKLe8UliyV5b3a8l5jeY9ZsrDWd5g5U9OSrmlOVTW+VTYkyuteS2teiE3/
FBr+wdf9jYv9ha3+MxPkKv6bLv9vuuy/6dI/0SDJn+mSv9Alf2VI/8aQ/p0p
+wdL/h1b+T1H9YKnecXXvhboE0TGJElNsqwuVdGYrmrO1JizMEuOzppnsBUY
HUUmB7AtrYEcpdWQvcRkKza2FektBbrWPKwlR92cpWzKlDemSxtTxY3JosYk
QWMiv/ENr+k1t/kVp/klu+UF2/w9y/z9/uzMwdwsah5Izh1Ci9A8amku1lHs
xuIshNjOT+/B2RDWy+kJ+J98a3Jsc2J0Y3xk/fdGNybGNuGnZiZ3Zqf3FmYP
luaPwP7qMhroMMc3keJztIpvwA1Y1ME1bNcnICje2nH8ieON0/jFtN244qOT
e0QYpvA1GsG393Dg/d3vM96vhPEpDEdj2KXxRfry5kN8i0Z+b9AVrV143IA/
A6wc8MCFHwemt6cn4REJ/i6rI4MrQ/1LA72L/T0LfbFP0MIJ94aW+8Ir/ZG1
gZ6NoejWcN/OKJxtBw8B78zoGZI7cbk4ebU4dbWEgtsA+Wxu7GRmBPzC/N3+
Zv6CXxjBc0A46Jvp9kIIcpdnshNZHgs4YSIPutt67eawBT3HFKg3uat1sEtb
MEUL7NIwiGWiejjqQnJRo0KC8GqVVoMaxq67zuBrMLU313Sa67pa67stDd2W
erjRYa4FyN4GI8xiGMSIMExhJU5YwsUJo0FsErGqxexaCadeFhu+Igsmseqk
dqPcYVI6a1SuWrWrTuOqw5z1kNYBNWjtuF9bIxrBVhjBzZq2FrXFrGptVZot
8pY2abNV1Gjj19s4dXZmtZ1mtJP09iqtvUxjK1bZChTWPFlbtgQWYEumqDUD
JArMqfyWFB6Ol9v8ltOcxGlOZP9eAgT3QNyWJF5LEr/lraAlRdiSKm5Jk5jT
ZeYMhTlTaX6nNr/TmN9hLVAm1pyBNaVpGlLU9Umq2gRF9SuZ8YVE/51I+3e+
5q9c9Z/Zyj8x5f/NkP0XXfJfNPF/0UT/TYWEf6IK/0wT/oUm+itd9DeG+O9M
yXcs2T/Zihcc5Uue5jVfmyDUJ4mNydKaVHldurLxnbr5PWbO1VnyDdZCow2m
LZgtg2rgR1tZtbXU1FZisBTpzQXaljxNU46qMUvRkCmrT5PUp4jq3grqEvl1
Cbz619yGV5yGl+zGF6ymF8zm75nN/9yfmT6YhUAx3ny8fdQ0am4K2pubhPPg
7uzE7szEzvT49tTY9uQonA034Xg4Pgytjz03PgKDGP7nh6G8PTMJFnC/c7Bv
H8MEX1uG9RsUxzpZWwHURytw+oYz+CIck/cXF/ZQcAO+XDpYRi8COV5bR4q3
dy5344Qf0CKNj2BYoe8e/99+7+J+4fiMn4LP7tELtg+v0SvHds63NuG8D3+M
g6WFvfk5eMxBx4GJsbWxYfC7DH4Hn/2iwjCIl/oiy/09qwPR9aHezeG+7dGB
vfHBg8nh45nRU8C7MHm5OHW9PH29PHOzPAM3EOGFifM/+kXn32/8zocg/1y8
AB6I9gNngAyKh7022KgjbU3dLXVwInbX6OwGTZtWaVbLmpXSJqUEalZJW9Qy
C+DFJ6+nzuBvrO5oqe1ubQhZG8O25ogdFbY1wZddlvr2lhpfY4ywulUXJ4yf
hdEUhqrFnBoJp07KbZDHhq+4TSu1GQCvwlWjcteq3XUadz3mrte6G7SuBi1O
GE1hG6zQ9Zq2BrxGtaVJbWlWtbYozGZ5S6u02SJuahM0WHn1NnatjVFtoxhs
RJ2tErOVqa1FSmuBvC1X+v8V9h5abWVruvZNnF3kHG2XXdmZYExWAomMEEog
EMpZiCAyAgQooJyzRM4ZHKp29+nuc67p/+ZaArt29z/OGM/QEGxcu0zx8L7f
WnPOpX7Zp/q9Vwn+/tKtwPyVPwd5OzB5aQ/aUuWVj9BkwJMO2ZNO2dMu2bNu
GTTPF/2ohf7MkP/ClP+K0lD2GxeQ/jok+YUr/okres4RPGPxK5kj5Yzhkv6h
ol5Ofjcrr2MwhzqQ1dafSUHmZpB6MondmYSuLIxsQlcOsSuX2J1H6ikg9xZS
+orb6SVURhmNWdHJftI99KyH97yf/9OA4NdB8e8s6UuO/M2Q8h1PXT2igaj9
wNfWAWOaOj6g/jCqrOUpqofl77nSt2zxK6bo9wHhr/3Cn/oEz3sEz7oETzoE
lTRhBVVY3i4qaxOXtklKKIC0+NjnOfZ7EQHv0QOgKnqwCKjqd+37nMhWr2PX
Y8eEBVu3tp1bKac15UiTTLOF+WsDf3fhj/jc+/DPCfqOwv5jyPQYRHAYdfJE
upmjCRqGTeirEHmhwH7Qvxd4uPfk92O3n4L7IfwOMlicRIu40gqffj67QC36
BiL48398/vpfX//5f/78t/+L/EUKp0nL+29Y+P4Jpv/77T0Ub/iDME1DG787
OoZyDuGO1p+gW9jRhwvp3h2PO+VGDymJp/01RSCCLRtgMRC1rMfwQ2jR8Xfm
XYflwLV15LGf+pznQfcVyBvFzI0H7hMYcaQwRDDk75nPfuy2Hjg2d7eMKfNq
fHM5ur6I+bsQWpsHi8PGhYhxMbK+GN1YAiIwHRsXg2vzfsOse3EaGrV5Ur2u
leMK6wW8iVGOdpgFQazkMADozCDvOJKXqxfy5iR8JK9aAsJuTCg2J1WmKcTm
lBI+hE8aMIUhhSeFQ9pRtnKIIWP3iweRwlCkx/o7IIuF9E7xQJd0EIWvioua
s250cGoMyasXcWbE3BnJkF7y6C8X/B1HUzBHI2KrESyVmKWSsFRSpko2qJQz
FEq6QtUvV/dKNV0STYdI2y7Qkvlawoi2aUhbz9F+YGmqB9XvBtSv+1Uv+5S/
9yh+7Vb83CX/CfztxP2VPQVPwVYqogKjHCEtp0krgA5om9In3dJnPdIfoYJC
EWVIf0ZtVvILR/IrVwz8MiT6eUjwgjv2I2f0KXukkjlcxuCW0NmFvcz8bkZu
Jz2b2p/V1ptJ7s4gdWUQOzMIHZmtAC2rlZbdSstp7cgldOQRO/NJXYXkniJK
X0kbvYzKqKAxn3Syn3UPPe/l/dTP/3VA8Pug6CVb+oYrezekqOIpa0ZUtSOq
D6OqOoTyw4iilierGZJWcSXv2KLXTOFLxthvdP4vffwXPaM/do0+7RytpPEr
qPzy9rGyNkEpRVhKEZWQRcVkcfGxFx0Xg50Ygzj0uQ98rn0v8JCwyFaQ1JIE
7OaEzZTYMsW3Nh8woc/YzEk7fIE15dyCIr3jcUCv3ve7DyC7Qz6o3Kh7owgO
IaKomYPRR+HAYcgPYQcxvZO+/OVKQuq5nEn0xp3yeLZ9vt0AWBw+jMYwhSGF
D27RCq7zLxDBMAWjCv31P9EIjF2/wkbg/4v49//zIO9/gLx3X/7t9tNf13eY
vJeYvCdI3r39i+0d6Oon8TgkPnYL2w9jO/qXgX8Npz1u34rZMIUxi2MY2N8a
Pwfeip1daTv02E98zrOA+zLkvY74bmOgbfATkESvIPJtzAehDP6e+mxHLsu+
fXPbakyYVmIby2ArJi8CyYvMXY6bDAnzCk7cvBLbXA6vLwZW5zxLelDYMoUp
rBTPS8ZA0kk+d3yEDRYjeCx4D5+ZFvKgNi/KBQaVeE0L8irNU2qLXmOd0QKW
GY15Wr0xqQSFIYWhSOvFIxNjXM0IS8FlSFm4wt1gMSAa6JIMdstYvY/hO8ln
TgvYMyLOrJg7KxkCcIWnoEKjKZijFbI1ApZawFIJmEpAOIgQDyolDIWUoZAP
KBT9cmWfTNUjVXeJNTShtm1MSxrVtvJAYU09W/OBqa5mqN7Rla/7lS97FZjC
clAYi2DZs45v/lbg2lKlZQgJgiYp75BUdIoru8RPusVPe8XP+sUwjb4YFP3E
FP3MFv7MEf7MFfzMHfuJy3/OHXnG4T1hD1UwOaUMVjF9sLB3IL+bntvZl03t
yWrryiR3ZhA7Mgi0jFZqRgs1s6U9CyO7hZrbQs1rpeUTOgqIXUWknhJKb1lb
fzmVUUljPu1k/9g99FMv7xc6/zeG4CVT9JotecuRvh+SQc7WDMtreYCsdlha
Myyp5oqrOKJ3bMEb5tgrxujv9JFf+ng/QYJ38Z518p7QeJVUXnn7SFnbaBll
tJTMLyGPlZAExSQh+OvEwE5s86IDkPfBPqStDdcWflDR1VfrBoROBLsAG8ZA
V2JNxqgZJRF8Aa4w+AuNetfrgI59gMLXexT2HUdwfzG+m6D3/R7IaDRmuh0J
MMVhi9m3ojYMuy1qt8eczgRY7PXuBAL74TCk8CkUaZiFIYJPTj/DFHx181ih
8QjGAHP/7b+Quf/8j89/obvAd5//eXP/59Xt1wu0Iuv+5Oz26OR6H5IXlzd1
Ek+gZZ/h8H4wAOmPbmGn/XUkHLaEYwsshiAGoE4n7ahyQAPZeTj4HTu4w3Ua
dF+EvFcR/00scAfOJkOf0qT9hVy+CDhhQD50mndtGynLWnzTEF1fQvKuLqDy
vIaSFzIX5E1aVlPWte0t4w7U7K11eA8ig9dQqkFhx9zEo8IL0rEZ0QiMw+Ds
xCgXYncKZl6QVzy6IBtbVopWNdINncI8pbLOaGyz4/Y5HWCbG9+a1Zr1oLAC
ivSSSjQn40+JeNggzEQ3lTCFxYMwUPdIBntkzF4Fu081RNfyGBOjTGjOekze
OcnQnHRoVjo0IwV/ueDvhIgzLmBpxpgqPlPJH1SMMuQAnyEfY8gFDLlwQCEe
UEjpChldjhTulam6JepOpLAGU1jTOqxp4oLC6g9MVTVDiRTuU2AKyzGFZS86
ZT+CwshfaSVVWoHL2y4BStvFpVREGU1U1iEq7xRWdAsre4RP+wTP6ILnDMEL
5tgL1thPbP5PnNEX3JHnXN6PnKGnHG4li13OZJYyGEX0gYLe/rzu3pyOnmxq
VyalI4NEyyBSM1rbM1raMprbMpvbspooWU1t2c1tOc1tuS3t+S20AkJHEbGr
mNRdSu4tb+uvbGc8oTF/7GS/6B76uZf3a//o7wNjLwcFr1kiqMfvOWCruIor
Bm2rOaIqjvA9e+wtk/9mcPTVAO/3/uFf+4Z+7uE+7+I+6+Q+pXErqdyKtqFy
ylAZZbiUzCsljZSQRkuI/GLg2OM49gLOI6/j0OPANtrY0DMLHGjFQty6CdqC
raHN1eC6IWBc9gNrS37jEryHz2AHKa/B14DCkM64v9C3oXsffgtfzN+IH94f
h9PXvvZ8LohpdIEI2WGNblnCVnPIYgqaMSzmkNUaBpEdjrgLFEYpfBCJHieS
ZxDB+4e3MAWfXXx9qND/G90I/us/v/zzv9Clqn/+J27uJzD3yz9vUOx+vbz5
fH51f3pxh+9r2Du82Nk7T+2cPsh7gOQN7vn9Oz7vtscDTSCFNwEXtGg7Dhrt
oV3AdOB27HmcUFEOfS5s1z96rOF52HcZ8V/HArfx4F0idJ8Mf0KEIIjv4gFo
1JchN0zHx56tfYd5Z2s9aVqF8A2jm78L+LSL/F1fim1C8oK8yNw9x+a+0wTA
G/gwaV2DIIYu7f1O4RWleFEmmBOPgsWQxcCMCMk7Lx1bUghX1BLjuHxzUgnJ
i+Sd1zkWJnBAYTDaNK2CcdigkaRbtAC1aNUwU84ZkLHpYLGU1Sdj9Ss4/Sou
XTPM0I0yJ8dYemFa3nnp8JxseE46PIv7C+ErZGvHmGr+oHKEIecNyHh0Kc4I
Xcany8bociFdLqZjCvenFVb3SDRYCmvaxzTkEQ1hWNPMVdez1B8GVdUDoLAC
U1gOCv/SJfupU/YcKSx9Cv5CVaZKyiFzwVyEqASgCktpgKCsQ1DeNVbRPVbZ
y3/az382MPojY/Q5c+Q5i/ecPfycM/Qjh/uMzX7CZlWwBssGB0oG6EX9fQW9
PXld3TkdndntHZkUagapPYPQltFKyWimZDSRM5vIWY2I7EZKTiMlt6ktv7m9
oIVa1NpRTOgqJXWXkXsrKP1P2hnPaMznSGHuz72gJO93+uhLBv/14BiE7Fvm
2DsEH7R9Ozj6hsF7NTD8kj70ex/3117Oz93s512sZx2spzRWJZVV0cYup7DL
yJxSMreUNFRKGi4h8hCEkeITjx0p7HHA+HYAaeJCC/W3seVGkLmQsKGNFVDV
t7bkXVnwGObdy3OAxzDnNcz7VheRxRsr6Cx06wZEMKQSjMkwMsMEfRTygq2Y
vBggL4pdNFaD4KA5yB63W6CXhi2bQdNGYHPdv7Huw9nc8JvAYkt4CymccHu2
/YE9aNEQwantC5iCj47vsQr9J7qR9Onf77+Arf/x+U8EtGXM3H+7/fzX9f3X
y9sv59efTi/vjs9vDk+v0HaGg/PtvdPkDhTy41j8MILvSwrt+gM7Pghf5O82
5D5S2LWNcEIc73hc6Ioc2nLoPvCjq3lHQe9x0HeK7xqO+C+jgatY8CYevE2E
7pLhexx4Hw/exPxXEe9F0HXisx+6rHv2zZTFGN9ciawvh9YWg9ihOvAK75G/
KHzXcHkPXOZDt+XIY4VXeL9r30ghhQ0PCmNFely+opIsYYu1YCKek4zCKyQv
fAY15+/C1z437pifcC5MOBcn4RVc/lsEK0WzMv60iKdDLRopDEUaLAYU3AHV
EEMzPDg+wpzkw9jLmRGl5Z2X8eZlSGHwdxrKs5CNwjctL1061C8Z6gPE8Drc
J+H1S0f7/6awnK5Q9stVfaCwFCncIdS28x8U5qgbWKoPg0pQ+H2/4k2fHCnc
LcMUlj7vkD6jSZ/QJJXIX3FZuwiTV1jSLkBQx0po/FIav6xztLxrpKJnpLKX
97Sf92xg+Blj6Ecm90cm5xmL/YzFesIarGQyygfppYz+YnpvYV9PfndXbmdn
Do2W1UbNJLdnEDF5W8hI3kYSkNVAym4g5TSQcxvIeY2U/Ka2gqb2whZacWtH
CaGrjNhdTuqtRAoPPKMNPu9gvehi/9wNYg791jf8Rz/vJZ33ChiA1+FX9KGX
dO4f/Zzf+9i/9rJ+6Wb+1DX4vHPwGY3xBHp4O6OibbCcMlhGZpaSWaUkdimJ
U0LklhCHSgjAcPGp137iBYXtmL/oIX07DksKJe9GFJPXv7YM5oKzzsUZx4Le
MT+NWNDDh/BJ+J9AYUhniGAYhKFyg78HftdR0AO2granGFj4+tIrEjF5YViO
29B13ZAZzDX619e8xlV0PhVgXPOsG70bmMKQwlCkXa4kRHAwdABTcDJ1DhX6
ECr0GVTor1c3f93cwxQMCmOkzYXY/fPq7svF7aez6/uTi9ujs+uDk8u9o/Od
/dPU7kli+yiWPIzGD8JRGK73Ari8/rS8CJjH0R5hGMx3vdAWPPt+qA0+dDkO
XZ8PnIQDp5HgWSR4Hg1eRIOXMSB0FQ9dx7Gno+KAufHAdRSX133qh1+SePhu
JMxrsQ1D2LgE2gZW5gOP/qLJF4Xvrh3JC+Ye+2wnGMfeLbAYpE49pLBnaRqf
hTfG5atqiUEpAmdh4AUgeaE5o/BFk68CRt2tGe2/+OuYRy3aov9+Chbo0YWs
4XE+pjCPqRoeBNTDgxoec3yUNcFnTwk4ehGaeUHeBRlvAfnLg/yF+XdaxJkQ
srR8pnqEoRimy0BeTp+I0yti96BXbi+ymNf3oPCAQjKglA0oFQMKJV2u7pdp
eqWabrG2U6il8jWUEQ1xSN3MUYHCdYPKmgFFWuEeGaawFFNY8owmeUIVV1BF
Ze3CUpC3TVDSNlbczi9uHy2mjpRQR0ppvLLOYXRbtmeospf7pJ/zlM5+ymA9
ZTCfDg4+GWRUDg6UM/rLBvpK6D1Ffd0FPZ15XR25HbTs9vYsSlsmkZLRSsbk
JWWAvA1EIKuemF1Pyqkn5daT8urJ+Q2Ugsa2wqb24mZaSUtHaWtXGQFTmNz/
pI3+rH3gR9rgiw7mT52sn7vYv3Szf+3h/IZgY7B+7WH+0j34cxfjp86B5x3w
xfSnVHC/vwJGaQq9DCAPlJIYpaTBUiKzlMgqJbJLAAKnhMAtOfPaT70OUBj8
PQR/0UFtliQMvOiBQavgJhjqWpoDYW1zU1uzk9aZCQDe2OemnAt6UBhSGEWw
2Yj7u+dxYP56IXBPIwEMPHy9hwEIL7QiESWvDd1UDZnWAxtrPmSuwb1qcK1g
rK641lbdoPDmpt9sCdlsUacrAVNwMLgfjR0nUmc7e1cHUKFPoUJ/ubyGCAaF
/3n7CWmLmYvF7t3n85v706u744ubw7Or/eOL3cOz7f2T5O5RPHUYTRxEYvuh
6F4wDM38QV7ftift7w7g9ez6vHs+mNN9B0H/YSiA7o9H0PW3s1j4HMC2HF4i
wgDIewUKx4IAtOgrIOq/jPguQp4zlLwgr23fadmxbSZR+K4+hi/mL1ToBdA5
isrz2rZtY89pOnRbQduzgOM86ATgDXx49KAwjMnB1TkPuiI9jisMUbuiEoPF
YC68wnuYfFF5xq5cWb/rz06sP3+Xv2l/FxTCWSlE8MiEACmMllmOsLFVl+xx
PntijDMl4OpFQ7OS4XkpMndBPrIgx/0dmkHlma0bY2pGGUqozUjeXhGrR8jq
FjC7BaxuIWYxpnA/FGm5AAZhhlLKUMoZSiVDqRpQqOkyTZ9U2yPSdgowhXlI
4RaOqpGpfFBY/qYXV1j6S6fkRYfkR5r4KVVU2S4sbxeUtY2VIPjFbaPFbSPF
7bzi9uES6lApjVuGVlawK7pZFb3Myr7Byn5GJX2gkk6voPeX0/vK6D0l/d3F
vV2FPR35XbTcDmoOtT27rS2LRMkkgLykjGaQF5mbWU/M+kjMxsj5SMr9SMr7
SM6vJxc0UAob2osbqSVNtNLmjtKWTlC4gthTSep9Qu572tb/rJ3+I3XgOY3x
gsb4qeORAeBFB/0Frf85rf8Zte9pe++Ttt7Ktt5ySi/08DJyXykJ6C8l0kuI
A6VERinxwWICwC459znOfI5TH4zAj/6ijTZRMxa+q0vu5XnHwgzIC9qap8fN
U4DWMg2jEwxQU5DCKILXDVCh41uYvzBHB9xgK2h7Fg0AmL+P4evYdqEViTHr
Zjgt74oHmbvsNCw5EMuOFYNzddVlNHo2Nnxmc3DLFnE642BWILgXiR4lkqc7
u5f7hzdHJ1ChP19cQQT/eX0HzgJ/Aljsfj6/vj+9vD0+vz44vdw7Pt85PE3t
Hyd2DmOpg0hiPxzbC0Z2A+Edf3DHF9j2+rc9/4O8yNyAH23zx81Fy9LQarSL
RAztN0zGrhDRywSmcCx0gbI4cBHxwyx8HvKeBT2nATDXeeSFbrO158Dkta7H
TWAfekZDcG0xgPxdCKDwXQKjY6bVJEy+KHwtx17bKcgbcl2G3YiQ6zzoQJev
3eY9+0bSAvV7MWCYdS9M2ma05kkVKGzUSCGIwVyEWrKG/EX5a5pSWbAIxq5f
4ZewxuG9FV2FVkF/xm4kSRaVwjnZGETwlIgHCuvGhqBLAxNjXJiLp4VDevHw
rIQ3Lx1ZkI0syhGgMPiLhl+8PKfDt1/K6RODvMzuscEuHLAYKcztlcD/OkKX
jw0oRAyVZFAlY6oUTJVqEFvXMSDToj2GIm2XQEMb1bTx1KQhVSsbKfyRoail
y6uQwrKX3dLfuiS/dIpfdIieUYVP2gUV6N4Kv5QyWkIZKabwiijDRW1DxW2c
4nZ2CZVVQmOWdgyWdTLKuwbKe+gVPf3lvX3lvb1lfT2lvd0lvV3FPZ2F3bSC
TmpeR3sutS27jZJFJmcSSZmtIC/xQV5C1kdCVh0xu46YU0fMrSPm1ZHy60gF
H8kFHymF9W1FuMIPFpe1dJW3dlV8E7n3KQVc7nv2jV6MnqdtPU8o3ZWU7gpy
Vzm5q4wEczQapUsAYk8JsbeE2FdCRBaXfm8xgVl6EXCe+52nficWEDD/ov6M
/IXyvL4C2Qrha5/XW2cmQV7TpHZzQgPAG/gQUhhy2W2Y9xuXw6a1+NYmzL+4
vychHyTvg78BzF/Pgc8F7RoP34hlIwi1GZJ31eDG5V1esgPgr+H/5e/27sX+
wfXRMVToT+eXny+uv17efL26RcC0e3EDnfnu5PLm6Pzq4PRi7/hs5/AkuX8U
3zmMpvYjib1QbDcQ2fGHtn3BlNef8vhSHm/KjY7W2Xan/d31PsiLYhcyN4yZ
C87G0U7D7cQ1DrxP/euu4ZMgdna0z3mItLXtu6y7+N5hbO8hGBrZWEEPWFmD
AAV/IYIXg2tL4fXl6OZKwoKHr/nQs3Xit58HkbxXEc911HMd8VyGXeeQwt6t
A5dpZ8uYMC2H1+Z9y3rn3MSWXmOeUD4qnAb81crWdXgEq6Aqg7BgMcQugOTV
qzenlOsTcnwtB/JXLpiBCBaDwiOTQh5aMo2tmtaLeTOSkTkp2Dq6IB9dVKRJ
+4uXZwGU50EVb0DO7Zewe0UQu4NdfEYnBigMKYwiWDKE+ctnKIWDKglLLWOp
FWy1ioWtjmYqNAyZli7R9om03WOajlF1+7CaxAWFlU1MxUeGvJYuq+qTvumR
vOwW/9Yp+rlD+JwqeNo+VtnGL6eMlFJ4JeThYvJQEZlbRGYXUVhFFGZR22Bx
O6OEOlBC6y/t6Cvt7Cvr7C3t6int6i7p6iru6ijqohV2Ugs62vOobbntlBwK
OZtEzkLyEjORvISMBgLIm4nkJWR/IOZ8IOYiSHkfSPkfyAV15MI6StFHoK24
vr24ob2kAVlcmrYY6Cxv7SwngMtdFcSuShwS0FkBEDvLiR1AGbGjlEgrJcAQ
3VGM6CwmdAElhO4SAljcV4opXEYcKCMyMAbLLoOuiyD8VLhA4SOvA37edh3W
5BZ64Cbm79KDvxOmqXEwd0OnBpDCU/ADAB1sGiq0H378Hvzd9zqOAh4Q9gz5
G0z7i/bSeqA845NvbMsUNmPhu7biXkVnqqflxf19zF/ozxZL0Ab+uuJQboPI
30Pc372Dq8Pj25Oz+7OLT+dXoDBoC0Ds4vLeHl1cH5xd7J0geVMg7+5BdHs/
nNgNxXYCkW1/KOUNJj3+pMeXdHuTbk/S9XgulgcbeJG/kLzQmXF5LxJoK8f1
dvJ6J3Wzi5HeOIx2DZ+jXUvYXxOd14EdGf1wJQHtGrasx8xrUWzhdHjdEELJ
u4TCdw2ZGzSm5Y2b11JbG7sO04Ebxl77WdB5AfJGvTcxH4b3OgIp7Dzz4xG8
nrKsRCGCV2Yggu0zqEWndy09KqyRrmllUKE3dIrNSSWkMAzCEMQgMgDv4TOQ
zkadbOXBXxiBZ9HSaD6ksF4MjOglIzOS0Vnp6LyMvyDnLyrGlgAlwF9S8Bcx
f9PD7xhLMzqohMmX+xC+jC7+QCfim7994K+MN6DgDyqFLLWYrZFxNAqORsnR
qDlqDVupYSm0gzLtACgs1PSMaTpHQGEVmasksBRNg/L6AVltv/R9r+RNt/hl
p/DXDsFP1LEf20eftI1UUHhl5KESEreYxCkisYpIzELSYCFpoJBMLyL3F1H6
itt6i9t7iqndJdSuYlpnMa2jiEYrolELqe357W157ZRcCjmHDPKSsgjEzBaQ
l5DZSMj8m7yE7FpiTi0xt5aUV0vKryUV1JILPpALP1CK6hDFoDCy+EHkxnYs
jjGaqaU4Ld/TXoJRjFH0QGELtbCVVtTaUdSKW4yCuJTYV0bsLyPRy0kDCOJA
+VUYfqt7LkLuM2h6fuehBx3UlrKZY5aN0MaqD+vPeP6CvxsTmnWdGtiYgP/0
Wose+evC/d189NeZ9jeK+xvEf7Dx7Xg7LnvSbo1aTTD5omtW2GOJvoXv8rLd
YHCsrjjX1twbG16TyW+1huz2qMud8IG/ob1oDPw92d49x/y9OT69Oz2/P7sE
hT+BuUjeqztUmy+uD88u90/Od45OUwfHib3D2M5+JLkbiu8EoilfOInkDSTc
voTLm3B5Ei53EuFKuZDCux7k74EfOgM0hxA6YAeSF5P3Zhdtorzd2wGwXcPI
34tE9CwaQlsO/Z49j3PHaUvZLQl8y5JpLbyxGlo3BI3LgbWlACrMi34sdgNY
7ILLYDTaCmE2Jrc2dhymfbcV+vZp4Ju8t3E/hu8m6rlCEWw/8VoPnJs71tX4
5lJodc67NO2c021NP0TwN4Wljwqv6xQbE0pk8eMSrEklJi8KX4NG8rAiWgAV
GhSGQRhnTsafl48tyMcWFYIlpWBZ9QhSGCJ4DvN3SsjRgb/Ylat0eR78V3+F
rF4RB23zl8GX8ZkqIVsj5qANDoohrXJYqx7SaIbUGq5Sy5ZrmVItQ6zpB4X5
6s4RFXVISeEoCEx5E0NWT5fW9onf94hedwn/6Bj7hTr6on3kGWW4kjxUTuKU
EtnFRGYRcbCQMFBIoBcQ+guIvYXEnkJSdyFaKNVZRO4ootAKKdRCSnsBpQ3I
J1PyyORcEimHSMomELMgdlsImU2YvPWtmR9bM+sIWR8QaXlrSHk1pHwEuaCG
XFgLUIo+PICJjMUxRv0DDf8CGShsTFPwSBMF0dxW0IwsflQYUriU2FtG6isn
9VeQ6Gmuo96riPcy7D0PwbCGWt++27btsMTRfGoMGA0ewwLMv1uzU+Zp3eak
FhQGebH8Hf9v+WtK+xsEf9Hwe/7g7zHm757XuY3tCPi7vwYn6sw4BscKkte1
vg7h6zNbAlu2sMMZ83iSfv9OKLwfix0lUyc7uL9H4O8t8vcCFL4/u7rH5T25
+Nact/HmjMJ3L5zcCca3/ZGkL5TwBBNuf9zljTs9cac77nQlnK6kE/xFN4x2
PDCne773FwZeqM1Y8qblTfu7nYRGDV8AMX0Q8O56nCnHFtrvgD1xOIAe573k
XVn0GuY9y8AcAO/RrTeYeSF8Qd4NQ9S0GreAvJs7DvO+ewuX9zzkvox6r2PI
3LtE4C7hv4v7blEEQ19ynHqth87N3a01vEL7l/Wu+QmYgi1T+MZh+ZpGhuTF
/P1OYdziNPAhfHJVK1sBedXiJaVoUSFcQLuTBHMIfKeSYEEhAK+XVMJllcig
Fq2kERpUoPMY7q9ePDQp5KSH3yHkr4jVI8D9xRjDztgRsfvEXLp0mCEfYarG
2GohVysZGpfxdAqeTjkyrh4Z1/A0mmG1dkip5ci1LKl2UKShC9S9o+ounorG
VVDYcsKgrGlA8rFfXNMjfNcleNXB/4068nPb8I+UoSckTgWRVUZglhAYRa0D
ha39BS29BS09+S3d+a2d+a0dBa20AgK1gNBeQGjLB4iUPAI5j0DKJZByWonZ
QAshqxk3tzWzofVB3tbMD61ZtSAvIacG5CUieatJBdWYvDUUoKj2e8hFKJFx
SIUwICOI/0J+HSH/Y5o8nHpiXj0prwF4uC2FFEYpXNzaid2Z6ikn9VaQ+ipI
/ZUIeiX8eKC7k1HfRcR3FvIcB1wHXgd0vyS6PrwR3Fj1fqvQMALrIHbBYhS+
0zp8/vUY5gPG5YhpDT3Iz5X29/T/7e+Gf92IHiu2uuIChVeQuY7VVSSvcd29
sek1myF8g3Z7xAXl2ZsMBHfCkf1YHPw9BX/3Dy4Pj67B35Ozu1Pc38v700vU
nFH4nl/un57vHp9uHx4n9w/ju/uR7d1QcicQS4G/XvA3EHf5405vDPx1uDCc
CYcz6XSmXFDyXXse977Pexjwn4ThrxC+iOP5m/oufHewLcNJiOaTaPgw6N/1
upPY44bRrybjqncFqsuCc3EWfvvBdw8Hvl2uh/tu8EsvhK77gbzrSRvIa0Hy
+hynAdc5lKKoD8mLzA3cJbFX3N8w+GtH/rpMuzZj0mSIGBewQ/AmHdgeJROK
YMVDBD8qLAOF17RI2EfgM5C83+RVChce/MW1hQ8xc0Fb8YoGkKxqceA9fFK4
rIRcHp2TIn8nBGwtROrj8JvOXwxMXiGrT8yhS4cYch5TyWerBVyteHhcytPJ
RyeU/AkVf0LN12n449pRjXZEreUptUNyLVuiYYo0A2PqvlFV17CCxpFTWDIC
Q9JEF9X1Cqu7x952jL6k8n5tG3pB5jwjsioJg2WtAyUt9KLmvsLmnoKm7vym
zrymjrwmWl5Te15TW14zBYOc20zCIOY0E7KbEFmNrVlpbVsyPiIy61rA3Mza
1qya1uwaTN5qYl71g7zV5MJqShFQgyjGQPIiSIUIYgGCkI9oBfIQLTi5j3xo
yUG05tS15nwk5Hwk5taTvt1ZbqYWYXeWS9N3lnvA30oygCl8lwzeJtBtyquY
HxQ+DXmO/OjEtm2nFfI0AhG8vuJZWXQuzdlA4dlJ6MwWvQ5et2Ym7XPTrsVZ
+FEMQgOE+mdD/h74nMf/v/66Hvw1I383jF7jmntt1QXaYrjS8qLm7LNYAzZb
2OmMuj0Jnz8VDO1GogfxxFFq+zt/T3B/MS6x8L28+Zu/R8fJA+TvQ/6m/NGk
Nwz5m/bX4Y45XDG7M253JOyOpMORcjq2Xc5dt2vf6zn0+45DML+HzmMR7MoV
Pvxi55DsbF9tpy6SiVO06yG45/eC+LEtK/y9fMZVl2HRvjC3Nae3zEyZ9RPm
aQT6ps1OoYljcRZ+6aHSsrESQ9+3zR2nZd9jQ/IG3edh72XUfx0P3CSCt8ng
HU7ioT+HnFh/tuD5C/5G0QlaM97FKVSh9Vpsy79yHddT83e0uMXoDUIjXVGj
2ozJi4Uv5i/S9sFcUBu+Bpxd00qN42nWxjGF1SKo0+DvrJQ3LeLqxtjY8Dsg
S1+8Qv6io+0GewTM3r/JO8pWj3G1omGdZGRCxp9UjE0qBZNqwaRGOKEV6LSC
8fExzfioanxEoR2WaTliDUuoZvBVfSPK7iE5jS0lD0pa6aLGPsGHbn5VB+81
deh3CudnEutH4uCT1oHylv6S5t6ipp7Cxq78ho68BlpeQ3tuQ1tuAwWkyEHr
Log5DQQgu74VyEK0ZH5Mk1GH8aElo7YlE6hpyapuBbKrCTnVmL9VpPwqckHV
g7zVlOLqtLwY5KIaUlENsbCGWFBDKKhpza8GWvKqm4FcRBOQ80B2DdCMqAVa
sj+0ZtelFYYUzm9EEfzgbyf4W0FCl7LB3yeI/if326G7VOg2GbpOBC9jgfMI
unx66Hehu7QOK3aXx+iHFo0pbEc3kqZtc1MA/Bw6F2egFqIcgZ9Dy3rKbt51
27739+x/8Bc02YpuWULmTfRYz3WjBym8hplrdK8jeT1IXmjOWyGHA8I3hsI3
sB0Ow/B7kEgcb2+f7u59n7+3/93fo/PL9MWro5PUwVFi7yC2sxdO7QQT24FY
0of56/6bvzG7I26H3y32pMOOnsvgcu55XAc+z1HAh452j4bP41FcYdAWQHuW
U8mzePw4EtkPBrY97rjdFjKbfMY1GOdtC3PmmenNqYn1iXGjTgOs6zQb6KI9
lJYpSOTH0hLf2oBpBcnrd8IvT/j+X8UC18hc9B/lDgHyBlBNgkkn7IbyfObb
OnabDxxo+z/05+jDCXjoEMsZLIInVRtIYQUELrCqTcv7oC1iBckrNage/MWc
TZurED7sFBavajBzdegi9sYEYn1CZtRBIZdABIO/8/LRGckwVp5Zal66PItZ
vULkL1ToHiETsvhf5B3Sing6yeiEbGxKIZhSiqbVommNeEqLmBwX6caF4+MC
zfiYanxUoeVJNVyxmiVQMUaVfcPyLo6UyhSTBoQtfWP13aM1HcNv27kvKexf
SIPPCQNPW/rLm3pLG7uLGjoL6mn5H6l5H9ty6yg5daQcdN+HgNGaVdeS9QGR
+aEZJ6P2gZoHqpszq1syq1qyqlqzq1pzqgi5Vbi8JCRvFaWoilJc1VZc/Qgm
cjW5qJpUVE0srCYUVLcWVLfkg7lVQFNuVSOQ80D2A1nVQBOipjnrbwqjCC5o
ai9qphajZSHf3VMm9aX5tBO534ncbYdvU+HrROgiFjiL+I7RvR6okekbtSHT
WmDdAEXabZiHLg2dEHAtoRBBizdQCYTyjH4O9zx2cP9/9BfGQ+xEC7QjAPlr
MQVMmz6IWhh1QVvEhmdjE8lrtvitW9CcUfh6PHGfLxUM7oAmsdhhMnm8vXO2
u3dxgK5fPfbnu7NLjKu0wkcXV4fnFyiCT76P4N10BGMV2g0V2gf9GfPXEbNh
z1Wx2RJ2W9Jh20aPVnEghf2eo2C6RZ/HYxdJdBUazEWHdWAHbx6GQrt+X9Ll
imxZ/RsbrpWVrYV504x+fXJidVy7olEZ1EpgRaNcG1eDwuiiH3bTLYCXFrtp
17116HeegLxR/1U8eJNE/y3uUpE79BqGCEaLuGK4vOji87EHhe+ezbhtWYlv
LkWM8yh/l6ZdaJs/imDLlDqtsE5hBIuRyI8uyzF5EQa1dFklWVLi/ooezQUM
KtSWscyVrU/INycVpiklDrwHiyGFcX/nZKN68fCEgKMZZf4tfJm4vFhtZvdL
ubi8HEzekQkJf1ImmFaI9CqxXi2Z0Uj1Wpl+XDY9Lp3SSSd1Ep1OrNWJ1OMC
5ThfruVJNFyhijWmHODJe7nSTpa4jSEk9PObukc+dAy9b+e8IjN/Iw68aO1/
1txb0dhd2tBZ9JFWUNee94GS+4GcU0uE0RU6cBaEaU1zJqIpsxqR8R0/VKXJ
wHnfnPm+Oet9S/b7lpz3rbnvCXnvifnvSQXvyYXvyZi8yN8SoBqHUoL5W/zo
b1VrQVVLPiZv3vvGXERDzgPZGFlVQCMC+dsE/maBvx8eIxhb2YX8pWH+dj36
+xTn81700270fjd6txO5SYWvMIVPI+h27T6usMMS29oMm43BjRW/cdm3uuRd
XYTODOZC8iJ5N1djaIIz7TitULyhfp+EvMhf/P4RuvkbOEr7izbFI39t1pDF
HABVNze9ELg4m0hefOyF5vwYvgm/PwWOgL/x+CG6eLVztgf+Hl4dYf6ent+d
IX/T16+Qwlc3J5fXoPABUvhs9/gkdXiU2D+I7e5FUrshFMEpPIL/m78x21bc
tgUNAVd41+3c97oP/V6kMFp5FTmLo5PBAExedOT1fjC47YUcdwTNFo/RaF9a
Ms/Ork9Nroxrl9SqRaV8QSEDlpRyg0YJQWyanoBJxG1YCEBpsW7AnLLvdUDn
QfImQjeg7Xb0fgdxtx0BkaFFX8d8lxHPOb730GM5QPKub1tXIXxj64vhtTmY
f73opI5Jx5wORTAojFJYvQkWT6jWAR38XyuN40rc5UeLcYWXkcIIeIMf0IEu
eY1jN44xcy3T2L1jdNdJZZ5GCqNbThrxolIwKx2ZEn07gUfC7vu+OaPwZfdJ
uAOy4UE8eceRvGNTcqFeKZ5RS2c1sjmtfG5cMatDzOgU0xPyqQn5pE6m00m0
OrF6XKjQ8mUanljFFShZo3L6kLSHLaYNCsj9/JYeXn0Ht7qd9YbM+J1A/7ml
91ljd2VDZ+lHWlFde0EtJa+GlFNDyIYCXAVJ2pyJrGz8nh+Ad/9KxrsmIBPR
nPWuOftdS8671tx3hLx3xIJ3JCTve3LxewpQgvtb9egvuQT3t4pQVNVaWNVS
UNWcX9WU/74xD9GQi6jPwchO05D1Pq1w5ncRjNaHfCTl1VPy0cpMKrYys7MM
Ww1SSex5Qux9Qux7CnzZj33ej33ai93vxu52ovDzAz9F57Hg9wqnYBa2mb5t
RNowYDuPDOHNlcdrp9sO85576wDd/MX9xe//4os3/Li/u2l/7VHbVthqCZhN
fohgUBjMRa8mr8kMzRmFr80ecjojbjfyF8oz+BuNgr9HKdzffdzfmxPc38v7
86v78+s0Z9ePCl8enJ/vnZ7t4ArjLfoxgvFL0MjfqN0RtdmjW1DsrTDDxres
CRs6juCbwgEvetIKpjAMvNiBIeghDgeh8K4/kHR7Ija732Ryra5ZFxY39PpV
nW5JrZ5XKOZk0lmpZE4mmZdLl1SK1XH1JlRo8HdlMbi5Ct9VmDiOAu6zCCbv
NvwWjX3ajX/ai6P/HNvR22QYBuHLiPcM3/vgtuyjjUjGlOVRXgjfWf+yHvfX
OT/hgBYNKTwzboFZeFprmtIAm1PQ3iH91eCyUQcgkcHiFY0ctxhDsvJwvwlr
y+lVW9iuQy3O1qwGLDahJR/f/J0UcrWjLAhfKacfnUaLXXYew28YMXtR+A4x
FCMsmHmRvNKxablwRiWZ08jmtYoFnXJhQrUwoZ6fVM9Nqmcn1TOTKv2kcmpC
MTEhH9dJNTqJalwo1/Alap5QyeHLB4el/RxR16CgvX+U0DPc2MGpbWO+Iw38
0dr3c3P3jw2dlR9ppR/aimrJBTXE3CpCDhRgSFKkZGPG24YfEPVp3uA0fEcj
kAG8bcp825T1tin7bXPO25bct615b1vz3xEK3hEL35Fwf0sQbaVVjzz4W0Us
/s7fAszf/PcNeYj6XIzvFc56SOG0vzUt2bVYBNeRctHi6rbCxvaiJlpJM74O
pLuC0FNJ6H2C8/Uw/uUg/vkg/mk/fr8Xu92JXqcil4kwKHwS8aNFU360aGrb
BZFkjtvQRuCYxYgD5ias6NopyLvrgvC1HcLwG3Cfpv1FEXyKb/hFZ1R6wN/U
3/w1+/EITsuLwtdnsfq3UHnG/YXyjA2/mL+J7/w9PLw6Bn/PbiF8zy/vL64/
Xdx8urz5dHELb+7Pb+5Or29Orq6PLnGFT3eOj1PQovewFg0RHE358KvQaATG
/LUhf60WIGY1x7csCezpotsu+67HiT3mzHcUCh6jI/7QWZ3H2GNi9oPosWgJ
lzu8ZfNtmhwrq5b5BePUtGF8fEGpmpXJZyQSvUQ8IxGDyJDFK8hfyN8Zz+pS
yGRM2C17EL4h7wXU5lT0DszdT37GAIXB35tk6DLmPwu5j/32A7d117G5vWVM
oO38+JE7c9Cc/Qa9b2nauziFTr1DCk86oEiDxXMTW7MT1hkdYJnRmfXjpmlA
i7msWZ/AXcYS+WFSfrxNDPUbW2+JzHXMjTvndc4FhGMe7RqGFIYKvaKVLKIt
hzwoz3j4wtgrYHTzBzpH6Z2jA51jjG4B+Mvpx8NXKxyG2ozLO6+RL4wrlybU
S5Papanxpenxxenxhenx+Snt3JR2Zkqjn1RPTaomJhTjOpl6XKLQCqVqvkg5
PCZn8yQDHFEPc4xGHyH1DDV1sOvaBt+T6C9ben9p6vqxnlZZ115WS4EGm18F
pbcl+x1oCEo2ZCBVP/7w+uM//kb9P14hfngNNAAZiMbM141Zb5qyEc05b5rz
3rbkv20teEsofEcsekcqfkcGeUsR3+RFIH9JJQ/+FlW1FGL+FmD+YgrX4zxa
nI7gdIuGKfh7fyGCyfn1lIKG9qJGajFazdVZ1tJV0dJd2dqD0fvkz6PE18PE
l8PE54MEKHy3F7/diV1vRy6TMO4FT6P4vgPXvs+x67HtuNCO/pTdhLBtpuyb
23bTDiQvknfr0Gs/hjkuiPw9w/w9/bZtEO3W3/G6Um5HHPM39M1f09/9tXzv
b8zn/ebvY/7u4/6e3JyeQXm+v7j6dHn9+er289Ud4vLu08Xd/fnt3dnN7TeF
T053jo6S+wfxnb1IcicUS/nDCW8g7vbGnMjfiM0GA2zEaolYzBH0dGBTbMv8
oDD83V37fu9h0I8rfIwdz3UQDu8FQ9s+CHF3aMvm3TDZDavmuYW1qell7fi8
UjUjk+klkmmxGBSeRf4q0v4uzHrXlsOW9ZRzC349Qku5SkYweVNfDreBzwep
T3uJ2+0o6kIR33HAeeDZ2nWYklZj3GSIrC+G8NjFzV2aAnk94O8DLsS0c3Ha
sQBM2RembPOIrblJ6+yEZWbCnNZZ+5jLULM3JlXY6Tpq6N5WbKW0Y17nWphw
L056lqY8y1PupUnX4oR9ftw6A80c4httGdaLeVCelcMMKbsPajPIix7O0k+D
19GBLqjQuL8qPgfCd0ommFFK5rXyRZ1qeVJrmB5f0U+szEwChpnJpZnJRf3E
gl43N62bmdbqpzSTk2rdhFKrk6m0YrlaIFaOCOTcEckgV9jHHOug8yg93JYO
1sc2RhWx71VL96+NHc8/Up98oJTVoAab/w5yEwRsyHxdn/H64w+v6v6B8/J7
PmLU/4DzqiHjVUMmAP6+bsx+3ZTzuikX/H3Tkv+mtfAtoegtsfgdqQT8fUfG
/S0DvvM3rXA1obga+VtU1VxY1QQUVDUWYApjfLMYzcJVDdmI7/ytaUX3mj8Q
c+tIeR8p+fVthUhhWkljR2lTZ1lzV3lzdwWip+LP4+TXI8SXwyQofL+fAIVv
dkHh6KPCJ2EYAGEMhBhy7Hls0JMhbXddlj2Edd9tPUjL6zgJoGMoTkOeszCK
YACtfMaHX3TUhivpAn9tEZh/MX99JhNentPDr8nsRf35Yf51Y/NvAJt/o9j8
m0r+q7/nl5i8N1+u775c33+9vofXL1f3ny/vwWJQGFL46uji4uAMDcLbB4cJ
iODUbji+HUAVOu72PfobtlrDFnPYbAqbNyOWzbTCdmvKacMeE+zGV1QehkJH
4fBhOHKANh7C8OuPO8FfO+6vaX5xbUq/rNVh/sr1Eum0GCJYMieXLaqUqzqt
ST9lX5r3ra9Et0w7bvtRyHseD91AbUby7nw92v16tAMK3+8loE5fwvc/5Dn0
2Xec5qR1PbppCBkX0UnR6JjZKc/CpBv8wgHL4DNL055lPcIw4zHMAm4M1zIw
41yacSzq7QvTNuCbziidLXro2yAmxCva3eCYn3Bh2voM0/4VPY5vBf7hU84F
iHUQX4n7Oy3maUfZ8qEBMbN3bKBrpB89VgnRRxuhd46Bv+x+OY8J5VknGZ1W
iKA2g7yGKe2qfmJtdso4N22c16/N61fn9Stz+uXZ6aXZqYWZyTn9xMy0bnpK
CwqP6xTqcalCI5Io+QL58IiExRXSmfwuOq+th9vawaynDFQTe183d/3aQHte
1/akllwG8fceErMp501D1qv6jFcff0CqfvjHH4j/9cA//qjD+PgDoh7IeAk0
ZL6EP9WY/aox51Vj7uumvNfN+W9aCh79fQv+kkoxf8sQ4C+l7Dt/S5G/xGJc
4eqWourmIqRwI0ZDAUY+Rl5VQy5G+nJ0Ne5vczYewUhhUm4dOf8jpeBjW2E9
tbiBVtLQUdrYWdbYVY4D/iKFj5NfjpKfD5OfDpJ/UzgVvkiEzrArWidhz3HQ
fRRwHvod8BN16LXhHAE+XF7nadB1GkL+niJ/vSAvxDe288iz63Nte5wJpz1m
3wpvWYMWFL5IXuzilRvAFPZ8F8FhF3b92Y9ffw7vx7Hrzw/+Xp+c3J6d318g
f79c3369uf96++nP289fgZvPX64/fb76pvDl4fn5/kMEx7Z3I4ntYCTpC8Y9
yN+I3QEFGH6lhCymkHkzZNoImTciZqQwKtL2rRQ61MuFFlWiHQ3BQ+RveD+E
9h6mvGiIRv5umu0ra+b5JeP0zPL4xLxKMytX6KUyvVQ6I5XOK+RLatXahM48
q3caFgOba3FUnp0wpFxC+O7BN3/n6/Henyd7X493cX9hkDmP+o8CLviFmbRt
RE0rQeOiD6xcnHbNTzjndM7ZccTcuGteBwqDbt7laZ9hxr8651+b968t+I3A
ImJt0be26F1d8KzOe1bm3YY5MBrX2YHFNGQ0JLVzAWW3GzJ9GWydCazOBtdm
Q8a5sHEOXuG9b0UPKWyfg+xWrY5Lwd8p0bBmlCXj0IWDPaP9HWAutxs9E22o
l8rr7+AzukWYvxrB0ISUD+G7MK4wTGpAXjB3Y2FmY3F2Y3FuY3F+fXFubWFu
dWHWMD+zNKdfmJ2em5kEhaemtLoJlWZcrtRIpEqBUM4blbCHhAMsfjd9uL2H
Q6ANNlDoNYSeN02dv9VTX3ygPKkhlb1vLXoL0oGA9Vkv6zL++PAD2Pp7LfC/
vgGfAeqAH35HCmeAv3/UZ/7RkPUSkfb3FfK34HVz4ZuWojetxW8JJW+JJW+R
v2UArnBVmkd/S6uJEMEl1a3F1S0YzUXVTUXVjTiF1WmRHxRO31cCf7OrmxGP
EVyL75Ig59dRCuraCz9Si+tpJfUdpYhOoOyvk9SfwHHq63Hqy1EKKXyIFL7F
Fd6JXqXCl9Di4oGzKPRhsNJzEnKfBF1Q6o4DDqQtMtdxiskLkxoG+OuBFg2T
3TF28Oy+373rxc+5wi4+YxevfKZNzFx088gFbKynLQaF4Qsggp0ObAT2JoPY
/d9Y9DCZON7ZPtvf+87fKxS+N3d/3n766+7zX3dfgD+B2y9frj+DwvcXt7en
11fHEMGnp7tHxym8QoO/UdzfqAv3F1V6dHSPaQNjPQwKWzYhguN2a9Jp23Y7
d72e/YD/IBiECD7A/N0LQH+GIdoTtjl8Jotjdd2ysLyunzXoJhfV2jmFChSG
FJ6TKxZUSoNWuz41aZ2fda8uw++HJJTngOcsFrrejn862Mbk3f/r9AAUBpfv
9hJQquHX5oHPue2wxCzG4PqSF5IU+jB2qPsWzKfTaptebZ/RIIUxf30GPZLO
uBDaWAxvLoc3DWETsAKENgFDcMMQWF/2G5dAatxo7woYjR+oMuuFZF+ZDayC
qvPh9YXIxkJ0czEGmBajm/DhPCjsNYDvUL9Vaw/+qkeYUnY/TLu8PhqYy+6i
AJzuNohgqNAP/g5PysZm1dIlnWplenx9bmpzYca0NG82LJgNiybD0qZhaWN5
0bi0sLo4b1iYW5qbAYVnZyb107rJSY1Wp1RppDKVUCQf5Uu4Q0IGa7SHPkzt
YRNpg42Ufszfjt8+tr+oJT+pJpa9B9fAu4aclx8z//iQgZn7j99q/tc3aoF/
/PYBkxf5m4HA/a1H8r6EP9uQ+6ox71Vj/qumb/6+Qf6WIn9J3/x9VPjR3xoi
UFJDKKlpLalpKalpLkY04TxaXFDdmF/dmFfdmIuBlnOkFUaLRrLxRV/pvRLk
/A9tBR/aC+uoRXXU4jpaCaKj5K/TFK4w8vc49fkohfw9SN79TWEYh0MXieBF
3H8e9Z1HYLz1YJ66zsDZoBPDhT589DcEmkNee6B4o22/2GlXSZc97tiKbFmw
8N30InONLqPRaVzDMDrhQ1DYhBZP+iCj7TYUwV4PVGh8BMbXb6D7R8jf09vz
i/vLq88Qvrf3SN77L//89BX46/7rX3dfMYU/fbq8uzu/uT65vDw8O9s7PkYV
emcvmtwORZP+0KO/IUh8zN8AdpIP+BtCCmMRbLOg20m4v2gvP/IX8hf1Z5h/
/YGE2xu2O/1mq3Ntw7q0sjE7vzo5vaTVLag0c0rVnEK5oFQtaTSrE7pN/bRt
ccFrXI1YTdtuB0wWF4nI7S6E7y6S9+wQgDfg7+1u4iIRhvay67EnbJtgH4jm
hN6L7TMyTyrNEwrAMqncmlbZZzUQweCvf2UmaJwPbyxGTYaYZSVuXYtvGTHW
Y4DVGLUaI5a1iHk1bFp9MHo5uA4sAaH1xfDGUmRzKWZajpuXExZDErAiEpZl
sDi8Pu9f1cMUbJlRr+lkuL8qHlPC7uMPdA31UMFcZgcZgDfcXuoIvUvI6kP+
Codh+IXyvDypWZuZ2FzQm5fnrSuL1tVl65rBurZiWV0xrRg2DMvG5aXVpQVQ
eHF+dn52ekY/OTU1Pj6hVmvlcpVIJOfzJUPDwkHWaC99mNbDJtEY4G8toRvz
tw35W0Uoe9dc9AbUq8/+oy7z9w8//PYobzV6/RXxD8zfH36rAzLS/n7M/L0+
C/z948Hfl9/8LQLetBS/aS15Syh9SyxL+0v+F38RNeAvrjChtKa1tLa1pLYF
txjjweKaxsKaR4W/LcrCIzgLV7iakF1DzKkh5daQ82rI+bWUgtq2wtr2wlpq
Ec7/B76CedM=
      "], {{0, 213}, {320, 0}}, {0, 255},
      ColorFunction->RGBColor],
     BoxForm`ImageTag[
     "Byte", ColorSpace -> "RGB", Interleaving -> False, Magnification -> 
      Automatic, MetaInformation -> Association["Exif" -> Association[]]],
     Selectable->False],
    DefaultBaseStyle->"ImageGraphics",
    ImageSize->{83.03125, Automatic},
    ImageSizeRaw->{320, 213},
    PlotRange->{{0, 320}, {0, 213}}], ",", 
   GraphicsBox[
    TagBox[RasterBox[CompressedData["
1:eJx83OV2I1m68PkzM1/m49zC3MDp4sxKNIkMshhCzEwhBYmZmZnMlAxF3e9V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      "], {{0, 213}, {320, 0}}, {0, 255},
      
      ColorFunction->RGBColor],
     BoxForm`ImageTag[
     "Byte", ColorSpace -> "RGB", Interleaving -> False, Magnification -> 
      Automatic, MetaInformation -> Association["Exif" -> Association[]]],
     Selectable->False],
    DefaultBaseStyle->"ImageGraphics",
    ImageSize->{83.03125, Automatic},
    ImageSizeRaw->{320, 213},
    PlotRange->{{0, 320}, {0, 213}}], ",", 
   GraphicsBox[
    TagBox[RasterBox[CompressedData["
1:eJyM3OV2W1n+xvmemTfzcm5h7qALuiCpkElgEDMz85F0xMzMjGZ2kkpV/S9k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      "], {{0, 213}, {320, 0}}, {0, 255},
      ColorFunction->RGBColor],
     BoxForm`ImageTag[
     "Byte", ColorSpace -> "RGB", Interleaving -> False, Magnification -> 
      Automatic, MetaInformation -> Association["Exif" -> Association[]]],
     Selectable->False],
    DefaultBaseStyle->"ImageGraphics",
    ImageSize->{83.03125, Automatic},
    ImageSizeRaw->{320, 213},
    PlotRange->{{0, 320}, {0, 213}}], ",", 
   GraphicsBox[
    TagBox[RasterBox[CompressedData["
1:eJyE3Nd2I1e2qOnd3Td92a/Qj7BLUpVMWjqAJEh47703gYAJeO+9j4AHQe8y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      "], {{0, 213}, {
      320, 0}}, {0, 255},
      ColorFunction->RGBColor],
     BoxForm`ImageTag[
     "Byte", ColorSpace -> "RGB", Interleaving -> False, Magnification -> 
      Automatic, MetaInformation -> Association["Exif" -> Association[]]],
     Selectable->False],
    DefaultBaseStyle->"ImageGraphics",
    ImageSize->{83.03125, Automatic},
    ImageSizeRaw->{320, 213},
    PlotRange->{{0, 320}, {0, 213}}], ",", 
   GraphicsBox[
    TagBox[RasterBox[CompressedData["
1:eJyk3OWSJNfW8PfH9hd/9C34Ft4jHeFoqBmLmZmrkoqZmSuzmJp7SHrvxffj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      "], {{0, 213}, {320, 0}}, {0, 255},
      ColorFunction->RGBColor],
     BoxForm`ImageTag[
     "Byte", ColorSpace -> "RGB", Interleaving -> False, Magnification -> 
      Automatic, MetaInformation -> Association["Exif" -> Association[]]],
     Selectable->False],
    DefaultBaseStyle->"ImageGraphics",
    ImageSize->{83.03125, Automatic},
    ImageSizeRaw->{320, 213},
    PlotRange->{{0, 320}, {0, 213}}], ",", 
   GraphicsBox[
    TagBox[RasterBox[CompressedData["
1:eJyk3dd2G1m2qOndfW7OZb9Cv8OuSi9L7wlHeO89AhHw3ntvAh4gQVI2s2q/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      "], {{0, 213}, {320, 0}}, {0, 255},
      
      ColorFunction->RGBColor],
     BoxForm`ImageTag[
     "Byte", ColorSpace -> "RGB", Interleaving -> False, Magnification -> 
      Automatic, MetaInformation -> Association["Exif" -> Association[]]],
     Selectable->False],
    DefaultBaseStyle->"ImageGraphics",
    ImageSize->{83.03125, Automatic},
    ImageSizeRaw->{320, 213},
    PlotRange->{{0, 320}, {0, 213}}]}], "}"}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellTags->"LastCellOfAPage",
 CellLabel->"Out[14]=",ExpressionUUID->"cb12d83c-76a2-4a5c-b8f0-a326db2fa761"]
}, Open  ]],

Cell[TextData[{
 "When the picture gets too blurred, ",
 ButtonBox["ImageIdentify",
  BaseStyle->"Link"],
 " no longer thinks it\[CloseCurlyQuote]s a cheetah:"
}], "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"e54a38c8-f2ce-4d81-ab9b-bb9d6d2e063e"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"ImageIdentify", "[", 
    RowBox[{"Blur", "[", 
     RowBox[{
      GraphicsBox[
       TagBox[RasterBox[CompressedData["
1:eJxMu1eQLGd6pkdJN7rUjYKxHHLIGQyA49u78t57X5Xlvcny3nvvvetqb47p
Y4GD4wAceAwwGM5wDHYY5HKkXUmhUEgKiaLIFSkt9TdAMRTxdEZ2dnVHV1c+
//t+Wdk/0rsF5v/8D/7gD/z/JdgIdGG8z6eLCv8r8InY5bdZXCYj3RUwWUy+
bf1/AQ7+Fnzg/rM/+IPLffWUDg2Ikg5S1FiTNG5B7eu6wXXL5Lp+8Kau+yNV
+49V7R+qO3+q7r3xHT+R1XHyCk6Wx/AjOyzHKs2wzNCucLXrDOgWSfITvOSH
ONkfYVV/iNP+1wTLH9JcP6A5t7gBHJRh2VqKwNQQ3TdGDzTRPVlozvH0yPYq
2pbDODJkZ5IFR3i2IN/SkPhH2sTCnF5Y0rvG1FSfHGmiHWWkAflLMldGAqdk
ppAEcvGkNi5AZsBLNDixEi2QIPn8HR5ni8/aFjC3RVykgI9i87cp3FUM+wZG
cJOk2mSZ0CI/Aorh9RmGLsvV5/i6jAhK8EUBJsGExhmQKC0CqdlBaLcA2+qN
LdX6unV7y4FG2LAoMw5vJlGtdIaRSVXR+HquWM9XmMRaq1xhEAgVDBHEVBr4
Gi0klgqoLDKWikKSEQjK9iZpbYWwtIS7uUy4sUa4uYq9voq5toG5jsAvYSnr
KPxNBObmBura6s7V5c0rNzcuuQ52dq6vgOOkpR3aCoK9guGv4MWrRPkGWbMN
AM8Fr1jDilewwmWCcIUkXGWIt7gypBjCylUkOUSUKQhyOR4gVaOkarRMg5Op
SRKIzJdROCIKS0AiszFkDprCRTHFaJ4Kr7BSDV62LcL35A3+kjlcs0cbcKzu
CJcsvqzenVC7YwqrV2CA2SaYbXFxLTDH6uTa3XxngOEOc3xJcSCvjFSMiY4z
N44Ud9PlvSzY5ufx/CSa7vlidZsvp4YTUkNApHZzRRYqU4snQkicfAer2EFD
WyQ9hmUnSUMsTUpgLUq9bVVyai0eumq3C5WzXOU4Uz1ONY5S9f1EbR6tToOl
ka849OZ6zkzHkW7b011Hpgdnhq5C05NvXZJtedItZ6Jpi7Ys4ZYx1DGAn+lq
K7wDRWCmCu6q3BOJrcdxDuXmJkdbJpnqBO+QmToQFY5VxSNt7QyuHHvyC09y
4owObOGBOTa2xOe2YFcdGeiiQ32op/HUJbYC15phWTMcY4xuS/PAKRpralNt
U7JpjtVM4bLemhSYYlxtkKXy0VVeltrHVXuFaq+Yb2DydByejiu1KPQ+C5zw
+XKRQD4RLaQ8CZ8poFPCXKEJy9StsgxLPOs6z7EpD2DVcbIyiodiGGUCqYiv
C0I3/tVfcX1NXL/5nb83LZObwF9t58+UrT9RNH6gbP2psvMjIC9A2SBAVZw0
hxaGd9jwGt24QtcsM5XLRNHbWP6P0Pw/xsn+GKf6AUH/b6i2P2Z5fySJU4G8
horI1deEFub4oTl2qI3ty4G/3j4FrmPhIt5doPtyQn9a6onLHS1ZcKJP7dsz
e9b0rjk7M6SGunhbGarJfXmpOy2Dk3JzWKpy8qR2DvAXMpNkBuKlwnKMRIIR
C1ESPhogEqCFAjRXiKAK1gn8ZZJsjWlEC5zgDEFrUmRjkWMuCyxliakk1WTE
kiiX6aJQHASCBYO3YEh2PAUmEmEc3o5Be/F4HxHnJmJteOAvxUJjmZksPVNq
FUNWicYu1zsUkJEvVjLkWo7OJlJp5SIph8om4mhIJHUHQdvapK6vkVZWiDcB
q/gby+irtxBvLe+8tY68uoW5sYW99p28by9tvnVzA3DlxtbVG9vXbiFurGBv
AX+3GatIzipGuE6UbVGU2zQ9kqpDULQ7QGGCbJ0gWSNL1mnSTaZ8mwehRSqc
VIWXQjipAguQQWBlQ0hUSJEKI1Ti+XICW0Sg83AUDpbAQBJZSCIXSRej+WqC
0k43+bmOmNBbMP7//Y2Urf6cwZPUeOIqi0+ktTF0VrrextBb6AYrA1hs8dEc
IY4nIfHlVGHgb9udmUTyu4nsLJGZRtPjcHLoj3edwarRnYVscbHOx5M7GXwT
gapEYuWbKOk6Ur6BUmzidQiGHS8OMbUZPnhdfB11YmYG/lbOMuXTdPU0XTtJ
14/TjYN4fTcC/C2P/f/qb6pjv6QPpwfOTM2dbbjSDVey4UzU7WDdCNfN/obe
29B4mipPV+kfqUO7mvCexr+rAAo7+xJLi2uu0+AOLTrnFk8Vtdva+m1z846r
duor7nvSUzg6sIQHxtjEnJyDHXVsrAOAHeCvo8R35C+xZ/jOvChYgRItY7Zn
zXRs8boxVNKYExx9mKX205ReAEPl5ag8PJVHdOmvnsXX82Q2ucFvdia/87cQ
C2Zi7rjXEtCrXXyRGXfpr36Fb9sQOBEyPw4KkxRhvDyChuIIWXRd4L+hndKU
I4Ks/a/+3gT+mse39P231J0fyet/LK3+kaT2A0Xrz1TdN1S9t9St7/zNIITh
La5rg2VcpUE3yZJraNaPEMwforl/QlT8mGF8m+W4IgzchJJr1rbC3lG5h/rg
3Bo7hBPH9sSxMXGoDM/5gRHd0yJ5a7RQlR+tKmIlbayg9/Q00aklfeDI7juy
u7bs1JQcaGMtlb8gdWdEzqQETsiAv+DZyW2X/sotJKmJJNXiwXkrluNkMpxM
gpdLCRIxTiTB8KVoumSbKttk6pBAXkWIDSXxhgLT0RDDbbmzrYSbamNFocqK
RVEO20elOPFUF4ETpPNjHH6czQ7TaTE6PcakBuh4OwFrwFJMZI6VKbJy1R6Z
3g0ZPQqjU6Y08WRausrEMbukCq1IKGfS+QQCG41jIzFsBIK1ucVY36SvbdJW
gY8gf5eQby9tv7my/dYa4sr38t7cfPPa6htXV358df2t61tXQfjeQt1cxS2t
k1e3mKtI7jpOtE1SomhaDMOMu8SIpepQZNXOpdHKHZYKyVGheGq0SIMFqoI2
IlagJBBapsKKNFsi9Y5QheQrMWwphi5EktgILGMHRd3EMDbx3G2aBMXX4pUO
hjnEB/noLZj9JWuo6ojVnNGa/fv89aa0zpjS7BVqrEyliaYykiE9EWy1FprO
QzcF2OAbfXlNqGGN971A28J+KjOPpaahxDgQH7qiPXugrnPlZSCMNAG2zEXj
GDFE5QZaurojXUEp1tGqTZIRyXISpBGmLie012SBHvDXmD90lM+SgNpZqnGe
ap2n2yfJxl6kMgtUJv7S6NJfkLzJti3esSW69mTPEa85v8MBfvlQzRKomHwV
vbuiBf762prAQB+e6cMLgDawq/LPlXBP7Gjz7W2Gb8TKHEkaF9ruQ1P/gaN7
z9U89Zb33cmxNdzVB7taELuxiT46huITdWKqiQ5U/pbcVZW4y1JPReavQoBw
VZPqmPNDR65vi9V1/oJMH2FoQ8BcCuShQh660sNUurmgPfINdJ6eITDw5HaZ
MWhypbz+PPA36o4F4AgM/NW4BWILnqlb4xjXRDBC6kZLvXiJD4AFGSSPoESB
FbbrqnZGAf7Kuwjgr6S+BPzV9pZMwyV9/5qq9Yak/EfCwh8Kyz+Q1v9U0Qb+
XtG0cFAZJU5v8YMbXHiVaVgiy65heT9B0H+IZPwpQfgWR78k826rY1hLkepq
sUN7dkB43xk78iRPvekzd+rMmjzVRBfi8JQd6DFCbXasKU42tZmGNVO1h0am
5ALOH7rz+67s3JGbWFI9XaSqvJQ3IQQBYY9JzEGJ2smTWdkyK0dsJIoMBKEO
J1RiRQqQwjiJjCCVE6UQSQzhQSSxIARTg+BacbIAU5Pg6Yo0W5Pn6cu9Y7V3
pPWODPaORl+RyzNCXphBcxOoXiIvxpJmhZIMjx9nshIsTorDCjMIDjzWgKaa
iEKYA7mFpiBkCSrNfrnBKVKamQoDDZzbJrCq6LkCNYMpxVNEaJIQRRChcCIk
RrCDFSLQ3C0kY2ObvLKBvwn6MwDk7zr6xgri6rWNn7y18qM3l3/85sobVzeu
Xtu+fhNzaxm/tE5d22ZuIAXbOCmSqsYzDESGlcSykJgW/PcK07Qopg7N0WN5
OrRAjxHqMEI1SqBECC5jFyXTYMT6LbFuR6BDcFUIpgxBFmxj2esoxtoWaRlB
W8Fw1qlSFF9PUDqZhrDAlpK6c0ZP3uQrWoJFa6Bg8eVMnrTeldTaw3KDR6Cx
s1RWBmSkXi6YWjwERHYzdEGePaPw1cyxgTczjxSOUuXzXOksWzhJ5g4j2UUg
NXdGhyZ/U+UsS7UxtiJA5TlwFMMWTrOB020SjTskK4rpJgpCNCjNNVfEoOUG
R5rkriF7YCmeREqn0dp5vHUn1bmT7pwnG4eR2m6gOg2Ux77cwAX8BfLG2tYY
iLwuqA0uQKTuDNZs/orFXTY4imp7Uelt6f19fXhqju6aQ7uGwEzjn6q9U5Wz
K4Q7PHefHZ3zi6fy9gPt4JFp+MDeuws3T+Di3B7vG3xNBYhaX1sa6stjU0li
pkjOVfGxMtRVgC8F6qpQUxftmMMNQ7ihu/R3ZMv0TaEqBGe4miBV5SdDnksu
I9jDhNwshZMtNDOEJqbYwle5IEvE7Ml6/YWAPx+yBWCLH0y66u/95ejWuaZN
iQuj8BLFbpwARgtcGLEXIwki+N5VpuOaekJUD/GKHlLaWpM2lqHWkqa7bOgv
67o3lY23xKU/EeT/iF/4gbj2Z/LWW8ruVU0dpShsixIb/MAyB15mGG6QZG9j
uD8G8mI5b9AVtxROrCXJ8lbF0YEmszAlzgLxU3/sxAe2iXNf+rYnfW5Lnerj
h7L4Qhgdc6M9frIjT7f1uZa90HQldp25fXfx0FvYc+dncHZsTbT1wZICyGuP
CqwhgBCcSJCdLTUxAUIjga/H8bVYngorgHCXCiuIEogkVRFFaiJfjeNqMRwL
TuSmKKJsTUZoarDhgdg7hfxzjX9m8M9M8EBrakLqokSYZDMCJGaQLEwypXme
OMvhJeicBFOYvsxihpdEc+B5LpoqKDTFIGsEsoZlJp9IB7OUFiqo8UorSWUj
87VEjgrHUKDJMhRJiiRegiJIwBaDFyKxnEuFEdQ1JHUNRV4FbOKX1zA3b25f
eXv9DSDvm2tvXdm8emX7+hJueZW0vk7f3OEi0GI0QYGj6UgsE41pI/8LZiLd
gKMbMCwjjmfG8U04oREnMmKFOrRQswOQ6FFyA0Zk3hQatwSGHa5mmy7fIArW
0OzVHfrSFvXmNmMZw9+gKlB8I0nhYekjAnNC7Ejp4bTBnTYCXCkDnNA4Yip7
VGkOgr7B1zq5ALWNKTdSwNgCmSlQkGdIKtw1S3Tszx8mq3cKzYe1zjv17ru1
9jvl+sNs9V60dBYAbQqEV3AAmXN8XZqtCFMFPjzHjWN78bwAiR+myFJsVZ5n
rIqdHYVvqIpMtamFPntgKp4GKqfB2nm4fS/eu0j27iTbJ9Hmfri+CFZmvsLI
A8Ze4G+0fUmsY492/JGOJ9R2B1oOX8PmqhnhitZaVrlbel/fGJ5aYru28K41
MDX4xjqwhjuaPLjN9vbY8TmvdCptXyj7D3T9++bhPUf7xFGYm6Idpaciclf4
3qYg0BFGJtz4TJRaKJJTZWyoDvc0kZ4p0bcl+zBYQ6ItU6JrTg1M8bbaDZ5O
hKj0ERUeAuBf/PUyFC66DKZLbEyJjS2z87Q+hS1u8mRdvrzHm/MYPWa9S6t1
ylUwF/jL02/zLTtyN17ppwphAteK4dqBwmi+e4fjBP7eUI+wqiFK2UNAnU1l
e03VWlW1lzWtW9r2ElS/Ii7+mJv7E37hT0WVN6StK/LONXV1R1HclCbX+cEl
DnyDYbhGha6QxFeIois0+ZLYjDJHOIGqOtG35Beu2kkwczeSvBNK3A4CkZO3
/cnbnuS5NXGqSxzJ4/vi+FyQGIlTfSjXNZd6rmovmNv3Fo8CpcNAfuHJTR25
oRX0EF9WBsdFtiDf7OUavDy1gy0z0UV6mhiUECOeawCS4rhqLFeJ40M4gRIv
VBHATMfT4Hg6LN+CB/LKwkwgr74ksfX5ronMt6vyztTemdY70ztGWlMH0lSl
shwPCMuN08RZlqzAleRZgjRNkKJLs1xFjidJsGVRjjYhsuUgV05jj8ttUbHR
x9U56VqYooVJkAUr0m1SoU2KYgNAUmyCiZUo27lEiiTJ0CCLgb8Y5hb2O/CM
S9C07R3Kxjp+eQl58/rOtes7N64jb91ALX0n7zaCi8KI8QQFiaKm0A2My9Hb
TvsXLBSGicAyE7kWotBGFNlJYjtRasNLLTjwKkjNaLkVq3QQxLZNkXVLYNri
6rbo0AZRBKbpW9vMm2CmRvM3wO/G1OJFNprcy9ZE+Pq40BbV/CvWiMoSVppD
EJDX4BPrPEKtm6fzXFoM5mWVg6Fzc4x5nbNhj84jpdvF1pPW4Hlv/H5/8ro/
e90ff9DqPis0nyQq9/zZE3tsVxscK+x1gbUqMFV4+iJXU+CpizxNUaAtCU11
maUld3QU3oEyPNHEFzogb/7IXD71Vs589fNA515kcJEY3kv0bse6x9HWQQgo
XJ76M0NXsgtfmtu2hYHIg2B46A8NfKGBJ9h3+rsOX9fq6Zo9XaN/YApPbJGF
PbrnCM2tvrHBPdBaK3R7jepp06MTVuGQ3ziXdO4p+3f1w3v29omtMNVFGlJ3
iecssbx1TrDN8w/I4JGpXUlmoUrNtImROTkCKeNNDTyJHnzZATqmWEfnr0nM
SbIygJDDGDmMBUBOospNVrmpCpgis5HldobcxlLCfINf7ogZPGmrJ213Ja16
WKe2yeUWnsxCE5twAiNCaEXLXUTIRwMvMduMZVuxQGGOfYsNrwGFlYMdgGqw
o+7vaLrb6va6urGqrC1r22tQ7Za48BYv9wa/+Ia4+rakcU3WuqGqbCuLm/L0
ujC8xHFeY5mvMnRXWdqbItO2zIY2BpnBsgb8SUvzQP0w1j3P5B5EMxfR1N0w
sDh5J5A4d8dPzbFjTRTk7744uRClp7LcWFMc2WqTQHsWKx75ysd+kL+5XXdu
DGd61khV405JXTGJ1c83uFhaB1Nupgm1JIGGLNRR2QYsS49hqNBMJQqkHvM7
WBCGCV0e5BhB5SCDsVebFZmqcmtTYR+LXHOZexeCJ3LHWAFPVLaB2tiWq6oi
4KwowxRlGdICW15iy4oscY4uStMVOba6wNcU+MaCGC4rXWAxL6hcGZkjLjIF
mHovzRSgm0N0hR3JhG4QlEtE1TJJtUZSbZDAWKfcpkAIKoSlKXAkCQrP2wEj
J4GDIHOQACJrh8jB4NgoFA2xQ97aJG0ANiibm9StLfoOgovBS4gUFZ2uZbGM
HLaZx7UK2HYmx8G6xEZjW6kcK1lgp4icFDBUKtw0cHpcniQukspF0HnIBh9V
4UICZDBSYEWw9VtU5QZevIriL19eDYNQDD2OZ6VI3UxlkKONCvRxkTWitoRV
5hDQVglmBGNA/h1SvU+s8fDUbi5A5WIBDAGBI6HwjYPxg1Tlfr3/YjD7aLr4
dLb/BWA6+6Qz+rDWeZapPgxkz+2xPa1vJAFNFe4InF2Ruy9xDxWuodI5UDl6
kL2rgPtKgKuv8o/U0Zkus28sHlkrZ/bKuat27q7f9rXvBgcXsdFFfHQnPjiP
9S4VjlTn/tzYk+o5411HpGuPdODgIBAa+iPjYGwWjM8DiV1/fB/gjS7ckV04
unDG992A0Mzu6uktdUifw5uKBLhBDA4o2T1W7VTUu6sc3tP3zo31fX26B/nK
XHuaas1QnEWqt85wtzDgkcm5MLunzO6aMjN7ZurNzULpgT899IIUjvfMoZYS
LrK0MbTMtyay7IgsCLEVKXNgFDBBAZOkYLE14WU2qsxGh2CWziuyRdVwQmeP
acFfXger5UahUEMV6AigTYnMGKkNK3eRFR6G0EZmm/CgTLKtaKZlk+PYEHo2
od6GarClGWxrh0htb0fd2lbVNhTlVU1jC6quiIo3+Lm3BcUrwup1cfOGtH1L
U9lRl7eVuQ1xdInrusayXeVYr/Oty7ogwRRhePKSTM9eWYQaB/H2abp/p1h8
nMg/jGUuwul7oeRdf+wcDp8YQoeK8KE4diBM7gvTu/L8XFfZdbT2wv3DTOnE
Vzm59Pe78mxLdy3hstYZv/TX4uOBsgrmL4mBehmvKqJAS6FqkDQViqzYuQw7
yTaAJN0BkGXbVNUO04QReaiqBM9Ykdk7Kmdf65hJXAu5c66wjaWWodQ6VJj7
Cn1bJi9xgbbiHBM4Ky0wZUUGQFqgi5JEeY6mKXGNZb6tKvU0lK6K3JERe/Ny
OC0wh5nGIM2eYDmSTKAJRfEmXnOdqFui6Fep+g2qfoumQzC1WLaWwNIQGQoc
GIrJfCSNj6IL0HQ+ispFUPh4Mg93aTELg2WiMSw0lo1BczBIFgonIFAgGkvH
4Rr5PIuQbxUJbGK+g3MJzOY5WDwbne+giWCG3M2EvEy1n6UPABiGS2imEMMS
YYLXRRvAq314uRsnsmHY+h2aapMoX2NoUWDp41lJEhcD8nNB+OpiQpC/1pAG
8J25ChANBr/sOyS6gEjl4SlcTLmTAQBznDkm9ha18dNs4UGt83Iw+2zv8Ouj
w6/3Dr7ePfp6Mn5d77/MN55E83fgxIHeP5baWkxDhfzdsCn0TRWhhTq0pw3s
ar0TjXukcQ/UQF5PHwr2VYmprnBgrp84Wueu+rkT0Dr3dO74hheRyUV8ejc5
uZPsn0Q6h2EwCBfH3nTfdelvBwZ4+x7/0BeeBuJ7ofRRJHcWK9yOFe/ES3dj
ubNQ+tifOgokDnyBid1S16iyYnUKrc+i7RWcv0dK7zIap4L+PdX4vrFxqC5O
1dGG2JlmGqN4fQxnSROBwo4aAjwS+Js/0Ob3LDkw7s39+Xk4NQqkx/7U2B0b
WMBQbMnToci2yLvEM2wCBKZtiRUjs+NAQQJK8g1oqZUktVIUDrrWyzeHpWAc
M4fkYJHUwUqpns9RELhKjNCAkZix4FtkTgr4ywutVJ6JxDETWCY03bQB/JX4
kfLuMtRb1wy3tP0tIC9U34IqW4rypii7LM6tCLLLvNxNfumWpL4iaS4Lazf1
ddSlwsVNKLMmDF5nOd4WuG+CpQbOM0NNORhXawe+3nlq8qA8fVgd3iuX341n
HwSBuYDomdN/aPDuQcFDSfhIGDsRpE8k2WN54VBX2XeARtQ5SlTPvcVjd3Zh
T02syYE53jQECip3Uu5KyB0hidHNV1joIHx5KjxXRQRQ1CiSEoGXb+HE6xjh
OhrMd99BhHZoejTfSQZjr7EosbeV7pHOOzHYp2LbRGQZAsSmvljfFimrPBC1
oC0DeYUZKj9F5qeIggxBmCWK82RJBi9J4ZQ5qrXOd7akzqrEWZb665AjK4DT
fHuKbUuyLCmGIUaSubfYxht4/VW8/jrZsEQ1rgN/6Xokz0wAw47eJxUbLq9r
caQEkZIqhChsMY7JQ/FkdCoXh6PtgB2WlEriYjkQgyIksBR0BkS/fH/QLlU4
FWK7VGSTSRwKuVcqcvKUQZnUJVB4Rea4UgkGCh/XmpA6klJrTGQJ82wxnisp
guM8c5DhynGNEaraS9QHacYQS+tjfPcuBksGU1V+Nhh7lT6WOSExpaTaKN+Y
FNvCWoNXprTzIRtP7RLqvBKtRwi5OPqgWOXnylwMCUyR+ximlCTUtmRnvsz9
UuNFb/bZ7v7X+wdfLYC8+18OF592ph9WgLyZY1topnR3RdY601qnO1os94Af
nEkj++rogS5+aEwcWcILo2eo8fRVgaE2NjGmZ6b83FLeszYP4c6Ju3JoBRZ3
zr2tI2f72DM8D49B+B6GugfBzn6oPg+UJj7gLyjPoYY1UDN7Bi7/2BsGsXsQ
zJxGi/cSjSfZ7rNS40m69ihdvp/I34klDoOuvkWdlwkjbEloDYptmvI7vi4x
s2DWT4Ttc3n3XFPdU2UGcn+Rb45QNH6cOojVR/HmFMndIgR6tNhYlF1oiweO
4r6nsAgCf/PzKPA31gdDt8pW4GriOIl/je+6wdVuMqAVAF+/LTYBJVF8HYKn
RYqMOLmNrHEzDT4+4HIqcfM0Lq5EfXn9U6CmiHREiZkgtxHkDjLo22BkFlgo
HAOBZcSBKVgAo8Q+lDwEJt9l9WDVMNrRDy/DF5grya2JMhv85CrYCnPrgvyq
uLoJdZFQHyHrbOibaODvZYXOrAjC13i+t2SRJUMO4+/w0lNl7Rju3Y1MH+X2
nlb3ntanDyvld0KZC3fszBE5sQWOjO6F0r0Qew94oWNO9JQTP+WnjsWZQ2V+
31Tcd9cOg8VzR+HYmtk3p6bGxEAfaWkDJaU3q/SkIHtEennlysoSG6l8DRnI
y4bwVA0a+IuVbiAEqzv8FaRwDSPZxMo3mSYC20YUeKnKJM9Ukzp6KtdQDTD1
BYYuT9fmappcVR305EtnuQkyN0ZiRwisMJYZRrEiaG4cI0wTxFmCJIuSpNFQ
jmisMKw1jrXMsZV4LmBxUegqicDWnuOYUlRlGMd3rtFN1/GmKwTTdbJ5iWZe
Z5i2BVaC0s0FS6szqtNYhXw5iScjSpU0uZomgyhSBVkkY0gUTLmKY3Eo5Voe
S0hUGHhSA1dhEkkMfJlJqIYhvUejdmuUTpXKpVb75CIrF3JLlC6RPqCwJ3Vg
0TaFJM4E5EmrvWkl6CpwXORLyQIZBcCfl3gyQmuUDaqCKy0OlTSenNIU5uv9
XHtcaolLAGAccOYge1rmKqjgmM4SVGpdYpWDD/wF8mp8AoA2JAAdGwqwoBBb
nxR46tr0Lmi20dqzVu/1YPfL2eHPFqffLE5/Ntv7tDN+WahfBHOH1uBA7qxz
TXmqJolXJzC6NN5So7i63MBUEp5DiQND+sia2LeEJ4bIyJiYWPJzR3nhau67
2/ue7p6nd+Cu7Frq+/b6wlGeWqpTOzg4OAz2D4L9/XB3EW7ML69CZ3uueNse
rpuBv94BHBi7I3Nv4iCQPQ2X78Vb72R6LwqDV6Xe82LznVzpIhk/CNjbRllS
xPLS+N5bkvCqNrPhamITU2rxgFs7kjQOlcWpItGWubN8fZCqdOMhL04XIRmT
FHeTGuhy42NFdmEoHjhLB/7iXqiwCGVm/sTIHeqanVW5KcdSRrEi3zrXeZOl
3KBIlsjiW0xonavZ5qh32KptgMSMV9gpWg/L4OfqvcBcttLBgOx0oZLJV1B5
CrxAg5eZiUqwzDppCgdVamcIzRSukcgxYthmlMCJkAeR6hhWO17RT9dNkx0D
GIQb20BeXmKFFV5mR1Z4qU1hdkdc3FE0MboRST8jasY4QwujqSGg0qY0syKK
XwNoi1vONjGxJyqf6bsP3dOnsb0XuYNXlcWz8vhxrvzIlTgz+xcqz0wBTyX2
CQ+esz0HLP8JPXxGi54xYyccUKTje8r0nimzZ08dq9NH2vS+NjFTh3tQoKHw
V6FASX15905cYfSLVDBXbmGLjHSOmnTZSNUoEL4o0eoWd2mbt4wWbxAgJEUL
kpfKc1NEfroyybn0t6O0deTmpkjdYCprDFmJIsqReEkCK4qj+hBE1zbBuYWH
NwmONSK8SvVssoI7ggQahK8sj5RlkfIcSlMiGsp0U4FuKbAcFQFc/hesRa4u
RZMEUUz7Ctl4FWu6QjTfoFiW6ZYNsE6CdHNntMmap9AKucN6pY4tg2hqHctk
EVjtIjss0ah4Dlgdidpyeb/dqZDIKTaXwhPUWT2Qzi7VWMUGl8oeNDlCVlvQ
AgDlVmHl69wyk1/piGo9CaPJJ4OjKl9Cl6o6ih1Prg7HCvpI7vLN9ETJGMjI
wnnIm5Q6wvxwXlUderNtBxyTBPOaeN0cLusDBU2kYvAXNe6sPFjWgHXGGoS0
LhFk48qsTIWDqfSw1QEeKNggoIG55rzY3VDH5/bqnUj/ndzwo97s8/HeTyeg
M598NTr8tDN6N1U5dUYHKm+Nb01TtWGs1LXJsyxxzbcEthV5dBOMnHCD7euK
oxPV5V12CxswNzGyZEdAUndrERjsB0d7wcHc1xu7azMHoDqyFnvGcs/SnDgH
u/7hIgTo7YZbs1Bl5Mv33am2I1a3hGomT8fi79sjU1cKJONZoPog1n0vM3pV
nH9UG39Y7b8ogRQG+WvrGCUJIcND57pviIK31Kk1Rw0VHVGyu+zCnqi0kGdH
ULSpcKbFYCS5fN/WT9dFWOYk11cXBDqS+EiXW9hLB97yYaC0Hyzsh1JTT6Rv
BeOVpSjUJKnSEJLnXmPBN5nQJkm0RBDcpEhWwP73sJTbMitJCdN0XrbexwEW
g31wBAQuX0FnS4hMMQr0Z4WVrPUwNW4GBNMkFrLIQuWDVDKg2MZNgXNbFUWZ
cgTL7rplvmmcbKrb67LiKi+xxAwtMQKrrNAmN4EUZNGiEhZqk/RTmnFO087I
xg5e18Qoq9uy/Iokd1NZWrb10aE9WvZcVHuoGz5zTF8GF6/ii1fpydN490Eo
fa71z8XWLtPUopk6NNOAYpuSnQckzwnBd4IPnBGDJ7TgASe4EIEFObKrCR+I
Ygfi2J4sMpH6u2JvQxxoKMMNXbhi9GQ1lrACNDqVUyC2sDlaCk2BA2MvaM4g
dkH+okTreAWCpsOzLCS+m851kXlekiJ+efeXtSk11viqIl1aJINizElgGCEk
xbsDnEVZVhD6m9va64Ad7VWk/jreukT3bvCjSEkCqyjtyIsIRQGhLGC0RYK+
QDUXGbYK11bmm/JsfYalzbKUSQrPjyRbl9GGa0jdW1jTNZJpGfRngYNoSyry
vWB/UTw47ZZrYdgJGQ18u03s96liMX0qZQ559OWsf9BKzcalZMxiMvLiMVOh
5AlFDLBbYXZInV5tOA7HMr54NgjwJywWD+SNGv1xM8AXMzj8yljami25+5Ps
4XlzcVhpdiO5kiOdt2YKtkzZnK/Z0iVTsmAot5yDebQ1Caar5uY40JgEMg1z
tKhJVg2RstaXVQQLKldc54gojV4xZGdLLFSZjQq5GZogRxfjGdMCW0nibqvD
U3Pu1N14HO8/z00/a+990Tv4srf7cX36Mg9e8fyuIdQUw1m6KYJXubbF5lWO
8ipZ+GOC4A2K5G22/ZosuGHMEOEKJ9CWJcbGzMSaHthyA7g4cNZGvu4kNJ7H
ZvPoeBwc9X2NsbM+git9W6VjqXWt7aG7P/UP5+H+NNibBcFzAd9S6LnSbUe8
bolUTe663t8xhsfW5AIunnkbD8PD56np6wJg/GERpDCo0+mzqHtk1xTV4rhI
EFyRxNa1uU24iQmPKOk5J7crzM0VWVDmm1pXTmWKyHQhsSEiNacU9rzSX1NH
2obU0JbbdYPwBf4W9335PW9sZPZ3tLayWJdmQlGiMIBku9do9ltAVbJ4Bc+/
CbZ0+QZDcSkvR4343l9gLlAYtGiQxUBeUKqBv0wRnibY4SpQwF+d+9Jf8FWR
iSi2UYQWAsuwwzSsCN3ruhTKXiE4DjaBwrr+srRyk5e8xorcZIZWgLycMJKX
wAqzeFEJr2iRdGOmbkbXTMmGHknfxaubKEVtU1lbNQ22ffuE+G1m9oJXfVfR
e2kcvrQPX7hHz3zth3DltiU859s7ZG0JqSohtHWUoYO2TNCOfTR8uOM63vGc
IoHFnkOKd4/t3RX5dhW+PXpgjxVYcP1jrrfL87ZEwY4q3jPHO7Zg1QyndcYw
pPZIpA4e18BgqMlAXgBeskVQIChqDMNAZFvJPAeN66RynESuhyiL0XQlgaku
0JaY8jSJn8SxoxiKD6TtOtq6ijIubWtvbKiuriveBmxCbyM0V3HmmwznGj+A
kMTQ4sKaNL8uzW9Ks1uKHEpbIF2mcIltrQpUKbo4QpDGSKIoke7ZQRtvbqjf
2la/CSwm6Jfpxi0QvvEGPDmq3nkwe/7iznxai0dsbhgKeVXZhLlahFs177SZ
PhpVzhaNi5Nuvx5JRfS9Zng6SNWrvkzKFgkb4gl7oRiuVpO1RrbezCUzznDM
ki/5swUv2E9nXMkU3Omm9w7qDx7Nnz87vrg3nozzjXoY0G7F5ovieJodz9Lz
vfz+URGwd5zfP80fnBUmB/FSy5Yq6cC21LIkK9pUVRfKmLwpvSOiMPiEajdb
Dc6f7+TVJ3mWgsjZhEJTQ/LYXr4faL0XG7yfmX1c2fu8cfBpdfQ8UT2DUyOl
v8SxxYjWINbg3IEMq0LoBp33Exz1T3DUH5JZb3DM1xS+TUua7C7xwi1FamAq
jODCwFkZeGoDX3sQGg6js1F8PojNu5FpO1BqWIt1C6Bct9Zajlbb2et7h6NA
bxQEdEaB5sBX6blzLXuiZo5Wja4K5G1oIgNjem4tnbjaD4LgF5u/zo0/yIw/
yF1eUns3k70d9c3dlo5VWzEo0ghVDmUoo51tQmhMS8y56Zk4M1Gmh8ZY2+ov
WR1poyVltGXMcNHqqTpCoN60PZlhAMy83zVnf3bhTM/toZ7G1ZAZc5eLuSxK
EAbQbNcWzbbKgdBU0SaBu0IWrDNkW0z5NhtC8NRouYWitFN1bpbew9Y4GZCN
IjURxAacQE5nCfFU/jZbhgBH1DANcnyntokI1lKRjcDUbzINSzLfmimPdtbx
tr1V02RJ2brOz73Fil5hBG+ywxv8GEYQxwtSRBBVgjxBVqdohgzdjKmZUA19
qmlENQwImi4CVG7nPi50m5y8T88+ZlfeE7VeqNrPNK2n+uYTY+meOnss9w5I
5goSyqxCuTVNbdvQ3TGNt627W6bFsvVwGT7ZcJ6g4COC64Du2ue598W+Q7J/
n+LbpfkmTN+IFxxKYmNdamLLjNzxrtNfsdmSOo1fJoYFPBDBJubldWYFiqHB
cQwkroV6eUkWvoTjJAF/Qf5e+lvgGEocdZYqT+LoQQTZs421X5oLYndHd3Nb
fXNLdWMLur6tuoZUXcPqb5AsS0x4g+fdBqsoN31dkLslyi4L06vS7I66SAD+
GsoMS00gS1K5ARwvTGAHcSDHt/Q3NrQgf69gjbfIpnWuHetIK7sH+YfPDl59
eP+Lz56enwxB1MYDxmzM0ih5Bq3QuBt+72z8/Pb02fn4/Ye7dxblaSty96B8
76R2ul+eDVLdRqTXSAy6uVGvNBlUZ6NmuRQADHvZdiPerEUnw9LutHb/7vyD
l/c+/ejxx6/uP7q7uz+tz4fl40X73un4ycPdizuji7vDxw9njx9O7t/rPXzY
f/Z8evde/egs3x36ai1bf+wDodbowa2BK16yRvImb/pyWrm81S0uMiUExhTf
DpL3/5O3cOFpvBvqvkoMX2emH6R3P8rNXyWad+DkUOor0R0xrMW3bXZu6c3r
kOqWUHSNTn+DQPghmfwGk3FdbF/RhzGeIjvSkGe6xvIEBjNsexap9/y9YWw+
zRzOi8eTwtEwd9zLABptT7XhrNXhRtPZbrlbTVen7Rn0A6NhaDgK9ceh7jgI
FC51nNmmDSjsq0Khljre16VnpuKhpXHX1X8nMHoRHb9KDl+lus/TtSepzHkk
sPA6Ry5b32lqUi0Niq1NcvUpwTEjNuMmppLkSJUcmGMdOFz3eMs+b8nvrQT8
9WCgGY41Y8lOIjdKXv5rxjycmbrjY3N0pPW0JaCVaTJUKEGUx4hgYed40FTb
JluBoQi3CNw1sGVId5gyBFuB4qpAtlLVMBPI+72/IGolRrxIj+VKKAw+FvjL
ku6ItRi5hSgzf/dGkgkvBylsw7H0a2zzTWV43V5CwXWkcXJN278mq7/Fz/yE
GXmbGbrFjyJESaIoSRalqcIMmZ8lSmtU9Yipn3O0c6ZxwLBOWNYpzTzB23ax
/nNy9D4t/oCcfEQtPGWVnwqKjwXF+6L8PXHqhB9ZsL09vLm8qc4uqQsr+sam
sbtpGK4ap0u62VXj/nXr8ZLjdAs+wcLHFNcR130kDJ9RAsdk74LkndNDu/zk
QpnbtxT33bm5NzcJxDteOG9WB+UiWCCw84QOId9IEZppIgtdbGeKYJYQZgmc
DDD8Mu14Nkzg+4jSKBVK0aAURRrHCMMIgnMDY1tBGm5taa5taa7vaG4BEOpb
aN0KTr9MMK5SzOt0+wbLucn3bAm826zUm4LcDVFhWZxdBS1aXyebmyxjja3M
0UHsckN4bphI82Mw9g0AyY8mWlfpjm22EwOF2Kmu9857u5998+ybn3/w519/
+PjefreaKKec7XJg1osfTNPHu5lPHx1+9HD/g4vZl+8dvbw3ur9Xfvlg9OL+
8L2L/r3jxvG8dDirHM5qB5Pm4axzujeaDQrzYfF40Zz2i3uT2rsPDl48Pvn4
xcWXr9/96uP3Pnn58N2Lw4uT6aPbi1fv3P705ePXz+5+8PT2iydH7z3ee/7O
/vvPDl+/Ovjg/b37F80HDxonp/ndvej+YWK2GxyM3JOZ/3KCbjqTdRBnlkTD
Em4YfFUVXJKmZrbMIVy64609CgJ5W88j3VfxzgeJwbPg4F1/4541PZUFqwx3
Gu8IIazODYN5RatZUkhviHjXWLQ3qYSfsGnXJbxNpXvbliBHapJsV18e2zu7
gdFBcnqQHUySJyeNZ48Wnz4/+/LZ+RdPT7965/RnT8+fPp3ev+icnVaPDov7
88x0GJkMwruT+GwUnU5i01lsNIuCyl0fXioMUjje0iZ6hvRIn50ZCgtD+dhc
v2NrPnJ1nwbb74Ub78SK9yPx02Bwz+ed+wGBXYlvJvRN2IEpKzLjxOeC5EyW
nOiSIzgxCCR68UQ3E+8WYj1ALt7Pp9rFTK+QH+ULk3R2Gk4MHaGezteWwnWe
uUhXpQnAX3CyyWJUng9HtyO5SgJdgiILtukSBAfCAsBgy1fj1A725d0vPr7R
xwX+yi0kIC9fg2Lw8TQumsrdYkq2BSqk2ICVfHdbndh8eSFaZMOw9Cs825I2
vukoI+Dqlrr3E6j9hrjyBvCXHbvKjiwLYkhxiiQB5TDDuHw/JUuU1KmaMce0
xzfscQwjpnXOse+xrAsyfEQKXlDjj2jRB4TYA0L6ETnzmJa8R4uf0+LHDDAU
e8ekwABvrW1q80u68qqps2XqbeiHy7rRNc3kTf3ibcvRDfvZBnyKcZ5QXCcc
94koeo8WOiV7D0j+BT12IMyeaEun9st3hPcChd1Ichh0l+zqIAT8FcEimUem
dvEhFw8gd3ElLg7wF4QvD6bQLBimHcfzEkQhoiRKFIXRvMAW27uOs62A5AXy
riuvbCqvgvBFapZQ2mWSaZNs3qJZtxj2bZZzm+fa5rkvFWan3xKVlmSVdUVp
S1PHgUEeHgrtHSE/jGEH0EBeboxM8+Gwjm1KEC8tCRhuJNeLFQXIppSkvpd6
8cXFb/7y83/7u69/9eefPHt4Mm3nO+XQtJs6XZTuHlcvTqufPDz46P7e64v5
Ny/PPn48e3ra+OTd2UdPJs8vBo/POvcOGud7zbNF62S3e743vH8yv3vcv3PU
uzgd7o2qtw/6X3z4+MvXT7748J2Pn93/7OWjT188+uCdu+8/uQN2vv7o2Z9/
9urzV5cP+Oj5vacP9t5/evTNF4+++enD16/2Ht1vPXs2fOed9t27pZOTzHTq
7/Qco4l3sJ/u7iaa80h7EeseJhqHkfzMFRuYOg8S3SfxwbPk4GWy+yIO/K0/
DwI6j5zVO+bUXOZvMNw5gjuJhQPbFvuKVntDrbguE14Vs6+wKG8xSVeErFW1
BKt278BJeryuyPeN9Ymzvx+dHmf3joun5+1XL05+94sP/6d/9/P//fd/8be/
/4t/+P2v//Hff/vv/5svf/vrlz/97N4HL/Ye3++dHZSOdnNnh4XFNLE7T853
E9NFYjiPdsbB2sBb7rqyA3NuZMqPjbmpLjvT5vZ0xWND+dxcu++oPPSUHvgy
t/3RY29o3x86iESOYunb+uSpOnooi+zxY/uC1IEks6fO7lpAsGYn8fy0kJ/V
CrNWft7KzZrpWT3ba+T61cKoVBhn0+NgtGf1tSBXnW+vso0FsjKFV6YIqgxN
kaAL/CSGAyPUUlhyLEOK5kB4oZb0PSIdUe8G5vItQZHJLwD+ysxEgRbNVSEo
bDSZhQD+MsRbPGhHqEMDf8UmnNRCUMAUoRXNMizxHbcMqS24umMrrRqbS6ri
DXH6qjB1i5tc5SS3+Dm8uEoXlGjsApFTxEvbJPWYopmStBOsboZSTfHaGdG8
R4aPaQHg6T1q6gE++whTfIIsPEZkH+zE76CCx3jPguaccmxjrqOPtrZRuvqO
qrR1OQJXsIYm2dyhWQd0+5QJL1jOQxb4UfApxXFOdt4hWy9WHBfbrgt84B47
fgHl7tkqd8P1u5nyYSq/m4p1A3DBqI4IFUGWMsrUp7n6uFAV4kg9dKGTIoCp
IHm5dirTRmZYCUwbkQeTRB6qNECT+sgiD47vBPm4gTWsAWcR6mWUdhVvurx5
nmLD0mECzUmge0gAggOLtiLxMJYapHAybEVTrBvIVV2+qscyzXnmXZ5+xOLk
EOISWV7kCRM8bkAoCmr1Ob+zmbMl9UqP1OBTJSvhg7PJl199+Fff/vLbn//0
l5+8/ujBxf3Z6LRTv92tPhw3Xx6NPr23/w2Q7vH5V8/ug+3n79z52YuHr+8f
f/LoDBz58OLo/bsHr+7sv3s0eXo8BVzMOo/2hxfz/qPF6MN7p988e/Krl8//
4sWzv3jx4pfPn//svadfPX33F69e/uaTD3/z+Ud/8dmHv/z0g7/8/ItfvHr/
88ePAL/44MW3n330y49ffvni0WfPL14+OHjv/u6Lx3tP7k3ODmp3jpvvPZqB
teLuYe/iZHz7aHSw292b987OZg/fOf3gsyfvfHT28MPFyXut4b3E6GFk8m60
c+Gu75lLU32qDQUKYjjKNnloOhtJYyKKpNtyGUIm2hKwl9i0K3zmdUiwopNt
WeKbcBobrrKLfW171zs9yp/eHTx4dPTTn370b3/9q7/9n//X//Qf//Gf/vYf
/p+//ft//j//r3/63/7uP/2Hv/5fvv3lf/+bn//Vr37+ycfvP3py//Tu2fxg
Nt0d7h8Ojk57i+Pq6CjVPQrVjjyFfWtuV5OdqzMzKDtX5BaK/B6U3ZUnZ9LC
sTZzoEscGGKHl/9Q457b3Qt34DCUP3RUz731O/7Kmad47C4cefL77vTMndsN
pqeh9CRW2i02DlvNo35p1kr3K7kBCN9cdpgA6Rzu2PxNtach97RFwF9DkabO
EJVpsjJNBf4Kg0SmG8sw4yh6FFGFoKvRfCNJZqMrbCy5mSEz0U0+mT2iNvhl
Cidf6uCyjVS8DIkWXcGIr+KkV4mKGzTVKseAENsoKidP4xbLHXyJjS11UJQB
kiFBMGdRlvyOtb2qLl+XZK+IM7fE2XVhfkdcxsnqNGmDJqgRRQ28ok/Sjkma
MUYzQehmSO0uwbBHsh3SXKe00B1G4oKeeUjOPcbnH6Ky9xGJ21vhox3vAuOc
khxDpm3ABvKamwh9dVtb2tGVUfoa3tKm2fpMx4gDz7iufY7riO08ocOnVOcZ
Gb5Nge9vOe8jfRfk0H1u8oGq+MBeeRBsXmRKR7HsPBLqOO0FjS4uUsU4uhTP
kBcYk0J1lCfzM8RumsBFAcnLthHpFjyA5SDw3GQgryJMlwXJAjeW60CQbTt4
0wZGv4rWrWENG0QLEshLteMYbhLdRaS5iWQXAWtHY2woko/ESXDkdZlxpLMv
jOaZwjyXOo8U7lO5Y1+sbFH1HZ6hJVcW5fKUSpd3+Hv57H6/tldMdSKpZqQ2
LOyfjl+/fvrbX3797c++/PL509f37z092ns4Gz4Ytx/N2s+Php9c7H/9/MH3
tv6rvx89OAH74Pj3/oLty9t7wOJnp/O7k9bpoAYU/uj+2TfPH//qg+e//eDF
b95/+etXL377watvP3z/248//PbT10BS4O9vvnz97Vcf/+6zz4G/wOufv3j+
uy8++Ztvfvrtlx/9/PV77z86Af6+enL88fPzD947fu/h7vPHex+/On3x6PCd
OwvQwG8fju+eLZ6CKP/0xZ//8tM//+2nH/700dNPTh6+np0+rx88y8/fjXfu
uKszY7anDpXE7gTHHmQaYarKgJcqkFIpUi5DyUQ7As4Kh35dwLylEK1rFQiV
ZxlO4VJtWW1i6e4GDu403v/4/q9/+9Pf/81f/o//3X/4x7/7+3/+x3/+v/+P
v//nv/uP//wP/wT8/aff/9X/8Iuvfv/zr/7mt7/85mdfPH/57Pb9O7uH873D
2cnZ/OzO5PC8OTvNj87jnduh2qmnfGgs7OmycyXo8+mZFJCaSuITcXwmDY2k
vpHcO9K6xwbn2OLddYeOI+VTd+si1HuU6DyINe+FG3cjtbNQ6TBU3I/kdqO5
ebK8V2getVvHvfK8nRlU0r10qpuMdYPBptNT1cEVmaMicNS4tgoL+KvJklUZ
iirD+N7fy3/QsBFpRgxFi6Tr0CILVelkX95D7uJpnVxbSGaPKo0BqcYnUvmE
PCsN+IuSXMpLkF8nQTfp6jWuESmxU4G/Wo9E6ZIA01Velj7GsGQojhLeVkHB
/W199ZYid01evKWsbirrSEUTA3UIyh4J6uFVA7xuSgDJqx5ua0bb+tmO+Zhk
OSE7z2i+O6zoBTv9gJN/wqq8w8g/IGTuYmLHSP8c4Rqh4T7B3qPbeyxLC2lu
oox1lLGGNjfw9g4VHrBdE55nJvDtCf1HIv+JwHPKdp0y3Gd01znNeR/teUAM
PqTHH4lyj7XlJ47640D7SaJ0Fk7venwtk7Uo1+eE+hzfVBSayiJTRqxL8JVh
lsRHB/5yHUS6FUsxocCWDROFPpo8woLiLGmYwnWjmbYt4C/RsoU3XXIprx0D
5KU4cAwvmeYik10koouIh/F4F5EVZ8vKcuPU5DyCfbdd7jOT90wfumcI3dX6
TiDTgGcdiK0dyFBRqbM6W9WXXbSGj0/P3ztcXIx3z0f755Pzu/vvv3jys88+
/OLVi/fOT56fnbw4O3p2tHi8GD3Z7X54e/HzZ3eBuR8/PP3y6T2w/V5boDP4
FIgMjgC+ePcu8Bp8CSgM/L0zboKDv/30xe8+++DX77/3y+fv/uK9J9+88/Cv
P339+y8//W+/+vzf/fTT333++tvPP/zdV5/89c+/+Nmz5yB5P3v08JuXl/7+
9ddf/OrT/5ert26OJEuwfL/EPtvZnu2ZedbTsz3TXNWVjMpUgpRihghJoWAG
BTMzMzNzKEBSiBViSFRCZVVmcVVTdXVXw7y13Wfvqsvs/bFmx665Qq4wk+S/
e87xuO6+vL80v1pObTWye6uVw835/fXyzloeaHe9sLNcWZlPz2fC1Xx8s1l7
erL38ZsXn3/++uUHJyvbpcpyeH4jkFuxRqtKV46tC+H0XqzMPMuSjpI4vfi5
Hjju/vjUzf6hS4ODlwb7L/b1nOvpfKf73s/6u34xPnRhdvIGhHieLLgvs8xY
Q/RwVr20lnr/w6Nvv/31n7/5/V/+8If/9df//N9//n/+9rtv/ucfvv1f3/zp
j59/+dXR3sPG/NHKwsvHh48fHa1srhaqJWDB2XyqVEkWK+Fkzh7MqDxZsS3H
M6QZujhOFUFI/dNC97jAOcyzD7BtfUxLD0nXgVbdRyg74eqzayXQxmmym8CO
sdVJurnId9akjqrEPi+2lcWWgkCf4quiHEWIKw8IVGGZPqoDFqzwaoQ2OdvI
YhnpNA2BqIChxWMIcR9S2oVSdKKVnYDfackdqPguVNwJ+B1k3P4/+UW3T5G7
kYx+NGsQyxoi8Cbw3HEUaxjOGoIxhwfxHe2Qy9fHfnJj/Mftkz+7C/1F5/R7
vYhrY9h7EEL/FHEECEoZgjH6kIJunPweTn0Lr71Odd9AGd6bUv5sWvsO0nIR
4bg6a79ythbaeQVo1nMV4bsGsJ2yvzvjfA/pu4RJ3sam2snpe2f5ttAjKQ8o
q0O62pCq1KPIdgqitxmeGxTbDbKlnWTtJNu68eabePMtIIKlnWi7T3F2Uz0D
c74hVmScFRtjJceYieG5+AAl3gsopiQekPN35godnPKAsDquqMG1DbyhRjXX
mOocVRjCUSwQlHoYqR5Aa4dQumGkbgAlG54V9UO5PaN0wG876LwA3luwi/ex
17tJt4eZHZP8bqioe5Rzt4t8qR39Tjvy4m3EhTbkhe/gBeQC3cZdB+QC3aHc
uTt3/x69o5PTPaqcgNvRhChpLjvHKTFYBTIrj2Hl4HMJCCkwjLD0oEyDSP0o
TD4xI5rGqyjKiDmylM/W47FiIFUI5cvRajWz3qytViu5gD/hcJQCvqVkdCEe
LHptGYd+Ieber2UAnivZMEByMekHhAJUAb8AXpCrwbfAxuO12nGz/B3m5aAd
7PZktfbR0db7W81HjdKjRuVpY/6kUnizufp2ZwPo/a2V042lF62V93fX39/f
WMtmmskEGAG/7++1PjzcfdpaO1qpn6wtnO6tvTraerq/dtJaONqs76/N7yyX
9lZrO8vzrWb1cHPl1eOTz96+/urTt599/P7p6eFiM1+qBRsr4dKSK1ZUelM8
W5jmibAtHorKgOZJoGT6EBLzYBJ6Z3SkbWT45mD/1Z6uC72d53s73xvqvTQz
cQuH6MIw7jFlozonKVbQbe4VPvzo+OtvPv3rX77565/++Oevv/nb19/++de/
/8OnX3775a+/+eyLj5+c7hbSZZ+zkYoeb28eHe+tbW0urC7Xl5eaKwura42l
5UKxGogWDL6c3J7lG1IsY4oIEAYuLPFBhK4RjrVvTt9J1txHSNqm+NcnONfH
+Xchkp5Z9TjJgWVHWMrYnCnPd9Xk7rrCDcaa3F6SmrIibYKvivAVIb4yJFGH
lYqAQuSScMx8uo5MVeMJ8lmkaAwYxzSvEybqQMg6AcKz8vswaceM7MG0tGuC
3zlIv9NDvtmJunkPdrV96tK9mUv96DYItRPN6Sfwh4mCEapkgiwZxwiG4JyB
KVbvMOluJ/Jq2+RPb0N/fmf6l/en3+mCne9DXh/F3J3E903iBqGE4SkqgH0A
LerFyO/hNbcJuhvcQAfJfg1tOI+1XCR4rhJ8V9Ce80jPuVnPr2DudxG+c0j/
ebj3HMzxDsL9Hi54GZO6jk3fJGRuzeXu84q98uqopjFpWpg216CG0qQiOSwK
9nE93WcX9jr7OK5+urOD4XrAdHcxvX1s/wAnNMINjXMiE8L0jDA9xU9DOYkx
emyQFumnRfrosQFKupuR7+eVx2T1GfUCSr+INS6STAsUbYUkSiKp7nGceRBr
GsBZR7CWYaRxAKMYRskGQZYeZd3vI98G/N5FXrmDuNxDbh+YuzvG6QT/LIik
e4hzu4N8vg3987bZCzdh52/AAcKX2rHX7+Jv3iHcvIVvA57bTm7vYD7oEw0P
ycbH1FNwG5YcYjByHG6ZL6rxhTW2oEJmZZHk4Bja3osy96ENAxjtGEI2AeND
cVKCMmCINrK5SiyR8SVS/nw+ulgttFYaC/msV6+ziAQRkwHkZ8Bv1mUO6qVx
q3I+bAfxGNTbesyT95oLPgsIzABn4MKAXzA+Wa+/2G4+Wq0CkAHOAN7tcurp
Wv3lxuJxLbtXTD1plJ4vzj+pFV8sVYHAl0fzueN64dlKDez2sFmpR8LzwcBS
In6yvARS6GdPTj46OXh9tPvm4cEnp8cfPzt6cbD5cHNpf60OsN1aLB1vrj7d
a708Pnz/0cnHL55/9vqDj14+f/745NHh7lKjsFBPrq5nG0vBQtmSLxvy8/p4
WhWLy70+vlpNmJsbR8B7pqAdUEgnAtY3OdYx2Nc20Ht9sO/GxFA7CtYzR5qk
8SeUJkoiZ9raK7/5+NEfv/3qb3/941/++A1ovn/69dd/+c03f/riN19/8sWf
P//q92/fvtjfr/pccZO+GA601po7O6311lbr4GDv5GR9e2N7Z31jq15bSqSr
jkhF7y3JrXmBOUMxJAnaGFYZnBW7J9iWPrL6HlbahhDegLDPFgyPsm8DuKZl
wwQLih2gq6Isc07sriq9dfV3cs0rbEWZPiXUxPjKME/m54MULXBymEY6VUPF
yWEY6TRCODrF6ZkE7sC5Ny24B5d2AGdHKrtRqh6Uqg+uGACWMcK6PzDX3ott
f4C82TF7pRN+ZRB3c2ruPpbfS5YOEcUDc8qxOc0EXjY4y3kwPtc+TLk9SGq7
A3vnHvxXHfBfdcHPdSMuAn5H0PfGsT2AX+C/MPoYgjuEEfdhFfdx2jaC4bok
NsL2PaC6btG8bXOhm+TQFVzgPWzgHaTvp3DPj+Hun6J876A878Kd7yBd7wG6
4bFzyPglbPI6NdMO+FVUx/WLcOsSzrlIsNfwpgJal4SpwhCZf0ziHRF7hrne
Xr6/XxgekcYnpMkpWWpamp4WpWbkeaQkBxekoOzoGC04SPH304L9jMgQNTHI
yIzyy1PyOkK7hDE0sWdaxGrrKElumhkeo3gGSe6Rs9WYrjGMfRSvm8CoR5HS
AQjnwQD1TjfhZhf+BtAIowPAC8wX8DshejDAAd323A30T65PnftON+GXbmOu
AXiB7d4m3b5NuXOf0TkgGYXoZ2EWLMJOIAXZzLRU3FBIFhSyRal8QSip0rlp
DNk/jrP1Yw29GM0ATjWKFo/P0Mdg9CmOlmuPu4rlRDodTMUDqai/lI6u1+aX
C/mIxcJEzOpYzITVWAm6M06TXycBittV1ZAz6zQUvZa4WZW0amph10LMuzuf
Aejt13JgBBgeL5YOG4W9anY5FdwuxnbLiY1saDHsbIacmwnvVty7ErQfFWJA
rZR/NeLcSHj3Som9ShLsFjFqAzpVwmZazaWerC9/Z8FvHh59/OQh0NtHxy/2
dx5urO4tNYD2mwsvjg7ePH389unTV8cPXx6dvDp5cnpwcrzV2ltdWa2VNkES
2KptLKdXFiIbK5HN1XCt7KqWnJm40WbkcugwzOwAamYAgxijEmHw6aGxoY6R
gXtgnJroIWKhfDZBpqbFM47Dk5WPPjn97W8//csfv/7bt3/6K4jKX/3+26++
/ttv/vjXL3/3x08+/+sXX/7ugw8eb2xUPI60wzIfj2wsL262trb29w+ePjl5
9gwYcWtno7XTbK4Vys1IdskdXzIH6xpbfg4grE/g1WGExDMJ+KWq7mEkN9Gi
Nhj3JoR9Hcq5O83vgktHSEYk20fVxgW2osJb1/saBv+CPrBo8DV0rnmVMSME
FqwMc8ReBs9BoxuIRCUGI4HDeKCvDUDZ3d+dVJlgt5/xK3mA0fThdENE4yjJ
NIHTjyOUQ1BhLzgCx2jdI5QHg4Q7g4Rb45RbMM49vLSHqh4gyrvmtAMM4zBB
1TfDuzs6d3OM3jbJutuFu9iDu9SLv9yHu9KPuTqIaTs75YXtnSKOwSiTCCYE
xR9BS/oxyvsE/W2i+aYqDRdHJrihfm60ixm5QwleIQTexYd+iQ0Cfv9j1vnv
CNfPke5fIe3voRwXsM4rU8Gfw0K/REfPk1I3OYUHstq4cQnrWKa5F1nuGsdV
ZtrzNEsSrw/DVP5xuWeI7x0QBodlsQlVZlpTgGuLCE0JpSwigQC/3DiE5h8i
OnqBKO4Bun+EGp5gJqCCAlxRQ2mXsLpltH4JoVuEK6tTkuIkNznKjI7ORcZp
IQjFDyV5J+fMMxQDFHAEE/aNMzuHaXf/fsKqc0rQPyXsBX/DSXH3qPBeL/PG
HdJ719E/uQa9eBVy4Qr04nUY4Be82H6Xeredereb3/cdvCgnCeelE/xMekwk
LGjUqyZlUytvyGQ1gbTEFCRxTP803TlBNY/SDBNz2imSFAqjjkygB3EslNQo
BtjmU5FKNp6N+JM+z0Im2aqUFpNxKRlv5LHCBlXKbgibVC4l36sRha2qvNsE
sAX8pu06AHIj6gH8ApN9vFLdKibWc1GwvVNJA5bBBqC77LGUPMay21j3WppB
W9NvqTl1ZbNiK+rYSbhXQ/Z5u6bi0CwFbcthR8Nn9qhkNonArZQWfK7NUu5g
of54beXlTuvDk8NXB7sv9/Ze7e8/BVgsLgI9Wl9/dXz8waNHLw6Pjze2DlY3
H23sgM65VV3cri+26rWT9ZVnu2snm/XjjfLDVmVvJbu/Xtxezi4UA2GXWiWi
sSlIJhHBoWEkXBoFC4dBRmaho1jE1BwJo5TxvS5zLh/f29/47NM3v//dV3/8
/e/+8oc//uV3f/zmi69/8/bLrz/+6s+f/+YPbz/5zYtXv3v//Y8fHu/MFwtu
W8ZlK8XDi7XKytrqztHR/uOnrf2j9db2zt42eKuN7frCZnp+M5rb8CRWrI4y
x5Zn6BMERQAuck1yzQNzmg6y4g5echslbEcI7iLF3WjZIE41STej+T6aISGx
59Xeqt5bM3yHMODXXVUDUzakBcoIW+ilMSx4ogaOEEFmeGMQTjdwikl25wTr
HjBfqOABXN6LVg8CbGm2qbMLMVxImh2GN0wiFCMzkoFZ7sgMZwDK7Jlk3Iey
7yCF9wiKBzR9N1XXRTUC9eA1D2bF7RDOjUlu25SgfXCubYR+a3Tu1ij11gix
bQR3ZxzbNYkdmCGOz1IhgF8kbxQh7EHJ27G6GzjzNW2GqEggxPEpYWKEHeuk
BK8SAu8Rwu8Swu8gPT+esf870vELtPM8ynYRYb6EtFyd9P471P9jePCXhMRV
ZuE+4NfUxLtWWK4Gz12TeOel3qLAkaaaIkiNf0LlHuK6+0SBYXl8Upuf1ZdR
hioGSFtFK0twcXaGHR4nu/oxpi6csYdsG5xzjVP808woXJjDKKp47RJe18Rq
mwj10oxkflxYHONm/l6Z4xBmbIYehs2FZll2BMMCI2kgSPHwFKsbwugGVQLG
H0RJxuDioRlxP0TYNcK718O4Dvi9gfn5Ncjlq5OXrkAvX4NduYVpu0u+d3/u
PnDeEcXkhHYGbsPjfQyin00J8NkJubRkNmy41ItGaUUmKfAlGYYwRuQHUAI3
XOxGSR1ome1sqQOOPglBDqDJMwIF223U5yKh1flyLZmIO6zz4eBedX6vVi64
HXmXNeMwRowqu5St41LM4jm3VpBzGQG5Z2D6bfNBx0o61EwGgP+Ckgu2wSsA
Z0AxMN+NfKzgMbvEbK+MlzYrV6Oug0J0PxtqxZzrIfOKT9+K2taCprJZltYJ
ilZl1aWrOLRppzWoV4cMmkrIB/jdq1cfrjQBv6/3959tbj5vATs+fLm9e7iw
dNBYPN1sne7sP989eAScrbEMdNTc2K4uNRK5/cXlk+bK+3t7IH5/cNj68Kj1
/v7a0VLhw4et093l7UahEHZ59HKDmK0WsDRinlklFTLnaDg0g0KU8DlmnTod
j6wvN18+f/XZ209/+8Vvfv/V19/+7tv/+c1//umLbz578dGnTz/86sXb375+
89njp693dz482HmystAAc6DNELEakgF3PpeqLy22jo9aJw+ry6utvf3D44Oj
492dg+bKdqG+nShs+pMrDm9d7ChwdHGizDsrtI1xTP0sXQ9d/YAouYsT3cWL
OomyAbJyjKqd4VhxEh9dH5fbchp32egu6z3zOmDE3roWRGhrQWzI8pUxlsBL
mjOhsAooTDAMYfdN8joh/AdAUEHXtKgHIR/AacdIRsicDQbI5ftxggCB48HQ
rDCQDNGqEZRwAiEYmeX1T3M6prm34aJbWGX72UVMtk6K+R7JcA+nu4tUtM+I
Abxt08LbY7w749w7YGaYYN6ZoN4ZJ96fxPdA8UNT+PEZMgQ2Nz7LHgKle0Z8
A66+gjJcNuaZ2hxNncMr83BheoQeuQsiNDl6iRQFLfhnZ/eiBM5rvQQzXJzR
XJnV3Ri2/XDc/j+mvT/FRM7PZdvFlWHdAsbWZFmrfFAignVdsKr2F4WOJNkS
mTWGJoX+EaF/SBweVaQmdWW4qYE2NNAgDCvKMF5inOIFTbYLpe1Ea7oo1hG+
b5YbwwtTRHmRrKpRtYtkzSJGtQBX1KfF5QlhcUJYgIoKs7w0nBmG0QNwZgjN
d2LpBjhZCaGpYWIHSe1nCSwEogRCkEIoGsD1FEwyMMi43UG50o4/fx39i4uj
F88NnXtv5Nz12ev3SR097L4B0cioEjJlgE9qZqcNGKKPxY7LeEm1KKWX5y2W
Va+2YZUXFLK0QJ5gyyNzMi8BkGvwU+1htjMsMNhYAimBxcXyhVSFiu/S6eIe
Vz2VXMnnG/FoOeBZiIZaxcxOMb2aDANOQU7Wc0lqNt4ioQOEw3oZ8N/NQnw1
A4qqA4xAa9kI4BdQDBCuR9zAlAHCAOSgVqKm4osuCyi5L1eqbzbrr5YLeyn3
sle36FJuhIy7CeeSR5tUcjJ6YcNtANoq54F2qqWT5YXnrfXX+7uvdreft87I
fbqx8eboCIC8Xanu1RqvdvZetHY2K/Pz0UQtntpbaB4vb25XFoAer7Zetfaf
rW++bG1//ujhl08efrC7ebrefL7ZfL61crxcWyskwfyQ87uKIW8+6Ev6XPlI
yGs2WbVqm1bntdtrxfLjw+NXT0+/+ui3n3/41Tdfffu/v/1///b7//z6k68/
OX37dOv4eLn1xdNXXzx5drqx/mxt+XR1YSMTyTsMMasuYFYHXZZcNrm0vrx+
sL9+cLi+d/D01avHTx8dn+ztH6+1jhpLu9nsmi/cMHvrUmuBrY0RpB6Y0DbB
NQ4CeCnSu1RZB1ncQRQ9IEn76aoJvgUjP7tFDNcYk1tTaldeB/h1V7TuisZZ
UQJ+TVmBLs1VROlCH5FuQxN0ZzfRQsjGQXcG3RYm6wcJGaMdIximvrstD89P
FIepshhdEqGIw2SeDwcQBs0OIxxD8oamQZVjtkHY12Dia6C3Uqx3mJ4OmuMO
0XQLo7+F1t1Bqu/CZHeholswZd84/+4Q4+Y4ox1Kvz9B6pjE9kJxI5OYUQh2
dIIwNEnthrDvTEtvInRXUebLlorIUObqSjRVCSvMTNDC9/GB64TgFXzwEui8
05Zfwi0XEKZr09orU8pr06q2YfP/GLH826T9P2b9PyfGr3ILPer6rGmRbl+Q
eBuGYMMarht9RYkjSTGHYfrAOIBXEBgShYakqXFVEaqpwtRVmGJ+WlyAsGJD
ZE8v4Bet6wb1gWae4HtRvBhZkqGrykxdnalfoKkbRPUCVtVAAXJ5WYggPSPM
IPhxFCuIZPjRrABO6qLowzxfXg0aUK0VXdhO5ha9vqzOFBQJLCSceALC6hma
u9dLaWvHXLw6+4vzQ5fPDV64NHGlHXuvmzEwwB8ZFI8OyyegegAvCuekCVMq
3bzDOO82Vjzmil8LnCynV6bUuozKmlVaU2Kdd05uxDp8rGBUkkxqYzGdyyk1
6kUGnchskPsMhpjDUQ6Hm+nkSiaxlokfzOefrzUeL5QP59Ogui5E7H4NzyKi
Aum5BLeE4xAyK17rSiLQCLlqAUfVb2/l40e1/F45DV6sB51g3MxGF8LurE23
korul/Mv1pc+aC2dLhb2sv7VgLFmk64HDQtORcMhr1plJZO06TVsxT1rYQeA
d69eebzWfLW79eZo78PDfWC+zzbX3x4ePFldOd3YfH9nF4wvtlqPllcWYvGU
y13w+muR2Eom1yrPHzSaT1Y2X2zufrCz/2Kj9XKz9WZn58Xa2l6psJlJbefT
m8UsSBcHjflWOb9eyLQqhf2lxtFqE7T+UixWTiYWi6XV2sLJ9sGHz159+PT1
Jy+++v0nf/rm87/87u03v379mzePPjxY2m4kCqvZ8of7h2ByeLHWfLxUPa7m
m1F3zqaKWbUhqzYecJQrudXW+ubx/tbx0dbxycPT00dPHp483D84WQf8Lu5k
ssueUN3kqcqsBa42SpJ5ESI75IxfZRdVfI8muU8Vd1BFXVTJAEsNkVgxGh/D
HBGY42p7Rusu6D0lnbOkthcUtjyYAcT6NFuTZMojVL6fyHCgSAYYRjWJlI9N
yfpgykGUdgKQSzbD6Q4cx0sWBOdEYYYszlEmOPI4QxqdEwbBT8EJ+gm8ZAIj
Gp7ldkLZbVDeFbjsMt54ney4yfC1k11tWPM1pO46QtsGV9+BKe5Ny+7Oavog
0o4J3l0o5/4U48E4sXMC0wPFDk8gh8dRw6PY/nHygwnm7SnJtVndVbTtsqUq
1s9zdBW6ukIUZqepkW5CoB0fbEO6L83Yzk+Z3oMZL83or0FV1yZl1yalNwZ1
/z6g++Gg/l/HLT+E+35JS94SV8a0daJtUepZNAYXHYG6xVOU2RJUQwimCYzx
/YOCwIAwPChODEtyo9LiqLg4IigOczKD1HAv3tWFMXdi9D1Y7SDdOiP04sRJ
hqrANTVE5iWRvsFS12nqOkW7SBHnUPwkQpBASVIkSZImClPFIYYsynHFlYWm
//D5wuvPDz766tHbz46fvdo8fLRYXY654mqelojlQyYZfd3Ytlvwi22z566M
t12ZvN2OetDPHB4TQ0dkkBHZBOB3RA6d1iPpAZ6xag9upBJb+fh6EchW9prz
TmvW6s7bwmVHrGgOxBUeLy8aURSzpuV6aLOZXq6nKrlQOuKJBh35YDDv988D
fpOJjVxyt5Q5qRWeLVcOKondfGinGF5NulMWWUDF8ak5ThndI+WqqVi/QlBy
m3N2vU/Od4pYgOL9SubxUmW3lAI2dDCfBUQvRjyrySCAbiUV38omgQWDehuW
M31CkouN8vMwXg4qpWTUbPJ5q6Jm1wDzrTp0q8Uzpg4XawDhZ5urT9aXj5uN
g3rt0XLzu0UdT1aWTxYXjhr15WQirNMGdJpy0L+cSjeisdVM9snq2pu9g9fb
u6+2tk/XNp42myf1+moiUXA4cjZL1edpFQsPlxZfbm2+3N54vrX2YnsDTBQv
QDNdrG/MV1oLC0eAuc2d04NHrx+9PD148uroo9+9/fbLl799dfjB25M3j1aP
Evagji3MuTyPmksf72+/WG2c1HM72VDdZ8xbZV69xGdRxEL2Si3X3F5ZPdhZ
PzoACO+dHB2dHB6f7BycrG3sV6ob8dSiMzhvcM/LLDmeNkqR+9AS5xTfNMpS
dgN458RAnXOibqZ0SKCdVtnwpgDHERM50lpXVg/4dRe1jpzCnJEYUwJ9iquO
05WxOVmYAvIwy4Uhm2E43RRaPYlQj2H0EKIFTnVgGW4Sx08XhwGzImVSpMlI
NVkRQBi4MLBgthtFNk+SZBNY8RCc1zHFvTEtvIxUXSZYr1E9NxnBWyTPDWCg
MO2VGfWNWVU7XNUBV3bBdb0wde+sohsu6QV9cIL0YALTC0GPjMGHx5BDI5i+
YWLHKKNtUnxl1nAFY7+ir7G183R1maooY3mZKUqkF+e/gw22z7quzdqvwGxX
YeYbM/obUNWNCdm1cfG1fuWPexX/1qP4l37N9yes/4oOnmdluyXlWUODa22o
XXWLe97gyEuNCbI2PKM+47efHxzghfu48T5eqoed6WZmuhjpB4x0FzHUibHf
QxrvA//F64dZDrgsSD2Dty51rqoda0rTolhb5WgbHNOiEDiyPEdXZFmGosRS
VtnLWlfF6KvawMF08HDhg48PP/3i6aefPfnko8cfvj569WJvZ7dRbcRCGYvB
J6HIkH2Yu+0zlzvQbffQfZ24wQH65KQUPqNBT6rg48rpMeU03IyleJnKnDaw
Fisd1RceroEjb+FgtbjVyK4U4/VErBhI5L25grtc9NSK7lrGsVIJHa4Wnu0t
Pd1fO9xYWK2V6vnUci5XjcUqocBiIrKRT2wXEtv5MCB3HSTbkHE1Zl2JWnJ2
acLIT1skCbMIACvFwxUklJlDtQsYSjJaiJ4OqkQA2A93Vl9uLAIjPmkUAbwZ
qxbwm3d7NAy6SyqqB90hlUCBhUoQQ3zog7mhm+LpLj8Pl9XyAgKKi0VIaUSL
XvPuQm2jUlzKppYzqZVscjEZLfrdSZspZtYvxUOH9fJWIZ1zWqJaZVgtDyql
ccvZh1zNVKwRCa6mE09Wlt7f3gSB9ulq82SxDmx3KRJKGvVeqTikUgCE9+Yr
gN/nG6sf7LY+Pjn4+GTv5e46mCIerjdbtcpmpbI5X9+oNPYW1082DvaXt0/W
nr15+NmTjWd7jf3Ha8e1cF6Ep5MmIBm77XC++BoE8mbppJrcTLgqTkXeJNCL
KWYNx+815Iqx+ZVqfWt5aWdz/XB3c29n72D74Li1e7i83MoXlwPRqslX1jjL
EnMW8EsD/EqdMKFpjKPup0s6mEDiByxJL08+KtPDdE6SI8T1JaRn8OZ0nrze
mVdbQLiKc9VRhjJKU0SowHwBhoBftgcHQjLR+HeEDVM4E5xsx9I9FLaXwQtw
xVGJLCHXZlT6vEqblSkTvL/7L4HhhJ3dcEkyghb0wjh3prjXYJKLGOMVivsG
PdxGC18neq8hLRenNBegiqtTinaYqgul6Z/V9SL0fSj9IFoxCOP2TZG7Ibj+
Kez4BHJ0Ej0+gR0aIXWO0G+OiS/P6C6hnZdBRtXUiLIKRlyEM1Nj2EAnwn0b
6WlHem+hvHcwnntIezvcdGtad3NScW1MerlP8ose8Y86xf/cJf+HIcP3Z9z/
QUrcZGeHpSWSqsDXFhT6rFyX5KmiRGVwRhGc4Pr7zk5uR/pYsS5G/D41focY
ayPE22iZB/jwXZTjDsJ0D2XoIRrHeW6MOsY2VsWOZbV/y+TbNNqWVaYFhWVJ
5VgxOJpGa93gqJvDy970Zqy8nQEHU/O4cXyy+vRZ6+Xz3Ven++8/3f/g6cHr
x3vPj1uHLdCWygtLuVIjbotoiSLkKKl/hNw/xoaPcRAQERqmxsO0uAnl7Jhi
akI1w0uIFAWta9GX3i4sHC9vPd3ZOz06OH24++y49XB3dXultlAs5sPVXHht
Pn6wlN+tJQ8Wco9Wqy92zlY6PdvdOFhrbi3Ul3LZSjRUCngasQCosesZ/3LE
vhDQ172qilO2HNZtpayLAW3JKS06JFmLwCvjyQgIxtQIeaxPgJoSYWY4sxM2
Pn057n+7tw4EzLcZ84HdNDQc4FqAI8B6+sQEfMENfi2pkjDNh/XRhm/TBm9w
Ju6aKFNOJlqDhRjICGC+p43iQXMBwJvxujIuByA37bTaJQIxEa1mkGthz6Pl
2kYmBt5WzyBaeXNhjSTvtuRc5oLHCr4L5p/DRulkaf5sreZq46BWWk5G0jaj
QywwcphOiTBq0JZ9XpAHjhrVp+tLL7fX3t9df9Faeby+8HC1sVnKgUljIZUG
bXolV9muLm+Wm63K3uHS8VK6mfdmk9agEDeH6B3iwJGricijRunFcvlxLXlU
Dq1FTHkzL6llSLlotYRst8oiKU+mnik0K5WNpeXdjbXtjc3d9dbu8sZ2tbGW
yjTc4YrBW1Jb8yJ9kqUMkiQulMQ2LTCe8cuWAXK72JIurrRfqBhX6GeNdpIz
yPHHJM6UypFWOzJKa1Kij/LUINQFKNIgCUgSJAF4QZNlubFzdiTwXLwJhjUj
iHYMzUlheBgsL4fjFwqCElFYpkpoNGm1MimRhFkgcv/dfMcxqh4srx/O6Zxi
3ZziXYIrLgHzpQVvMGI3aeFrZ5/GWi5AVBfGZVcmpbdnlN0IzTBU0wnX96EN
QyjlEJw/AKcPwchjM/jJKQx0Gg+dJo2PU7uHmW0jwgtQ7Tm4/aJhhaBeQEvm
Ybz8BDnWB/fcmXbcgIFkHuo4uyAo2ovzdQCEZ403oOpLY9LzvaJfdQt/2iX6
v7vk3xvQ/bdJ5w9QofeI0fvMxDQ7RuJHmMIgi+8jC7wIoW9S4h9lB3o5wR52
tIcZ7aBEb+MiVzGRy+jIFXLmDjZ8G+2+i7V34a2DNNuU0EfUJrjWBZl7VRNo
mYPbNu+m1b1u8216Q61QYjcV3Ygn1pPl3crKo5Xd09bJ64Nnbx+/eLr34tHO
s8PW073NV4d7bx8df3B09KzVOlxZWquXl+r5peVieSntjJk4ujmcEIlQ0GZl
FLiSBNeSp9WYMfnMqBwK+KV5GcKIWJ81euf9+dXC1nHryctnr968f/rq/ecv
Xzx58uhot9Vq1rfr5eOleVA/X7eWX60vnq4uPF1dfLax8mRr/dHmxsn6OgiN
i9lUNR5aTASXEt5qwJSziBNaVlBKDMmIVZdkN2vfSpqXAuqqW1a0CdMmtUfM
EaNnsH0dDMgwb3aSOtavpeKWo74PWysf7a7v5BM5q87EJIN91GQMfmJmqqdf
SCCceaherqEiebAByvAt6vBN1li7Fj/uZmM9PEpaK24lAk+rxbTb7dYo9QKu
WynPeRx5r9MlFwrxSL9asl1Ovdpc2qskqwFr0iiNaoVZqxJsZ2zqrF2znPAe
VNPHjdxBPXu0kH/YrOxU0vWIN27WgHewS3gepTRs0AABv96rFQ8XytuV7G4t
+3Bl/sV2cz2fqEf99WhwIZFoxBKg3m4VF1Yz8yuZ1Xq0EdT7NXQZBYIevnkP
MzAU02keL8wDeB/Ox7cz7q2kZdEjz2gZSTVFIcCoZWSTWeiLWqPFcLKRK6xW
G62VpdZyc31xcaVYXUjmqr5o2eTNqRxZiS7BlgepQgeaa57mGSa5umGOsu87
eDnibq64TyAblamndSac1U13+rmmsNAcERkifF2YowzMST1EkYcAepzQh+d7
sGw3muFEA/MlWREE8yzgF2/BkOxEmnuO7mEz3Fy6U8B0ClkuEc8vEQVFwgCP
56WCvD1ng+E1g7OS+yhOF4x1d4p1fUZwGaO9RnZdp4dvMBM3KOHLeN9FwO+E
6vyI6NKoqA0q7ZpVDQF+gQUjdQMI+QDgF8UaRVIn4XjIDAY6S4DNUiEQet8I
6xbgd1L9qxnLOc3yrKwOEZRGGNkBQrQT4W2f9d5GBe8R4t1zmWFGZoQc7kG7
bs9ar0O1F8Zk7/TyL/QKf9kj+WGP8r8P6v9hwvEvMN9PkP7rhNAQyTdLceFJ
NtzZvbLNEKZ9hOMeYvl72CHAbxc9do8YuYEKXUSEzsHDF/GJG9jwLVywgxIc
nPNBmB64yE9SRVmWhtjRlAPzDe04I/v++GEidZzLncyXHy/lwVGyU186Wt87
PXzywdNXH718+9mHn75/+uGTk2c7Ww/X1k43Wx/sHby/s/d0bWOv1lgrlxYK
uVolW64l46WQPWZWuqUEAx+rZ2OMLLSJDjMQJlUIYMEzWsSsFkk0kdgOjtwl
c8VclcXK3sHusydPT5+9evr4+ZOjR492dh9vbZ1urL+/uf5ha/3T3dbrteXj
amk7n93M57bK5Z16Y29pab+5sFkrrhSSy9lwPWrPOuRRDSMkJ3sEaA8PXjCx
WgnDdtK4FtKuhLWA4qWwp+K2+KQ8AQIqRE6xpkYByBoKdjUeeL5SB3lyKxPN
2/QJvcIv41s5NAVTIJ1jGwTCoFbjVYo0cyj+7CAb2kUeuMmFPnBy0HmT5Oy0
c9y7l46thr0WiURCpbKxKDWHmXJYFhKRos8R0MoaUc/DZgng2Yy7QCUHaoQs
S1HrStzdCFoXQrazayuqyf35xHYxslWKbBaizaSvHLTnPKaC1zYf8tRi/mrU
Vw37V7PxVjm7UUiuZMPrhchuLX20VCgFbBmnqRxwNZOJ1Uxup1w/rK9slxbX
cmthQ1iM52OHYVMdA+i+EZtQsF/OP1kqPaqn1+O2ulvZcEnLVm7OwKjauGY1
1aCmGc08R1AXyHoilXh6sVABU3NzPj+fTmR8objZG9XaoxJjmKsJMiR+Ks+B
oeugFOUwTT7AlPcypF0gOTOEHUxBJ5PfxRMOCqTjcjVca8QbrVS5Y07pOpPU
RRHZ8XwbmmtHcp0ojhPFsiNoVhjJNIPXQzH6KYx+5kxmPMFKJNvnyHYG0cLC
Gxg4HROvYxINjDkLg2GnM+x4uh1JtUJxmj6Y+A6G1w3n3oVxbyIk1wmmGzQf
CM/X52LXiOFLWN9FmPWM30HhhUHejTHhgynpAFT3AGbomdX0zYh7Znn9GM44
4HcGMwlBjE9jpwC/UEb/KPv2kPD8mPrdKcu7ssa4oDzIzPfQUg8Isfvo0F1c
9AEl3U9K9jLzI6zCKDnWg/a0z1qvAr8ekf28l3+pT/irPtmP+tT/NGz83rj9
+1PuH8E8F9H+HqwTirbA0Xo4UjOJ042QTX10Wy/D/4Ad6gLhmRa/QwhfRQYv
wIPvzYbPIaNXMJFbpGg3KzHBjcJ5QQzgVx6iG2u8s7sqrenCu67kcSz/pFR5
tlh9vlo/3Sofrlb2lpePtw+fP3r64enrj97/+NM3f/jsk89fPAeGu19fOKgv
PF5af7q8+XBhtVWstqq15UqpkI5GYu5g0hXK+0JFH9UqIVuFJLuA5OShbbQZ
PXZah0aasHgLgWajs60sroGjsihDEf98pbSyuHR88HhnY3e9sbxRWzxabJ6u
bbze2Hyzvv56pfmoUlqLRspOF+huOY+nEomCrLi1UF2fz68WU9/xW3CrQEjO
WbgVhyCjo1YdvK24dj2iWQkqN6OG7YS5GfEChLMWLWDTyCBxYROEwS63iA1e
P6xkHy+U15OheY91LREEShqUxVCyFE4kna6A7oxfE4ekJEA1JCiAV0+GpnWc
Ba9+OWDdy0QOC6n1qD9kMul4PD4Rp2TR41ZjMx1fyyUW4oHFuG/nzHnNfiU7
a1MsRizLcftWzreR8W3lAq18EIwbWf9K0r0QsZUDxnLAVPAZ8l5jLepuzWdB
Qn662QQh+XipulXKgDdsxL2bpQQgF9QKQDHYM203VPyu1XRquwhm3/VXmwen
q3vblW27yIzqnxm/04cbhtiFkq1s9v2N5cNSspXxV92qtJ6VN7ABvBULezOi
dprZFj3TaOZafUp30uHPh2LVdH6pnKqkw0m/w6Mz2kQ6O0floEvtJIEVy3Pi
GaZZonzk7IGAwi6qqIsm6gDw0nn36Lz7TE4ni9vLEwyLpVC5GqnS4QRGnNCE
F1nwZ88+M6HYJjjLMsuywZk2ON0CIxogGM0ESjWBUE8gNVCUdgqhR6OMeJyJ
hDVQURoqXE6GSckwCQEhJ+I1ZIqJTDPjaFY44Bev7Z+V3MUL+zD8DqSwHaO8
SbbenPOfJWdK5CIhdPE7fkeV5wYEF/s510b4HRDxwIyxB/A7o+qZEnaB/gv4
RVAmoMix0ekhCGoSRpn8P/hlVdo48w/YpQFGFsJKozgZPCuFpcWn+YUpbn6Y
neuZS9zF+9tglmtjyiuDkkt90v8yqPi/xrTfmzT845T5X2DWHyHs76DsVzH2
e2hLL9I4BNMOTKl6Ydo+nO3sMSW0EJMepTISaHpqjBy/jw1fQQTOz3ovYYL3
saFBQmSSEJ7ChyHYyBgxOU7NjsvzJO0809aUAf/NPEyUHldKjxYrx6vbHzzZ
/+D50euXh6fPjp48evLs6evXrz799ONff/rll2/evn325MnW8k41tZn3tQru
g7J3PWleS1jAEdhMB6M2s04kcWitxXgh7skaFFajxuz1uk0uvUDD4GhIPBOB
LJtiaxECHYavQkuVRKuFHw7o01F7I19Yma8WYtG0379SKe03l45Wll7ut46a
1UbM75bztHN4r5xTD9iWY66yW18PWPZKsf1CdClkbXiNVZcmZxRmdZyNkLEV
NuzGTEcpy3HSsh/V7YTUe0H1SsjSDJiKFllSLQhJmKY5tI4M9whom0nfatS1
GvW00qG9UmK/nAQ6qKT2F9OrhUA5ZJCTIXLSeMbICQixRtKomz5lwY9EeKiG
WbDpVj5MOZ/lfRseddHri5mMZj4vZtSVfe7D+WIz4i/ZdbvZUM2t94uoPh4h
q2HPW8TLXtVxzr2TtG6Dv1tIvxUx78ftG35j06leD1gWnIayTXc2k2TiR0v1
hxurh+uruyvNrbh/0WNfDXr2svHDQuaomN1OJ+Y9Dq9YFFars1ZrIxzdq1Sf
rW+cbmw9bK6sxWMaIm5upI/Se9fDQJ8Wfa8rvhd5+8O47mFSv2hj+zgzLh68
7JI046aKX6VX0HRymlZFBxU4HLWnCqFMJR4vR30pj9Iu46mZEiNXbRcqTCyR
hiLWkISWOboKi+dPoNgDGE43jvsAw7mDYd0kcm99JxLvDlV4ny7pYikGOKoR
mgZKUY0TFcM4xQBB1UfS99HMA3T78Jx1hGAcwOgGsboxtHoSJp+AyaaQKgRa
jsSpMAQNDqPCzIoRE7ypUfbkBBsyI5xFydAULZFponIsVI6ecPb0Q/ksTtGD
U93B6i/i7T8lBn5Ejv0bOfETUvQ9QqANYe2YUndMSu6Pcq4N0d+BcH+JUpxD
GNqQhruzyruT/DsTrA4oawDKHJugDveiOjtnbz5AXB2iXIPwr0GFFyCSX80o
f0UvtHPnewXVSUEFJSyRxGW6qETlFVCi8jQI1dxiFz15Gx+4PmM5P6J8t0/0
i0HFfx1R/8OE/ntQ0/cBvzOWH8Jtv0DaLqFtdzG2s0ty4PozhJHGAaJrjB6c
mgszmPE5dgZDz4wT4/fQoctw3xm/IKJjQ/348AQhAgUiRieoqUlabkKSwSuL
NPOC1LdpTR5FCw9L84+Wqg/X118c770+ffLxm1effvL644/ffPT2k08++fKL
z778+HPA78cvTl8cbB4u5rcK/vWMfTNtrXrlNZ9qIWw9WzJhNRrFYhVXYpBq
/ZaITe20m5x+v98bcttDJo1LzFDgWGoMU4HiqrASLVmuoum0bL9TXUj51mrV
jUa9kc2W4tHVUhHU6pO1pScbS0/WFrfLmazT4BQzvFI2IHcrG9zLR9bjnqNy
Yq8QPjtt5TOUrPKEmp3WsOp2WStqOkzZtkP6nYjuUcZ+lDCuusSLXlNWL3Fx
SA4OMaLg/F3cvFmxGnGm9JKoil/3WvbyMaD9QvxRLXe0nGtmPEmbVIQblWKH
IwqKiw034octxFEbcSzIhmfEpIKctmSV7IUthzF7yedN26xBjXIxFm7lUieN
ctVrS+llWaMsb5ZnDaKSSdxwqgC/ZZNwxadei5hWg/qNiGknbtuKWJse7YJD
s+jUFw3yklULUsFRo3K6tXa4vNjIpTJB/7zNGFeIM3rlSsizlYg0g96UTmVk
UCVo4E5kr1RacLt2K+WXm2efHT9sLs87bTI0XDA9qsVNF7V8wO/zvPNlwd7y
iJtWdlSIMJFHnNzZnJVf9MjjJr5BOWfUMG1mUdBvSGV8mVIkWYyEsn69Wysz
iyRGvsouBvxKdHN8JVGkPnv4IFmKQLGGYXPdCEYHht3xHb8Y1nU08xqWeR3H
asOxbxN598mCToqwGysewYgGUYJelLALKe7AKh7gNd1EfR/FNIjTDWA0Z4s0
/n9+EUo4ToHCq7GAX6zyjN8p/gyUNw2EVmCJWgLTPCd0sCVOltg2JzASuDo0
RTdE1neSLDdIrnfIof+gRH9Ejv6EEH4P47kON96FyO+OCe+MsK9+xy9S/h5M
e31G3TYtuz3Bax+ZuzNE6hgm9I6SBv7O761O+JUB0rUJ9lWI4OKU+FczinNz
2S5BbVzRxCmX6MoGV1HnyaoMSRknrcJE88Ocwn1a4irG9y7U/JMh5b/1in84
ovvemOF7k+Z/hFq/D7X+M9Tyg2nrT2DW83BrG9L2AGkZQJgHgTD2YbJ/khmb
ocWYzPQcp4Bn5CcJiXuI4OVZ//lZ32WE/zY60IsPjxGjEFIMSklOzmUmwT78
OEqaJenmBc4VQ2TbnznMVR4u1h9vrj073H/1/PTjtx9+8fnHn3/xyaeff/7p
Z1989vlnbz/9/O3HX3zw+u2Toycbje1KdCVpaUZ0RZuw5JSWPZqy15SyG51y
uZBMI88gVVydXmw0qkxqmUqhkFmcJoNby5RQWDIyQ4KX6ZgOt8phk2uVXLtO
mg4512vz65XyciFfTURriegeyPLbq49W6s/OTl7Vd8uJolMb1QpLDjWIfw9r
qYNC5Lgc380G14B3e/VxFcvNw4fEJL8Av+CUAUCyKnpew9iOGADIOeUc4Cgs
59hYBOC5ANt5p67mNmwmvIt+S0jG9grnKk7dRsK7HHaAmeFRLbNdCVeChrCO
rSFP6alTESnJy0U6aRDFdKcRM2jBj7nJ0AgXm5XR60bRdsDokYgcAo5bzN/O
px8vzD9ZrNQ81qxJGVPxQTxoJd17Wf9uxtP06uZtkmW/djPpqDhUNZem4dHl
dMK8XlKzawp6WcmiKVqA/9qbyRAovLVEOOv3JFz2kJSvI2EsdFLWoKq6LVmj
1sllCpEzEgxCRyP5ZKKqz3Ncm3+1sXayWF/LJH1CthA2aSQismp+K2gE89hh
VHMS0zaM9Khg1kjo1xIGPCJMysKNmrkuJc2i57isopBfl854SpVYthwNp32O
sFWo5YsNfI1TbglodC6JSEPlSnECJR6YL0EAnaH2ThLvTZFvw+Zuz87dgNGu
zlIvz1Iv/n28DKdeRdBuIOduoebuTDN6ppld08xOGKcDxu9AiO6j5Z1YZRdR
34/RDKDVgyA/YzRTCDkUJpsB/JI0OIqOQNUTCRo8SoYECMMlSKQMTdZTGCaa
wMmW+XgqP0/pZcnsNLGFyLJOMm39dEc7zXuBFvwZJfzvxOB/4HzvgsgK092e
lNwd57ePsK6PMc9PC86hFBdmlFcmxZcnBNcmObcHiDfvz1ztmLk9hOntR3Y+
mL599jgP7OWRuUsT3AtT4vMw2XlGblTSQBnWmYY1gXpRKK9xxWWaqIgSz0N5
pW56+iou9DOY8wcTpn8a1vzjoOp7k9Z/gtr/ZdoJ9M9Q+/chtn8+e6i35RfT
lquz1rtIex/KPgSEc49SwxBWcoaaYDBzDE6ZyChO45Ods8Grs/6LcP+1WW8b
0v8ARGhSbJKWnKKnoYzsBDM3zg3DRQmCMscy15TeVUdyJ1k+ri8+3tp+9ejw
9ctnH715BUrvJ59/8gmA98vffP7rzz8CFvzpVx+9+fTlk7MVuYuZzax7JWZa
DKiXgrqGX1dy6fIOQ0SvUc3RiJOT6FEEDUEV0vh0Ih2LxjGZTIFUSGVSiDQ8
V8x0ukz5fDyfivhtRqdOFbIY68lIOeKvxkM5jyNsUjdT4ZetldONhdO16get
pZfr1f1iZAnES59hJWzdTLiOS5EDUB4TjrWIpeZSAXjVmHETeUaGGPDysD4u
VoEY1OHGsxrmvEUYFhEiSkHaIM9b1MBn12LupaCtGbIflxMrYUfZrinb1Sth
O1DFoak6tJsxd9Ymi+m5UTUrKKPE5JSkkhoWYP3sWdF4u262TzXVpYP1++hI
N3XWjIF46WgNBS/BwLUk3FYqfLo0f7pUXvDbwJwAJoqdTABMNQeF0F4usBl3
bsRsB3n/ZtYfUnNdfKqVRZChIRYGLq4Uurk0r4DlFbF9UoFfIXLJhU6F0KdX
xR3moIyvIaF1FCzYCCuETh7dQMPL8Sgrh+6V8DNm3Voi/GSx+qxZ30hFsxa9
HAWRwceCfMqKWw1msFZAuWzjVnXUmBCkiF7RTLuaMOSSYP1aOoDXKqN4bLKg
T5tOukrlcHk+ns4HPRG70aMT63hKi8Ts0zqjRotXIdPReTI8X05gKkF4hkBJ
XaPoWyPoK2O4y+O486OYdyfw7wGN4341hgU6N469OIG7AnS2wJjSAaV3wthd
SEE3Wtp7dlt+9QBRN4xTD2E1YwTdNF43i1HDMSokVodjmchsyxzQnIFCUuNx
KjxBQyTpyEwzg2tnSbx8dUCoDQi0Po7CSZfZyHzXDNc1ynJ3MLxXaP5fkn0/
xrp+jLT9Em66PKO+BRHdGePcGmffgHAvz4ovopWXoZJLo7xzY+xLE6y2Xsz1
myPv3hq50jfbCdQF+J263Im4MEC8OM66BBVempZcYKQnpTW8YY1vWJV8x6+k
RBYU4JzcAD11Cxf8Bcz1L5OWf5g0/ReI6b9Czf8w4/rBrOcHcO8PYJ5/nnL+
d4jt+xDrv0LMP4EYz81YbiLtXRjXINY9RPSPzEUn2OkpSoZOL9KZFSK9NI1P
dSOibbDAFVjg2oz7Gtx7FxPsI8fG5lIQZg7Kyk4ys2PcAFwYwcoSNE1WYKlo
A01/drdUP17ZfH588OrZszdv33z6xedf/OY3X/3+9199/fWv//Dl57/59Wdf
/frTT7/48OXbx3vPNqtHjcRe0btfcO8XvBsJe9WjLTu0eZveKxXKSFhY99hM
7zhuAkGAYVEQBHoWg8eSEHAMHI4UCyWxUHipXFmZryxk0oVAIOWwlfzOtMOY
cZoCGqmBQ0maVMeN3Mv1+ou1+ffX51+tlJ820oDZvax3M25fDhqPC769tBPk
z7WQoeaQ2eizwuluOWJYAO1RokbFM/3UoXb+dK9PSCpZpUWLBMwtjYBzLRHc
L6UfNvI72chGwn9cSR4WY3u50HbSt50CudS14jeVTNK4nKUiTFpZiLCMWjLz
i0ZOhI9106Am7JBg6KZmpkc91aOd6TOix8RjXXPdt0TjPU4OVY2Ha4nIjZjv
ST37tJEDzr7gMwNtJjzLIRtIDnWfcTXmBPnheD7RTPrMfKoYC2PDxknDPVL0
jIVJFsIhlKE+PnzKQCfbBSw9myqn4tQsilXCzZg1fhk/pBTFdXIHn6EioVV/
x9kv4cY14orTAPr743r+uJKedxk9QgZn9IGROJVTsZoOWcPMq+joeTnOTh7S
Y7uFkDbOZJucMGTgwLQckJTQOpBbPOpY2JLLeAvFcDYfjCRcDp/B6FQZHEqz
R+0MGb0RkyOg1pm5UhVFJCfSZSgcZwJK7BhGXh9CXhpGXxhCvTuA/PkA8mf9
iJ/2wX7SO/PT3umf9828MzB7bnD2wjD27hihY4rWjeT24yTDZOUYRTtBNUD+
P6be8kmSK8H2/AfW7K3tvh17b7p3ZnpmeqYltdSSqlQqzMyqrEpmDGZm8PBg
jvAAj/BgZo5kpspiZmaUqsTQ896s7X7eG639sGbHrrm5JXiYxe+ec9z9ust8
RLGXIEHJ8iBHERTIAmJFSA7HYHtS60zr7WkjsFptWKUKQHCwddrTENdbUgYk
Z0GLVl/BDPh1JyFnTG5MUVv8JgfgVLsytVcc/zMv9BHT9yndfYBq6wDwTquO
4lRHyPojDMtBlm0/ybhvGt4zrTqAh44Ocw63j33eMbZ/kNo7ROvrJ3f2EI/0
UvcP8w/gVIcohsMU0yFFlQjaLrIFwrPWuaF1rEKWJaFhgSIr9QjzB1jJD8iR
35GC/xsl/L/TY3/HSv53Zu6P7MK/swv/ysz/EzX9e1L8/yRG/0AMf4gPfEaN
dLCT/YLsuCg/LS3hoAZJM0dRLsLQMqRaFSuXGeK5SX69l1U+ysi1UxOHGelO
Xq5fWp2AZwgAXngWBzcmtVmGPs8xFcWWEoTUzeGlYOlkdeHS+sqF7VM3r9x9
9hT47c8//Y+//vyfv/7wH798++tPP/71px9+/um7b398+/r9kzsvb555fHbl
3k7jwVb1/jrAKgWY2s4Gwdd1MeItIUa/Vi8hkEi9g8S+MeLQNHOaLmZKRCwp
jyZ06h3VVGlzZvnC6saN7e1r62vn5lv3TiynA82wK+cyhLTSjF0N/PHe5syz
U4sPN5u3l4t3l4oP18uPN6v3V4u35tL3FtK3ZxMXy4FzBd92AskahW7+tF9M
weR0v4zm5BGM9HGPmF51G3ZLUYDMufna6ZnybjV/dXn26bntByeXbyzVAb/P
Tq3cWa4BW7xYid9ZLNxbKm7GkATMNlEHQwpazsBf8mlnHPKQcMpN7deNHoH7
99sJPX7meJhH8LFwZvyQgzKZVPDjsDAgZUWUvIuV5O2l6t2V+m4ufKYcX0ug
Gxms6jVGdeI8ogMpZQcYfS21XEhEbDq7jG8UsPQcukcuBoKI0+KJESOLFtQq
UzZD2KT2qCQ+nSzu0M1FfbMRdC0b3cjH634k69DlnPqcTTsfQsC0uVuIXmpm
QZvYLUQKVtjBIcLjHXE5FRz5sldVNXFzGkpWTTKTOiyUYxpCm47WbZdOOSCy
UUY2wUyvVZaMu0DzrVcT9UaqXI1n86FExh9LoclCAChTwDJFXyKLhGImjx+2
uySwlSnUEGiSfqKgkyhoJ4qP4IUHpnh7hxkfDdI+6CP9qYfwp17iRwPkz0bo
X46zDuJ4/STxIAMeF5oJcoSq8jHUGEMVYCgxugylyXxMVUiojsm1cbUxbbAW
rf6iLVB2YGXEm7dZkwZDTKOPaI0xvTVtdGYtYCf4Aaxg9ma0SOvFEFJtjKiO
TsDRPijeIY/uE4c+46CfMJyfkc1fEHVt01DbmOTQhPwQUX2QajhANX4xDX8+
qfh8QrZvSnJ4kHGgc2Jv5/iBfsKJQVL3APF4N6Gti9Ra149TtpG07UTtIUlp
CqqTtXMs7RxHP8PTz3LgGlleHGHHj7Die+ixD+iRf6JHf8eI/zcALzv19+zi
h5zSB5zyvzGLf6Bmf0dK/p4Q+0dC9N/woU+osSPc7ICoOCmt4OU1gmqWpF2k
QCuwYkkpXxLJl1jSJaJwdpRT6WLkjlLih+ipDm6uW1Yd1czgdHMEAK+yOqZO
0zQZpjrNghM8XUrmKFtiS/HSdn321PLmxVNX79198ebrH77/9def/udfv/+P
n7/55Zdf/+cvv/z11x9/+uWbd9+9fPzm3tWnlzYfnpq/v1W/s1a8sZAB5Q4I
FL2T2dBKxL1dykQNGiWFzBgawXcNMMZIai5kkpk1Aq1L7cj5E5uVmSur67e3
t+7vbDw4uQkq54VGFpjUXMgxF7BXXNr5oO1yM3lnpXRjNnOlEbveTNxdzDxa
Kz7ZKD/drDxdLTxezt1oRC6V/Gfz6BJmLNlkNSc8h5lmMUvJqQW8pEDVBcG4
ljo/Uzg9Wz1ZK26WshcWG49Ot5Y5XFsGR958urt0fa54thC+VI3dXy7dW8qf
y/oWPNoYxKxaJTkdt2YR5zVslDHkovRBvfsAv6q+A3Z8b0xIjopoYRE9oxKV
jZCdOooJSAWT9OZs5tZ87tZ8YTcfBIa+kwsBflNmhZGNRySMjFNTxaz1oD0f
8MYQq1cPu1RyVAP5dbBDKlJSiHYh3y0ThXVwxmHKOo0Zh6HgMTVCSC3kboY8
K+kw4HclE9zMRzdyodmAYz3tB//iVDF8qhACbbrqUIEQIuw/rBo+6OeOJRXE
soEdlU4i9C6UNwCN7dPgj6hJR3WsAZNoQi+aVglwWgXNYRb5wAwTduYyWL4Q
yuYCqbQvlfFn8v50zpfJo7m8L511xZO2SNjo96s8HrnByYOMFAE0xpL1MeRd
DEUnWQoQ/nKM89kw85N+6p97SB/1kz4dZeyf5naQRN0UyThTiRMZqJCTrUZ5
OoyvDfDgAFeFceQoS+HjwiGJIQGbMgZn2eGb8cdq7kTDG2t6Q1W3O2s1x3XG
qAbIljI6MiY3QDhn9KQ1SAyyhsQmH08VmoZCo8pQvzJ8XB46LMP2C1x7OLYv
aboDVFB75e1j4oOTskNkbRvNeISs+3JM+vGE5LNx0Z4RzpcDlP3d0we7Jo50
jbf347r68Md7cEe6CF8Osg5Oy48S1O3AhUXFIWllVFGZkBVbkhbGBal+Zvgo
NXCAFvqCFf2UHf+Ik/x3dvKfWYl/YCf+gVP6iFv+kFv5gFX6Z1ru96TU3xPj
/0CI/ish/DE9eURQGJRWpwC8ygYJRGLdElW1CsuXZNIFgWyRLV9iSObxvOoQ
I9dJiR+hJ9q52eOtS8Czk7oZHFxrrWhQpUiqJEUZp8lDNEWIq0+pfHVPaiWz
fmX71PUL1+7fefLi9Tfvf/zlx//xnz/930C//vU/AcK//vzLL99/88PbF28f
3Hhy6eT93UUQBW8s5W8u5h+uVZ9uNe8tly6UI1sJ9+lKdCXtq/ntPkgmwRFE
0yQjX+GUG11KsxsyZ13YqfrM7Y2NGyvzN1ZmH+0sf3Vx4+5qdTvjP5nzX2ok
1iKOGY8OZOOL5RAw2Su18M1m7NZM/M5c4uFy9tlG6fVO5dV2+d58/EolcLUa
OpPzbiacO1kfaMcXG5mdfKTkMebdxqUUtllIzCcDc8noeimz2yxfWZm/s7Vy
aaF2rpm/uz5zb73ZSs6VeIu7ufTlUuhSCQPOvhm27cTtRT2/oOXkIEaQOx7l
T5nGO2zTxwXtnyh7DwQ5uJScnYVBKOXayBP6qeMxGWUNM7zYrN9dzN2YSe+k
vOcqsUvNNAgAEYNEMtUnIww6pSxMJw0a5KhJE7CaEDVkkoocKoVTqdSyOQoK
2SYWAZADamXeZQXANoNI1WepoOZGxFvGnBUfaOXO2ajnZDnZ+owu3SxmWww7
liPO+YAZwAsyg2qik3z4I2XfXivumIvalVbgUc6AamSfmXhUMrxHMr5fhmuD
aD0Qa1DCHBYwR2RCnEbFspoVqMcQj7oyKV866QHK59ByKZCI23JpVzHvyaad
8agxgmmCPiXmlbtRidnBUekIEnhUoOrnQj1UaRtOsB8n+nKSv2+EtWeQtgfA
C9oxTTbAgce4KpJIR4dsPJ1XbA7KTCG5IShuvXnBz1d4AcI8dVBmSGhsWTNa
c0cWwqmmJzPrz8xh0QaK5m22uN4QUevDsCWhtyb1jpTOmWydubIERTovW+1i
KLBxBTYKBQagYJcq2Cn3tUucRwSWdo6+g63tIiuPTYvb8PIjDP0xpvkY1XBw
mP/huPCzMX7rOPtI+/oJR3qm2jtHDvdOHe/Fdfbg2k7g9g8wDk3Lj+Hhjinl
IV76KDfVwU50MGNtjGg7I9zGCHW0FG7jRNq4sUPs6D5m6BNm+ENu4kNh5iNW
/uPWSxPqn/Cqf6Ln/5GY/O/46O+JsT+SY58yUm2AX3kdB89StQsMzQIVCJiv
ZFYknuHLAMLzLGENz8oNMNNdrPQxQalLWu1TVPvVjVH93LSmNiFJ9ysTeChJ
lEWIfBQnxuj6lNJVtqMVdPbU/MkbZ+89f/TVN99+/93PP33/17/+8J//18//
z/c///XHn/7600+/gAj93ZtXbx7efXrt/KML23d35q8vla/MZoFRPtls3F3O
A+JOpgC/vsuzsasLWfA1K7psAbUKU2nDemvEYEuanWWPbz2durZQf7A1/wDE
49XS0+06yMa3FjJnCv6tJAIi8WbMthwwnM56zmTcu0nHTtx2KuUEtD5czLzY
KH91svZoOX17JgKIvr+YubeUfbBWerIzc3ulAtLySspf9JrzLnMziq7k4muF
ZDmAruSTq4XURjFzplFaz8VWUoHLs63AuRpzbSW8lyrR2/OZZ+vVp+ul6/XI
rWbyTNo761SmlYy0nJpXMbNySoQ36aMPKbr3QX0HzZPdkq6D/M79mokeC3EM
YJ6QU04lHDdqkYtF//liAHyKKzOplZhrI+OL6SV2EUVNn4Do44BfLywE/GpF
HDmTphPydAKBmEwWEQgwgxkxm1IOax6xAX4LLmPZa5oJ2OZCtoK7tQSjjNrr
QWfZ2yK64jYmjLKqW1dywEW7MmeUeIV4aPyYZPCweuqEenifcfKwnXjMST5u
wrerxw8oRr4UD38hHN0vwR0VE09w8F1c6oCMP61S0GEly2KSu5yaUMCSSXoK
WbSS81fyaC2P1oveUsaZiRjimDriU4RRedAjDbglLkRgt7GMJorGgFfqx8Sa
QRZ0gipvJ0kOEyRH8KI2gugYVdrHVo2K9QS5iaayCiGbUGUX6NxSEwa4UxqD
rau3Ki8fRgUwJtFHYXvWhFZdgRlfeD6UnfMBhFNNNDXjC1Zc9oQewAv8F8Br
imnMUZU1ChlDErWbpbRTIAdV7h+DsFF1aEQXGTVGR0yRMVNwzIxNQrZhqXmE
o+6jyDspUCfb1M02HSdpDgF4p8RfTPC+7CV+1jX1+QCxbZjc1Y87DtQ91X58
+lA36dAQt31KcYyoPk7SHWcnDzBi+8jBz/C+j/HeTwjop2T/l7RAW+t6bqyn
pehxfqyNHz8gTH0pzuznlfcKa1+Im5/zax/Rc38gJn4H8vP/n19Fnaieo2sX
mJp5OgBZNisV1YXCmkDWFMqafH6RxEoPMxLdnGyXuNyjqPVCtT64MaRrTMDl
cUl6UJ6cVqQI4sgU3zchwkjqpNheMrrLzvJ2Zfnc2sU7Vx69ePbV199+9/6n
H9//+tM3f/3hl/8A+unnX3/47vtv3759+/jhi1vXn109d3Nr+epSDYBwY7H4
cLP+aKNybSZxKodupI0nCw5A8W7RD1JxxW1O6NWYSp4ymwp2S9Pn3spGQF+7
t1F9sFG5t14A2fj2fOpaIwrc9lIleLkc2I7ZZl3Qsl+7gumAwMZ6wHA27boz
E3+2VgT++3a39mqr+ng1/3i18HSz9mi9dmOhcH2hBHL4ahor+6xZt7mMuRpR
P1AzFljNJVeyidl4YCbsawbcCzH0VCm+nvRVEf2C33Klnni4Wnm0Vn60XLwz
m77eTN1fKFzIYyWDyM+ZDHInQ7wpD6UfIfaA/KwbbTeMHaMf/Ij4xZ9Uw8cQ
xtRGQAd0pxm7UsJOJuwXCr6tuHMj7qggMEDMJaboWVMaxoSBgw8YJIiSjZk1
OiFHRMYJSXj25CR5cJA9Pg4xGHkvmvcggN8CYq6jtvmwE/SIpt/gV4swWJSx
a0GkAdGi6NQlDHI3CPCwIARxwipuFGK7uDh4+gRA2Ejqh/q/0I4cNE22G6c7
tJNHFMMHhP17OX17OYNfinGdCvqgkjOplpDNWr7NLANC7JDfq4+F7fmku5L1
1nLeet4zk3eX46ZcSJtC5VFEFHEKwRhFwCjEXGLUwUPsLJuNZrQRYPOESNsP
EGbBXWy4l6Pu52lGhfppQK7awTO6JEaPyuBWGD1Kiw+2BmALBulRGewRa1Cx
2ifW+uXGqBrJWXw1d6CJBmd8uVlfsuGO1xCQokGEdmXMloQOwGuOaw1RSB9R
GsNyHSZUIHSZjSSzEWS+YVVgTBeeMkfxjjgJiVGQCMUVpJvdZK2DIDWMctV9
PEO/0DbEtXSTNG0Twj0Twi+HGXtPTP/lxORnwH+HSJ19050D+BN9+GM9xPY+
2uEhftuEooOgab2rhZXYT418No1+MOb4w6j9nyeRD4noF3R/mzA+JIiNCCKj
otiwJDkky/TKsp2y3DFJrV3WPCJt7BdUPmHm/khO/CMx+gdS9N/Jkc8YiXZh
flhZI2lmmaBQq2cYqgZFUhUIClwgWUUoLQv4GRozPsGMDYhyA/JKn6re3+K3
OgBXRpSFEWlqWJkG/E5JYlM8bJznn1ZEWIas0p43JpZilc3KxsXNa/dvPXv1
+v2777//5ufv3v/yzQ8/f/PDj999/+M333z37s3bV0+ePL9759mNq7d3twDC
V5ZrV+dL99brT0/O3lzM7mS9yzHNYgReiujXEtaNJLIQsuesqoCSl9DLshZV
3WtaT3jOVUI3FlP3NwqPtsvARq/VQufz3otF381mFAh47gyiqNkkdbu04ZBV
reKKRTTnhgAd4CcBxS+3q292G0/Wig9XC89PNu+ulls1sBjdzoUX474Sakk5
DRmXpYA6Cj5n3muvh9GlZLgR9Kbt+pLHvBzzrcTRps+a0Epqbh1orM93Zh+t
Ve8uFkCQPleMXaomFnxGUGzlA4ethN4AZ8JLHwQRWnLiM/XQYdNkp/D4HnHP
fg9rIqlkrmPac2nnvdnYbtwOphoQwnfTrhoC+aRkv4Kup48BAQtGVdyYWe5R
st0qiYZN4eNGGSMDxN5ufHc3f3raJBKFjKao2ZCyGktu61LUs5UJrMSdDa8u
a9XE9YqMRV12GUqIvu41gyMvOjRxjTiiEkRgXkzVWg+lI/RDEyfU0z3qoYP6
sTYTrtNEOK6b7oQm2sWjhwXDhzX0YZOQ4FSxEZ0AMUoQi8xplluAd7s0IVSf
CFlzcUc5Ya8mbY2kdSZlyfuVKbcoamEH9DSgsIkJtmNWTswlBop4xUEf3+tl
WREybB4T6waE+iGpZQJyEjUIQ+vimNximw9yBTTukAkICRucIb0jqDP7Ia1L
Ajn4Or9cg0oBv5aoxl2wBeqeYMPrr7uzsx4Ab7hij1Zd4ZrLX3K68lZHzmxK
aHURpSYs1YbEsI8jdVJEVoLYhpeiQ4BfQ5TgTNJ9aX4wJQrFxcGYGA0IHG6m
1kpQmCcU9ikZMsk19xNUbURF24TgQB/5087Jj09M7QX+C/jtxx8bIB4foHYO
Mo4OcTtGRe0Tqg6C/hjFdoKTOMyIfEn0fzLp+rcJ5I/T7j9T0H0MrFMYGxeE
pwQhnCSOU2Zx6uKECnhrtgtqAh1XNI6IK3vYmQ+o8T+QI/9CCn0AHJwZ6xBl
R6AKWdNgaupsuEZXlimiHJufZgpTPElWDMRLMLlRIi8xriiNq2rD2uYAXOtV
lnpluT5ZekiaGlUVpqHctDQ5wQuOsv2j/CBRHuPqkgovmPEW4nOn5s/ePH/3
8cNXr9+CFvzD97++//4HIJCpAb9fv3339uWr14+evnrw8NGVy48vnr+1s3Zl
qXF7Y+bp6eVbK8WtLLqRMK9E9HN+VdMD1V3KikOWNQoTGg4mJcdgVtEqnfPp
tpKOi9Xg3eXM0+0KaLWAytNpBITkSyX/1WrwTMa1FjQseOFFVD3vUQGECwYe
ENgGCINQDeowIPfhagmY/rPtGcDvuWp8NmifwewgdqYd2oRFk7Drch5LyY9k
HIYG5topplaSobRNU3Qamn5HyqQsOrRJg2wes4P2/ersyvOd+dsLxfOl6FrC
10AtQQXXQhv38PAVk2jOqSgb+A5iN+BX2bfPTuhCaINxGblulZaNwrpFuBUy
XCx4QEgAx9w6+LA5AtFgfLeJPmxmjSMiYlTHz7vUBbcmrBcCP7WI6ErqFG98
iNzXRe7tkRCIdqlMz+WgsDLntNb9yGLEDeL3jM+Qs0gyZsgv5/hk7DBo3FpJ
wa6Z8dtmUGvWBKUNcqCUXhaQc0y0SeVkn3y8x07uc1IH3MxRL3fCzZ1ycibA
MehZEz41x6cH6V3iMUodepFFIzSq+XoVF3Wqgh51zK9LB/SZgDaPqUp+qILJ
s05O3EwLqvGoYhxVTARgXEhHjBjIKac47ZFm/bJ0SBYNCj0o0+TEQ+YJuWkM
dpJMfo49JHEGIASDvQG9P2Txx+1AvpgFjZoBwsCF/8avQI+2+NVjCltcByAN
z3qDTbev6kg2kEjZihXMWMkaqrsA1GgVARXPkjHo4ypNRKYJiyGMK3FRxcBe
ERLwXzgwaYlSPSlBKKtIZDSptC6V1EbCSi/KtzioOidR5yWrPDiOaWBa0c7W
D0yJ2rqIgN+/dOP2DZDaB8mdA6RjAN5h1okxQdeE9PgEdAynP0q2dzG9vexo
JzPSTgvtJ2N7SP7PqP4vaP7DdN9xYWxKGCaKo1RFiqEt0g1Voq46pi73wjOD
qmavstEpqRzg5j6hxf+NFPojAfuAiH1OC7XzEsOyPBkqM4DkBao0RxYlGIIo
EEeSEEsSUmGUJ04ylTmKporXNcb0s0Pqep8se0IY7xLFB6TJMXUFpyxNyTIT
/Ogw0z/IQEcFQbIiLjDntKFZf32nBiz4zNUL127dfvL05Vdff/fuu++BAMLf
fvfTt9/8+B7sef31+xdvn925+/L27QcXz13fXL61vfT47OqtjcZ2KXQy4wEC
AbLhhpJadlBOikDUlJ7pFU2EFOSMgVt1yhYD+pMZ1/XZ5MP1Mmi1N2ph4L/g
m38u5zmbdQOQQecFLgxo3YnbN8LmeQ/ccMhXMP25nHc37TlbxH773UdbjXtr
lZtLpZtLlaq3lS2TFihmVMbMUMqmK3lt9bBnJe7fLSZuLjfOVjPAv3I2ddYK
u0V0wG/NYzqZD9/fmHl5du31+Y3bS9WViDuiU7plHK+UVXJqdzPY2bx/PWRq
2mUB/oRqYJ+853PzVIeHOVA2cJe9qoqZXzYKllEN6L/gaFcDIJBrShaxmTbA
79unJvT4ZZS4nld2QfMRc92nLzihslsfM8lsAopocpDYdZTUfVwwNallswC/
wH8bAbQGMoNdk7MoMiZRUssNQwIHh+TiU8FGTC1OGxR5CwzGKCyKayRgI21U
RWAJwqcbqNNa0kRQSAyLyVEZLa7iJDX8hE4U1YlDOpFfJ/JqRHYVz6xk6+Vs
nYJtVgvseonPqQy6VTEvnEBVSbc05RRk7NysnRXR4oLKcVTc7xb0eEQDmHw0
Ak/FtfiUmZd1iAqorBCUp0LiAADWTTU4CWobzuihI2GJL6HG4iYsYsZCFixo
80dt/r/B6wkbnZjWjKr0LrkGEeu8MhCkjUHIlTYFa0h0xhtuIL6qDcAbKJp8
OaOvYAb7gzMeX8MN+LUWjIa0RhNXaGNSVYgvQ1vPXlOgdDk2pA5OWWMMNCmO
pjWplDGXsuQS5mRYE/RLXG6OA2VYMYbaS+KahwnQcZ55dELY3on7y9HJT7sJ
B/uJbX3kowDeEXbXuLAXD/WTtL0kczfF0c3y9/PDQ4xAHzPUw4qcYEU72OEj
jMBhmq+d4jkOnFcUpsoTHE2Oa6yyzU2SqTlmaPRrmmOamRG42auodYiKe9mp
j6nhD4j+Dwno5xR/Ozs8KEzgJGmqNEMTpyiiJBn8EX6AxsfYoqBIHJRKwhIo
JTZUBKYmzTQzbZod1dT6xKlj7GAHL9wHbBeqTMqLY5LsKC8+RMf6Kd5+bhCn
THBNeVVwzlfeLgELXtxZ2djduXDl6p0Hj5+9evnizdvXX7/7+t13X7/7/qu3
37599f7ti69e3H/y4u7DJ9eu3Tl76s7pzXtn1q9vNs8007vpyIVS8nwpvhy0
pjRcr2DSL56Kw+SQHBdTkbIGdsUumUW1GzEEmN2N2cKtRhTw21IjcqUSAEa8
FbUAZreiVjCuRyybMdtK0DiPaoCvnS/6T+ew3Tx2oRa7tVS4tVS62EidryUu
z+TmQo6K25iyqgDCWYeu6DU3Qshi0n+hnrm+UL6z2gAbSxE3CJ8A27RJCVxs
JeYFO++sNR+fXHp5buPmcm024MB0Si8sBUn7ZCF6bb4I/t1ywAAI9XFGZX17
eJ0fSLs/0YwfSEGEFRSasYvSaiZI+xthE5iCtmPWpgvKGwVGSh+3Z6+W0JU0
cAt2SR2FV+LWpl/T8KmbqD5tlti5RNFoF627gzPUJyPiNEyGRSiIW001zJ21
G6IaUcogqTqVIMCULbBPQHMwcG4e2cunBaWclEaa0MqzJrhg1ZYcprxVH9Mo
vFKeg8eyc5kxOTuu4CRU/LROmjNDwK+zDg3IJFEb7DcoHLDQrOQa5WyjkosY
ZAGnNuCCoh41gDftVaacoqSFFdeTEzqCT9jj4Z1AWEedzA4v70RA0h9VjiXg
yYSGmTbx8ogoi4oTfkEAZbu9DLuXZvPSnQGBP6GKZM3JHBJPIeGIMxCwuwK6
3+TwayweCHThlrxKvUdmwpT2uA7NWwCnoboTq9jQktGX0/vzBm9e78kb0Yod
a7jQutNeMlsKRn1ao04o4KhEGebL/Sw5xlCFOVBoVBOatkborSf2xNTxqDEd
seTClkxQF/bLfD4BGuYjEZ4OpQjt40zjENsw1rptY/KTzum9vaTDvaQ2AO8Y
twcvHybBwzTjKNM+yvQMcQKD/OggKLl0/xgzMMKJDHFjfbzoCXboGA3tpCDd
TO84DyPL4mx1lqMr0fTVKUNj0NDsNszgDDMTwDe1M11QtU2U28uKfkLx/4Xg
+pzsaWP4+jiBcUGEKIySgFobPjLPQ+G6GAKPQIBKWmtsswrHjNI2y7LM4c1z
Y9p6vzDRQfcdYWM90uSUtDgMqrEwO8hLDjFC/VQfmGRw6pzA0TSEl7HSTmHm
1Mz8ztLq7ubZy5dv3Ll779HDh0+fgEb86qv3wI7fvvnu1cv3L599/fLRq5cP
nj69fQcE6TtnT17bWrqwXD09lzuTzVwo5s/mU0sBR0YnxMQETDIdVeGBAMUZ
PQvY04xHtxZxn85GLpYz16uha39bd3BvIXVrJgb8F2C7GjAs+nUzbtWcVw3w
WfDpaw5l0wWvha27+WDr6kwjBcg9W4mB5ruTC21mA0CAPlASK6h5Nowsxr2r
6dbV0kv1zM2F8o350qVm9mIjA2ryZjpwMh8BY+v+h2Ls2kL17vrcw+2l64u1
tWRgJhmaS4a3q7lbm3MPtueuz2fPl4Ogm/t4Y5Kez2iH/sDr+Hf9+IG8lrLk
lWbVZB9/qmIRg4SwBfpvwFB3Kqp2mY05rBhvBy5ctIqLDmndq9pIOWYx7ULI
kDcL42q2k4dTE4dh4pieRTGymTCdYuJzQlp1ymaIGhQpo7yJGlfClgVM17Tr
PCyieqxXNd6rnhyw0qbDch7gd97vXgyhs35PzmoMKKUuIa8liSAu50Xk3KiC
l4DFKQMEinPSrIla1DG71m+AnGqJDRZYIB6QUy8F/IZdLfNNo3DGI085+DED
BfhsRDHs4R5zMdsd9EN22kGE0YZyOzFBT0DcF1dSU1pWxsxNObgxhB3wslAf
yxvgeMN8b1QaSKmTeUe+5MvlsWjUHfBbrR7I5lWB0YTIdXYJEODX5FOZfEpH
VOvP2YIVZ7Bi95VN7rwOyWqQhArN6tDC325yLpjdFZuzYjXnDaacXpNUKiMS
BYA3yJH4mbIAE46w4ci4Nowzh1qzB4q1bueO+YwpnyHugYMeKYYK/CEREuJq
PGSxY4pvn6BqhgYYh9pBeCYfGGIeG2R0jvN6qRBox0SuDc91TQn8k6LIhCgx
xk8M8eL9TAzPDuJ40UlBckQQ7+dGehj+Lpq7j2gbZHpw4ggDSjFVWSJcGFGX
u7S1TuMMwTg7bZofM8wBLz4uKx7kJvbQAp/hkT1E12GqpxckXjY2xQ0QeEEi
kMBL5CIktp3KcXL4LrEUkxpzsGte45jj2ReIlvlxwK8gDhz/INPXBfgVZvu4
mV5eqvWWcGa4jxYAdBN0ZbFv2ZHYCFVOFRbOLYAIffrK+et3b9978uTBk8dP
XjwH/vvuux+/+/6Xb7/99d3XP3795vs3z796+ejly3uPnt68eevszpnlxnYj
t9PInCvWzmRz6+FgzWFMqYVhOSWsICZhYkQ+FYFwCTUN2FPTrV8Le05l4meL
mdvNGOC3dWJqLgH4BS4GnBdEVuC5sx541qNZ9Btm3OqcSZQxCMp2+W4hdH2h
cHulAmwXwHu+ljpVjq0kvLulKKiNDZ91PurezId3K4lT1eTZRubKTAY03JuL
xVuLlcdb81dm84D3i39bPNiqmXH/xWbht/WDlxcqu5VUNYwtZGOnZyv3dlae
n994cnL+cj26GjYW9Gz12H764X8Wdf8ZZfbOu0RNO8+Eb3OyRis2aQNRgqmm
bJWATwdGA7nXRO1DuGMVh7RoFdU8yu0sMh/ULUdNWQM3reVElCxUysSUAj8k
NXEY/IlRi5CHwVDEACcMyqrbsBZHlkPmgkXUdGgwAcVOmQQUoyBFy7hZPVQ0
awC/8wFP3eOMalROPsfMYSAioV+piMh5ISkH2HRQIYiqpTGdMqxXglBhk/IM
QqZWyDBIOS3/lbMdGhFmg4NOecytSqMQaLUJGzuiIQQVI4BTv+A4yu5AaIcc
lANACO2w42+KychxmJo0sOJWVtjOCLqZIEL7w/xATIrF5aFki99C2Z8vBOJR
t89jAdiaXQqjU6aziWGzQG0RgvwMUrQtqPakTJEKEqm7A2WbK6e1p1S2pMIW
kbuzWl/RiOQNjrzeWTTbiiZDRqtLqRVRqSTElwY4kgBL7KNJMQYUZWtik7oI
3hSk2Xx8l0eOuTURlz7m0gXtCr9dgLq5aEBgx1gqhCC0TQidOIp6uJdx8Bju
80Fm+6Sgd4LfR1aMC2w0uYct8dJFPqIkhJcmcNL0OD8xwI52MTw9bOBxwVFJ
eAJIgI2yPQMMZz/F2s1yDYqDU8oUSZ2jqQt0IFWB5iyxXFWWs0ozlyb1+SFV
5rg4eoiJfk60f0S0fkKx7GVY27iOPqFzUuIkiu0khYUrs7DFFpbIyhC7WMqQ
0JhX2ppq+6wSWW49VVKeGWX521nYQXGsXZ46Kkh8zo18zgjspXr303xH2cF+
UXxKniGhq1rPnCa27l682ti5tb11aff8zdsPX7z7+tnrb15+BfTu+Ztvnr/9
4fX7n96+/+HVm3dPnr19+PD13Tsvbl99dPXstZ3VrZnibDaykcdWM+h82Fpx
q7IWIQjMJTOnbuMBzToFc4iwYecDrfiVZ3OO6w0M6EzWvpuyXK54r9eD54qe
3YzjdA45W0RP5dwbcSvwLKDFsLHpUwMvA+H5UiNxd7X8cLMORmDEO1lsNe4+
XYqcKUd3C61Fwb/dOXl1oXhxJntnLX97NXdrJX9vo/xwu3Z/s3Z9MXehntxM
++YCdkAKiNA3l6q3lhqPt5dXor6CXb0Qsl+eyVyfz58qBE4Xg2txRwxmWRlD
0/v/hXX8L8L+vfM+1XrUiHAGXdyhkJiaUfNzWmFBL6xaZGmY42ZNWMh9ERk5
qWIUDLyaTTLnhlYw3VrQAApyw6UA/PrEeBt7XEsZVE73qogDOuakmjamJo9Y
ONNxvWDWb1yOWJeChnm/NmfTxnXSgJIXhPgpvaxoU5fsmrxFBep5xgyF1RKX
TGDkMbUchlUq9uu1mF6QdEJRq8IhZxp4ZKuEaxKylTSSgkqEGXQdh63jsYCM
Qq5DKUIB1w4J6ldHw/qwT4HZuT492QtPeuSDLuFxp6Ddxt1vZu/Vsz7VMv6s
ZnwAZOUOuKTjQS0hZqUlnPSUl5nFuNmIqJSC0nFlNKKKxk2JjDeW8WNx1BlA
NBaVzqbUIFLYw1egTBB6gW/Kw6CvaS05k6vgxEpopIyGck5PRGdDZa6QxhWF
PQnIk5Z5c1Igd16G5JSQl6NEhQqPWGTnCqwssZOpQFlwgKsLcMwBgQMVOWxC
t1kSsMnDdpnfzrMYCUYb3ujBG3xEPUpSI0SlGS/V4aZEXVOiE5PC4xPiTpzi
BEXXx3WOC32TIj/Ac1KWmFJkppXZKUlqlBcB5ttF9xxj+U5wA72i0IAw2HqU
OtPVS3N04w3HqLY+rn9CFierskxNgaMpcYFsRZajzLCVqabilCY3CGW7RNHD
gF+C7UOC+S8E016y8TDD3M02D/PMk1zjlNTIFOppHC2ZqSfy7TR5gG/IKSx1
lWMOcizIjXWWODHM9LWxfYcEoTaAsDC2hxX8jOz+C86+B28/QEO7+JFxWZKg
K/GQpiq+4WleKKxfXdm9ee7q/Qf3nr/57qt3P7z7BozfvHzz/sXrb1+9/e7l
2/fPX7x/+vSrR4/e3Lv76u71Z9cv3T23c35tFiC8EEfmY87ZoLmOasqIvGIX
NRHxvFuy7FNsBFXbEc16EAbwgvFU2nqp7LlW999oBgDFYPtc3nkq6wT8nkzb
zxXRCxUMCIB8poCeBRsV7FQRvdqM35hL3VsuPd1qPtude7TVABEXJOors9mb
S6Ubi+XWqoFy7HwjfX2pfGsV0Jq6sZS+vVp4sFV9stt8uN24sZQH/C5HkYxZ
GYR4q3H08kz+2nzp5mK9ibaIXkt4tjL++YC16lID1dzwjFcDwvDYnn/gdH2m
mmxbCmgAvwBeA6kzCbEyam5Oywf8lk0SoKJRkNfzcjpu1SoG5C6i6r/B29IK
pgFmHVZSW6eFGSMm5piONgqwVVFGBOMnlPgBKxcX0/HrHvUCZmi4IRC/Abxh
WNg6BS1hYjJ2COJEIW4Y4kf/ttMjYXtkfK9S7IFlAYMmZrfGbPKgUeKBuXY5
0yJhmYQsNYsiI+NhJlXNpms4DJhFgxgUDZdmkfLcapnLA4VDxmTcmghoQk4h
ZqR7VVNu2ZBT2OXgdVg5h4zsL3Ssz1XUjyWEPwqm/qChnDBz+1FoMmKmpBFm
3scphoXluKycVmWTqkRcE0uYowkHFkUQzG5xmdVmmcYh03ukWn/rRQDKIEMZ
aT3V2ZLX2AoWdxEB/AYLbl/S4gqo7R6pDeTqgNwRljrjIiQhQNJ8R1poS4kh
P0fhFYgdXI6RxjKQ+NbW6wPUQY4hJLCFJU5M7kbkPrsi5IBCDjnqENjMJJOT
CPjVowSNl6By4OUWvMyAI0r7iPI+snKAph5kGkd4jgkpSlAEScooUZkgKNNE
ZXpalpoURodYgW5QdRmefUzvAY6/jevv4Pg6me5OmuM42Xocpz9KtPSxPJOi
MFWZ4sB5kbogBjJkaOY8w1ik6PJTcHZYnunlR47QvHsJjk/xls9whr0E3QGy
7hhN10fXjTA0ozwNkaacJEhHiMpRpokoC3A0WZmxonDOqy1NEZQlcwK9NHc7
y3uEiwEd4gU+p3s+xZn/PKr786h+D8F+lO0fEkWn5AmSaxZK7Xgrp5MLl2bP
3Dl/8+nD28+fv/v69bfffPX9+3fffPX2PWi/X331/Zu371+8/PrpkzcP77+8
fePp9SuPLp+7dXrz4sb86fkq4Hcx4VqOO5ei1qWIaTWs34zqT8YNuwnjhZzt
atl1qYiA7Y2Qej2s3Yq19l+voTfqGLDgtZDmZNIMKAb+eybvutoI3lpI3pxP
XJ+N3V5M3VvJ3l/NPVxt3fJxZyH9eL3y+sz8m7MLj9Zr1+Yyl5vpW8tlkKvP
VZMgTq8m0d9W+l+eBQ03fWet+Phk4/mZuccnZ26tFC8108B/Ab8BJXctgf5t
LVLpdCmetaiWo26AdtEBR9X8uLalpJ7f9Kjh6c6eD/4r+8SnVnrfWsSwETMF
ZdNafEfFLC0aRA27chaBQRGu2aQL3tZlr1mXErjtdsy6GTH+Bu9qQLuIqvJm
sVdM1JH7gfkCWh0CspGDA+Yrme61cPBBmJuxSMGMAZwX9OiEmgGcF1Nw/VKW
R0jz8EluHhGMXgHZK6Y6uSQnn4Iq+SB1R0zakEkTMukiFnnIJI3aoLTbELbA
FjFHySAqaCRguAYBR81jKpgkGZ2g4lLMcp5LK/F4NZGwJRO3J4P6iEsaMLFQ
GI9IR5zifjv/uJnXbua1GXmHVMwv+LgPaSP/yB/eryB0WPmDwIJTTlYRE5TD
kkpCXk3DpYw2lzIkEsZA2OhCdSYHrLVCSqtA65IYAlJDWKiJsuDWa1C4+qzU
WtAiJZu35PIXPGjS4QrqHR6lFZGaXVKLR2L1CWwhnj3KtSc41gTPmhQBq5W5
ORwzlarBUTSTLNO01EvVRjiWqBSJQWhUi/m1Ia8u5tFH3LAfETmdTIuHYkQJ
WhSv8uCUDpzMjJMYcCztGEc/wTdNi+x4uZuk8JGVAYoqRDFkGNoMFU6TlIlp
UWSEg/XQPJ1kpIPq/hPN8xHd+wnD+znd/SUNOUSxtxFtnWR7DxUZZXnxghBL
lhAqUzJ5WiZLyaEEWZ2haLIUZWYSRF9pup8X6QRZl4jsw9v24oxf4vSHiLqj
ZG0PRdMPwjxZNjIl7BvhdU1KBxgm3P/Hb0lubUDqPJsfGqe5uihIB9PTARBm
eQ6z3J9SbZ9M6T8eVX8yrvkCZ+6gu/p42KgoPG0q8bFFQ2LNW9hKLF1YPHPn
4qWHt548v/Pq7ZOv3r949x6A/PaH79//8M3X3371+qtnT14/vP/01rWHly/c
OXvyxs7qxdXZMws1kJ/Xc/6NjHc9hWykWk4KcvKFvONsxnq56LxZB6j6zufs
gN9FnxJoFhEBL96KaIFBL3ikWxH9haILmPKVKnprPvZwLftgNXN/JftwvfB4
swT0CtjoSv7ufPLBUubZRvnZVvXeSuFaM3VjIXdvrXZntXq2kliMukC3PVtN
3dmcvTqbvLGQubdWenqy+eL03NOTs/fWKjcWCqAXL4UdM6jlYi39YH3mciO3
GESSOtmZchzAG4Z5aaM0Z5FlzdKYhuPmT0tHDnf+63/hdn/u4Y8B/51DoShE
1BOPVa0SoNWAYTtmm3O3rlYveGEA70bYcDrtOJtFtqKmlQAMtIyp5r3ypFHk
4OPkk93i8eMwddQmJCMShkNEs4soCaOs7NaWEFUFgZoeVckqCivIrfuslLyA
nBOUMQNSBiam+IQkL59gY4xbmJNuATWiEWfsrXc2Ja36qEWbcmlLAWsj5ikF
7AGj0izhmCVcJyw1SXl6ERviUqUMvIQxpeCRjBDbaRAjDlXAZ4wHLXFMH0GU
IavAr6W5lVNOybCF321gd+o4RzX8Ywr2ITb+L4ShfyV1fswd/lJD6/LIJ+NW
RgEVVELiUkRST8G1rL6UNSUTeh+msSIKrUWiNklkdqbGxzfHRaa0QJ9ia1IM
fZ5nLsotBdhZtHqKiDflcIaMFrfSYpdYHOLW6JSY3XyLj2MNsawxljXBsaWE
2jBP6mGwzQSabpKqHWOZgW8StTGWPalGM6ZQyhaO2OOYNeG3Rrxan1uKeLkW
lKbzEWDvtNw1JbNPSi2tlwLLbCS5nax0UpVuKozS1BgNwihKjGhIMbVJqiqK
lwTHud4+OtJJdRyl2DvIyO8prn8ku/6FjPyJgnxCcu4jOw+TnMCXRxjeKRZK
4gc44rhEllRKE5AkrhRHydI4GQRacWJSlBgRJAdBiab52gnIAZxt/6ThwJTu
8JS6Awcfxym7puRdI7zjg+yjg9xjk/J+pg0vC3LVGak2J1XnBIIQiWTvw5mO
Em1Hac4OOtLBQNpo1k8pps8Jhs9xAF7dEZKlk+7oY7uHON5BATqmjJKteYm3
ao7NB2dOzezePnvz6cUHr289f3f/1btHr98//frdi7dvnr96/ujNk4cv7999
cvMq4Pfuud2bJ9eubi5dWpk900icrEQ2s+ha0rmWsG0lLKcztnNZG/DZ08m/
WXDFc7nkallwRAesedEjmXHwm3beglu8hMrXAipA+u2Z0MOV5LPN3Mud4vOd
8ouTlden669O1Z5tl15vFZ+vZR8vpR8sJh8spO8vpm/Pp27Opm7N51pBuhpf
DCM5O5yxqGbDyKlq8tpc6uZi9l7rHunG81Ozv0Xu++vVR1szoDufLoYvVFOX
G9ntdKDuNjY8pouNTETNT5tkyxFn3irPmCRxLVcyfITX+8XxP/6voP+6uCN1
RJo3ceMwGVRggCoAFvjs6TQCDLfplM4gAGHoTMYJGj2Yi8DHXPTJlzEl0JxH
ElLzjMwJ5kAb7ugeen8bTBt3yVlBnThqkJW8hiZmLjmggkVSc8jLNnEKpoGq
C2aSuFaY0gqyelFaywvJqF4+zkIdcrAmwwo2KOwNn7WOORqYqxny1CLOZtyb
9ZocCh7MJpvEbEQtc2sVchZJQsdxyeMswhCLPChkjakkJD1Et5qkXgcMnCvk
gQG/MackZOFgOioinzCLBtTcExCnU87tFDLbKLi948MfEo5+zOzbqyAcc4jG
ogZazs0vByTlsKyWVFWzmmJGH4+pPT652S7SWgUai1DqpqiCTFOabylwjAWm
Lk83FLjmktSUg2wZozNlcYTMFo/GaJWZzGKzVQRGo5mvtzH1TpoepZhDVEuC
aUsLTEmhws/i20kcG4HrwAmcOAVGNiTZ7qwlUHBGc+54wpMKu1MhJOo3oh6F
yy+0Ygytn6DwTkld4xLHpNQ6LbXi1S4GjNBhhKr20HU+hi7I0AZoMEaCAgQl
Ni1BR3nOfob1BNXcQbEepdk7CY6/Izj+G97xO4LjnwnOjyjufTRvBx3tZfnH
6b5pOgryLVsUE0uSEJAopmydUo4QeVE8OzTGjo5w4yOsSD81cALvasfZ2yZN
h8c0h8ZU7cPStkHB4T7uoW7GgT724RHRcYJ2hIuQpQGOLMoD4ngJBPPAMNQ2
Ah/BGdpJFlC3j9HsR6nGPVTjl1TDQarxKM3cxbD0Mex9TEc/29VPs51gO/pB
FzCnpWjNVt7Jbd/ZuvR098aLczeeX7j2+Py1hxduPbh06+6V69fP371x5d61
y/cun7934eztMzuA3+uby1fXF66vli/OZ0+VQ5sZ92/+eyZrB/xuR3WrfsUa
pjyTtgB+QYq+WHIDk70MvDioWvJKf2vHmyH4VNIEPPrlVu71bvnNqcqrkyUw
fn2mCRAG/L5YTb1cS79czT5ZTj2YT9ybjwMjBqH6zlLuYj0OqmvOqvJIGQ4+
JaQVV1DzxXoUWPDt5fzDzSqw4Oen5gHCwIXfXli9v16/UEsATtfi7q20D4xX
Z/Lna6m8DVoI2XfzwaReGFQyQxBDNtpOPPynjj/8L7j9/2Km9jTdAC5hwyWp
OoQXi74rFT/w2e2YGYTkspmf1dGBz4I6f73hu1hC1kLwAipbBZ/RL687eE4J
TUEYmj66t+vTfxnY/zF3vMcmYYaMioQVKnr0Va++6ITKdnnTrQQzQ80mqnv0
rXUKFnnFpmwgqrpdllazAiJ8AqIn1ZySRT7rNS4EWksv54LOxYg3iejiDg0C
CVRMvIZLtUFCYLts3AgDN0SfHqRM9ZKnu2nEHhZjUMAbFQvHjDq+wyTx2GQ+
qxiziUJ2fsjCap3F0uEdqgmTfFgjG1BKB4S8E2TK4cmpvcQTnzIGvpTgjpp4
IwEdGfBbCcqqUUUtAZWTqmwcioYUbo/AbOfpgGwCaZAIxSj6HN1UZpgqtNal
0gJIqjx9QmKIwMaAVu9W661Kg0lmNEmsFolJL9Jp2bCWAhmmVbYpkH5NMaot
zbEXJOowW+ylSFCqzE+V+0nqKMWa5/iKznDJmygGEiksGUWTIVfEb3Z7FQ5M
aAowYYwgQyfE7nGRa0LsmJLYcRqEATspKidF46Yb/ExjkKnH6LCPLLSOCGxD
fFs/09RN0XWQdR10cyfb3j1t/T+mLX83Zfn7KdsfCM4/U70HQS9mh0e5ERwz
QKD5iEyMzovwBDEBLyzgBLjsIJETIjKD0zT/GDU4zIyOMWMj1NAAxd9LcHdP
2Ton9MeGoY5e4YFjjD2HiX/poO7p4R6aUPXRbdN8L5WH0tluCgMhjME9PaLD
x7h7+0QHAO9T2naCoYNiOc4wHGIYjjANxxjGLpa5j20d4tgHOc4BgWeQ7+nj
ufqF3lFtgh2at9bP5Zavz63dbGzcmFm50pg/U10+09i6sHL28s6Fi7uXL5y+
Aci9cO7u+TN3Tm3f3F69ur54eWX2zlbj2krpQjNxuhw4XfKdK3qAB4H8DLAF
kDZs3FUMamXpkutqzXdrNvRgDrtZdV3MWM+kTEDnMpYrJeRmw/96p/DuTPXd
uQagGBgx0POtPBgfz4WfLsSeLSeeLMbuz0XvzsXuLaTuL+daCyjmMpspNGuB
7HySlj7pVXCKbsNmynW6iAGE76+Xn+3OvDi98PLMIhDg9+5qeTePAZNdCNpA
nAZ2/PLM8qVm9mQ+uJXxr8ZcRbsyrGIj/Gk9qY/TvWf4098Bfi203u2kdTmo
3YwbdzO2m83w49Us4HcF04A6XzSxg5LJBVRxqQxaAHoub18JKBdQKRibiCAJ
EwwcvGCid+jgX4588A9dn3/AGOkyCeg+jTiglUT00oxVAfJz64wZiOIuRd0u
BvCWnao6op5HdUuYfhHV1GySvJaz4G6xXLJIq05l1aUuO9XAiIEwndSnkQJ+
gf+6YIkDFitYRNJwF3BeLnWMxxjjc8ZFogmJZEIqHRfLxvUww6RlmrV0k5ps
hQlODc4OA2yHbPCIRT1i0o4bdOOwZlSkGKDzj+MYR/Dde6h9X3DHjsCMXg+E
Tzm45YC0FoOqMagQUyRCrUuuNoRtsDO0NqbWwZLF8YoUAc6R9BWyqU4zVGia
LBWKMtQRoconVTmkkFmqNkoNJrnFJLeZZRadRKfmQBBBBo/JjKNqz6Q5TrPn
ud66UpfgyjGaMshQhRlwmGpI0d1VAVb2RCtYshgC/MYjvnjYE8TMLhSyYQLg
rcBVZf5JsXdM7J6UIFNiB64Fr4MMpHFR9F66xkOW26ZaD5FW97J0vWxDD0N7
gqLuoGqOsk3dAvvApPl3E6bfj5v/acLy73hkz2/3UPET04I0hR0l0wJ4BkZk
BcmcIIXhI1DcU8wgHojmnyCio2T/KD0ywYiNU8MjzMgkNTBK8gxNWXtH4M4u
wcFD1M/2TX8Ixm4hcNghtofM89FYLjLZMoXTj57gtbVR9x4mf3qcvW9IcmRc
eXRa00kydrGNRwG8TMMJlqGPYxriWEZ49hGBc0jkHVAERyS+AY6jCwrhIyvm
6vlY+Uy8sBsu7ITTq1hi3p9djC6crJ++vHnl+rmrV87fvnbpwbUrj65cfHj+
9O2T69fWFwC/AN5LC7lz9diZSvBsBbtQRs8XEOC/IDav+ORlI2PGKQReDBD+
refem/E9XgyB8XzWCuAFBfnhYuT+QuT92drPVxd+vb4CEH6ynnkAgF3PAITv
N7AHzeD9meC9ZuB2I3ijHrxeD1+tRy6WQzspL3ArVMqUTHSz+9rV1PGwTjLv
128mnJfr0QdrpZenZt+cWfpNT7eaVxvJlZAtpuIsB/9fnt4zKK5r0db98er9
eXXP3W+fc3byDva2LW9btiVLQkIBBCLnBhronHPOeXVcnXPO3eSccxAIhEAi
CVAOzt625bjvPbde3d9vYr96VaNmzaZFCaT+1hhjrbnWND+a7dsbybxcGd2b
6Hm0OLyQ9vY7tbNxO0izenKTkdzkYLeJmq/92n+3+/0LceNMWLOYMADbPRiO
gJA86hJv5G3DDmFUilqMaQG5AOG1jHHCKx51CcDYZaB6uPUqGprZWg2ct+j0
GzWXPmAga/U8ik3GMfLIsIDsVbCyFhnov11mQUbLSmnoSZ0AHGGGXdqZkGn+
ZE2aYcannXSrRu2yTi0rJiXFFdSsngd6egoSxrX8vFOfgNURoxKUX7tCcHLN
l08zADsWkJVislpBhXRMgxmIrjOR1XqCQo5Wy1FKCVImqJfza5SCKhm3RMi8
LGBeFgmKFfIqubZBom1kyWsJ/PIOVnFb5Ucd1eeJTYUCXLlJ1B41MfI+UW9E
2pdQ5CLisJ/jcNAMVrLaQlDBJAVMkmRwkgxGlseoe3H6QZKujyxPE0728/Wz
pHaeyMCTaPgqrUivl5iNUsCvVSc1qLkKBUGkaJFALWp3hzlJdvRyAmNKQ5Yr
DZBkQbIqQtVEKaYM3TskDPX6Yn2hZFckngjEwp5oyOkPmO0eucHPUQcB7Fhx
oEPgRfJdSL69Q2hDqa1EFQx+NpzKTgASGzto0mo0p5gqq6IpaxjqOpqqiiwv
JykqmFA9H0agLO82ql+vVbzRZv6IEqgAeZiV7OCkcLwcmZej8jIUVhTQ2opz
1OHt1QRHNcndRnC2YuyN7bZ6lKMR60WQQm3UKIoexwFRghicoxWhqa7gFV2j
nL+E/xBM6iRl7VAj2Yahu4gA3iZJbRmj+Cr2wmX02WL8+Ur65XpeUaOgqEVS
2q4op2krwBEGHGrYxpZfH+zJNjXxbU1Cd6PE30A1FuG0hZoELr1o7rzpTszZ
QxOWyKQ9Me3OzoX7F3OTq0Mrm7N37q4dH+29fPLgs8cPX+zvPN68dbS6sDs/
8cuGYvm7k533xrNbw/FbPb7llAV8toHnAv8FhK4mIFByfzlPpVlNm1eSxrt5
6+Gw/8lU7MFY6GDQezwafDqT/GQp/+3m0A87kz/tTX+9OfxsPnt/JLo/Gj2c
SABy7+Zt21n78Ujk+UzuaCSx3eO/3eXbGU4spt19Dg3gl4Mow1y/wG+rCah4
c1EbgBS0Y0AowPP+RPbFytATkKWXBsC3TAROljmBCQD8VqcPvHt/uv94buBg
qmd3LL89lJyKwBkDP6FmKlHlhOvvgf7r5iLHvIpfzpDb5mPQzaRlLW0FXQD8
LgNWXq+ZDdLypE+6ENX0w+xhB2/KLwWxGagfZkWkSHZbLabyau3FD6ovvo+8
Uchqa9SwyXYZ36US+IAF68VRvSisZLsFOJjeaiDV2zg4kOFBDR9wKOYipvWs
cy1pmwtqh20gzIj6zIIcxAGN2MpAWlkov4QS08u8Sh4soOo5ZKOABkvZNhUf
1ghMGo5ezdBp6Hojy+oU2D0Cs5MFwRSzhWwy4Y16FKRpVsurpcLrQt5lPqeA
yfiQL7osUpbylTeYqnKqshwluN5AL0DWF7TWn8MgLnEI5WYZOmpj5/yifEjU
l1blErJwkAs7yVoLTmpGy2C83E6kBpqEGbR2kKofomj7icpOgjiO43sJTBOB
qaXQJGSmkCZTCsyg9Ti0DpsS1kqMGp5SSZSqO9TWDkuU7OhkWLuYzkGhc0Bq
6RJq40x1mGpOsZxdfG+vINLjC+Y8waQrEvUC/40EHR4vZPGI1W661IuXBFHS
KFoew8tCOIEDxTG1suUNUkOHwU3VuygCCInnlWE518miCraqgamqp8lrqLJq
lrpeYGoFYusaMdaLzdDZJugcyn6dEmliplDcLInfSRf3soVdDAAyJYDA2Mvb
TVc6TJfRpkIsXIux1LSZKpGmyjZrHcaFIPg7KGEsOYIjh7AEHwZlb23RN9Qq
KqrEZRXCUjBp0tZ2mFpxNhTO0tGqaqpkl14nXrnUca6w/WwRDvB7rY5T0sAr
aRKWIGUVDH39ifPqETxTO9+M5hiQXFOL0IYQ2KqFriqOtUToqbH30gJjUme/
yNYthrukxqzY1qmOjXsAv9O3xm7vrh4/Onj65MGLxw+eHx4A/wX8PtpYub88
c2dy4Ff/vT0YB/67knfNxwygDPabWQthNYAXJOTlmA7MTy4ndTlA/wWG+3gy
+nI+/Xw2BcgFtRfEZsDs9/cmft6f+df+/Kt7U6D5PpnPP5rNPp7LHQ5FVpOW
Gb96JWb5pXsGdwajoPxu9kSAXYLqCrNwpMrLzZfe4zVXRtSCMa9+1ANt98f3
R7PAc/fH0k8X+0/ufZjvBfNf77bYHgivZByzUdNWf2i9N7EzlgcW/HJt8vHi
IOjUQx5NWEaRtZXSKs6Km69FZPhRj3w2AgH/HXFLgP9udrp2B4JzIR1Izm42
AkToSZ98yi/rs7BGnIKZoBxQDPjtNtJ8PIQE1wwQxlZdqy388MbZU/VXzzPb
G/V8ukctAQhbxQw9C6sgNqsITUY60sHHwSyMV0yNazh5s2jYrZwO6meD0IRb
DhAec8kGYFGXiQecOq5ipCAuSAtJvTSs4oPuYBczbBKmVco0SRmQmBpwqt02
qdnEgwxMrZGis1D0VpreQTfZCGYYZzC36fQNGk2lQl4kERcKxef4knNizVWp
oVSoL2PrQWArxyhLEYLCjo6r7W2XMO2XWdQKnRwVsLPSAVE2Is0n5ZmENBTh
23x0rQMvtWKFNozQiWNEkMIsXtVH0wzQ1D1kZZ4siRK5LhJRhSLLCFQhmSWi
yzQii1XldOl+4VcG/Fcux0tU7Wobypamuns5zgGub0zmH1O7B5RwTgin+a5O
cahfHumXhTqdwawzlHSGoy4Ab9BvcbhVBqdAbMEKnWhhoEMaxwB+pUEs8F/g
ViIdUgy1AfHVzSRhZQejCM0C/FaxlI1MRQNdVsdQNggMbTLw8xvbwbzDWoS0
FLVbS7G+emocTU8T2Xk6v5sj6ufx8jSQijHOilb9JYT6g1bN6Xbt6Vb1tRbV
VYTqGkJd1AzdaLfUol0teF8HIYAlBPBYLwblQCFhZKupBajNgmw2NYOXKBuq
w9yGUDdVcSuKiFcuoy9cRJ4tbD93g1BYxyxt5Nxo5JQ28ktbJZUMI4JuQLCN
SD6M4ZlQLKiFq0cI4Xq2oZRtvMYyX5X7q00ZtCLUxrHVnxR/F07kJhkS4uS4
f3Stf/nu3O6Duy8+fvrxy+cfP3z06N69o9sbDzdWH99eOVyZ3p4e2JvtvTOW
XesNr3R6l7IOkDNBGQT8TvtkSxE1SMh3Om23cydntEB4fjSdPB4LP5tNgbb7
2UrXl+sDr7bHgOf+tDv7w96JvtuZ/ufW5GfrI8+X+x7Pdz2Yyd3pCYDPcB8s
/nU59GrOA2Lw8Wwv8MrlrL/PqbVzifSaIkzJeQ2ptcepmwlZFmL2w/H8w+me
z29NHk3kjifzu0MJ8L0LMctSwrrZ7d/uC00FoG6TYMR9cv0XlN+Tp9/kg6B4
dlqkWaPAwe6QtF5nVJ2Tt5UAfk8WpTglY17ZqEc6bJeOOqUjDklYhFG0Fumx
FTkddTqgBL/1gJUz6hL+etp52MHvNTPC4raEWW7hkxiIChChQX5uK7/GRiGU
DKKQ0C4ho2UUlBCLAAVZ2FGnpbXbhGS3mBZScZOQEFhwl1k0YJOCXjxkk8yH
oWm/dtKrHvepQVnutogBv0kdB6RoYN8+CcMjoXsUbL9O4NOLPXqxDeLBBp5B
z9boaEotSWOiGJzMk5M8NpzeitbD7Xpzk85Uo9GXqqAipe6y0nRNYy1VOsol
9kqerYpprSGaKjDaGyROFZ52A0cpYbKqVap2j50ZD4syCXkmqYgnJcGE0B5h
6/wUsRvHd2G4bgw7SZTkGYoelqqXqe5mKLIMYYDMggloUTtBiCcLaGwpRwlJ
YYfG5lSZYLFZK9UoOBIxTqhAqhxoZ47hHxH5x8SRGU1s1hidMoWGoGC/Nj6o
Tw8bssP6QNYSysDhBByO2AC8bqfOYhNrbSwWhOTYWgX+9hN+49hf+QX+q7Bi
uJomkrAcYIukXgHCckqpkhpALlPRxFY1C6B20I5VdpLIgKJJ61vgIqT9BspT
iwshSQksNUWmZRnsTjYzx6TFCTgPos1c2qQ61yR/r0X2DlJ+qlF8pkF0tk74
Ua3ofJ3sSqO6FGGoaTE3olwdGA8W68Fj3Di0CwsE5ngfscONPfmKA9diQNZI
aotp1y9jCws7Ci4izxWhLlVRrjdxKxC8csAvglfWBvg1t9BNzSxTB8+MZes7
GKpGkPl5oKobbvBMxWzDJY7pMt92gw5dJyiLGIZKGtSqDLCCA5behfT81uS9
h1uPnj94/vzp5x9/Avh9vLNzvHn7+NbK0er8/uIY4Hd/rg/4762+COB3Oee8
mbHeTJlW4hDovMtRzXrauNPnBtruduwPB0Ew/vU60ac3e7641f/N9sRPB/P/
Olz8cX/hu905QO4na0PPbg48Xel/tNhzOJPbHT+BdCIED7qh8aAFtNTVrvDm
QPLeaA5oJR/s/6X/ittqeIhyJ598skISlo979Zvd4bv98RdLwzuD8c3u4ErK
uZKygzoJEN7s8W31BaaCOmBknUbugNswHoKXsv6MQcxHlMhR1SDKGkiN7NqL
2GvvMCo/MpFrg2JMWkvrt/GB/wJ+E3KyjdqkaitVt98AFANbnPAoANSgC484
RaAXj7lFE14J8OJuI73boQVUkmqLqs+9U33hNLryOgfdLCJj5Ayiik3RcWla
DkXHIRl5VKecE4QkgPesVZ13aHKwPG0U5gz8vJHXbeaPeVVAAN4xj7rffnKz
YUzNDCsYJ7daC0kws8NAbYM5eJeM4YeEAYtUycUqRXiFjKhQkVQ6stpI1sAU
nY2mhjFqGK2ztuttrQZ7o8FRY3BUGJzlBncZ5K1Ueysl7iqBu4brrme4GiiO
Bi7URpc3koTVDFGdXNthd9LCYWEyKU9llLGMwp+WWuN8dZghDpL4ISIvRBRm
efIugbpPpO0XaXuEyjSX66aQtDiUAE0UUugStkAl0piVFqfW5FBojRyDSqSU
MgUiDFfeonCgHHlmaFwamlLE5wzZJUdu0Z2ddufGnd3jrr4xR++wLZwxRNOm
SMIUCZv8HshhlxthvhqmsfWtXEeLMNgmS2AUCZwijJd5cBIHBvDLVNR1MK62
kC8CeFHMYqKggiFvpIhrOeoWqQmvslG0TrraThNCGLoU0WC+0uoux4WbSIkO
cppEztDIGQY5zcKHiVgvqt3a2KorQcguNArfa+C+2cD+Wz3nrVr229WsdyrZ
75ZzzlQKL1VKiiplZfW6eoSppd2Fw/rJhBCNGKaTIgxylE6KMsEE56G0mDoq
RbXXyNcvoQsvtV+8hCwowV6pY5S1Cmua+VX1rJIm7o02cTUTRjLhdjaM5liw
TF0bRVYPmjtbUy62VGh8NTJHKRMqYEGFbMN1pqGMD9crPPToiHV4NTu22rO4
NfPo4+Mvvvr05fMXX3zy6edPX3x89ODpzr0H6zf3l6bvzQ/vzA8ezPfvzvRs
jaTWegKA35NlVP3eo9HQbr/n1zNU93pd+4M+8PJgJPR4JgWC8cuV3s9uDX61
Of5qZ/bnw+Wf7i99A+C9N/Px+sijhb7j+Z7HywNPVk6eWHt/pnOlJz6fC81m
AmByezh3b6wbaGeie70/ORX/5eKRgKLGNymxDR4Rpdeh6TSIhhxq4MLTQfPx
ZNfecPJgNH0wmnwy172ctA275CcIeFVdJk5UTvAJOrqs6mGfEfALqrSR2uri
4wEXemID+caHjWf+1Fbwughx2UiqcXFag2IU0LhblVLSXEykndYclRCBIc6H
Db0mfifEHIAFw3YxsOYpv2ImqAIg91k4CWCIMrqK0Iy6UVB36X1U5TUpBQPL
BR5IZVVJIBFHw6VBAqZdIQwYlFFYl3MZOl2GvFOXsSrjkAAQGlbQ4ipar0V0
co3JpQTwdpqAO/NBVOhxKBNyipeHtlCatYRGHRmhByDz8AYh0SClqiVEmQQP
oqlcTZBpCEIVmiNFgo8r8BqQeCEn2uBEGl2NRneNwVVp8lXrvFVKT5XEWyvw
1HO9CLYfyQ2iJD4Cz9bB1DWzNQhQJM0uqi8iiKRkqW5tpFPlzcnMyZP9AUUx
uiDBEKZZspxC06szDkHmIZ2xT61KS9l2OlaOwwgJJDGTrRCKdTLIroP9BpNL
rrZw1HKeXMrgizEcRYvM1g5nacB8Ab/JBVPnTU//zWj/QnhwJjwyHR4ZDw4N
u5Od+kT2ZNFXJASFvBqXXWaGeRobRWpDCz3t4nCHPI5RJ/CaOFkToqj9ZB7U
TBJXtDGuAGG4pQRhBUVSB45IZHG9yIjVe9gmPw9ys5RWmkiP56g6auALrd4S
fLKJksdQuyjUTiYxzcREKM1OVAvc2gjVNClKGwQFtaz3qsivl+H+VEt7rZr6
5wrK325Q3rhOPVVMf7+Idf4a53Ix/3q5qrYZRmMDNHKMQ0tyaRk+ED0roiX5
hCCrzYKrkzffYFZcwxdfQV+5jrlaRSlD8hvQUgRSUAP4Bf6LktXxPFieBy/y
kkVOMseIpika6YoaHlQlMZcbgw2Qr0psviq0FIttFWJrrcyJiA7BY2uZua3B
idX+m3fmXn7+/PvvX335+VdfffLFl08/+fTBoxf7ew9vr+wtTewsDB0sn1w/
ur8wsDfVeXsgcrPTvd7pBD4Lii3Q4bB/p9cJyD0cCYLY/GAyDsz301vDX92Z
+PbeDID3u4PFH49WwPjV9uwX2zMv18cAtk9XRz+9M/PF3fnPtmZfrE/cmRxa
H+1bHepeH+3Zmhrcnx+5vzh2uDCyPpiZTXmBu4UUHDsXb+PgwgpWj0016TMD
eEdc2qyOv9EZ3OoNH45nny/27Q7FJgNawO9sxDAZUHca2X4hSk+oyhhlWZMU
gN9tVeZM4lG/oRcc0slNtIqPms/9BVX4pqTlKuAXuLAOVyZtveLnYoN8fFJO
z6rZPUb+tF8HlNUwwiJcnxnwCwK2eDaonfKpug3slJKcMwmjGraR0cFqLiPX
FfOxzaD8An6NUr5exIckAotK5jXogrA+YIG8Rk3Uog6b5GGDLKIXB9Rcj5jk
4mM9QnxSwxhyKRYS8GLSOhbQ9zkUOYsEGHRKQYpLiBExPiwhhuTUgILulFHN
YrIL4hmUNLkIB6KpTEVUQmSpjihS4zRurtbF1rkYkIuoc7RrHQitrVZlr9S5
q+XOcrGjXOSq4XsbOd5WXggtipMUCbo4SOQ7UXy4HTCi99IcEZ4vKY516wKd
akdeDqV40jgTwMvPsPh5jiJvgPph65jLPuawDFh0aS0PBCMVjSBh0OR8jlom
Nar1Lj0cNBg9MpWVq5By5AqWSIHjqJBiKxJKEj3DguCkPLNs61kLDq+nxm5m
xxcyUzPpqYnExEioa8CU7dInE5p4WBMLaEJepcMtMLroGi9RGkCJQm2yGFqb
IuqTNH2ErvWRacoavKgMwy8BI1laA0STNTAUTRxNm8pBs4SFcFii93BVVqbE
QBZo8WWm9xt9V7CpOnJXB7WXQulmoOKUJjeqUt9UpaqrEN2o5F2tYhZUUT6o
xL5Z1v7XasK/VxL+owz/u+u4PxXhXr9MPHWZ/MEl6rmrnGulsppGSwfKTycl
ALxCRk7MzIvIKSExxsMGGCgHpUWPbZC31nDqKmgVdfTqNgGCpEZTIQxWjmgV
VnVIa8n6FmWSqUpydEm+JsqTOik8PZKvb1bATTL45L9M4ypTOkrVrkqJtUIC
V0MB1NBifGQ5PbbcObs+une89dXXn3/33Xdff/7Nly+/fHn05OHdHdB/76/O
31sYuzc/uL/y//G7P911dzS5ORC6OxC4Pxp+PBX/eDH38ULm6XT8wXjk0WTs
xXzm4+Wul0udX92dBsD+dHwTkPvD4fJ391f+uTP/6ebk51uzn2xOA3K/2ln8
9mgd6Ivd5Zd3Zu/NT2/NTNwaH1gb6bs12rc5MXhncmBrond7vHe1Oz4asgIA
vWKqW0CKqdndVvlsyDYfcYAU7eMTAMjzUXg14743ENno9AJyb3d7H85k7vR6
x33KnJ7uE7SlDVLAb8YoyRolg27teNAESqUaU82svtB28Q180T/kbcUGYrUO
V6FoL+LVn1e2lrkY7b/evADGEbty0qvpNvCAKf+6kBJ48ZhLMWQTJeQAK2xI
SraxO8TtFeSqQlpjqRiPBLWXhW7R8jkmhcQPmzNBf3c8mo8EYm67z2Kwyfmw
hGWTsfxq3sljNGR0gLBPTIyqGINO+XzKuph2Tkct/W5NAuKBt/JqSl5N69Qx
eoy8HlgCoI5AfLeKbZbTdDKyWkZSKSk6PUsPc4w2nt7OUTgEKgdf5WSrHWSN
Hau2t6isDUprtdJeLYTL+JYynqOO72nm+toFYaI8zVLlWbIkFSAs8mBlbjyo
unCY44gLvFmFMyeHs1JdWihJcjgJJjvNYGWZihxsHPDYxgL2US/cZ9OfLDpX
C6xyNiTj61VCvVZm0mgcWr1Xo7YLRAaKTMZRaXgKAw3UT6EVqY5i7f0c/5S8
c801uBmb2uqeWe+dX+ldXOhZnMnPjadHJh09fcZ0Qp0IqVIRXTKqC4akVj9H
FyDK/CiRv1UaRUEZsiFF1wYpMjuGpqkDCNNVdUxNAyiPNEU9U93MN6BVDqrB
z7WExOagyOgX6dw8hYUu0BKL9G/Vus53JCrxna3kXiKxi9oawlaamq9KK6/w
b1xjXiumXionn68inqnGvVuJeqsc+9/KMf+9BPN/X0P/7ir2z5dxb10ini4g
n70uKClX1jfBmA4fjRDlklN8akZIy4rQIWZHgN7hpqGdVIyNijYR25WoFnFL
hxhJ1uC4MI1vp1EhFEbRSNS2cOxYfY/I1C21dCssObk2yJHZcDIrCnK3G7wI
jbNSbi3WeSoMgXqJuQzw60rTRpaTuRF/fiS8uj33yVfPv/vhm6+/+uaLj7/8
7NlnD+4ebC2tbs3N3Z2f2Jod3p7t3/kV3rk+4L97k9n9yfTRZBL47MOJKAD2
q7UeoOdz6WezqS9We/55e+jL9YFv9+Z/frD6X082/vVgHcD79e7C51vTz2+N
A7f9fHvun7srr443fnh055vDWwDeBysjW/Mzm7MTaxPDK0N9iwOdC73Z2c7k
VCq0Pphb7IyMBOG4VgizMCD6ugWEpI63nPBs5MOzYbjLKN4ZTN4biAEdTWS2
eoOLCcudXv/OUGjELYsrCUk1CYxZk3wibJ1PeeaT7qWMZ8ijs3NQQkQxyM+I
j/7cfvENXn2BDFkEKAb8Av910juScuawTdVvluS13FGHaiFsAaF6xCFfSQDb
UaRVtG4Dt0vPiUoIcRnp5JIQs81AaeG1lFHrrrOQNQJ8G5+AtsglNq3abTJ4
LSYw2nQas0phUspPLuCyT64E+TTCuEkKInREzYqoGWk9L28WATc/OW2l5+Zh
aadVljaJ+iAaQDitJCcVlKiCEgCHCyFRz8VouVi9lGyG2LBFYLEKTVaewcqF
bFyhmSe2cGUwU3ESpHEaR4fG2aJxNkotFVxDCct4g2uv53taeX60KEpRZnmq
LqY8Q5fGSNIgUe4naoNUc5htjfFsCZEtLTFnJdqMUJzmspNMWpJOTVEVWYex
3+8YCduHfOYehzFn08fNar9Z7jQq7bAcNknNWqVVpbRJRUYGXY6Sy7laSKiF
2VILDvCrDKNtfWzfhKL3tm9sOzN7r2/hzvDy6uDq8sDqfO/SZH5mzjswYEon
lMmIMhuHcilDLK5yRnjaky1aWgXeZsCvIUMxJekqN56vb+GZW4H4ljaeGcnW
NgOEefp2uZ1sjgjMIYHRLzD4+OagBEhl5/C0hHOS1yps76ESl6jdV3j917k9
JTjfpWrFh9Xiy2Ws6yXUshJqxXVK6RXixUvEDy6T37+IPHce8VFBy4UrqGtF
2OtXcUWl1JIaQVm7vh4N15PcrYwwjhGh0oIMkoeFczDbYWaHldVmYwC12qkt
NlKLjdhqw5N8TFaII4kLZGEOF8YxtEjwD2KN8J09eme3xpuXh3KieJIVC+AC
1ga3rtSjKwmZKwNwtdtaZ4XrVFCFxlLvTdGGe30Rr2ZkKPLyk3vf/fzis1eP
H39+uPPkztrO0tLG9PLa5Matma2bM3cWJu7Ojx8szzya6dwbjv+yv23g/lgK
1Eygk/VRs10gtX68MvhyeeDZQi+Yf7Y28vWdqf96sPQ/jhZ+vj/38/2Ffx0u
/3yw/N0uyM/z/7x389v9je8e3vvm0e5nx/ee7995tLvxcHfjwcby5uzYTG9+
KJ0YyCSG89nRrux4Z3YsEx1LBsaizgGXBpBiJ9dGOM0jBtpMxDwbtcyETADb
3f7YYgS+nfPt9EWXotbN7pNNlIB5DXo1WViQgvkDQc2YS5lUUJ2sNp8QH5HR
rSyUEFlGriyoPfPX8nf/0H75HVFzkaj5mrj5io1Wl1QSUgpWRsWZ9hnTSraP
g1tLuQ5H0rNh87hXl9Vxkyp6HywGAmnWwUS62O1eUaODjzAxETJ8E6e9iYvu
kDEYOolYI5d4HFaf1+n1ekPBmMng4rE1Qp6BR8brpUKvWeczaa0K4cn9CAKK
SUBySekeCTWooIPmC4z45Cy0S95nFWQgloON1JFqwV9hYjfLCJVC7A0JpVpE
qVIJW2CI5LGzvS6uw86ywDSzhSpRNil1SI2hQ6NDypVNYmWdQofQWJBCqJ6j
q2ZAVVRjJd1exw62iNNYWRdJ24NT92AVebQw1caKtjAirZwEhpsmyvu4si6O
tJMtzbFFCRo/TBFGaYoUB+pWmAd0znGLZ9zpGLZbus26tE4d06jDKk1ArfYo
ZDaBSM/kqUg8BQFIodWrLVpzQO1Iicwpki6FtPRgAhO8rjUb4Hdhd3xxa2rp
zuzN27NzS8PDY5meCVO8WxlIS+M5KNdnS3ZbfAm5NcjWuLAqb5vEhQDHH4G3
RRrBi8Mklufk8ZgyM5GnxTEUWJoCx4WoMidHG+SqvDRzlGlLsKwhhtXLsHk4
VgffbOZckP6pxvYuPnmJ1X1NMFDC77qOdRfUSE9X8y+V0q6ArlpEKC0mXb+C
LyjEvV+If/dS20cFrR9dbC243HH1KrqoiHC9llfTrkVQXCimH8OLE/lJGjtK
I3qobSYCQodF6MmtJhqAF+Vko71sjI+F9bJwPhY7LhKlJOqcXJMUST00gQWn
dtIccZEtr3J1qoPdqmS3PJ3lJUKEkLXRC93wakoCxgqPsdxlqraYa1Xaci3c
FEwzsglzb7d3bX34xWc7L78+2H+xuXh3sm+hq3ems3siOzTZOb84sn5zamtl
+t7SNAjSB+Oprf7QSsYxH7eA8e5g5OFs54uVgU/Whj/fGPvqziQQmHy2Pgom
396b/XF/5vvdqe93Z37Ym/8J9N+9xVf3lr7cWvhye/nrg40fHu9+/+z+P58c
fHq88+zg7uP9rYd3VrcXpueHeia78+M9XWPdnb0nO255+mLBwahvMuGZjtsG
bNK4FJsUo3o15EG7YjponPBBJ/vxdYfudoeORtL3esI3E46lXx4UPx02zMTN
Ax5lwsAOQ4ygABOXkRNySkBIsLPaNfgGTkMR5vqHDefeqD79R0zxu5LWYuC/
qvYiJ7MxqcTltfychrccc0y4tSkFY8oLrcTtkx7dgEWa13NTagZAOCojuzkd
BkKdqqNcgy9SE0o1xFoVuVVBwcqpZMCvlM2SCXlquUSllOp0Oofd43XHvO5k
yN8ddlkTflfK74674DAMBQxKh4Jn5JHlxGYtDekWEQG/Q17VuF8z6JB2Grlx
FQ2mN8tQZTJ0uQJfJcFViPEVMkqtlt9qkmPdJobPyfM6uHYLw2gg6yEibCNa
7SSLlQAZUIBfkbRaKK8Rq2vFUB0XqmHqK2nmSoajjhtqFafRsi6Cphej6sbI
cyjALzvWyowiuUm0MEOWd7MleZYky5SmmaIYlRMg8oNkSYyhSYlNXRrnkNk/
4fKP+zxDblev097lsCTNlpjRENTq3ArVL3vLnjxaxy50+8KBWCje402PwMEh
ob2baOsleEZYgN+p3c6145nV/YXlrbnFtcmpuf6B4WT3uDHZq47klYm8Ptlp
CmcgT0xmD3MhL0HlRvLgWrqpkutolEaI0ihV4D9ZEgb4FRvJAj2Vb6CLYZbC
zQP8GiJsa5rnTHPtcZYjzHaHRC6/2OYQXZP/vtH+D0qqgN9bLOkr5mevYK1n
agT/qGSevY49fxlZcK39cjH6yjXUuUvt713qOHUR+eGFlg8LWs5far90FXO1
jFbRrmqju4jcMFmcpElzLHGGSQ9QOkzYOhmynN9UJkbWKDFNRkq7nYnxcQgh
ATUqYiUkil5I1weZ+iFzlwqKCbVepsnPdcallqTElVdEe9XZPkU2w0sE8SEr
IqivBPwG9eVuXZkNKjfpq9S6KoOtJZbj5rrda5ujR8/Wd5+u3jqcHbnVExry
wGm9PWf25GyJvuDIdOfKzfHNW7N31xZ21hb3J7I7o6mN3tByFuRP1+2+8MP5
3s9uT366MfHl1sw3Owuv9pbA+Ovkh/s3v9ubebU7/Wpn9uT81e78t/fmv9ya
+/T2/Ne7t14dbf/47PCnjx+9evnw88eHL453H9+/d7C2tDEzuTDUPzc8uDA2
Oj040JNMxNzOTvBZD7qGwo6puOvkyVFu5YxXsRrV5SAegHfcpZkLmk72wx3N
vJjp3sp5V2LwtFc77detZV0b3b7JiD4H81NGdkSI64Y4nRAHEKfH12uwNez6
a60XTyHOv9Fw9q+k0g8U7aUqVCmEveHjIJJyrIXQaMLV95nEIDknZLSMitVr
Eoz+sjh5wqOe8GnBwQSAnFTT3Nx2Ha5KgrokQV+VYSvUFKSORYa4bAWHI2Ex
FWKBRMgB/FosJpfLEw6lYpHugDeXjYbiXrffZvLDxoTbmvM74jb9yZMkxVSr
gGTnE7wSMujCKT07Z+Bm9ey4luHgdSiwleL2UsCvjtFk4LZC3FaHiug10EM2
XtQtCrmFAGEnzLSZaE4b1Q6TYTPOqEfpoDYd1KrVt6pNLXJTk9hcz7XUMK1V
bE89P9IsyaLk3XjAr7oHLe9EidJIXhLJS3cIs3hpF1XWxZBk6eAjKo7TBCEK
14PneQmSEFUdEZsyau+gPT4ZyswlsnPp7EwmP52LD8cjfeFAzuuKW50Rizdm
iWRd6e7AwODYyOTo1PLA1K103xIcGee7BmjOfkbnCjyz333n6dLG0dLi5vTU
8tDIRK6rP9Q1Zkj1aeJ5VTyni2agQFzlikhcUb7eR5Ram+lQGUl9nQmf3JWj
iNElYZrcQpRbSAorQ2nnqNxCjVesDQh1Ia41I3Dk+M4sx5HiuJICX0rmjSld
AdkN1e/anG+zMwWyvmuKnmu8aAEGerea+eYN/D8ut7xXUHu6sP7steZzV1o+
vIQ4dRHxxrnmd842nTqLOF2AvFBCvN4oaiKaCNwAnR+mgVgiTtJZIQoWRjXI
W8o4DdcZdQXUymuchgppe50O1wrTsH4uPS4R5FSGUSs8ZnWMWJx9BmtaDuI9
HBI4IiJLlOtKC8M5aTIjjIepEVdHyNwY0tcEtOUhqNKtKbdqymF9LQTVWOzI
ZCd/cC699WDx1uF090IsNGo3ZZViP1sW4atiEmNS7eu2dU0kZldGbt2au3Nr
afvW0uFsz9FcLxj3pzp3xrNgfLQ0+HJ94vna2Keb0//cWXx1cPP7wzWgH4/X
f3qw8ePR8g+HS9/fX3q1fwI1SM6fbS58vDH/0+O9fz07+tfHj3/85MnXLx59
+vjo6dHug4OdZ7t3jzdv76zdvLt6c3t1bX1hcXZkdLgzD4x4LJecSEeABY/6
Df1Wya978HVBfOCJAKXlqOVup3+/L/JgMLEWgYdNwh6IM+3VbHZ6lpLwgF3S
b5eMBbXLEcOkR5GSU2Byg5FYbyI18BuvtZx/o/XC6y3n/0YrP6PsKNFhSs2E
ch+3KSxoTUjJYQFu1C4fgiUhPtbDbHOz2qISIhDovCcPoreJc3p2VE5ysFoh
fLWJVaOn1aipjSpKm5pBggRco0xmUisNGoVCKjCbdCBCO53uYCCWSvT5vemw
zx1w2Jwmvcuoj7psXRFfd8SdcZsyLn3MIverOG4xxSMmBeSUuIaVNnCSenZQ
QTYzWwC8EK3RKcV5VCRYgnEoCG4tJWBmRRyCmEsEKI64hGGnwGEmWQ14C4SF
jVinleh1U7w+iitAMrraVc4WiatR4K7jB+rFyVZlF1rTh9cOYDT9WGUPStqF
knSigCMreqmafqamnyvPMURxijBCBjYnAPgEaNoY1xxVu7OW5EiwbyE/dmto
ZmNybnN6YXNu5tbMxNL4wFR/11AmP5DqH81NzA0srI3fXNlcX1/fuLt0a3d4
ZivatQSFRrnOPlZ20TS9n998PnfrcG56fWhktqtvLJEfCOVHoESXIpiUhJLK
cErrjyk9YQnovxo7mq+vJcmL8IoihqlW7MfKIlRJkK6CSUorReNgQh6hMSA3
RRTGmEQf59s6RfY815Zn2bJsd07kzSo8GZUrrm40/A7ve1uYu6Dsu6zIX2Z5
P0TK3qggvVbc9rfC2tfPl//9YuW7V+oAxe8WNpwqbPj7GcQbHzb9/UzTqULU
+WpmBUqDptnILDdZEKHzQmSmF4c1tzXK6srZ1cWU6mvEmg8x18+Ryi4za4uF
zVUqVKuVQokIhXk14Nc+ZnOO2AC/9qzSFpPYw0J7UGCNsJ0xjifM9PiIbmub
29Dg19eG9TURqCZiqPVpqhzaKrux3qSvszna03l+91yybzntH7Aqw3y+j0ow
I3HmZlGMLgzT1UmRs8eYGg2NzPctr05vrK/cWV89nOv/VQ8Whx6vjD5dHX+2
NgH0cmP6s635r/dufn+08eODzf9fPz9c+/nh+o/Ha9/dX/1m9+bXO6tf3Vv9
cnf9f3/+7H99+vznj599+/zJZ48fPj++f7y/c7Cz/XR/9/HOzv07mwDe1YWl
+cnZqZGJqcGR3lR6KJ0aTUeGw+5uhzatFwDXG4BFIw45gHfSrd7O+3a6gytB
02rItODRxnlYP621S0Wb8aoGLPyMmjpoFc6ENXdzjnGHOMxHWUkNVkojCL28
usL2S28CfpEXAL8fKJBXtR1FFkKZm1HjolYmpaS4mNClYwd5aDO+1kFFgG90
0JsDfDSI4jEpMa6kBERYKx1hpjSA0avo8MgwNhFWz8Vr2BRIKLBrtT4bbDfr
IY0UhnVOh8VogLzuQG/XcF/XRHcu25PPdWWSqWgoEfBmwr78LwhHLOqoRRk1
yyJ6UUjLDatZQFENM6xhhNR0pwhnYLSYuO1eJcWjpJj5KLMIY5XiXRpqwMiO
2oRxh/hXhexsn4XuMZG9VnLQw4iFOZEoOxBjuCJEawQLhdsU4WZ5rFmZRWp6
UdAQDkg3iNUO4DSDRO0QGRqmG0bZxjGeeUSo7mSKYxRxkCQNUJQhpiklcner
YnlPfjA6Ote7uD61fm9l6+D2zv27e0c7u4c7W7t31jaWF5ZnZhfGl27O3N5a
3tnf2N8+2tvZ3zu4vXV/5uZe5/imOzevCY2IMwvmybvJmw9G53dGxla6BmbS
fRPxrqFQsk/pi/NsPqYzIADme+K/QZHFxxBBzXTFDYL4ClFRzLI0ijxYsY8k
9lG0dqrKRlXbGTo3zxiQWmIKOCUzZ4S2biHcxbZ2Me3dXHeP2N2tcHdpPJ1Q
u+13lNDfxZ1n1b2F0uQ5MnyqkfvHEvR/Xmv+46XqP18of/1ixanCqn8U1rx9
pf5UMeIfBR1vXUK/cwX7YSn5CkJUR4CwVCuJYsXzAjS6E4vSNdYKy0poxZdx
xRdRJQXtpe+jis7iSwooFYWMmuuCxlodGu9hcZMydQ9kHjS5hq2uXoMzq3Kl
FJ6EzB2VeBIcV5gGuzAmQ5NRVQMrKnya6ghUF9XXxwwNAV2tT1/ntSAsxga7
FRlPMgMDLkNCxbWTqTCaZGvrMNRirA2CJJnhQytSHPeAITURGJzrmr85eXtj
dfv2xvHS2MHc0O50/+HCyLP12S92VkGN/VWvju788PDuT493gMDku+Otbw83
fzhe//7o1neHa98erH2zf+vVwe0fHu78/PTwf3/5yX999vLV8yefn8B7+PDg
4GDn3r27W7vrt/Zvb+5u3L59c21pdnFucn5+amF5bmliaGS0u6s3GkraDGGt
OKETDbg083HrL9v4SgctYsDvvZxv1CQaM4vn7MoeBdVLaohyOoaNnAE9a9DM
nXLLhm2Cbg05JcYGOK1OaqMJXyVrLmKUncFcebv1/F87LvyVUX5ahrioRl42
40vspDJ9R6GuvdSErQR/WNVSpEIWu5nNDuB6DERMivew22Bak4XaqCfUqFBl
emKtm9dh5iOswg6bmKDnnTyQSsagqwR8vUJm0qksRrXLZXS5zEaD1qg3OW1e
nyPUmcsPDQyODA/2dXWmY+FUyJ+N+Dtj3hCsDZmUPp3ILmOYuHgjGw3z8Q4x
EQAb1DKAPAoykB/kdgXZIkA7ZUQw8WvoISMnbhUm7eKETRSDBUETM2CiAUUd
rFSAn02IshlRKseL5Tm+LMWaxuqTSE2mRdPZquvrMAxj9MN4IMMIwThOhafZ
1hmufZpvneBbx4RQJ0MeIyvDFF2Mbc1Igv1QdsI5MtY5Ozu4vj6/u3v7+Gjv
8aOjp08ePX/2BIwPHxzt7+3c2VrfuL26eWdtd2/r/vG9h3tPHh4cHx7e3T1c
unM0uryfGVizJaZUyVloYCM4dS83fjs/tJwamE92jUfSfR5fimPykDVmrNFO
dwbErqDE7GRpYCJbVkMWlxAlVxmaCr61WejECF1EoZsCOekaK1UBU5U2JuQT
mGNSc1pqyQqs3Ry4h2kfYLmHBa4hkaNf5uzX+AZNWN9/MuJvSLo+UPZc4EU/
QOv+WkH/7VXkb64ifl9Y95fC6jeu1J4qrHkH8FuMeK+i46MS6rvV3IJGUXGT
qKJVWo/TdVDMeKoFQzZ3tCtrK5lXrmA+utD60UdN5z+sK3i/5tJ7bZc/RBed
J9y4QL5xiVF5Q9zUasKTvWx+XKzt0tgHjIBfd14T6NRGu6BYJxTJ8Twhihlu
1SqrIEk5LK3wqmrC2roo1BA3NIX09UETwm9Fwvp6s7EhFCLZOiGBg0oytJHN
rThLPc5aQ/E1scNIhq9F38WNTdl6F+LjC71Ly9Obt27e3dg8Xpm8vzi2Pz/y
4ObUx9sr3x5v//R0/+dnB7/qX8/v/yrwxe8f7YB3vz1a/+bw1j8PVr/YvQlg
/+b+HQDv//Ppsx+fP3715NHnD45fHB0+Pjw8Pri/t7O7vb19/87W4fbdw529
ve3d7Y27t1Zvr66sA60trc6PjfelEgmbOQjJkiZ5v0s3HrSM2JU5LQuk3IWA
4VbUOmwQTJjEcw75pEkYZbSk+KhRA2cAoo/DvHEbPyZo07VccRKrvLRGE7Zc
2VokbboM+EUVvIH86DVUwd+YZafFDeeVLZfM2GIYWySv/9CIKXNQ6oJcpAVf
DZNqvWzwz19lIdWq20vkbcX8hkJq+RnyjQ8YVef4jZdFzdf46GI+tkyAr+Og
m8gtDaj6+taa6qbaKhy6hc8hq5Vcg05qhFQKiZjH5ArYQq0WstkcgUAgEg7G
w6FkJJiO+FJBV8ZvjzuNXp0E4hLFBIQIU6+kNBs4aJecEtSx42ZhwiKKGvlg
7lXR3eBgpaL71IyAlhXV85JmERCYBDUspxwEbGLAQI072J1hcW9G2det7BmQ
Z/uFkR6Wu5NozqKgbIu2s0Xf164fbAfmCyzYOEq0TTPdCzzvosg9K7BP8qxD
XChPVcdIUJzpyInCfdr8hGNoIXxzcWJzbfFoZxMkqE+fPPri2fMvn3/8z5ef
fvLo+YtHT548ePjg/gGgeG//7v3DneMH+0/2Hz85ODoGHn1/5d7x9NpB9/Ca
OzKmCIzIUnPm7iV316Kvay7QMx2O9zudMY3Rg1OaO8Q6pMqA11sZOgtNrsMK
1UimpIoqLqHKS3nGOqG9TeBAA36lXobOQTu5q9GIl1koWg/HGBGak3xDmqXP
UkxdJNsQ0zUusI8ITL0CuE/hGTPjI/9Bz/xF3Hta1nOeFXofqf5zCfk3F5H/
Vtj8+8LGv1xufPMKiMoNpy7VnSpGflhNKKwWnm3TFuNMdR3aulZpLUrVTDKi
aTC2WVJVQSu82PbuB/Vvvl976v2aD96tOPN2yQfvIgrOtF89jys+TygpIJdc
41TWKlraLTi6j6FMy239Blcv5O3WRvuM2SFLbhgGldYfJptNzRpFJeDXKqv0
quqCmsaIrjFqQIT1TQFzc8DWaoFqDPpqj6fdmlVzrDiyHkHQ17eqizHmMrqv
Hm8rF4SQrkFJ/2pw+lbXws3BtZXp7ZurO6sbO3Oju/Nj95enHm8sfnzv1leH
298+3H31aO+n50c/Pjs8OR/1/OjnF8dg/OHp/e8e7397vPnN4cZX+2uf3V35
dPvml3ubPz4+/K9Pnn15/+CTg4PnBwfP7h8+OXpwfPhgb+9ge/seIPbu2q07
a+vrK7fmZ5eGBscy6a5wKG4xwS7YFnY68iHPeDoy3xmdzfonY/YuozAsITvp
bf0m4ZwPGrWIZ52qBZdyQMUI0xA5IXZIS8sIUXkJNi1G6ZFXJdVnrdiTzTdP
dkupL9C0l/BrLzR/+Ie2c39GX/orq/w9cf1HquYLZuw1E+qKqOodatEpYc05
C74SJlS5mU0eVosWdcNKqcdde5tZfR4IXfQOEL3mPBCq+B18w3lM7fm2ioLG
kkuVhQVXzp45887bp974y9kPTlWUXWqoK8ag6iVChlIikPL5BrUWjSFQaQyR
WGowGHxedyISjAY8foc57rGlvHDCZfAbJGYRRcNEq+jtWhbaIsa71fSoRZhy
yGImAWDWo6SB0S4iAHd2Sck+JR1gG1IxvVKKQ4AHBdmnIkWMzJSTnw+JupKy
7rws3yPuHJLEB9jebjKc69BnWqB8C9TdYuxr0/ahoQGseZTknGH6l4SBZZF3
TuCa4Jj7qLo0URcnWTOsUI8iM2IenPVNLke3Vxf3b68/2d/97OHDfz578c2L
T799+dmrl19+9ugF0MdPnj1//OjRw8PjBwcPHh48eHz/8e7R4/2Do4Pt3YOb
d49mVvf7+pfcnj6BrYvjG5KEx7XxcWNmypEZc3rSOpWdpYBbRVCTUNMi0aGl
OrxAiWJLm1mSBqashiq9wVRXCC0IsR3Ft2PELooyeLK0UmYmiA04qZmsdjH0
YY4hxtImSKoEWptHWwYp9gm2eYgDugDUI7KN6cnZ3zM7/8Lve0/YdZbgfadK
+LvLhN9cxvxnEfZvV9vfuIJ8qxh1uhx/vopUWEksLMMVIJQXCNZylq+V6UGR
zW1YbQtK1dQur6vjFJeTzxcCfmtef6f0r28Xv3Gq+NQ7xe+dqv7g3bqzpxEf
vdd87v228xcIV0q5FfWKRowFK4ryrH264KglNmbJTtjz49b8iCXfL4kk6FZr
K+DXKK9y6ZrCxraYqT0JoyOGFr8e4TMjXJYmq7kOttTZ7I2mhEDmJtINTXht
BRYqxZtKGe5qUbhZk8T7B6TDK8GNuyN7u4v7Gyv3FpfuTC0crs48ubP8yd7G
5/fvfHG49c8H9354fvg/P3sM9K9PHv788QMw/voSzMFbPz659/2ju98cbX65
Dyi+892D/e8eHb56eHT/5vLznd1Pjh8+3j/c3969c3traXF1dGxqqCsPlIpE
jDqIxWBjMcQ2JBrRhKypqm2oqW6uqaSiWmApN2pS5J3asV+eoWFnoszU5pSC
MQTLRq2yAR03IyBEWW0ubFWM2dopwQZpDV5ytY9SY2i7pm2+7KHUBtkIC6Zc
1nhJUHuBcv3dljN/BOGZUvIOv+aMpOGcrOGsoumsouGMrO60qPY8r/IMt+qM
qP6CDFEob7l2cnYaX6lEleFLTwNyO669U3f2NcSlNzClp5sL/1524S+F7/7H
mTf+44PX//D2n/7wp9/+5g+//e3f/vS7P//xN3/7y2/e+8cfC86/dfHcOwVn
36spLSZ1oCgMNo5ERaGxeCJBKpU67Baf2+Y062CtzKIWOXXSgFnuhUQAYYOA
YJPS7AqaU8XwQdyQQQDkUbNgIQFidQBrNnEwNiHRq2D4lEyXiGzj4e18gkuM
dcnwXjUpZKLHnOxkkJeIc2MpVjjDdKeIlkSHPt6qSzRqUo2G7hZ4oMM2TodH
qUD2CYZ3jueb53um2Y5RhjaNUkXbdFGsO89JDmm6JyzDc+7Zmyf8HmxuPDvY
+/zRo2+evnj1/ONXzz/99tknXzx+/vnj5588evz04dHR4e7B/XsHR3f3H9x7
tLe/f3dz9+7a3v3VWzvjAwuhyLDWOyg1ZChwN8PZz/MMSJydEmNUoLDThUYS
U1nJhxq5mmYyvwZNK8czqmiCeoaknsgrZSiqVC6UwoVmm5pVQaYlq5B4mDo3
7ddLSGonXetlKtwkhQ+nDKMMOay+G2Xow0B9OF0fWdvL0vaLoAE5MfdbWvdr
3L732PkzGNc75aI/XiX/7hrxtVLSWyX4t0vx71XTzjfzrrcIKhrYpVXUIqT+
As1TKYqj+CEczdqO0TYCeJHSqkZuUTW9oAT3fkHjW6fL/3Kq+K/vXH39H1ff
/kfFO+/XnD7TeOaDpg/fa/rgTMe5q7RrlcIKjKmNH2KYupXuQV1gGIqPmtLj
pvSoMdcnBvzaHB2g/9r0CL8ZFYaxURidsuNjVnTI1u63ttjNdUZDpcla7fA2
wHG20ovjWpqohgoiVEo0lNCtlXx3g9jVDCeYXSO2lZWunfWp/eX5nZm5e2Oz
e4tTj2+vfHH/7ndPDn94dgz04/MHP798BAQm4OVPLx7+j0+e/M9Pn4IRzH9+
tvfdw+0v9tY+37313YPdfz178M393YdrKw83Nh7c3ty7tbGxuDI7Pt3d2efz
hnSQiYhq6WiqrywtKrxw/vxH5woKLp396Py7755+88033337rff+/reLp99u
LCkg1Bfz0LVGLsYno598SgUkt4Dg5eFjYnKEj7Ph69ykJiuqIkBtjLGRdkyZ
sfUaMF953TkLutTUcV0HknPDRX7NeXbFGcr104Sr76Avvk4rPQ0glTYVyBEF
wILViHPKxrPihgJe9VlO5Ye82o9EDZdEiMvStiI1pkLQcg1z/b3WK2+1XH67
+txfmi6/1Vr8bvmZP5360//x5h/+z7f/+N9Ovfaff//D71/77b//x7/927//
5v/60+//7S+v/dupt//9w9N/+uC91979+x/+8cZrH7719/OXrhTfqKiqq6+t
r0MgEEQCRsRnaeRCnZRnVPCdkDgEKyOw0g8J3RqOR8s1CokWCcWpYvn1gpBJ
HNQLPWqOXUZ3SGigJkNMQDHOwiMY2VgtrV1NQcoIVXpWs0uBBxU4aGP4XTS/
l+YOkl0RoiWEhoItunCTNtZkSDdbujrs/RjHCNM2RLcN05xjdM8kyzPJsA2T
LL14bapdG0UaE7hADzc3qu6fhscXPPOr4c2bs7ubK4/2tl8e3f/04fH/y9Rb
B8d1Jeq+OWfOZMKxY4iZQRYzY0tqBjUzMzO3mhnU3FK3mMmWmSkMdsAQO5yZ
TDIZxnvve+/PtzU599at+mrV7i2pSiX1b3/ft/bqtb9//PiHJ09++vyrbx8+
/urBp08+vvfJ/Xfe//DOO+/feuuDG2/du/neW9ffuH3pxq2NK3dWT1+fnDob
Sy1bw4tKXYpgyOEtBYolRwOIU/upUhtJaCLxTP0iy+aH7ikiEJbdTeD10UVg
mmSAIe8VmMAaP94QpZoSbNeYxjNuMiYVAL+bW2AFuZYw3xhi64NU8wjFUaR6
Z+muWaJlekhbQqrGhtRFqm6Kb5yTs6a3Cub2AvwKS9X4wIl+1YFu0cEB8Umo
uGJQcAoiqsJpOtkOJM+FpxiQaNkAbrhaMDKgn6Co8zROAEs0QbCagSFlD07V
jVN1oSWtA/SqZtTRyt69ZR37T3UeqgAdr4GW16OqqxCnyuDHK4fK29jNg4pe
ho8kS3Gtk0r/gj6+YsmcdoyecRZOD5fmVZmiKJKgh0PURISRjXILUV4hzB2L
cfNRRiZKjYWxXi/Y7u71RsDRHMZf5NpTlM11LD4Y3wViObrZw31CN0zmxjgT
vMl5z/VLUx/dOf/4zvWn128+uXITgPfbe2//8emnAKH//O5zYPz54PefffzT
449+9+g+MAJfBVgG4N1E+/N7f33y4U+fvPX9h3f/8OkHf3364PsP371/5eKj
O3ffPH9hY25htlAaCcf1WhNgtcBbGNbbAu5p6Wqtr6s+deL44YMH9+/atXPL
lldef33Hgb07972+9cieV2sOb288tr3z1C502wnKYDPQDT0yhp2L05Ogbg4W
yNI2Yr8F12NGd/oogzEuAmB2GN/hInbZsa1eWp8B0STtr1SA6wDzFQ/U8nsr
eaAqcssRIahSjWo0DDUD/deCb7bhm81DdUZ8uwrZIIPWSGH1MniDBNYoBn4c
3Qa4LaLp0GDNHlDVnt7qPdDmI/31h6r2vbBryzP7t//i4OsvHdixZd/213Zv
27Z9y6uvvvSrHdt+tXf3C0ePvFJ+cntD1f7G6kOVR/ccen3L8y9v2bln79GT
wCXqVEXFqZbmejgERMYhWUS0lE00y9legzgxrMp5DRmPNm6X2+V0p4rlNwhi
djlwJufTA2PKpY6YxHYJVUVHamhIPROjY6CBP4uSDFPT+20idNBIjw1zIm52
wMPwhxiBBMsexpuDGF0QZojCrZkh7zg5ssBMrHDDS5LQojC4IAit8MOrPP8S
wzlFtIxhTDmkLYvxjlHS8+KpM6bF8671S4FzV2PXr67dvX3+g3euf/L+3U/f
u/vo/bc//+iDrx98BBD9yftvvv/2jbt3L964c/bynfXzt5fP3l46d3Hm7IXp
pY3ixEoqvxhOLrqCczrnpECWQMmTMOUITBGFS3xIoQPNt2AFRjzXAmIZ+kmK
bgy3A0lvHwIQ5oOIwl6OFiKxo5Q+nDnJ9k9pvZMGU1plSKrMIY45xAPgNQXZ
Gi9F7cOZEkR3ieqcwNknUIYSRF2ASLMwSWZImqcoihze7Hbp4kHlQqVgtJbg
LYdqj8NUFVhNI1bViJBUw8VVJH2H2IdThGhcO4GgguGd1eL0oHmGpi8yuMEh
onlwSNOHVXVTDP0s6wDXOkhWdkJolS2ww/WgA/V9hxoGjjVBy5oR5bXw41Ww
o3XYsl5hG8YIFibo8jTLUBR5F7QjZ22jF92F8470afPYnCo1Jowk2fEEN5MS
j2ZkxbRsPCMfS4oyMWY8QgqGUO4g2BnuD6QhIxOY0CTTNUY2p3HqOFIcgLAd
IKYNxHXAVG6SOy6ZmPZfOz/1yZ3zX75167s37nx35y4QmP/w9CMgGwMJ+Z+/
fvI/vv/8f/3w5f/30ze/f3If0E+f3QNG4BuA5PyXrx4A3/bXpx/8z28e/Our
T37/6bs/3Hv7x/vvffXWnXuXL1xbmJ9LpqN2p0muZlOZEBC4tbmjqbGNTYZr
pQyHSSYTMQdBHUeP7N++49Vt2199fddrh/bvPHJgW/mRHU2ndtcf3VKz//m2
Y69WHtgKb6+SUxF6Dk5NgVuZGABhI6HfSgCZh3qclMEQFxnhwINMiJfZ76b3
WYfaNfAGJaRei2zTD3WqUO3CgTpWTwWx+QhAsRLVrMe2GrEtVkKbldBixTXZ
aP06XIcC3SxHNQHkcsA19N4Kam8l4LkAuR1lr7ee3NFdfWCw6XhL+e6Dr/3H
kb3PHT/wysFdr2x78blXnntu+5atO7ZueeXl57Zs+a99e58/dvSV8rJtbY2H
IL21oNbK+rIDz7308n899/wvf/Xslte2Hjt2pLGhpr2lvqOxEtRWixnsYGIH
pXS0Q8FMOlWb/Folbg3Xo+UFjKKYXZH26HJ+Yz5gAsa4TeFUsLRsrAogl4kB
9POBVYyxy3FODXHYQLQZiVYr3u4mDwNt0YlQDEOkjgGFe9CaxEam2dlVSeG0
PDInDc+KQ7OCwBzPN8McHicaswhVHKRN9JtSMO8oYWSWW1xRTp82zZ+xLp5x
LJ4Z27g4feX6yvUbawDLN66svXH97Du3L7558+yta6evXF0+f2Xu9JWppYvF
qY10aS0xvhCaXI7nZgOhUYc7b3AVdfYxiTpNlCSgshREkQLL4xCJHyZyooU2
vMRK5joGqYY+jKgVwmyGMduxvF6yBEyVD4osaG2Ioo/RHQVReN5kySkEXpYy
KjcEWYDtAjL4N3eu0/ixphjOnhvSJweMeZCpOGgch6rHkLIsRpTC8pME+dIe
7coJ3UKdKFdPdddgDbUkfRvD3EvVtQ1Ja1HCCrKqWexCqQJUkYNE0yDp4QZV
EeZYYpkmWbwwhmgeGNIA5tvFMIPEbpgqgJIMD5IkzQPEsi7k0Q740Q7wiQ5Y
WQfiZBPsWAPyWDu1Bq0GMbxYeZYtTTM0oxz3kjJ7xTl23Z29YI2uarLTymiO
B1xgoylBJqcYzatKBc1kUZ/PiKMRqsuLcAUgnjgkkIVGSvCRWUxkke6bItuL
eH0GIw0j2c5BlgPOd+J1Qa4rrsoXvaeXc2+cm79/6fTDSxsPL5z5+sO7QPP9
8dEHAKE/U/yv3zwFKP5vWv8vAUX4798+/h9ffvT/fPPp//zyk788fO+HD+4+
vX3lnfWl88XRlN3mVqnkTCYeAmuprjt24MjJ42UAwnh4m1KA99rlBi0PCe8+
enT3a9uf37b9pZdf/sW2rb98fesvju19oaX89bbybU1HX+wse/XEga0Np/aT
ET0WCX1YzrQLKWbmkArb7+PhvWykmwkP8TAJKT4sQDppIDu5R4dssRC6rYQ+
AF4dtttEBMmR7YyuCkLTYU5flQLZosW2A55rJXZYSe0WfKuFBgICs2KoHQjM
Mkw7B1JH6D4F+D7guX21Bzor97VV7u1vPtHfcrLh5O6DO3917OBLxw5s2bfj
xRef/c9n//M/Xn7+hVdefvGF5/9r69ZfHjn8alXFztqKHe2NBwa6Kroaj1cc
3vHazh0AvM/8xzNbt75aV1sJ7u8e6GnrbKrqaamEd9dj+5tp8A4FHeHVsgF4
IyahV8f3AZXBJI47lBmvfjRkKUSsgDIBY8ShcOv5dhXLLKPpRSRAwIFZitGL
URoxXCNH6TUYnQmrtWAUZqTUBBWZ+/mmHqlj0D5CSi/KJs4ZJ87po1NyoOGG
J4W+cfbmhT2DUsf6pIF2VbjbnBz0jg3FphjZecHoomxsXj46JxuZdOfmwuMr
IzMr6Zn5kemZkbnZ5MJ8enkps7SSXVrLLpzJTJ2OFZZ9sVl7cMIYHzckJi2h
MZN1RKmLi7UpkTxBYwch3AhImgSpsoOaDFQWhgPIbD5JwUwE3pAEbQeE39DP
aISwO7DifqoawTaghI4hY5xlywlc43LPlE4S5NAsJFlEagpz/rdYlgjTGiNb
E0PmEah+pMeU7bEUQeYSWFOASVJwXhTBCqFMa0esa5s3j6SpBqargW5u51gG
RDYIV99DltUP8SuAUWyFqFx4iQXPUiI5iVbVONwyR1GNEhleCNbQjVa0o2Ut
LCsISLDGBNYQRgnMvQRhHYJSDiWegqCrwEPVg9iqPmxlL7kKLmyl2KCbj2XJ
sqQZmrbE8Z/W5G4MA4qd1foWJdExoXuEORyhh9OidEGVK2jzo7pSyTCSFHoC
eLMLbPEPuJLgYBEanUGMLKGj6zTfEsk6hdVkMcIIguVBcDw4WZBjz+r9GWtm
1Dc7lTi/OHprZfLtlel3lqffObf80bWzX7xz88cH7/882/zzPPMfn3wEvPzr
lw9+nnz+P3PR/++3D/722fu///iNHz+88/UbV99anpkLeqNapUchdSuUWi5v
aABccejY7m07Th0r6+3uA3ecRIPrqLgeCr53oK/+1Mk9O3e+ALz5t+/41fbX
fvHaS8/s3fZM3fFX28u3dpRvGazbWXXqwOH9W7ubK3QSRtypj5jlTgndCHgW
G+PioO00iIeLTCmpUTHWxQB72GA7qd/HQrgYMO1Ql3aox0qDagkDbFA9oeU4
p79OhekwEHp+XoI1TO2xk7sMFBBArhTTqsB2yrAdbFgjrqsc3nKiq3IPqP5I
Z83BjprDvS1lzdWHj+/fcmjXiwd2Pbd/z4t7X39lx9ZXXnvl1a2vbtny6ssv
v/SrPXtfrqx4vaPtSG/n0f6u4wOdpxor9hx9/fnnXnj+F7/8r+eee/bAwT2t
LQ0wcA8S2oMe7ET0taD6mlC9tUO9tQxEh4oOd8hIHjXdpeMBkPrN4phTlQ2a
SonhiaRrMuUejdlTfkNkWOk1iWwqll5M1olIRilVJYApBRC5CKpVYUxmosFG
kJuQfM0gTzfINw4KTANKF8Kf544DfnrJOX3GEhtXRUvyUFHozTPtabwhBlEE
uyTeVm2ky5YB+0vY8AQxNk5LjDMTY4zIZleVWpPy4ZTGk9L6R/TBuA4oQ9G4
YSRjzY46CtMA3a7krDU4qXUVFfZRsWdU4i5ILGmpJsqXhtmiEIPtH6K4+9iR
Hmm2T1+CmYsoTRIp8wL+iwX4JVt6kMrmQV59P7sZxu/GiPvJagTThOY5MLo4
01mSOsflurSQ5SQz7FRZTGFJCKwjQntCaIvznEmeO8MaTuPMiUHXGMRZGrQX
+wyFXnkKJIj0swJghh/qPF3mXKuxTDfK4k18ZxvfBhJbYWIzVGwEsRXNVFE1
S94kNw9q7FipEctVIDkjzfKxQe04RpJG0dyDeFMvXtuF17TznAOaMHI4S3Rl
SYYgUmzspUubSYIGKrOTwuokstvxvA6irIduBHM9GFGMKElSlAXG8JJs5Jo1
f9s5csUcPKPwrUmHEwyDn2j2U4JpcbqoSxU0yawqO6YJxjkOP9bgGjQFQPZU
v6c4GJ6DJNdQkbMU9wrOMImWZRDsEIzuRfFCdPWIwltyB8e8ybHQ1ETizEL+
1trEOxub+2C8cXr2g0urn71x+TcfvfmHzz7845N7Pz16/7efvP39x2/97uF7
f3p6/y9ffPznzz8CzgMCXv6vL+///v7t79668vTG2Ttzo+NOS1Am8svFGZtl
PBTMeXxSGrOpovLAjl1lR050NLcje8ugXSdhfZVoSCNkoK658fjhI6+9vuuF
o4dfO3LwlQO7nz2699mGkwC/W7qrtiJa99TWHtu5/bljh3awKMiIS58PWGIW
mUtCUxPBdhZ6mIX08jFpLSOuIAeE6LSWFpMQwkIc4Ms2KtTJRrn5eBMVJkK0
U7oqhdBmLbHXQh1wMAa9HIiPC/WwB8xMsArfLUa2iFAtfFQrdaAO1XES3HS0
q2o/qOl4V93RjvqjHQ0nAM/d/sp/Htz98v49z+/b9dL+PVuPHNh76MDBfXv2
7tn9+t49O06V72tsONjVcay/58Rgz8meliM1x17bt+UZwHn/69lfAO0eMN9+
UBcK3o9HDlAwYBKyFzvYguypGeqpIfTXsVFtWgbMJSO7NXy3ThgwyxIuXSFs
nxjxTGX809lAacQ9EjD57QoXUIR1fL2CoZFStTKaUgRTiGFKGUKtGdIacWoz
TqxHcNQDDGUv3wCROZDmCDk1o16+7F++7B1fNY0U1bExRbggdKfpljhGFxpQ
+jvlvhaAX3sW8F+Ut4D2ZlHe9JAzjrYFoQI3mecgcqw4gQUvt1H1TpbZzbV5
eMN+oS8hj+S1oVENAKw1y7fmebYxgb3ANSQZQJ0UBxl8H43hxlFcUIq3lxPv
kRX6zNMw69QQEAUV/iGRHfBf8pC+DaZohEpaELJujHxwSAbBK6E0PVLoJmri
DNeEwlGUCnxUmg3P8/MBfk0JviMtAbT58IUYy5WiudJ4RwrqH4f5pyCeSbCt
NKjNDYhj/dzAINMH9p4p96zWWMYb5OFGwXCHxAaWWpFSA0xhBAtUbRx5g1Dd
rrZC9HacQo/lyxD8dJuiCAb4BRI4L4zg+BB8D0rgQYj/bb6+IjU0znBnSAYf
kHD6+OouqQwqlkOFSqhIBxdbMWIPThoiCqMEUYKgG2eHLhqKb/tH3/TELukC
G4rwWZUhSFA5MTovMZARZ0r6kYI2llYmskp3iG7zDxl9UFOo35LodRR6/LOD
I6eRwfPk4RWMZhwmSELoATDVg+JHWbqc3l3y+AreaN5fGk+cWRx749zsR1dW
Ht5Y+/TmuUd3Ln7+9rVf338DABZAGNDvH38AIAwc/O2rT//13eN/fvvoH988
BAQc/O3RO7/78Oa3b17+8MzspMdkomIdXFrJMzwfi1yantqYmHCoVN2NTQd3
7j64e2/Z0ZPI3hPwXsCCa0hD7VhkW1dnecWpPQDCu3c9e2j/C0cPvFBx9KXW
ytc6q7b01mwd6trf3Fq1Y8eLu3a+gBhod+gk2YAtYVc7RFQ9FR6QUUMySlRO
zuhZERnRL0KP2XijBi7Ar4uFCEvJGR0/omCYGQgZppsJqpOiu0xUyDAL7uYi
AdjDIlRQgHAJMDoyCICXA29iQurx3RWQxqM9NQf7Go9COir6Wk/1tlZ0NJ3c
t/OFF3/1zKF9W44e2rp390v7dr927ND+o4eP7N97YP/+vcePHWxpLW9qPNRQ
t6uxdkdTzY6q41v2v/bMy//xzLPP/fLVV18+dvwQqK+LTMDQSUM0PIKOhwK9
ggTtwIEaiAONlMFGJqJFQ4f61TSPXuQzSsI2ZdJjGI04xpOeybQP0ETWD/Dr
tcpcFonbKnWaxTY936zlArFZLUPKpHCRGMKTDLClA2x5/+b2btIugF+1G+/O
8Iqrto1bsdXLgdF5/UhRGx9VhnIi9wjVHEFpg4MAv8pAmzrUZk33uwpQRxps
jQ6YwwN6b5/S3kW1ofA6KEbWh5eCmCq41EzQOmgGJwOQI8j3pKTOtMD07ycQ
mXIs+4TQVmAoowSBB8v3klheEsmBIjrB9EA/M9IuyfXoJsDGElw9AuRnBM+M
5hsICG0zQtWMUncRDVCyHoVTwnEKCEkDU4aZ2gTTPam0jEnpDizZhhOFxcKw
RB/l2FPi4YzUHGHrA0RLBD+cxDozcHdhIDAJCS3AQ4sY5/SQNo8SReEcP8Sx
3macb5aO1XMS9Zxgm9DXL3chtWasVUc0i5BWLiQgQ6VM+KQNEzIOerRd5gTI
NzqUmKDHMoxwiB7xMJMeUdYjHw2oS1HtRFo7MaoujImiGbIjDNa6O3TOTouz
2+sAJawDWTMkY4JELWDnMMQYQngX+clb5vxbwxNvOmev26dW1dkxlseJ12gH
jR6MK8sypujmLMc1KrZE2J4Iz+mmWh0YiwdqS0Hs04PWtR7jRod1ia+fZMoy
BGEMJwzgFUHqcFIaL1nHZ0OTE6Gl6cT19amPbmw8fevqt/9et/zN27e+/+DN
P3z6wd+ffvqvrx//j28++/vX/33b969A4f3us7/95smfv330+68//cM3D/70
3aN/PHgb0LdvnLs+ER91yJNG0XjAvDoaOzdburCydHb1TC4zzeWZKmqgr+5s
eGFbfUPNTiBhoqHVWGQNCnwK3HWgp3F7Z82rlfufaTz6q/ZTr3aWb++r2Qtt
OoZsK0e0ljeUVe56eev+7bvbGlpsRns4GIuGY3azRSWR+K1mj1o+LOLkLZoF
r6VkEGfl7IJDnbEAv4ZkRCeIqJheIdHOgFvIA1p0uxHX6aIPRvjIhBAZ5cFi
fHhKhAIit5M+aCL1KVBtQMDGt5VB64/1VR8aaDiF6G6Cg1pwiL7WpsqtW38F
aMfrLx3e/8zxw8+WHXu+7NiLVWWvNdXu72g63t5cDh3o6G5raGusa2morzxZ
sXPrjud+8fyv/vO5X7yyfce+I03tXWQKns8mcchQLqFPRuuXkns4iGYCqBrb
W4sDNZGgPQIyVivi2VQcv0UWd+sSHn3MpQXGlN+UDpjDDoXPLHZoOCYZzSih
WOR0p5brNQoNWrBGOSARdfG57Wx2G5vbyRH0cUVgoQyuMpK8YcXEXPDcldKF
axOL68nRSY9nQuosihw5jiVNMyWI+jBG7YMq3H3GMNQUgZhjYFO0Xx/qVXjb
RI4GrrmaIOvHinsJom6KBLAbCBDOtRa0zopx+KhmJwGIndphojnEcaWlnlGN
r6hTR+XSAFvgHhK4oHwnjGdF8U0kkZWu9jM1IYxupM+Qb9fn2qTRDqq1HSVv
G5KXoeUVdFsfP4AnDaMRZjDcCoLb2/l5pGoCa5jAy2NwrmWAo0JINHS1Xqj1
ECxhqi1GBkKsLjBoG4F4R5GBEsqdh8ZnSZklbnyK48+znSNsc5CucVFsq036
+QbpWC0v2cgLd4j8YOkwUqnHaGVoIx8xLETFtYSCk5Z3E0cc8Ih10JWDxSdJ
+VluviRIj3BzUXEpqpmM6acT5tm0eWHUPDdpnJxWZkrsQBrjiIFdMZgvAosF
EDk3YtSOyFvhcRvU7YJ506TomjRz25J/w168ZZu+bC4tSEbSFLsFoTMMWn1Y
W5yiDmOB656zILJGgfDMtA+TLHb0z/zapgbMKz360x2aSZo0i+dFkfwgWhIk
6OJsf0GTm3YtrqbWVnNXz03du3Puqw9uAW77w8dv/fTJOz/ce/unj9/786P7
f//iAcDvP7/97B/fPAbg/fOXnwL8/vM3T//145f/+O3nf/rm4Y9P73//5MN/
PXr39/duPbi4eCEfmAkY5iO2ixMjd9Ynb6zOXllfvXD63Nz02rBjBIkWHisf
2Lan5dD+VypP7GxrPDzQVQ6kaFh32WDbYVDjntbyLX11u6CthxFtxxGtJwF4
Yc0n+2uPHHl9/7YXXt316vb6inqzzhL0RyKhqN/tcZhMdo3KJhGENLJpr201
NLzkNi45dVN+c9Gly1vlGZMkqeNFlcyQhBQQYM2EXiuxx80AA/wmxWgAYUBp
MTokRHrZMCsVpMK08wYbyF2VqJZT0KaTsNZqVG8LtKcZBe6srznxwgvPPPfc
M8+/8J/HDz9XcfKVmvLttRU7Gqr3trec6OuuAXU3DPa19rQ3d7Q0tjQ0njh8
/LWXt7347EtbX3pt3/HKqqZWGArN5tBFPCqfhgD4FRK79VyEmjYowHVToa3I
zpqBlhpEbzsNg1By8QDCQZsi7FABigyro04NMAJQe4zCYS0XKL82JdOuYg1r
OJtl2U50WHAmHUolh4pEIL4AJJBARHKETIszDbMiGePsWgK4tp69Nj6zGs9O
uHxTcoBfC3DxHyHrozig06kDEKW3T+XrVXp75O4OqbNN7GjhmetZ+mqauhwn
6cP9m1+qrPdnfjXWTX5Nw3itdUhlxWjdZFuU786rPKNa56hGHhSLfXSRFyvy
wHnDULYJztHjBWY634yTuGDqWK8m3apINHLcjThtE0zc1M85gFXXcVxgQZBA
8+DQNhjC1o/zgbgpqHJ8yDhJUMYQLGMfTTLIleJkCrbeR7JGaPY4xRzBmKNw
VxaAFxOawATH0cl5enaZl5zlR0oCf07oinPNPqZ1tU47VyUZrRKkG4WxboEX
zDNCgYublAvXcVE+GSFrZY372EU/OeNFj3jgkSI6P8eYXBJOTEtKBel0Rr2Y
s6zmh9cKzrWia33KubrgWF42TixIM1OsaJEQGyWO5AjZBL4UxI57hooudMaN
DvlRsSIjsSZJXzNmb5iL14yTZ7WFKX48hjfrB6wW6HAAZwwOSd1wTZhgS21u
nKKzYU2WIbMNYfHBrEmIZWLAsNCrWekA4OWE4UAT5/hQqhjdVVCk55wz64kL
VyZvXF+49/b5Lz+++/3Dd4B6+9uP3gT4/eOje3/+7KO/ff7pP74EEvImv4D+
/u3jn+ef//bt43/8+gmgv3z98Icn97799J0f3r3x1a3z9zdm7s7lbs+l31op
vn164u7pqXcvrd09v3HrwsWr567NzWzYLAkonHuyYmDfzl37X3/9+P69taeA
alnR21zZ03C8o+YgGDC+jjJI63FQw6HN+Fp3uKfmUGflJryvv7xjz7Y9NeW1
NstwLDIyEk8X0nmP3S5lMeQMcsysmQ0OL4ccZ2Ouy0nv2oh3MWKf8hpG7cqs
SZTRc0fUzLic4qRDhqn9AL9RASorxwHKyLBZKTYuwwApGuBXiW7jDtZSe6oJ
XVVDXTWAJ+LBXfC+VuRgV31N2csv//LFF375wou/3LPrF0cPvVxRtqOmcm9j
3ZGejhpIfysc0g0D9/X3dHa0NFeXV+zevuvl517ZsWXnscNlPQNwNJ7E4XHF
Iq6MTxWzMCLyAA/bpaQPqhhgGRVCR3T2N5U3njzYXHGyr6UJB2sHGDcpWW6z
5GeKQ3ZlwCr3GMWA3AYBwKxDzQYQBizYJKUOm8mALHq8WoES8AfYnD6uACKQ
InRWmjMky095Vi8Vzt+aWrs8WloMJcZs7gmprcA3pqjqGFYVRqhCYGVwQBXo
k7jaRPZmrqmOpa9l6mromhqqsposryRJegGRxb0MOUigBf/Mr9aG0WzOcqOU
VqzBx3CmZJ68xpHTmJNyqV8o8tKEniGhB8KxD9B1YLoKzdQQSDII2zgg8XXK
ok0Cfw3JVAWTVPWxqjsou+jWLkkEJ4iQuGEqzomAWfpIITArAVGPD1mnSao4
kq7rJvN72AKURE4zh+m2OMMxQnOkiK4cPjROik6RotOE1CItt8jKLwoys6LU
lDRelAdSouEwx7JaqZ4tk4xVCDNN3Gg33dZDlvaRmX1cGlTNQntklKyVU/Sw
c15CyofOhFHpSXxpgTm3LJ6blsyMyebzmtWCZT0/fH7cd3bKe3bOvbHkWl+3
Lq5pJpbEo/PckRIlVSDlk/hiGDcRwI77h8ZC+HScEM1To/O8kQ159qJm/JJ+
6rS6UOTEQ0NWfZ/HhfSECUYvUumGGcJEU5iismMUepjaCDPYoSY/zJKEGMcG
NJPdipkOfgxDcQ/grb1sF8qQ5EVnrJOnY8B/8+bdlbffOPPpB9cAfr+6dxso
vF+9c/3XH97509OPf55Y/ttXD4Hk/PNdYED/+s1TgOI/ffHJz/d/Af32wXtf
fXDn04vL9zbm3loqvbk4em9j5sGV5Y8uzN9dHf/o2pn3Lm+8ffnSezffvHPl
zZmJdZ3ai0Hxak91HNtfs3/HscO7j1UdrWisqG6pqmypPlVfdrC99sRAa+VA
azlAdGPZnmM7n9/xq2e2PPvKwV2Hju47VlfZ4HL4UiPZbLqwMD3vGx6WsBgG
Iafgtc+HXetRz7VC9NZY/EIhfDYbWIkNT7o1YxZpzshPqugxCdHLRgD8uqgD
AL8FFbGopYxpyKNKYkqBCwnhFkqPHNXEHaxh9FXT+hsog80kcBsR2gPvbYGB
OhtrKna+9uqO7Vs2te3ZQwe2lpftqzi1v/LUobrqky2NVW3NdS3N9TXVlceO
HN21c/eWV7bt3L67tqoRDkHzRFK1Rmc06DRyoUJA1QhIWh5GQYeIyb1yGlhK
g5Bhnd11ZacO7T6+f0/5kUPNlYeQoGYxE2vTCPw2VdTz30Ea8F9AXpPIYxAA
zgvAaxCTtQKCUYo1KwlGFUEpRvFY/QwGiMWD8KUowzDHn1SPLwXXro2euVma
O5dMTzsCWQ0ArynL1CWJ6gRGHYdrYmBVtFcV7ha5m/n2OqahmqatYmjqmNpm
pqaVoW6lK0AAuUxFP1fVL9JCZEbEJr//dl4AXrWTbAnzXVmVu6AzJ5WqkBjI
zwC/HAeM4wCxbL1UDYgghuAEcDS3nyDrZJqbOa46pqMaq6kEccpbiae66AdF
AaQ6RRfFKNI0m+TFgPWdBC+Il4TrJ4m2aaoqhmBqu6nCHoFsSK1j2xJse5Ll
zDB9BVZkkpWYYyfnGYlZanGNX1jmZue4mRlhdlKaKsrCaZErxLKsnVTPHpOM
lQnS9XR/65CqFUZrRmI7qNgBMQnpEJLjBkbGTk25sNkgppTClWZI80vslWXx
0rRkviBdzqvX8qbTOduFCf/5Se+52X/zu2ZbPm2YWVOOL4tTE7T0KDmfJhSj
2PHgpsYiuEwCH0kTw5OMkVVR4axqYkMD+HUuTYt4kW77QCQ8FIriHYEhWxgP
BAmdCyvU9su0g0r9oM4ONgWh5jTcMApRjPWIRjsYXhje1ItRdzFtcOOIIDHr
mDmb2rg6cfPO6pt3ztx7++LDd68/fOPKw9uXvnzrxm/vv/3Hzz8G9H+WZwDM
/gzv//rhS+AAOP+7hx/8+OD9X99/69ObF26vzlwoxM6kgytx93rSd2Mq9dG5
ucfX1x5cX3/v3PxbG4tvnl1/9+rV92+8eW3jaikz7bGGySh1Xyu5/HD30b0N
xw/UnjpcW3Wiuq6ipubEydqy49XHD5Uf3lN2cGfZoR1Hd7+677Xn9m47UHmi
tvxYdU1lk93iSo7kCrni0uxiIZWKeVzj8dBGKbuRjV4eTbw1U7g7nrw0GgJ0
NuNdDlk291W2SdMaZkSE8zBgdnLfMBkE5OcxNXXSyJjQ0UoaSlqFC4vgDlqP
GtMshNXxoQ08RBsP00uFdZLhfZDOZlBHU035yde3vbZvz979e/cdP3awrrai
taW+vq7q5Ikjhw7u379vD/Cl13fs3LZ1+2tbtr2+Y8/xo2VdHb0MKsegtbhc
Lp/X7bSZtTKejEPSAMSJ8EByM/AxBiFOzkJRUT19LdWVxw8e3PP6nh2vnTiw
raelkkWCGRRsn1UZ95pG/JaE3wi4MGDHfosE6LxuPR9AGIjQVgXDKqXaVUy7
hmVQkKUCNJ8PE0hQEi3O4GJ6U8qxFd/y1czy1dT4uj82bvCkZeYC05SnGfMk
0yjOPIo0FiD6bK8m1SHy1fCGq5nmKrapnmdpF1j7+MZBrm4QyMw89QBftSmh
Biw1wJQWFFB7FZbNJx3ofSxrQuLK6YfzRuOIRhWS6keUQg+FZu6jm9sZli6K
phfF6R0k94Ap3RBGE0JQgVWfIuor0IrKLvqpWuRRsLBSFsZpMmx5iqkZEzHD
eKhxk1/5GH5zw4FJsjKC5Or7eCqw1kQZdkmBtOnIcN2j/Oi0KLkoTi8J04uc
1AKztC7MzrH/fduLlRwVxLICf4zrDDBMK0dVs0ekxVP8VB3B0TDAq+7G1kEQ
7UQ0WIBHmrmkkJaRtFNSXuzYCH5mjDw/T11f4Z9ZkazPSFbHZOtjmo1R80bB
dnHcc27SdXbGdWbReXqTX9PMmmp8WZqbYeXH6YUcuZgklCLY8fAQADLAb6pA
SU4xsyvisXX5+JIMMN+RCC7sgEb88GyaMpIk+WPESJbtSzK1wyiprn9zyyPL
oN4JNoXhtizGXEQpCgP8VBfR2I+Qt8NErWQdRBPkREqWybWR05cmr11fvnNz
7YM3Nvl9+u7NL9679f3H7/z16Sc/ffEpoD9+8eDPXz36y9eP//btk5+XUG6u
ovz26d++evzHJ5/87pMPPrt99Vwxm7ToLEyCW0hL6MQzfsu1iZGPz88/ub7+
+Orq7fnCzfnitYXJG8vzd8+cub1x/uLSmZXxudDwnIIXQA+I2uqxFSe6Du2t
Obi3/NjhyqMHjh/Zf/jQvr1HD+ytPnW8q7UR0tsO7esAAOrrgDTWddZWNRt1
9mxqdG5mcW1xdX1x8cLy4q0zK3fW5q/NFG5O5+5O5wALvpDxXR0NXxkNbCQc
KyHTz8/bHZGSnFSwjdAD8BvjbfI7YaCPa6lFNTmjxsalCDcLZCS1q7FtClyH
gtSnoEIFuAEeAYECdYLaWypPnNi1fcfRw8fKTlQ0N7eCwVAsFo9AoDo7u2tr
GstPVZ88UXHk8Injx05VV9V3d4HwOIpErLRZXX5fJOgGurrVpJaKmAQOAcoj
DkqoYBkdapWRzWKynI2hDQ1A+9raGmsrTh47eGDfiUPbu5sr6HioRsIcNsqC
Tm3UbYi49D/zG7BKAxaJ3yz+3/r3bngaLkC0VcvSyIky2ZBEjZYasToPzZ0W
ZxYts5eCs1eDpY3h+IzSNyqwTdJtk1T7NNkxi3fNoR0zYPNEl2GsVRQu5/kq
ea4akbtN7h6Uu5BiC5KrgwqVA4D4chBP3stTgsQ6iNKG0bkIqmGC1sc0RYX2
lNqe1VszBlNSp4trVREJ14mjGLvollamtZOk6oTQ2jvRrYDakJXtuEMg9kGU
rAwprelhVNajy3CaTkmYpMvxjCWxcVLKiRFxzn5mBG6aZVhn6eZRgjIE31xf
YcXY3RxfUG7L8IbzfP+EJLmkyq2q0oADLgrSC7zMHDdapARShMAIOTRC90dp
7iDN7aUZlg4qZw4D/HJH6jDm2i5aeSemAYbpo5NwUhrZLmbFzbysm50NEYtp
/FSRuLJA31jmnluSnJ6WnBmXnyvpL4xbz5fsF8ddP/ML+O/pVcfyumV2FYjQ
ssIcrzDNKZVYEwXaVIYyk6ZMZinFPKU4xRqb448ti0pLEqD5plOUET827kQl
YuixMUYuz0hmmNmSOJTkmJwYixtr82JMboTBB7Um0K4S2TFJUueRvDgILe+C
8lvB3FaSAqxwsYN5y+Ry8syFqes31t68c/bBB7d//ejDn/69NhKIzUDh/f1X
D//49aM/ffP4z99+Buiv33wGUPzXrx7//jMgVz8A4P3p0w+/e//N9zdWx1w2
JQGDaqrgQLs9IvpcyAGkaIDcR5eXPzw9dXs2f2M6d76YXM+NnBnLXp6duba0
dHl+fnH8djq87NCnJDwHDiXobEM2Nwx0tkOOHalqbOhAwId4HKFOo7fozUqp
jE1ncBgyLIre0dpfXdEsE2ty6bFzG+fPr5+5snH6zsWzd86u3Vyeub04fn0y
cz4bvpAJXcp6bxTD18dCF5KO0xHTalA/ZRUlZWSAXIBfN7kvzkcVlOQxFSkv
x+dkuKQCHZPAvZwBK63bSO7SUXoM9EEDG62gIWUMLA7SB2ptPnX0OFBpK09W
N9S2DAygqVS+QmFSKs08noxC4eDxdByORiQyaVQ2UHPlMo3RYHPYPS6nf1NG
vVEhlrGpHBKSMTRAQ3VxsX0AwjohTivACxkoArIP3NPS3rIZv0+eOFZ+dHdP
azV5CCzlUYxKntMk99lVQJD22eRAC97Uv/n1mUReo2BzU2gxwyFjOBQMk4qq
U+EVGoxMhxCb4foA0Z5hxOflxQuW6euO8YvG9Ko8Msv3LNLdi2TnAnZ4AeFY
6LfOdRqnGvWlWlmyTBqrVESatDGQKY7WB/BiC5qlgPLEPVxRN1vUyRR1sCVd
AiDmObCGAN0c4dpTUlde68gB5Gp1UY02ptMnDCwrYL4IhrWH6+xkO9oJitZ+
UnMrrLm+v66u/1QD/FAn+RBUcAola4QK20CsVp4LI4tS7ZNy/6rJPCVlhTDU
AFSaxQ8vCewzTH2WoAggVG602U91Brkuv8Cc5joKouCsInvamDutSy5IR+b4
mQVRaJTiSgzZg8jhIMYVxLu8eLeP5AvSdQub/EpKpzjJBoShupVyqgPTiCJC
xTy2XijwaaRpl3w0JMzHKPkktlAYWpmlnllgn10QnJkSAvxemNBfmrRfnBg+
P+E6O+U+O+c9u+w9c9q9su6YXdn8kHVuhpef5hUnOZPjnNlx9sI4Z36SOzvN
m5zjjS8IxxdFpTlRbpSVjJPTIVI2QEomMeMTnLEiJ1cQFEuqSJxrcxOCI2xP
jGQLo4whmD095Jmiu2eYujxeEIaiRD0QThuU1U6WwZXDnGDGNrWUPndx7u7t
cx++ffXrh+//5ddP/+cPXwPZeHN66quHfwKw/e4JcPKvv376l++eAPwCRvyn
zx/88ODD3z2899v77379zp0nt67eWZxJmrQ82MBQSy0b3GPjUSY8pjtzhceX
1x5fWbl3ZvrdldLd2cL5fGQh4pyLus/kEhfG8+eL+fW5y/OlMxP55dHUjN+d
1KgcMplJp3OaLH6bze9wAH4VjYazmdR4JlmKR3IGjYuE47Y19Z84Ws2g8oD+
e/XClfPr61fPrN8+t3Z5YfLy7NhbazPXJtLrCe+VQuR6wXd3InKrGDwft60F
dMte9YSJnxDjHKS+YUKvl9qfEKBzcmJORkiJhlIidFwMDwnAXna/jd5tonQa
qX1GBtjARkrIEDEVjR3o7mqoP7b3wM5Xd1adrGtr6MITBXKlwxfIBMN5hzOm
M7jVartKZTGZ3Farx2H32W1uQAC/Djtw4LJrFGoBR8ogSOg4EQXBJQyIqFCA
XIOYpBORBHQkCtLR1lRZVX786JFDe/fuPnV8X2drDQ49yGfgVGKmRSdyW5Qe
q8JrUfxcgQF4/12B2XY53SKhGHkEo4BgEhMMSrxOi9OY0SobXDYM1kXRthw+
tMguXFJM3dJN39QULoiT6xzfOtG9gnEsQixz3abZZv10tXq8TDl2XF04pc7W
6LLtthzcmSOYI2SJGU2XDrI4bYDonFYqp4UqaAeytNKJM4VZnlGNf9IUnHI4
R626mErmlSn8Kk1Yh5HBCNpBjhMkCfbyXJ1YWUMfsb4N3lrZWVPdU9kIP9FF
PgkT1Awp2vCaAYIGro6z1ElOcMmYueQxTgipnkFGEKIepXhWxLYpljaJl/tR
Oj/BHmYOB1hmF82Q4dhHReEFbXbDmj2tj81LYzNAhJYNJ/GWIMLohlq9KLsX
Y/Og3T5CMEJTzx1WzZwUFk6RAxVwfQ1C3klT4eV6id89nA14p0f882n7VEpZ
SNIzaWwmi1qeoazO0NfnuGfnpRfndZfnLFfmXFdmvRdnvJeXIldPx8+vh1aW
XNNzxvFZ7cSCPjsrKMwKi7PCmVnh7KxwflYAaGaOPzXPn14UTy5KS9PCfJ6d
jFNHguSkn5TIYbOjtLFxwWhRlslKR5LikZQkmRd742RbHA3AG5xlpTcUyTNa
e4krDmNpajSY2kZXDRkDMqWVa/dr55ZGz52f//D9m08/ffd3Xz/62/df/v37
L4CcDFRdQAC8gP76m8//8dsvAYT/8PmnPz6+/+PDe7/+6N1Hd65+dPnse2dX
AXgvlvJ5h1lNwlJB7SYmqeA0nM3F3lmZ/PLmuR/eu/a7d689ubzy7uLYhXxo
Le5ZjrkWoy4A5NmIq5hM5eOJydzo0tz84vxScWwynRnN5CdG0qVsfrY0sbq8
dOnSxbdvXvvw4rk3V+avhnwZLIpx8mgd4L8sKieXzF84vXFxdeX80tzlpenr
y5O3lyfuLhRvTGUuFsJnk97rOQ+gc1HzrF0CkAsoq6SEWHDrUKcaXK8G1zoJ
3VEOHFCYBQVGJ7Xbzx4I8MDD9F4jucNEA5lYYC0DIiIOiogIIhTUWV978sDh
Pdv2AB0cCcapdT7b8EhsZHq0uDJWWs3kZlOZ6Wx2OhLJRkKZgD/udgWcwz6n
w2O3Ok0Gq0UmtsiFRhFbziRw8WAGpoeF7eOTBpnYPiahn4odwMC6utvraqvK
gDZ9/PjRnyfEwP3tVCJSyCXJ+FSFiAZkaZOCY1FzhrV8ICq7dDyPluvV8Xx6
vhm4FABVWjJk0eHMliGtHabzw61JtH0U5ZsjpC6wxm4Ixm8Ji1fZ+Yv0zDlK
YANtW+hVFWsl2ZPC3CHx6EH1xHHTfKV5ts443mgsdFhzEFMcKXdAuap+uriP
SKwhk+vwlFoMqQrHbODrYOYI2zOmis7bk6v+0Ix7s/YGFeqQWuiQ4CVEhGiQ
YoTw3CBZuFfk70SJqppgxzbNt6+lDlRfDy5vGTrRz6rAKjsZVpTATVOGme5J
dXTNGlzWmYpsdhDCCgxox8juBZFxlC4PD8m8Q4YQ1RHj2ENsg4sM8Ouf0yTW
zYk1Q2rdlN8wR2eltiRJ60eqnRCzH+0fofpiFKsH7Y2Q8hNSw1KVcalBM9Mu
zvWwQoNcL1ETknvizlIpszxROD+bOzcTWR43ThR4hQIpP4ZfmCEvzTJPLwjP
LckvLhsvL9kvL3ouL/ovzAcvLUUursU2ViNLS96pefv4nGV8zpSaFKanBYUZ
QWlOPLUgmVkQzy6JZpZEcyuSuRXZ9KJ0bFKYyrKiYXLIRwi5CdECIVlk5Cck
Y0X1aE6bS2vSWUVyVOJNkl05vGeCHF3hpc+qE2s6Z0mqjbPZagKSARLqaYG0
3RuzxLO+jXPzt29ffPDR2988+fiP333xzx+/+edvv/7Hr//9UcHvPvvrb774
63efA/rLt0//9PVnv3/66Q+P7v/w4N5399/9+NrFW8tzZ/LpyYCn6HakzPph
AcenEIz7HReKmVuzY28ulu6fmX98ceXxxaXPr669t1Q8k3CP2ZUpvTCpFyb0
oqiGDyTAzfUJfvNkIT4/MzozXZqZm11cPb1x/tqFS29cu/H+3Tceffj+N/fe
/+bOjYfnT789ml0QsdWN1Z3NtZ1ijmQ8M3pxde36xtrVldkbq7O3V6feXJ18
e3n87lzuejF6Meu/lrRfTznOBnXTJl5BSc3KSFEuCnBeM7rdgm4F4A0ywBE2
zE8bAI4duE47qdPDALkZICu5U49vN1C7jcxBPRMqxPVJqUgBGUNGwvtaOyqO
VTRVtRIxdJ0xPOzOxpMzo2NrpYl1QNNTp+fnz44XF/K5iUQ8Fw7EPS6/xWTX
q3RqmcoqExqEHDmDCLRpOgpEgnYQIC14SAsF001CdQ9BOyB9TR0t1fU1ZVWV
JysrTtZUn6qrO9XRWgcD9+AxYAoBxqagRSy8gkfSiClm+eadX0A2GQ0wX0B2
KVHPR6r4EI0CYrQgLAHU5l2VWbJ7BhVZJxSuM2feESy8J5x5g124gk9tIO0L
neqxal7iMCe+l5veK8zvV0wc089UmGcb9MVGdapFHemROXtYijaAVgy5Fgkr
Q6PLUdhKNKmGzO+QOXCuggKAN3cu7J2y6EeU+oTGkjJpglq6ig6lQwF+6Ra4
NARTj4AkoQ60pKIFebwJ3NgG7WsGdzTBalux5QOsaoKmh+/GKcJsfVzgnVAH
57SuKaEmQ2R4uunuLkVqyDBG02ao6hhFGaJoAjRjkGEKMIx+umVM5J3ThFdM
4SVdaF4TmAEaMUvhQ6m8KJUHbgwOuRIUN6AoMZpjF+dVlpV2+xrItoowzuI0
YzRjQeofd+ZnkktLpfOrU1fXSpeXEyvTlomiKD9KyY4Rp6fJ8/PMtSXR2TXN
xdOWS6edl1d9F5ZD5xZDZ5cip5eja8vhhcXA1JyrNGMbm7FGi7zEhDA9JcrP
S0qL0okV2dSKFND0qmxqSVacFWXHeFGgjwfJHi/J7SG684RgnpYYFWYK2kLe
lMsa0xlNPCv2ZKnecXJ4iZXckGTO6eIrxsCEzpFRKa18hoRg8agmFnMTc7mp
2cKVKxvvvX3r80cf/fbLz/7y/df/+t2vf+YXsODNdRrfPAGw/dOXj/74xcM/
fP7gpyefAPD++qP3Ht659sHFjbtri2dL+Qm/Oz9sTVuNQZUsqlfORDwXS9nr
U/mbU4V3liY+Prv48PzSZ5dW761NAoF2xmcEEC4Oq/N2RULPcyjwDhXBb+Hl
E7bZ8djSwtiZjZUr166+8/5HH9z/7KNPvn708Ienj//w6JPfvffGV9fP3b+w
fjPkTg1ByajBIZ/Vszo9c2Vl+a2LG9eXpm8uT7yxOv7u+sT7a6X3lvNvzqVu
T8RuJB2ANnyacQ1zhD8U46AAn/VSQC5iT4gJifOQgOcG6INuUq8d22FENNkI
XS4qyEXvt5K7jcROgF8zE2ziwLRshJKJFpBQZCQU1NpWcfhUR0O3mK2Qq1xW
RyKamCqMLY9PngbgnZvbWJzfmJ5cKWQnUolcOp6JBeNuu8tmsNiNVjWHKabg
mWgYGdpHhHTjIR1DA83wvno6rh+P7IT0NXS1VDTVnaivPl5bdaKm8nhjU01d
bUVtTXlTU1VnWz2ouwk52EFAg9hkuIgxpBGQTFKqSUoxColaLlbFRgLmq2QP
ilk9cilIawXbokhvERtcwofWhhIX8MW7jKX7gvVPRIvvsUavYBKr/dqxKn7i
MNW3gxbcwUnuF+WPyoqnVMVqbalRlqjju2uZhlqCqBJKONYHPdjTf2ig7wgU
UgZHV6HI9XRZvybA8E8aE6vuzPmwIaMS+XmGEa0laeQZ2QgGbBAPggkG2Q60
ZgRtyA7KIh0YaVk75kQ7og2EhfegIR3o9g58DZhTR9b3SoIEQ5pvT8t8JZWz
KDKmyfIIjO5oIVobeIF+SRStTlD1SbY2ylH4qDIXSeujWqIcx5TcPacOLOr9
C7rhcak+yZL6scJhhNwzpPYNGYI4a5zoTtMArLJz0rFllfccyn+e4DtHd65y
LbNCx6QmMuspLCSm59Kr89nzS5mN+cDCpL40JswXGYVJWmmGMrvAXl6VbJwx
nD/ruLDhObvmP7McWFsMrSxEFuZDs7OBqVl/adqVn7BnipbgKD9cFMYnxcl5
SWZJmluS5FckhSVhfl6Ym+anipxIhumL0dxh6uaTmoN0fWrIkiK5krxoSpVK
mVIj5lhc6U/w3DkqYL7BFUb8nCRzQZ9as0Wn7IG8zRuzmV2a9Gjkyq1zN+9c
vnxl4427Nz699953Tx//+NUXf/7NN//44du//+ZLAFug5/7xiwd/fLqp33/2
yU+PPwb048P7X3/w1qO719+9cPpMKZd12+wirow4ZGDTIgZ12mGOGRQln30x
HlhJBNdHghfziStjI5dzsUu5yLWxxGZ+TrjWRtwbOd/KyPC4R5O0MeMWZsop
Ko1Y5kuR00ulyxfWb9+++cGHH3/88ZMHD755/OD7Jw9+fPrJ7z5+95t3bjy6
unE3GyvRh1gkJDHmDCyOjs7nkpdmS5dnC9fncncXc++tjt4/Xbq3WnhvMfPO
7MidtOPmiHXDoxiTkwBgAVQBt41xEQC5WSk+LcYCJwGcgfP/bcH4PhcV7GVA
PMzNh5rZmYM2DsTKR5qFWAUDycQMYAZ6W6trDu/a31LbqhCo5aphhzORTM8U
x1emJtenptYmx5fGS3OTpfl8ahSAt5DK5UYycV8w7PICo8+gHVbJzRK+Qcw2
STlWBR9IwkYFUyEksilQNLitt72yo+lUS0NZc/3Jxtrjbe1NdfVVFZUnKsqP
V1ccq685AbgzuKeJjBlgE2Ey1pBWQNCLAM/Fa7hoNQupYELl7M3PH6m1MIMT
bo4hgeTsnEFGz+Lil/CjtynzH7BPfyxcfo81dgkVW+rRjFYKYofogd3c6CFJ
tlySrxZlaoUjtexANclUjhQfG6Qe6EHsbe3Z2dKxq6NzXz/oBARSAcfUYOlt
LBVcG+K4xvX+eZt7xqpJyRVRiS6mFNm4MPpgH7oTSQYPsHvZjiFDBmfKD0rC
TRjZyW58WR+uF04lQEiYflI/iNYMFzRRjD3iAEafZnqySv+ozJpiqCNIaaiP
5WwimWsZjg5JCKmMUXVJvjYmkHjpgmGi3E8zj/AAfj3zmuCK0Tev02W4Ag+W
50RLA0SZn6AKEtSh/5+k9wxqLEu0Nf+/v/Pem3dN39vd1eV9ZVb6JPFeICQh
JBBCyCAh77333nvvhRXCe28Tm5gkvamsrMqu7urbfSdiIubnnKyOWHFCwBGI
gG+vtc7R3hvKs8J14V7PAM1doBrjGPsCzjbXZ5wiyof7BMk+QYSiivBtUUUw
qsvEjYNp/VBKmY5xolESUFQjWUIo1x0fwGVHqcPjvNEJ6cioamBQlctpMmlt
KmVIJAyRmC4Y1XjDSodPZHHxND6CLkAwRommJMmcJZqzBHMGa01hLHG0Odhl
cHeqrQipESHSdwr0XUCK6Le00MwwvhGjMFL0Ro5Bz1bryBI9SuqCi0JgWbpd
P9LrKnHdIwpHQm3yqaxuvcWuyRbiewcbDy8fnD44vDw7ef3s8Zunj9+9ePbr
D6/+/sPLv79+BqTlf/L7l4cP/np5+svFyc+nh29P9l/sbx0tTC0OpFN2o5ZF
oSAgqAbgj3CXAGkWE3uVNKKsD61nEB18RkDKyxnVEz4HgPCgRTNkUpbcxim/
ZSponYs7VrK+uZSjGNAN2gR5Cz/nEA/6dcWkZ3okszI/vbW5frB/cnJ8eXry
9PTo2cPjl49PXj85fnVx/+ne8nHSl8PCscjmdpNYEbPZ4hZdKeqaSbgWk471
rHt3wLs/5NsveLZSttWofsHGn7fyxrW0BLvLgQWZUHWALOgGJ67FS4QAR2NX
LYCwDQcCoNYgq6SQalVHnQ4NMmBbNZhGKbpW1FMr6G2gI6sJsGpUSxW0vrLs
6pUP/vV3333+HbYLJ1dabY5IKFKIxQaj0Xw0kgHgDfljyUgq6Ap6bK6A3eUx
2yxKrV4qM8oVWi5XxWErWHQZkyyh94kYBBEDJ2LhxRwcgHAntApAuLHy+/ry
KzV3v6u89fX3QPv9+rOPPv7jnz78z48+/P3nn/zh6jcfl13/srXuTgeoAtfR
QEG3MDFgwHwBflmYFnJ3M72vjcOAcAQQrhIssLVKwxBlps1QhBpLrc4ZaGQN
WdjFFjZ7ojNQ12CdOHGD6f2m3/EFxfMdPXCz33UTrbsKl35bT/qwHPWHa6B/
+a7yf317839+c+V/3rj+b5VlH9ZUfdbQ8HUz5BoUXYbhtjHNOGGALoxw6K5+
qr2fYiLipOg2XEMl+GY16FZLe1VVd3mvHMLztnG9FX36b8GUj6qQn9cja1u6
Ea1oZEtvC4hQ0Ua5jeSX4dR1FHOb0kFSOQkCM5SurWaYyvt1t9DS79CyW0wH
nG7pppuxdFMfWYftU6OAsM1z98kSVG2eYxoWypN0ogHRIajvlrUwrGiauZNu
RtJMcJ4TaQCssMjSJTBUfY11hmyYJCmGcKx4N9nTRbajuY4+pYPuCUtiUXku
ocjHRYkIPRLpjyRJMSAAjxASxf7MBGtgUlAYl2ZHZIm8LJpURBPqGABvwhiK
6b0htc0t0dv5ajNb6cKrvH2qEEEd61Mn8co4WhHtVIaRmhBS5emQWdtFBhhP
B3+/nbGmEwgSveaWPmM7Td/DV5OlcqZMQhXJ8FwlgmeDcnxNgnirqoCyDjNc
A3JHTGvxaDV6mcWuy2Tj2zvrz589evPyxU+vXv31p59+fvHyl1cvAX7/8QbI
z+8t+NeXD399dv6Px5eA/vbw/N3J0Q+H9x9vrq2PDA74XAoqqR8O6QE1EKCt
FGQ7D9fDJ2LpPZ0SPErZ32tkkAB+ix7rZj65nU8tRL2LMd9c2DkZsE4ELRMR
20zCMZdxz2WcCwDOQct0yD4bDwDDwub0xOHG5oP946ODB6fHD89OHp8dXp4f
XD45efri9AWgx0cvMoEcBtIDq2kW9VM9CnncrJmMOBYTrtW0c6fg3h/yHA56
djO25ZBqxi1etPGXHcIFK29MRU6yu3xEsAPbZO9tNnfX2zBNANGAXPhWB6HV
hG5SwavksHpVR5O+B2zCQ7S9IDGqmtdVKeipA/jFQcphtTfrb1+5+tknf/g/
//L9F9/2IHrMNr83EA+H02532GH3etzBoD8S9IR8Do/b6nQazHaNwarWmOVK
vViqEYh8BgMgt1ZjUUo1QraUQxYw8DwahorvwKGaEW0VkKbbbY23wA03W2re
5+pvgCb82cd/+OA//vDH333wx9998uF/fPvln+58/3lDxbW2utvdbVV9yAYg
GNC6QYD5AiJ0tfZjwWRSG4ne3C9q5ljaJGGYPAOVZ0GKfINhBOSd6UivYQpr
2ORcZ3gMYhhslCUquIG7TO/dfnt5l+pGM/ObKvznV9r+86u6331x91++vPGv
X1/51yvf/a7s5of1FV9VV31V13AFBL0Jx9URxECg7RcGWZwgg2TDEwxYlBjR
2tdQ31neCC9vgpY1gO40EepJOqQo2A7wi9d9BaF91NDzbSsGBMV2d/T1dlJR
neyWLn5Vt+QeVl1FNNRLDT1ySw9X00xVlXGtlVxHJc1U1m+sEQbQDCum34Cj
W6hMG51uJbGcRGGAos6yAHiNQ0J+gNQtb4Xx6jEqGNOB43oJLBeG7UQBT9Rm
iNosgWyua6Z+qhjAirI9jBASa2/r1rf06toZ5h6Zo98V5EciokxM8n4+QpgW
jpIjGXJikJaeYWTnWLk5fmFGkp2QJYZlkYw0EJcGYqr3U37S1nDC5A5oDA6x
ysSV61liG0bsxEr8OGkYL45iRFGUMNgh9LULHG18cytH28JWt7G0cLoOSdGi
iJoupL6pRwcjqXto4j4Gm8hg4BjsbpoIyjC2MDwN/ARYln+/46opybcG1TaP
Qa4QOZzmdCa+uDDz6PLi5zc//Pz69S+vf3j34uWfX774y6sX//X6xd/fPAf4
/dury7++uPjH5cP/fnT519MHPx7c/+H+7pOtdYDfvMdh4DLxkBbQ7evNd28g
G2sYmC4Vm6bmMYDymzKr0yZ1waqbiQBpNrM7kFmKBefDPiBOp3TilF6SNEni
RnHWpSzFrFvR8FY8tp6Ir2bS68Oje3OLx+t7p7snBztHp4fnFyeXZwfnF/tn
T44vXp09eX3+9GTj3Kl1Q2pa62+W49ugCjLRLeGkjZKlhG0j47g/6H5Q9D0Y
8d7P2VaCqmmHcMkumLdwJ3X0YVlfmtsdpXcA+m2NyhZAnr42HwkK8GtANWgQ
NYAMKCggIwZmwsM0GJCos0bQVSPGNvJ6G8jIOmjttbJvP/nsD//+H//rf3/7
yZftLe2Ao1qsLofTZzLadVqT1exwWZ12k82g0th1RptGa5DIADlUKptCoRMI
AIrVfL6MxRLRqex+fD8GiW5vhrdUwZrv/ZNcSNPN9ubbsKZbkNprLZXfXQPi
8jdf/umj93MTf/+Hf/vgg3/74tPf3/j2Y8CdW2tuAvwSOxsBeAGEgZfXj6jF
wEGYzhZ0dwOaUEvkg9gWGOB9DG8d1VPODJRJk7WWkbbIHCq72Jue6Y6XOp1F
uDrTzPVXksxlCMn1mv4vvu/409ctf/qk6veflf3xq7sffX/nsxs3P7157ePy
G5/Xl31XW/NtfdO1FnhZZ38zRdkr8LGEYR47QMcZezqlHa20hnpMeWPnvRZE
eSusHNRyp4vXCbikMoHi+cr7DN/A2Z+0Eq7B+sBIEq6H3o/n9xFkSLyiGa+u
JhpqKZZGoRIp0nUwpNVkyXWetUweqJUEmsUBmNDXQzf3ko19HDdHFBTxAlx+
iCFNcvXDAvOYRJXn0Ow93fK2XnUH3YHnB6iSKEMYIgvDRHGMIIr1kB3NIPaX
V5H/lyiNYUdRJDe029SC0rbiTXC+q08fZHoi/FhMlEtJc0lhOsFOppnpQU6h
JBhY4Q8sCweWpYV5WXpSFhuSBtJiT0zijSnDaXMy54hk7M6gRmcTAvBKtQye
oZtvRQtcvaJAryCC5odR3EA7zwOl6uuoqlqqop6ubGFpO+iGbiA/kAxoiLq+
Uw3GylAEbm9fP4ZA6OrrhxG4IKquieltFAIDb6FLkcKrgyyjV+70mE1mXTwR
HhkuLC7MPb44f/fj259e/fDj0xdvnz57+/TJz8+e/PXF019fPfmvV48B//3L
8/Nfz04BvTs6fL2zDfD7and7b7JUjATMAg4JDoFXlwPw9nVAxDSiWSawKkR5
h2HIZR52W8a8tpVM9Gx6/PHi9MOZ8bmIr2BWxzXijEWRc6jSVvlQQL80GDxM
5w/S+d1MYTM7tDlU2p1c2lvcur+6d39j/8HB2eXp48uTy0fH5y/OLn989OTn
R0/Pti9dGje6BdnZ0EpHoQxsWlgtTOkEcxHTWsp6MOC+KAUfjgdOhpybce2C
TzJnZBXlxCSzE3BeNx4U6IdkeOiisj/OQoVpiBC1I0But/Y0KiD3lO2V1t4W
JwFtwyItuA4zoV3b2yLuqhV11ymIrVxMPQvT3AurBpVfv/H1Zx/+7t8+/f0H
ZTfuUGksuUJjsTotZofJaLOabVaDRadQWdQ6j9niMhh1IoleKHSq1QC/SiZL
zRdKGCxefz+XTOJRiXQCugcOamu611BxtbnmewBeRGtZF6Siq/VeR9NtaP21
6vq6G3dvfvHV5x98+Pv//P2//v4///WTD//9u68+APgF197CwGr/mZ9p6CZS
Rw0eWoFuB6M7QN2oRlw/iAmw4OpmOMA9mpsozXc4y/ecwD1dHhQY70xMY1KT
PYlil7vUqU63spyVaMWNBspX38P/8HHtv/+x/D8+vPvBZ3c/vVrxTVn1jfLy
a/dufFV+7cvam9/UN1xvarkJ6azqpkFoOoI4yAX4ZfppSAUcwm0FUeqacFUN
yLKGtlstbXfgHTUkNVEZY+lzWGGwimj8Gsn7HNp/C0GGoWkkPIdOllIpmh6y
Dkw2NtJsjSxXC18KFyihFGE5gf8d13RHHWnUJaH6DIbnfh+YaWaKKCCRJ5TS
uESaEKjyYlNRDPArTdH7zJ0YLZzhIQJQA5KlONIkU5amS9P9DH8HXHbrFvbf
P237H6wUgRLpxXtQeGd3nxNLc/dz/SxJhK9PS615hWdI7h4QOHM07wAtPsEZ
XJKm9kTRdU5okRFeYIWn2d4RtjPLcSTEwYI5PODw5+yulN6ZVdhzAnkISzGB
ZBqiUIUVaLrFlh6FHyMPd/P9UKqzHmu816MtQ6vu4tS1VFMb24oCLJggbsPI
EV2iDgQTASV3gvEIMBGK4MMwemifp4UUbWSlwcIMCuj4Cr9UZTWq9Q6tRhGP
RebmZvb2di4vL3/68e2ff3739vUPAMVvnz1/c3n59uHZu4enQOf9++MzQP/1
/OyXR0c/HG283PttSfbNmQdT+Y18MKbiWBi9gq5WDgKkJKBsPIpXwvVIuVEd
L2OVDvsMU3Hn2lBsbyK3VcqtDKVKUV8p4h8Ougf97lI0sljIb44VN8fHV8eL
88MDE9kUoNXx0vHa6tnOzsnm5oOtncdHp0+Oz873jh8dnr15/PqnZz++vHi+
M72q5coJ8G4xhalgsSwyaTERLiUCYxHnSiF0UEo8GIuejoTOBn1HScu2X71l
oy/p+ooSVI4Li7MgKR5iQIUfMzOiAhQgP6vDQWyxYhvt2AYrps7YWWmlILQ4
sAzVIO2ql6Dqpd0NCixYTerQvl+NGS8k9yBba29f/erLT/70+WcfffXl5who
B0Cr12I1qRROvdar1wCDmF0hdGnEFhnXIGICMkk5ZqXAKOfpJGwlmyHnMIS0
fgqmE9vR1gNr6YI0IFprW2pvtzXcQUCqe7tAaEQ9FHS3qf56c8ONxrrylqZq
UH1lxd2rX3/+x4/+8//++Pf/+6sP//32lU9AVde7oXW4jiYsvB6PaCR0NGJh
de2dVZ24eiwNRBbCuLourhlJUtUjeN8jBN8STXdF0WbdAMwx3uWbxQQWMP75
HvN0pSJXRrVdQ7C+qUN8cbfui2tln35/85Ovr//xRuWnlZDr1Yi7NyF3Pmu4
+UlD+Zfgxmr09fKea0306i41nOTp42f5kqyQ4aWgxLC2/joQphKMq2tEV92D
36roKm+htHKd3do01TRAlSa6qc7GDtnVNt7XXfI7vYoqugkmcaBlNrTK3KW1
ILQmqFLTzJNVs8RVFO49Mqeap4Yb/Ax7QmKOS1gmIstG5LgowihTmRfoi2LT
uNQwIbYvcSUDOKofRvG0cwM9ohBREaVqE2xdkmfJi6yDEnmcRrK0t/Lu3MZ9
/HXHvwgHqOw0iR7BU3w4qqeP4e3nBhiiEFeTEBkzYmte5CjwnAVGYJSRmuEN
rkjC6+zAEt0/R/FO9TtG+i0ZojXJcKXEoQGLL2P2ZW3BYYd/RG/O8iT+XrYT
JlER+AoMT9UtMKKknh5JAMX1tgG/eK+hrEt5q0t+C6+toVugTAuCoob1ScAo
CQTBAbf1t4KwrU2YtpY+cKcQTjDDaeF2dgbCL8D5qU6eDy+ycTV2s9UZctjN
+VxmeWlhf3/v8ePHAL/vfvr5zctXLx8/ffnw8tX5+ZvzBz+dn7w7O3r3YP/n
k/t/eXz888X+68N1gN/Xe0uvd+Yfzg/vDsemguasUezgELX9aCMN75Wygdg8
5LHknepS2Dqf8S3mgoAW8pG5bGg6FZzPxZcHMqsj+dWRgY2x4a3S2ProCEBx
KRWdyiXnBvMAyIcri4/37z852D/f3T1YXT/Z3D7d2T/bPbg8OH1++ujVxdOX
58/WSgsymoDZS7JIVV69PuFyTmTiC4Mp4KdsjsSPSsnj0fCDId/5oOcs5zxK
GI/8wj0Pd8VCn9b2jSiwwwp8yUifdQsGNP1pGc7PRFpxIDOm8bfLWWBvX6uD
itBgmoXtFRxoGa+9XNxVpyKATfQuG7/PKqIoGNgeSEP59W+++vTDzz764JOP
PwQ3tcoEIofp/TZHFpXCJBdrBSyjiG0Us9RcioSGF5B7RVSckE7gU3Gcfgy3
n8Aj97H6sMBIQOiEYRGtKGgjHFQN8NvacBsOruyE1ba33gPVXQf4bWu5CwU3
wNoaoS31TXVlAMJA87199bO7Vz+/d/2L5spr7U33kKAKJOgeClwJqAtUDm4v
gyLvdeHrSFzwP9djJMiqkPyrvYrrTGe1Kg21Fjs9072heXx4gRCcw1km6hSZ
Cpr5Fop1raX7anXLlbuVX924++mdis+rQN+1dJeBCbW1mJqb8PLv22tvdYHb
KNVgajVKCqW4+3hJjnJYLsuLaU4SSgiB9ddDsDUwfEMzuroCcaeup6adDZcE
8PZhnn2UJY12kS21KNk1hOgqVllOVNZxzHClG6tz9xmcvQYHSm9pV+pAfGUV
V1HFklaz5A0yM8oUptsSAkNMIHJT+G6ywE9VprimMalzVm2flVmmxJpxEj+L
ogWhdH8HP9QjChPkEYomzrIWxAC/2hSL78f3maBQUXkl+asbmD+qx7iKEY44
x+DEKKxgPztABfjl+xmSMEsZYWrjDGuW6R5mRyZ5qQVhYUXsXSS7Zvqckzjr
CEafRauj3cYExZ2V+rI6e1zrSVtiJW+4ZDWkuAC/4kC3XEsWqQl8VQ8wePKs
CI4DxnS2UhwNgP92Km6iFLf7TY1sRzvTAqdooGQlBMl/v8BIE7amvgtQXQuh
CS2GUewIdgwuyMPF+Q5mAEbUwqjyPrVR7/cnC/n03Ozk/v3dhxdnP7x6/Zc/
/wLopx/ePL24fH5+8fLs7M3Z2duz47cn+2/2d17tbbw+2nl5uPFsd+XZ9gLg
v6+25y4WRvdG4lsD4aWkt+jWA332fYI1q8eCzoVMbCrl2RhLHc4P700NLg/G
ZzPBmXQI0EQ8sJBPbIwObI0NbRaHFweyo2F/0maazCYWhvObU2N781PHq0vn
2xvn21sPNjZ25+d3F5eP1jcfHZwA4fmHy+dvHr0AFDZ7e9u6AH7NEmXIYhmK
BIfDnsXBxOpg9P5Y8mwydTEeezgSvCg4T1Lmg4h23ys+9Et3PZIlM6ukJhdV
5Akza94pfr+7mYYe4WHc/e2uPmiQggjTOoP9HW46Qo9tlnRUCKB3BbAyEbJS
gWnS9cOM9G4do1dE7EK31VfduvLN5x9+/MHvP/jjf1TeraCTyGat1qJR6aVi
wFsldJKKTdEJ6CoOWUonAPxyiWgqFonvbANQ7YVDMO1t3ZDmztYGVFsTUFe7
YU0IcM1v/N6FNJdBQffAjbcA5wXgRcJruhBtCKBmt9VDWmpaGitAtXcaKm/U
3bvaXH0TXH8X2vBe8MY7iOYyQO0Nt4Fw29hyHdZZRmK3cjRwprqFrKwkKu9w
HDXKRJtzrCc0R0osUdOrjOQSIzZPdU3CdBkQ115DklRj6fWAd7fByxuarzeC
r4GRt7r6azAsEJze3Iivq8E11fa1dvNb0CIwzYqVZwSmktY6bdIMyGi2vk5u
K7y/AU6oR/Q1gzE1dV3lYGITRtyjiJB8E1JPiS8JIsiG6j5VGVF5j6lrBF6Y
2NylcxONnn6Tm2B09mjMcJm2RaCvERhqRaYmqR2mC+AAszMlWL/dEaZLglRZ
jG4YFLhmlL4ljWNWYhhn8zIIRgxGD0FYYQQ/2iOK4mUxijrBsA9LNEkmx4Ml
W5E4E7hLUwcR32ngXDVNiy1TUt2oUJJh8CJUToDC9pPZHhLPSxZ4+6RBoi5N
dhc5sVl+akmUWhI4ZnDmUrdmEK7KwhSx9ytL62NEZ1pojkgsEZU9afQWLO6C
3pDkKyMkWRirNbHlBipfiwPKC1kN7tc3A6We4mwk2qrR2ttAhKa7WkWBLo69
g2GAMo3wDk4VuP9eI+ZOA6oc1F0F7WvEiNoo1nZerEOSQwKiuyEYMaiP263R
qWPhzOLCzM72+vnZ8fNnT96++fGvv/zll3d/Bvh99vDRs7PzZycnz4+PXh7u
v9jfebq99mR9+XJz6eHG4sXa7MXK5KPVyScrkw9mBrcHY1sDUUDr+ch8yjcV
dU9EPJOJ4PvpRYOJvdnR07WZo8XxjVJ+aSi5NJheHsosDqQ2ioW9yeL9qbGd
8ZHVodx4NJB1mCfTkYXB9MoocGZ+caSwMVm6vzB7uLS0v7QIUPxw5/6To5M3
l4/fPXv1/MHFweqmnq8EwrNeILXKlD6DYSwZy7gtU0nfxnDsaCL1dD7/ajH3
fCJ8lrVu+6XLFvamQ3zfp9zzKZes/JKKNqqhTVkEi275pE08ZuIPqBlZMTkn
JmdF/TEGxo1vN2MbNF2Vio4yRWe5ClWpRtdqe5v0RIi0t0WEhbB62nDtjeDa
u+U3r3z35aeff/ynq19fQSGQaqn0/a6+cqmURRNR++QMEgDvPyVnkYQULKUX
AcALWDe8qQZSV9FUfquh7Aa45l5nWz3Abxe0HlR3u7n2FqjuJrjxDqS1vANW
hULWY7qbe1BQFKIVAWuCgesAhCFNFa31ZS31d9pBlbDmin/yC2ssgzXdgdbd
bKm8WldzrarmGzDsJpXTJjN1iS0wsaNFGWg15xDBSXxujTW8IxreloxuSQfX
pNlFQWyO6B7CaINIub1HaSYC9sERYMhUWG9fPZHRyHg/NwFJU3dgRBAkt62T
B+uTtpNUSEmAbh/T+hcdgSWXcUBBN+NRLDCK0tzT39LTD+7AN7b11nUxYFQN
UR4mBqbkvnGB1Atn6mvZ2lqetkGiA8v1HSpjj85CAKQx9yr0nSJNG0/RyLdW
i+wNCm+bIdZtzZLsOZo+TpYFiLIQSRmn6vIsW0nompU6poX6Ubosj6dFW2gR
MDMC5UQR/BhaEscrU1Rtlq3LcQF4cTooVttGtMLJbnifA9prabZPy52zSvO4
VJ5l8UL9bD+JDaRoJ47lwjKdaJ6nW5UkOIvM8Dw/PM8JzDBN40h5FsQN1/CC
taIQSBbuUIV7dRGawsM0RZWmiEbpFSl9XH1CoEu8n0z9/hK0lsKSY4giKEbQ
gJHVEM2NdE8L0VHfayrHm6qYnlZhsIPn6WDZoBxreye7DEq53Ya7DcVWtONr
uqiNeEkrUJAFYbgsg5CmkUwHFC9qofIwRoMuE81urC4c7G5dnJ88e/r4h9cv
AYTfvP7h9fMXQH4G/PfRwcHFzvbFxtr52tLZ8tzp0uzF+sL52vzp8tTpwsTZ
0vj54tjxVGFrKLaWD60Xwu/frDicWh9KLw8mgYQ8nY7MDabXJ4Z358a3posb
40NrYwOrxcLKcG5lOLs2klsdzi4NpJbzyZVCCjDryag/7TAOB12lmH8s6i8l
gouDufuzkw/WVy62tl4eH786efB4f//F8enr04vtmfmkyxs0OT1ay3R+OOH0
RCyWuXx6KOCcSwdOpvOPFgberA6/XSm8mAwfJ/XrDu6coX/Hoz6OmI9j1k2v
et4qWnDI1wK6rbhl2a9b9GpmnYpZm2zWppgyAjWO4icBre62uO17EfiqvP2m
FlVpxDXYyRA3u0tDhCgIMFFfBxffQeqCwEG1lXev37jy9VefftlYW8el0wF+
rWqlis9WsKkKNplP6gHE+00sYjfgv33dMCwS3AsHo6GgjuZaaH1le3MVUH4B
hAESAXgbqq7XV14FNd5GtNf2oluxPWB0V3NXR0snHATw+5sFV8FAVe0t1R1t
NdCmcsB/W2oBF74Nqb/TUn2j7u63lTe+KL/zTdndz8HgG3QuWGtDG/1djiQq
OIpNzZFGt7izx8r5E/3soWFmzzy+aRpZ1g8sC+PjLF+W5k/x4zlNKmsKRpRO
F1up7dVaeq2+PmecZonRlEDVtfXyLHixFS929JnS4uicI70ZTKz6rQNKhq4X
x4YSmBAyEw4IS4agyOA+UTffTFdGKcFJuX+Mr/QiRYZmqa5ZqmqSy1qNWrRe
3aNR9sgV3WI5kieHsmQghqye66wR+RrVMbi1gHeO0qwDNE2yTxrCyaN9hhzD
NSHxzcgck3zdYL8s3SOMdTLiYFYCxk108OKd/HiPNN2vK3BNwyJhiEw0IpHy
pl49lBnAClNEQYYkyPTZJ2XuWZVtQi5L07l+PMeHY3uxdCea5kDRHQi2FyFL
YsyjFPcM0zlFtYwRFIUWdriCZL9Oc97h+etEQYjY3yXzEWQemiGiUPslLB2Z
YSAqQ2xlhM62dzMFBKYYSxahsJxWBLsGKajA6eqpHjDAb5+9BhDV1cTxgHke
KMcBYVjAPfyyTtbtTkrZ+yURmA0EfjNNBWbZIMA53OD7nZqpxhayGMqXEB1m
QzaU2t5YPjncffbo4vWrZ29+eAXAC+jt6x/e/fDjmydPHx8fnW1tAjn2ZGnu
weLcycL06cocoOOFyf2Z0aPZkZPZ0f2J/PZQAnDe5VxoKRteGYitjWTWRoFi
m18cysyNDi6Nj76fylcaXRkf3pgsAlovDc68j9bhUtQ36ncCSXsmEVhMR+aT
oSG/bSoZWCgkAQEevVkaOl6cPV9ffri5/uro4NXJyeO9vcd79883t6ZzeadK
G7Z5ByLptfGZjM8XtVqnM4nJhB8YRl5uTrxeH327NvR2KfO85DtJand8gi0X
ezdoPMt4LguBo4RjK2TcjVsP0s77Gedh3rOTsK8GDQDImyHLesA0aRCn+f1O
XK0OcVvS8q2w+WsJ5Jq6q8xKbPaykR5uj5HWqaR0yijdXBIK6K3NNXfLbl4B
/Pf29RuYzk69XArwa5AKDWKumkdjE1D0XkQ/CtqHBPehIFRcJ4+Kk7D7eWQ8
j4JlEdHkXsQ/iUa01v7mvO/9t6HmZkvTHSS8DuAXgLcdUgXU3maA08Z74OYK
QNDmSgBhOLgasOCmmpu/pejbgBoqrlbc/OLu958ABbns9hdtrTfoDJDW2uWM
okOD2PQ0fnSNPn0gXD7TrJ1alo8cS/c989u+6TXf2LKyMC1OjwgLRfXEjGtu
PjQ55R0pmiIxXjTBTg4ICuOK3LgiNiT1ZgXujMCfkwLtLzJhHFgPjezGC+th
54CWq8MxxCiOAM0XYgSiXja/myZAc9UkhYNryLADEwrfIFfrQalNUK26VSlu
VPFANnm3Xtit4HVKhV1CKZKraGeroTwDlOtvEIZbVBmkrUh0jdOtIzRthqRM
9BnzTOe4OLSgCszLLKNMRRorjnWLY138LFKSR0vyvaIMTpIhqgss46jYNKrg
hWh9ZnSP7rddh1IMxRBPUxS+v95Vknmm1cBRlqCyvb0cH5Yb6GV6uqiOdpoL
xvK1S5Ld+mGCuUTUj/SqCih+oormv0VyXKN6bnEDNfxgs9APB3xWHeGow2Kh
g0NR91E0OJ6dyLH3krQwIrObIuilSXoJIngnp6GDV9GtqiZYG0juRloARPM1
k511dHezIAAT+KEMa3OfvBwrKMOwy4jcWqoIxFS2Cc1wqR/J90FYzmaKqYGq
aeWouvUGXsTjBP7zdzeWzoBu++rpX37+8Zef3r798Yc/v/3pb0CK/vGnH58+
e3x8AqTW/YWF+7PTe9Pje5Ol7YmRrfHhdSDfDqRWB5KA224MJQFyF9L++VQA
ML65bATgbnkkC/jscrEwNTQ4VxydHyvOjg4vjI2uT5Z2Zqd2Zic2J4YBNoHv
A3yTjeHMweQgMBQcz4zsTAwezZdOFieA8WF3cuT+zNjJ0szZ6uI/EX66t/Ps
/v2T1dX5waGUy+3RaNP+cCk7MJ0fHAyFCz4P4NpLuRgQCZ6vjr1YGvxhOfd2
Kf1yInCe1R9FpYcRyWbQcJr3PR6Nng74j7LOo4J7P+vYjBkPCq6dtHUtbAC0
m3QAmndrBhWsOAvixFWr22/IwFdkbVeVHbfN2HoXDern9+jI7cLeVj4eziF0
Aki2N9c0VN4qu3Pvu6++bqip5jKoOpnYpJRYlGKdkCmhE4DaS+6GYeDNPe1N
+C4InYDi0fEAxXwankPuBYgG+MV1tnW1N7S3VgHqgNYBam+rgUNqEfAGGKQK
1HSn/M63FXe/q628Dmoog7ZWAwJqcn3lNcCsa8uv1lV8D1DcWH2j6vY3Zdc+
BXT36tfA59uhZRRqo9IAc0e7Y8OY1GTv8HL/1A536VC1dGBc3nOu7AZXtuJL
G/GpFXVxVj40KS/N6JdWvZs7kY3NyPKKd2RUNVxUjE3r5lbsi5ve6RXP2IKz
OO8amXNmJ80DC87SdnRiL1XcikdGzAozVa4mqtVkvYqi19JUGopCR1FZmHqf
0Jrne4ZFtjjZ4EBZrZ1WbbtZCLbx4TZel5aJUDCRSjFGpcMr37/jF6eJEvjR
NmEcqsx3W8epzmm2tcjSDwCxmeGfVQbn1eE5tWdCZMjTFHGcIo5VJfHKIZJm
lKIZpasGGJohnmlMbilpDSMadV7JDbLpXgo/ypEVRMohsW5MYZvV2UYl3im1
Y0wmi/ezvGhuoIcf6mH7kVQnhOJuZQYholSnahCjHsHIBztF2XZOtJweuA0g
zA6Vv0/R4WZRCC6L4sw5sSLEZ1toVB2RqiNQ9T0kDQKnaCWye5lSEk9Hoal7
e8Rt7bwquLQCpauieFu4cTg7CiE566juBkm0XRrpYNgbyZrKPmkZnn+HLKxi
KZpFBojC3amL9ajiKABwurmVY4CrbZRwyDCcjgH/9puAnx7u/PjyPb9/fgs4
7yuA37//9dcfnr0A+u+Dnd2dhYX18fGVkaGlgcJCITObTc5kEuPx4GjIXQp5
puP+2cT7wlsKO6binpl0aD6fmB9IArF5bjg3P5IvpDJj+cGJwaGxfGG8kJ8v
jmxOT+zNA3V49sHy7MnSNIDqw5WZp1vzzzbnH6/NPFydutyYPVuZvj89slUa
3JsaBfg9X1t4ursJUPwbwnsbpVJQr9dwuCaReHt+8f7y6vLY2EqxuDIyMJUM
bY2kn6xOnEykzyfjL+ZTP69k387FLgfNR3HlQUy6FjGeDAUeTyYfjkfOin5A
93OWpaB8PaZZCSuXgsr1mAFgeT/nnvOosgpagAyyYaoAC9YibhtR9yzYWg+l
LcjtBCK0HAtiIGqZ3S1AhAa8tRfR2tnW2FDX+Pmnn9269n1fL1rO5xgVYpta
CvCr5lGljD4WvguHbEW21cJB1fDWGkRbHakHDgjXBe6E1CHANd0dTbjuNkIP
tBsJwmNghN52FKIZAq4Ct1S0gsqbGu5Ul39fde9qffUNaGsVcE5XR1Nz/Z17
N78sv/XVnWuf3b3+ecXtr4EPb3z30bVv/nTzyseVN6+Cau90I6qp1EaFps0V
QcUGe+KjqMIMrrhGn90Wz2/rFjbty1vhta3M2mZ+dlUzsaAYn5HOLGrWth27
h/7dg+DWnm9+2TK3aF1e8+zeTx08GNg/Ht49GNrdH55a9Q3P2YYXXBNb0Zm9
9NR2KjPuNDk4JhPLZmA5jRynmWuzcE02tsnNMwdEtizfkebqvTiDuctjRfv0
XT4ZMiLrNdE6NL9tMGFQ9lmdDEv4/YVf5yiPn0AKkp2KAbx1ku2cEVnHeKYR
rmVEkFyzxxZNvkmVZVCgSVBVMbImSdZnaPpRrqkkMpUkhlGpqai2T5qtJatu
wOCY8qgLeklSIc9rlAMaWV6uGVHbZy3mIRGAsGlQIIkS2R4UJ9ApiHQLoyiA
XEYAzIq0CdNw2QBSWkAA8PJSEMB/maG7/e5rJNf3NN9dXrhRHEdIYr3SKEXk
Y7BtVKqBRFL3EBQIgrIdrwSzpBSmrJ8ux/fLu7EyGFoOQqkbUNoaWhDKTyF5
iXaKt57mqRdGYcIQhGKtEThbuOZGmqq6T3iHwL1NlVQKLC2KAFIVR3PdMLoZ
LHPifHHFWDG6szh9sbX95Gz/+aPTt6+e/PXnN//1l3d/++XPgAv//ObH3+4f
PX764PTB1tb27OzC0NB0JjWZSozHokMBT8pujhrUYb0ippcnTaqsXTPoMY6G
nAsD8b3ZscPlme25iaXx4fni0GCmkImlEqHIQCI9VxzbmJtdnZqYHcwvDOcB
g96eGD6cG79Ym31/N2p/9dX9FSCT704O7E0Bnx8DvnR/urg7VdybHnuwPP/8
/vbhwtzFxsb62JhPo/Hp9BGLdXZ4eKlYXJ98PyYASRt4yl4pvz0Y2x+KnJZi
lxPRp9ORpxPBw4xuP656PGpbipkORwIPp+Pnk9EHpcBJybudN82FpNN+wUJE
vpJQL8VU8yHlpEc6YOTEZKQIC2H5beNgJfwu0H9NvXUuKiQkQHt5GDURIuuD
6Tl4HY8EtFoarpNJROOxBFBT842rV8BN9WqxwKqRa0Ucm0as4dMAftkkNB3f
ScEh+jEdOBSkB9HCJHWz+tGAqH2dfRhYDxLUCasHDBfZ3gAc26G1yI7G7q6W
TkQTuKWyrubmvdtfV9270tJYhu5sIeI6erpa66quX/n6g2vffXT9yse3rn1W
BoB84wvg8Y2rn969+VXFrat15dfaWm/h8JV8abPRDfVlENHhzlSpOzeJH55j
lhZkk4vGmUXP/FJseTkzu6wozQiHx1lj07yFNeXmfdPWkX1j3zGzbFhYtq9v
Ro6ORy4fzT16uHR+uvDgeH51Lza54ikuOqc2w7O76bHlcHLQHAgrPDaB28Dx
6DlBmyjslQaDcm9E6oxInBm+PcFxhWnBACXpJadspJgGGxJhnAyUW/B+X3K/
gxeMiyMjivC0PDgr0RbpqmGKvsi0z4itk2LdEN9alIaXzPEVR2rFGZ42GzN8
qb9fHqRoYkx9kmUelron9d45q3PSYhk1m0dttjGvbTxgLfmNI279kFM9aJVk
VIKEFKDYNmM3FPjGAYE6zeT60BSggXra+RGEIIHgxWCcWBsv2SbKwqSFDnEB
zs9AOMlWbqyCEbwD8AuI7r/LjdQLYjBhFC2NU0RBOsdFY1pIVCO2X9tFVLcT
VG10CZGpILF1/SwT8f0bxqydRHs70dXGiHYw4+3cZDs3DuPFIbwImBMAsTwN
0gCM7wDRNFV44U0c7zpZWsYxNYg8EF0aKwl1Cz1oY5iZHLTOzeYON+af7O++
fHTy5tn5L2+eA/z++u7tX37+6c9vf3z349u3L18DFvzy4eXl/uHhyspaqTSb
y40nYqORUMJidkiFRg5TyyArKHgNFW9gkuJm1WjEtTE+eLQye7g6vzE7Plsc
HB/IxIPRsDcIqBBPLYxPHaxvnG5vP9hYXx0vro2PbIwPbY0P7U6N/kbr2MHs
yOpweqOYA8Lz6fLU2crs8eIUULcvN1cvt9ae7+8B+fnxzs5soQDAm3S6ZvKF
+ytL27Mzm1PjhwszF+uL50tTQKSfDtm2CoGz8fijqeSjycjD8cBhwXqQNz2e
9G8O+Y+nEw8Xsw9mYkcTgYOSZ3PAPBeR5Iykoos1HRRPByQTAWnJKx11SQas
/LS8z8PoMOCajPhmEwEEyE5p93K7g1Kik4e18fvcCqZTydEJGXIuRcGn8flC
ZAfi1s3rVffuELFoGZ+pFDA1IqZOwlIL6TJOv5BJ4FJ7WWTMP8Vj9ALi0rFM
MpqMRwDO29vdhkGBATy7kM3IjqZORHMXEoSAN7a0VNbXv59RCKq7iYTW9eM6
6GR0HxbeBqoAoAb4BXT7+hf37n4L6M6tr8rufFNdea389vfV5VdbQDfQ2Aq2
uEFtB9vCMEcS4s21h4ZQyVFirsQdmlAVJy0T0/7pudjUnKQ4ySkUyYPjpOI8
bWaDv7AjX9jWTC5pZleda1uJw8MSQO7l6cr50fLpwfLKdmhyyTE8YykteafW
wsU5f6ZgjYY1EY88ahOHzIKQVRTxSENBqT8icUfF7pTQk+QFY9xMUlBMiqZi
kgmfoGgXDJr5OYs47ZKl46rcqD43r48tKvzzAsuU2Dwpsk7L7NNKc0lmHJE6
x9WRBXt6xZdc8vhLJl1cIPHSlH6mIcY3J0WuMVNg2hWc8bpKLuuQ3Tbqc03E
fDMp61jEPBowj/oMRcCIjfKMWjdkdM64tDm+KsPiBwn9VhhWXw80U8B2AaBE
aagoCxHnoJI8DJAoD+WmWpixZlaonOZ7zy/RfY0auMuK1LEjrewQQhQn8UIU
jofKtJOYVjzdhCbr4SQtlK+lSSwslU+kjYpVSb40RRcm+jgJDCfZzYzDuWmk
fKhHXugSxCC8UKs4DlPEuwReCM1YQ5Td6ZPcoqjKmaY6tqNVEuriejqFXpwl
KcqV3IvLA8c7i08Ot948efDzq0e//vTi13c/AAi/+/H1ux+B49sXj578dgvp
4bPTs0cHB6ebm9vT00sjI3mv1y6WCPE4elcHEQLqaazBtdbTkJCAVjaZDAHO
e7G7erK1srsyvzhZGitkg66gz+EJuHzZSHJquLi1sHiwvnaytXF/cWF3fgYo
wvvzE0dLUw9WZ8/X5s/XAQMde7/W5c7qi/1N4Agk54v15Se7m5dbG4DenJ0d
LS/nfP6o1TaZyV5s7706PX52tP/4/tbzg62X+5uP1ub2RrOLCc/hWOrlytjr
9dHLmdSDUmh/yHV/0Hk2ETpaGD5fG3u4Nnq8kN6fit4f960PWWbjiqKPPxOT
L6a1c3HNZEQ1GdYCKoV1E0CK1nFCYpJfgPPyel1stI+PjSopESUtquMkTJKY
RRa1KgJmldes9JiUDoeLwWCAW0E1FWUQUAObQlCL2BIWScIiAhIz+wB4GUQU
GYekAEZMRJGwMEDEXigeDe5BNgG2i4DVA0dcL6y3B4pGgQF+YbB6MLi6ubm8
sbEcgLe9tQLX3coko9gMTD8BCZzfVHf79s0vbt/88p/M1lRdr6j4vqrqen19
WXX1rfqG223tZVhSLU/epna2G4IwYxhsibU5Uh3+HDYySE0NiwpF7fC4Y2zC
U5oSDZXY6RFiYrgnVerJT2MHF8jDi9yhOcnUsn11O7W7P3Z0uPBgf+nB3vLx
9hIA9ci0MTumHZg0jc66h8ad2aw5FdGlvJqEXR4xC8MWftgjikZkkaQymFYE
UtJIRprJyceGtEtF00bRtj5gXkmbZ6OGYkhbiGjyOX1hyphZ0gTnBPZJmmte
618xBVZM9imVuSh3lFS+GVNozg7AG5m22wtKRYAjcdHUfo4lIXXl1JEpPyB/
yWMfcJjzDsdI0D2e8Eyl9IM+04jfPh5yTgWt427DiNkyZnFNO1Q5njhBpbq6
0doGhKKsW3eP5KphhhoFmRZJASwfgv6mdukAVJAGs6KNjMA9qvdOn+s60X2D
HLhDC1XTgg1UXxs7hKF7cWQ7lmzupZgxdEs3zYSgGttlNo7GL7alNa5hvW0E
GDQE0hyNn8bxshh+rkcyiFGNAJ0dI8uhFLlOTaFbmekVh5FsB4huqmWaati2
epa9iWlvodohVBuC7yFYc/KB6dDy2vDx3tyjo/UXFwdvn50B/P79z28Afn95
+wPAL1CBn15cPj67eHp68eL84tX5w6eHh4dLy4ALR0wmDYNJRXRgW0DI6grY
vVtYUL0A3x01qWfziePVuQfbq8fba4fbq6sLM2ND+XQoDmggkZ0aLq3OzO8s
Le+vrR+tr2/Nz67PTGzNTN5fmjlZmz/dWDzbXLrYXgGwBfTqcPv10e6z/c2L
jZXz9eWL7Y3LnR1A7x49BtJyyGybzBaOVtb/+vzVT4/Pfn1x+d+vn/z65OzV
wRZQpc/nxh7OFx8tjv31eO0vR8tPloZOplJHE7HjyfjFUvZ8Z/nR/ZVHuwsP
1kpHi4X9mfj6qHcuY1wZtK+PuNaG3Is5+3zWsZj3zecDMxnvdMyVt6sDSrZL
TLVzCVY2ziehpo2iiJZbcGlGQpa835T2mrIBeybkTPiskUhMo9FQKf1toMaa
8jv47g7Af/k0vIJHASTjkSUckoBFYFN638OLR1L7EDQiEhCF0EHAQnvRrUAk
BswXg27r6W4DnBcKrWturmxouAfACzyAgu51tdcBvAP80iko4CkAv0Ccriy/
Ul72XWX51erqGzU1t6uqbr4nt76svrmsqbUM2lVFYICEOqTGizaEunThdnMS
4cigPXl8eJAeH+ZnR5UDJcPIhH2kJC8UhelRSnykNzyCCBThwSIyONYbKzFH
FgyL28mtvbG93em97Znd1anNxRLg3elhaXRAnBpR58bM2UFTMq5LBNQJhyJu
kYYN/KCBE3WL0ilNbtiUHjEkcppMQT8yYpwdt21Mu3enPFtj7rVh53TKNPx+
yq0qVVAlxuSBKa5jkmKawPmWDMltV2LL5ZrRAMnZO6ULzpkCU8bgpNkxoFSF
OWInWeqk6cMCAN7wsCk27gsMO60Zkz6uN6YsloJLn3fJE2ZhSKvKWewT/sBC
2L/gd83Y7BN6QKqCUBCj9ju7UNp6uOIuQn2j13qn31fOSdRKCi2qIlQ1ClON
wpUjHZIChJsAsYI1NN89ovsmwG+/7w45UEny1vS5GkmudpwJjlbDMCo4QYug
mpB0cwfdAhWbGSov35RSOAbVlhGFeoAnSpPZSSw33SsfJSqKfaICWj6AMY2T
7FMUY5Egz/VJkxhJBCEJw2WRdnkULg6184JwVgDFDuAUSZ6/ZCmupNZ3SscH
c5cnqxf768/P99+9fPS3n1//+u7Hv76/ivU+P//8+s1v+fnxi7PLp8cPTtbX
F0dHR6Ixv0anZbO5mF4yvL23pZEABskphKhJMxr1rYwN7C/P7i7N7KzO726s
LC9Mjw7m/TZ32OUfjGcXS1PbCyub8wvrs3PrQOKdnV2bntycmzlcXz7d2QAs
G9Dpzhpgow+3lk/X5h8CmXl34+HOJqBHu7uvz05/OD9/fXoxGEskPL7T7fs/
PXnx3z/98suzs7+9uvzHq0d/efTg1cHG++2ZdpbfHW6+3l7470f7fzvfebo5
eb4yCuhio/h8f+bx8dGTk6PHR/cf7q2dbs4dLo1ulhILA96FnHs27ZhI2CeT
rsXB2NbEANAFFocyo/FAzKozi1gKKkFA6BLikQZuX0gvzLo0E0n3wkB0IhUY
irpGEv6hZCAXcUejcZvNJhYJ4JDW69991Vxzj0nE8Kg4KZskYhAEDDzAr0xA
EXP6af1oXA+MRuxg9CNZlC4auYtEgL+/yftbcm5rrWxrrQKBKgByAR5ra++A
QFUwWGN3Rx2uG0QhtDP6uwD2gfM7oHXglop7d78BMvPt21+Xl1+rrLxRUXWj
svpmTd2datCtBshdGLoKz24VGNFqP04fweqjKGee4BkkBYapoWFGbISXGBVn
S+rCpG5gxJQfVaVHedFRYmC0yzUMsQ1CLPl2ewGXnpZPb0XW9wY3t8c210aX
53LTxWg0ywqkGMEUN1qQpQa18YwmGlYlvMqMW51zqFJWScwqTAXkgwOm0UnH
4KQ9k9UNFIwTY/bFac/GnG9r2rs27l4adRbTxkJSm0wpInmJZ4BpGsCbihjr
DCawoM3sOLO7Lu+syl6UBme0kTmjb1xlK4jVUYbQQRBYCUof3ZqUBAd18TFL
oGC1xzUan0TlkxoSBkPSzPNIelX9fUYaLyg0F83BZW9k1eVfNNpLMsMQVzMk
ESbpFC8KZ2vpNlah9LcwlptEzx12olo62KwpQlQjgKDaIkIzipTmIfxYMztU
S/HdA+DtD9wF+CV4q3Guhm5TY6caBJc2IaTNWHUb2QijmqAUYwtLixdZqaoQ
z5AR6/IiZZ4jylJ5GQIz1SMZJUmHCdx0p7TQ45hneZc4lnGSYpCsKJA0AwT9
EN40hDMOYjWFXnkOrxpgAOxbitrEQmBsI7+0NbK1UzramzranD+/vwYg/NPL
y1/fAhH6x19+/PHnNz/+8tPPQAV+dfnk6cn5+f39bSAO53Lv77GaLD611ioU
qWhUKYmo5zCSNsNCIbU7MwY035ONpftri7trC9trS8vzM2PFoaDNE3F6B2Kp
hbHJ9ZmFueLYWC4/mskOp5KDifhYLrM6Pbm/tnK4ufJgd+PR8f0358dAGH6w
vnS+tQrU8ycHe08O9p8cHPz06NHri8v16dmQzVXKDf74+OXf3vz51x/e/b/v
nv/95cWfLw9/Prv/14vDv1+e/OPx8T8eHv4/j47/v9eXf3u0/2xv4Xx98mi5
eLg69hCIHKfPLk8eXRw8ONu7f7y5fn9hem2sMJePzuXDE0nvSNgJDEQLA9n1
8XFgvCqlsiPpVNTtNCtkMgaVhUezsF0aNjmgl45EXHOF2GoxOzeUmMhFS/no
WC46mAyk0tlAIKDVqNDdyBvff3Pryped0CbAf1n9aBqhk4pHcigYKZ8sEVCZ
1F5CLxyPbsFhWgFhupuR8DpIa3lz492GulvVld8DSRiIwQCPFRXvk3AbpBHZ
CenDgElYCBkPAwS4cA8KBPALwH7j2qfffffRlSsf37z9TVn59+WV1yurbtfW
3atpu92ELEcQG/vFCIEVpw1TzBmqNUdxDdM9wzTfKCMwwgqOsMLD3MSoMDUm
zhbcyYIxWpAGh6i+0R7HaId5GPJ+vZ1cd3RKXFr3zW+nVrfyq6uZ2cngUM7o
jfa7Iv3uOD2UFcfzqmhCGQspU37taNQ6HrGNBg15n2ogrimO2otTzvy4KR3X
DOaMk0Xn0ox3fd63NuNZGHfOFh0DGV00JvNGebYYVRPplkTAygGIZQYVnFem
N82AAjMyV0kQnFbEFrSRGY0xw5T7+3hWtMSFM0RZnpwsOKQOj+htYakxINR4
+Lqg1JTUamJKsqG/jQnuknXSnCTtgNQzpwst6X3zUvMIQ5HGqkekogyLGcHR
g0iyD4x3VhHcd8n+u/xMrWIEpBkDSwtN0gII4Nc8jjYUuxT5DlGyFai91OA9
Suhef6iK6K8heBoRumq4oq5dUt8pb8FroQC//foWgqauX9ZJ12J4dqLIRxWF
KYIYmZsgclI4egLNTHezU128TJdq5P+n6j2A2srT9N3duzOzPR2cU9tttzu5
nbMNJuecc0YSCJQlgkAEBYQSygFlCSREEoicwYAJxiabDCYn586zs7uzO3f+
P3pu3brX9dapc2QhoIrnPO8nnQAH/Eq60gXNmMKGdFZjWlEzgd+E4TciQHiN
KLB5cHR3W6GsU2Ts19cPVrY/qXr8xDw0UDM+0AEQnnnevzo7vr+xDPrzP/kF
Ct5d3wT8ghF4YXxivH+gr6EZIFyn0YFUSmVaNkfDYlbKRG1lJb015ZOP26af
9ACBAgyBfJ/0dnZ2tLS1NrbX1DdVmMFysL0b7AQ66uotZSZzqYFPL+BQyCI2
s1ynabWY+9pbxgb7F6fGf9x8ub84szE9sT49sfFicm1qcnVy4uXU1Or0zMzT
ZwqeSFjIHu0bfruxB/j9ae/D3z/s/GV35f3KwW3Ef3k5+9f1xf9YW/jt5dx/
bS7/ZX1h78WzxeHuqSdtT7vqBjpqJ4c6ZqY2x58tPu2fHOge7G/t7rTUNxmN
Fo2ix1zRXm5o0GtrtTqAbUt5bbW2XCdSl6j1xUIxh06nZhMzkKn4ZAiZgBAX
5JZKOFVqcYNR1VKpB2muLm2qKmmsKqmsMhsMBqGQT8wkhAb5Prh91dXuPgoa
lZOWQsTCALygPNNycXRKBiUXn01EolIjkCnhydCguGivsGAXfx9bLw8rT3dr
DzdrF5eHjo73HBzuA4QBiQGBnuERAUC+0FjfhCgvIGJQpCNC3YIDHAHyNtbX
79+/DGJjdwfA6+pm5+bp4OXr4hlpHwRxjyeEYGjxOSIEcBa/MktaRxLVpklB
LHhZLb7YjFPU4DWWdH0DscSoUuh5En2O0IgS10DFjbGChqgiSxSnOl7dRqrt
FzYPqLoH9f1PSlpbxVUmilSHEGtSxDqMwpilKSNrS6gGXWG1ntdkEHcYZa2l
wloNq9bIAvzWNPJLa+il6oIqA6upRtDZLO1ulbY3ChtqOTVVLH0JRSDD0wSw
PFEMURpEVPpQqwIEXTH6xzTjE0ZpH13RSpI0ZCjbcoy9hRUDbGEVgaZKzpXE
F6oR0opshTlfVpkjLiOxpQSuKltUQpaaCsUVDIaejC6ChxMDovNDUEIIxYQv
asgUg3LejGNUQ/L0oYV15LyKDKIBQTTCMkoiMSpvoFS8zvlAvo3B9PpAkskz
u8yLWRcuaEsUtEKZlnhqZTix1BevdcPp3NBad4TaM0XhF8lwDaN6RpJ9EgqD
Uosi0EWhKYXeiWTnxIwgGCkshRqFZMYhubEIUUyqNAahiMKWxMOVIQhlcHZ5
IrsZzW/H8VowgF92aw63PUfYQRS04fnNSBBhO0HcnVvcz5b1CtT9iorhsoYR
c/uQuW/Q/PRpHYB37En72EDnHJg6l2df72wCfve3d354++7d3qtX61vby6ur
M7OAnWedPf1NTY/NtX21dR2milqlyqJSdlYYe6rLW8q0/fVVQ+2N40+6p0cG
hvt7OloamxotgN/WaktNSZlZb2ypqm0z19YYjEalCkQrkcp4RUqRwGws7Wxp
HOztnpkY3Vpdfr2yuLc4tzM/s7swuz03uz4NyJ3enJtbGB0f7urNxWeIGNzt
xbUf9z78/OrHv//2P/+xvwzy2/bCjy+n382Nv5sZ+3FhCvD7fnZ8d2J4/knH
VG/L1EDn056mp73NC9NDY883Bvrm2puHmmu6GirqzTqTqVhZKhI3GwxNpaUA
3mqlvlpVVqk26cQ6CVNWQGXk5VByMklEPB6TDIPHRuOTE2gZ6KL8TBE9Rytk
Vmul9eWaRoCw2dBmMZnKK41GY3GxlMMuRCOSrO5ev/n9l+F+rgDedFQiLiUW
h4hLx0AyCfCs9NSsTAQWFY2AhwH5hgU7+XhauzmDGfaOq/N9UJ59fA7efXJ0
PFAw4NHL29nP3z0u3D0iyCnIxybAyzrQ29bP28bbwwrI2tX5gZ3dbSBfR+eH
oDa7ezl6+jh7+7m6hD/yh7gBfpHU2HReMlmBYZsyxJYcoTkdICypIUhrcDIz
WlGDVdcR9A0ZGp1WrOAypZlMdQqvEipuTpC0xYuaE/j1ME1HdlUft75X2vlE
3TuoaWsXVpbnFZcA/6YCfotLM1WGPMBvuYFdb5I0lAjbDdJ/8ltjYNZZBFV1
bFV5fqmSVlnKbKjmt9YLW+p4lmpmuZFSUpKv1ucXChAZhRFpnCCiNDBX789q
CFU+gZQ9oRv7C3Td+bIm8GPjlS1Z5U8KG0dFxXUZ7JIUmhLKNWKVtbnKmnyh
MYOjxTKEaLGOpDWz9PV8eS2bWZqbLkRAaJEJ1BC0OD7XkMqoRnHqEEV1cHp5
FEnjn1eLJZkRpEo44ChdH4GV+6Vr/cnloZyGOHZTLLUmmFDihit1y7EEUVoi
8xrDWBZ8fjkiXQ3DKWB4dSpem4JSQuDSyEimW2C+VQTVFsL2SOUE4nkxWFZc
Iik4FOMXiPL1SfXywfgGE4Oj6VEQUSxcGQdVhEDk/nBtEKE8jlSLJNdlMJso
/I6i/HZUZj0sqz6poANDb8VSahGcxjRNb6GpX1jTr6jpVFY1qIBHRwZ6Jp8O
jvb3DbZYRrpaxp88nnn2dHFqYm1x8dXBWQwf3r15/2rv9e7m1ubKyvrCLGi2
YD4F4+3Lwc6JFstAtfFxhb6tRFWnAvtYzUB9zUhz0/P29sHmliZjmV4oUXNF
FQpts6m6obysw1LT19LU01hvMZZqJWIFn6cU8FUicalCWVde0dXSMtTbP/70
2fzUi7XF5Tcb83svZ1ZfTKy9eLE9v7o4OjfRN/licK6r9nE+Lo+Tx5gaHP5x
d/Mv77b+97e9//p5/f9+t/vXzZXf1uZ/fjn9fuH5j8vj75ZGV0d7x7oaZof6
+ltaepq6BrpGBvumx56tDfTON7dtVJin1frBYlWPVNkhkDZwxTVFoopibb1U
beHLKpn8Uhpbk0OTodOZCXBSYBAsJBjq7x8dEBARHhYdERYeGxOOQcJgCaEJ
UX656alaGadKL2urLu2pr7CUKsu0kiqDQicXSLgMem52aIDPnetXrO7eigkP
ScehMwhoVCoMi4UjEAkwWAQGA8FjI6CJPrHRbglxQKZO7i63nOyv+3g+DPC1
CwlwOfgIONgjJMA10Ncp0NcFJNjbI8DT2cPZ1tn+voPdbSeHO84ud93c77m4
33Z0ueHgesPJ67aLz11X33tuAQ+8Q20C4/1Ck4Oj8OEJ5Fg4H4JSw/EVyAwL
IrcFl1ULTy9PJBmgjEqUuDZTXZerrcsrNhCKFAiqOJkmx7BKszlVZEF9gaSF
VtxBlrdlaVqJFR15jV305tZCSxW5Qk+SVWOFRqSwFC03ZqgM2UptrlZLNZay
GmqK62sk1VU8UxmjopJRXccsry3QlmXJSrFaU2ZFNdlSTa+tpFWb8ioriBV1
mQxVKFHihhLbYpWumaX+5KpYbitG1Z9v6jUY+0pLe5XqboG0o0DanacezDeO
F4q7CdxmNLM6mWFKZZdhiwzpXF0mW52hFPF1cl5lhbiuiV9mIRXp4vKkPrkK
36xin/Rin2xtOPgSwC+tApJbGp1vjKXUEwDCudWp2eVQgjYMU+yboQugVUUw
LdGgM+dXBWC1zmidU2aVD6k+KLPGj1qByNRBkOLoFGEMUgbFqpMxahhKFZPA
8wmn2UYV2MOKvFC8kDRRPK4oAZIT7Al1cIfYuyc5eyM8gomB0fQIqCAmSRaJ
0segSiLQpeF4U2x2dQqtLp3RlMtqpOBrodiqeEx5LM4Ui9JH4XSxBbUYVU9h
1ZDM3K+q6dI0dhof9zWOjvQ+H+of7O4caLUMdzQ9e9w5Mfhkbnx0ZWF+e31j
HzTord2Ntc3VpeXl2dnlF1NLk+MLYyOzzwY2nvXPPW593lTbW2mo18gqJfyW
Eu3T5vr+2poWo9EgELGysgmQJHRcIgWfXszk6qXiMqW8QqMyyGVyLkfEZMiK
OIBik0YL4O1pbhl58mTq+djc5PTy7Pz60sr+6szmwsTL6fGl8fG5kcnpwYnR
nrGhtpGiPD4mAc2ncqaHnn7YXv+P99t/+2Xnx/35/9xd+2V98eAexMuTb+dG
Xs09XRpu76rSVsoFNVpFp8Uy9uR5b9tgZ+vTZ8MrzfVPK6qmpMXdeRQjPl2G
xgmwafyMbHEuVU5lqKgMZR5Nlp7NReLoEHhOSCTawzfxgZXHndsOt27ZPnhg
7+To5u/rFxLsHxrkbXXvsrPNbSQ0QlJEKVMJQXnubaxurSqtNipryzVlWplG
JuAzCuIiQ+/euHrj8ncP79wMDfSDJcakJicSCAg0GgqFhqekxCTD/ONi3GOi
XBNivWIi3QJ8rb3c7/t6WYEuHRXmFRPhAxIR4gkQ/ucBz+72Ngf3EX541/re
DesH1+1sbjo533Nzt7J1uPHI4aqd8w1HTwDvQzc/K69gu8Ao18AEz0hkYEJ2
NJQanciKhAqiELoEfGVSVh2SWA0nmpJyy1IYFThBNVFmzj1ooUYCW3nAL1mK
LNCkM40kfi1V1lKgaDswYLEFp7EQyuqI5dVZBn26uhjHM8ABv1ITvtiYIVET
BBKCXJ4D+K2rlVr+yW85s7KK+U9+daYcRSlBbcg0mvKqy6lmE9VUQtJpsTJd
ElUalCnzTFO6ZZT65FSG02og/DY84Ld6sKJquMI0oFV18flNeUVN6dKebO1T
sqANU1SPoFdAaaVJdD2CocMwNWlMZVqJUmIqldXWyqrrOcpyfKEi4p/85moC
sw8+YI1iVCVxGzBsSypAOM8QQ6lPp9bh88xIYlkiVhGElHgB/xZURxfWRNJq
wkgmH7TSIVVlhzO6EUweKINLuio2VRSawDy42E6SMBqjhOF1cLw+MUkcGFXo
APiFcjyRvECCMA7Nio3N9LMNv2kXddspwdob6RJK8k9gRiWJYuDy6HQTNLMy
Mc0UgzdGkaqghY14MPnmV2NhJVEgEHVYnCwwQRKI0sYw6zPVfRxxHVVYTpZX
suo6SkfGel68GHkx+Xzi2fDkk+6J/q6x/p6p4cGFyfG15aW9rW1g3r2d/a2N
7bXllZfz86tzMxvzs5sLc1sLM5vjw0uDvePtTd0VhnIRV8MurJZL+mrMvbXm
yuJiLomEjU8IdnZxu/8gzM0TlwAVMehasbBKp6nUqjVCoZBRWESlgMn3wLyN
Tc/7n8xOTK3MLQByt16uba+uA35XZ56vzUwujo2N9Q5PDYyPPR5vMrWi4tA4
CNZYrF97Mfvr693/+eX13/+yD/j9dWPp57WFn1Zn3y2O7714ujnR11er5+fi
4v3cIrzcC4jZj5u7H7cOdLWNgNqsUdQVK7vJNCMkieEXhHX1hLl6QnwC4QDV
kEhUVDwhOiEtLBrjF5zs7pNg5xx+/5H/tavW589fuXDh8veXb9y9e9/H2zMo
0NfW+s7FL47bPbiGS42X8wtNanG9Sd9hqWytMrbWmVrrKuoqS8xlOr1cikel
2ls/uPzNxa8vnHO0tY4MDULAIUQilkhEY7FJOBwMmuCbGOcdH+P5e7yjI9xD
gxzBFBwa5Bwe4vq7f92D/Jx8PGw8XKzcnR9a3blz/9b129cu37xy6faNyw/v
Xbe1vQM69kPraw9trts63nF0t3L2fOTsbeMZ6BQY6RUIc4lLD0gtiElhRscX
BsUw/ZNk4TgDNMucSqpGkc04ujmTY84V1FDEZrqkplBiSmOrkWRxEkkEz5Gi
qJo0XmWeorlA3U6RN6SLKxFCQ7KsJEWqThFKkrm8JIoshqNNBvyK9XgGP4nC
gHEFOJ2OXl0pqKrgm0xsg5FurKCXmWmllfnqsmx5SZqyJLOkhGQqzS/T5eoU
6UIBlMoJJQn8gCJzDIEUc3RBXQKjIVXUmakZLLSMmC3PKiuG9MpOHqcum1mL
47US5P3ZQL5sSwrNBCXrIBR1coEayVDj2Oq0coPcUquua5SBb8dVJoLdAkXh
R9EE0gzhVEM01RTPrEkVt6UXd2UW1SMP+K1Np1rSyGZMZkkCShaIEHunawMB
v3RzBLkqOLPUAym3S1XYIDUOCK1DstIGzgs4+KSJ7BZd4JfMj8Kpk9P18PQS
KFwaGEm3D6dYxxW6JDG9EawQCDkwEOVsHXrJJvKKc8JdH7RDVH4AnBeDU0DT
9LDMMhjAllgel1YakVOVyGnBMBvRJGNirCo8RhkWXRwWJw1D6hMp9ZnizkJF
DydfjQXjD0WYVlavGJnsXVyefPlydn1taXt+6uXE6OyzIdCfgWcBRK93996+
fgcq9Ov9N3ubu1tr66BCby0v7iwv7Swvbk48X346MNHV1lVRbhIJlYX0UgGv
XqfpqqoqFQhYmZnpEEi0p6fH/fvBDk7oqBjAL/Bve625u76+sbzcqFSA/ixm
sVtrLU86OqeePl+YngG1eXd98/X27pudvffby2sz42BHsTo9M9E/Mjfy4lnX
cwVHDQtLIqZm1htrXr1c+68f3v7t59d/+3nv17cvf9lY/mVj6ae1hddzY9uT
g8vDXTUqPjo68OF3Fy6fPe1t71gq10+MzI4+XWxrfsZhaNEYbmxcrqdX8iPb
sNt3va9cc7py3fH6Lafb99xs7AOc3cIdnEOsbPzvPvC6ccsN/O/ly3dPnbp4
7tw3X3196dtvLzk62Hm4O3/71RfnTh3xcHlEycaXyIUVOmVNqbbeZKwrMzTV
GCwV+spSZUWJSl0sJhKwLvY2F784d/7zM7evX/F0dYqKDEEgIABeEDw+CYmI
AIFBA6MjvUDiY/1ioryDAhxBggOdwNLf187DzcrB7pb1wyv37353++r1G99f
ufLNN99/9dWV7769efX7e3dvWlnfPYjNPVsHKwfwe7g+snW1dvZ28A72CETa
xWf7oFgRyKLIJFYAhOOHkIQTdIl5VRhabQanMV/QwhC38CSNQmmDWNogEVdl
MPXoXEkSkQ/L4sPJMgzflKNpphs6CjQNmeLyVK4OArjgSBMK+fE0djyRE1RQ
HM/TolgyeDY9JjM3qoABlxRnA4RBkdZoKKBRq0py1YZsRWmmTJcm06SpdNlg
4C1R56mlRCkfw2QlkOgBJH5grjqUZo5lNEILm1LYrXhZL7lkhGN5Vl07UmEa
VGu6ecKmPHYdoagRL2jDFzWhgEPpFUlUPRTwS9egOPp0vjGrukre2KyrbRIV
63FUYWie2LdAG1xYFsEoj2ZXQzm1qaLWNN0ApewZQ9KellsaQ67JKLBkUmsJ
2UYYThmOVwaTDJEFNXEFtdF5FYEErUuqzAZebJ2itIUrbCCyh3GFbhEUp/B8
V+BfpCSeoIUDfgm6+FQJ4Nc2jGwVTbOPpbrEU7wjMz08kqzsoy87xF11g94J
wNkn0AIwkoQsPSKvHJWuTSSVwbLL4jNKIslVidxWFLshBXzrBFVCTHFMjCQK
oU2iNJBEPSx+c0FBGTFPjsMzkkgsjK5C3Pe0ZWZu5OXLF3t7az9ure8uzy9P
js+NPl+amt5Yfrm/vfPm1Vsw/wKKAcJgE2hxfWlpfX5hDVj49zP4pvr6Bpqa
WsvLzWp1jUpVr9NVyeX83FwAb3JISLirs7/tI0iAHxmNZOaSNCJBndHYZja3
19R01tf1NDU/bm4B8I4NDM6NTYKxF/gX8Ptu782HV+9+eb2xtTC9tTC3PjP3
YmjsxdBkg7ERk4B1t/KAhkIMMt3W/OJf37/9+dX6h53Fn18v/7K18tPG0oeV
2Z3p56uj/TP9bQYhIzHA4/LnJ746fuziqdNoKLLZ0mnUWzLTGFHhqPv3/W7e
9Lh8xeH7y3bffmf15cW757+8+eVXN7/57u6NW3b3HrjdvO343SXrLy/eP/fF
7dNnrn/xxbeHDp84dfqLM6e/OHr06KXvvrl548qRzz46dvhjXw8XRn6OViYu
UynKNepK3cEV2xvNxiqDqkwrL9UUK6VCam52eGDgjSuXv//m69vXr7m5OoLx
GfCblobMysIAC2ekJafhYcmw8LAQ95Ag15go39hon7AQV5DQYBeA8O/8PrC3
vX7/7jc3r5+//PW3ly5+/e2Fi998efHS199cvXzl9q0b9+7dsbJ68MDq/kNb
q0cONo8cbW2cbZw8nbwCvQLR1tFEl6QCXyQnEMkNRgqCcJLINGUcxYQtNGfx
mwulHUJ5p7K4Qy1r00lbdcJaIsOAzZElZ/BhRB5o0WihgaSvL6hop5c0Zikq
UEI9jKuGMOSJNHFiPj+RxAujSuLpUmh+UXw6OTw9J5JMh7H5OKEkUyDOEEjT
xYpMiTpTrMILVFgQkTxNU0I2Gug6Rb6ES+CxEEwmlMyKzBNH0gzxrMYUViuS
0YIuas9Q9BeWPhcC+ZqHjeVPVNoevqydxqvPZFSD6RUGZlhOLZJVmVpQmkTV
JDF0KF5ZprQqv75R1dSuqqhjFClhJK5frsS7QB9SaIpkVMbxGpCyTqJ+oKB6
gm+e4sk6M0j6KIo5g16XXWjJzK9AkgzQXFM8rTqRUZcI+CWVBaCVTnCJdbLU
Gig4Wf4IJgN4OgN+o6geUE4wVg7J0Kaka6FYZVSS0DuiwCaM8jCSYhuZZx+Z
6xKa4eKWZOUKveGedMcPZR1OdE1mhWbIYflGLL0qjaiDkwzJ2XpIlj6OXJFY
1JDCqU+iVkRhDPgkZUqSPDmtlMCop7FqqUQ5Bk6NIXKReAo0pxCl0he1d1U/
H+1ZWhjd3Vr6bX/n/dbaztLC2uzM+sLc9urqgQRfvfvw+j1Q8I9vfwDrAOHN
1TVgyZfzi5tzC2uTLxafjb0YGB5/3D/U1tZdU9taXqEuKiKj0fG+3t5WDxyu
XnG5eSPWy40Eh6anpHApFJNS2WAyAX7729qf9fY97+ufGBpemJheeTEHJl+g
4K2XG292Xr3dff3z663t5bn1uZmV6RfTw2NPWvv4NKGbtcflL64Guwcr+cXg
8V/fvHq3/XJ/ffaH/YObMb1bmX29OL05NbI00jfe3WwQsRGRQRePHrp44sTH
//JvD67dxyOJoYEJ1y7bXr1s/xUA9oubX5y7duH8jQvnr509e+ncue9BPQaS
/fLLa999d+frr26dO3v1zOkrp05+f+LY9ydOfn7o8PGTp86cPHn6s88+O/v5
6a8uXjh++NPzn5+KCQ/hMukaidSgVJWpdUaFplytrzCqNAqBSiaQi/kCDoNO
zk2GJAKkrl767trVy8DdMGgcDovIysbnkdOJ2RhiRmpGGjwVHh0R5hXo7xwa
7BYe6gGWAN6QIOcD//rZeHk+cHS4/uD+1zdvnPv2woWDXPzy0tdfXfv+8s3r
N+7fvffw4cN7D+7funP75t079x89sHGyc/Jw8Qrw8Y8I9sM+DMmwi893TWH6
YXgheGH4QQSReVok1ZDGNJMFTTxph0LapRN36kUdekEjiW7C5ShSskTwPDGS
KScUG3KNloLqZprRkqkoRwp0UJYmsVAFoSmTqMpUpjKJqYRTRZBMRiQ+LzQ9
PzKHlphfCCvgIAs4qQweqkiMKyrGcGRIjgzBlaMA0bpSWoWJq1PQxJwMHhPN
KULSeBCKPL6wMrmoFctuxzFbCdxOUnE/Wzcsqh4yVA7qyvrk6i6uuJHCqMCQ
dAlp8nBGFZxZncKuQjCMqQUlKYxSjKgqW1lPa+lWm1uEyvIsenEMSeSbW+xD
LQkpMEWwaiCSVkLJEM08KaibkZieM7kNqEx1WJ4JT6vOKKhJp1ahKZWp9NpU
Zl0KvTaRZo7JLPFJkdrChFbJYquUYhsQuOxRHNM1usAlttAziRuKk0PStUk4
ZTxCGhLHdA7Jvw8SQbEOJj0Ky3YMJbp6IW380Y+C8fYR2S6wwgCCJC6vBFFY
kc42ZzMqM2ll+Fx9ao4Gml+aWFCRyKmBcC0Qcg01y5iVqc/IN5Lyddm4ohRY
dkQ8NohATiKRU9hcYplR1NVeNf60a2VmZO/g4KW1DxurbzfWXq+93F99+Wp9
4932zodXb37+8MMvH34G+eHNh/2tvY2V9ZcLKyvzoNwurUzNL4y9mH06MTnw
dLjzcafZUm8wqDhFrKwsQkJcgp9PmLM9CDTAhxAfScJgJExmlVZbX1bWXFnd
3dj0pL0DUAya89LUDOB3Znx6duLFxvLaq629/c3dt1uruytLYGeyPDkz+2y6
zdyShcr6/ZQa6zQ4vrmqYX128ce9HcDv642Fn16vvVtf2lua2VuY2p4dXx4d
HOtprVJJ8jCpVlcuX/vyq0P/9uevz33jZONx9dKDc2euXDh/64uzl8+e+Q7k
/LlL5z7/9tTJ8ydPALd+efjQKbAOHvn89LenT35z5uSlMycvnzp+6djxkyDH
T544fvz4sWPHTpw48fmZU4Die7du4tEYhViqU6jKS8qqS8vLtYaqEpNcwuGz
CwQcehGDRsnJyicR0akpnq4ugPoL5889sr4fFRkKhcWhMckZmRg0FpaThSUR
MWk4eBIkMjzU09/X0cfLzsfL1t/Xwc/H9iC+j7y9Hro433hk/e3dO+dvXvnu
5rWDyffeLUD07UfWD21tH9nb2957cPcaKOg3r96xumfvZn9g3uigCEhkYLpd
WLZzAtUHwQrCcsPw3HBcURiGHZYtg+UoEBR9BrOaJmwVibuUwm41r1PNa82l
VeBJqtS8YhRDQeBrDj7VNdXQymtyteVYkQbCkEVRQJQJVF0K3YATGfE8PZYq
guEpoUiiPzo7GJcbgc+JzKTEZZBjSfREGhdOF6bQBLACIYwlSxXKiHoDs7Jc
oFcxigW5Yh6Rw8Pk8yA0VTKrBsPvSC/qTGd1EPldFMljlry3SNcuKemWlnRL
5M0MVnk6SQHBicOwIqDUZE41kleDK6rEsExobgVBVp+n72TWdUlU1XlMBSxf
GkZWBgF4gXxZ1XGCJqSih1QxWtQ4r6iZEhd3kvKNcThZAFGLyCvDUipw5Aok
rRrJrEcx6lMOrrFcHZOm80kS2STyHgKEAcipMjsQSJFnHMM9juEBKwrCyOII
SgimOCpVFBSa/9Av62Zgzi2AcADxflCWbXCWizfWPjTDLYrkCS0IxIli8nRw
RgWuyJzNrcmRNDLYlblUHSFPhchVwSi6BFYFVNyAFDQIWdVslonBMtKzuDgI
ITwuJSAVE1FIx4n4eeV6QVeDabS3aX6kZ316ZG9xcnNmandh9u3q8ru1VYDw
wTWfwcrG5m/vfvj1w48/v/vxze5rAO/izMLs5NzMxOzC+DzIzLMX40+eD7Q/
bjc3VusMJSKpsqgIKFjNPvjEVJiXzc4k0PFIKiZFweWWq1Q1JSXlKk2FWtta
UzvyuHdycOR5/+Ds6MTi5OzU84kXY1PrS6sA3t31bQAv2I1szC+svgCtfqG1
uhkIys3aLT44vlSmnx+d2QHPXAXwrrzdWvlxf+3N+tL24ov95dnXL+fXwQv1
dzcaS/gUcqCz8/WL337yf/376SNnLp69dPLoxdMnvvv0k/Of/vnEoU9OHD/y
+dnTF0BOHj9z7MjJ40dPnTl17vzZr86f/ebzU1+dPPoleP7xwxcOf/LFp4c+
O3To0J9//wdWPv7440/+/PHJ4yesHlgTCZlKqUIj15rLzI3mxrrKuqaapmqT
3qhTlJeqSzUKiYBbLBZxWUx4UvLD+w+uX7vi7OQQnxANT4GkZ6CpNBIpJ41C
yQLJz88EjTo+PtTLy+HgmA3HO94+dt4+Nj6+tn7+B/H0vu/ofN3a5jvbRzcO
zi2yvfv7cR3Wzk62zi52Ti72Vo/uX79z9fKNS7etbzh62vmEe4YmBEQnh4Vk
ecTm+8OZYZiiaDwIOxLLDMUyw7NFiUQJNFuJoJVn8ZqZ4h6xsFfC7RZz2/Oo
1QSSBpGvxBRpibLSPL2JWllNM5gyFfpUtjQqhxeYyQ/KLo4hl6QClRRXZglL
0wG/6NxACN4DSvBOTg9ISvNHZIWAYPPDs1mJuUUQEjsulxsPniaSkfSl7HKT
UK9hq2Q0mZTMFuKJrDiyOuXgvalOYlFPFqeLJOgukHQxRW0MoZmmaOJo2rii
GnKeOhXLiwQtIl0SwTAheGasuC5DZEnnm9OEtRnqdlpZf1FZC6tIiyRyg7PF
gbSSCFZlTFFtIr8xRdqRruqnVE2Km5Y0FaM8di06TRGMFnln65DZOkROCYJs
QtBr0IUWBNUMzauIzS4Lxaq8oHybhCIrGN8mRewAkiSwTeS4xRQ6xxa6p/CD
01WJGWpIqiAopsDJJ/26T/oVn8yrgOKgnAchuQ6hua6hOR4RuX5xtCCMMDa/
NJXXkC5ry5G1kqUNVHFdgayOxa8syFfg0wUQkjyRU46UNRJkFpGhQ6uukxZI
sjPyUwkZEFI2nFeYVVsqa6nQPKkvH++on+tvXx/p258aeTc3vjM39Xte7M7P
7C3OvVpeerW68np1dWd5CYgYUAwQfrW9v7q4tvBicfbFwurcxtz44ouRmWe9
I42V9QqerJgtNMrVNdqSloqK7pqarpqqripTZ2VZe0VJi0EDnNtRW9deY2kw
VdQZTW21lv7WzqHOx4Ndj6dHxmdHp8aGn89Nzrzeev3Dqx9213bfbG28393+
6dXr1xu7mwvrDRX1sKgkHydfaCQMrK/OrLxa39pfX915ufR+b21vfWFvdXF/
benN+grI9uLs7PBAX2NDY1kZOS3D38Xr4qkLR/984sShs4c+PfvRH0/98Q8n
Pv73Q3/4148Of3r8i7Nfnj555ujhY8eOHAfL40dPAITPnjl/5uSFU8cvnDx2
/sinZz/+08lPPvnzH//4bx999NHhw4c/+eSTP/3poxPHTl67chOamFxYwDLq
ysr05QZtWVWZua66obayrt5sMpYoiyV8mZinVytMpSVyWTGzkBEaHPLIyvr+
/bsRkSHZpPS8/Kx0IgafjkwjoAG5OFwKGIrj4kL8/V2dnR88enQDIOzqdh/w
GxBo7x9g5+P7yMPrnqv7bQ/3ewdxe+DmbuXmZu3qDmLj4m5j72pl43Tf2umO
g+dD73DnCJgfFBuZkh4TT4uCM+NQRRAMJxHHjk/jxKWxo7GFYTkSaIYwNkMS
n6dHFdYQOS1kblehsJ/D7yRTqvB5enRReY7SXKitoOvKKKYKskKNEiuhdEEo
juYGzXOAM7yJKgj4QkVlDk+Dz2LHwjK8Q5PsgiCPIlKc47FeCTjvpAw/ZE4I
hhyKzg8CwVKCCQVhXHGmXE1TqgtVykKthiWTU9niNJaKIKrLKTCjKRY0pytb
1Esuas3nNpLFrSxlM1taRz84yVeFyBAlpAliiNK4XGWiyJIpbybJGrOAf0Fk
jSRFS56onkhXpebL4rMlYSR5CM0QyamDCFoQgjac/HFOyVNW3ZyqaUmn6SvI
UEbCmM4pXDfw64NOm1+GLKjCMC1Y0J/zKxKzDBEZ+mC0whPKt0/k2CTxHVJE
zqkCJzjPIZHjEstwiit0S+YG4uVxeHlMUpFfBNnGn3jTP+tqQPa1oNzbofnW
4VSnCKpnJNUnnh4JZUcBU5MPrrVFUHZnqTpzipvzpXU0eQNXVstjl5JJElSW
OIlRipI1EA0NqtI6BU9ZkEfDUGkEUVGeQcZtMqiGG81jTZbplobZjsal7taN
gZ7XY8MfZp7vzo7vzU3sz0/uz03/PwEUL83/tL31w/b2u63t/bVNMJxuvtzY
XtvZ29xfX9hZmHw5PjT1pH2gSl8pLOTRs8nMHLLFUNZtsTzr6pzs7Z3o7R7t
bhtsqe+xVHXXNwJ+AbkmpRqkptTUWGFuqqxpqWnobGjtb+8ZHXq2MrvyZvvN
z29/Bvmwu/fj/qufX797tb6zMb/WWNmAgqCjA2M0Yu3S5OIvr3/6y/sff337
7uc3+3/96e2H/c03W+uvN9f210FzWN6Yn515+rS/paWposqk0qESU29+e+P4
Z6ePHvoc8Pvnfz8J+P3oj5/+67/88eOPPvv89BeA3+NHj50A7B4GDB8Dm5+f
Pnv65NmTxz4/cfTskc/OfPzvxz77DDD7h3/ye/jw0UOfHfvq4ne21o4YJKGI
JTAAePXlOrXBWFJRbqwu1ZnkUp6yWKAsFillYo1CrlYppGIJh8X29/V78ODB
vXt3QkKCcAR0ZjYhLRMscSgUDA6PT0yMjIkJiYjwCwry8PS0d3K6b+9w28n5
HkDYw9PK08vay9sKxNvH2tfngbcvyEOw6enzyNPb1sPH7iD+9q5+tq5+jzxD
bUMS3RPQgSnECFROFISemMpKRnGSUSwImhUPECYAfpnhOZLETFEMsTiWYkgG
4mM3pXPaMrkdWazmbKaFyKwicityAb8GC8dQSdeUZskUqVxZXD43EE11geU7
An7BX2++CScqIdIlCCwlLBbjEgSzCU6yjUK5xKV5wbIDUvJCkKBUU0IReQEp
OX6IPH8UOTCPheDKSFIlTalh6g08uaaQLc9k6ggccya9BlPQiGG1pbHbiEXN
uaLWAlUXV95YCP7U+ZU5dN3Bu2rZEmi+MrlAh5TV54AA7XIqsJwKNNeM41Rh
6MaUdEFUhjAyqzgiXxfNqIZwG+H8VjS/Da/oo5Y+49XOqs3TCkkbCS8LhRQ6
Qpn2oEVQjMjCSgy7jsBtIoD+DPjNLInAqwMRUg8ozxHKdUjmuyKE7qkCN3iR
cwLbGfAbz3BP5vqjJREYUTiE4RGeaxWaczsk71YY+VYE7WFUoV00yz2W7RfP
CUniQ5KFcThlLLkSIuxAqvoJqm5ccXO6pJ4kszCKLVxxNYeuIeVIUYwSvKqF
Vtms0ZiENGZaNgkh5VPqjareGtNoU91id8dKT9dab/fq466XPe2rjzs2B7r2
Rvp2p5+/mh1/Mz/5GlA8MwY292bGX81NvlueBxTvLS7uvVwFyttZ21qZfwkq
9Ejf+ED7cKu5w6QuF7NE5Ix8LAyVFJVAwqYJCgrBnNvTWP/7tV77J/sfP+tq
H2jr6KprqC01GopVpTKlQa7WSxUKnkQlKtZKlbVlVcO9w8szyxtLG/sb+0DB
v7798Mub97++/fHd9qu9lzu9LY9Z+Uw6qXB8YOwv737775//A/D727v3v757
85cPbwG8b/e29jZXt9cObpgIOsPLFzPjT4aB4rvqWzViFS4lzcPJ76vz1z76
0/F//ZdDf/rj8X/y+9GfPgGq/eLs+bMA2ZOnjh45dOzo4VMnTp45dfrk8VMn
jp0+fuQ0cPTH/34EFOY//OEPf/zjHw8dOnLi+JkL57+xemgXGhJDITOLZdpy
Y01ZaXWJtgyQq9cY5VL17/yK1AqJRiHTqJUqhZJXxCXnUUJDw21tbe/evevh
5R4bHwVJioMmxyPQsFQEJD4hIiTU1y/A1Rc0Bh9HF7dHdg53rG1uWNuAwnz9
ke0Ne8c7Lu73Aa0+/nY+fvd9/B76+FkBI3v72Xr72nv7O3gGOPiGuHiHOPqG
2wfGOUXBPaGgwZJCMfnhyYVQwC+CBYMXxiOZ8XhuYpognsCPBRbLlESTlLH0
CniRBcWpQ9FrkgvMSQXVeG5DjqiBIjZTNRZWZbPQaGZI1XihAs4UR2UxfZBU
5ySqC5Ljn1Ycl6VHsOQ40JChaT5AvoHQR6EIx5g0z8Qsv1RKCJp+cFsuLCMC
SQ1OzvVLyvFJzvVFkiLzOChucY5MW6gv4xWXFHJUmeBPt6AcU1iHpTehqfUo
qgXNayIpO5j6br7AnCOoIhWZMgu0mHwZHIShw/BMGapGirQmi191UJ6LqrEF
hmSSJj5LFUsQRqWJIzPkUTklsQVmGLcZLexIE3VlK58wykal1dMa/SCfXo1F
CQMS6HZxNOscDZRcmsSsQguaMkTtRG4LlloNIxqi0IqAVIknjO8G47qm8j1R
Am8EzxvO8YhnO8YxHROYbnBeAIAXJQyGFnpE5j6MojyIod2LZTyMZ9smcl0T
+b4wUViyJAouS4YXx2O0kfnmKH5XnKI/sbgnQdwCFdahikwZvHKytIrDLaPT
NVm88tzSLm5Nq1ZTxivkpLNZmWZj8WBr7bPmurGmuvn21rXenlfDQ6+fDu0M
PAYIL3U1LXY1bY0OHBTpmTGQ11PP9ieevpoceTMzvjE2tDb6dG1y7NXy8oed
XUDTy/nl8ZGJ4a5nPY19tUYLECLgl0Nh56fl4JNRUragTKkF9Xiws2O0H0De
P9zd+bi5sa+5FZRnMCNrhFIhnVWQlUtEEdCQFBwcRcvONypLhx4PAX63Vrb2
N1693/vwZnNnb3Vr9+XmyvTSzLNp0JmZeQwJW7y7svOP//zH3//y3//54y//
+eNPv71/+5cP7wC/ayvzKwuzK/MzGyugSK/vrKwtT85NDY33tT7ub+trtXTI
RVpYAubeHYczp787cvj84UOn/vBvn3z26YFGL126/PXXX587d+7IkUMgJ0Az
Pnny+PHjR48eP3b0FFDtnz/6DPALOvPHH3965vQX31+6bvPIOToSlpVJlctK
TEaLpaatuqqh3GQ2lVXrtAapRKGQCflFDAaNzGIWyKRiUJ4LCxhoNBaJRHt7
+957cN/e0S4w2C8yOiw2IRIgnIpMSICEh4R5A3KdXa1t7e8+sLp6594lkFt3
vr15+5vbd78DjwCiXdys3D1t3D3vHsTjvrsX2Hzk7m0L4gqWfnbuAbZeYXYB
sY4RKS4Qgm8qKQC01lRWPIKdkMKMgzNikKA8S2BEeRJRAU2XxWTIo/O1iZxq
pNCC4VQlU/TROaowMKaxqtLFdWRFA1PfzDM28TWVNKEax1PCaaIIAsMzleqM
YHgSRGFZamiuDknhI3D5UdFIlwCIdRDcLprgkUgKSCIHIRmRBF4CSZoEpJnJ
i0fRQwC/iUSPWLwPoSCRKsRzlXkAXr46jyY/uKhsnjGFbkHRGlJzqhIpVXBh
M1HdRpc3UAu0aJrm4ILPOWJYliAxX5rMKSFIq3NV9VRxdZa4Nuv32pyRXwLN
VEWRdHH5pchMZSJGHIqTh+WVQzgtOElPjuwxTdHPNjwvLnsul7TTSCVJSIE/
FGBIt04Th2XJoylGKMeCEbSmFTVjKGZoljEaWewHF3sl8T2SuJ6pPF8E1x/J
8Utl+cQy7QG/BwdZCQKxkjC0IDiJ5RFLsQEvBWE9gvHskgTOMLFnkjQALo9E
qhNT1FCEJhZnDMlr8Of1BsgGA2S9/qK2EFFjIsOQBHZKAhNVVMXkmaiSGnpJ
J8/UWKw0ctj8LLGE2lJX+ryneayjaaqtaba9bb3v8atnT18/f7o93LfS17H0
uGWxr3VzuGdv9MnbqaH3L56+nx5+Ozn4ZnLw3fTI7tjQy5H+peEnG1NTb9fX
f9p782Zzb31p9cXwi+HO4ZaqlkpNZZW2or7MUmeqrdJXDPc8GR98OvN8fG7s
ILOjY+NDA0M9XX3N7S1VYPhW0rNyk6PifBxd7e5YWd+45+Xohk1ClxTrBnsG
1xfXf3z903/8+FeQ//3r3/7y46+gSINZeOnFclt9u1KsaqppXp1f++tPf/31
w89gHv/p7fu9jY3djdWXC7PTU2Mg8y+mV5cW9za29te21+dW58dmX4xMv3g+
N/1sfrhvrKaylUbhBQTEXLtmde7zbw9/dubM6S+vXb196+a9y5evXrhw4f/D
73EwDx89evTYsWOgLQNsP/30EAD57OcXbt287+HuD0lAgpfSqitrqtuaG3vb
W/ubGjstdc3mmnqD0aRQqrUauVTCL+Iw+Lwi4F+TsUyl0hQV8QoKCqNj4mzs
bB2c7EPCghOhcdCUxGQkDAILT4CERsX4+we6OLkcHEZ19/73AN4bt769fvOb
aze+vnn7u3sPrlo9uvnI9ra1zS1bu+t29rcAzvaO9x2drB1dbJ1c7Rzdbe3d
rZ19HrkH2x7wC3eDELyRuUFYWiieF4PjxyCLIlM44UjgJgUkQwNNUyXiiqPT
FdHkUpigFiurIxQZk8iycGKRH0kByVfBge80TeySFr68qkCgz+Lp8IVyaDYv
CEVzSaY4oljemZLIHCU0V4MgsZKQ2aFRCNeQZIdIjCskJzCVHg7gTRcl5qkQ
DGMaqyw9X5GCYUUkZntG4h0j8O4oWjSJn0qXENgKIk2CzRbCcpRJuUYYuTYp
zwzJLIumViZJm4jFdVlsPSanGJolScjkx6VxYjK5cRQZQlBKVJqpxTX50uoc
RROl9DFD3poDACTpYwoqk8hlOJwsHlrknyoKzjElFbUThd1kfgdV8pitHZJo
BsVFjXmZmkSk0BeU4eQiOyTbGysIyFSGU0yQwlp4QW0SyRSbpgtLlfomi7yg
XA8I2yOJ7Z3M8oEzfOF0v1imLajQyTwvtCj4d36DAL8JBfYwlh2cb58qdk6V
ucFlPinyYIQqBq2HJesSEYbI9JpASrsnd8BF8tRROuAo6fKQtkewK2ILdHCO
MVtspv9+8BtdVl8gKaMzi7OzCxAFLEK5UdzdWDnSVj/b27nU+3hzaHDv+dPd
Z0NrQ30rg91rz3t3pobWB9q3hrv2R3vfTQx8ABRPPXkz1g82d5/3bjztWx0Z
2JqaAC16a35xbmxy9MnTxrKGCmW5mqdS8uTlqrKuuo7xgdHFifnJ4dHp0cnZ
iRfzUy8OjmReebm2vLI8Pzc58BQgbJSrSRiCn5Pbja8vXzr31bWLlzzs3FAQ
hFIg72zqXJhafLf7/ue3v3zY/2FvfW9tYW11fnV2fPbZk+fmshq1VDPQPfhy
bvXX97/+9PaHX97/BPjdevlybXFx4cXkwuLM8tLcwc0jtrbf7u6/3t7fXQEI
r20v7eyuvtlc2pseXehoGVApTDhcrr9/9KXv7p058+35899fv37/xs17l76/
dv7LC0ePHzly7PDxk0dOnDr6z3WwPHz0CPD0px8fPnn8zNUrtzw9ApJhWCqZ
q1FVNtT1dLYP9/Q8e/x4pKOjv6m5w1LXYCqv1Op1FeWlVZXGygqj0VBSqi8x
GAxGo8lgKBMIRMnwVCcXZ0dnp6Dw4DhobDwsNg4aExntGxsfGJcQFB4J/OwA
EHZwuufofB8we+fe5Tt3r967f/2h1a0HD2+C9Rs3L90Fj9y7dv/BrYdWd61t
rMAOwcbB3tbJzhaA7GXrEewUEOcaleqVlBGAoYRlsKIzxaHp4hC8MAQlDELL
wgjABZpYpDwCXRxFUMVRDaliS7rcksnXp5K54ZkUH6IgmiiILVChpIARM52l
zaQWoxkadJYgEsv0TiI7gCCZXgRBaLooOk0Ql5YfA88IikF5xGA8oMD4jJg0
fmK66OB6jPSytKIqIqs8PUeenFoQHJnmHIx8FEX0RLNiScLUfDGaKsNl8+E4
TjRBEpVVGp9dEUcsj8goDaGWJwgtOF4ZiiKOI8kSMoSxBE5EOic6RwRlKrEi
Y05xZb6sIk9SlaNppgF+FW05BeXJuaVxlEoIVgZJ5kUkcoIw8miaBQvg5Xbk
F9RnCztZkh6etIvLsuT8k99UnitK5IIuAvz6ZciCcnRReaa4nN/hRcn9D+Dl
eyaw3eMK3RKoHhCKF4TiAyX7xLHsIFyXVKEvRhyCFYUCLycdPMEGXuSIEDmh
i91RCs9Uud/BuYGaWGwpLEEdnloWktHgS+1xLhq0EgzdEj25Le6xFrZ68moj
iipTeBVESQ0NzMKiGiq/KpehycrmohDZMYRcqERKqylXdNeVT/S0Lg32bz57
ujfxfGt8BIh1eeTxxtTA7sLzjSdtIDuDba+fdX+Y6P8w/nj/aedmf/NaX8vq
k45VYOqRwbmhoeHO7pZqS1WJSStUCWhcJonOJbNVfAXw78TA6P7q7qvNV4Cd
vc3d7bWtnfXt7c2dtZerC3PzK5Mz4/1DQMFiBgcRC/Nz9vR2cAvx9E+OgeGS
MWwyExA6OjgG8NxY2lxf3Nhc3lyZXQEIL8+sTD9/AfxbX9WwtbIN6P7H//zj
b3/5r3/899//8T9//+2HH356+/bNzs7W9hpYvNrfffPq9VtQErbfvNp8/Xr9
zf76mx/2f329/cP06FJTXQ/gNz+fA4enXb9m+8W5K+fOff/ttze//vrq+Qtf
n/viwolTJwGwAN6Tp48dPX4I5NiJA5A/O/wpmIK//OIbextXYF4Ar1JuqjV3
dHU8fdwz2t8/3t8/2tn5pKGxtdpcaygzanRqhVys16lKSzRKRbGAx2ez2Uwm
u7CQmZdPiY1LAPAChAPDgqITomISo6PiIxKgQdDkUBg8LAESEhHlExAEpmAn
Hz9nMAU7OFrZ2t3/PQ+trO/eun31ytVvv7/07eXLl65du3bz5u07dx8+eGjz
4JEdeJ61g52tu50rGISjXcKSPCAEPzQ5PIMZS+C54QXuWKEnWuyDVQUTSqPR
+ii4IixVHo4H/JahpHUkdW2eSIulMqOJJH8sIyijKIoMxkw1oUBJyBUjswRJ
mcIEJMMfXuCWRHNKKXRFs30wnABEYQAs3y8lLRiC843HekMz/FEFkRnCpBwF
IleDLDASCox4SgkmW56EZIfH53hFEJxCsfZx+b4EQWKeAk1T4KlyHJEPQ7HC
Qd1N10YSSkLxJQHp+oB8QxSzDMYEk6kwKlcOyRTFZPCiScJEhhLF02cc9AFt
prQ8V1xJktXmgP4sbsiglSena8JwikC4IDaZH4WWJZDKkezWHGEPjdNGoVly
eB2sohYmt4kO+M3SQVN4XoA4rNQtXRKQIQ0kykNIugiSIZpYGolVBaVIvGEC
j0Sue2yhWxTFOTrXOTbHPT7HIyHXO4HjAIZihMgPKwkF8oWzfSA05ziydQrX
CSVxwSo80Uqv/5dfjAEWVeyXXOqb3uBJ6bFhDtxgP/mG1/cdv+cWu95WUB8q
siBFNUSphVrcwJBYqNwKErM0N1uETs2NIZCTxDJKuVHaXF0y1Fo309e99mz4
1czE/uzE+sTw0mjf8kTf2ovBA377mgCw+8Nt78d63o12bz9pWu6sffm4aaGr
frK1brChtstsbq2sbCivBnls6ajVVh6c2C7RmhSGf/L7buvN/sb+663Xr35H
eGdrF/D7cnn1xYvZpfHp6aFng+3d9WWVUiY/F0/MQqdRMnLIGXmAXxIuy6A2
As8CBYOGvLO6C15nY2kDjMOA6Kln06A515Zbtl/u/PTmp7/99rcfXr8H7fp/
//pfv7z///G7v7ezu72zu7EDWjeYo19vgtH4h9ebH9YWdyaeLw71T7Y290sk
eiw25/pN+8/PXT15+tvPv/ju5JkvT5w5d/rcFyc/P3P4xJHjZ479/mnw4cMn
Dh09deTIyaOfHv3s81Pnb1y9FxwQCWZeRbERwNvd8XzoyUzv47EnTyb6+p63
t/dZ6pqAfDUlerlGIRRwJGK+VCKQiIVioYjHE9Bo9MzMrPgEiJe37yMbOxc3
1/CYiCQEDIFNReERWEIiGhePQMckpYAiHQJ0HBTi7hfgGhDk7u3j4uZu7+xi
5+hkY2P78Pad61eufnfhwsWLF7/+5uvvwTB+7dq9W7esbt+zufvA5r6NjZWT
rYOXvVuwvX+scxTSE54djKNFpdAfpLKsEVx7hMQVrw1KK4/GlcWkaiKT5WFY
dQLNBMozWVtLkQBaC+NIWUFIsg+JH0uTpZAEyRlFsAx+choXgmCEJtG8kulu
KQw3TJE3juuPYvnBcj2i05wTkN6xSK8EnE9yTgiBlZhTjKTqcDQDnmLAgek4
XQqBM0Pjcr0iM1yiM1zjsz0TaP4ZMliBDs/QZzC0aUQRDMkORYtCcMpgjNYf
q/NL0/lna0Mpqki6IpYujs1TgP4cByoBWZbM1RNEpSSOKo0mRsoqyAITkWfK
4JvTeDU40H7RMv8EliNKCsErk7KM6AJLZlF7Hr+LVtROZTZRuG1sZj2dVUcD
/GbrYUkcdyjTFvBL1tvlap1IGg+iOjC7JDazJCFZ5h/GtoniW8UI7sTzb8cy
b0VT7kRnW0VnOsZluMeRvVI5oRnF8VnFCTheaHKBd2K+W2K+C5oTgOYGYvmh
OFEEXh6TpkzAFsemiMLjpQEoQzipPorWFcLo9WL3OzEeW1Ha7rG67RjtroWt
3szWsMKm6IL6eEYjlNuO5FYjaLpEmhLK1+HVxnyjkd1oVg601j5vb57p710d
Hd2entyYnliZer489XR5euTHqf7N/sbF9qq1HsvuYAsI2FzvbQT+neuwPGuo
GKgpH2wwj3W2zwz2Lz179qJvYqpvfKDpcb2xtqHcMtw9uDq7tL26ub95cMvg
N5s777Zfvd969WZ1Z3t+dWNqeRHMpsNTT7uGOi3ttaVmvUQrZgiLyOxcHCkN
jkclIHKw2WUKw9TgxM7iFsjm/Muf9t592H67t7I9PTQJnq/gKsb6xt5tvPlp
94e/vP3lr+9Bfvpp/9XmwvzMs5Gnj/unR0ZXZxc2F1fW51dWF1Z2Vnfe7rwD
Ft7bePNyfmPy2dzI0FR/z2h1ebOQq0pNwNvcdT515Oypo2fOnvkczLxHT3x2
+vzxQyc+Pn7m6LEzJz49duSjz45+cuTU0eNfHj/59YWLN7x9o7JyWeJiQ3l1
axvozINTHX3PHz8Z7RsYGRgc7u3tbWyorSjT/x+e3juqrTRP1525M90zPV3V
1bGqOld3tSs7JwyYYHISCOWchRKSEMpISEJZCIEkkAQKSIDIOeeckw3GYJyz
XanTzNwz6677x/3oOud6vf7W1rYMXrYfPe9va2/tpqC3PVLf1tLY6PfVOR3O
KkBxdbXDXq4u43JYBQUQ0HjPnf88OTUOjs6mFaE5fAKTg6FSkWQynECA4nD5
GEweCBZbAFJYmAmBpGdlJaekxF2/fvnKZTCtf/r5Z6c+/OMHpz7808enPvr4
1Ccf/enTzz45ff7spcuXrp0HT4m7ei3tWkL+9XRsch4zEyXKxykQeEM6yZxF
qcyhOvNYDTBBM07Yguc2ooCFJRGqprXYOaD1D9usQblYTy8pp/JN2QJzjtAC
EZggfCOUqytgawqY6nyODgEGVZASC15kJbC1hcjixFza5RxpQp40GyZH4fUo
ngeibEsq77ymCKeJarBsLZ0mw9EU2YzyeEZZHEOazSjFyMycmrDeGtDKHCWq
OkmZt4RfReHXEIRujCJIktXjpXX48gZ2hb/UEFA5msyVnhpDTYWmWqyv52oC
eL7jRrEzVteebxvEqltgjmF27YRY6sOxbdBiB4KqzeY6qYpwib6zrKJbZR7Q
O6eqqketho5ya4fW0qKqjmpcEa3OxuWXwJUKQp1Tqm64rvanKP25J/5tJIuD
FKYLhjQmIs0xWNslUtVlkvUqQXcVo4gF/GJLUvCaDLYNJvUSlfVkkRNdZMgG
8OIViVRNGl2fyTDnsO2FXOfJ/dEYdhjJAqHUFgpbsJoRkmkGbZ7JMc4kVUxc
1Q5frhiN1Q0m6vozjYMI0yBB30us6CYbeun2dq4xRLeF2MHO8t5h18hQw/RQ
0+p431xPx3J/3/b42J2lhePNlePt5dsb8zdXpkBbfjDdczTWfn+y6/Fs36OZ
3ofTPY9m++5O9RxO9t6ZHLg9PXx7duLgH7cvOVhZ3JvburNya39xZ2V8YWVy
cX9jF1Dz8Oj+yeD58OmTowcPbgPvHj68dfxo796TW/cO1vcBhquTy4DfNn+0
1uIyyCsAs3wqj1iIh9zIReUgdBINmKMBvH9/9dcXx4+/ffbm9YMXTw8f7a/e
AmiDf7/h9uEXd599+/Trv736M6D7z89ff/v8xdOjw/31tVtrm3e2b97bO7i3
d3j35sHhrQPQvYHHH9998vj4+d39B2D+3dm8s7NxND+92ds5XlsZICIZH//+
i5/96Bc/+8nPfwZ+/uLH7/7yhOK3fvLDH/3snZ+++947P33vB2/94u13fv3e
Lz/KhxJFYp3b29zcOtIztDA5vw34HZ5aGZ9eGZmcHxqb7Ovra4o01rmqaiqN
riqzxaADMVVojDqtQa/TacvFolIGnZqSknwaAPjFR4k3ruUXZmAIECwxH4pI
xeML/v8AbNFoCBKZC4dno1D5CEQeDJaTD8nKzLiRcD3m4oXTX3z+0ScfnwLw
fvSnU6c+/OjUhydV+ovPz509d+nClasX46/GpMbE5cYmIuPTScl5rDSoIAel
ScYZ00n2HJoLwvbDAbwlbXiwFjdiZS0n7xY5BzQNw2ZLUCo10mUGJuCXZ8jm
6XOKDRC2NpeiyCBKMkjSbICtooZe5mLJnHSRnUSUZxVw4hCCpDx5ElSeiyzD
UExYoQ9aFk2URS4K3HFUTRZJiiGL0VR5Fk1xjSqPLZLnFpdRNNUiW1Bj9KlU
bqk+oCrzlHJtZG4VttSDV0do5WGaLlxka5XYo+rKZn1te5Uz6DbXGdQ1IqWL
KnZCBdUpYl9yeTTX2IOq6EBb++iGDnqpFyVvIJaH6YIalMhXVN5SauwpM/Wq
bMMVNZO2ykF9eYvE1KaytJTZm8oq/VK1mSFRYo2momCgXFOfpA1k6oIwTZCg
DrNkITbHRcCashAV17GW62T7dWplItmYSFAlYaUpWDGwdmaxE64MkMG3k3tx
XBuEoknBKxNQ0liMPB5ffgM8gWLOJZqy0bo0uDqZ7kHJO2mVczznCs02X2CY
TNKPXdMNXdH0x6o6r6s7Mgx9SHM/xdRNqWijaKMkS4Slb6DbQ/yWPuP4tH9+
Kro42r4y3D3bFZ3rbFvq7dqZHL27Nn9/Z/n26szW3BCoygfDbfuDzYcjrXfH
2o/HgYg7QYUGRj6a7D6eGbw3N3o4N7Y/+93tTsb3F7aO1/fvb9++s37zYOMm
QBUAC6gB4ru7f3hne+/W6u7N5e3bqzfv7Rw93XsA+N2YWRvrGonWN3tstVW6
Slu5BURAKy4tKikXqYCOO0Pt88NAaasA8yd37j89fHB35w4Q987CVqO7UVOq
qdRU3lq+9fTO468ev35578mr+4///OLlm0cP7+7uPDw4+ZDqo929vfWd7aX1
9YX1zaXNndXdve3bB7t3b+8c39o8vH3z4f2jl8d3nu/t3F+Z2KmzB7GFlNMf
n3//Z7/88Y9OTsD6xclhqx+99aMf/ujH7/z0Z++9/fYv3nrr/Y8/upSdhbFX
hyItQ4Mjy8OT62MzW9PLexMLu31ji32j8519I82tXaHGk0/LMZsqdOUKrVpa
KuDJxSVKaalCIhaXlvB5xRQSGQ6Hx8fHgvYL+E1KiYXCs/DkQiIVhsLlwpE5
UFhmXn7qd50ZBs/FYAuJJBQaA8Vg4Tg8EgSFhkHys1NSE+Pir549e/rzzz/9
+OOPT536+KNTn336yenPPj/7+RfnLsXGXEmMjc2Mu15wPRmdkEZOzmalQvgZ
MM0NnDmTUg2h1RUU+WHFzegTfltxJVFCWSfT0M2vGVDVDehMfpHCSldXsqQO
OICXrc3mVECoykw4Lx7KikWVpIKiq/bwdH6+2scV2AhwYVIe+xqpLKewLBmm
zEOr0FQLpqS+UNGcLKw/S7ecR4jiUXwooQRBkWVRZfE0WXxxOVxuKq5wSTQu
cblLammscLRZAb9FJjzHjlUGaRWtbEMr29oucPWqq9u1lrAW+Lc66DB7dOUu
gciG5lgypb4cTbRAEcnRdCDAf3tjD10RwakiRGtPsbWbpwjg1U38irZSQ5fU
1KuoGtFWj1Xou2QSP6uiRWSJyswRsdbFUpqIFTaG1y/v7LLq6tNMwXxLhGBu
ZhubROWNYmEdm2pDYyqy8aYMii2Tak2nmtJpFRngFYmizmVVQ0rqEMoQsTxC
kTVg+Y58mj6VoE6Aia5AS68USmMQZQlwVUKBMi5PGpsjiy2qxWh6OZ41uX9b
WLOMtkylGUav64euq7tjlS0JZU0ZFe0ISzfV2sE0gJfTCNUeLrb6uc6QqKXT
NDzsmxmLLA63rQ51n9wmu6ttubt9fah3b3bszvLk/uLI1kz/7kDzVldorc23
2dFwqy90PBJ9Mt39fK4PUHx/qhsgvD/auTvUvjnYvjXcvTvWd7Cwdndt5+E2
QHjv/s3bj24fPbh9Ir797Vsge2s3txc3AbAb06vbcxt7C7ubs+uLo/MjHUPt
gdZIXSNIa0MLKNJAx93hzgaHD/Drs3v6mnvA77q3e/evL7/9y4tv3jx8+fr+
y0f7D4B57Vq7QW4YiA4AnB/dvn/v5h3wTb9++uzNo8eAX0Du7U1A7ura7NLS
zMLi1CLIwvTSytzG5vIuKM9AvoDfB3dfPXnw1aN7b+5sP16dudXU0FFcVBp/
NeEPv/ng3Z//4l2g4pMzKU8uUPjROz9/++33Tp06TyLy62pbegfmJ6a3phf3
x2d3R2d2JuZvjcxsdg3Nt/ZOhKI9vmCzpyHorvVUVlpNRp1Br1HJJZoyuVol
L1PK5TKJSFjCoNHRaHR6euoFUJ8vnknNSIIhc8h0JLuYVMTFs3k0BotEpKDR
uEIYMg8Kz4HCwZoHRxUgUIVINAyDQ4Ig0QgorCAXknMtLubSlYtnzgFmz5w+
A77iZZDT5y9diIu5nBQTkxkXD01IxiSm01LzijMLSnPghnRCVT7di6DXw+gB
GCuM4LagQKSd5PKeIn1PcWWv2NEp03hYUgtRU83SNVBKbFCWLpulzcWLb2RQ
zmdQLiAEN0RVZEOjyNwildcxaNqCAn58XnEcSZuDUCfD5ZlwWT5eW1DsypU1
JpZ4LzDMF5El8SheHrY4nyzKpEkTmfJUYTm2zFwiNrOFRqbaKanrrvH0OZV1
IpaZKHCSdC08UztPH2WbW4urOhTGkFReIywDtblOo/codV6huBorrM6taMOa
ewnChnRDD9E2zNL30DRtFPsw3zUpNnUxZAGkoa1Y18Ipb2FXdAhtA3LroFwV
5Qo8pPLmYlObSB8sltoJCiu+xi9s7zMOjjmMvqzKRpQzyqxpK7VHy0yRcoVP
yqvhkI0YogFKMOSQTVlMMO/bC05m2yp4cR1E4C0QNcDE9XChO59tz6QYbuA1
1+Gyq/mlFyGiS/nSq3mSK1mll7IkVyDKOJYbp+0u9q4oQ9sizwrJPg0xj6aa
BpM17QnKxiRFILOiCWVrY9ha2bZmDki4Rxfu0rV0Grq67UN9numBxrWxzr2Z
4Y3B7o3+7tWe9pXu6Gp/dG24dWOsY2uyc7svstzinWyonPbb19s8x6PNT2Y6
n810vVzsezbbe3+y42A4utPftNnbtNXXsj3QujM1dWdp6f7W9pP9/WeHd58e
3QX8Hu7sA/MCeLcWNpcnl+aG5mb6pmf7Z+YG5ueGZpbHFwHFW3MbQK+zg9OA
XIDzdP8kcC7YA/aD4RdU5fs3j58fnbx7++jgwaODhw9vP7i1utfd1GNQmIWM
0oi3aXly5cH+/ft7x8D4J2d1HoHxfW1jfml9bhHAu7awsrWysbu2e3P91s76
zeXZ9Y2lne2Ng5tbx4DfuwfP7h0CBb/Y33x8vPdqb/NeX8eYRqEvyIN/8dnZ
937x/jvv/OTdX/zqvXd/8+67v/viixgigVtX2zo6stY7sDg4vj40sdEzvArS
N77RM7rS2jfb2DHii3TW+pvrQ03+xiZ/IOQ7+eFxuxzOGru90my1mECMeoNM
JmOz2ZmZmSfX58ZczMxJBZziKAgam0BlYSlMEoNDOzmQJeJyhWwml0GiE3Fk
LAqPhGMQUGRhAQJaAIeB5MMKIYXQlMzUhJTEa9dPjjlfu54Qm5Accz3p6vXr
F65fu5QccyUz9ho0LgF9PYV6I5uXkS/OgZmz8DUF1Hok3Y+ih+BFEQS7Gclp
hku7yWU9dE0nQ9fONjSzJDU4gRGurCJZm9jSaiTgl6rOhPHjkvGfppDOIEqS
uRa0JSoxtYqLzAiYNKmgNA4mTcCqUxCK+AJRYm5xUqEoiWJMLKmLK/XEFNsT
8JIEJCcDzkjDcpMppclMaQZbBi9W0ChSFLMMr/OVBUfr63prZK6SYjtN7mPr
WwS6JrY6QNEEi4yREoWLw6kg87R0hUNQ4RMZG4Xlfoo2TKjsp+k6cSx3Ss0U
zzrE1nRQTP0s74KsdqZE301UNsM1EYasniD24coidGOPABQMeZjO92AB0YYo
X91AF1eiNE5SsEvZN17ZO2K1eLJqwpi6NnZdm6Q6Wm5r1muDGrlXzrQwiHo0
VpNLNOTwamBgMFcGCWV+fLE3h1uXxXFncGoyWFUZDGsKqSIBVx6PUcUWSq/k
Sy9DFbEFythcRQxUk4CzZgq8VF1HsXOqtG6B55olVE1CrcOZxt5UdXOSMpCm
8uebIsSqKNcZFbqjpbWt0v5R1+Coe2TUOzroHenxzfSE1obab00M7Az07Ax2
bfV3rHRG5tr88x3+tcHI7kT7Zk/jfHPdSJ1ppNa4HK45HGh8OB69DyiebAMb
x8NNdwYie/2NW12BlahvIVI7Bww+MgBm4Se3br08Orkc+GBjZ3NhdXN+fWli
caJvcrB9aKhtZLxzYqZvFvAL4AWE7q3cBIQCigGzoEsPtQ0MRPv6W3pBepu6
gYjBOtU3ARR8f+/e4zuPXt5/8eLey8Pto6n+WV+VX1WiafV3bMxtvn746uun
X755/OLN42dPju7tb2zubd38Lge7+4c3D49uHd25dXRw83BnbQ+Yd2/3+ODW
ozt7jw/2n+zfenRr98Hu1pNbO0/2dh9vrh8ODcwaDfbMjLxf/fL3b7/105/9
9P333//g008vI9EMuyMYbR2PNI2Gmkeb26ei3bPNndPN3TOtffMt/fORnpn6
6JAn3F0XavM3dUZaOyPR9nBLtKk52hqNhBv9dbU19kqr2WgqLy8vLhbg8cSr
12JOnz1z9dqVfGguhoiiFBGYPCpAGEvBfhccFUcCLHOLuCXFfLGQI+QxuGwi
nYom4hE4XCEa/d08nAfPy4HmZUJy03Oz03JyUjJzEjOyrqenxabfiM1Ois1P
ioMnJOCT0opSIaJcuBJaYMpEVReQvEhKEMWIoDhtWG47mhNFiDrQ4jasKIyS
BrGgdvIrT5xbaoNXhCil1YVF+kxiWXI+79IN0scZjLNIcQLTXKBv5YMJEV2W
nCW4AFPGocoTYapYmCQmX3gtmxMDKb6EU13lVl0rrb1eWp1KlFyHsZKh1ATA
L0OSyZTkkovzCUwoSpDHUBNszcbQWL0tapLUCKR1PHWQX97IUfmp0jo8QAzw
K3eyizQEloosq2IaQiWGcLG+iVk1wLX1M6SN0GJfVnBDZRosKmslgtU9J3LP
8qwjRE1XodBRyDLnsCshiiDJ0MXTdXBljZSSelx5S5EmXCSrxYurkJYAu3mo
omPEGGyVmWoznCG0t43laSt1taiqmvTmsF4T0HJtXKIWhyrLIxkgYh9W304z
ddP0bQRBQzbXk8FypjCrT06KZthSKYYk4F+c9jpSGYtUx+ONKQRzGsaUQq7O
KQ6gy8I8bSvX2FNk7CNYBhC24QLLQJaxK1MRSFLVZ+kD6OpmVl2ryBdVNETL
gu3awQH36Ej9zFjj7GhkbjAy2x2abQ/OtQRXO5rXu5rXOpuW2gJzzd65aO1q
t39nOLzeFVyMnvh3tM4wH7TtdngPev373d67ff69Ls9Om2unvQ7s3GyrXQhW
jXmMU23h+Z7W7Ymhu6uLAIbDzc3thZXlqfn50dmxnlGgy44Q4LG3v3l4oHm4
LzII/Av688rEEliBc4F8QSZ6xoCIJ3vHgYgBuWA0DteGwBQM0AYGv7mye7Rz
F2R74eb0wFzI3awq0TVUB2cG558ePfvzi2+/ff71189ef/fZtg+P/nfuH9w/
3j8+3Lt7wu/u3Tv792/fug/Me7j/5PDg6Z3bT/duPtzdvre1/XRu/mBicnt6
dmd0ZKm62l9YiP/ww9NvvfXuO+/88v1ffXThUjKRIjTb/LX13TV1Hb5gP0C4
qWOquXMm0jEd7poBaeyc9jYP1YZ76xo7Gpq7AcK+YMTjD3n9IX+Dp95XW1Nd
pa/QSqVSFosDum9aeuaVq9dOnzkXGx8HlIqn4OhsKnAuW8AQyEtZJTw8gwzD
owowcDgBjaNTyGymQC4plkq4YvCrQnoxj8hkIYlkKAZXiIeDZ/7jychsWGEa
JO9GTnZiVmYiJCuxIP06/EYCNiWVlporzEWp4WQzrsCWh3RC8V4E4JfZguF2
4gC/rGZoUSSvKJDLcGdyanNLPFC2NZOqTeVZ8iS1BaCmsi1p5PIEuPhyXvGZ
AtFlrCqRXZWvDJG5Lmie+HyW6AtEeQy6IhahuYqSxaCkcUhJPFoaS9HGAvNK
XDfE1ZlEaTyGl4jnpbEU+WI9FpRnOh+GoebhpdCSSlZtT5VvqFbtU0idQm1A
enIZbD1D5iFIXFhtsKgyKlHVcYs0uCIVQVpDMYaLFR68KoBzjQuAZAUNORW9
lOCW1jjE0fYyLGPsqkl23RK3ZoYsaUrByuNRkmtUXZoyQLL1lug7ePIwVRKk
qJtZsgaysBoJmoYzKoqOGYGCTS6q0ZlWHYB7ovTaKL+mWWJvUlkjOkNIV2zj
kjRYhCKHYoYowgT7IKNqmGLqRYqCefz6LG5tOlBwsTubU53FsKSSKpLw2iS0
Kh5XAbjOY7kKGK58nh+laKcbWksrolxVBK8IQ8vbcky9eeaebH1rpsSTqPLk
WoNEb1QYalOFWsrDLbrWNnN/p2u837841rw+1bk10QWq8njY0+eyTfjdU0H3
dKh2OuSeCjlmwo6FFtdyR+1Ke8NaW8NCxDXVYJ31W9aaqrdbndvN1Ue9vput
NWsh20qjbaO5ZqPFuRSyT/mM64Ntq4NtG2M9e/MTh2vLd9bWbi2v7iyur06v
TA/ODLQOd0f6OoO9zZ42j6Xepqpq80eBagGtAGHgYuBfsP0dvABkAOxw+yDw
73enYoKde2v7tzcO7u89eLD3+M7mve2FvYHWUZumWi2qCNc1b87tAISBnV/e
f/760fMvn7w82rtzd/8QkHt37+7h3tHR/vHxwf17R0/uHT27s/9wf/fkI38O
D54Bfk/8u/NodefJ8NRuW/dctGsqGO4rU9tyIbgvzsT+8O1f/ujHv/3lbz89
d/FGVj6JwSuvsAY8oYH60EA4Ot7aM9/Wu9DcNQvIBQl2Tnn+wa+7scsT7nT5
W2xOr9nuslQ5tZoyo0FrNOpVKqVAIKBQaIUwVEZmbmZWXlx8QsKNFNCBQTHG
ENEUJpnCIhOLqFQuky0q5svEJUqZUCEFGzyJGDBbJBTwxFKBTMGXyosEJQRG
EYJAQpLRGBoOSyMiSfg8JCIVkpeUnZWQnR6XnRKTmxQDTYhDJSRTUyAiCFaP
YTioiOpCTB2K0IAiB1FFUSzglxVFUINZpPo0ojsZWxlLqbrBdecybGlkbSLL
ksGtSubXpBZXp9DM1zHqy6iyy1jNNZIhke/OE/qgRNP1bPFnebLPkboLqIoL
GMMlQlkcVZvE0KcwjTd4ttRSZ5bMlSOtziPL4ymSJI4qt8xONtYWqytZXDme
xC5gVmBVPlH9sNPVYxdXC0F/NjWp1A18pYcB5Ch1Y4xhdk2XvNzHZWrQFAUK
4KYLMYsr84S1EPcEX9uBBQb0LUt8awrzCMc+Kaie5VsnaPXrPOcCker6Ipd1
Jod1hqi+oQ4xHAMyU3eJsokpCzFUTWxRHYFrRchcpNpORcuoyRkRSSrgwL/2
ANTVTHCEqVZ/kSUkrG7XeQccZfUSig5NM8JKQXNuwpj6sVUTWE1XlqoNJY0U
ioNQRSNSHkSV1BYyrVkUfTpJl0rQpRCN6UxHvrABLY9StX1s04gADN3ljUxR
HbTEk1nRUeCcwNj68mW+61zLFaE5WefGBKLS7gFrb6+9q93a0WLuCFQOt3lm
exsXwdA61rE/2b/e0zLW4Oqq0g86LbMh93q7fyXqmWiwDNfpxuuNQ27TbMi5
0V6/3e5bjVQvBqxLDaaVgGnZb9xpcWw12afdmkG7bMylmfYaJuv0i92hsUjt
ykDrzemRuZ6OqZ7u7fnFvdXtg83bK1Oro10TPU2DYXdLdYXbpnZU61wtviYg
VsAmCGjLgNbRzuHv1u9EDBQM+AXPAQ9Bfz7cPT7ee/T8/puXD795dPjy3t6z
m6tHkwOLLmtDNNg9O7p0sH30/MGL109eP3/w/MHhPZDjg3t3bwNs7z04evT4
3tPHD16CPHn45sWTPz9/+ucnj755/PBrsD64//XR4avNO69nV48Hp7Y7+her
66JUhjgmNuvDUxfefuc33/u3d9//9WeXY7KyIBSuyGCsCusrQ/7QQLR9qmdw
ZXBie2Biu2f8JL1T251j6819c/62kYaWfn9Ljzfc5m4I13iDTleVo9pmsZgM
BoNeb5TKFHAE5vyFK3HxSVAEmisQlcrkRcVcLBmPJmLxNDzAEEsjE5g0PIMK
zEssogNsBXIAsrxYIgP8ghUgXCyRs4SlNC4fxySiaTgkBYem4NE0EpxIyEHA
k/OyLqcnXMqMv5QXexURl0S5kSvKQWmRJAs+35oLrYSgXAXkAJIdxfE6cNxW
OKs5nxHIxNbEw8yXkcarOGMcwZhANd9gVWWLfCkgNNtVrO4c2RxDtcZSzLFF
VUlsVyrZGoepuITWXcDoz2P0Z7Gm80TbZWDqYnumtBYiduXy7elyd4HKgyix
ZRVpE0vMWcYGqq9DBQpUuZ3LLyPwFDixu6iyU+seqHR0W2jlBJlLUO4rUdQW
aQNsZR2xzEswhJn1wxprs5ggheAlEK4pv8iYhZZdUoWRNWMsUSBb142N7JY5
54XuRZFjpljThyvvQ9bMkfRDefiqP2UzziBE8RxLoTbCqRkqqxlVW/rk2jah
PFhEMxbSKwoMIX5wyOBtL6twMuVGrN6dafLlVjaiHM3kygjNHGLZW6V1/cbK
dpXIRSupJaoiRFUUWdEDNQxky6LXVFGMtBFAXQBKS3ENhG7KImtSyZp0vDqV
qs8Gk7I0QDr5HJ5uTkUfxzDAM7UJtU0MeQCpbMy3DaA9s0RbX4G4Lp6hPS8w
JBvc+MZWZV9f5WBPdV+7faDN0VVfOdxUO9sVXBtoPZgefLg4cTDWtxT1j/oc
M0EXgPf2YPP+QHghXN1dKQ+pOaFyQbtFMVlv2Wz1bEbdc/WmMYdyyCaedqsB
xcC/k7WaHrO40ygasCtH3dqJJtdIqGa8ydvtc3qNuma3e2l4Ymd+487GCb+D
bSNN3qjP3uA213lsvkANmA+jgE0QsNERbBts7QeSBf6dGZgCwAKQwSwMdgKc
gZ3BmHz/9pNHh8/fPPnLty//683jvz4+fL04se13RUtYCpPa0RrqWZ7eOLp5
7+m9Z18++/Ivb/7y+tmbl09ePXv4/OmD588fvXz+5PWLp1+9ePrNV6///u3X
/wPy9Zf/683r/3796v9+9vRv9+99BfidWz/uHFhyeTuVageJLEpOKvjs45jf
/PKzn//kj798/7MzZ5Nz86lCicXujrobeoKh/qboaFfvQv/I+tDkzuDkTt/k
du/E1ujC7YGZne7x1Z6xpb6xxe6R2bbe0ebOwcawPxD0eTy11dXVFmulXKFG
Ywhx8cl/+viLcxdjMsGXLuJIVSqFRs0Xi6gsJoZKAvyCgA2Q7/jly6QAYaBd
AC+3VAICNoTystKycq6smC4owheRAL8IMh5GxBbgULloeGxOytWcxCv5sddQ
11OZafkSCFqHIJiwUAuk0JaHqMoleEBnRnGjaE5zITOcS61P+9/8mmMw5nic
6eTKdHpVFs1xgem8SrFfINnO0x0xjOo4SuU1elVCkSMR4AygxlWcx1WcBSGa
zlFtlzjWNI4tWVKbqfLnq/0IYyPV1MgocyPEVVnlvnx3B7txSFsXLS+v4pVo
SaV6oszHrh2xOAfNmqCMqsbKa/lyN0dgxcvdZIkTparDGUP0+sEyU1iIKU1H
CdOp5anMijSmMdnUjjf1YHmepIpeRHCr1DHLcsxyDMPkkkiOKJKmHyoo78mg
1HxEUKYyKnKFDrQ6VGTvU9RO6KtHNaYeqchLY9lQQge+MioN9uurw2K1jSTW
IMprc8qcmTpvvr2ZUNlCNjaSrVFu3UC5b9RgjJZqm9mGDnp5O1LdkVnWcV3Y
eFoRQpf6YDwnhFWZQ9WlYxVJaGkSXplO0eSwbQipl6xpYlV0cAw9XNMAzzzI
tXTyTR1sQzvZ1I1xjhPqZvDGzhyhMwYn/bhIdU1lhbm8/EhI3RkxDEQrJzrd
s52Ny73NK30t6/2texN99+aGD8Z71jvDiy31AN6bfU13x9ofTHXe6gsNOrVe
Kc3EQFqK0EEFG3RjUJLn6g3DlbIBi7heiG3XcAG8i0HblMfQY1W0m6U99rKh
ettEo2us0R2y6Wyy0pCjenlkcm95587GnZXJ9a5wb7XBpZXodRKducxs/cc5
0kGnH4y3je5gszfS19wD+P2uRU/1TYCJGGC7Pb95a3n3YH3/7vbhg4Pnd3Ye
7G8e31q7e2f74YPbr1ambzY4W5gEoYApc5jqgIJfPHj9n9/819+//k/A79++
+fu3b/785YuvXj198+Lpm1fPv/lH/vzqxd++fP1fb17914vnf3v65K+PH/35
7tHrm7uPppfujM/cauucqXI0qZVVfLYalk26+nny2//83jvf//W7b//xiz9d
g0JofJ6uTFVjMvsj4f5wZKglOtbRPdc7tDowvgUsDBAemd8fmrs5NL01NLMx
NLXaN77Q3jcWae8PNTYEg36fz1PjchpNFrFEgcNT0rMgV2OTL11NuJZwAwJD
FfEEkrKyEpmMxedzSvkEJqUQh4QTsBROEVskKBIWk9kspoDPFpWwS0qZfCGF
zSWzODRuMUsoYonYdD6DyCKf8EvEFRIwIFACJhWenQhPS0DdSCGl5xTnIpVw
nAFNtGCR9gKYNQ9my8I68+gBGK8JyY3AikI5NF863pmItsdi7Nfx9hv4yhRy
VSatJgdn+wxn+RyEXHWB6Yrj1CaxXEms6iSi8QpedxGnvUCouETSXcJrzhK0
58j680WmGzT9VZEr0dgCt7ZRbK08WxNf20DQBqBV7ajgWHHjmLqqUSIxUQU6
jMxGUDXz/PNVlu5yXhWVYcApPfxiC4leni8ww0SVULUXa47QfaD3hjhIYRKc
n0hWJAF+FT64vZdSWg9eYc4b+qF1iwzrON40jJU0Z1GqL9Pdl5Xt6aquNG7D
BYEdXurClLgwpR5iRbvAM2PwzZnsQyqeEyeowWn8HFen0t0q11RThWUFfFmu
wlUgtKaJHRmGRrS1haBrxFhamb6xsvCcqW5UUzVw8jHRui6Mqj1D2hLDb/xC
7MGcXHNkzCKpM7DSFJggoZCfABfcoJVDeRa02EWUeEjyAEnTyrAMFDvGSux9
gupBfvVwUdUIwT6CsvTnl4WTuI5LWNkJv/KKPKOZVG3jBJyS3pBxutO1M9J1
a7z35ljP5mD7zmDb3mjX7bHuW8PtG13h7e7GnZ7wneHok7n+x7N9oDAP12ir
eDgDucDBRfdXKpZClbM+/bBDARRcVVToYCGCcsZgtWrMY+yqVDXrpS1mRatN
NeC1jYZc3XXV4Sprl69hfmB0a3Zta25rGcioqd9pdlXI9XqZTi/XasSqKl2l
x1YL4AVFuquxA7RlYN65oRmA6uHmwfHO0cO9+/d27+4sbIGdJ28Ktw6PDcxt
Lt2+d/v5m6f/+e2r/9lYOHTZGiV8rV7laPJ3Lc1s3d45Ptq7/+T+s2//D79v
nn/17PErkOdPvgTyff70mxfP/gLy5PG3946/BLX54Pbzrc0Hiwu3pya3x0fW
u9umAu52m8pdSlEUxCMu/ubKb773+89/fuaL98/HfZqMz6PzyNISlrpC4fDW
Rus9bf6GzlDjQHPrBBicuwaXe8fWe0bXwNo7tto1NN/WN9nUMeQJRh0uv81u
ttjMBpNeqSpjsblg+E28kXHlWlJ+IaYAgYOhiQgsGYUnYyg0UhGbzuNzxQJ6
MQtMwYBiCodB47EBxaBOk1gMKpfD4BfTeFwcjVGIxefCkVlQWA4itwALRZBQ
gF8kCVuIQ0MwiFwUNBdfmEeC5tEL8nkFhWIYRo0imbBUOxFXVYi05MBNGdiq
bEY9lNsI5zRCGQ3ZdF861ZNKcqWQXGkkZybFnUurK2B4CynuS3DTx9CKj/C2
c3RnPM+bxvdmcWrSEIrzaMUFQvlVqi6OpL6KkpyFCz5BCD/FyC9glJ8LXDHm
Dpitg2YMcysCPHU93hCBOvthgQlGXR+/zEljlsHZGqjMgdZ3CXxzFmUjj2ZA
iZxF4poivDSLIEljlGcILblaH+CX7Okv1QdoCGEcXBDPLM9m6TL0YYKlA0sx
nqZYPzENQexTCNMwVNOdx3RfQVScojsvAD9qu7Pl0SRRLUrixfJdcGYVRNZI
rp0ur1/Q24elLMfJSY/mFl51q0jnpvCUWfTihCJBkrgGyTJlc20ZZQ1wXQRZ
HkJYOqiB6bL2TUd0tco3rXEM8c39FE0nRNocLwxfKHXiWKYCojIDVZpSyEvM
ocdnEq9mEK6gS7JoqkKuGcW3o0trcdoWZuWgwDlRWjMkqB0XuiZYtkGMtjNT
Go4vrrvAtp+j686XWtL0VWirnWI30evMvGaXvD9gWGwL7Qx23JkcuDPZB+Dd
G+s8nOw9nhnY6g1v9jTu9kYOR9teLA2/WRt/PNVzsysIEI6Uc5vU3Mm6is0W
54LfNFKtBAj3WiROHraCCKnmkwC5rRZ11FreUVXRZJK327X9dfaRkG+4MdTp
re/whQdaeofahiZ6JsZ6xntb+roinb0t3V3h1ibviXnbA61Au6AnA/MujS2s
Ti6vTCyBUXdtamV9ehVkcXT+u8NZwMjri7fWF/a2V+7srh3f3QNF+r8fHX49
M7Lpq4kWkUUZSQU0Arc13H3v4NHXL//y5Yuv//z13796/eeXz74EzRnA+/LZ
1y+efQvyl2//n6+/+p/nz/4KOvOdgxe3bj5dXjmamNyeH1rrCQ3VmxsrxQ45
UUG+Qcz9NCPld9fxV5H0RCL6Mgx6Lo+QhKdm0jiFHA1bq1Pbbaa6OnckGOgG
Im5uHWvpmI52z4LxuWd4uXd0qb1/qqVrJBTtqatvsjpqnW6H3VFpNBtkCjmR
REtOzQLaBcnIhqHxDA5fxi9V0DhCHI1JYLCAUrEULLOYKZAK2EI2jkKAY5Fg
ZfI4JAaNSKcSaBQ8lYohkaAoVEZeXlJ6enzqtdScFAgCgiQgwQSNwGHy0Ygc
ZAGUiIAz0Rg+DlOKRojhSAWUUIGi2QgYQy5Clw7TpaBNaZSabGZdHqMui+JK
IbtTKbVpZHc6wZlBcGaRaiEUTyHVA6fXXy/Qf1xQ8TnFeZ3jyRA2QPiefJIh
EVpyASW5SlHfYGrSiNJ4KPN0Bv7DdNwf0+i/gwh/w3detHRBjS1Ela+ozMMu
q8cp/amWrjTnEMIcJQmsGJqygG+Caxtw5oESy4CEVY0maiFlDXy6Bp5COANl
XyVJE/imTG09yhDEVbUxgYgRJVcx4ut8A4yhSq0I4MqD+RjVB9zaM64ZaM0s
1D4J0fVnUqq/gGl+x/Nd0/Xk6jqz1W1pUj9CHkTzaiE0e7rIj6gcFVRPSiq6
ijhOSFkIb42yDAGysCKTxLtEYl1kCeJ4dkKRGcGxF0jrEWVBWFkQau4geSYk
fXu1fbe8wQVD1UCJbahI34uQNiWVNsVInBSOCUmQ58CL03Kp8TfQlxJgFxLh
FwuYNyiyAr4FJ3VRNCFGZY/QNSZ2jpbUDPMcw0XWAZy2I6c0HMfznimq+azI
fppjvqx25VU3UF1utsNCr9HR63Ssej23r7ZyrsW/P9Z9PDt0MNF7c6QdZH+0
faOncbXDDxC+P9X7ZnUS5Ml0//FIx3Zb3VyDZbbedLPTe284st/tXQ5Vgil4
2msMyFlmJsqj4A55K+ejDbOtgakm/2zEPdXoHgu4p5tDM+1tXR6/3+Zqdoca
7PVt/rbR7rGlicWthY2d5Y31mYX50bHvjjYDML+rzd8xCzozYHaiZ6wn0gUA
B4L2Vta1NrSAKXhr+WBv896T46+/fPZfrx7959PjP++sPOhtnclLw+JgLHGx
xmlr6G0fXV/cfXj09Mvn3/7lm//85su/fvnq2zcvv/ny1V/evP7Lm1d/e/3y
71+9+e+XL/7+4P6Xe7eerKwdTk3vdnbN+AO9Ddp6A0sngHI5mTT2DQovkVyW
xXNgy0McR6TY6WVYrFiVBi4S5bC4GbSSPDaPKZaLtBaDy+dpaYoMgCINEA63
jjZ1THT0z5/It2eiuXO4pX0g2NTu8gYBvza7VW+sUChVJBozLTMvKSU7KxeR
D8NjCEwmp5QrUvJKFWyhlF0i5ogkJDqRQMWDEGmEkyPSTDKBSsSScCg8GoqA
5xbkZ0PywJoHLciG5Kdn5yRnJQB+s6FZUGQBgB2JR4PACWjAL4KBxgiwaBEK
LiqAinMRSghWA8uXJkJk1wsU1xGaRJwpmWBJxpgTEPoYtCUeY0/E2JPhliSY
5QbCnoWpycc6C0h1iXm6LzBVcaJmuCiMKmlAsqoLCktjYSVxOGkKsxzCVkHw
xclZ6NOJkA+T8v4Yg/lpDv9XwrrL5u58XRNO4WEq6zhyD5pTdV7ReMHYmaJp
hAnsSPB/Xl6LtbSSK/p40jAZp89AqTKVDWyEMOUq9A/Z1DMESRzfnF7uhanq
oBVBrMxZiCqNoahTxGYsXZ6m8aHUDdkMy2f6zsTINia0ifKswConcpnuL1D6
P5QG4gEdinCKMpJa3oZRRVElgbwid6owkKftJuh6yLIIQuTLA3888GKicuez
FTFU/jmO6IpYmcCyULh2iqiOJPPjpAGYLJCvbcHa+zkdW46ubXfdePnJ/Qr7
2YZerKw5VdqcIKlhCK0Upgb8VedkEuITCy+louIglDSqBFVipml8fFOTyNEt
9U6ovJNyx5DQ1k/TtaNkjRnCQJwgcJlXf47tPg34La6K0XmgriDDXctyWhnO
ClqdjunTMhsNZR0O/XjQtdQeXOsJg2z0hbcHm1c7AxPB6ulG58Fw26vViZdL
Y4+mBx9PDhwONAJyQY6HwifnbIy13OkL7HZ4xmp1YOBtMyunw7V3ZwafbSw+
WJnbnx17vDD6ZHF8d6Bjvq15ob2r3x8OVLrDNX57OejJnq5I98LYHIB3a3Fl
dWZ2eXLiO1q/O2AF5Pudbce6RiwqE4hda6u1uEKuABA0+KVH+w9Abd5dO9pe
Ocna3MH6/J2NhbsLE7eGuuYj9b0mjVMhqqix+eYmVl4//fp//v7/fvvV3wC/
QMEA3q9e/xXA+/L5yWHnw8Nnt/efbG4cz0xv9/TNNvh7tDo3h6sW5jJFOUxZ
PqcCIa4hlDdxqsdVTWvW/lVjz6KhC2wsWrv7lYEA22JBSUrTqIg8LAgeSS9m
y/S6aldts7ehw9vQ5Qv1RtpGmjtGgs19oaaeSLQ33NzpbYjojVq5UlZSKuLy
+HA0Lj4xNS4hLSsPSaYXk+kCCoNP44jYQjlXdBJAsUBcTKTh8+F5cEwhnU3j
CNgA5Hw4JDs/JyM380ZGSlJqSmLKDbAmp6WCpGYnpWbdSM9JzYXmwDEIQDqW
jEeRcQgyGk5HIVhwRDEM8AsrzS0QZ0LEaamc81mCKwXSOITqOlIThyiPKSi7
CFGeLSi/CDfEQvWx2ZprGeWxeYaUQlsOrBIChmKI/iKzPlfbV1QaJnBccLoN
WihKAsahl0E5GjRLDkcxbmQUnkvK/iQl7/N4wruF0t9L/DGmrlxNGKP0siVO
FtuajdV8wHV/oIxcKQvkiKpRgkqstBataYRLmgh0JwRenlggSZTU0ZCiG2mk
szDeZVpZotSeU1EPk7ty1J5CSTWEpIrn2/LkVhJLlWMKkS1RRHk4uWEe1rGP
bz/A1a/mu+cg/PozOOMfShpipcEkfl2sMpJe0YtSdxSKwpm8+lR+KFMSzZe1
5JeGcuWNEEMbytyMVtZkCDQxInWMxnTDUpVNM9L5TrYswJY3koG7JX6IKozU
t1ECs7rwgsXaLVYEyYZupqGHKGvKVERTJQ6muIopMFKIpYXZhMRkeEwhNZMh
walrRNag0tmmdXapvMPljbMV9dMqx4DA1EOUBrOZzqus2gsloculkcv8+nOs
qtNST7I5gAL81jgZgN+GSl60RtLlVjhK2NVitqdMGLVpRvyO5U7/rdG2u7N9
y+0N3TUVnVWa9Xb/k/mh5wtjz+ZHv16deTbT+XA8enew8bA/CFag4KOB0H5P
w3zQNtVQORN2bfdHH65Mvb61/nJv89nO+pvNub8fbN6fHZ9pCU81Rf/Bb129
tdZaZqnWVzf5IjNDU1uLa+tz86uz0yefgvUP1QLzgg0w5O4uboM5F2i3t6kb
MDvcPghYHmzt7wi2Reub2/zRhcnN4Z6ZicHlldlbq7O3V2dP+F2ZOQAKthvq
cXBmZjKUz5IOdo8D/7568tV35n394uvvjlyByffxwzf3j19tb9/d3DhaWtwf
HVlpah6xWP3MIkVOLpGXSqqilvdqg/NVvZvO4VuusR3b0GJ525KqdVRQPyEJ
TKsiXQJ3hGV14cqkSeSkyynnPrn80QdfXDx7HV5IFpfqDaY6s63e6Y36I32B
pl6vv9XT0BwIdwTDbXW+Rl9DHfCvRqeVSOU4EjUpJTMhOTMPikXhmERqMYsn
40vUAmk5p0RGZQvwNDavhMMRsJhcOqAYTUAicSdvDQMdp2alAX4z87LSstOv
JyddjYu9fC3mSuy1+BsxIElpCdn5WQhQtsl4DAkHw6NwRQQkHQWlF8C4UJQE
hpZD80sz0nnXk+lfZPEuwaTxGHUiUh1fqLyUJzubI/siV3m+QHsFor2aprx0
Q3ElU5uYZ86GWHII7jSoOa44gtIN8bleNNmaz7AhscocugbJ0eL5GlKRGIkk
p6XnX0rLOZ8DvZpS9HuM5hNlOM4I6msIpfCw+DYqRhELlb5LrfxFqf9zaX2a
sBrJtaK4lbnF1TdY3ny8NRWmTsgVXRO5yGRVDl6WSlOmcirS1e5CUxAld2Wp
PPlydwFTn6L0YNRVzBI97OQOxQPUmkFo2w6xYx/bcQdbu5hZO58n9J8F/BbX
XQbwcpwxumierhcmb8sRhlK5geTiUIognFYayRCHs1QtEFMHwtwCL3OlSk1x
usobNR6Izw/nayFyG9rko1uDLF0dWV6NKaslmBqZvmGld1ipb2KWuJGyerwq
TFUESfIAUVXHL7HRaGokVppXWJIBXiRJBrTAU2Tu1VSPmr1zVZ5Ze/WIwdKr
NnWXWbpVqjaBookj8BCY9nxeZb64Bia1Q0S6dFMVqqaG6K1hhpz8Lq9qOGQe
9Jk7HdqIvszCoRqLCEGNZNhj32hvvDPcdTjSvRDxeGU8G4s4WGO6P9H3dG7o
eKzr7mjnm9neJ6Ot9/qbjvojd/qabvZEwIx8c6D15nDHxkDbUl/r5njv8fr8
y6PdN8f7L45ufvvg4N7GwvbU0PJQ9+JA5/ro4NJw30BTo9ugKyvmNdjtO3Nz
6xPTvU0tEz19N5dWVqYXbm/sPbjz8Pj2w73d4+3Nu2urh4sLtw9uv1yav11d
GXBZA2VCbSlDrBNqm93hgKepLdIz3Ds9M7ayNL29Mru7PHNzYXxrdmS9Izxk
UtdwKCIxW9lY27K/dvT31//r79/+7ZvX3755/iXQ8fOHX96/8/zo1pO7e09B
D99Y3F+Y2ujrGDFqrNlpORfPXEpLSrVqtCaVGqyyYj4yNy8/Lb0gPSPpytXP
//DHzz74A1jPnvro3Ecff/r7Dz54971f/fgn//HWD3749n+8/c5bP/35zz48
9af0zIwSkbjGWeeu9TX4w8FQc319xOtt9Pubg8FoQ0NLfWNjbUODsbKSLRBA
4PDU7Ow8GAxLJpOZTLCHxeeDeRZNJFJZLI5QCPZgqBSmgA+CIpMKMGjwkMQq
IjAZuQh4RkF+YmbGtRvJVxITLidcv3Q9HuTz2I/PxJ++khyXmpsPRdEIZAGV
ISYXCcgcNpyKOLmPYgkkn5+GVuTClTmx5LOXCZ+nsGOgskyMOh+jzEeIs+Gl
WajSbJw8FyXLREhSCkrj8kqv5MuvADvjTIk83xWs6RTHG6vtRZaE84mOG5jK
VLgxBW5MRVszMbZMqDY+RfRZPPe3Sbzfppf+MUN7ltl0Xj72ibD3t7zGK0If
nmOj4FVx+ZJ/p1n/r7LQR6WOZJEZr3LRBLZrbNt7UOWvkOWnYKrTFEuaNEDj
OMg4DYxpI4q8dHWYKWlAcKpvCFxJ0oaUsmC6PgpRNuWaulj2fqF9BAOc23VE
j97kumbz9UOfe9euK1svlwYSaI5TbM8feJ5zJd7s8roUdV2ywhMv88SIfZfE
/nPi0BlJ02lZ21ll5wVN92Vt11Vt+5Xy1iua6BVtS4zYAFNX4S0NrKrGYmM9
U+nAyBxogHBNt8jZU6oJUIvtUIETLvXhJF4sAFnhYgmtpKIKFF2HoOtRXDtJ
ESwGtAJsPbO22mmLY1hn6JSVNwvUTXywljXzpY1FXCeaasyhV6TzTFkCfTq/
LEWqzjAa4G471W/nttRI+r36Ub9ttMHeUan3yPlehaDbYZhv8t0caNsf7tzs
CE/UO4JqkZVNrJNwRtzW7c7wnaG2o5GOByOtdweaDvvCAN793vBud/hWf/T2
WPfR9MDd+dHdyYHFvva10d57W8svD28+u7394vbW0ers7szI2mjfQn/H5vjw
zuzEyuiQXaWKej1zAwMzfX0dDcEmj6+1IQDWyb6RvbWbx/v3dtf3tzcO7h6+
OLz9YnnpTm/X7EDvQkt4wOto1MstxRSBUWaqM7qKORKD1tHe1A/QW1/YW57Z
mRvfnB3bWJzYXp7anRpc6QgPNNV3DnVOHWzc++rxX75+9c1XL7/+Evj3yVfP
Tu7G8BLwe3v70a2N++MDC7WOgFSoKsxF/vG3f/rh999676fvnzv16fmPPgP5
8P3f/PwHb7/7w3d+/eOfg4333/7JL/7jRz/797fA+t5bPwZ73vnXf//hP/3r
v3zvX//1+98D+d6/fR8gfPbcBRQaK5Yoqhwury8QCDbV1jVUVdU5HJ7a2oDP
F67xeGw1NWU6HYPLhWEwAGEkHk9iMOgcDoFGo7HZJTIZt6QERSCA/Uwejy+T
skUlFA4bkAvFYvLRqO+IRhAJ4GEOHJaalwsojktNiUlOAiCfif/8XPy5y0nx
SZk5eTASmsgjM0U0jpDCY2FZKEIJEi+FomU5NAMCX5GfyLgQSz+VITiPUCcT
9JkEbSZGmYKSJ6MVNxDS60h5PFJxDa64BFVcKFSdQ+sv4SxXi1xX8ObPme4r
yo4ccTSL6opHmq8UVFwDCGNtuUQ7BGlIzZafSxP/KVfxJ3jFJyhHLL/rimr6
E9nQB8LIJUEdushCwKuu5Yr+hWz5Z2XwVLE1nlGWJzDC2cbzXMevYNpfY00f
k21X2M5M8GRONY5dRZDUs8vCPGWIwnXkUoxxPEey1JupCuYa22C2QbxztLR2
QuqeJjasQyK7mNpZtKYzoazzI89qYkVPcnlr3gm5oU9LAudF9ZmGQKbKkyh2
XhU5L5Z6L8pCF2WRi5LIGUn0LIiy7YK2K8bYc72iPU4evCis/azMgtVWkSw+
dlWQb/KxFJUYgb6Ap8+vbOI52oQqL5ltgnAtEIEDBiJyIkssWG4FnKmFgom+
tIasDnJt3QrXmL52yuQYKTd2S9RNPFmQLmugKgL0shBTHuScvPVciaCcXH6Y
wtVmlFTkSDTZgtIkjSq/xkyut3FbHNIBn2Em4l5u9U811vY4TW2V2u4a46jP
sdoeWutoHKuvngq6R31VLaYyj5QbKi8d89pXW/0g2631W231u52BE/N2h7e7
I7v90f2x7sPZ4WdbS482l7bGB7Ymh57cXP/m4d03xwePd1fvgrl0aXpjfGC2
p3VlqG93bnJreqKzoWF1fGx/eXlpZKQnFAk63c3e+uH27t2ljcOtvTtbt7eW
djeWbm6vH64s7U2Mrk1PbI4MLnVER60VrkptjUFuCrlCFqWZQRGo5KZwoHNm
Yn1xdmdyaGmkdx7U6eGeua3lw4eHb+7efLY+t788tb23fvzk6M2bV1//4/jz
1w+OX9w9eHZ0+9nOxr356R3QC+yWemQh5fL5xA8/+PwH33/nn//p5EYK//ZP
//KTf3/7ne//8D/++fs//cGPfv3T937zs/d/+/Nf/v7dX4MN8BBs//GXvzv1
mz+AfPir3//kpz8HeftHP/7+v/3ge9//95//4r1z5y+nZ+TIFWqLtcrj9btr
6622apPZbq9yudw+k92uqqjgi8XAsEC1OAoFYAv4BaoFDwHRYBVKpVKVilJU
lJGXh2fQgW0BwiVKBbGImZKbk54PAXvAfhydhqaQYXhcHhIBdiZnZyVkpF9O
uXQ5+eqV5OvxKVkZEDQMwyDQ+VQOj1JMIwqxNDmKroGzrWipj8GqRmfwryZy
f5cl+QSlu0owxmN0sQjl5ULJeajkbK7wM6jkNFx5Gq4+Ay//DKH7DG36Al95
ll4ZT7JeplSdEUXi1L3JQKkI68cFFafR5mRiZQGlCo0zQWDqOGj5aZzlc0bt
GWp9XGnf5fKZjxTDvxNEzrFr8qgVMGzZFcAv5R/+ZZuuYEqSSbIUgvqTIvuv
MJbf4StPsepiin3pRc4sgQelifLMPWJDWzGwG1mfTNbFi9152jDK1IKv7mHU
TjK8k9KGGUVwhRregdSv5Bp6MoT1Z+Utn/iWM409uZpoIdd9QRT8WBo+p4xk
2lvz9MFUpTfu/+PpPYBS2xJ13b7vvjrd53TY3bt757X3ysG0zDlnEUUFRUki
CAoICihgBEUEMYGoKGJWUBAVc8Ccc86u5Mpr593hnHPvqXr3Ddtbp+qvUYPB
xHKt8pv//885mTNL5cJv9yjo8srVunDbbOl1D2nK+wyVeWabk6jbt0DrnVZl
nVB4U1CCBxLJSMU11CJFEk+CpueGJ2dBihtSKjSsgjpSqhhOF0XSiiKThVBK
YRiFH56UC03ih6VKkdnKxMLWFHEnU6Jn5zaTuSo8swqVWhmbXoO6up9AI1HQ
lMipSWLLCCmS2KQCGK0gnCOGC8pixeXo7CxoYU50eT6uoZhhqMqbaK5Y0NSv
djbtDHYt6ZrGGiq7ygpai7KN1dJRtVxfUdhfU7LY1bje2z7ZUj1cWzbVXA1g
n+9QrekaQCPe6G7a6uvY6Gmb16onW+sm2urGWlWr/d27k8O7U6MHsxMXa0sv
ttefbqyALH24YDqYNwGopw1dC/09AN7V8ZH1iYnj1ZWdubnF4bHZ/qHBTt2Y
wXi8vn26tjvdPzbYZZwcMI32TbSqO5WKlma1vrtzZGRgbnRw3qAdGtCPD3QO
d7caWGRWsUghLaoC23R1DPZ1Txi6Rvt7pk2jq2NDSzur56+e/Pj66U8nuy+3
V86AyV4cvv3w9iegy2cfrr5ktAt0OTe1rW0d5rKKoiMJD+86fPyHr//0+6/+
7dcfA4Q//fONj3/757s37t38/NbXn35jZ2HvZu8ORgcrxwc3H17r4a1Hlvet
bM3trB/ZmN+1uHP30b37IFk/+PSzr377uz/+7vd/+uLLbx4+soyMiiEn0fiC
QmlJhaS4rFBULCqSgkl2Pp/JzSCnUImUJBKNAoRLJCCxaGhUBJ6c+M8rJ+Nj
MKiEJBKYJ1KTgcmC2AxoZXA5wHYBqr7/fEY4IBedSLwG+ZpiYM0gVPtFBPqG
BXlDQnwgMMBvZCwhDk/GJifiGfEJ6bGEbDhNHJPbmCTtYaarsGEZTqHch1F5
j1FFLmiRS3SufRjLIoB61y/plg/pRjDjXiTXAkRZBN8SkW8RW2SFLrYhioNI
Jd4YsTlNZSYZ9xIMOuKrb8VIHuBK/Qhl0YRSDFYEj8nzii2wJlSY0dUWRJVt
usEid+xGpvGLlIaHicV+6JygaK5lePr/Syz5l+wWM5rUFZXhi+Z5x2XfIxZ/
RlI+xJbfItfY0lSeZLkXtwVZPpxW3s8SdSZn1MaSRP6MUmhJJ7m6P62qJ1Vp
ZJUPYuVDqXWT7LYNQvsetHrOL1fjSVVY8nWO9YvR+dqodFCoCx+QKz/PaDYr
0AWV6cIkHcEFrT757d7CTp/8Tk9eixOoydRqs6TKB1SFObfBWdgZLNQEZ9S4
JUksJeXJohKSqIxcLKcC8aV4jjCWxUdI6xiKNo6kLiVDgmKKECkCGIEXhOcE
UHMg1LzQVGEEtxx19dzSVqqwOTmnHk+RhCUVhSaLoaDkcqvj8tR4gTqBX4/n
ySkZpQRmEZpdFJdZjMkvi5fKCDI5qbgQI8pGSjPRDeLU4XrJvKZ2vq12Uq3o
q5YOqSoG68pbirLL2ckKHr0mO01CJ4ARrB9N9F0umy5mh8HkdGrg6fzo07nh
48mrM8Wb/dqZDnWnrKgykyVikKtyuTX5Obpq2dJA79H89PHi/MnSwtONtZPl
GQAv8N/dmTFQfrdMozuzU8ujQ4tDQ0crK+uTkyZDH+i/2/PLi2OTM4Oj/S1d
VaLSkmyRuqIOOKxEUFaQJS6X1JSIqw1dI736MdPwwmj/1PL0mmlwWlmham00
VJY3SAoVFSWqhrpOnWZodHBxcXZvf/v52dHbV8/++u7lv79+/renp9+fHb4/
Pfjw6sV3r1/8+PTs3fH+JYB3dfGoRd0H4LWz8n101/nTj+9+9Nsbn/zp1qcf
3/ry03tmD2ydbLx83SFgtDZzBpMgH5ibg5+rva/ZXVurh4425i62Fq6O1p5g
xeGxh+UDBwsLexsbF3t798ePne7ds/zm5j3A8v0HFhaWNq5uXpFRCBI5mclK
z+DwuJm8zOwsOpsJmI0nEQGbKaw0GhMU3oSIGAQsGh6OiAIgA3Lj4rFgjiHg
eXk5AFsQmAGwoQg4mAALBqiCzAxABhOAMFgBugYZKBp/dcFVJBqYMhAuIg6P
wMUjiXHYlGhcejg+C5JaDi/pYShGM9gqZDjXDpHvGSvyxRT5xwp8YBnOvsnm
rtg7DrFfO6Nv+ZIfhbLsInkuoPxGZDtG8p2ihW7EQhj56hFdD0lVN6Umh/J5
J5b2HrHqUaLMh1iKiC+MQ+ZEwDPdkXmWhJJ7tJrbSWozTs89/uiXHMOfk2tv
J4jc4nheMOYDWPq/xkt+ndVixaz0IReGJxWFYYVWieU3Od2u+Kp7WPk9UrVN
Uo0zrx34aXxOK1LQjslWI9MVEcJmfPN4bpupoNrArtDSS3qR8gGKeorZvoFp
2fKWm1wymx0p5VZSY2DjQkJ+KzpdgUTl3ccW/Zau/LxA5yrVBYk6fHOb3Xn1
Duxam7Sax/QaK3qNdWaLJ6fRg6v2yGkOBLW6SBMpaA7Lrg2srMkok6eVylLl
1elyZUaZIlUio4krqGVKVnUzT1rDyBbHc0QYVn4MOQNCYAbSsiGMvDC2CM4r
jePXEAobyCBjZ8jiaOIwIHoxLL0MkaWIy6vB5Fajcyvj8sqpXDExQxifIyEU
lpKKSohF4nhJIa5MiBfz4kq4uNZi9mSzbLWrcb6ldlwpV2SndpTlj7VUD6pl
zZKcWkG6jJeSR0ZVZjEM1cW7Y4Z3Owvvdxcv12bebC38fLr93dH6q635k7mR
1YHOHpW8lJdKj4vChvgmw8MTYVAeKUFTKV/qN+6YJi5Wlr8/Pfvu/OD1wear
/Y1nm6tHCzNHC3O7c9PzAwMzfX2mnp7x7u6FodGt6TlArr6prU1ZL8sVSjl8
CZdfWVCqKlOqymsrJQppQYVMWtNU1yHMLW6sbe/vHt5a2VuYWjGNTGlajaqa
jnJpXVlxbW1VW6dmcGRoftq0uTR/sLp0fLD76uXzv37/4f/78Pa/Xjz528XJ
jy+f/QD0/OLbk4PXa4unnW0jDArfwzn8y08s7t9yMrvn8tjM09UxyMsNEuAT
AYfhEnCpeCwjIgzn4wkL9ENAgmJ9vSLcXSCP7jtZW3o62vm7OgUH+MLhEQnR
UcTwUExQEBwKjY2MxEZEoIKDozw9A52cvOwdXO/eewRkaWXt6e0Fi4zA4NCk
pEQanZpIJeMS8VhiPJgw0tNSWAzwMiIGkBsHiYD6QwJh0ZF4MoFESwLrMZhY
CouZzEwDYAJvBW03NgEPmIVj0CFRwINjwUvwFuA3gUpJpKcAgybSUxJoKdgk
ChKfFIUmhMeiwlDwcEwoIikIzfLH5/pxauCywZTiXnJiqV9ohnlkTlBUbjA8
Oyg83c+f6uaKs7ZDPHoccc8Vbe1PcoWm+cIyAqEsnxCmVyjHJyI7MD4nnFAY
hCu0JJTfyDbcL5myEQxYpzXbAq+MF4fGZIVHMAMjmM4x2VZ40T1y2c3U1kf5
w2aiiW9Y2j+S5F8nFrvH5/nB2WZRnD/FF/0R1M8MJYRREQuCJUXmxai1LZqC
UVpssZX3E5VWKWrn1AY3Ro0HqcQxvx0h6cRKNHiZjtIylt08mlPelpxfg5UN
xKnGU1vmmI2LEdWzVpJ+C16DfUqFnWIkunmOVtSeLGxKIUvs0cJfE0t/ndX6
sLw3qFDrxVXZ02SPyNL7lAoLltIpq8m7SB8u1MLy22CCJtjVE4EbEfkNcIEK
Xl8nqK3JrVVmq9WCpiYhGJWqXKUqW1HLq2vMK6tiCcQkoTQ5vySZm49j58am
8xE8YWxmEYorRmWXxguqiHmVCRklKE4pOr0EmVEcA8STxmSXxuaUxQEJiqlZ
+YRMQbywOKm8IrVEkiTIRmez4JIsbEkWXlVIH6gVL+vUOz0dW/qObV37aHPV
oqHlbG74yeLY9oh+pa99ukvdpyobbq5e6us4nR99uTkH9Hxj9tXO4rfHG9+e
br8/3ny5u3wwOz6maaqX5IvTGQJ6EiUmigyHcQgJqiLRWEf7+sjoxcoq4Pe/
vn3191dP/np5/t3Z0fOtNeDIp2vLGybThmnS2Namq2/sbW5TlciyGKwMCl2Q
ziugp4tZmZV54uYKpb6+Q9egUctUFaJyRUlNhbiSkcyqLK1Zmlkb6h8rL6ks
EkqB7aprtSBgA3hrKltamgy9honhwTlNe39v9+TC7MGTsx/fv/2vd2/+69Xl
/7p8/h+vXvzy8vnPzy5+PNx7PTWxVV2pJRG4ft7RIYFoJIKCRaUmJqSnMwtz
MksFueXFRUoep4SZWphMzsagUuGRZERUUjg0wcMt4rGlr51NoINdsJMDJNA/
DodhUpNzKUk5eAKTSEonJ2ckUThEEjMOQwqLQPoHQd28fG0dnaxs7RxdXXyD
/KCRoUhMDJ4UT05JJoA0+09CaUx6MoMKWI5Ewj38vOBx0Sg8JgwOC4GFxuJQ
gF8ANcAWsJmSkY6n/N8sDWwX8AuLRUbjsIDla9sFCAN+AenkNGYiA/BOQ2AJ
EESMf0S4X6S/X7QblOgSy3Yni3zzmmPK+hNZdZAwzsNg5p0Qtg8QhOUdzPDy
o7h6EhzdsbauKJtAskc4IwDOgUZkQEIYvv40z4BUn9CMIATTD5vjQ5Q444tv
EeV/4ekeiIZdsjrdE8udY/meUIZbcLJTRKojOsuRUGhNFlswW+8VjVmJx26n
NPw+oeQGQ+afVoEgFnjGF9wnl93ObvZm1UBp5bGp1RhaVXBGq59kFsXuDiDU
2VCbHFhtrgmyh9H8GzjhfZE2smaIpBygVHQRlD1UpSFF0ojNrYysGkK1zLDa
5hmKMa+ivq9EhvtCjWduY0DDFLF1li1pS5PpctmVvqj8/4kR/YrXdLO8P1io
9eDU2TAUFmlVtplqT6EGUqxHiLWIwrZoYVN0vhqZr4rl1yJzFdGZFZFNqqKG
2sLmerGmpayzraK1ubi5UdzSJKmvz29qElVW8grF1NIKlryKW1LOFEvpohKK
uIwGiM4pSgCWWlCenC+j5JQQgDIl8RmF6PT8mAxBTLYQJZDEF5YShUJaVhY+
JyuhRJxSI0+vkKTkc1BcSriIja7KoxgUBUtd9QeDXcdD3c/GB9/Omc7nR05n
h54ujT9bnjiaGTieHTxbGNmf7D+YGXq2PgOYfb4x/3RtFgD79nD99f7qm5Pt
754e/nx5/v5s/2Bxar5fP9OjWxrs61HX9qnrR9vbFo19h7NzL7d3fjw9/8fz
SwDvL88v/nb59Mcnp6/3d98dHXx7fv7q4GB/fgE0X0NjSzqJ6mZh4/DIMtjN
N9DFm4khMuLwhamcrhr1cIehvVpdKSqVico6GzrqKpTp9Iwcbl5PV18aPT0y
PDoeQ0xJ5gLzbW/uUdW0l0uBBbfqOocG+6ebG7t7useXl46ePfnl7ev/DeAF
evf6/1w++9uzi58vTn843Hs7M7nX1jwkFav5OfISSUNlRXt5SXNFaUtjfZ+2
fayjdaSzY1wsbhIIakWiBjAyGEUpKYVEYnZgIA4KTQwNJfr6olxdo8DL+Hhu
aqo4LU1CIGYQEzlJyVkpjFxGWi6Fxo0n0KJj42PR+LDIqEBISBA0ODQCGg4P
Q4DcQkCnclKpTCqZTgZKYiQRqcQ4PGipkRHIiABogG+ILxQOjYqLAisx2Jh4
cjzIyQBVgC2g9ZpTAK8fNBQ4L4aUeJ2cwQQIYE5OZRBpjPhkOhJPCkXEeYWG
ugZ5Ooc4usDM/XFWsRxHWplfgRYp7kHjxfYeSX8JYHwTwnEAgnIcwzIcw9hX
ggGxnCPTXZFZ3nF8f0SWT3Cqow/V2pdhF5zuAkm2jeW6JZV6YQvNw3l/SlY8
EBoD+PqQhBIHRJZNYLJ5QKJ5JMMxPtubLPSjinwZ6m+Khq0KB+4lVv4eV3gj
owYmaEhiyRCMCk9mjUtee1hqFYwghpPLYpIrIdyOsPwxHKc3ktLkxezw5mg9
44puQNi/IxTdl3SFN09SGseope2xJW1IeSeqpDWqoC5EPoBomWU0zyYX9zrk
aP8o7n1YORQpN2I0y2mtMxxRU2plNz+jyj+W/z/iCn6V3XpLpPfMaXFKr7Pm
1DkIWv2l+qiKblS5DituQRU2oAtVmKJ6vLSBJFYR8+QorgTRpJS21JV2NJbr
2hQGTQ1QV7tc01Le3lRq6Kzu0lbW1xVWK/Ia1WJtR3mnpqK+XqhQZIOYq6wv
UCjzRCWp+VK6VMGprM8RltJ5fDw3B5edFy/IJwgLSUXi5MpSTlU5r6qUqyhJ
V5ZylBKmhJfAJcGY6MAyNsFYLV7sVC12qOaalQe9Xe8Xpl5tTr9YM10sjF5Z
8PL45cY0iMfAbd/sLf90sf/XF8fAcF9sLT/bWHyxs/Jqf/35/vrrkx0wPtla
frG3+Xx342Jz5dXe1qu9nQ9Hh692tl9sbrw7OPxwcPR+//Dn8ycA2w8nBz89
Pfvf71//49Xl28P9y7297588fXVweLS81lmnJiLirG/dv/PJjce3Hzmb24Y6
uiVFIUu5OV1VdcNtXcZmTYusRl4gLuUX5XNy2NTUjsaO8uIKBiU1iUQlE6mp
FG4mO5+fKc7OyM/k5BcJS6vkqtqalqGBqZmp9Y318/29V0cHH85Ofrp89r/e
vbvi9+2r/3zx9K/7O683155tb7xYX3kyO7U/aFzq7poy6KbHhtdNY1sDfYs9
+pk+w1xd3UBtbX99/VB1da9Q2JCVVcVklhAIOTSaKD4+My6OjUKlE4m5YF0s
buHz6/ILavL4itw8WX5BlUhcU1Ao52UXprIyiWQaCpeARKMwCVhgu1gCJg6H
BKIyKTQWNYVNS2KQ8UnxaAIqDh8LFBIRHBgW4B/qB0YoPDQyNgKBhgMBQoHJ
AniB7QJ+AaFg5b9PJF177nXGBnPwFoGSGocng9gcFBnlFRrkFOTqFGrtCn/k
G3+PIHTntyOKe1HcphB41gMv8l8CU2+G59yF8G6GZ92JBZG41JFa6Z5W45eu
CgIjQ+GXVO6BFTvECu2QBbawHPNA9u0YjkOyJIAs9Y/NsY3gPkRkPwTOm9cZ
RZV7hrHuehG/DCbfh9FsYtM8E3jQxMwIVvOd4hG77K57sfm/ieR8Ti7051UR
AcKc6kh2TWBymXeiBJJcFpdUjqRUwbhtiIJRaro+lqOHszVB2fqAmPzPorP/
nCS9X2lE1I/g5boYaRtM2RtX04uQd4c2jsc0zeEGD/ilBkRm0z2x8ZsC3X1Z
f+TAvqBnm1fRQ8irI2dU4NkKb1LpH5CCX6XW/EXc7ZvT4lyo9VMMxVT1o2R6
VHknTtqCFdVh8ivRxSpydRsLSNHMKqml5khQLcrytjqZtqGqu7WuT6M2ahsM
HSp9W62ho3a4p2W0r82oU/V11Q31No0YW4z6+m5NbWdrlU5ba+xtBtJ21ra1
V3Z0VterpbLKXImYLS5kykszlZV5tfK8qrKsmmKeUpqplHJVJbzGsmx1CVeW
Ry2ko4WU2Ho+09Qk3zVqtnraQPkFCK9rGk+mjGfAdmf6DyeNQMB8Ab/fHq79
/OTgF+CzT49/enL0/cVVhz2YNy0MdI91awa1LVpVlbZWMaxtXRjqO1ya/eHi
5NvT45+fXACEL7c2X+9sP19fe7q6Aibvj/ffHu6C8YeLs1+eAxd+8ubo6MXu
3rPtvbP1reXRyfpSOQGOsr1n8fUfP7vx0aeOt+4jfYOKmJxupXpK3zvSrmmQ
lhewMjKp9Ex6akWhxNhpqCguS6Mx01MzeJxsFjUzg56FhGGw0fhcHj8elRDs
B8lgZSpkdU0NndqOAa1meMC4tL764vzkrxenf3v57B/vX//Xm8v/BBZ8cvjh
/OT744O32xvPlheOZ6dANQet+Xxp/mR0cL1XPwekNyx16ua79AttHVPVyr7K
KoOsUl9Y1ARUJGkpKdOIxM28LAU/X1Uu6wJS1HTJFJqKyo5yeWuZrElSWpsv
kuXki7k5Agabk0SnU1LpVzk5NRkAm5yaBEagRBoxnowD2MZgo5G4GFRCHJgA
ZgG5kMiQMAT0mt9oDOL6ODNA9br5ApMFkIJFwC8YiSk0AC+dk8HgcsCEQKOS
6GlYUjICFx8WhwyMgXrDvbxjHQMSrCPSHjMUgYW6aL4WRq/2QmSbQVn34vj2
kfyvQjM/CeX+BSH4mlBqxqhxyGryytcEiruhgo4ATqNnWp0LTelMktuixGZR
/Ns4oSNdHpJSERYvDEDl+kVnX121RZD60KsCYnIe+ZE/8U/8MjTJIpTgGJ4Q
EJ0UyW65x9c/TlPfiuX/OSrjFjrTg5AXTi2KThKFEAq8kFmOGIEvTR7LUuHS
m1B5OmzxVJZwhJ4/RORooVmdAVE5n0RnfcxU2Fb2wmv64qTtYaXt0PphZN0w
VGH0aZoK6ViNHzrKrRnBFXU7lA49kvTY147hDBs5HUv0/JZwmhhKzoemyV3p
VZ/iJf9PuupWXptrptqxoD2gvPvqC4zyrvhqHUXeRilWJhbKCGU1tOqG9Go1
G6iihi4Q43RN9fpmdW9782BXx6iha6ync6RbM6Rrn+jTTQ3qgSYHdAvjxs35
sfXZkdkRg8lomBzsnRvrX54ZXZufWJgZMY0ahoxXD5zWtCpb1bLm2rLOxqr+
DnVPs7JFIWlXCNsqC5or+C3l/HZ5gbYyv7Ukuz6f1V0pHFWXr3W3nIwaQH5e
bKsbqS7tKxeNNsrnu9Rbg1cXUK0PaLeGdWcLY+/2lr8/3fnx/OCH84Pvzw7e
Hm0fL02b9O0diooacUFhRhoNgyTFRKbi0XkpyXVi4VR355P15dd7W883V4/m
p/emJ9aHB5aMPVtjw6/3twG/bw72gPP++OT8b5eXb49PDheXzte3XuwdXu6f
LI1MSTIFYd5BPvYeUQHhsQEhtFiMJIPbLleMtmvGOjQdCkWlQJBFpVHQ6Aqh
SC2vLhUW5fFy+Dw+QDgtMY2CpaSSGJyUjOhQ+O2vbt775k54SBgencCgpbPS
stlMfmmxemRofW/7w/7Ot8+e/PX1y/8Eifry+d9fPPvbq5d/f/H8l9OTdyfH
bw/2Xx8evDk+/LC18WJyYnewfwXINHU4PLo9OLxp6F1qbZ9o10xqu2aaWkbV
jUMtbeO67vm2DlOFvLOkrL2ySi+r7FKqDHXqXqDq2q5yeTPgt0haLSquFEkB
xYXszEwmNyONw7o6VMVOoafTk1ITE1MSsCRUDA4eERsGQ0KjULBobBQmMQ6s
gJdQREhYNCQyLhwsIuMRwHmvc/L12d7rA86gC4NQHROPA44MbBe04/++zCOB
TIlLIMKxmHA0IgQFCYjzDCK4hKXY4QquzFfaj+I1BxOKHaNzLGNy7IgSv5j8
h2G8ryGsz+FZ3xCKrVhKV35roEQPkxoic5r8wEu2yitD7ZdS5YYvscWIragy
N05DOKc+Nk2BpZbjMQJECMPNl2JGqfBH51v5JH7kEvd7H+xtt0gz93BnRCIy
V/+Y22FOlt2MybsRyb4fTDIPJNhGpnihuD7R6c5hadZxuV5sFTpXk5jbiRf2
EgSD6SVTmeXTaXndUSCWR2X/BZn1iaDJp6YPWaaJKmqElHeGNY4jlKMBimHn
pgVv7SbOeMBrnqMpJ8NlY06lA971k0mqCWqtCcNVuSeJPZOLArMbfXM7HtKq
/sxtsEqrtMlQOhe2Bks1UcVNMbI2Ym1HqkJNL6+miYoTpSWUSgWzqpqtrEuv
rEoVivDDOt2IXj/e0zPV378wPAw0O9A/1dc7PzQ4bewZ03eaevRrprGT9cXT
jaXdhamNqcmdudn9xYW95cX91eWdpYW5scEBXcdIT9fMUO/sYM+4XmPSaeZ6
uyY6W7uVlcb6MoOyuLOyUCsX9iiLR5orpztqZ7Wq7QHtRl/7Zm/7Vl/HpqF1
ob1uRFnaW1HYXMjrVYjntfWbxo71vo613va98b6ny9Mf9td/eXr8Hy+f/vLs
9M3+9uny/Mb48LzRMNzeXC3kJ0VHhro4+NlYhjjZpWHj2mSlJ4uzgN9rhC9W
F/enJgC8R7NTz7c2Lne2Xu5uXz2HZXPzcH5+fmBwsL1jXGfYml54un2wNjGn
lFSwSIz89NyO2paGMlmzTN5eVd2jVo9ptTPdetCp9coaWV5OGg5XLSoS87L5
bG4BNzefl5tCSklGk3i0jLrSalGWwM3a/vOP/mh1776bg4PDYxsfd9+QQBgc
hmUy8pvVA/PTJzsbb0+Pv3/+9G+vX/7HlV794+2bf7y8/AUEh6dPvr04v9LZ
6bfg912YO56e3J+bOVpZeT4zc2IyHQwObuh0cwbDYl/fSmfnjF4/39Y20d5u
6uiYbGoaaWwcrqszlpS0yau0AGF1U1+d2lBR2QL4lZQqpeXK4vIqoaQ0WyDk
5OSwM7mAX2paSjKDmpxGItLwKAISYBsKDw6JDIREBQFm4egIgDOYgEXAL3gX
4ByXEHN9hBnYLui5wIUBwuAl4Bc0YlCEAd1g5frr/FdfBCYlxmAw4K3wOHgY
KiIEFRSI8wxNcopkOyaV+Up6MaWDmFSlDzLPMoJjGcW1R+V5x+a6RmTYhqVZ
RGfYJgjcqcV+bHlIpjKMWRGAzbaBs83i+Y4UqV+ixDe+0JMo8U2pdsluheVp
8LmtKbwGJkGM8UlytkF+jchxjMm18iR+bI/4NzfkVzbBXztDrBMziKJh5/QW
M1zxDWTeHQTHwo/wwB//GMUJjE33ieW6x2S6JIr9slti+Z2YHC2ywICmNaIL
h+nymdSCXoTQEILM/hSXd6NMF1HXH1/aFl3UECbTRdYMhVf0u8rH7Ns2vNo2
Yrq2UjWrGa0rCbIxn5L+4OrR5LwWWHFfYGazHbfeL6shTGwILui2piq+ZCrt
6RU2vBrPotZwSWN0QXV0SS2hUkWTlpLkMmZBXgI/GycVJVdVMBtqeTWVqUI+
aryn39Q3OD0wMjc8vjRiWhwemzEOmgx900bjeHf3cCfgt2dzeup8c+Nia/Nw
eel0aeVsbf18feN0ff1kbXVvYX52eNCoaQWwb02bDudn10cHgdOt9fct6nVj
TY0D6vLuanF7Gb+tOKeromCovhzYK4B3pbt5Sde42NUA+u9SVz3QvKZ2urVK
X1YwWFOyoKnfHejcG9bvjXSfz4y83lh8vbXy3eH29yf7bw92LrfXL3c2Xu9f
2eizteWx9pY8Chnu6eJlcT/QzpJDxA40q47mJ1/vbXw43n1/tAP0fHP5fGXu
cnsV8PtkffXpxtrZysq0waAUiYCTsonkDFJylUhqbNUOtOtbFarakipNXeuo
fnCmv39+aGhpeHh1bGzLNL45Pjxj6BpsUmsUFUphASC6skAIsnR6cgqPzmYl
0TmkVHl+iTA9Oz4iOsLf38fBwcnSPMDDzfLuPVsLKx93v9goXCotp1Tc0KOb
X118frD37vz0R2C+b17/+/t3V7fKefP6ry9efH95+cPzZ99fnL8/PnqzvfV8
dflibeXp9ubLre1XyytPFhbPpqYPhobXR8e2xid2evsWBwZXwU6ouWVYozV1
dk3pu2c7NBM1ym5guw3Nxo7OsTbNkKqhW17dUiZXl1fWl8hqpBUKcWlFgVia
U1CQnsWjMVOvzvwmodDEmGhsBAwJCYUHhkT6B0f4BcF8wQQSFQBWwqKDwVtR
qLAYXGRcAuL69O61ALnAf6+POQNskfj46yJ87dGAbtCRYdFwaHREWBwsHBMG
wQVAiO4RDNe4HNf0eqikH8PXRcYJHwemfBNAfQBh2EQw3RHsoEiGLyzFE5Hm
HcvyRbE8UWx3bLp7DN3BB3XLOfIz//iHUalOMemeKJ4/Ph+KL7FhN4TkaDC5
HeSslhSCNNY72d4aedM14XZomnkA5ZYf8WYg4YE99CuPKPO0wgTRqENq072Y
ws+ism7BuY8hFMsIhjO9OAaR5hGf55ck9k+tCsxsCeU0BqQ3BfB1EYlKaI4B
UzaRkNMZlNnqGs37E7nwbnUPqmEgubQFU9yErOhEFmn8+B1W5aPWHbvedYuQ
llVKxzqvfSOlbCRU0htV0ktKlDrwdU4gt4v7AvM7Q/M63dlNd+OLv0yp9OA3
BPFVIQWq8OxyaHp+CF8cKy1NKhQQS0Q0DgPJSooUcLByCa2xmlNTTs3jRA13
9Y/q+yf7RuaGTAsjU3MD4yZD/7C2e6LbOK7vm+rtX5+YOl3dAPUQMHuwsHi+
vHK2tHyytHS6vHywsLA5NTE30Deu7wTjztT4VVidHN8avnri9vZA31q3ztRa
3V9b0lGSV5+frshMkWdQlNmpjQWcdknOgLJkXlu31tO80de6Pdi2P6o9HO3c
7m0Fdnx1DTOAd1C33X/1Xf5Xq3Mfdjfebq+/2Fh+uroEKu37w4P3x4cA4cu1
pc0ho7aipJhJzyLgOAmYylzehKblcHb8cmv5zd76673190fbr3bXnm8uvTvc
+nByBMwX6Hx1daClhZtIDnVz97a287Gxj/ILpqIJAiavWlTRrmw2NHf1tOhm
R4ZXJ68iB+ii25NjG2NDi336yc62qa72aZ120djXWFqaS0+j44jkODwhGiPl
8Nl4MgoSFubhGejsBHF3iQryiwkLDvR0C/X1QyFimbQMQWaxVFTX2jBoGt5Z
X322u/3q/PQHkJw/vP/P7777jw8f/vHu3S8fPvzt9eufnz4FDR609hcgQoPN
AOzrG88Xl86A5hdOJqf2ZueOgAaHVoG6dFM6/bShZ07bCRCe1HfPgEl9i7FF
O6TpHgdq6jBW12vLqhqLZbWi0spigHBltaisIlckTs/NSWamAQ8NjwmBIoIA
qtfAXk8AwkBgfg1vRGwo4BeBgSHjo0Akvr424zo2X182+d+ODCI0CNJAwIsB
y+HImJCIEEgkBBIDgaKDITjfkES3KKYzWuCap40VGpAUhYdvyhcO2D97Eu4G
UuzCGV4win94sh+M4htB8QpLdA7CWgWgzUKwZqHxZs6wzx8HfuQI+8wX+zCE
ZBtJd0WyvRGCByRQJ1UhDBWMUYfAioP8Uqyd8HetYr7wTbaM4rjgcn1jOa6e
qJsBuHtpYphozCat9R4i/7OQ9C/D2A+DaY8AwiiuVxjVliDwTZUHsZXeabVO
yQozRq0tMNwMbVR2d2TxSDS31SVFcR+e/m+MUguFLra+j1bSRChuSihqRqbX
OLNVD4oHH9evu8invBoWE5sXueo5mrQ/UtKDFuvImAJLkdFRMmJZOuqV2eqc
qnpAqf4CX3wnvTZCpscIaqFsiR+F50FK9WDzIoSChPxMQi4LR8VCk+MCucmR
xdn4aklymQDHoQQOaPqAy0z3TyyNza2aFhdHZ2eMo2M64/zgxMLQ+Lpp9nBh
7cnG3tPNfdAQT1bWn6wsH87OHMxMHy3M7c9Or44MLA70rgz3gzS7NTG0PT60
PzFyYho9NY0ejw8fDg8ANhc6VWMNcl15gYJLy8Ej0hDBqfAgQWJsiygT8LvV
377e17RhbD4Y01zM9ryaG35q6jsd69nr1063KLvLi3RlooFa+faw8Xhq/Nny
4sut9bf7e9+dHH97fPJmb//58vyThZnd0cGVXv1yj266s3VK27I2YDhbmgb8
Pt9YfLox9+Zg7e3h+rujjV+eH/309OK7s6ujW6/391dHRqryhehQqLvFY8d7
5rZ3HrqY2cC8g5KQCVl0TkVBSbNCPTU4sDo9tbM4vzE1Af6lsz2dc4bOxZ7O
VaPhYmHGpNWoisQZhEQ0JCLKD4IMhrGwiV5mNt6WNgF2drc//sj2ztcYWEg0
xB+LgCViUCwKg88TSApkMklDXZW+vXF0cGhtwrSzsnp+dPL2xcuf3r7/+/vv
/v7tD//+4ft/vHr70/mT9/uHlzt7L3Z2X+7uvdnde7uyfArqy7WmJrfn5w6A
hoeWR4ZX9DpTt36yt2dGqxnVdIwYuqd6DNMNbcbG9v6mjoFmDRiNtU1d5dVN
RWXVOcISoVQmKpPxxVIuv4DB4RGoKTE4vC/EwzvYzTPQBYz+UC/gvECB4T7X
FgzQBrqmGPAbi4dfN9/r00NA15dDA6ivqi6VArwYpGVoNAIIAo8KioAFhf8z
kMdCYLgQaIJvKNkFnuGCE3rkdcZwmiExAjMn/B8dcZ/5ksyDKa7hdL9wijuM
4h5BdQsn2wdiH/jE3PCP+zos4XY0xSw04aZf3Ge+6C+CCbdgKRaINLtotkNE
7kO0xA4jtUVJ7fEy91ixU2C6hRfFzJ1o4ZfsEJsVTC9BEgWBUMqDaOYDdrlP
Tv/91La7MUWfh/G+Qefbo/ku0BRzv4R7YbTHiUJvZqVfapVDUvktXPEnNOX9
4sFg0UhMTndw2QSM3+VCk99E8n7HkduL1OHVWoqoNqGwLiG3BkGR2tGrHgiN
liUmS/Gwfe0cXjGWIjXi87siRHpcYWdyvNimcMCmYPCbXMN9suJrQsVnyTVf
kcqtMhviSzrQTIk3IcOBkOpCpvuw2ZE5HExWKpaGhuLDvRMjfVl4aDY1QshC
5DBCaVjn4a4BU+/Y4ujc1uz63uLW9tz6yujcXL9pZ3YFaH9u7Xhp43Rl62x1
+2J999nWwavtrbPFBeCz5ysLh/NX/K6OGg/mTccLU1tjg+uDPfvjQxczpicz
prOJ0ePRgaPx7oNR3c6gBkTlbllhSSoxPRZKjwyghvtW8VImWxTL+gZTi2y8
qXTFoDoc176cHXo2aTwb7VnXN+ul+YVkHDsmPAMFFyYRWySF8/ou0GSPZmdO
FxeerW+82tk9nzadAsfv710zGo6nxi7mp46mx05mJ7ZGjNsT/atD3UuDut3p
oZMlEwD5/fEmIBfw+/35+XdnZy+2t6e7e/KZrHBPH5eHVlbf3LW+9dDDysHT
ytnTxhX8eQo5giGDHvB7urVxtLK4PDowqWsf1zRNtDeCvcSPx/tzBl29WIIJ
CXV+YOlv55Ych/d4+Nj2xu07f/jjl7/5zTe/+zezLz9xtbzn72IH+KXE49hU
Oo+ZWZBVXF5ULy9uLhU2NjUPAZccHlldWTs9Pn3z/PKHN+9/+fD93968/+nF
q+9Pz9/uHbzY3b/cPwDwvgHheW31dH5uD8SB2ZmdSdPGVS6Y3R0aXJgYX+vq
HO1oH9TrxoG69RO9PVO6rjHAb12TQdnQpWrubmzvU7cZFKp2qbyOxxfzi0oL
iiuyhUWsrFwqKyM+iQJHYwG5bn6OTl62zt527v5OPiHugGggwHJAmPc1zsCL
AcIgY4OkfX3wGWB7Dex1+b22cjABXAPnDUXAgyMj/MOg3iHB4dFhkXHhcDwM
SYYhKMFwhg8614dc6sdpDqdUe0J5t1wIH/tQ7oQyHEOpnlCqfxTdOYruCE+x
C0sy88d+5Rv3lzDil2jmw6RcW1K2NY5jFsu+j+KYE/n2xHwnfJ59dMHjuCKb
yIIHMMFdVMnjOKkNJPORX5oljOsbQPWM4UKpUjSBHxDNtiQVWOeofFM1n1Kb
bqCkN1Aic24jLL8DmyTxgyQ/hDPtksV+zEofmtwiofhTVNHv6LW3y8cCpeOI
TJ1X5Wxk2ah/ev19vODjzConbplvRQuJL4/Pq4zPuHoimA296hG/x4rfd0fQ
a141hREbCFktUSCH52txQi0lsdSep73DbP9Nct1vo4W/wUh/T1HeSCyzYVWj
c6ugCRwbJMWcxPJIy4ByMmK4qbFpxCgc1Bsd7Ar4TUMHM7H+rAS/NLxnIsJ6
RD80OzR99fie3dPDtb2FsdnJ/vGZoYmrWyKv7RxvXOl85+D54SnQk72jf15z
OHMwN7U7PbE5MbI+NgScF0yAN5l0momuDkA02OBkaQ5sszdj2hzuOZ+bABl4
rl01XCXtFGbVspIqUxI6+OmGEv5YvQw0Yq280NAgmx/Sbc4O7S3P7i/N7C5M
LQ4bB1oatFUyeV5WGjYO7u0e4+eVEhetyM8d03VszowfLM8erM4fz48D7U4O
AlTXhg3rIz1T2qZOeXFdQVajKE+Vn6XIYtcXZI+oq3eGes5nxp6tjbw/mP/+
bOPN4frJ6txYj06cm4eKRDjbONuY2T66bWbzwNrLzsPbziPIyTc2OKpWXrxo
GtqcMy2NGbV1MoUgU6so7ZCVLPf3vtnZW+oflOcVoiEIN3NniHsY1Cvi7pdW
33zy6PbnZjc/e/DJ7z//7I+f3/nimzuffeVoZhbl65uOjy/npKsL8jul0p6K
sn5ZRbVEXl2saKxqWpzdXl87W9t8vrz14vu//59nH/7r/NXfz178vHX47OD4
6enJk421zdPDo42V0/Hh5RnT+voy2IluTY2vjg7OaduM/T2mHt1oZ0eftr3X
oBsy9oz16Ic1bd3q5rbG1o76ptbqOnV1naquoVFZr5ZX1wgKhXkF+dn8vPTM
jGQ6BYkBjhgaAAl0dHNwcLV3dLF1crVxc7f39LT38rIDgkA8/QNdPH0cPfxc
/EK9Q+CQsNiI8LhI8MFYbByWGE9MoRAYKTg6FcegxbMYmFRaHDURQcRFYGOg
SFhwVEhguJ9fqKdtyGNvpGtgvDOU7Bib4YbP86QUB3LqkJy6ODTfN4hqG0Cz
DWU6Q1iOoWx7GM8RmeSIotnDk+8EJPwrhPY/sMLf0JS/p6t+w2j81yTlvxDK
fo0Xf5RQ+BVB8JCYZ0PMtQc/EJX3AJn/MUbyF4z0IYLvGsT08kqxg2RZB3Du
xpcFoIWRMVkITH44Mu8xU21HqoNFVzzENn7EGv2UO3aLbbBltXqxan1iM25R
BQ4FCgy/jJKSi+Yo4GJjQF7v7eJhn8I+H6E+uEgXxa4KAPsNmsSZJramFT+g
l9+R6Fx4TRYslZmoJ5Db4pVS7ZLXxZTP0pntbuxWX2p1RGYLKacjJrHiDq/V
kSbzJhYExXLtaGVWWQ0OSWJ7Yl4Qq+QxKfs+lvkoKcM1lRdKTQsnkUJJeCgC
6oKBuScjA7iJ8FxybEpkIDnUnxMHXzEtbc6uH6zsHa3vr8+sTA1MTPSNAn4P
VrfPtsGfzgnA9sXR2eXxOYAXsHyxtnK+uny2snSytHAwN7M5MbY4YJw26I1N
DT1q1UBL00J/3+70JIjWO1OmLdP41kjvzphxvU8719EwoZLrJHntfE6PJHdQ
VjjXXLOqb17oapzQqmeN7Vtzw+e7i88Otl4cbL082nmytQp2ESCZT+o0+toq
WW4moBgV7J+KjVOXSRZH+0/WF8+2V59tzj/fmL9YmT6cHQUUz/dq2koL86kE
lJ9bjJcTws0+ysUW7mpHggbIOamjDTXrg+3Hc8an65OnK1M7s2BPZeyoVwGf
T45PxMfgIgJhIR5BIZ6B/k7eUPdAfASqs6l2Y3ZiZ35ixqhTFuVlkuNLeUxQ
sSc7O0AMmDX0NkhlGYkMfAQWH5UQ6AKxN3e3uGNvfsf2/tfmX/zpxhcfXX2/
7/M/fPTFb39rf/cu0s+Xh8cps3m98oqhmqq+8rLyvOJqSaU4R9rbOdrdZeru
nZtbfrJ19O3J878fP/vl5NnPmzvPDg6en52+2FzZOtjeB/xOjq1Nja8vz+/N
TW2ODy8O9k3rNIO9+rGOlt4mtbatWd/dNdjbPaLvHNC09QByAcLK+kZZlbJM
XlVeqZCWVwjFEkBuZm4Om8tJTqHF4VAh4RBPPy9XLzdrh8dAdg7WDs42Lq62
Hh5X8Hp72/v7O/uC/xR/R28/Z+9Ad/9QP4BweGxELBYJ+MUQcHgKGZ+SjKEl
Y+nUBCYDn0ZHp5CjE7EwDDwUGRYcFXR9HMwP5QFLCoii+UUxPNA8z8QC/9SK
cEEbkV0dRy6OjMn0C01zDWO5R2Z6RPBcoekOGBokkugGwT2KoN0ni60zG52y
Wh+nqW9Saj4lyT/BSz5B5X0BZ38dmXIvkmYVnWKPyvSAsW6Gpv8rUvgntOQR
LMvBk2Jnn3Dfk3E7jG+GLfGGZwcG0339KXZQ9k1ajXlibSBeZUbq+Di5+zck
7R8pbWbUOrf4QnsY7ev4DMvs0uhCRQq3OCFHFVU86C0auSns9xT3Bxb1hOW1
htLLfOglPlk1oelyD7LoAanohqDdMV/rnNPmLOwOTG/wSlV55+noxeMJSfWW
tHpnahU0T5PEaw2PE32S1+maVOaKyfZCZ9mnKuy49TZEoRVFFJpWZpeQdT8u
9X4C24nKC0piQglJIQkJQQRcADbGnYT2ZSeGpcWHkuH+VERQOg6+s7B1rY3Z
1fnRmelB09LE/M7i+tH67tP90zfnz949eQH0+uzpxe7hwermyerS8cri4dL8
/sLs1rRpftA4pGnTq+t09bU9TerRLs3y6NDu3DQQeHdzamLHNLQ61DPX1TrT
0TikrKjlMspoCQ3ZzM6inIX2uk2jZnNIfzg/drA0cbQ68/p8992T47cXR98+
PflwfnS5swGs/HBu6nhhZmXI2CYrFTLp5Tm8wY7mo9X554fbT/c3X+6svtpd
A+PL7RVQeHcnh3U1FeI0KtThseudGw5ffep+52u32zc8790khPjLeeyZrrrt
Mf35yvj56vTJ8sz+4tz69PTc6Fh3m6ZN1VRRKM1jZ3Ioaan4JC45pSynYNyg
3Z4b354Zm+3rVBbmZiSgCulJldkZ09q2+R7DhLazV91cJ5FVFVaU8UsJiIQk
DBUFw0YFwwPdA+we2Zjdun/vy6++/MMfPv3Nr21vfh3h5kyPjqzOzBiokhsr
yuqzMlIwSXQsFQlBVxQpS4pUFWVtpqnjqbknO0c/7Rz9cHT+887u6+OjNxcn
bzeX9w82jkFrAfxOjKzMTm5NT6z194Dd25BeO9zVMVCv7KiSNQKEAb/AgoER
A5Zr1U0A3sqaupKKyiJpmVAszc0v4GbnZPMFvJzsVDYrnkiARsA8fD0dXB1t
newePTY3t7awsDG3sbd0dHrs4mbt6Wl7jbCfnxOwYN9AZ4CwT5BHcEQADAmN
Q8fEoKOROCSKiEOREmIT8ShKYnwaFc+koVMSAb8RWMBvKOTqxFMgFBEQRvJB
sUMxnCBkuieK64HOdicXBXHrsFe3Ha5PZijwOGFETG5wnCAInu0RQLeKTkLC
CNAoanCSEC5oThB3x2e2BFMVdvDcLxG530RybwYmf+WC/Nwh4oY7/JFfnB2C
5e5H+tKH8utowV9QYrNgtoUt7o557Kd2iX9ClVjHSa6ejOlOtLKN+yKU/UVK
7SN6kyez0zq151N866/ilP8zqcGcXOkWxbaAkG7Ckx8w+CHCyiS+ApetDhD0
PBSM/iFX71nQGyjsDk+t9k0QOjFlEH4DPEsZRCu2wRfc4jXYFxn8RD3BRb2w
3E6YQBcjMCQXDEYnKG6TaixTVZDSYUZeFwwt/kSgcyWKrWM4dthcW7bSIb3W
Kl7wiFoUwq72xAsso9LuI5m28RzvBFYggRGcyAjh5iJxeBcMxpFM8MKjXElo
7wwKnEeLvb4b6vzI7LXzAn4ByKdbByeb+y+OLj48e/nt81fvn17+N797C/NA
27Mz65Om+aHBMb2ur7VF36AGk2lj3+rE+C6oZ//cYHP66mTx3vTE1sTQcr9h
trOtt6pMmpLIQkCzUZHSFMKgsmLF0L5vGnx/svP6aPt4c+HNk6PvXpx/+/zs
A6D4ZP9ic2VtdHB1uP90ae7J2tLu1Diw463p8afba+8vjgDpr88OALyv/3mQ
+e3B5rcnu69317bGB0ba1GWcNBoiHO7uGOXmgHBzjHZ3SoGHl7DoRlXpnK5x
f7L/dNF0vjYPftSz3Z2LnZ1n+4enm9tL46Zhrc7Q2NJeVa2tqhlp1ywMdK+M
9K2P9q8M9fTWV1XlcoFapIVLPbr+BtVoe8d8X/+IpttkuDoG2Frd1N3UVV+u
LM+X5rJ4JBQuBgIN8fBws7TwsjZHB/uycEgxg6KVFk41qfoqJOV0cqxflKeF
u7OZG4eax6LmC3Kq9fpl0+T5/MLlzOyzjY13O5vvjvbe769fzo9v7q89mZnc
Mo2tXd9AYGx4Wd810trco2nvb2kyyMrrS6VKtUqr6xzQdvQ11Gtqa1qqqlWV
itqy8kpJcVmBUJyTm5/B4aWmsbi8LA43M4VBR8bF+vr7OTo72djZPraxumf+
6IGludlj88c2FtcIu7nZeHva+vs6gFASGOQSGOgaEOQaBPGCwvwj4MEIZERE
dHhkDAyOgkego2GY6KgEVFxyAhAyCYtIREXiEOGo8PC4UBgKEoWGRKV44LMg
xLwQYL7IDJfINHskx40sjhK0sIp1fKlBmNfKSa1OJBQj4NlegQxrOA1LyqNx
q3iC5swCbXpOWyJwMWSBnRv5Ex/qVz7kmw7IL8yC/2we+KUTzNwnzgVCdXGP
B/x+FFt4G1Ns5Z/6wAZ3wxb/qQfjL+Rap5hCixCWhS/VwiXhC5z4UZbGDvCY
ZTBL7/6Y1PKreNVvU5rtqYoARLpDTJodkmqbnBkAWm1hAzq72YXX9afMgV/l
dHlnafxzO6CJxS4xXGuy2DetIoQpAynCnVhkxlDY8dv9xT2RslG8bDy5fCQ5
vwebrQ9AlX2Cl92k13mDRb4+JFH+VWa7dULRI2SmJTbP8uo+G2rreMEDosAj
oyGIKHWJznwcnWEP+gWa45OYE8wURYlqEzA0+wjsAzTRGol9TKH55+Si09nR
1w/xuXqmrX5gpHtwZmhya34dwPvs4OztxeV3L14DeF+eXIAgfbq1t7e8vre0
tLu4uDk7uzQ+PtXfP9HbC8a54eEVk2lrbu5gZQVoe34emNra1BQQsOCrmD0+
PNnZ1l0lk6WnZeKQPHS0hE4eUClW+7uP5ie/f3oMgD3f2/zw4uLHV89/ev3i
2ydnb04OLzbX5o29E1rN9sT4y+2tVztXF1083926PNh9e3r0/unZh2fnL/fW
3uxvvDvcen+0DfgFI3Dh08Wp9ZE+gJssk51Dis8iYotSKfUFud2K8vHWmoXu
1u2xHtCan28uAza+vTj97uLi/fnZ29OT8/X1vbm5vZmZleHBmW79orFvZ2J4
0agDEWJvYmh9sHukUakpK+qSlUx3traViEdaW/ZnZ9cnQNKYPd/Yvdg+Ol3Z
WhufnO4b6G9vb6ioqMgXFHLYGeQEVgKqLIvdXiYyVJdMtdSt6luGq0ur2ZSk
SJyvpTvEOTgOgoX5oXPTK+Rlndr2+R7duk6zPD5ytDD9ZHn2ial/09g+tT51
ApgFmprYABT3GaY0bYOA3Ib6LoW8qahQLswvr5Q1NDfq1aqO8lKlSFheLK0Q
FZXkF4CWX8Dl5dAZrEQSJR5PIJGTKdQUQiIxDBbu7Opi+djKzML8kbnZHQvz
e1aWZtZWlrZW1nYWdvYWLi6PPd2tg/ycAn0dA/3sQ4Jcw6FesAhfGMwvDOYb
AYdAYYGQiEBIZEgIPDQYHhqGikQkxILYDMiNio+OjI+IxIVFYqBwXFgMIRzD
80wuhCQWBMZxXRAsexjDLobrTSlGSXX5cmOpylSnnlGV9IlSqwnYonCUMIgk
ThG0CcuMJQJtFludSKtFYqS+gemPXEifeVJveCR9Y4/+zAb+qQvyjn+CTSjZ
xQdv746/DWF+jS+1xEltgth3fVLuQrPN4kosWK2esWLzqFwrRI5jVLZlRpOH
eMC3yOiW3voVtek3tNbfpLR8mdbkQldA4nP8ybkhSZkBKbkhORVISVuMUOeQ
1fPb7JFf5fdCWU3evDZIgsQlnGWGzHJEZTsmFrmTi11IEnuqHIRnSMkAum6e
qV7mSfrJud3hjEarqMJ/iRH/Mb70QZ4ulKm2ISk+Z6huJUrvxRdY4QSP0uus
Be3OiUUPMVnWVGUgscI3vtgnXuKPEfqi+T5J4uCMqkhBY2xM2qNw0jfoNEsM
w5aW6Z+WC4sju/a194zohyaNE4DcZdPCweru5fGz909f/RPet99fvgERGjTf
k81dYL47i6t7K6tbC4srU9NX90YeGp4fG9+cXzhYWwc63917enB4ur0Dttld
XrnWxtTUztzs4tAQqMatFSUyXno+hSSkkoCLjTarN8auDna9PNx7cXTwZH/3
3fOnb56cAITfXpy8Pj54dbgHOAIfnOsxPFldeba5/mJ783J/B8ALyAXbPD/e
Ax76Ymf13fHO9xeHPzw5+uH88LvT/Q/Huy82ll9urZ4tzqz0dU9pWhcNXTuj
gwem0Z3Rnu3hXqCdsYH9qbGTxemL1cWLtaXT5UXw859urDzfWnt/tPNqdx18
9mxp+uXa4v740Mn0+Pnc5PnM2Ga/3lgrN9YqwK6gVpAz3tF6trR4vLgIqD/b
2Pjp8vLF5sbx4vzh/Cyo/2DnY9JpRjRN3fVVDVLhQFPNXHfLnFY901473VSl
k+bKGIQcAp0cjqYhEv1tfW1uO2XSRdnMUhG/Xinrbawb69dv9Het9LYvdNaP
NVX2jHYtdWlGdNrRkcHF3u7JKnlrjaJdreoUixRZvKJ0Fp+VlpvFE4mEsqLC
ikxuAY2SnpGexUzj0FNYKbQ0MomKisNFwBChoWEREVEYDA6DwUAgkP+fprdw
amxb1H3X2efuu9dee1kbTePu7i6BhBCSEHf3QIBggQAhuLs2jTSNu7u7u0PT
3r3W2fueOvfe9/6BNzhdr+qrUYOZyQSq+I3v+zIlbm5udnZ2NjY21tbWRlY2
ZsB6HR3tnO0dnGxdXGy8PewDfBzhELeQQGc4xAUV4onHBJIJUAIWgkH7ozHQ
UGQgPCwgBBUEQwcFo6EIQhiGgYPh4KFkBJIWhqYj0PRQDDOUxEPTRBhepp84
D8JM80BHWSEirAG/9NTQ+CppUW9+8UB5/Uzj67W2qqmKlDdxsQ2C5DfitJ6k
zJE0ZU8sv5pIKYJSiyHoTCffaF2/GF1InB4kRs8/Qjso0ggdb4uJtw+VWfkw
7QIllgSVnaDShVlkj1Sa4NQ2ohqvuDb/6BYvfoUzv8yHU+grLPFWdcHzRmG5
fR6RNU8FFX+Nef1M3moWUecqLg7ipsOY8ZDoDLQ8EyXPgaa9Cs4ZcFKPP1LN
/VAwRYhtCUzpQLMLPMNiLQhK5/B4W3a2NzvHXVYZmNQSVj7Fb1iPbd1NadlJ
U/ey1cMQQZ1ueNYPpPyfyHka0Q0OzEINYeUzcbWmoNiAX2DNyjSOq7fL6PAS
5lvQU6xoRX6MokB+ZWhkHVZchWIXQHhFgdG1sMhKH3ySPi5Bl5dlL872EGf4
UWNdfQk6gFyQnw9X90+3jm6Prr7dff7fX//z//7xn19vP/zrwzfgv19u7kFy
Bvxe7h09ILy1u7W4sjQ5szA+tT63uL+2ebqzf753+Pbs8vPt/bf7Dx+ubm9P
zr/r+ugUcP3wFMfp6bm+vsHGxqp0VW5cdGWasjRFMdBQuz87fbOzc3t0cHdy
/P7y6uvb+9vjwz/fvf10dfHx7PTb5eXW1FRndXVvff366Chwuk+np8Ar/+vj
h//18f2n68urg73zjeXrnfWPR3v/urn4P+/v/p+PD7cH/t/3d9/Ojv7r7fX/
eXvzx+nR/fbG7cbq1erS2dwMIPdwYnh/bHB3bGB7pG99qHdtsAfoYHb8dmvl
w/4GSOD/eXP6z8uDT4cb3462Pm6sXM1Nfd5au1uaO5saOxofWGht2ujvaivO
BSkafOPDqbSdjbv9nbP1FbCwvNtdA9SD8X577Xhh6uHpWzOj6yO9Cz2vt0e7
9sa61rqbphvLh8uzmtKiSiIZlYrUknilWiJnwHAwF0gMN07KkMdJMtLiihur
Boc616oLugrTXlbmtJamN9YVtBUXNBTm1Te/6i8pfMVjy+Nj1QBeHieaQRMz
6RIqWUAm8thMiUQUy2VH4DB0GoVJIlCJeAqVzACTsFB0UGBwgF+gl4c3EhFG
wOHhsBB3VzdHewcHe1tbGytDywd+bZ2dHVycnV3s3d0BvABbNwTEFQVzw4V5
U7CBDCKUTYEzySEMEiwcGwxcGIEOAHEauDAoxQ9XV9IxMAw0BA+FE2BwYnAI
AYKkQkkCFEtGFOR4ivN96KlOyCizsEgrVLQrLSU0qlSU/SY3t7M0v7cyt7sk
/U2GsjU+oyehaFypnkqM75MKGin0CgQu3z9U7RystAxUmISkWiBSLREpZhiV
DbvIS1IJYWS5QiP1oDJnjNKVXeQhrHKl5pmj0vTIeRYRDZ6J7YHMYsuYpkDF
awyv2F9c5p/YDM3oDc1r84mtNImu0U1qNZM32YornHh5PmxVYAjLIjYXk1yM
F6Z5yIqcVF12meM6mfO/5k8QFe2wzEECPdcZFmPIyPWkpDvzC/24+V5xDYjM
fuqbfWXbQUr1UnTtSmx6Ly173Jdd8Rib/QO78ldu2XNZgwk5+6fIly9E5c8Y
OU8ZWbqMDJ2oKktgwawMQ3aGJa0ggJzjT8uHCCvCRJUIXkmAoMwnss6HlW9O
y9JnZhuIiq0jSlx52S74WEsoT/98+/Tt8e37s/v701sgYL5fbj5+urp/d3YD
EP7z/iMIz8B/AcJAd8fnpzuHmwur82PTS5NzB+s7V4dnlwenx1v77y5uv91/
+vP9l0837+7Pb4DuTq/AS+8vby72j443ty539/cWFjpra+vycwZevUyLkDSW
FO7Oz32+uPhwfvnp+uaPdx+/vn1/sbcD+AV2fHd8+OXyYn18/GVeXlVGBmB/
Z2oK8Pvn7Q2g+93Zyd3J0c3RAYD3YnPlcmsVNFlQmf/z7up/3V4ClsHk3d7W
7tTYQm/nfFc70HTba9BYgZneLM992tv482Tv29HOh521t8CCN5ZAPP6ws/Ll
YAOM73cWr1Ymj2eHzhfH9of69gZ7360sHI0OrnS0bvZ2giIP7Li3qmS4sWZ/
egS0+7d7698uDs/X5t8dbX/ZX/24s/T1aP3z/vrZ0uTBzDDQ5mgPGEFo3x/v
3uhrnmupGKnO7sxVNKZFDFdXDFSUVyUry5VpyfwIKYXHQtNjePF8irSuqLW3
eTwpMltIjU2XF6ZG5SWKM+RR6ZHSpKyMMllEsodbMAHHAZ4LCUDBYXgkgggL
Dvf1hgVDUAQcE4elBkEQsMCQIL/gEAg8HIHBhIWHBsOD/CAQP39zYxM/L28k
PDTI38/Fwd7e2srOytLa3MzAwtrcxt7OydnZ1QVg7ePpFBzgjoJ6IYPdCWE+
TEIQjwrn00IFdISIiZRywvEEgHAQGhOEwUHRWBgKAw0nhhGZuIdrL/FQGDYw
CO0LCfcOJQeQBGGcaKIwzzWi2IeX405JcSAnueATvEmKEH42K7UpM/NNSUpj
nrQ4jl8gjmuIyhlILppUpU4mR3SIBa/ZEW18WhU2MNk1INERm+OPzfbBZ3kR
sr05ZdDkDmpGH0dcCYXJTfDp7sxCH3GtL6/SEZelg1A+IWTr8ivtIuo9whS6
ilZ0Ri+Tne/HK/CXVUFT27AFzWh1fZC6JUDd7i9/6Sosc+AVuLJU7l6EZ8oy
Ym4DS5jmJsy2Tm13zhm3z523zBrGKLtCc8fIeLUZRKYprvTnFfuIKwLBGPMy
VN1L7jhKe7UZn9qNyxmhp/cRM0ccSLn/jlb9IKp9Iql/HtOoT8z8q7zJQFim
gUv5EZv8CzX9maTUTFBgglNocHMsBKVh5Aw/jNKdmO7FyvPnFvmIK71jX3kx
8vX4pYa8EgNBsaG4xIaTY0NT2XIyXK/3Lx9OHu2evz9/+/X2E+AXUHx3fHlz
eP6d34+Xtx8uAMvv3p1dHa1vr84vL88uri+u7m/uHu8eHu0cnB2c3J5fg/76
DpB+dXd3cQO+BCP48uPdeyDA9UewYfdwd3llY2ZmcXhooquzWJX2prpqZ2Hh
YmcPrAwgpYMV4OP1/afrq883118ApJeX17u7y8MjrRWVJcrU9oqqpaHhu739
r1dXX29uwA5vT09OtjaPVhYPluaPV5eud7dA3v6P26tvIHifHoMQe7K00N9Q
nxUdlcTnpYpFYEzgsEGAf52fPfum+XR28uPu+tfD7YeLq/c3LuYn7jfm/uNk
6/PeCsjYi91N7aVZmZGcfKk4mUYpjoqMCkclUklN2eqW3MyjqbHV3k5QjS9W
Zo8XJo/mJw5mx04Wp97trd+vTHzcmv20NX+zMnG2MHoyO3o0N3owM7o51LU+
0DHVUjNQmTdYmTtUmT1el7fWVr3e3TTbVNNXXtCQqcqPi0nk8vh4Ei0MJyBz
B1oHlFGpZAQ9mhsnpEgjmDHR3PhoWQoRzwXF0sXJ38bKHYkg+3hBdbXNPNwC
gZydvGxtAI6g0Qb4+kC8vQI8nd3tLGwcrOwgPgGokNDQICjExy/Q29fb9eFM
L5C3m7OXq5OLvY2VqZGRrpaOoamekamJhaWjo6OHu7O/l0soxAOH8MfAvGjo
AA4hmEeCCamhUiYqgoWWMJAkciiBGAIoJhDgRDKSREERyEgcERGGfbhSOhjp
64/wDCEEAH5DyX7hbCgrw4aVac/Pc4soCRAWBjHSIZQUOD2VFFORmNqUDyQt
jWfn8GXVYlVPfP5YirwviVTBpNfy4vqTZW1yfAEBpUYScjCEbBS3gsotI8Y2
84qmkmIbGYgEF6TCDZNhRS9xZpU6hqt1AmJ/hCb+SC3UiWxwI6jNwpOtBCXQ
vH5RZheXlw/h5Qent3MqW6WvBuRt88pX87L0TiS/xI6dZy0t8aAm2DISXRKL
w6IL/FFRmvENbgmvnbPGA5I7oCXTdFUPEh7/HJtuTM21kdT4SmsDhBV+okr/
inlp15kqvQfHL3NNeA3NHMDlTThE1Gvg1D/QC/4uqX3KLPo7PffvUXV6tKzf
uIUarJwn4Qk/hUb9Ha/Q5OaYSUpsIkpRNJUvJt6ZmubFzw8UFvkIipwBsKJS
Y0rG7/KXFjF1lrwCQ36BJV1tEVHsdXd0c7V3Afi9ObwE+flq//xy7+z64Oz+
9Prz9TuALeAXCLgwoOxkc3dzeX1jaW1nbesExOnDUwDvxdEZAPbq5OLhc+T/
m9y3l7cA3k9vP3x9//nru69/fPjj8/3Hu9OL053d/dW11emp2cHB+uLi3ubm
/eXVs51dYOtgrbg/u/sIVo/ziw+XV8COgSlfbe+tjk32vGyszy+qysqd6uq9
3Tv84/ru680d2OH+7Pxi/+B8ZwPAuzs/s7cwe765dn+0//n8BIAMKL5cX20p
KeKgkTAXJ4iDXaCtDRDG24MTBs+Olo68rAEV+HplDpB7Ojt8uTgOxrO5kYOJ
vsXOxr6qgpxoPgXiHmJpbvf4kaeuju2j3500n9MgASk8zlBDHbDyqTdN462v
ZrteA2+9Xp97u73w+Wj9bnHw2+78v47WPmzM7o31zLxpGKgtby8vaC7MashK
q1ElNmYr3+SlNqrje0rS9wab94Zb1rsbJl6VvilUlSRGJQuYMhpJRCLJuYKS
jBwUBA71gkTzZFwim4FjckhcBlXg4xns6wV1sveys3bz8YSYm9g++vW5jaWT
rZWjhamNnraR1nM9Az1jc1MrS3MbG2MzK0MTB3Mrfzf3MEgQENTHN9DTPdjH
y9/d1cvJ3t3extXWysnK3NrYwExPW0vPUFtHz8DAwNLCzNHO0svZGurjHA71
JIZ609F+bByEgw8SUuAAXhkHAygm4mFAJAKcQkJQqeFAFAqGSEIDIybQ0BhK
KIIYHEYJRlACEbQAkggpKnQXF3lJS3yERb50tScmzjU81g+vQIryJSlN2arX
+dxcKSoOQ84gxDaJswYT8aVMIGFzdFxfalRbgqQpOqY1Nr4tgVFEF1fzhJWM
pDZZxXy2ok2MUvogFJ6IdC1cngmpwDI80wCV/oyUpymstZA3eRPTbLm50Nha
irKZrWikxNWRUl/zCvrjq1+nvurN6loo61jLKxziSKtceCUWsXWepERTSbaf
NMuPr3IOi9QkpRhHVPnIm0JkNd7ZA5iUrpCwJE1ChiE5xxQUbUmNt7TWL/oV
tHCSU7UgSmwNEVa4xDV6K9sDi2acxNXPkYk/YFN+YOb/DZ/+Q7jyB1beU3zK
L+z8Z6JSLWaWJjZBAxRbdpZFZLltTAlSnA3jqyHinGBxTqAgy0Oc7xJT6czI
1CKrfo9vsIqtt+LmgdRtgEvUpqvMj9YOgI7XD0H/Pd44OFjdPVrfP985AhH6
w8Xd9+s3gID5ggp8tr1/uPHw2V4gRd8cX4CEfH10DiI0GEGWPtk+AIEZbARO
ClL0H+8+//Pjt2/vvwF+v7z7dH91A+rw8db25vzc/OhIT0vzWE/3wdr66dYe
ODJYK+6Or0EGuDk+uTs9A2zeHZ2A4rwyOjHS2t5Z+7JcnTXZ2fP24PjPt+++
XN++O7+4PTm9Ojy62t893ljbmp9dn5naXpg7XV+73t253d+73t4+WFhoKSsT
E4kwFxc3ExMrTU2zp0/Nnz2y19HE+Hrmx0VNNNev9bev9bat9r6+mB0Bul+d
eb+1cLU4tTPa21ddnC0TMCCBXgaGdk+fmf/2m9Zf/4ejjjY/HF2YmCDEYiIp
hEQeozYzZW2o825j9nZ95mZtEvD7YW3sen5wvrW2Lj0hVcCKJuHEuPBEDlOI
QQlRoelibkVydFGcqCUnaW+k/XSibX+kebGtsqMotTBOkMgmSEhIPi6Miwtn
YzGWuro+Ts5iFhcNRUB9AvGh2PAQnIOFs6uth59boJ+7v7uDh76mwZOfn5jp
m1kYWhjrGGs+1nj0j9+e/fbEQEvP3NDUTEfb1tjIzcbaz8U5xNcHCQmA+Xj5
OjsGe3n4uzl6Odq421m62pg6WhhaGWqZ6jx78UL7+TMNzefPDLQ1LY10nK2M
A91tMcEeNKQ/I9yfiQkACIuooQDeKC5ewkDTqUgWI5zPJYqFVImQwWOTqKRw
LDYUjvAnUdEUFgZHR6BosFBK4IP5ykmRpYGRpQHAfDm5Hvgke7jMBhHlikmA
MTJoMVVxUVXxuCRSkCwYl4YWVTJk9Wz/5EBMIU7yWiLvlid0x2RPqApnMtN6
5axijKACL6zEpfaIK5dSkzq4aJV7aLJTaOZTZLYeJtsMk2lKzjfmVZlGvrSX
v/SnqLwkReSkepGigR1XT0h8RVa3SfJ7k2pasht7y7vnmtpXqvIHRKIqZ1ax
UWStIzHJOL4yVJzhQ1NY4uMNgkRPRSVBknIMO9chuSVE8ToIo9QmZxsRMw04
pXaiag9uqZukOlD+Ci6rC+AXO3GLrKLqHJJa3crn3EXlL0Ki/z0s/t+I6n9D
K38IjfshPPHXsJh/UNWPxWXawiJDYpIBKlofwCivcVGUIGVZEEl6QExuSGxR
aEwhJKbYL6HKi5Ohz8nWTn3tnNzsLCg0oqp0kTFPENEa0/2Tc0Mza1MrO4ub
u0tbYDxce7h44+PlW5CiAVnAHL+/f3W+c/CgvUOgq8OT7+9QXR4cH2/tHqxv
rc7Mby+tnmzv3Ryfvbu4/nx7D/rsPz9++fz288fbjyBX35xdXBydHG5srsxM
TQ72j/f2TA30Azs+2di53D18d3J9sX1ye3AJyjI4+Pcft7e0tjo2PdM9OPam
u7uuaX1s5sPJ5bfbd2A9Ab8V2A389Iu93dPtraO1tf3l5e9nrEDL3p2f//4w
yaaSUjmHSwiGBjo6ORgY2mrp2OhqmWs+8bY0lRDDq9KTuisKxhsrgeEejffd
Lk3+1/ne/3t3/s+zgy8HW7cbyzvjQ10VVQVxCRIcgQYLcTcxczE0pochSTCY
hYaGva62r5UZDx1Sn5E8/bp2Y6D1dKr/y/rE5UzPZH1JXgSbFugFs7OC2FrB
HB3oIXCEmzvc2UkQjsyQ8vNixMCI1/tfX850HY69WXhT0ZqXlC1jRZERNJg3
2tvFw9LI3dLM4NkTX2cnQhjS0drWzsIKDoGhgsL8XX1hPsGAZaBg7wB7M2tz
PWMTbQMTbT2D51paj55q/vbY4LmmjbGJq42tk4UZoDXI0z3A3SnY2w0Z5Bfi
5+nlaPVd3k6Wvi7WPs5WbrYm1kYvjLUe6b7QfPHkieaT3/WfPzXXe+5qYRDi
6UAM8eFig3k4KB8fLCCFRjIxMXxiBAvHIyFYtHA+mxAhosdE8mQSNpdBwqFC
YEE+QUHeWDycQEGgSFAk8F8qBMsP4yfSpUVQSSFEUBDAyvIgpzrjkpxwSi9S
KpSTRxaX8Nm5HGwKjppFktWJxDVMfAY0KM0dkx/EbyTEdDCUg/yiOXn6EI9R
7EvKcqblu/Er/JN7CDkTHHFDMDzFFJZsjMjRCMs2CFNbodJtSDlW3HKQb50i
KiExFVR5mSStMa6gNy69jRFRERJZjk1tkdS2Z7WPv+xcaKseLVY0M7gVToxS
gKQFRmEcXRoqy4cQ44zoaaaAX0amj6iYyMpwkVcHRVX7oRJeULNMsCo9Wr4V
r8w1ojZIXAVh5XvQMh1omRaMHGN5nX3pRGjhqAsn70Vo1C+4pN+pmX/Dp/2A
kP8AlfyEjHlGTnsiKtEG5ZeaYo2MNKcoraIqHTOqsZEZ/ux4l4j0wOQyTHIZ
WpbnL8h0JCfqkpVa0lLLmBpbfqEJHfhvkhYs6mlPU1dvc/dw++DM4OTyxMLG
7CrwX5Cfgc62gSnvgd4KUALJ+XhjB0yu9o8BXEBgAl4CG7dAI56YWRyb2pxb
ArsBskDeBsH7j7cP9fn+8v7q+ArE7NP9w5O9ve3V1bmxkeHuToAw4Bc04sPV
9dPN3Zvdk6OlnYuNo6OdvbPdh1UCeP3x+vb+wur2zOLW5Pze7PLF5h7g99Pl
LUgF9+dXIJBfnZzdHB1eHx5c7u8db27sLS1tzs6uTU2tTk4ujYxM9fRUZGXx
cHiYm7urqZm1to6Njq6jmZG1rparmSEJ6qcUsavVisH6krW+1rvlqbcr0592
Vj9srZ7PT18sL7zd2rxZXztdWtmdmhloaGwsLlOII6Q0ZrJUFurla6urZ6Oj
Y6351NVAm+DrqmQR2wtUh6Odd3P9231N7bkpCioW7+UaYm8b4uiMcPNAuvvg
/YLIQVAOEhXLooEA31qSuzXcfTU3cDTWMf+6ur0wrTherOAQ6SF+MGcbw9//
bvjkd93HvzuYmTrb2uo+f2Gkp+/p4gH1CsDCkKQwLC2cSAvHhweDgO3n6+xi
pqNr+FxT98lT/WdPTbW17EyMPe3tAtxcgz2d0UG+QGAC9XJBB3uHBXr4Olt5
2Jl62Jl4OZj5uVgFugN3tnC3NXQw07I01DfV1TLVfmFtoAPgDXS2IgR5AnJF
pFApFRlJR8tY2GgeKYpL5JAQBERAeFgABhlIwIRQcUgaHkVCh2HgUHiQfxg8
CIdDhONCQrEQJBmGYoTgBEhOAl1ShBIVhvLzIPx8f+Bo0jK4sCSUVxAmKadE
VPIk5TxJlSDpTay6XxFRz0Ik+YRlupGK/CNbcckDNGUfJbkTI6jygMVrolP1
cGojboVDYgcstj0Ym2PqHfskQKEJUT2BqYxClA7wJGesyoFd4iir941/iasc
ySvpKi7tyS8bVqg7SOIyb16Bf3QVoaZL0TVf82auSdWs4JUg+TUe/DpbRqEV
NsmGkx4QX4HGy/UoKdohkY8gIh2S0p+n9pfkB3Gy3KCSp4RUI2TiC9CseSUe
FbORqe00cWkwN8+Tnm6FT34BQHuzSc3scWRm6hMURvw8K0GxJi3rb6i4H/04
PxMVpmB7RIVhTLUjN8MLLXMIizImpeqkVcAj0j05iS5SVUBsXlhEFoyd7E6J
t+FmONBVZqD2Jrf6p3dBU9qhyW+gIMx3NrS31rQA9b3unh6YWJ1aAi58srm/
Nb+6u7RxsLq5v7Kxswjma4drWwDnq4NDoIu9/ZOt7aONzb2Vhw/JnewfWByf
2JxfON3eeXt69vHqGvRTIDAB8B5u72+vbu5tbB1sbW2uLM6ODo/0dIFxdngI
EAcq8OHS+vHK9s708jkI8zsHZ7tHF/snN4fnd4cX94cXbw/O7/bPPpxcvz++
AvpwBsr4uy93H0BEBy37w+XF/dnp1cH+wdrq+uzMytTkxszMzsLCwxUm09Nv
qqsVEgkFgfC3dwD8mj/XNNd7YaH7wtXCKDzAM5ZDAfyONVVuDXXsjHRNt9QP
VJd1lRV1lhYPNzQu9PTOd/fuzi7c7B6crm3uLq5O9g72t3Z1Nb6O4Yuhbp5g
WfC2NHfQ1nDRfoqwN1NxSVMvS2cbisbrCjrzVWXxshQuM4ZEFYUTuUg8ISA0
gSvOjE5QiiTJIlGhIq6vvvJgdvxievhotHe57dVAZVFTdlpJYkwsk0SB+tto
aej8+svTH3988fujF0+eaTx6pv1Cx9jQzNHUMjwoBA0JBsKHhGKCYZjgYJiX
l4uFhZ2RkbWBnqOZiYettb+LE9TLLSzABxviRwyDgBHu54oIcMPB/dDBXhAP
O8Csr7O5t6Opr4spxNMqxM8+NMAR7u/g7+Lg42jr72QT7G6P9HMlQb35OHgs
Gx/NwMRyCQkCciyfAuDlU8MBvKAa+3o6+Ljaejnb+ro5hPh64+AwOhbDoZAY
ZDyLSSFTMBgSAs9C43nheGE4U06LLCFKCjEAYWkJPO5leEorMaEJH1EdLiwN
l9UyE5ulyW1yZUdMbIsYJGRkig8uGyKqwWeNRuVPRsU1YTiFXqQMG1SiLipR
B5WsB/CMfQ3lVXtBEnTdIp4FJhp5JfzurzANSvSCJ/jj1H6S6mBVBzG/N6pz
5U3zVHtJd0FiPaDMjVdszS925RcGZDYSagYVxd1qYRGbmAnh1HqLXrlRixwp
ah9GSrCiikhPNSMk/YaM/cmF9tdgqQkvBcZVBZESnfw4T9EJhtCo54R0K1lt
SNtetqqDKy4J5eT4IGP0/bh/ZWfpVE+E5vR6SAodZEUQVTMivt5aXKpBV2uH
iPWoyU7cHIuIctOIUnu60hPKt/ekPXOj/0CLMWLEWQqUbpGZQUJVECvRl50a
KM0PUb7CS8v8JBUeBePk6hV+wSQlb5Ka1BnWWN5QW1jdUFo/8KYX+O/m3BoY
Z4cmJnqHV6cWALlr0/NL49Mbs4sA5KP17cvdfaCzrR3gmwcra3tLKysTU5O9
/fPDoxszcycbW7eHx/cnZ2C82js439492j5aW1hZmJpbX1zeXV/fWF6YnRgd
7+9Zn39gDeTeg8UV4LAA3s2Jhau1w8vjcyBQrt+f3369fv/t5sPXy/tPZ7dg
/Hh6A2L258v7P+8///n+y+f7jx9u34GyDCrz+e7eztLy8uTU0sTk1tzC0doG
+E3AL7k6NtlZ11CUms7DkzytbM2fa+lrPjbT1XQ0M4B6OEjI4eWq+KH68rm2
l22FWTWpirLE2KI4eZYsOjc2vjRZVahIaSgtB9iCP/9gdftocw/U/OWp+Td1
Ter4pIy4uFg2kxIUEGJnGWpjIsfBu/JSB0rUgOKltvq5llcDVQ8PrKlOzy1O
ysiLUzWX1HXWNDUVVzYXlXRWV0+0tW5NjOwP9gMtt7cOV1e0Fea+zEjPjo6M
plGhzs5GT59q/PyLxi+///7Tr08eaWg80XryWNPg0dMARxd3S0t/R0cMBIIO
CMAFB4X5+sA83IPdXGEerkg/bwzEH4gYEswID2XjQpmYEDIiEA/zJSH8qKhA
LNQT5mUX5u8Y4m0b5G4J87JCBToSQz1paD96uD8NFUIJg9KRUA4WISKiIijo
OA4hVcpM5JOVUkZKBBPwK6JiyKhgmK+Lp4O5i62pk/WDPOxsoN6exDAEj0KW
ctlCDjNSwheKWCwBhSWl0qQkkgTHiqULcvDCPKwgDyEqhsfWo5VtBKDYRqyg
NFRShY9p5CS8lsrquYxCDCETRsqBRVRHZvSq6xYrCofThMU4cqovJdWdkOwE
l5kESQ2IKpeIahS9ABoYY+cXY4dI8fFP0YOmOIUqQ9GpOHYRUfGaWjQsrR7P
bFtoL26viymUsdJ9iSpdYsYzZr6pqMwjttw1qRYVW8lm5ZLIuVBGlQ+rxoVa
4E5Rw5gqtCQ3LLLEmZT6EzbpfwZF/gQRP6fHwVgKGDneA8LVxcabwyK1Ofke
2f28ssk4aSmGrgokJ7n5sZ54M/7Ky9LP6fTJ6fGJKvVS1pEKu5nJjc7R1Yay
Mgea0o2T7icudBKXGNNUhnCxtQ/V0p2s4UL5AUL9G0r4nJvsFJEVLEyHspTB
0jxMWiNHVo6iql0Ialv1IDF3nCqq9+bWeODzrIrSC4AAv8B8jzcOQPkFk/aX
LT3N7YtjM9sLKyAYTw+MrE7NAX6BHZ9vb1/s7JxuboK+CQRsbn16erq/H2hl
YgJs+b7DycZDmt2am9tZ3pgfm54YGlmcnt1aWQH8LkyMTQ31H2ysbi8uPBxn
YXljfBZoa2z+buv4+xmo+/ObT1f3f959Avpy8Ra48OfzO0Dxp4u3YMu/PnwD
/H68ew92PtneOd3ZBSOI4qvTYE2Y3lpY/O9M/rDUgINPdfc1lVbIuQJ/B2ez
51qGWk/N9F9YGWq5WRqSYX5ZclFLvrqjOKe/qhiY70Rj/UBNTVlyilIoTmCL
oulcRWRMXXH5VP/o7srm3ckNqAOX++fnew8l4nBpdeDVq0yZlAsPovq4pDLx
IxW5q29qTsd7Pm0sfFhfPp2e2RweW+kfW+ydmOuZWOibmuocnursXxubXB8f
n+/tnu5sX+vo2OzuXmh93VdW2pSVWatS5cfFJvEFWL8ASy1dY00dUGyf/vbs
91+e/vbr019+fvri7z85GRmbPtPwsLDEBwWH+/sTgoMxAQEogG2gHxkOZaLD
GCg4FQFlY8KktIeWKqAgmVgoAxPMxoeACRbqDvW0RgY4hfnbIwMcsFBXKsqX
jQ/iEIPYBEgkgwwUxSIn8OlJQrpCQEuRMDKieWBURXHSIrkxXBITHxoO9fFz
tXOyNrY1M7C3MHK1s/B3dQ4L9Af8MnBYNpHAZ9GjI0VR0SJJNO/hWpJoOi2S
wktkU5ORTFUYOyOEkwuRlEHjmwDC+MTX+Oh6rKji4S0pWT1bVE2j5oVR8uC8
ClxBf239XFvTUntGWyZbTaGnIhlpCGyMZwDXwo2qD4925RUSqNlYWFwgXAEn
ZpHRBY7Y3CB8FoWSw4+oEWX0SMsnYqvHc5qn3sTkpeGjMLQUd2qWDkLxV4Ja
I67RP7rcXFrkKSoEAYDOq8Yxq30p5U60Ij9kvB9NicHLPeKqvchpP+JSfqBl
Pgd9kxQZzEyAs5MDERILYpItIsZIVhXyajlF2cwmpwQQEn2IiW6BXE1cjHZa
k3fZICylxUWY45ZYScppY8ir7SPK9WKr3AVZkOgSdFyNH+AXJdfwour5UG1h
IvOwmOehvF8xUk2GwhbwG5GNFKiR0nxiQi2LqvKHyy1DFaZpA6SMMSql2B6b
ZwVL1a8qrW6uax7rGQHOu7e4tTo6P/amt6emub++dXFgbGV0ari9e6Szd3tp
9XR/f3dz43xn43Rr7XRrA0AKAAEWPDc0NtDaMdEzsDAysT2/CIwPULm3vLg6
NbYwOjjVNzDe3bswMgZsEYw9TS1AMwNDwCKBgH2vTk4D716bmgFH+3b79j/f
ff7X249/3L3/dvf+y7sPn969f3t7d3N1/f7+3eePn/74/OXPT1/+9eHLP999
+nR2fbm1f7C8tbe4cb13uja5MDc4sTO/tjoxf7S6c7lzfL51CLafbR6MtPcp
pHK4N8TVwt7X0srb3MLDzCzY0VlCoVdn5wGD7qh9OdbWuTo6BtruOVgHBnrb
igrUIp4YHVqaHN9TXbE22He8MHO/u/mv6/P/fX/zn7eX73bW322tHEz09ZZl
F8dwy+N4Y9WZZ6OtAN7b+dFv28vnE8P7Q303czOnk2NnU+NXi7Pnc5PnCxO3
6zN32zNny0Pro83TneXHPe3rLS/Hq0rb83NKk5Pi+QImjoQNC3dzdHdx9LA0
s9XW0Hn267OHzxl89Ozh00Ifg/kz3ccaVgaGIDZzcDg2FoMNDMRC/Hl4TDSb
IaGSGEgkDYHg4/EyFjOGwUrg8sFhZSwWl0wih6OggX7uzg6eHi4uDrZuTvbQ
AF8MHIYNgZHDwrhEooxHihFS40SUGB4uiomOYaGTBES1jJkeycyJE+UlRqVE
CgQkPNzP18XaxsrQxMrS3NbGytnJwcfD3dfTy9vdw8/LExoYQMKiBWy6IjYy
PSUmRRERG82UiQlSAZauDKEmBRGT/Uhqb0axr/CVn7w/MHHCP2bESdptwXql
x6w2ZpfbULMd+QWQ9Dfc6pn61q3XbXsvK2ZVSW/Y/LJQdLKbj9DagWZlS3Tw
5gciE3AoBRqTgiBlhoIATCgMjGplRTWJGLl0ZgYvqlSR2VRY2VeT35rNUIQT
YwOZaUEouQMhyVlei1G2UPC5cFIRkloRji+BhxcEMSrDmOWwcKUjOs7Ck/Iz
V+UQV+VPSTMlpBlj1IbBiufMGH8Mz0GYBJXnhBMjHIlR9onl6IxGkjDbU1Lo
RVaaYhJ0uLnWgmI7QYlNfKNX3CtdSYWGtEKXk6uNT3rCzTWV17jw880jy60j
KyzZOdro+J+Q8p/JqdrAiPEKHXaaETlBC8L+K072jJdiRo8ziUh3V5ahRGl+
aJEFP907rgqm6ghlFhlSCp+Gqv5tsGdofGB8bWZle2FjZXxheXh2vm9spKkT
8Dvc0jHa1j3a2bswOrm/tn6yt3ews322vf6dX+CzwON2FpYAv0NtXSMdPfPD
4wBSgOT2/Pzq1MTccP9Eb2dfS+t3AWw7Xr7qetU02tm9ODoOdgPfC/YHqfs7
9SB1A37/4/Y90Lfbd5+u7t5eXt9eXr29vrm7uQXw/vnl6398/fYfn78Cfv98
++H98cX5xu7uwvr61CIAdmV8bqZ/bGF4arSjH4xg+8n63sX2EaAbbCnLLJCx
RaRQDAMewkKEMcC/NwaXJotqrawBBj3XP7Q7t3i2tn6/t/dud+dkfmai6WVl
ckIym1YQH/2mJH+hu+NofvrDwQ4gFyD86Wjnj9ODr4fbb9dnjyd6t/qadntf
nYy+vp7qvJ4dPhrp2hvomKyrHKut3Ozp2Bvqv56febu2dL00e7k0db06dbk2
fjTftzL0aqqj7LDrzVhpfmmkNBoXTgoMCHJ28bCxc7F2MDM0NzeyMNE3NdTW
//4EAL3HGs//8Yupto7+Mw29x09tDQ2Rfn58IkFIJDJQCFoYXEQmyLmsKBYd
kMsOD+cR8GIqJYEHrFOSJBZHMhkcEoGCQYVA/FydbO2szcxN9IEcbSw8HGy9
He1h3p6E0BAOCSGiIcVUJAcTSIK6EiHObKRvJDEkSUBKFQMjFmTFy9KiI6Us
Bjo4yNvJ2crM2NLUxMrM1NbSAsja3MzOytLZ3i7A2wOPRsgkbJUyOiNNnp4s
USZwk+LYzCQ4UwlnpcFYWcGsAj9utZe01Su6xz2m31HWa8V6qUsp1eaUWQtL
PKWl0MRagqJRWTJW2LRRVbecnT0kjW7AkTL8IJGOvkJnD5Z7kASGScRjFChs
aigtL4yeD+fVoeVvgIMzCCosJ5uvrFfnvikq7iyRZgkYSWi+Gi3MCSUme5BT
3IRFUHEJjF0aTilAkIvg+ILg8Bw/SkkwrSgAlWQbItN3wv4VF6PPz7DDxuui
H+q2DjpVjyX3Y8l9ItLgrHhvKE2fILOTF4ZIsn0YqfbCHBe6ypKg0KerTclp
+vjkF8xcU1WXmajsCT3rF1LabwTlY0GBWXSVEzfXmJGhQ1D+jkn8BxgZmVqA
a062OTPDjJqsxU7TDxH8DcL4N5TwN2aCSXIZNL0aB+owWmRFiXNUNqDjXgby
Sy1Juc9Q6T9Oj83MT8zvLm9vzK6OdQ7N9o0CfjuqG9sq60FTa62sG+vqA4n0
aHPrcHsb8Pvf8D7wC0z2cHUV0Dc7OAoY72tpm+4fBl14eXx8bmhoqr93sK2l
o6EW9MeWqppXZRWVufnV+YUA4e9leXl8cmlsApjv7uLyxc7eu9PzT5fXQN+u
3v5xff/5++MCDk8uj0/vb24/vv/w9fOX7/D++f7TH28/fLl+e7t3fLj0ACkw
3O/mO941ONzW29vUPt03ujmz/N1/D1e2wauzA+OdL1+XZxUWJykq0lIr0tPL
1erm0rLp3l5QwC82dz6cnn46Pft2fv7n+dnH/Z398eHBmvKX6pRKZeJ/32fU
tD02eLO5+uXkAFB8sTr/8WDzw87Kh+3FL7sLf+zOf14bv5nuOhluORzuHKrI
a1Ql5kn52SJeSUxkUXRkfWpyX2Xp6MvqufbGjaH2nbGOlcGm8TelPXVZDQnR
KWQ82dXZx0DXVvO5yePHWr/+DjqvnqaW7nNtIx09G2MzR3MLR1NzR2NjZ2OT
YDc3UH4djY0CnByByUYyqIDZOA5LIeAl8rlgLqWRAb9cLFZIJgFmueHh8Vxu
skQSxWbxyEQqFh3k52VlbmRmrGeo98JQR9PUQMdcX8dcV9vRzMTXySE8yJWC
9OPgoEyUHx7ihPG1owa58lH+AGEZNSyWTUwUMOIFbAmNTEGFISGBwMrtrS0s
TcFaY2xubGRqaGBuaGhtaurl6oQOhUaKWepUeV6WIic9Ol0pSlXwRckYcRpW
koERZIaysv3oeS6sUlt2tWl0p11MpzW3RpeS/1xQZiWr8BTl+fLUPnQ1NaEh
unhMVTqZlNHLl7/CMfMgaIVHuCIQEROETULTMsjkdCwtC8UvwfBLUYzyYF4l
CpceFCoP5Ofy1M2Z6qYMRUU8JgJ0SWRkAU6ch6Cn+5DT3BmZ3qxs36g6AqcI
Ts0LIuX6o9RumAw3rNolLMEsWKrtiPkLlPeYKNfHRL1ARmkgop9S1CYyNVyc
ApGmQ6nRzsE0HYzUXKDypCfZMpV2olxXXpY9JcWYkKSLkj9Fxjyhpumld5tz
Cn4JV/wbXvkz4FRSYhVZbsvJMcIqfoNG/FuI7C/0DA1JqRkvz4Sm0qemGfCz
DVIb3PmZ+hDmD37kHxgJBupaRHIpIjoHhouwI8Y4pDUS+XluwjIHSq4eJv3R
1Og04Hd7ZXt1ZnGse3BxZHquf6w2r/hlYVlNbhHgbqSre2tx6Whn52Bra3t9
7XzzuzZO19cOlpY2p2YXh8Zneod6GlqAWU/3PDxydqKrc6TtTXttVU1ednl2
LsC2pqCoKq/gZUlZZ0PjSEcXSNSA4tnBYcAvSNFvj08/Xlx9OL8Ek6+XoOde
3x2dXe0fXx4c35xdfLx/B2IzCNJfPnx8SNQ3bz9e3r47vQTmuzO7BOLx/NAk
SMiDrd2A3Pa65p7GNuC/IEgDfm8PzgHCN/tnd4cXgHTg0RNvmme6Oma7O6e7
u5eGhg6Xl+8ODj6enX27vv56cfHwcUjX58Bbb1bnNwa7Z1sblrrfbI/0fb9Z
6WZ9CcTmu82Vi+W5+83lu/X5d2uzH9an75dHLycf4D0ZfLU/2F6dGClFBmNd
7NCOthgXB7iNJdHTLQKLzJTwW/Mzpt/UrA20LPbU9zfkNhUpVDQC18/LT1/H
5vdfTH772eDXn7V+/lnj53/oPnmq+/SZua6eq6Wln4N9oKMjxs+Hi0JG0cnM
sBBikD8bFSqjkeI4jGQRL10mSYuQSEgEkKKDXZ387OzA/kg/X2oYggyFylks
pVQqpdMAcRhYsL+7i7mRnr6WhrbGY53nT4y1Nc10Hk4YWerp2Bkb+juaoAOc
ebigaAY6lhUuZ6IT2OgkLl7BwaUIyEl8SgQZQ4b5I7zdED6eGIi/l6ujg7WF
uZE+kKXJA7l2FhZOtlY+7s7hiGCpkAHyc2F2Yn5mbHZ6ZEaqJEHNlqfTI1MJ
wlQkJy2Qke5CVpsTMnWim21lTWa8ci12oba42JyTaYWNMkCJDUgKlCifklDP
jasjScvgnAJ/WpY3SeWDS/bHKoJoGVhOHpmWgaJlwtn5cEZuUIjCApnkEBRl
B4/yiizmZb9RpdQmSLKYtESENJcQXYyVFsJ5uYHUdA96hhc4YHw9VlgUzC0M
YBf6Y1UOCIU5Msk8NM44RKbjQf0xRPCYINchxuqgpE+h3J8oCr24vFBGnAtN
7sCMd8aITJF8fZLckqGwEWY4ywo9Iwvc2GkW+FhtVPQzaoq+tMg+oVGHmf13
rOIvVNUjXq6+IM9UmG/GzzUhKZ+Ex/2ETfwHO/sFP8+AkvICIfsVJv6Vl6Wb
1xGganSnxD/2p/1AjnmhrIBEZflGZEDo8Z4CVVB8BRr0bm6+k6DUHpv6YmF6
fnl2cW1hZX5semZwfGt+FcTgytzC6vxiAG/Hq8bx3r7NhcWT/Z2j3a2NlcWz
jdXvOllb3V9c3JqeWxmdWBgcG2hu62963dfYMvj69fCb1t7Gly+L8vOVimJ1
ZklGFkAYuDCAF6To4fZO0H8Bv8B/95dXr/YOQHL+/pb19f4hSMWXu4dHa1sP
73UfHN9f3Xx6+w5gCybvb+7eXd/en1+9Pbm4PTwF+2xNLyyPzQ687mqpfAns
taO+pbGsFvALvHh/aRNUY4Dw+9ObbzcfPl/eA4TBl98f2HU4P324NA9WobeH
B+9Pjt8dH306P/t0dvxwBfXV2dfjvev1hdO5sZPpkavFKcApoPV65eFZIocz
4w+aHQPl93pp+mp+5GZh5O380O1M7+1M94eF3ovp4YJIPtLe3O7RP+wf/+z6
4hlQqK0lwdtNwSS9KVSv9DUfz/YfzfasDjROvC7pyc8qEPOYAT6BpkaOL55b
PH1i8uyx8bOnek8emetoedtaIX29cAE+ZIh/FBGbI5MUxUepRJwEDlXBoydy
6NF0YhSNEM9hyFk0AiTA3cLUSkvLTEPDTPO5m4U53MuTDA0C7qyWR8l5bDoG
iYUHwXw93OwtrYx1TXSf62s+NtJ+ZqGvZWOoa2es72Bq6G9vhPCyBeYbz8Vn
y7llyRGVaZFVqZG16fL6zIRqlTwzihdJwdJCIcRgXyIs0M/T2cXe2tbCxM7S
1Nna0tXW2sPBzsfFydfVCQULEDCJybHiXHVsUU5CSX5CaUFiepY0MZUbmUAU
JqBEKSFCdQAn04meYRhVZyOpMOAXv4ioMJSWmKEjH3nh/+JP/gczBclVo9gZ
IeQUj/B4a1BLcQobgtIFLrNDxriS02CMzDDAcngicGTXkBhLX4lmQIRegNgk
PM5LXsHObE5Q1sriy/iKKm5cOVFWEhZTEQaSOSXNhZzmJqsMiyj0FeZ6RpT4
S0p9Cek2YYnG6GSTcKVxWLxugOAXjFybnmRETzDASp9BKP+O4v/KTnAMFxmh
hYbkaAuizAwjBhHaiBZnJkp3kOa4yvLdeOlWuOgXQHy1VWypW0TlU27+r+S0
n4jK34jJT7HxT8lKbVGBJStTl5Oty8vVZWfpUNM0MXFPoaJffFl/Q0f/PaHK
LqPFS15shZb+hIl4JMt25iocOQo3oSoouZLMSvENj7aiqxyia3xxSr35ydmF
qbnB7v72V80j3X0rk7OjXX11RSUAt66m5tHunvnx0Z2VpdOD3eO97Z31leO1
haOVxcPlhcPlJeC/2zPzq2OTC4MjY+1dnXUNLeVVbTU17bU19YV5BSlJGfFR
gN/SzGyQokEFBs13rAvU5FHQfEHSBhX4O7x3Rydg8v+fmdrbX17fnF3cXVq7
2H24LREAe316DnR3evFwT+L3S0d2DsBuKxMzg209Pc3tb+qaRrsGQH7oaHgN
xoXR6eONvcO1ne8Xgv7z/devtx9ujy5Otw6Ol6YPFyYPFmfO1ldu9rYBuTeH
+xe72/dHh7f7O++Odh8+Gnh/42Jl+mxhFHTV/fHe46nhk9nRg8lBYMRbY/0A
3qvlWbBlY6BtpfPV4XAH4Pfj8siX5eFvq6PbfW2AX5qve4CpnrfBC3ft57aP
fvHW1yb7uafy6F1lORsDrVfLox/3Fj7szd5tTmz3tI9Vl9UkxSuYFEZwQKCd
laO+tpW2hruFcZiPu4SMUYo4AFiVgF0slzakJ9Uoo0tiJXmRvCwpL1XAiKLi
2AgoKcifAPHzs7Gy1dO20dGxfPHC9NkzkLEfTio5OQjx2LyEuPIMFVhOFZFi
HhmPCYGwiBg8Ahrs7ebpYO1qY+5uY+FpZ+XtYBPu74QLcKGGeEpJ8FQJtUQh
eSA3Iw6oTh37MiuxOT+tuTC9JiMpSy5K5NGjxVwhi8IkYUCzxiFCEBB/mJ93
iL8PBg6l4pASLjUxhq9WRoL8XJAtL8yJVaXLEhWCiBiKJBYXocREZ4dFFQRJ
C11AqhQU6vMLtWJrzaPKzEJFf3fD/ACh/8hKCaUlBeLkLqES02CBNlSsjZAZ
hMeawyJMwqLtKCm+lDT/sBhHuMwmRGbux9eDSDUCxJoBAj1MnKskDyMrIMcU
09JfidMa2BEFcFFuoKwUxsvxCosxD40yJ6a4MlPMOCrLiCJXabErJd0cn2pM
zDDHp5uEJmj5iX4hJBvQUk2A/xIjNUNoP0IIfwllP8dJDPBSw3ChDklmzEu2
5ybZkKOM6HEmzAQzYZoNT2mJET/HSjQ4SabCNCthwWNxoSY97VFY5I9Qwd8C
2X9DyzQkeXaCbDNpgZW00IKjNqQkaeFjX6Ajn4eKNNCRvwmzTFPqvdIbfOiJ
Wijx7+xk84dVIsJSmglNqaaGS63CZZZUpa282p+WbjbU0zc1MvbmZWNNcRng
d2licrC9o7Oxaaijs6/19Wh319rczPH2BtDe5ur+1tr+0szO/OT27NTu/Bzw
3935B37n+ofGO7qbSivKMzOrcnKKVWlJUlGsgKWUiYrS0xvLy4fa2kApXpmY
2J6fP1pb+96dz7e3746O3h4fX+3tnW1tnWw8dOr/fvtrEWh/de1sZ/fq4PB8
b/94a/tsdw9MwJajjc3D9Q1g3GtTM8DHAa2zQxOTfSPbC2sgPIAIASb7K1sX
u8c3h+f3p9cfL9/+x7sv//rwDcz3ljf3Zsd2Z0Z3ZicOlx7ud7jY3QTwnu9s
nWyuHizNHy3P3Wyv3G4tny1Nns6PXK1Mns2N7I52z3e+GmmoHKwrG2upXx3s
AnF65k3D6MvKsfqy5Td1Oz2NB/1NV2Mdn5eGNnrbOouy69MS8yIF8RQsI9AL
Ym4QYmMaRUCVJ0WNN1ZuD7dfLIx83J3/drTy5WBpb7B3u69ruf01qNsVyvho
Gp4c7Bvu4yrEhaki+C9zUjvL8jpLszsLMtrz0ttyUhrT5bVJsvJ4cWmcuCQh
Qi3hcJDQYEdbd1ND6xfPLbWeu5iYuJqa2uvr+9rakmCwcF9PPhaVER1RX5Dd
Ul5UnZehjpPFCFiF6cm5KQkpMVIJEzTZEAzUHwsLwMMhUnKYiAAX4oIBvwks
rFpKz4/lFyeIgPLlvMI4QU2avK1E3VOV+6Y442VW0svyvOqi7LLc9AJ1Slp8
dJSALaRTBTRKnFSQGC1KiZeqkiLTkyNUSeK0JAFQsiIiPkEUE8eVxlJFCXhp
CioyOyS6yF9SaCcsMhYW60XXmMdUWVGSn8HFP+HkmvQEX4zUIYhp4E155kN7
HMTTQETqhMcYY+LMcPE25FRXbIJDkMgIIjaCR5lDxIZI+QuI8AlEoElKdGKr
AnExD0+5VFSRY8uQzDQ3ToY7P9sDLTcLFuohIh6e1s5IMeCkm0jybPg5lpRU
fWqGMTXLDJGkFRz/zF3wN0yqPlFpiJA8psbqkqXPg/F/CWE8IkboA+HEOsw4
c3Gao0Bpx4wzJUh1ULxnxAhdIBj9VyT3KdgIRE76iZ+lRVFowPh/D+E9gvM1
MJF6ArVDRK4LMGhOmjlXZcFMNifEGGEjjYgxFhS5ESPRRJpln1DqSUvQxUZo
sJLMoMwnCL6+SO0nSPcP5Rthos1YagdhvqOwwK6/rXNxYrq75XVLbd3G/MLB
2vrs8Mjy5MTs8FBXU2Pv6+bNxbmLg929tWUwOd5ZA//5G5Mj6xOjW9MT+/Pz
e3Pzq6MTs70DI63ttbkFOQmJOQkJiSI+A4VghSMShJz81NTe5ubN2dn95eXj
9fXbw0PALED1cncXYHu9v/8dXvDSwcoK2AeQu7u4fLi6fra1c767B4A93twC
wH4XgHprYXFzdh7AC+oziOKLYzO7Sxtr04snm/vAcFenFq4PzoDVAucF5ALz
vTu+/Hz97r++/PPDxR3YbWtyaH1iEPwJYBUCwB6uLZ1tb17t727OTS0ODywN
9x0tTl2tL5wvTx3Pj1wsjd+sTC10NdZnKlL49GgaNpFLy4uLrMlQDtSWj9RX
zLbUzr+umagpHC3P3uqs+7Y6/mlr+QIY9PzEVn9Hf0VhRWK0kkXOkXIqlTEj
L8sOJ3uvlsaAblbHgQufzg3cLs4CXcxPbQ329NeUlafG5cZK8uMjChIiXxem
jzZWzDTXzDRVTjeUD1XkdWSndGQntKTH1KfIXqbJ3+SpatMVMjIOuLa/rbWb
uQlovpiAAHxQEBj5BGxWvLxAEZciESTwWKpIcWFSfHFaUokquUStLFIl1eRn
vizOLVIrk2QiGZceyaEBrtMkzFQxQymkKXjkRB5BySepxLSMCGZVahRAODOC
oRJRwFiqkDTmKDpK1S+LsxpKcl5V5DdWFFUXZBWolNnJCdkpiblpifnpSQVq
RV5GQk66PCMlAsCrTODK5aK4BGmcQhIRy2bLcIxoODcZIsz2Feb/911yJabS
ClN5va241IKRacjOMaXI3ULYxq6o3+zh/9MV83cI6wk6Sp+UaEpKsiAqzAkK
S3iEnjv9kS/3BVxmBkwZl6AbIn6KkGpz1e78DD8Y3xjKM5LkQiILAxkpDvws
N6bKMYivFSoxoSs9sTHO3GwjXo6xMMeMpdInJb9gZhiR1Pq+Ef8IjH9sx/0L
Ik0XmaTrx/uJkWwsTDYPpf2E4WmgOU9R7CeUCD2BwooRbUSJMBAobEgSvRDq
b6H0R6G0J37hPyKZGoJEO6HCHs7/HwyFNlmugxRoUmIsGXGOlGhbbpJbXGEQ
M8GGFG3CS3HgKZ1xEnMU35QS5YIXWyFY+mi+ATPeCifRJUcbgGQOYz2FcV5w
U9zCRIahYn2s3EiY60BNM4iucgIJebizC3gu6Lmr01N7K8sA3qGO9r7Wlpmh
gc352b3VBaD9tUUwbi/Nro71r40PbU6Nbs9Mbk5OLg0Nz/T0TnX1An6LU9MS
hSKFSBRBp2ACfQjQADmXBsx3qq8P4HlzcADgBW4LBOaAXOC2gFkggDPQ7uLi
2tTDBVQAYcAv0NEacOTtg5U1AOz69CzYDsa5oRGQwMEEbFyenDrc2H24muLo
HOj/4+k9nBLL+ndf38kz3dO525xzzjnnjKCAYEBFFAygiAgqgoKIICCCimIA
A2YFVMw5p9bOPT3TMz3pfX+/c86tW3XPX3CX0/eeqqdWLWS7Qdyf9Txf9t5r
/fzy3ad3v3x8/dObyxegDzrg4V8/f/rPr3+CFvzwaHMPwHuwNHexvfoS1AJH
e28vzt5enl/u725o5jc0s/vL/9C9NPt8U3e9odmeHl4f6+uglucnR6QFecZ6
OgU7WEa6OUBDA3paGjbHhy90MxtDPTNC9mxH85ZC/FIz9vFw59ej3d+O9345
2Hy5pjvXTgP7vl6Z++ts98/TLaC/z3f+62r/f1wf/vfzA9D58/zo5/0tUGif
aqd2JpVro/K18f7d6eGDOeXe1OC5Tv18cXJfrVhTSFZ7RRoxd4pXp2RWDTVV
j7czxtpZXcBD8UVV+egSZFZ1YSG5GEvMz6cTCF1slkosHOrgDwm54qY6Fgnf
WF7cSqnsBAmcwwASMWmdzfVSDoPPqGWSy1ppVXxWXQuNBIYOIAahgABPLUqP
K0OkENGQCkQKoLi1slBIxUvqKyR1+E5qqbyJpGqj9bY3SVvru9uaBsRtw118
hYjX28HtF7d38zndHexeMUfe2dojZnby60F4bmVV0ujV+PKinEJ4bjE8rzwr
tzItjxKPbY7BtQUXtLlmt5jDWc9yeBa4LhecxAMjcE4vckjIs4hCPgvPehSK
uBed+yijwiKP4ZzHcMS1eSFotrGlz/zQd2JKzQpbI1CNgQVN9on4R4haO3xb
CKTSLjj7YWKJZQ7do5Dli+P45ja4IMgOSLJbZqU7sPUcSlhui1l+i3lJu10B
yyK/0RRNN0mtfojm2mVx7TxwX/mWfZ9AM40ue5hEeIyoNEnK/SEF9WNumQUS
Z4wqMS+pcYEWGsYj7hVUOZXV+8CLLaAFJvBiq0Tk4xjYPQTOuozun1n+LB33
BF5uk1PlAcO5QbEehTURxOZkRmd2doVHWqEtnOAKLXbNLvMvoSXiqEkVtAx4
kX9WkQe6whNV4YypdS2guaaVmmVW2mRTnPMZXmi6U2aNeS7Tpphnn9tsvDg+
DqQdHweU3U5Dt721vaTTqMcWpya2lzUA2IvdzfOdjbPt1dON5cMV7a52Ghz/
J6uLZ+srgN/t+fnlcbVGqVqZmJRxWslFRSUIRFZcdLiHMzIxStLSMDeiPFxb
eX918fPNc9CCYhOYHbA8EFmfH+ydboE9b17t7wKdbK7vLi9uLy2ebN1mbMD1
55uJzjY2jlZW9peWtjUaoJ3FRZDDAelgs6uD/XfPX/108wbAC/AE/c9Tf4Cf
AHL//PDb37/8/vk2RtD+8ur99fHFxeYKMN+LrfVXR/vgPXy4ef7LyxcvT09O
t2/PWQMLXpkcXR4bPNRO32wuni7NTHXzeRRCTlIEINf52X0X40chzjYpgb6k
XASHVAbwUbDoMyKuXt65O9xzOTPydmsVIPzH2eGnk92f9zd+OVz/43z3v24O
/32xC8gFLWAWkAv0n8u9v862wfYAc1Bcny/OHGvGD+dHzxbVLzbm3+0tnS/e
Lr94pZs4nx89nhwCCE+2NU22UQcaK3vo5X0Mcm9TXQetml1d2VJT1UisZJHJ
zTVkFrm6g1EPyB3p7BjgA3ipkqY6cWNtO5XEqS7j1RJ72I0qUdtoZ/u4rGO6
TzIs4Ylb6J3seimXwW0kt5LLQW4n5mTlJkVnRQWDMJ+XHJOfHEUpgDMJ+Twy
Tkwrk9LLuhvKehvLexrKOlk1oqZqaQtNIeSopHylhA8oVsk6RuRiVa9IKRcO
9/KHetvkUpakg97RVlPPIJcTsTmFSCQGlo3LzC7LQJESkZRwRL1vTosHkm2b
0WSSyTbLEzpgxK4Inh04yMERnoKxjkY8i8sxhpbbomsdkZTbqWZAesyut0mq
fBpR/BhS41QuSsZwosp4ntlUS0yjM5bpHVtk6AX5KhLzKINkVSUMy6U7QCpM
0RRnYH/wMi84wR+kd2ynUw7HHMezLWgwRZIeICofpuDvQCmGWc3WrhgD16Iv
I2ueBRb/EIr5IQ3/DFL8JAP9qLTaubzW81ZUr4ycZ1Gp36JxNoRaH3SJfXax
LRJrl5D5JCLtXiraDFHskFvlWET1KqzxQ5X5ZuODiqrjS2pTQUtvR1exILR2
eLOkoKULKx2hj+lEw3P8qbmeXgWL01FKrE/OKfPIrnDIqXFCku3wnIDcBrfs
OgdojVlSxUNIzSN4w+OMurtLqtGlsfHVyamthfmjFf3xxhqAaGV2cn9l8Wx7
HcTL6/1NUPOeb+jBYb+vmd1dmDxamjtfXbpYWz7VL+3MzS2PjM0rBtcnppRC
MbW4GJ0Yn+DnFexoWwJP148Pbek0gFMALyAX8ALIfXF8eLm3c324D+A9WNUD
gc7n/qZ2AfALxpDP81tuLSysTk+vT89szMwCLY6OLanVtwsCrqwAXe7v/fzi
5vf3H3998wHw+/IMVMo3H168BQ+BALyA2f/+9Pf/0R8//QqefXW4d7KmP99c
A+8ExIBPb98AvbkAFry3p1/ST05MyLvBkb8yNnSxqr1a0x1oJ/Rj/YCC3JSY
AHsLF9NnrmaG7qbGUR5uyQE+WRGhRDi0k1I10sqcF/O3hnuf63Uf9rc/nR18
2Nt8s7n888Hanxc7/7k++H/eX/zfb07/54tDwC8A+Y/jjY+7qx+2ll9uLD5f
WTjTTQNyd6YGgM6X1G93dSBdv9qcf7epvVme3lTJ5zp54CWk1Co2NouCTCKk
ReHTYovTEvKS43PTkrFwOCotLTs1FQOFVuTnMYjlICqLGuo66DUdDTVdTBpg
FrRCOlncQOnnMscl/AFeM6B4okekFLcJmVQ+g9LeWFNfVdJIwJZnwxAxEeCf
GOnuHOHmFO/nDgn1L0xPAOVDEz6PSyoU15Z01xPElEIuAckAiboin0vBdzXX
DXa0KLvaR2XCcXknQHhIxh+UtgN+RxSCEUX7oLy1v7uZw6XTGoklFQXZBXB4
AQxZAoWVxieX+KeUuaOY3rlcT0iTZXKjEbzNFilwgrCt8kg+eSQ/WIlLQo4l
BOeArfcvbPCCEk1zGbaFHMdMmkky8WlcuSGc7kEQpSAbwnLrbZEUS4AqgmwX
lns/KPtOWoU58GuKJCynzgZSapRPca1kxlQyUmubUWxxeYXCD8EyLWqxwlCe
QTHfIIruwArvpOHuplU9dcgycEIbhBGfBGDvBOZ8l1T8BIo3hqONK8neNbRA
Yo0PluASn/pjaPTXUJRZDs4JhXXIL3VH41zSUVapKCsYxiEjzy4b71RaF0Rs
TKhtyWoR4dmiivpWbB0bw+ookY/Xa7a6ZlaF/WrWhK5z+2zm4Eq3rp/RaYfF
XXXF5dHpOXbQQktgwcT24GpReE69cyrROKb0XljRV/HlP0BoD9OodzQDg8uq
kfXJyd35+cOlpePV5aOVpd1lLYAXkHsL79bqxfri6YrmQDO9OTW6Mz8B+D1b
1Z6tLB4v6fY1GvC7umEVGAemenubKioQsdGpwf6Z0SEt1WXgt4D53hwdAM8F
2AKTBdgCnM93toDAU9uL2p0lHSD3aH0VjBvrC3MgvR9trB+srYI8MNnfPyqV
Tcr7FpUjYJRYGFYCo79d0lSjAdu8Pj8D6AFOAa3AeT/z+zlCA1RBYP6v3/4C
zgtaADJogReDp96cHJ+srZ5trL85u71V6o/3P/325u3L0zMQxfXTs5MDAz28
NgmTMdEtAX/vhV778/n+h8uD0zXdcGd7dXF+RnREoLOTk4mxzaNHDk+euDx7
GupgiwgNIaQlt5WXLnSJjudnX2+uAoRv1haBpb5c13zY1384WP5fL4/+vtj+
eKB/t6F5vTr3emXhlX4e6PXWMjDf/VnViko229M+JW3VDYh2pxQnmpEz3djL
9fnn+ttJa8cEXGl9bTOuKD/SL83LLtzGONDKxMfS1NXM2NXc3NPWPsDN3c/F
NdzbOys+rhSeWZ2Pbiwt4pLLe1obuljUziZKTwtdJeRMdfEnwFAgYA+1MUdE
rdNy0biM38NjdLczpG0NbHolKe/2PFSYi5O3jaWHpRnYv5+9TYyvR0ZEYDE0
GRTFrLK8dnKRlFYK+OWUwqvy0smYDHpJNodcAl6lj9cEBgRgxP1CjlzQ0tPB
kotaBrpbh3pbB3o5ip6WTkmzUMRiMMmlZRiQolHFmVnFSUmYwKQSTwwztEQY
Dm92Tqk3h7bYZ3KdUpnWCLw7vNQNWuSSgXVBk/yxjSH5NK+MSjNUvVUeyxpK
fZZaY5haY4li+mP5KYlEn0TcAxjJDOTnZIJJeN69hBJDTJN7tSi4rM2nmOGc
X+tQVOtTx0nvVdaqZwRDI+2Vg0GQuqcYunkR0TAL/hU27x4O+xRV8DAu5zuX
NAMXuEFwyYOw4geRhQ8Tip7E59zPghkV5jsU5NnDs0xTkh8GB38ZEPxFKtQk
HW6RjXHBVgRgCH5Zha7oUu9cgi8k1wFaaIMmeJJZacq5ls3TsclFaaeioUfV
zO0izq52nb6eXdqVd8gprZ1Vw1Oi5R31/PjQ9Eg3g16QkmYfk/osLc80n+JE
EUdi2Z5Iul1ypVEQ5nu/3C+SyE/RbBs402xO1qvp7V8cHF4bV2/PTu9q54/0
iyAqn2+tgKgJcvIhKHg1t5M07kyMrioHtmbHDnQzx8vzh7r5A+3CEUizCwsb
U1MLg4MzfX3s6mpkXAw6MRZUWxM94suNxYvd7duVvk+PgecCkwUtEIjKwOgB
uWvzs0CgA7wPOPXK7PTmkm5Dq1mcmhyTy+V8fg+3bUwiBeODZnAYIAz4nVIo
dGo1qNNB7v351Ytf3n549+LNy8sboLc3rz+8fv/bTx//+OUT0L8//fVff/z7
dg6f3/4E/b9+/ePTh19fHByAKH6wsvbq5OyXF7cLxADvPt87Xp3TzqrG+0Wd
7NpaGh4va2GtqUeOFxdONxavdlef74F3Oz/e38NtoBOLirBIZHJoaJSXt4+l
taepWbCdbaqvd11e7pykc2d64nJl6c3W2suNW28F8H462wB6uzn3fGn8cHpw
e6RnZ1R+ODF8OTd5o509Whjbm1FuqhXLw10z3W2jQuZ4J3O2h7czpVgd6d6Z
GrpcnnuxvnSu00xJxMzS0vyYwAQPOx/Txy6GDx2Nnlo/fWptaGRvZulu5+xi
bedt7xjp7ZUU4AccE5saX1eQLWLUcCllHDJeyqROSwXLQz2a3s7xjtZRPlst
bpuVi6d6hUpxq0rKG5S0drRQCShUSkiIl5W1s6mpk4mJvaGhm4VFiJtrYpA/
Jj2BWoxmVxbxa3BSOr63kdBNK2ksRTBKUYyynGZiAY9aJmHWdnPqZVwGiNN9
HWzAL1C3qEkmbACSiup7JE39Mk5nB6uBRiIQMNhSVF4JNAsbnUkIKWUnkjqT
8lv9oQ0OMJZjJscljeGQCewM45hR5J5HCimiRqGq/WCVjhCiJYJukcOygtUb
ZTGs0M2eOGF8WWdmMikoBnsfwAtyZlzx05Dcuwl4I3S9A4HrXdTkVEC3L2nw
JDEiWvioiRne+vrI7JSc0BOQXv2ksNa8rNwMC79Tm29Mw1qWFxrDEHfCM770
hhh4ZX0ZnHMnrvBpXM7DwKR/pUTdT4p6GBNyJ9T/62D/r/19vwwM+CYq5mFa
hhUK41FKCsdWhKFwfoWk8AJiWBraNbvEEVZgR6iNGZ1n33xYOb7WjM2JpIMN
vC7SuIa3fjS4sN4lUdAaODiOkKwYFcwMygYlzeXFiTFRhnFpjyH5RsgKCyzT
JafBsYDtlc1wC8c99c2/A6HbFfB9MxkOM6KuSZF4SiKZk/fqhgZX1WO72tmz
9eV/4NXua6e3psd2psf3p9Xb48rVAbl+fBAgDFL01szEztzMoU5zoNVu/TM3
7FhXF5dCxmVCy1HwAQHneHnuelv/+uzo3eXtVdPA0I/W9aA93VoD4Xx7cQGk
dK16RDcxCjrrCzOgBf3Fmclp5dCQrEvK43ayWN1sNtgtSAjawaFVtVqnVKp7
enQT4y9Pj3978+rN1Tlg9sXF9edp9N6/fAv4/Tz11p8ffwfM/uf3vz+3AOR/
5vD5+Wx9a216bmNBe7V39Pbixe00BefXpzuHm9qVGaVa0tpeVVicnw6hl5aO
SzrXxsc2dVOA3INV3e6KbnV+dmF8bFqpAuritdcTqxDxSeEubsH2DtGu7tiU
lA4KZX18ZG926nIFBOD1jyebn863/rzc/utq68Ou9kY/cTg5sDrQqe3ma7r4
C50CIJWANS7mLPR1rI/1bk30rY1J9arO1dGu7cn+2yytn3t3sPnhaP/VzrZ+
ZFRU34hLj4cG+4Y4WvtYWbiYmVk/M7E2MnewdLAytrIyNLMxMnY0NnYzMQq0
Mc8M9SXC0ylYVC0WVY/P51MrgedOS/jz0o6Zzna1kAsoBnaslvFVnVzAr7yD
1VxXTkChU8MivW3snc0tncws7ExMHcyAv9uGurtlRIWWoaAMUAVXY8W1xXJG
mZJD6mbdqquRKKKVCWhlHfVEPo3IqSHw6qs7WJRODq2zjSbm0SR8WreooU/G
krXX9osZwJSFnIamOlI1EVdWnocrhxZWJVU2p1bxU4o5IchG96wm1yymG4zh
hsR7ZRS6wEv9cHUJxbQEGMErudgGQrROrzLKohul1T4G/OZyfctl6dVyTAY1
Jh73JKfeNavWPizvQRDqbjT2cTrRJIdmi2mwh5Q8xVQ5NbaldIiLh4da5tQ9
yl5REd8LSjIqqbYm462o2YbcfBugpgJbYoFFJuKBb7yBY7SBT9oXUch7kdAf
guINEgLvhXl+7e9kEOj6ZZjvD1HB90MD7vp6f5eYZJGJcisuj8ARY4pJsdVN
sBo2AlsTj8LZpSJNsovcmtrQs0vCi5eapY1+Jre4Q1Y5MNagXuBM69rV821C
GZnOKqxnlXApJeTCNEisbUTYneSMh3CsIbLSBFVriWG6lghCsO2hSdWOwcWm
qVR3BCswluSg6ZJNCoSj7Xy1SDTdLdMNK7ZnJ0FtCypc4LwbkyPLSsXayMDW
2PD6UL+uWzLT37U8NrA+NbIyrlqbGN+dn92endWPjQHzlXO5IHm21dawqytn
+qWvDzZe7q29OT9+e3Fyfbh7uLa8p9cdb6yAzpZufnlaPT86PDEgnxzsAx1A
7sKYcnpYMaUaUkjEgmYmr57Or6/vYrGGBR0zvXJw9AJphobmh4Z2ddp3Vxcf
X714dXEKsH1+enl5fA78FxgxQPjnNz8BnwX6TDHAFvALBHz59fOXe7pljUqt
HZ86Wt252j99cXL96uzF88PLrcWNWdWEmN2GQ6CSgoJzk5M5VdW97JYxhWx5
dnxraWFlYXZVM397iu3w5PLgeEOzNDmgbCbX5aSkJ/oFRLt7wkLDq7NzxsQi
tUQEPrTrjaXfL3b/uNwB/P77euc/V9u/Hi5fL05sKmUT7cxOclljXnYVNJWE
SqcWZLZVF6sEjOVhye5M/4lOdbE8caIdfbGl++P50aerk5fbW6d6/frEjLJT
yiAUUTBoPAKGTk2JDQx2tXEE5NqY29pZ2ttZ2DiYWgLf9LOxSA30IiEgbSQc
nZB7ewNgZVFnPUnVzpyV8bU9Qk13h17RpZGLdAMS7WDX/JBkdkiiEDc31hQX
QLOSgsM8bR2dzKyczK2BwD7/f4RdkPERNYXIVlKRoLpIRi9RccgjAvqYsEHV
0dDHrpU0VQnqKpiV2Jqi7KKspIqCLHplYVNtCYtO4DIrJfw6UP8qBBQFnzYo
bBoUc2Vtzez6mloStrwyu6w6g0BNLG2MwTaF5DR4I+luWfVuSIYnutwPXuKN
wAfmk6LzqqKzygMgBGfAb2LF41TK41jincSaZwD2EnFKVV9hZn1KUplJTqNb
OtE6APlDYPYdkHsT8U+ya62QNRYJ+T/mlts3taULRSXDfc3D3QJ2LRlGs8og
GOIrrGlYa0CuDOPSgbQRF7qxSlzQsEeBEQbeMQahGd+Fpn0Tkfx1StYjeIxF
nM+9EJfvwj3vxgY8Tgw3Dgt86OJgEBr2JC7ZGpnvhymLLKlJpPPyOFJ8vQCT
VWiaBH+CKnYm1ERRGDDFaOPIdCu5PrOBje5SEHuV1bLBqp6hWragBFeRgiqI
ykv0ifM1DPX8Nibyu2TIHRjmPrLSEFljDsJzJs0ZVu+TQvGOLHOOI3kmkn3C
8U4rfYpZUecolzfGF0x0STSDfYDfy3U9cNi1SdW8ontSKpqTiRd7pfMS4TiP
MwqMY6hHPz60NDKkH1NuTE0AW5xTKNQymaixcVDQPtUr7Wtja5V97463X+2v
A3JvjvaA7QLDBdgerC4B893QzH6GV9XTBQQQnlEOTA31j/V1jw30dfG4LCqF
WV3VWlvbUV/f3dwywGtfV08ACwYvtDo5ebWz/dP11Yeb568vzwCSVycXF0dn
N+fP31y/Avrp1TuA6udpMIHhApA/R2jwc7DZ1vzitEI5MzS+pVs92Ty8Orh4
c/EaaHVeP6OcFLe0F8PRkZ4+AMkSWCaloLCqtKBX1D4/oZoZVS7OTD0/Pf3w
+u2r89tJQl6dPt/ULPW0Cmg4AgGOpBZguxqZrVWk1qrKgbaWY93M39eH//3q
+H+9Ofnfv1z+frIKLPhKO7qiEPc3kqnZGVl+npFW5gle9kk+9tnRfrUYKDCy
hf72/bmBq5Wp9/tL7w/XPp4f/LPO8t6rg8Oj5dXpvuGJLuEU+MT6evo7Omrw
FfGRsW6OHs52rq4O7q6gtbLzsLKKdHcuSI3jlBf3M6n9fIa0ubarqUbJZ+qH
ZIdTyt3xgdVB2aJcPNctWOgTAX41SunccFcPv5FMQGfGJkV5B7hY2NgaWTia
2Thb2dubWVsZmrhaW3nbWiWH+JILEHxKqYiCA/yOtNYM86iA3zEhY4BL62aS
+dRyemkeITs9KcQzOzmiNAdSWQyvLEGQy1EseomAS56UNQ4L6Uohc7JbNC4V
i5ubaKSSCgKisgqKJcbkk4IK6wLyaD4Iqhu8zi270Tub4IMs9c/CBUKLA+D4
EFRVKLLaF0KyTa0yTKt9El3xfQzxYRrNsUiQVCXHwhvTsiiOhc1+EJKNH/L7
QPTdcMz9GNwDRI1FSumjlIIHRdWuNGYSj1c0OyYe6xWDYiG29FEq9lFJiSUt
36qz0GUQ496VZdeH82ktckUl3Q0JMYjLuJOeZxiZ+n1U8ncYnB0+0xcWZh7r
9SDK636sH+DXJDLwsZOdQUDAg5BIwxSoSxYmII8QRWqCNwqxdbz8HLw1JMeI
VB9OZaVC0W55uNBGTl4FJQVVFMDuyBN0Y6nMDBItBVcZD832T4Z65ia4gp0n
htxDwgzTod8nwr+A4n5MIzxMIDzxQ98NLDCOJ3rGEX0jyrwjy/0iynz1kvZx
dr20tlJGJ4M0tbswcbahO17TzI32jfYK5HxGP69eyW8c5tEULJKMjldy6dOd
bP2AeGOsZ03VvTwoWVSIwTA+IeFOdrXN9YlASTXdI9yYGLre0L3YWjra2Lyd
WW5nC1TWq+qR1fEh8NTt5UyKzkkQ23jNox3c6S7RlEyilnSOioRjneLuZhar
orwag6nFYltrqdLW1j6+cGF0fGJAuaCeOt49BJ57dXp5enBydfr8+eHB1cE+
0M3x0evzi5+ub355+erX12/+/vDrZ/3Xxz//+9e/fnv94Wz7cHlaMzcyAIYO
zbhKD/L/kubz2SvwDrd1utXZ2WFpN7OqJjcNFunlH+cfUpSZjUlKrSvEyphN
s7IuUESAVPzpZPeXg80/zw/+ujr64+Loze7WsVazPTm9PT17ML/45mDtxc7y
zfbSq921Dye7wD3/fnn5329f/uf1zR/Pr346Ojxb1oM40VRWDgkJ9Ta3DLJy
d3ti7WlkleIbXA5H8mqq5vulz9e17w5Wfzpa/3i2/ev5zvvDDeDmp0tzJ7rb
M3fXuxugulkcG+5qrqfi8oszU/KSYzJCfeK8HEPsjEPtTaAhnrV5UDmLMtfd
vqBSLk+ol8ZHNCA+Dcu31EO7k0Pbo/KVAcnqYJe2R6Dp5g+20rvqq/qa69rJ
ZeUFuYFuLlbPngLPBYHc2tDSydrZ2dLJxdLRy84pzs8fB0tnk/Bg58OtVGUr
ZVzUqJawVCKmnNcgYNbUV+OLC26nsIsKDQzwdg/2ck0ND8lJiiuFpbEIWEUL
Qy5u6uLXyTrqFLL6vi4qn13aRMtvoBY0NpTQG0trGbgqBqa8IQtLTyygR+bR
Q1NqfRKr3RKrnKFUz9wm34ImXzTVCVZpjqq2ycAbJ2KfppSaZpJskbUuuY0+
Rc0h2JaIzBrHlMpn3ggDf7RBYvkXibjvShp9sNWhuPKkckIWvQrDoxe105EN
hJAyhA0B5VgBtaVDHASZ7nKEbz/CpwftJy4OZpUFpSU/CYq9EwUzDU818gv7
MSriaWaKLRpilQu1TYt+kpFgSiwNwWODwkLvW1kbuHl+EZdmDst1Tsm2Scq2
Si+wLyD7U/lpjNb83OIQVHFQQzuiSYhAEtzic4zhZU4p+eYFVd4iBbaOmV5C
CC8vT0hLdoKmekSEf5uW+jgp+cdkyN0k2L1k5EMk3jYNawOr8EjEucSWgo/C
O7HGPZxoHUw0Ca8xmWhtHGHVKRi1wxzGgrxzb37iaGV+f3l2YlDazWOyyKWN
ZfnNxAJ+DU5cWyKpLRVRy/pbqFOSVoAtgFfXL5qXC+d6O/4ZyWXr6kEg/Ujf
gXbizf7Gu8Ots62t8+3tk7XVjdmppdGBRWUf2EzTDyrutnEhW9nGGua1jAra
xjuFIHkqBfwBXlsHra6hFF9TWFiHwzVXkyVs9kBn1/zIGOBXOzlzsncEPPf5
2dXlycWLy5fXR4ef9eLkGPD75uLy7eUV0OcFI357/f6vn377/e0v14fn+hnt
WN/wrGoQBPXFyTFQboMYsKdfOlpfPdnY2AcBdX5+QTk6DDIqsTolNCrI2SM1
LLoElkVE5zaW4DvqqCNC3vaE6sW67v3e2i9HW5+nf//t/OTd/t7Lze1XO3vv
Do4+XuwB/Xq5//vzk89rI/771RXQ//70y//14e3fL24AwruzczJWc0FqWqij
E4DX9YmFt4lNkLVjqL1jaoBvQ2kBGACvNzSvdm4t+MPxxruD9ZfbKwDh6/Xl
f797+fHy6GxVu6IeXhjq1f6juX6phEHhkgml0PgkH8fs6IAOCl7bJ1xVymYG
B/ST41vzU1ugCpge3ZlUrip7ZmW8BVm7Ti6Y62pbAkOujAei9UhHs5hOrCjM
i/TzcrY0d7W2sTE2s3xm6mTh4GLl5O/iFe7tD4uOrspDCeqIAxzaCI8+0kYd
5FIGudT+NtpAB6Nf1MJjUovz4DHht/C6Odp6OlhHeLmnBvsjYsKqUXAhhSRm
1wqbq4UtREkbsbO9UsDBtzJx7CZ8awuphUNqYldSm7GVjGxcQ2pRQ3RRYwSE
5pta65VKcYfTvQpaAovZAZgG9+waW3SNNbTMKKn4SUrJM2ilJaLWCcP0LW0L
LefHw2ud4/EP/FAGsXgDRN295NIfsol2eeX+FeQMCjmvCg8nFiVTiqPJGF88
0qYw07okw4oCsWnPdOtB+HRneoqy3FtzvOoKPRPi7wdEfx+RYRya/Mw39G5Y
yMPkaJOcTLscmENavDEsxaqiNIxQEhYfa+Lq8WV4rGFMsnkSzAaS45SCsg1J
fRKPtCylR4h6SMBzw5NNEcVejA54U2dWIcU3AW0cjzLKJ3oCfhmtWSRyApUK
g8N80pNcwYsCfpNT7qVlPopJ/S4a8n1WsU1qgRWqOiAZ5x5d6BiFc4zA24fi
zcIqTONqrabamnQS3rZSfjqnvlnT3mzpD5fnV6ZHugUtbGplVRGKmAsj52dS
82HUnAwqOp2BQwlqSoe49aCSAhgCeKdl7equ9rm+zsXhnt3Z8f2FyY1J1YFm
6uXO6uu99Vt+NzcOlnWrU2MgVANzmZF1jIs5CjZdyWsa5jL7WA19zQwlj6sU
8AbauF1NjOZKYmVODhYKLc7KqsWViFiskR65un9gVD4wPz65t7EFqt3jvaOj
3UOA8MvTk/+jz1PqPT/8Z56fs6tXp5fvr1788uLdzdEFgFfZrejt6FJ0dii7
JWpF79zI0OKkegOUtOurwH9PbheG0GzMLuxoFqf6B6uLcJmxCfkQGB6OwsOR
NZiCthrykKBNNyjfm1NfrMy/2tF/ON75/er4j6vTX8+Ofz4++nB88svp2dvD
9Z9OtgDCv10dAIT/vDn796vL/7x+/j/f31rwnzeXv56fXa6ugJhRkY2M8fB0
e2oJ5GFo6fLE0P7+wxB7G1pxHvgkj7Tqy9W5l9uL4IVuNhev1nSXq1ogYOtX
64uH2mnwOYOHAG3gzmCb3dlRMGwqWuubywvaa/BTUt7qSC8IOYvjIzva+bP1
ZYD8kW5mb3pE1985wm8a4TWMC5pAmlroFYAcBf6Vsz0CeUsdIR/E3pBwH6+o
AP9gL+8Ad5/ooPDkqHhIbGJ2anpFbi67qkzOaVCLWqbELHVHg6qNquCQQfLv
bKoSMsksagUuH5ESH+npYudgbe5oaeZlbx3s4hjj5YaOi6zJR7U1kPigTGYR
+UyCoBnf0VoubCW2t5DaONXc1ppmTjWNha+oRxbXJRfSYgtpkYDftFqP9Bo3
wC+m2Q/b4o9pdEVRbFC1VlmVxqn4x0Dp5UawaqtchmtJWyCOHZZV4xBXci84
1yCx4l9ZtXfjsd+kYY0RxR648oQyPLQoJ7EIEV6RH0LK98YjbFEQU0yaSXWG
TSvcrRPhKYS6ciAOVKhtZY5TbMxdn8hvAYlBCQ99g+8EBd6JCnqIgDrAM+yT
E8xTkyxzUN4IhGdYhKGL57cpMKf4dLuoVKs4qE1cpnVA4uPglGcwrFsdE5FX
EhKaaBgU9whZ4lHNTsDWBkTDnySgTApIvgJ5EbUpDVMcgsfHpqe4hgebJSc/
TUp6lJT2MAPxNDTuy4AYg/Rc8/hs0wycW3y+c0y+UzzONa7UOaLYPAJvGk+y
1Hd3bA/KjiaVZ5qpc/3C8eLssnpY3SeVcJoaiHg8CoaFpWAhiQUJkXnRIUB4
WEJdIUJYVzHc3jQpuSV3VMxVCbkTMuHCQPfunPp4cW5zZmxnfuIcHHIbS2cb
q0DHKzow/gOnmJQJxoStI3yWuK4SBLYBdqOsgdpJo8hZjQouW85miRmM1pqa
suxsSFhYenhEJQYj43InB4aGZN3D3T0zI+MbyysHW3vba1u7Gzsn+8fvn1+9
u7r8PB/m5f7B2c7uydb2yebui+NzoNdn1wDe9YXlIWmfrF3cL+6W8rhiTktn
K7tP1KFW9AGEgQXf3ki1vn6wvLy3uHi+uXmyujGjGJLzBCqJjEOpY5LIIMYr
BAKdcmhrZuJEvwCGpp+Od3452/90dfz75cnH06P3B7vAhd/u7f7jm/o3e6tA
gKxPl0f/eXX5P9/dfLq43fLTxenPxwfnyzqQN6pzcxJ9vIOsXYH5uj01dX1q
5GVqkuDtUVuIHha07M2NXazMvt5dfr0LnFd3saIB+flIe3uZx/Xa/E8Hqx9P
Nn872/50vgM67/dXTnUT62N9OoV0RSm/vbdCIZ3tFs71iNbnJg6XNUf6BVAZ
rU0MLg/LpqRcBYcqb6oG6iDjVPxGwK9e2Q1gHxawGFX48gJ0aW52eSGmNC+3
AIEszS0AhTa1rIJZXc1voPVyGKNizmwPb0bWMiFsHGJXjfDqVPz6Hjalra6s
rhyDy83MhiZ5udo72VoCfl2tLT2tLXztrON9vdEJMQxSSXtDlYRDETUTxexK
KY/c1VbTziJxWVVcNqWFXdPYXE5mYAg0aHFdUjEtDkb3h1J9oBTPbLo3cNhC
lm9+g8tnfuHVIDkbw4hGkMpn6SRDZJ11QYtrBtE+vdIiruRuKMYgFmcQhzOI
zjVIKTRMQdukQN1SU71RmWHlmDhKSUxFnndBhgUs7WkOxISYactEubZne3Bh
zvRU67Jkk4pcx4TEe75R3wUkPvCL+dEv5IfgoLuhfj9AMuyhMOd0iENisk1c
gnVQmKGb14/2rt9GJdkmZriEJVr6Rj2NTLNKRjpFw2xCU01gOe5orH8K0s4r
/Dv3sC+jswyTcszCIA8iIY9ReA+WMBtXGR4WbRwdYxUaYubt9Sg24WF03I/J
aY/hOWaAX+9Qg6Qsw0jI00ioWSLaGVUZWsJIAskko9ItscQyiWB+Njm8P9a/
Pti9pJDpRxSbU6Mrk6MLqqGhTiGHWkNAI3OTE+GRYZAAP2igb05EaHqwV15S
JKUAKair6ucylULuiJinEvEmu8Xzgz2789Pnq0u72tnPJ6GAzjf0l1urV5vL
B5ppzUC3sr0ZYAvEqyyW0kg9DGpnHZlfUwkQljY1yJiNgN8uFouGx0OjoiER
kXUEQr9INNrbJ+MLFJKuadXY2uLyztoG0OHOAUjRoNr9cPMC8AtsF5B7sLZ+
sLp5tL59c3T2+Y6GnaX1kd5BMaejRyCdGlIPybqE7OaWulpeY6O8o2NyYGB5
ampXpzteXQXkHutXjpb1N7t7L/cPrnd2QbupWZofUYMBZEmt3l9avNrZ/HBx
/J/3L/5+fQkEEvIf12e/XR4DC/7l5BAIkPXr6RYg6+fDTaDfTneBPi+R9uns
4Pezow/72+e6+fmeLl4VkQCFRLv4BFo5eJmYB1jZxHl65MTH1JdgpEzaxsTQ
uX4OjAA/n2yDFowGL7b0wIXfrs//vLP4y+7S+23t282FN+sL1ysz5zr1zsSg
bkACKqAlZa9uqFvdJRjrbAdpRzM6uDKpAmPy/GD3RHf7eBdnsK1e2kjsZZFl
DFJTKQr0Fwc7F5VduiHprFw41isakrTLRa39YoG0vY1TT2fWUvhNTUNdXSMy
yYhUNCbhq6WtU9LWEQFd3lIpqsYMtpDmpC3zcr6ys7mVXonNyUiOCfFxd3Sx
t3awMHU0N3U0M3ExM/W3t4/x8fnnrhYMv7Faxqntaaf2C+t7+XRRC6WNSW5j
UVvZ1JZWSiOngtqMqWIiKhgZKEYEsj4YWeePovvnN/pjGrxA/QuvssgkmSDI
Zjl1lnl0awTFFFZlCKea5TPtk0rNUsqMwzFfh+cbxJcYxBf/K7Hou7RCoziY
aViMWVycU1FubG15RhU2qiDTITvZJB3yNDvTFARpOtqFhXZpgjuQ082xSU+J
WLdUyNOAuO99Y773jvg+KOJeVOTjsMAfE6H2kGw3RL4fBOkZFGXq5HXHzuOO
g9ePzr4P/CJMfcON/KONU5AeMIxvWLK5g++38RDLDLRjKsLaP+auc5CBZ8SX
frHfeUV+5RryrzS0bT0HVlAa4uj6jZ39lz6+T3y8n4ZE3IlJfJieaZJTaJcA
eRQU83Ui1DAy+Ul4sjEsz5vUCGV1Yut4WfnkgIxiuwyc9Zqic3VAsjIgXR2W
78yMHekAevMrU5MTffIeHo9Ho7OIRCI6BxUZk+bnBw0IDHOyTg7wLExPaMAX
SZpogNwpuWRO0Tt5+6WobH1m8mR1+WBJC3S6vgJ0uaW/3l55vrUMnB1UvgpO
o4haISQTOIQCPgkvpFR21BDbqsq4xLJ2UBzV17FrKJLmlrY6WikKVYxAsGtr
ZTy+mN3aQqOLWrkjff3amblV3dKmfvVk7+DV9c3759dAoPK9Ojg8XN/YWVoF
2tOvn+8cnW0fAngnB0clXJGwhT8kVegmFiaHBoXsFhqxklFd3cnhqLq7taOj
G3NzAOHn2ztna2t7Wu3VxsZPJycfTk9BCxI48HGwc+Dvby8vPlxffHx5+efb
m7/f3/zx6vLT9emvV8eA39+fn4IgDQTI/ev5ARCwxZ/2119vLZ9qp9ZHFfsz
46famYul25uIgY7mplaGFRNiASW/MDc+KdLZ1dvUPNDGGhYWSMPm97IbZ+Vi
YMHAygG8nyn++WT33cHmb7vzP61N32hUlwvDN4vjN0vqfXW/tkcwIW6dkHBH
BOyelgYJgyprru9vax5oZysl/Kl+KYB3Si4C/E7+c4lIP7t2RNAwzKOxK/Il
DZUA3iVl96Kqe2W8b3VWuTKt0oz2L4wPaNVKVU9XN583IBEvT4wtq1ULQz0T
3QIwCIyJm3qaia0kNLcMzq/M6aKVDvLqRjpbpK20iqLs5KjA2DA/P09nRxsL
W1NjGyNDOyMjZ3Nzb1vbUGdHZFwUrRQjZpL72ukDHY19HY09PEYbg8Kur2E2
kJmMKmYLqbEVX8fG1DBR+Y3xOfVR2bUhCEogosYni+QKIVgnYY1SSw0BxYUM
J1yza269dWa1EaAYw7CDVllDKowD4AYR+QYIysPsmscIomEK5lki3Cwd7lJQ
GFVDyiKXpxcifVFpNjkZ1knQJ1lwE0y2VTnStgZpR0HYlkPMclOelOHc0mCG
gF+P8K88w76JjH+akmwaE/44LM0yDu6IwAVnFgX4xhhbeX5n53PP0f+hicMX
Nh4/eIY+TYJ75JRGJMKdnfx/MHM2CIq5FwcxSUVYRaUbekd84xhg4BRoAIzY
JfiLJLgNrRlWVpPo7Pm9iYWBh/cjL68n3kFfp2ZaZOXY5RY7ITHA058kQ02i
Ew2jEs3Ts9xx5XE19dBycjwi3yUlC+zWWMmhzYg5ekXXlnoIVHYHmtmtmanF
UWDBqrlBpUY5ujCglDQ2F6VCYl08wmwdfa1Mwl3sYBFB5dkwDpnYz+NM9Uo1
QwPqXtlYd9fimGpvUQd86lC/fLaxfrq+drOzcnsV1qr2bHl2c3wQhOfOuipe
ZUlLaUFzCYZdhmuvKudU4BtKCpsIxe1UMoNEam9oEDAYLRRKE5nMrW9sZzCb
62g0IqmtiTkEIvT4uGZ6enlBe7C18+LiChS8L09vVxW/5Xdta0unX19Y3NDo
gdbml6aGxjpbhW2NHFm7ZKxPNauamlGNiFu5YG/1xCpeY1OvQDDR17c4Pr42
NX2s158sLx9oteerq9cb6zebG2/3915f3Px08+rj63cfX7/59e3rX9+++vnl
1dur009vrj/enL4/2393vAP00/Hu+4PtN7sbLze1r7cXb9YXALZAZ7pp8MGC
HDstFYDCf6qrY7ZbvD2herO9+vF4993u+vbkdA+rpSgtNdbDPcbdJTsmvLYg
p72WON0j3pkZ+fwdPqh/P6dx0P65O/dpa/rj+sSHtcmPW/MftzRXmpEtVbeC
VdtJI7IIhdV5tzNyULF5LGIZj0qW85tVUj6Ad6pXON8v1o92r412Lw2K53q4
873tnfUVA1z6xmT/0kiPTtmzOaPSqeU6df/UoGReJd/STC5NqCYV3dqxId3o
kHZEMauQgkFgqqdtspvT20JiliG5pXB6bnIVPLY2P72NgutqqQUWXFWajy9E
wVLiArzdnaz+QdjY5POlIM7PjKI9PfFwKJdS1sUiA0nZVMBvB7OumUquqyqj
kgkNjRUsTiWDXVrXjClhZRY2pOZS47OrwrMq/dNKXBMwVlFowySsKZxkj23y
wrG8QJxOAYUw4Qm8xiyjwgLw659lEFf0dT7dNLfWGF1lnpL7NAVhDpyOXAOt
LEvJyw7MgjghM+xzMu1iYY9TEUbwLJMcmEkR1ASfZQFaZOrj/Dzb+PRHPlFf
A9P0CP06PtUUmmmbEGvkl2YUDDXLKPHLJAT7pZjZ+t+xC7hr7f2DicuX7mFP
ozIcsgoCs3HBMek2boF3XQPueId+E5NmmIG2S0JYBsT+6Bxg4BL4L2DoPhF3
I1JM8NWxFZQU/9Cndi7fhcfYhEZYuvl8kY1xReY7IvLtCvBumTnWSWnGMfFG
oMoODTOJibaBQNwyMpzjE0wio++DpK0fEG+PyvenlbtTqp3p8UPtHDh6LzY2
dxZ0W3Oa3YXlNfWstKkVHZccYGnvYWjuZvzU18rs9uuIxNiawjwBva5fwBuV
SaYV8jGZTDs6AuAFWfRsY+P57u7Fzs7NzvLpytzRIiiu5040k9r+LjmTxiOV
NeMKaRh0IxYDnLe5opRSmEPFYlrJxFYqvZXe0MFqAbYrbWsXMJtbGxqBGsg1
Qk4r8N+5iQnA79L8/N7Gxs35OcjMoOwFaflq/xjwu6FZWpnV6We0C2PTM0p1
b4esmdrEoTf3i3vVitGRHuXiJAiJElYtvaGKwqJQwfgga+WNyGRgyNqamdmZ
AzWm5mJFf7KkuVxZAqn49cXzDy9u11p6fnR8eXz87uX1rz8BkF/9/uH1zy8v
3p4dvDzYfLm3fr2pP9cvgPp0b3pkZ1KpH+4FURaUoscLE0fz6o2xgdtv7UTc
fnYDSCBLg91vd1b+fn78+/n+q+2t+b6edko1m1gOyv85uXRxqG9BIVsZHThb
ngfAAngvVuYByC+3l0H/0/rEn9szv29OvV8euVkYeqEdebM6DUL1OJ9Jw2Qj
IoIyQvwzwoJgkaHlKKSgkX57Z5+oVdXJHenkgL98a3rgbHEcSNPfsaKSKlpp
YxL23sLo0mjf/KB0bWZkfkQ2p5IqZbzxPuHm/Pja9OjcUK9+QjnRI57sFQPz
BfwuDIl0w6IhQT27Oq8hN5kMjyOkhxFg0fWl2Z1NVf0dzXIRR8hpIOELUmIi
PV0c7a3M7UzNbE1MbYzNXI3MIlzdi9LTmomlfFoFl4JvryuXttT38thtdBq1
ooxSWdpYT+S01ra2k1ncCko7nsTBEhjooroMNCkehg9OLvCIzbFLwTohiJ7Y
xuDCBt+MMqtI9P0I9N1E7OOovPuQMpMw1FepJfeyySaQ0kcIvGlqjmF02hMM
LgBfFpOR4R4TaZaebIuEOWakWkRAH8VnPUuGPU1Pe5yV/jg30xiVaZSR/giG
MIlIuusZ/oWTv4FXyDfJGZZwhHNigkkgwtg/0yiV4IGoDg5BWDlH33cI+9HU
+0sr32+S0O5oQnhGnlcSwjExyz4GYhGVZgZeNzHTJBVpkZRpHgcxjkp5Fhj9
o0fQN17BP7j6fZuS5VSAjwqNNQuIMEYVhMNzgx09DfJLfOD5TukIs0KCZ3ae
Q1zSs8ioZwEBj9xd7rg4fB/k+zQuyjw2yjAq7MeosLtHc6rj+ZFjzfiJZvpw
YXp7emp5dHRucGh5fHJfu3Ki39SPTsma20jowtSAUD9LO28LE7uHPzo+fZgU
4EPKy2mrrelp4wB+p/r6pvv7F1TKrYWFi62t6709gPDO4uLR0jTg92xl7nRp
5nRpbnN8uLuxjgiHAnKp+blkdDa9uLCRgCPloary0a3UaoCtTj05qxwZknUD
r1T29LKodTRSFauONijrnh9XqweHxoaGVrTao52dw+3br6o+L+xysXsIYjOw
3dW5xX/O806OypWKTnmfqEch7hvqGhiTj8wMT6l6BngMdmN1HZvWxKLQKPgy
ZlWNnNcO3r92eHhjQr03P703O7U/N3m+rHm9sw4GB2Du755fv7m8en56enly
+OLy7P2r6/c3V68uj68Pd6/3NwHCzzeWV8eHR0XtynZ2Ry2JV10OOvrhvnVQ
fir7V1V9gFxpI0VST1a2NwOcX24s/nK0BXS2tLA1Obo9NXazof94evDz8d7b
vU2gN3vrt1dOHu98ON56u78G+D3WTe3NjbyYkb+c7TsZEW/0cDblvMNR2bZK
uiDlsfGYwsSoOC/nCFf7YEfbIAe7tLCwitzcNnoVi0zg00mjkrZlVc+aWr47
PXixPLEx3qtViIY7mnpb6SOSttvLYhfU6zNjyxP9urFe7WiPdlQ+PSAZ7OAI
6slMYgkZk80iFosaq+Tc+rEujlbZqVOJZ/p5wy3kpqKsClhMFSqlsSRbQC/v
EzQNdHK4DAqTSqrAYSDJ8T7uLtamphZGRtam5i6G5r5WdtCw0JoCNNghoxzD
o1Yo+C3t9bVCZlNbQwO9mlRVjqurxbM5ZL6Qxuioq2gowVHyyhsKcbXojMKo
KLhnLMoT2F8OORxdHZSBd4XgHRAVLpAS60jko+jchxnl5jE5d5OKHqRiH8Wh
76blPwuI+Soly4xAiiooCg4Le+bndy8k6GFk+JPUFItIxNMwyINY2BMI0iQp
7WFI6L9Cw75ITH0AzDcw5jvXIAOv8G8BdGlwWwjMLjnFyjPzQSjGLLHcJZng
Fpln4ws18kk3CoaZR8BtoxF20Vm2UVDLWJhVYpZ1bIZ5WPITCNo6LsPQO+yr
wOi7aUib6FRjN/9vvEN+NLE1sHIy8Aq6H5loFRRlbOf5rb3nD6B8Doy8l5Jp
GZn0ODblCRRlCUVYJqWZ+PnfiY0y9/N67Gz7vb/XY0iSE8gPWRC7ApTL+dLE
89W5F+u3pyf25if1I6rZ/v4JWY9WNXY7f7tGv6KenVcM93H5BAQ6yN7Z7Puv
zX/4xv7RvRBHW0RsdB0O29vKnlP0jUqlE729GqVyfXb2YHkZWDBod7TanYWR
A90koPhkaQ4YCjhQB1vZ9UUF5ZmZpTBoMSQdC0kvyYIR0EgWmaSSdmr/mW5a
Mz41NaycHxvv7hDSq6oBvBJeu0reN6VUTQwPzk6M7ayvnB3unezvXO4dvTq9
vF2scPdwd3ljfWEZ+O/S1MJI7/BgVz/gF5ALBBDuF8lBK+J0gEQNfHlI2qcQ
dYvZbW20Bi4V1G6d0/KeJeXw2phqc2Jkb2r8cG4CjGkgRVwfHLw6OXl1dvri
7OT67Azw++r68nZCv5PDs9u7qJb3F+dXxlVKYbuAWl2Tj8KmJxWkxIMOt7pC
3ECRcxhjne3DAg7QuIS/rOoHQ9nr3ZXPXyy/2lm9WtNdbywBWt8fbr3YXAEg
A35/vzz5HVTWF4eg8gXOe7I4vTk5qB/p3e1vW5c1z3ApKkblFI++Khfo5cJp
EbuxGJ0TGx7pYg/+L/621q6mpr62tnEB/p+XQaknFMq5jQuKTrCHTXXf3szQ
2miPStjCIeNpJbksUqmkpWG4q0PdJ51X/n+aUYjkbQxGeSEWmgCPCcpNjixH
QerxucAxe1vrpuV8jbJzblCo7xf1McmC6mJhLUHUUClroSgEoCphStoY/GYa
nVyWj4RGBvo52VrZmJnZWVh4mtoF2rkgYmMZFThpc52EWQPUx2NJOc38RmC8
VZXYokp8cQONxOZQuW21LR3sWialqrGK3FRFoOIQuAxYUSK6EpJdkZRHTskl
xyLLgxFlfmiSP5rkCy/ziMp5nIgxikY9SMI8Sy8ySck1TEA8ASTml3oTKbE5
+T6BwQ/dPL5x9/jKw/Pr4JAHgen3I7OeJeVYQPIsU+BG0an3w+N/CEv4ITjm
e5/wrz2Dv/IN/z488WlihlUqzD4lw8Eb/cgP/TgwzzCiyDK22C62yD463zYK
bZOO80jIcQyDmISmGUVBTBOyLBLhlglZ5mGJ94EFe4V87exrEJHwNCbZ3Cf4
vmfAjz7BD/zDn8Wm2kGQnlGp1s5+P9h4fuUWfA/wmwyzCIm9FxjxXXTyg4R0
QyjcJjnFJjTU2MfjYXS4TXF+bFV5GjYvCA13yUe7XepnXm4vvjtYf7GlB9aj
GVCMdXUpheIJmVyvntqcXQAt0IxigE4oi/T08jQxdDV64vT0obvJs1gvtxIY
lEel/HO3uGhSLl8aG9tZWDha1h/rVw71eoDwxpxyb3HyRD97sa4DIRPk0jl5
r6SBUYFAYSHQzMjoxMAgWGwsuRQ3LOvaWV68PDg+3trVz2mAVua1cnFnayOj
r1MCbBcIwDuvHrudUu9w7/r85Or06HZJtcubtxfX5ztHW7pV4LxaMOCMzoBq
d0iq+IxtD18mbBZw6zkcWktHi1A9ML46C4aIOZVM0S/oFLPYrbXUfh5vrFM8
Ke2c6BKCEnV1uH97fAjoZHnxbG3t+fbtXVTvri5/enH97sWLNy9unp+fATs+
39/dX1len52ZHeyXczkg/1cgs3LiY6ChQVkRocjoCFRsFC4jhVqYK2PW97Yw
VEKudrBnf37i88lcMKCdLE4eaiaOtJNAOzNj6+PKg/kpQPHfNxd/XZ8DhH85
3Xu1oz9bnt6ZUa6rFVtyrkbQMEDDy2qKR5trV3o71oeki3KxrIFSCYcm+niG
ONj7Wls7GRm5mJj62tvH+brBooIrcrJEDZSZXtHqmGJtVL48LBsWtDSVFeYk
RkHCA2Ax4bnpKYT8XGo5QcgkS1tpg0IWkIBOAsxmhPrEeNgn+rpkRQYUpkVX
5kBaqorBswvDXYujsoVeYX8LrZtRM8BtULQ1DgqYKglnUNwCEJa2M9uaaqtK
C0AhHObn7evq7O3mHOHuH+Xpj0xIYBJL+3hNAx3M3rb6Xm5TH79V3MxiVNcQ
i3HlJVhqTUVzc20br54nbGdxW5pam+jshgoaMa88v5CUX8kkIPDpyLJUOCEW
VhwKKfKDlfjlVIYUUSJj0UYh0PuxKMPUfMusYvusIgeAT1j8A1SBWx7WJyPT
PjTioV/IPa+AHzz9vw+KeOQe820Y9GlirlVSjlUi0jQebhye+gCUve4hXwB4
QXL2Db8TGPUwMsEsEWKXluXik/PQJ+exf86TYIxxJNYmHucUj3WKL3ROLnSJ
zLIKg5glouwgec4JcMuQxEe+UXdsPQxC4x94Bn9t4WDgE/xjQrptVLx5UJhh
SJRZeKxlMswlM983KcvJJ/KxU9D3HhE/+ob+APw3POG+X9iXQVHfRiU+ROQ5
52J8Q0KN/fyfleJSlcPsTnEVEunl7/uDs5MB8ALgAq931262Vg40s4vDQ+ou
6XCHaJDfsTAwtD49szY1rVerZwcGOpubqoswwFwSfdy9TJ95mxnHebrl/r9d
nfdTW1m+7T3dPe12t9s5EEzOGSEhQAEhJCFyzslgk0wOJucgcpaIklAOKKGc
QGREDs5uz+25c2fe3Pum3j/xtqbfT69q1a5jm6JwcT7ftdbROftE498WF5Aa
6tfGx/iUeQ2Hc6BQnG9ughP+zGg0a7UGKWtXLTwxKi5M2muTAZRrLZvLmSaP
Nrc3FZWlRUZjAoMTsDjQcPUb8ivz4dXJxdHOgVGtNekMO4ZNEZfPXF1VSiQK
4bqYw5Jw2QbFBqDm3anZcvMzsMLjyy8X7z+d3Rxv7eulKilbKKBxAbxgZZDp
y5OLSxMLgN850hwQeYQsXFvfVGztqnd5K5yJnpGRtt7p3qEF0vDy8DBzcmJt
bJjS1bbQ1cqdGNKszhnWFrb57AOZ+GpT98l88OXiDCB8c3Z2eXp2fnxyYT45
29vf1xv0EgkIHszp6fm+vp7Kqqqs7BwCPiEsNNLfL9TVBenpGgUNKE6MrcpO
7aspX5sgGfjMY0CuSrIr5YuXLZdz6WM9tNFeYND8+Qk9Zw1EdxCk/2LeA/AC
fT3c/LSnBWP2ekv2QcnZZ83LJvv4w+0K8uihkH6tFl9rNw6lgqWB7tLURGIw
NNjNzfeFnY+dHeA3xM0JB/HLjca3lxVRR/qkK/NCytTqcG/3m1fZBAzCyxnu
4Yrw9Qnx8UEFBkah0KVZ8dWFaT2WqNwAkm19flouDpkYEhAL9cnEhBTF4wDR
vbUltIn+DdaiRkADNWG6tWGitZ7S10rubwXpem26nz4zsDhuuR1rYcJyR1ZT
5etXOek5KYnZyQl5cRmZxPj8xIS3pYXjXXWUoWbyYMvsQOtsfxeZNDTVP9jT
3FJXWV5XXdrV1Tgx0Ts2MU4aGe4fHujs765rbyipLytvrqjvr8urycqsSEwp
iUoqQkXnBsXk+meUhZU2R+Gy7SBRvxCyHRMKPbPLIPllMAzxGS7GGh9rQ0yw
i060B002Kt4eTXiGjHwG3NAn/DYE/2tI7KOwxKeIpCfIpCfw2PtB+J8hEXcC
0T8FhN0OCL0ThHwQhrXCxjgTkzz9M+8jXtpEljsDeMPy7BE59ph8V+JLn+hC
v/BUp8h014xSeG4lMjrTLRB11w3yJ2ffW5iYp6GRD1x9b0ERD/DRLhicYxj6
RXCYVTDyeXiUAzHVMzLJKSjyoQ/6TkDkL/7B3yWkOxITrdCEu2HYH1H4X1Jz
3HOLYGFoGyj8eVtn0f6RUCKfqa6PS0jzwMe+MKtFpzrphUF5YVAdKWV6Lke0
uMSYmuLOzwsXFxUs1pZUZJKJNUK2kkfXCJlz7c1gzieFQJNDYTlYdD4xsjYn
c6iuenVkkDU1KadRDzZk73e3Px8eXm1tHSqVRjl3Tyc9M2kudgyA6H2lSscV
ri+vsWaXJzpJtcWVyYS4lOiE4b6BbePm9bkFXqAdg8mk29zbNG3rjTqFAkgq
EEiFPN2G1Ly9dXNyBPj9A+Hrw7MPJ1fvzBcH+m2lQAqwZS7QqbPLDAqNOrMC
kjPgdIOzoRPrdlQ7ZqPZvHm6Kd8GFFNGgc/0DTR1THUNgGG1QhpmTU4wR4dm
25tG6ypmm6vpA+2c0W7VEnmPx7rRq78c7n48PLzc2wPMnuwfnhwcnx6egB91
S6VVCdZF1DX61DSlf7D9jeURvCxidAI6HAeFwt3dAx0dIc4Ofva2aH+vwqTY
8c4WJYd2pN3YV0ksV4dWxqmj7RNtlROt1SukLsDXjoh3rlV82N78uGMEQRqE
asDvb0fG38x6oH8c6N+phLvsZQN1zsRcPpHyP26qfzfv/rZn0rLWJttaq3Jy
UrBYtJ9/oLOzr709yNIIT/foYMjr5PiRxhrayACIAcMN1TXZabEh0ED7F0HO
znBPTz8nFx9HV5iXXwIGlhIBf5VCBMmZ1FDR8jKrKAabiYbn41A1mYk9lcXj
rfUg7gpWZmXMJQljkT0zMdXRMtRQRWqsAn0WoD3aVjXZVbcw0rE63cekjDIW
JlZmhmeGe0d7O0hdrR01b99WVIO41VFTQmqvmuipBRrtqOtrqiJ1tI339Q53
93S2NLW+revpeTs62jU8PDQ42N/b39PZ19Xa09rQ9bauq7G2t64CzKPG3Oyq
pNTX2Pj8kJjcwNRieEFNRHiqnX/EPXy6W0Kuf2ZxSO6rsHCCLS7GjhBtGxVr
FZ/mmJzlio+3DYt8jMA9Cye+CMT+6hn2Z/ew7/xxvwRE3fPB3Qki3gtPsQmP
fw6PfOAPv+0Nue0P/xVk3TCcPZLo5Jv8AFFoH1Xhgy/zjnjpHpHvhc3ziczx
SSoJI2T5EbP9s8rQeZXYuKyAUIJNEOYJiN8xaU6RcS9gyIdIjE0oyjog8AEU
9hQCe+oPewQJexSKswohPPEL/8kT+b1X+PfQkB/Ssp3j020xxLshmB+Cw/9M
TLZNzPAiJLgHo2yr3mZs6FdowqGajqRXddjyZvypdgPoTKcAAuHWtC5U0GkC
MsUoFIqWF7kL80rOmkHC1a4zjVLuoVFmZNE446TZ1saR2jedr1825GT0lL2i
9HZwZyaF5Fk1g2ZWKj7v730zH70zbYFjEGrP93Q3ZpPlKSSj0SRTaPhSOVMk
WGLTZ1fnh2ebq94WZhUO9Q4a9Zvnpxcm/dbe1u62waRTare0+gPTDvBiAYvF
odMlAu6mVnW2vwOK58Xh3vnB7qV592zn6HL/BKwgPIPYzKdygPmC8rs2T2Mt
MKQsMcD2cu/y48nHrxdf/+PmP26OPknZ8lkSeXYITJCFpZE58sAopZ9EHRll
TY5xJ0fpQ72zzbWkyuKhioLhypeMnlbZzPg+n32pUVxtWS6qXx+Z351fnh2d
nh2dH5osb1fc4Iq4C6vg+5Ca22oLi4uS09JwUQnoiJgwFGgcwW7uECcnL2vr
AEe7SGjg6/SksY7m9dUFo5i/IxcfKphq1jywYO4sScNatlxz3jF+Pdj97XDv
/30gZbnzWXGuk5zp1oGuFOt7XJp2ZU61PKdemdfSl0FVv1DLd0QCNZPBI5NB
kAB1viovPzEcE+rlS4BC8UFBSUhEZWbGeHMjdXhwebBvur2lIT8nPjQkwM4O
OLW/s7uPo7uvk0eQZyDC1wXl45KECm4ozBqqL+8uK6xOi38di6tKjSNVlwO3
FS3NyuiLEvoikzxBHu4DvaO3pqa+ML8qJ6M4ObooiVCRHVeVl9jTUDzcVkUm
tQGE12kg9iywl+bo85Pk0enZ4ZGpgZ7JgbbZobezpKaxnuq+t2XNFUV1JUX1
ZaXt9Q19Xe39fZ0DAx39g20kcGYMdPf2dXT3tfeQuntGu9uG2wG/5W2l4ORL
K4uOy0cQs4KiMnzx6R64NFdY1LOAiMeoOOeoVN+ELFhyJgxLcMbiXgB+I/CP
8HHPI+OeBaEsxgqLeATHPoNiH7gF/+AS/L0v7le/qPtekb9A45/GFnpFpjkA
xn2CfnL3+8EX9msQ6jkUYxsYbuMT/xiW8QJV4I5/5Z9YiUirxca8CkWmeCOT
vMOT/GJzQrPLo3IrCHGZMATBJQhtC0H/gou3w0TbIrBWEXinkFArX98HISG2
vgEPvPzuekF+DkTdg+IfBBF+DSDcDoz6MRz3a2YeKNpPw7B/DkLcCkQA+34S
Ef+CmOYThncuqIqdWeseotTlVGOIed7EPPdjrexULz83qs716mO1fFciNvJ5
Og77UCnXcFgi6qJ0bUnOWd3gLG3wl7TStUv1xrlSuitgbyzOMUcGwNnOGBnk
TIxo6Ctg/m+v80/Vivcm44ed7UuD/lilPNvXXZtNH84OAL/7Wq1OKFWwxAqW
REwXcZY4fJpgcXqlt6N/ZYm2t3u0f3Bs1GxqFRr1hkolUwKE94ADK9Vry8ur
FMo6l2VQg4FgODIZgQ5NuoMt7Ynp4I/9Y0HzFTEEQKDYqgQKzbpKL9Ee6vc/
HH8A2H67+vb57POn00/nuzcSloIytrQytcJbZguWWOy5JebUHH+ezJ4a502N
CWdGmaSuqYay3tfZ3cUZ46UFlMY37MEeCXlatUbVC4UmlfrAuGPeOwYC/JpU
myqhnLNIn+4d7qysL8vKz41LTsTgiaHoSCgc6RsAQmyAkxMM1FI312APVyw0
EJTNnoYqFmjZIu6Zjn+q5Z1o+JdGyed9Ayi8oPn+8+byH1fnfz01A/8FNXlf
xtsU0HTcRQ2bYmQsS+cn+FOjsoVZNXVRRV3SMeh/wAu6j3xtTcFgSGj05dGx
ptclGYSoVAw2DYstSU7pq65a7O+jDpNoI8NrY6Od5WVZOHyws6u3rb2vg7uf
s7e/q2+QJwTmYhvq4ZCKCe0sLyJ3tUw31w68edVf9rK/4vVKX6d8haxmURUM
Kn9pfmF0YLDtbVtlZWFiUhIGE4cKw8H88FCfmDDfmDDv3Fjkq1RcY0kWKNSc
pQkZa1m8tshenmEt0xkLiyuzE5TJ/sWprqWZjqmB+p7GktqSXJCx89JSSgoL
m+qquzpb+gc6SCNdE2PdY2O9gyTAb3M3qa1nrLOV9Lam682rt4X5telJr/DE
bFh0NiQ2xz880SkAdc8H9QBOtAshOGHjvYmJAYRYX2KsT3iELTL8cRD8h2DU
T1DUbffAW97wHyDhDzyD73jDf/IOuQMsGxb3PCjBChL/FJluF1PgjYi1hqEf
eAX+6O77ow/0XiDiuT/K2gf53CfmKSzVEZ3rjSsKSqhAp1bh8fmh0GgPT6Rd
aLRffG5ExuuY5AJcRAIEinb2hln7hNwOJ9og8dZw1DMMzhmJsoPBrDAYNwjk
qW/gfR/oXSjmISLuKTLpUUjC3aC424Tox9l5rlFxD0MjfgCCR/wQHvMQjn+M
SXRDxXtklhN65utG6C21pKz0OlRCBeRAKTrRyS+3NJdGLeAXpN9D+Qbgblcm
OVBIdxUivYil4K2oBCs6GWNLxbY85qCWgtgGTh7d2opZKtwTckTz01tc5o6A
sydZP5JLzQoZEDg43JAcbivP9vSXh6Zj06ZeIluncXjLLCGVpxVqOEs8IV28
zpEy6Vy9znR59X7LtKdT6sV8kYi3rpDIDWr9/rbFf9k0GmV6mseka+TSLbXC
pFHuGlQ7euWmWgb4Bc13W2UAJiik8wC8m3L9gW7vYvfscu/848n7v77/698/
//33d79/Of8C+D3eujDIttfXJKwFFpNM5y9aXrNo4ItUDCaIEOzxYQl5UjI3
utzVMFpdNFxZOFiQPlCUNVxaOFbzZqqtebavjzwytjA5Z1QZt3Tb27odk2pL
K1bxV9iA37byupz4tGRcLD4UhQyAwjx9A1zcQDT1c3LydXSEerqjIAEEBDwl
KrKiIGe4s5k6O765vgAQ/nas/8fN/n+/P/2fDxf/+nj9fz5/+N8fbv7r4vTz
3tapRmZaZ6qZCzLqFCjLIP+ASSKenzKy1443xGaZCNTzE5XyRP3vvQTZbCWD
pWRzuJSFgcYmkAQSkeh0LK46O2esuWWhr3emo32uqxNQTGpoLElJiwiEBrl4
Qt39gr2DoF5BgF+0rxsB5leSEjvV3sieIFEHusltDZS2t2sDPVLKjIFFB/xK
Vhc5lJnl8ZHx3s7STMt+HegAf5SfN8zNPtDZGuryLNDxYbi/AzHEMzcB3VVb
zJgbtlgAe0VIJQvWOKzllcWp0ZmRroXJztX57pmRxp7mkprXOa9zMwC/eRkZ
Rfk5lW9KenpbZ+dH5mcHyXND4+M93f1NbT31bYNNjb215S2vQfgray/IqY5P
eRWeWY7Or8bE5vpAMPc8Qu+hQdTEOWJj/fCxgRicZ2IKLBxjBwu56xNwKwD+
XUDon1z9Lfz6hP781PmWvcctf8RdRPwLZKp9aJo9Kss5PMc1MtMlAPPAD/6L
Z8CPnv4/+cLuB4Q980NaeYdZeeCfILK8iCXwqOJQbB4MkxUcmuDvGwF83xeX
FpaQh49KRyOJAbAIz2CMByzcHYL+NTrFFRvrAA17jAi3QyIdYDAbBMIRi3UD
fwzBWCGJ1pZHnJIeBUXf9sTe+oPf6MRHWOIdfMI9bNz98LjHgeG/phQFxxeG
Jr7ClHZmdJCrmmZevu6Nf9VLNInpZjX/ekd5tasxG+T7GsteMeZNzeX+1vGW
dk8t29pY35TwTBLurpS/JxPsqqQ7StH2hnBbytvb4B1scLeFdO0aRU2bPxCz
zpTCC430Sqc43BCBHgcGwvG25sCoMG+pTEqJiL7EJk/zKfOcuRnJ6qqSydTw
+Lp1y9uBjwybh0bLfs4qIVfMpAnpKwo+d1ul2NNpdFKxmMWkL5DXWQytTKJX
KjUbG0qJRCWVgl4MAAcyGYxK2YaIL5BLpPumvfeX70A5vT67+XD18dPN5y/v
v35+9/Xq9OZo9/hke0cuEPLpayIWd53D21gXa+VKlXRDLhCJmCwpmyll0Jhz
k8uk3sn2xq6K4rrUxMbM1Ibs9Kq0lFcJ8RXpGd019ZTBMaNYvilRbG+odxVa
cCClM5dHJ0bbLJ+AFGdkJUbi8cEIuIcv1NUrxNMv2NXb74UzwtsvNjS0IC6m
sSi/q6pkrK1+bYpkVG7s67U3+3u/n5/+893Nvz59/NeXT//99dO//vbbX75c
nZlNBvm6cIUCeiutr3utt3tpbHRtZnKDvnIgX7/SS9/pRB/1om87svc6/jvg
4zKGnk0RLo5Tx/vGu5q66ys6qqs7a2p6amv7aqu7q8p7qyum29/SRwcF81Pk
nvbS1MQIf2+0jxceBotBIlNwuMLo2OKYmKa8nIWu1n9vUE/WUKdVK+O7/KV9
cKrIOWal5dEnFYu+Njk+2dVVlx2biAgI83aBeHm4ubg7OLo6Obs7OzpBvNwx
Qd7Z0ciW1+mT7ZVLpFb6VA9znsRcpPBpq5yVZcYChbG4tDQ9N00anx2ZbKl/
W1ZUkpaQFB9NzEpLrnlTNtDbMTM5MjU5PjxE6u/t6+3t7+8f7Okd7Ozqaelo
r29prGx487IyN+t1AnA9TKJfYIStO/y+M/SOfcD3wE/D4p8GR90PT7LCpzoE
YR66+P/o5Hnb2fOut/9jCPxZEPyxT+BP7j7f2UDvOITdDYixRqU7ojPtCPmu
0fle6EQnCMbWP8zaB2btB7WGImyRWIeIKMfIGMeIxGDAKSodhsgMRBUEwbI9
YZmuuJe+qGQHBNHa0qkJtpgoOyTOPjTSIRTvCIn8BRnzDIZ9arlN2vdRGMoD
jfEOgtknJEMTUvzh6CdQxANAd2SCC4ro4I94Agu/k5zrRkx5gSY+DsE9DAq/
CxK+R8iP2BTnvBp0UWNkQUNEaXt0fhMmrRIO1h0pA/B7sbVxblKebAKpzneN
78y7Vwemsx3DkV4JgAW07sj4gF+gbYUYmPKOfB38zb6cD/g1CWhq2qyEMqpj
LGzzaftizpFMuCvm70uFFwbNvkG+q5Pt6WQqIZs2M7Y0OsiYmgASLCxs0OmA
X71IZJTJAcIasUTCBu2V8semHOtrNI1IqJdJ5HyugE7jUFfEHJZSJFSIxXKR
CKwGlWrXaDw/PjkzHx/t7W/pDTqVGqzn5rOvH75cn119vP4EyP364bdvn/7y
9cO3m/P35r2TLaWKS6XRyBQejQH4VYjBEFCpwQ+g0uplGwYwH0QC6doKbx4g
3DPRWt9fWgycd6alcaa1eaKleaa7mz41K6Gzd+SaPY3hyGAyG7cPNcZNyYaC
xRWt0jlLKxO9/W3VtZV5RWn4mKgQFDYoBOEVAISDwhOQyPzY6KbigsHGquWR
XiVrBdSB872dL6fmv99c/c+H90D//PDuvz7c/PXT1furo4MdrXKdTZsaHW6o
bS/IfZuR9hY0xErLmxTo44PSpUn92tyBYOVCwfyyJQa6UvOM3EXR8qRgcVJE
I0sYS5wFCptCZs7OAtyWSP1gLvFmJ9TMFSOfwZ+bBCUyw/LupIi8uLhX6WlV
BfndFeXdpaWj9dWccZKBtbTLW93lr+wJls/krAuN4EovvjTITjSyTRFHsECm
kAbaitMysHCUn3uAh5uDnaONrYO9g4uDnb2Hw4tgT8fEcEhNbhyp8fV8X+Pq
eCdjboi9vLjOoAvX6OuMNSmXx16hAXgnBkYaqupeFxQDfuOIUenJCeWvi0BH
H+rv6uvt7unq7urobG/vbGlpa2hsqa1rqK6vq6yvLq0uySlJj82MCCP6+aFs
vcKeeIY+dITctva+BfqsX8SdgIg7yPinkcl2ICo7+/35hct31g7fO7re8Ql8
EAh76Au5A/i1DvrpD37DM51x+S5RBW4R6U6B2CcBaGu/UKsgpCMS64HAOoeg
bfGxrlmFwcmFhOSiKFweEpkFgWf5eifae0Y/D06xh8daB0c+CQHVG2cdQbQP
j3JCRbmgol1hhHuYBJuwKBsPyD3ALzzMFYXxhoc6E2P9AL9ovG1Q2H045gkc
+zw4wgqCfo6KepiU44qJeRqM+QXwC498EBr11A/5Mz7dLacKWVgfkVcXXtyM
z6pFxBT5xr8OOFLxAL/HOpFZLz02Ks63tdeH2x9O9oH/An7NBhXg1yQTbIk5
W+tsIJNc+O9XMEhA8D5SrR/KeYBfFXWGPd7DmxqUUMYVq/Nq+pKSvmzgMixP
Q2il2xrJtlosYVFBY5of7FkdHV4eHqKOjfHI5D/2g9WKQGNd59Poq7NzixMj
S5Oj1NlJ9tKCmLkm47IlbKaIyfjjwyMgIZu9zuEA/93b3Lw8Pv5wfXNzcQkQ
PtzdAzo9Mn+4ev/t029gBfD+9vEb0B/8Av892D4Ss9jzY+NTQyQ6ZUnI5gLn
Bf0a8GtS6zYVlg1s1XwOaP1rE6TZ7pbhxqrZ1kbQ8aULc2oGTcu2bLRrkin2
tcZD/dbx5s75zsHZ9j44ONIaDtQ6oF21VsxgUWfmJrr664pK8+JTkiIIBBgi
KhgZHYokQKGxofBXyfE9NWXsubEjteTd2eHny5P/fHcFsAX++/ery/+8PP/L
5dm3d2c3FwfmfYNRIQJ5oLeyvAQYU0hociQ2nRBZlBjbUJg10lBGG2hWLIzs
8iiGtSmwbrHJIsrwykgnbaJfTKfoxZwdhXxTKtIJecAxxatk8fK8nks3K8Wg
VpvW2VTQYRurRpobpno6Zwd6F0dHeFNTa8NDrDGScmV+j08/FNGPpWvnCubp
xtq5mnupFZ5qRMca8a5UIKMtUyfHSLVFxQmRoPkGerrb2dpbWdu9sHOyf2Hn
+sIa4voiFuFXlR0z3FSyONTCnO3nLY3T5meBBVPnZldnZ8AUnSaNttQ0Wjax
K6koznuZmZyalpRYmJtVV1XR29U6Ntw/0N870NcPIG5tba+pqSstq3z1uvTl
61elVeXltWVFVXlJeQTAry/Sxgf5LDDC2gvxwCHwBwfILRf4Lc+w74AFA/vz
R/7qDrkD+H1ic8vG/nvvgPvBYc8g8Hte/n8G/Dqj7kPibLE5btHFnsB/YdFP
naE/+iKeQVAvcPGQtBwM6NFwlE1ktPPLMnRuRVLOm6SYYizgF5Lq4UR4aoe+
60V4FBxjBcM+hmMeWS53xzpFxrphYtwxcR6AX3SihV/PoPtuPg+hcCcE2jM4
xMkf8iQyyiUqwRUZaRWKfRYSaRUSaYMmOsem2acVeKKiHkHRd5DEp5g4a1yK
YxjxGTLOJjrXO67AL7bQL6UUFvfSF5FiFxxvdapbP9YIDtWCA43oUGfZLvXY
clFId7G3CQ72NRsGCV/Fpas5VC2HZuAzAL8HaumpXn6mk59ppacq4baQCvwX
8Ls23AEQli1Mi8hTQsqUgrYEEN7VAf+V72nlCj6TMT9Jmxqnjo1MdrQNNjRM
d3VRJyb5y8tCGo2ztLQwMTne1z8z1Dc3PEAZIy1NjlNnp8HvWkCngvwsF/IB
vAIGHXRhAYsFIvTJ/v6n62vA79XZ+cnhkXn/AMALjgG5n999+nj94fO7L/9O
zpb14/Xn08Nz0FjpZMpgR2d/WztIbgIWB/gvyM+WVSrXSWUbXDZ3kbwyThpr
qW8tKWgoyCR3NHMmLe/v/ved4Zozo/F40wRs93hr17y5c2gwHei39rRGgO22
Um1SqHRiqeVp5Tny3MBIa0VNSUYuQDgtMrooKaM8K7cqJ6ep+OVEezOPMgUG
4N+uj799uPz94/Xf3l//7eri99OTb+ajbyfm385P/vL+HPjv5enu8bZOwaaP
Nze+SYgH/IYHBmAC/fBB/sloeFkyYfBNPnOoRbU8Ip3v32TOAKPUMOb4lFH+
wsQGaxnwuyUTG8RC/TpXx2eo2Ktq1uquhHOh3wC/O5CENWyqlEYB/wS+AAwu
rZC3xWWracuq1QUjexmY7zZ3YV+weCqj7gkpR+LVI9naoYx1pOCD9K7h0jlz
U9Otb6qy4hPCQ+D+vo72TsB/QYQG/utmZwP4jQnzrcyKHnlbujLSziEPrVOn
hWs0MYvBXV1hLi4wl5YpE9ODHb29LZ19HT0db9uaauoaa2vamxuHB3rnZ8ZX
FueWFinzs3MjpOG2NlAFaktK3xS+LM7Kyy0qe1VRV17ZXFpck5WQh0XGesHw
DlDcC2S8MxRv5Y36GfDrArvli/4Rir0XgLoHQT1x8/3FxvEH4L/QUCsswRmB
ee4L+Qnw60OwCktzwed7xrzywmTa+2Du2vn/ycHvDjTcPiETmVsUBfiFhDwN
Rj6NSfZIL4rOKI2LfRmBzoEGpXk6457YIn/2xD34Iz+j8Vb4GEfwZdHJPrgE
78hE75Doh4BfBNE2EPEcGuaAifQDAvzaOX6PirDLyA2KS/UkJLrg4pzhWGtU
lFNipktmoQ/gFxb+MyrqSXisJf+j42wg2AfBhCfBxKdhcbaRmW64LPfgOBvv
iPsnWiHg90gj/IPfQ93GrmZjWyUF+RnwC9KygrsmolIkVDL41QN+QXg26+RX
Js21SWX5XEMj2lsH/XdePEtiDXeK5kd1a0sby7PSxVk1Y1XHpgN49w3KQ4PK
IBNusNZkDBp9YqyrsqKuoKC1tHTo7dv5oaGFsbGZwcHB9raO+rqxno6Jvi6g
sR6LZoeH6OQ5ELcAvyI2k0tbZa6uAgsGLfj86Ojr+/f/n/len1+8u7i5Ob/+
dPMRkAvKL0jRYH1/+RGUX53SsDg51dnYBATOHB6DJROCKC4Fq3JdAvgVMejU
qXHyUG9fTXlVdkpVVvJUeyNzkqRmUXdl4D+uPtuy9PRtjf54e29Pv7mp1AAB
7waxXC0Sg/y/TmcA86WMjgP/bSp5A/gtTs0qiE+tyCroq29aGRnZoFPNavn7
PePX453/9eH89883gF9guF+ODt5vm4DAwbeL08+X5ouTndOjrdNdg07Imetq
r0lJzkOiwny8Qzzdgl0cwtwdEkJ8a9OJ040l7JEWxSIJ+O+5gn20wdpcp+v4
NL2IZZTyNEK2RsjUg+wk5myKmFsiJqDvelO+L+PsSlha7qqWRwWTBMxkMJl3
lJIDscDEZ26yqSbeyiaLol4d09HGdrgz++vkY9mqeYN+KGMeq/mnOin4huvL
c5PN5bW5Sak4FBIKcXV2s7MH3dcN+K+zzXM/Rys8zKM0FTdQV0QZeAv6L4s8
zKOuKAQ8tWhdIxZppTIZT8ins9eZPAGLx6IyVsgL5Jlp8szkEnmWvrrApC8L
BTw6lTY6PNLU1Az4fVNZC/w3Mzcn52VecUVRaX3R67qcjNcxhHRoCNEZgrXB
Z/jg0j3h0c9cQ245BFoQ9kP+BJItgmAXGPLM1fuel98jdKRzbKIPBv/CJ/A2
6L+wRKfIfN+oQm/gv2HJVu6I2y6w24+dbgUgbIjJwVHxQTDkC6+AX70Dfw4M
uRedjkosxMcUYiLy4SA/uxOtLP6Lf4jNcMXE22OjX8QmuadmBSRnQ+MygmIy
IJhUG2yqfXiiU3ise2xaaGYeIT4JEYZ0c/e6C/y3qBSdnOUXk+xOTHIPCHkA
QT4jJNik5nqgCRb/BQgHon4OIzwOITwKIT4DCAdg78OinoFZQcjxjEh3gRCe
/F+oSJay
         "], {{0, 213}, {320, 0}}, {0, 255},
         ColorFunction->RGBColor],
        BoxForm`ImageTag[
        "Byte", ColorSpace -> "RGB", Interleaving -> True, 
         MetaInformation -> {
          "Exif" -> {
            "Make" -> "Canon", "Model" -> "Canon EOS 700D", "ExposureTime" -> 
             Rational[1, 320], "FNumber" -> Rational[28, 5], 
             "ISOSpeedRatings" -> 2000, "DateTimeOriginal" -> 
             "2014:08:18 16:34:53", "Flash" -> 16, "FocalLength" -> 250, 
             System`Convert`ExifDump`ReadFIDData[
              InputStream[String, 4], {136, 0, 0, 0, 0}, True], 
             "GPSLatitudeRef" -> "N", "GPSLatitude" -> {51, 54, 
               Rational[147, 100]}, "GPSLongitudeRef" -> "W", 
             "GPSLongitude" -> {8, 17, 
               Rational[667, 20]}}}],
        Selectable->False],
       BaseStyle->"ImageGraphics",
       ImageSize->{83.03125, Automatic},
       ImageSizeRaw->{320, 213},
       PlotRange->{{0, 320}, {0, 213}}], ",", "r"}], "]"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"r", ",", "0", ",", "22", ",", "2"}], "}"}]}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[15]:=",ExpressionUUID->"557b82c2-9583-4f8b-86f1-2d935602021e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   TemplateBox[{"\"cheetah\"",RowBox[{"Entity", "[", 
       RowBox[{"\"Concept\"", ",", "\"AcinonyxJubatus::3g535\""}], "]"}],
     "\"Entity[\\\"Concept\\\", \\\"AcinonyxJubatus::3g535\\\"]\"",
     "\"concept\""},
    "Entity"], ",", 
   TemplateBox[{"\"cheetah\"",RowBox[{"Entity", "[", 
       RowBox[{"\"Concept\"", ",", "\"AcinonyxJubatus::3g535\""}], "]"}],
     "\"Entity[\\\"Concept\\\", \\\"AcinonyxJubatus::3g535\\\"]\"",
     "\"concept\""},
    "Entity"], ",", 
   TemplateBox[{"\"cheetah\"",RowBox[{"Entity", "[", 
       RowBox[{"\"Concept\"", ",", "\"AcinonyxJubatus::3g535\""}], "]"}],
     "\"Entity[\\\"Concept\\\", \\\"AcinonyxJubatus::3g535\\\"]\"",
     "\"concept\""},
    "Entity"], ",", 
   TemplateBox[{"\"cheetah\"",RowBox[{"Entity", "[", 
       RowBox[{"\"Concept\"", ",", "\"AcinonyxJubatus::3g535\""}], "]"}],
     "\"Entity[\\\"Concept\\\", \\\"AcinonyxJubatus::3g535\\\"]\"",
     "\"concept\""},
    "Entity"], ",", 
   TemplateBox[{"\"lion\"",RowBox[{"Entity", "[", 
       RowBox[{"\"Concept\"", ",", "\"KingOfBeasts::vrwm9\""}], "]"}],
     "\"Entity[\\\"Concept\\\", \\\"KingOfBeasts::vrwm9\\\"]\"","\"concept\""},
    "Entity"], ",", 
   TemplateBox[{"\"red wolf\"",RowBox[{"Entity", "[", 
       RowBox[{"\"Concept\"", ",", "\"CanisNiger::99p6d\""}], "]"}],
     "\"Entity[\\\"Concept\\\", \\\"CanisNiger::99p6d\\\"]\"","\"concept\""},
    "Entity"], ",", 
   TemplateBox[{"\"domestic dog\"",RowBox[{"Entity", "[", 
       RowBox[{"\"Concept\"", ",", "\"CanisFamiliaris::597qc\""}], "]"}],
     "\"Entity[\\\"Concept\\\", \\\"CanisFamiliaris::597qc\\\"]\"",
     "\"concept\""},
    "Entity"], ",", 
   TemplateBox[{"\"musteline mammal\"",RowBox[{"Entity", "[", 
       RowBox[{"\"Concept\"", ",", "\"Mustelid::7cqcd\""}], "]"}],
     "\"Entity[\\\"Concept\\\", \\\"Mustelid::7cqcd\\\"]\"","\"concept\""},
    "Entity"], ",", 
   TemplateBox[{"\"domestic dog\"",RowBox[{"Entity", "[", 
       RowBox[{"\"Concept\"", ",", "\"CanisFamiliaris::597qc\""}], "]"}],
     "\"Entity[\\\"Concept\\\", \\\"CanisFamiliaris::597qc\\\"]\"",
     "\"concept\""},
    "Entity"], ",", 
   TemplateBox[{"\"person\"",RowBox[{"Entity", "[", 
       RowBox[{"\"Concept\"", ",", "\"Person::93r37\""}], "]"}],
     "\"Entity[\\\"Concept\\\", \\\"Person::93r37\\\"]\"","\"concept\""},
    "Entity"], ",", 
   TemplateBox[{"\"person\"",RowBox[{"Entity", "[", 
       RowBox[{"\"Concept\"", ",", "\"Person::93r37\""}], "]"}],
     "\"Entity[\\\"Concept\\\", \\\"Person::93r37\\\"]\"","\"concept\""},
    "Entity"], ",", 
   TemplateBox[{"\"person\"",RowBox[{"Entity", "[", 
       RowBox[{"\"Concept\"", ",", "\"Person::93r37\""}], "]"}],
     "\"Entity[\\\"Concept\\\", \\\"Person::93r37\\\"]\"","\"concept\""},
    "Entity"]}], "}"}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[15]=",ExpressionUUID->"fba8ba62-03f1-4135-9648-f20fb5f94030"]
}, Open  ]],

Cell[TextData[{
 ButtonBox["ImageIdentify",
  BaseStyle->"Link"],
 " normally just gives what it thinks is the most likely identification. You \
can tell it, though, to give a list of possible identifications, starting \
from the most likely. Here are the top 10 possible identifications, in all \
categories."
}], "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"c86528e9-c52a-40a8-82e9-baaf7aaf571e"],

Cell[TextData[{
 ButtonBox["ImageIdentify",
  BaseStyle->"Link"],
 " thinks this might be a cheetah, but it\[CloseCurlyQuote]s more likely to \
be a lion, or it could be a dog:"
}], "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"baca2076-a519-4bf2-a586-8a2a423afacd"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ImageIdentify", "[", 
  RowBox[{
   GraphicsBox[
    TagBox[RasterBox[CompressedData["
1:eJxc21d3I2ea4PnenZu93K+wV22qVFJ6QxLeew9EIALem4CLQCDgDQmAIOG9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      "], {{0, 213}, {320, 0}}, {0, 255},
      ColorFunction->RGBColor],
     BoxForm`ImageTag[
     "Byte", ColorSpace -> "RGB", Interleaving -> False, Magnification -> 
      Automatic, MetaInformation -> Association["Exif" -> Association[]]],
     Selectable->False],
    DefaultBaseStyle->"ImageGraphics",
    ImageSize->{83.03125, Automatic},
    ImageSizeRaw->{320, 213},
    PlotRange->{{0, 320}, {0, 213}}], ",", "All", ",", "10"}], "]"}]], "Input",\

 Deletable->False,
 CellLabel->"In[16]:=",ExpressionUUID->"6382d58b-6626-4c59-8d46-a10f4cb09a5c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   TemplateBox[{"\"lion\"",RowBox[{"Entity", "[", 
       RowBox[{"\"Concept\"", ",", "\"KingOfBeasts::vrwm9\""}], "]"}],
     "\"Entity[\\\"Concept\\\", \\\"KingOfBeasts::vrwm9\\\"]\"","\"concept\""},
    "Entity"], ",", 
   TemplateBox[{"\"red wolf\"",RowBox[{"Entity", "[", 
       RowBox[{"\"Concept\"", ",", "\"CanisNiger::99p6d\""}], "]"}],
     "\"Entity[\\\"Concept\\\", \\\"CanisNiger::99p6d\\\"]\"","\"concept\""},
    "Entity"], ",", 
   TemplateBox[{"\"cheetah\"",RowBox[{"Entity", "[", 
       RowBox[{"\"Concept\"", ",", "\"AcinonyxJubatus::3g535\""}], "]"}],
     "\"Entity[\\\"Concept\\\", \\\"AcinonyxJubatus::3g535\\\"]\"",
     "\"concept\""},
    "Entity"], ",", 
   TemplateBox[{"\"wildcat\"",RowBox[{"Entity", "[", 
       RowBox[{"\"Concept\"", ",", "\"Wildcat::8x3q3\""}], "]"}],
     "\"Entity[\\\"Concept\\\", \\\"Wildcat::8x3q3\\\"]\"","\"concept\""},
    "Entity"], ",", 
   TemplateBox[{"\"domestic dog\"",RowBox[{"Entity", "[", 
       RowBox[{"\"Concept\"", ",", "\"CanisFamiliaris::597qc\""}], "]"}],
     "\"Entity[\\\"Concept\\\", \\\"CanisFamiliaris::597qc\\\"]\"",
     "\"concept\""},
    "Entity"], ",", 
   TemplateBox[{"\"striped hyena\"",RowBox[{"Entity", "[", 
       RowBox[{"\"Concept\"", ",", "\"HyaenaHyaena::3zrqj\""}], "]"}],
     "\"Entity[\\\"Concept\\\", \\\"HyaenaHyaena::3zrqj\\\"]\"","\"concept\""},
    "Entity"], ",", 
   TemplateBox[{"\"pine marten\"",RowBox[{"Entity", "[", 
       RowBox[{"\"Concept\"", ",", "\"MartesMartes::tp4m4\""}], "]"}],
     "\"Entity[\\\"Concept\\\", \\\"MartesMartes::tp4m4\\\"]\"","\"concept\""},
    "Entity"], ",", 
   TemplateBox[{"\"mountain lion\"",RowBox[{"Entity", "[", 
       RowBox[{"\"Concept\"", ",", "\"Cougar::7bc9f\""}], "]"}],
     "\"Entity[\\\"Concept\\\", \\\"Cougar::7bc9f\\\"]\"","\"concept\""},
    "Entity"], ",", 
   TemplateBox[{"\"working dog\"",RowBox[{"Entity", "[", 
       RowBox[{"\"Concept\"", ",", "\"WorkingDog::c84g3\""}], "]"}],
     "\"Entity[\\\"Concept\\\", \\\"WorkingDog::c84g3\\\"]\"","\"concept\""},
    "Entity"], ",", 
   TemplateBox[{"\"lynx\"",RowBox[{"Entity", "[", 
       RowBox[{"\"Concept\"", ",", "\"Catamount::q4f63\""}], "]"}],
     "\"Entity[\\\"Concept\\\", \\\"Catamount::q4f63\\\"]\"","\"concept\""},
    "Entity"]}], "}"}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[16]=",ExpressionUUID->"2b8e715a-8952-4748-a94b-8f282e228804"]
}, Open  ]],

Cell[TextData[{
 "When the image is sufficiently blurred, ",
 ButtonBox["ImageIdentify",
  BaseStyle->"Link"],
 " can have wild ideas about what it might be:"
}], "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:18",ExpressionUUID->"23487128-efe2-47d3-8c8e-053664cdda7b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ImageIdentify", "[", 
  RowBox[{
   GraphicsBox[
    TagBox[RasterBox[CompressedData["
1:eJyk3dd2G1m2qOndfW7OZb9Cv8OuSi9L7wlHeO89AhHw3ntvAh4gQVI2s2q/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      "], {{0, 213}, {320, 0}}, {0, 255},
      
      ColorFunction->RGBColor],
     BoxForm`ImageTag[
     "Byte", ColorSpace -> "RGB", Interleaving -> False, Magnification -> 
      Automatic, MetaInformation -> Association["Exif" -> Association[]]],
     Selectable->False],
    DefaultBaseStyle->"ImageGraphics",
    ImageSize->{83.03125, Automatic},
    ImageSizeRaw->{320, 213},
    PlotRange->{{0, 320}, {0, 213}}], ",", "All", ",", "10"}], "]"}]], "Input",\

 Deletable->False,
 CellLabel->"In[17]:=",ExpressionUUID->"a801d062-1990-49ee-8ac9-9aa7a38b8a06"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   TemplateBox[{"\"person\"",RowBox[{"Entity", "[", 
       RowBox[{"\"Concept\"", ",", "\"Person::93r37\""}], "]"}],
     "\"Entity[\\\"Concept\\\", \\\"Person::93r37\\\"]\"","\"concept\""},
    "Entity"], ",", 
   TemplateBox[{"\"domestic dog\"",RowBox[{"Entity", "[", 
       RowBox[{"\"Concept\"", ",", "\"CanisFamiliaris::597qc\""}], "]"}],
     "\"Entity[\\\"Concept\\\", \\\"CanisFamiliaris::597qc\\\"]\"",
     "\"concept\""},
    "Entity"], ",", 
   TemplateBox[{"\"edible fruit\"",RowBox[{"Entity", "[", 
       RowBox[{"\"Concept\"", ",", "\"EdibleFruit::5d4pn\""}], "]"}],
     "\"Entity[\\\"Concept\\\", \\\"EdibleFruit::5d4pn\\\"]\"","\"concept\""},
    
    "Entity"], ",", 
   TemplateBox[{"\"hunting dog\"",RowBox[{"Entity", "[", 
       RowBox[{"\"Concept\"", ",", "\"HuntingDog::qzst8\""}], "]"}],
     "\"Entity[\\\"Concept\\\", \\\"HuntingDog::qzst8\\\"]\"","\"concept\""},
    "Entity"], ",", 
   TemplateBox[{"\"cat\"",RowBox[{"Entity", "[", 
       RowBox[{"\"Concept\"", ",", "\"TrueCat::xpnb8\""}], "]"}],
     "\"Entity[\\\"Concept\\\", \\\"TrueCat::xpnb8\\\"]\"","\"concept\""},
    "Entity"], ",", 
   TemplateBox[{"\"berry\"",RowBox[{"Entity", "[", 
       RowBox[{"\"Concept\"", ",", "\"Berry::94p2t\""}], "]"}],
     "\"Entity[\\\"Concept\\\", \\\"Berry::94p2t\\\"]\"","\"concept\""},
    "Entity"], ",", 
   TemplateBox[{"\"terrier\"",RowBox[{"Entity", "[", 
       RowBox[{"\"Concept\"", ",", "\"Terrier::4s25s\""}], "]"}],
     "\"Entity[\\\"Concept\\\", \\\"Terrier::4s25s\\\"]\"","\"concept\""},
    "Entity"], ",", 
   TemplateBox[{"\"wildcat\"",RowBox[{"Entity", "[", 
       RowBox[{"\"Concept\"", ",", "\"Wildcat::8x3q3\""}], "]"}],
     "\"Entity[\\\"Concept\\\", \\\"Wildcat::8x3q3\\\"]\"","\"concept\""},
    "Entity"], ",", 
   TemplateBox[{"\"working dog\"",RowBox[{"Entity", "[", 
       RowBox[{"\"Concept\"", ",", "\"WorkingDog::c84g3\""}], "]"}],
     "\"Entity[\\\"Concept\\\", \\\"WorkingDog::c84g3\\\"]\"","\"concept\""},
    "Entity"], ",", 
   TemplateBox[{"\"soft-finned fish\"",RowBox[{"Entity", "[", 
       RowBox[{"\"Concept\"", ",", "\"Malacopterygian::7923r\""}], "]"}],
     "\"Entity[\\\"Concept\\\", \\\"Malacopterygian::7923r\\\"]\"",
     "\"concept\""},
    "Entity"]}], "}"}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[17]=",ExpressionUUID->"3aacbb05-489d-4d97-b946-af0a29357fb9"]
}, Open  ]],

Cell["\<\
In machine learning, one often gives training that explicitly says, for \
example, \[OpenCurlyDoubleQuote]this is a cheetah\[CloseCurlyDoubleQuote], \
\[OpenCurlyDoubleQuote]this is a lion\[CloseCurlyDoubleQuote]. But one also \
often just wants to automatically pick out categories of things without any \
specific training. \
\>", "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"2e670745-4ddc-41bd-8c56-8eb2751525fe"],

Cell[TextData[{
 "One way to start doing this is to take a collection of things\[LongDash]say \
colors\[LongDash]and then to find clusters of similar ones. This can be \
achieved using ",
 ButtonBox["FindClusters",
  BaseStyle->"Link"],
 "."
}], "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:19",ExpressionUUID->"89b69608-9e5d-4b61-8e89-823422a4bdcd"],

Cell["Collect \[OpenCurlyDoubleQuote]clusters\[CloseCurlyDoubleQuote] of \
similar colors into separate lists:", "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"b87a84b7-28e8-436f-be74-9c429491d4d8"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FindClusters", "[", 
  RowBox[{"{", 
   RowBox[{
    InterpretationBox[
     ButtonBox[
      TooltipBox[
       GraphicsBox[{
         {GrayLevel[0], RectangleBox[{0, 0}]}, 
         {GrayLevel[0], RectangleBox[{1, -1}]}, 
         {RGBColor[
          0.048175746346922704`, 0.8856231902848692, 0.002187262571789972], 
          RectangleBox[{0, -1}, {2, 1}]}},
        AspectRatio->1,
        Frame->True,
        FrameStyle->RGBColor[
         0.0321171642312818, 0.5904154601899129, 0.0014581750478599813`],
        FrameTicks->None,
        ImageSize->
         Dynamic[{
          Automatic, 
           1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
            Magnification])}],
        PlotRangePadding->None],
       "RGBColor[{0.048175746346922704, 0.8856231902848692, \
0.002187262571789972}]"],
      Appearance->None,
      BaseStyle->{},
      BaselinePosition->Baseline,
      ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
        If[
         Not[
          AbsoluteCurrentValue["Deployed"]], 
         SelectionMove[Typeset`box$, All, Expression]; 
         FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
         FrontEnd`Private`$ColorSelectorInitialColor = 
          RGBColor[
           0.048175746346922704`, 0.8856231902848692, 0.002187262571789972]; 
         FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
         MathLink`CallFrontEnd[
           FrontEnd`AttachCell[Typeset`box$, 
            FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
            Left, Top}, 
            "ClosingActions" -> {
             "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
      DefaultBaseStyle->{},
      Evaluator->Automatic,
      Method->"Preemptive"],
     RGBColor[{0.048175746346922704`, 0.8856231902848692, 
      0.002187262571789972}],
     Editable->False,
     Selectable->False], ",", 
    InterpretationBox[
     ButtonBox[
      TooltipBox[
       GraphicsBox[{
         {GrayLevel[0], RectangleBox[{0, 0}]}, 
         {GrayLevel[0], RectangleBox[{1, -1}]}, 
         {RGBColor[
          0.9543437880041175, 0.9364915417894851, 0.08314980598714755], 
          RectangleBox[{0, -1}, {2, 1}]}},
        AspectRatio->1,
        Frame->True,
        FrameStyle->RGBColor[
         0.636229192002745, 0.6243276945263234, 0.0554332039914317],
        FrameTicks->None,
        ImageSize->
         Dynamic[{
          Automatic, 
           1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
            Magnification])}],
        PlotRangePadding->None],
       "RGBColor[{0.9543437880041175, 0.9364915417894851, \
0.08314980598714755}]"],
      Appearance->None,
      BaseStyle->{},
      BaselinePosition->Baseline,
      ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
        If[
         Not[
          AbsoluteCurrentValue["Deployed"]], 
         SelectionMove[Typeset`box$, All, Expression]; 
         FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
         FrontEnd`Private`$ColorSelectorInitialColor = 
          RGBColor[
           0.9543437880041175, 0.9364915417894851, 0.08314980598714755]; 
         FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
         MathLink`CallFrontEnd[
           FrontEnd`AttachCell[Typeset`box$, 
            FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
            Left, Top}, 
            "ClosingActions" -> {
             "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
      DefaultBaseStyle->{},
      Evaluator->Automatic,
      Method->"Preemptive"],
     RGBColor[{0.9543437880041175, 0.9364915417894851, 0.08314980598714755}],
     Editable->False,
     Selectable->False], ",", 
    InterpretationBox[
     ButtonBox[
      TooltipBox[
       GraphicsBox[{
         {GrayLevel[0], RectangleBox[{0, 0}]}, 
         {GrayLevel[0], RectangleBox[{1, -1}]}, 
         {RGBColor[
          0.8527294202095301, 0.15459949958575997`, 0.08139444813034824], 
          RectangleBox[{0, -1}, {2, 1}]}},
        AspectRatio->1,
        Frame->True,
        FrameStyle->RGBColor[
         0.5684862801396868, 0.10306633305717332`, 0.054262965420232165`],
        FrameTicks->None,
        ImageSize->
         Dynamic[{
          Automatic, 
           1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
            Magnification])}],
        PlotRangePadding->None],
       "RGBColor[{0.8527294202095301, 0.15459949958575997, \
0.08139444813034824}]"],
      Appearance->None,
      BaseStyle->{},
      BaselinePosition->Baseline,
      ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
        If[
         Not[
          AbsoluteCurrentValue["Deployed"]], 
         SelectionMove[Typeset`box$, All, Expression]; 
         FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
         FrontEnd`Private`$ColorSelectorInitialColor = 
          RGBColor[
           0.8527294202095301, 0.15459949958575997`, 0.08139444813034824]; 
         FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
         MathLink`CallFrontEnd[
           FrontEnd`AttachCell[Typeset`box$, 
            FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
            Left, Top}, 
            "ClosingActions" -> {
             "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
      DefaultBaseStyle->{},
      Evaluator->Automatic,
      Method->"Preemptive"],
     RGBColor[{0.8527294202095301, 0.15459949958575997`, 0.08139444813034824}],
     Editable->False,
     Selectable->False], ",", 
    InterpretationBox[
     ButtonBox[
      TooltipBox[
       GraphicsBox[{
         {GrayLevel[0], RectangleBox[{0, 0}]}, 
         {GrayLevel[0], RectangleBox[{1, -1}]}, 
         {RGBColor[
          0.12965437429396431`, 0.8338364200576898, 0.16859742903104202`], 
          RectangleBox[{0, -1}, {2, 1}]}},
        AspectRatio->1,
        Frame->True,
        FrameStyle->RGBColor[
         0.08643624952930955, 0.5558909467051265, 0.11239828602069468`],
        FrameTicks->None,
        ImageSize->
         Dynamic[{
          Automatic, 
           1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
            Magnification])}],
        PlotRangePadding->None],
       "RGBColor[{0.12965437429396431, 0.8338364200576898, \
0.16859742903104202}]"],
      Appearance->None,
      BaseStyle->{},
      BaselinePosition->Baseline,
      ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
        If[
         Not[
          AbsoluteCurrentValue["Deployed"]], 
         SelectionMove[Typeset`box$, All, Expression]; 
         FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
         FrontEnd`Private`$ColorSelectorInitialColor = 
          RGBColor[
           0.12965437429396431`, 0.8338364200576898, 0.16859742903104202`]; 
         FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
         MathLink`CallFrontEnd[
           FrontEnd`AttachCell[Typeset`box$, 
            FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
            Left, Top}, 
            "ClosingActions" -> {
             "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
      DefaultBaseStyle->{},
      Evaluator->Automatic,
      Method->"Preemptive"],
     RGBColor[{0.12965437429396431`, 0.8338364200576898, 
      0.16859742903104202`}],
     Editable->False,
     Selectable->False], ",", 
    InterpretationBox[
     ButtonBox[
      TooltipBox[
       GraphicsBox[{
         {GrayLevel[0], RectangleBox[{0, 0}]}, 
         {GrayLevel[0], RectangleBox[{1, -1}]}, 
         {RGBColor[
          0.14189318640501342`, 0.8685451286121387, 0.10426943556314977`], 
          RectangleBox[{0, -1}, {2, 1}]}},
        AspectRatio->1,
        Frame->True,
        FrameStyle->RGBColor[
         0.09459545760334229, 0.5790300857414259, 0.06951295704209985],
        FrameTicks->None,
        ImageSize->
         Dynamic[{
          Automatic, 
           1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
            Magnification])}],
        PlotRangePadding->None],
       "RGBColor[{0.14189318640501342, 0.8685451286121387, \
0.10426943556314977}]"],
      Appearance->None,
      BaseStyle->{},
      BaselinePosition->Baseline,
      ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
        If[
         Not[
          AbsoluteCurrentValue["Deployed"]], 
         SelectionMove[Typeset`box$, All, Expression]; 
         FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
         FrontEnd`Private`$ColorSelectorInitialColor = 
          RGBColor[
           0.14189318640501342`, 0.8685451286121387, 0.10426943556314977`]; 
         FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
         MathLink`CallFrontEnd[
           FrontEnd`AttachCell[Typeset`box$, 
            FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
            Left, Top}, 
            "ClosingActions" -> {
             "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
      DefaultBaseStyle->{},
      Evaluator->Automatic,
      Method->"Preemptive"],
     RGBColor[{0.14189318640501342`, 0.8685451286121387, 
      0.10426943556314977`}],
     Editable->False,
     Selectable->False], ",", 
    InterpretationBox[
     ButtonBox[
      TooltipBox[
       GraphicsBox[{
         {GrayLevel[0], RectangleBox[{0, 0}]}, 
         {GrayLevel[0], RectangleBox[{1, -1}]}, 
         {RGBColor[
          0.9244703510275273, 0.001783470411052479, 0.14318146272477922`], 
          RectangleBox[{0, -1}, {2, 1}]}},
        AspectRatio->1,
        Frame->True,
        FrameStyle->RGBColor[
         0.6163135673516849, 0.0011889802740349862`, 0.09545430848318615],
        FrameTicks->None,
        ImageSize->
         Dynamic[{
          Automatic, 
           1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
            Magnification])}],
        PlotRangePadding->None],
       "RGBColor[{0.9244703510275273, 0.001783470411052479, \
0.14318146272477922}]"],
      Appearance->None,
      BaseStyle->{},
      BaselinePosition->Baseline,
      ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
        If[
         Not[
          AbsoluteCurrentValue["Deployed"]], 
         SelectionMove[Typeset`box$, All, Expression]; 
         FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
         FrontEnd`Private`$ColorSelectorInitialColor = 
          RGBColor[
           0.9244703510275273, 0.001783470411052479, 0.14318146272477922`]; 
         FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
         MathLink`CallFrontEnd[
           FrontEnd`AttachCell[Typeset`box$, 
            FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
            Left, Top}, 
            "ClosingActions" -> {
             "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
      DefaultBaseStyle->{},
      Evaluator->Automatic,
      Method->"Preemptive"],
     RGBColor[{0.9244703510275273, 0.001783470411052479, 
      0.14318146272477922`}],
     Editable->False,
     Selectable->False], ",", 
    InterpretationBox[
     ButtonBox[
      TooltipBox[
       GraphicsBox[{
         {GrayLevel[0], RectangleBox[{0, 0}]}, 
         {GrayLevel[0], RectangleBox[{1, -1}]}, 
         {RGBColor[
          0.8340523614444824, 0.038129646837010533`, 0.09354464468116397], 
          RectangleBox[{0, -1}, {2, 1}]}},
        AspectRatio->1,
        Frame->True,
        FrameStyle->RGBColor[
         0.5560349076296549, 0.025419764558007023`, 0.06236309645410931],
        FrameTicks->None,
        ImageSize->
         Dynamic[{
          Automatic, 
           1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
            Magnification])}],
        PlotRangePadding->None],
       "RGBColor[{0.8340523614444824, 0.038129646837010533, \
0.09354464468116397}]"],
      Appearance->None,
      BaseStyle->{},
      BaselinePosition->Baseline,
      ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
        If[
         Not[
          AbsoluteCurrentValue["Deployed"]], 
         SelectionMove[Typeset`box$, All, Expression]; 
         FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
         FrontEnd`Private`$ColorSelectorInitialColor = 
          RGBColor[
           0.8340523614444824, 0.038129646837010533`, 0.09354464468116397]; 
         FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
         MathLink`CallFrontEnd[
           FrontEnd`AttachCell[Typeset`box$, 
            FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
            Left, Top}, 
            "ClosingActions" -> {
             "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
      DefaultBaseStyle->{},
      Evaluator->Automatic,
      Method->"Preemptive"],
     RGBColor[{0.8340523614444824, 0.038129646837010533`, 
      0.09354464468116397}],
     Editable->False,
     Selectable->False], ",", 
    InterpretationBox[
     ButtonBox[
      TooltipBox[
       GraphicsBox[{
         {GrayLevel[0], RectangleBox[{0, 0}]}, 
         {GrayLevel[0], RectangleBox[{1, -1}]}, 
         {RGBColor[
          0.06423181065333894, 0.9361486399945784, 0.08411970647251821], 
          RectangleBox[{0, -1}, {2, 1}]}},
        AspectRatio->1,
        Frame->True,
        FrameStyle->RGBColor[
         0.042821207102225964`, 0.624099093329719, 0.05607980431501214],
        FrameTicks->None,
        ImageSize->
         Dynamic[{
          Automatic, 
           1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
            Magnification])}],
        PlotRangePadding->None],
       "RGBColor[{0.06423181065333894, 0.9361486399945784, \
0.08411970647251821}]"],
      Appearance->None,
      BaseStyle->{},
      BaselinePosition->Baseline,
      ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
        If[
         Not[
          AbsoluteCurrentValue["Deployed"]], 
         SelectionMove[Typeset`box$, All, Expression]; 
         FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
         FrontEnd`Private`$ColorSelectorInitialColor = 
          RGBColor[
           0.06423181065333894, 0.9361486399945784, 0.08411970647251821]; 
         FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
         MathLink`CallFrontEnd[
           FrontEnd`AttachCell[Typeset`box$, 
            FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
            Left, Top}, 
            "ClosingActions" -> {
             "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
      DefaultBaseStyle->{},
      Evaluator->Automatic,
      Method->"Preemptive"],
     RGBColor[{0.06423181065333894, 0.9361486399945784, 0.08411970647251821}],
     
     Editable->False,
     Selectable->False], ",", 
    InterpretationBox[
     ButtonBox[
      TooltipBox[
       GraphicsBox[{
         {GrayLevel[0], RectangleBox[{0, 0}]}, 
         {GrayLevel[0], RectangleBox[{1, -1}]}, 
         {RGBColor[
          0.8676164929883508, 0.8866580065099905, 0.024086278089002183`], 
          RectangleBox[{0, -1}, {2, 1}]}},
        AspectRatio->1,
        Frame->True,
        FrameStyle->RGBColor[
         0.5784109953255672, 0.5911053376733271, 0.016057518726001457`],
        FrameTicks->None,
        ImageSize->
         Dynamic[{
          Automatic, 
           1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
            Magnification])}],
        PlotRangePadding->None],
       "RGBColor[{0.8676164929883508, 0.8866580065099905, \
0.024086278089002183}]"],
      Appearance->None,
      BaseStyle->{},
      BaselinePosition->Baseline,
      ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
        If[
         Not[
          AbsoluteCurrentValue["Deployed"]], 
         SelectionMove[Typeset`box$, All, Expression]; 
         FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
         FrontEnd`Private`$ColorSelectorInitialColor = 
          RGBColor[
           0.8676164929883508, 0.8866580065099905, 0.024086278089002183`]; 
         FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
         MathLink`CallFrontEnd[
           FrontEnd`AttachCell[Typeset`box$, 
            FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
            Left, Top}, 
            "ClosingActions" -> {
             "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
      DefaultBaseStyle->{},
      Evaluator->Automatic,
      Method->"Preemptive"],
     RGBColor[{0.8676164929883508, 0.8866580065099905, 0.024086278089002183`}],
     Editable->False,
     Selectable->False], ",", 
    InterpretationBox[
     ButtonBox[
      TooltipBox[
       GraphicsBox[{
         {GrayLevel[0], RectangleBox[{0, 0}]}, 
         {GrayLevel[0], RectangleBox[{1, -1}]}, 
         {RGBColor[
          0.8577958146408966, 0.8374035340744639, 0.0071190816223388464`], 
          RectangleBox[{0, -1}, {2, 1}]}},
        AspectRatio->1,
        Frame->True,
        FrameStyle->RGBColor[
         0.5718638764272644, 0.5582690227163093, 0.004746054414892564],
        FrameTicks->None,
        ImageSize->
         Dynamic[{
          Automatic, 
           1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
            Magnification])}],
        PlotRangePadding->None],
       "RGBColor[{0.8577958146408966, 0.8374035340744639, \
0.0071190816223388464}]"],
      Appearance->None,
      BaseStyle->{},
      BaselinePosition->Baseline,
      ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
        If[
         Not[
          AbsoluteCurrentValue["Deployed"]], 
         SelectionMove[Typeset`box$, All, Expression]; 
         FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
         FrontEnd`Private`$ColorSelectorInitialColor = 
          RGBColor[
           0.8577958146408966, 0.8374035340744639, 0.0071190816223388464`]; 
         FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
         MathLink`CallFrontEnd[
           FrontEnd`AttachCell[Typeset`box$, 
            FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
            Left, Top}, 
            "ClosingActions" -> {
             "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
      DefaultBaseStyle->{},
      Evaluator->Automatic,
      Method->"Preemptive"],
     RGBColor[{0.8577958146408966, 0.8374035340744639, 
      0.0071190816223388464`}],
     Editable->False,
     Selectable->False], ",", 
    InterpretationBox[
     ButtonBox[
      TooltipBox[
       GraphicsBox[{
         {GrayLevel[0], RectangleBox[{0, 0}]}, 
         {GrayLevel[0], RectangleBox[{1, -1}]}, 
         {RGBColor[
          0.9967431643372854, 0.969475575859666, 0.12251095291379577`], 
          RectangleBox[{0, -1}, {2, 1}]}},
        AspectRatio->1,
        Frame->True,
        FrameStyle->RGBColor[
         0.6644954428915236, 0.6463170505731107, 0.08167396860919718],
        FrameTicks->None,
        ImageSize->
         Dynamic[{
          Automatic, 
           1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
            Magnification])}],
        PlotRangePadding->None],
       "RGBColor[{0.9967431643372854, 0.969475575859666, \
0.12251095291379577}]"],
      Appearance->None,
      BaseStyle->{},
      BaselinePosition->Baseline,
      ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
        If[
         Not[
          AbsoluteCurrentValue["Deployed"]], 
         SelectionMove[Typeset`box$, All, Expression]; 
         FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
         FrontEnd`Private`$ColorSelectorInitialColor = 
          RGBColor[
           0.9967431643372854, 0.969475575859666, 0.12251095291379577`]; 
         FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
         MathLink`CallFrontEnd[
           FrontEnd`AttachCell[Typeset`box$, 
            FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
            Left, Top}, 
            "ClosingActions" -> {
             "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
      DefaultBaseStyle->{},
      Evaluator->Automatic,
      Method->"Preemptive"],
     RGBColor[{0.9967431643372854, 0.969475575859666, 0.12251095291379577`}],
     Editable->False,
     Selectable->False], ",", 
    InterpretationBox[
     ButtonBox[
      TooltipBox[
       GraphicsBox[{
         {GrayLevel[0], RectangleBox[{0, 0}]}, 
         {GrayLevel[0], RectangleBox[{1, -1}]}, 
         {RGBColor[
          0.8543889209256321, 0.09697598692920356, 0.10750903324099509`], 
          RectangleBox[{0, -1}, {2, 1}]}},
        AspectRatio->1,
        Frame->True,
        FrameStyle->RGBColor[
         0.5695926139504215, 0.06465065795280238, 0.07167268882733006],
        FrameTicks->None,
        ImageSize->
         Dynamic[{
          Automatic, 
           1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
            Magnification])}],
        PlotRangePadding->None],
       "RGBColor[{0.8543889209256321, 0.09697598692920356, \
0.10750903324099509}]"],
      Appearance->None,
      BaseStyle->{},
      BaselinePosition->Baseline,
      ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
        If[
         Not[
          AbsoluteCurrentValue["Deployed"]], 
         SelectionMove[Typeset`box$, All, Expression]; 
         FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
         FrontEnd`Private`$ColorSelectorInitialColor = 
          RGBColor[
           0.8543889209256321, 0.09697598692920356, 0.10750903324099509`]; 
         FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
         MathLink`CallFrontEnd[
           FrontEnd`AttachCell[Typeset`box$, 
            FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
            Left, Top}, 
            "ClosingActions" -> {
             "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
      DefaultBaseStyle->{},
      Evaluator->Automatic,
      Method->"Preemptive"],
     RGBColor[{0.8543889209256321, 0.09697598692920356, 0.10750903324099509`}],
     Editable->False,
     Selectable->False], ",", 
    InterpretationBox[
     ButtonBox[
      TooltipBox[
       GraphicsBox[{
         {GrayLevel[0], RectangleBox[{0, 0}]}, 
         {GrayLevel[0], RectangleBox[{1, -1}]}, 
         {RGBColor[
          0.8500363984900003, 0.9263311671408848, 0.13924242858059316`], 
          RectangleBox[{0, -1}, {2, 1}]}},
        AspectRatio->1,
        Frame->True,
        FrameStyle->RGBColor[
         0.5666909323266669, 0.6175541114272566, 0.09282828572039545],
        FrameTicks->None,
        ImageSize->
         Dynamic[{
          Automatic, 
           1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
            Magnification])}],
        PlotRangePadding->None],
       "RGBColor[{0.8500363984900003, 0.9263311671408848, \
0.13924242858059316}]"],
      Appearance->None,
      BaseStyle->{},
      BaselinePosition->Baseline,
      ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
        If[
         Not[
          AbsoluteCurrentValue["Deployed"]], 
         SelectionMove[Typeset`box$, All, Expression]; 
         FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
         FrontEnd`Private`$ColorSelectorInitialColor = 
          RGBColor[
           0.8500363984900003, 0.9263311671408848, 0.13924242858059316`]; 
         FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
         MathLink`CallFrontEnd[
           FrontEnd`AttachCell[Typeset`box$, 
            FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
            Left, Top}, 
            "ClosingActions" -> {
             "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
      DefaultBaseStyle->{},
      Evaluator->Automatic,
      Method->"Preemptive"],
     RGBColor[{0.8500363984900003, 0.9263311671408848, 0.13924242858059316`}],
     
     Editable->False,
     Selectable->False], ",", 
    InterpretationBox[
     ButtonBox[
      TooltipBox[
       GraphicsBox[{
         {GrayLevel[0], RectangleBox[{0, 0}]}, 
         {GrayLevel[0], RectangleBox[{1, -1}]}, 
         {RGBColor[
          0.9879209034166253, 0.8377732017482453, 0.15613661869756118`], 
          RectangleBox[{0, -1}, {2, 1}]}},
        AspectRatio->1,
        Frame->True,
        FrameStyle->RGBColor[
         0.6586139356110836, 0.5585154678321635, 0.10409107913170745`],
        FrameTicks->None,
        ImageSize->
         Dynamic[{
          Automatic, 
           1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
            Magnification])}],
        PlotRangePadding->None],
       "RGBColor[{0.9879209034166253, 0.8377732017482453, \
0.15613661869756118}]"],
      Appearance->None,
      BaseStyle->{},
      BaselinePosition->Baseline,
      ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
        If[
         Not[
          AbsoluteCurrentValue["Deployed"]], 
         SelectionMove[Typeset`box$, All, Expression]; 
         FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
         FrontEnd`Private`$ColorSelectorInitialColor = 
          RGBColor[
           0.9879209034166253, 0.8377732017482453, 0.15613661869756118`]; 
         FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
         MathLink`CallFrontEnd[
           FrontEnd`AttachCell[Typeset`box$, 
            FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
            Left, Top}, 
            "ClosingActions" -> {
             "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
      DefaultBaseStyle->{},
      Evaluator->Automatic,
      Method->"Preemptive"],
     RGBColor[{0.9879209034166253, 0.8377732017482453, 0.15613661869756118`}],
     
     Editable->False,
     Selectable->False], ",", 
    InterpretationBox[
     ButtonBox[
      TooltipBox[
       GraphicsBox[{
         {GrayLevel[0], RectangleBox[{0, 0}]}, 
         {GrayLevel[0], RectangleBox[{1, -1}]}, 
         {RGBColor[
          0.9573167308698426, 0.1507116093826361, 0.09832234398916928], 
          RectangleBox[{0, -1}, {2, 1}]}},
        AspectRatio->1,
        Frame->True,
        FrameStyle->RGBColor[
         0.6382111539132285, 0.10047440625509074`, 0.06554822932611286],
        FrameTicks->None,
        ImageSize->
         Dynamic[{
          Automatic, 
           1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
            Magnification])}],
        PlotRangePadding->None],
       "RGBColor[{0.9573167308698426, 0.1507116093826361, \
0.09832234398916928}]"],
      Appearance->None,
      BaseStyle->{},
      BaselinePosition->Baseline,
      ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
        If[
         Not[
          AbsoluteCurrentValue["Deployed"]], 
         SelectionMove[Typeset`box$, All, Expression]; 
         FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
         FrontEnd`Private`$ColorSelectorInitialColor = 
          RGBColor[
           0.9573167308698426, 0.1507116093826361, 0.09832234398916928]; 
         FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
         MathLink`CallFrontEnd[
           FrontEnd`AttachCell[Typeset`box$, 
            FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
            Left, Top}, 
            "ClosingActions" -> {
             "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
      DefaultBaseStyle->{},
      Evaluator->Automatic,
      Method->"Preemptive"],
     RGBColor[{0.9573167308698426, 0.1507116093826361, 0.09832234398916928}],
     Editable->False,
     Selectable->False], ",", 
    InterpretationBox[
     ButtonBox[
      TooltipBox[
       GraphicsBox[{
         {GrayLevel[0], RectangleBox[{0, 0}]}, 
         {GrayLevel[0], RectangleBox[{1, -1}]}, 
         {RGBColor[
          0.04278634258158939, 0.9055378427790535, 0.0003309996431954121], 
          RectangleBox[{0, -1}, {2, 1}]}},
        AspectRatio->1,
        Frame->True,
        FrameStyle->RGBColor[
         0.028524228387726263`, 0.6036918951860357, 0.0002206664287969414],
        FrameTicks->None,
        ImageSize->
         Dynamic[{
          Automatic, 
           1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
            Magnification])}],
        PlotRangePadding->None],
       "RGBColor[{0.04278634258158939, 0.9055378427790535, \
0.0003309996431954121}]"],
      Appearance->None,
      BaseStyle->{},
      BaselinePosition->Baseline,
      ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
        If[
         Not[
          AbsoluteCurrentValue["Deployed"]], 
         SelectionMove[Typeset`box$, All, Expression]; 
         FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
         FrontEnd`Private`$ColorSelectorInitialColor = 
          RGBColor[
           0.04278634258158939, 0.9055378427790535, 0.0003309996431954121]; 
         FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
         MathLink`CallFrontEnd[
           FrontEnd`AttachCell[Typeset`box$, 
            FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
            Left, Top}, 
            "ClosingActions" -> {
             "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
      DefaultBaseStyle->{},
      Evaluator->Automatic,
      Method->"Preemptive"],
     RGBColor[{0.04278634258158939, 0.9055378427790535, 
      0.0003309996431954121}],
     Editable->False,
     Selectable->False], ",", 
    InterpretationBox[
     ButtonBox[
      TooltipBox[
       GraphicsBox[{
         {GrayLevel[0], RectangleBox[{0, 0}]}, 
         {GrayLevel[0], RectangleBox[{1, -1}]}, 
         {RGBColor[
          0.8058039405531526, 0.8318774133774354, 0.10151558699591279`], 
          RectangleBox[{0, -1}, {2, 1}]}},
        AspectRatio->1,
        Frame->True,
        FrameStyle->RGBColor[
         0.5372026270354351, 0.5545849422516236, 0.06767705799727519],
        FrameTicks->None,
        ImageSize->
         Dynamic[{
          Automatic, 
           1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
            Magnification])}],
        PlotRangePadding->None],
       "RGBColor[{0.8058039405531526, 0.8318774133774354, \
0.10151558699591279}]"],
      Appearance->None,
      BaseStyle->{},
      BaselinePosition->Baseline,
      ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
        If[
         Not[
          AbsoluteCurrentValue["Deployed"]], 
         SelectionMove[Typeset`box$, All, Expression]; 
         FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
         FrontEnd`Private`$ColorSelectorInitialColor = 
          RGBColor[
           0.8058039405531526, 0.8318774133774354, 0.10151558699591279`]; 
         FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
         MathLink`CallFrontEnd[
           FrontEnd`AttachCell[Typeset`box$, 
            FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
            Left, Top}, 
            "ClosingActions" -> {
             "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
      DefaultBaseStyle->{},
      Evaluator->Automatic,
      Method->"Preemptive"],
     RGBColor[{0.8058039405531526, 0.8318774133774354, 0.10151558699591279`}],
     
     Editable->False,
     Selectable->False], ",", 
    InterpretationBox[
     ButtonBox[
      TooltipBox[
       GraphicsBox[{
         {GrayLevel[0], RectangleBox[{0, 0}]}, 
         {GrayLevel[0], RectangleBox[{1, -1}]}, 
         {RGBColor[
          0.006814389873512461, 0.9336694049188562, 0.06907220235176909], 
          RectangleBox[{0, -1}, {2, 1}]}},
        AspectRatio->1,
        Frame->True,
        FrameStyle->RGBColor[
         0.004542926582341641, 0.6224462699459041, 0.04604813490117939],
        FrameTicks->None,
        ImageSize->
         Dynamic[{
          Automatic, 
           1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
            Magnification])}],
        PlotRangePadding->None],
       "RGBColor[{0.006814389873512461, 0.9336694049188562, \
0.06907220235176909}]"],
      Appearance->None,
      BaseStyle->{},
      BaselinePosition->Baseline,
      ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
        If[
         Not[
          AbsoluteCurrentValue["Deployed"]], 
         SelectionMove[Typeset`box$, All, Expression]; 
         FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
         FrontEnd`Private`$ColorSelectorInitialColor = 
          RGBColor[
           0.006814389873512461, 0.9336694049188562, 0.06907220235176909]; 
         FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
         MathLink`CallFrontEnd[
           FrontEnd`AttachCell[Typeset`box$, 
            FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
            Left, Top}, 
            "ClosingActions" -> {
             "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
      DefaultBaseStyle->{},
      Evaluator->Automatic,
      Method->"Preemptive"],
     RGBColor[{0.006814389873512461, 0.9336694049188562, 0.06907220235176909}],
     Editable->False,
     Selectable->False], ",", 
    InterpretationBox[
     ButtonBox[
      TooltipBox[
       GraphicsBox[{
         {GrayLevel[0], RectangleBox[{0, 0}]}, 
         {GrayLevel[0], RectangleBox[{1, -1}]}, 
         {RGBColor[
          0.9450158125329948, 0.9670907305400336, 0.05040029871534907], 
          RectangleBox[{0, -1}, {2, 1}]}},
        AspectRatio->1,
        Frame->True,
        FrameStyle->RGBColor[
         0.6300105416886632, 0.6447271536933558, 0.033600199143566045`],
        FrameTicks->None,
        ImageSize->
         Dynamic[{
          Automatic, 
           1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
            Magnification])}],
        PlotRangePadding->None],
       "RGBColor[{0.9450158125329948, 0.9670907305400336, \
0.05040029871534907}]"],
      Appearance->None,
      BaseStyle->{},
      BaselinePosition->Baseline,
      ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
        If[
         Not[
          AbsoluteCurrentValue["Deployed"]], 
         SelectionMove[Typeset`box$, All, Expression]; 
         FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
         FrontEnd`Private`$ColorSelectorInitialColor = 
          RGBColor[
           0.9450158125329948, 0.9670907305400336, 0.05040029871534907]; 
         FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
         MathLink`CallFrontEnd[
           FrontEnd`AttachCell[Typeset`box$, 
            FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
            Left, Top}, 
            "ClosingActions" -> {
             "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
      DefaultBaseStyle->{},
      Evaluator->Automatic,
      Method->"Preemptive"],
     RGBColor[{0.9450158125329948, 0.9670907305400336, 0.05040029871534907}],
     Editable->False,
     Selectable->False], ",", 
    InterpretationBox[
     ButtonBox[
      TooltipBox[
       GraphicsBox[{
         {GrayLevel[0], RectangleBox[{0, 0}]}, 
         {GrayLevel[0], RectangleBox[{1, -1}]}, 
         {RGBColor[
          0.9752641706478989, 0.8013981246170678, 0.10899973580393796`], 
          RectangleBox[{0, -1}, {2, 1}]}},
        AspectRatio->1,
        Frame->True,
        FrameStyle->RGBColor[
         0.650176113765266, 0.5342654164113786, 0.07266649053595864],
        FrameTicks->None,
        ImageSize->
         Dynamic[{
          Automatic, 
           1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
            Magnification])}],
        PlotRangePadding->None],
       "RGBColor[{0.9752641706478989, 0.8013981246170678, \
0.10899973580393796}]"],
      Appearance->None,
      BaseStyle->{},
      BaselinePosition->Baseline,
      ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
        If[
         Not[
          AbsoluteCurrentValue["Deployed"]], 
         SelectionMove[Typeset`box$, All, Expression]; 
         FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
         FrontEnd`Private`$ColorSelectorInitialColor = 
          RGBColor[
           0.9752641706478989, 0.8013981246170678, 0.10899973580393796`]; 
         FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
         MathLink`CallFrontEnd[
           FrontEnd`AttachCell[Typeset`box$, 
            FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
            Left, Top}, 
            "ClosingActions" -> {
             "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
      DefaultBaseStyle->{},
      Evaluator->Automatic,
      Method->"Preemptive"],
     RGBColor[{0.9752641706478989, 0.8013981246170678, 0.10899973580393796`}],
     
     Editable->False,
     Selectable->False], ",", 
    InterpretationBox[
     ButtonBox[
      TooltipBox[
       GraphicsBox[{
         {GrayLevel[0], RectangleBox[{0, 0}]}, 
         {GrayLevel[0], RectangleBox[{1, -1}]}, 
         {RGBColor[
          0.16590548598015492`, 0.9015045495499641, 0.09828783196817376], 
          RectangleBox[{0, -1}, {2, 1}]}},
        AspectRatio->1,
        Frame->True,
        FrameStyle->RGBColor[
         0.11060365732010329`, 0.6010030330333094, 0.06552522131211584],
        FrameTicks->None,
        ImageSize->
         Dynamic[{
          Automatic, 
           1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
            Magnification])}],
        PlotRangePadding->None],
       "RGBColor[{0.16590548598015492, 0.9015045495499641, \
0.09828783196817376}]"],
      Appearance->None,
      BaseStyle->{},
      BaselinePosition->Baseline,
      ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
        If[
         Not[
          AbsoluteCurrentValue["Deployed"]], 
         SelectionMove[Typeset`box$, All, Expression]; 
         FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
         FrontEnd`Private`$ColorSelectorInitialColor = 
          RGBColor[
           0.16590548598015492`, 0.9015045495499641, 0.09828783196817376]; 
         FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
         MathLink`CallFrontEnd[
           FrontEnd`AttachCell[Typeset`box$, 
            FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
            Left, Top}, 
            "ClosingActions" -> {
             "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
      DefaultBaseStyle->{},
      Evaluator->Automatic,
      Method->"Preemptive"],
     RGBColor[{0.16590548598015492`, 0.9015045495499641, 0.09828783196817376}],
     Editable->False,
     Selectable->False], ",", 
    InterpretationBox[
     ButtonBox[
      TooltipBox[
       GraphicsBox[{
         {GrayLevel[0], RectangleBox[{0, 0}]}, 
         {GrayLevel[0], RectangleBox[{1, -1}]}, 
         {RGBColor[
          0.10048980936842117`, 0.9171495192304465, 0.16131399976146749`], 
          RectangleBox[{0, -1}, {2, 1}]}},
        AspectRatio->1,
        Frame->True,
        FrameStyle->RGBColor[
         0.06699320624561411, 0.6114330128202977, 0.10754266650764499`],
        FrameTicks->None,
        ImageSize->
         Dynamic[{
          Automatic, 
           1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
            Magnification])}],
        PlotRangePadding->None],
       "RGBColor[{0.10048980936842117, 0.9171495192304465, \
0.16131399976146749}]"],
      Appearance->None,
      BaseStyle->{},
      BaselinePosition->Baseline,
      ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
        If[
         Not[
          AbsoluteCurrentValue["Deployed"]], 
         SelectionMove[Typeset`box$, All, Expression]; 
         FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
         FrontEnd`Private`$ColorSelectorInitialColor = 
          RGBColor[
           0.10048980936842117`, 0.9171495192304465, 0.16131399976146749`]; 
         FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
         MathLink`CallFrontEnd[
           FrontEnd`AttachCell[Typeset`box$, 
            FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
            Left, Top}, 
            "ClosingActions" -> {
             "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
      DefaultBaseStyle->{},
      Evaluator->Automatic,
      Method->"Preemptive"],
     RGBColor[{0.10048980936842117`, 0.9171495192304465, 
      0.16131399976146749`}],
     Editable->False,
     Selectable->False]}], "}"}], "]"}]], "Input",
 Deletable->False,
 GraphicsBoxOptions->{BaselinePosition->Scaled[0.1]},
 CellLabel->"In[18]:=",ExpressionUUID->"fe017016-2c55-4e4d-a60c-2b0db24d5c41"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{
          {GrayLevel[0], RectangleBox[{0, 0}]}, 
          {GrayLevel[0], RectangleBox[{1, -1}]}, 
          {RGBColor[
           0.048175746346922704`, 0.8856231902848692, 0.002187262571789972], 
           RectangleBox[{0, -1}, {2, 1}]}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[
          0.0321171642312818, 0.5904154601899129, 0.0014581750478599813`],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[{0.048175746346922704, 0.8856231902848692, \
0.002187262571789972}]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = 
           RGBColor[
            0.048175746346922704`, 0.8856231902848692, 0.002187262571789972]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[{0.048175746346922704`, 0.8856231902848692, 
       0.002187262571789972}],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{
          {GrayLevel[0], RectangleBox[{0, 0}]}, 
          {GrayLevel[0], RectangleBox[{1, -1}]}, 
          {RGBColor[
           0.12965437429396431`, 0.8338364200576898, 0.16859742903104202`], 
           RectangleBox[{0, -1}, {2, 1}]}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[
          0.08643624952930955, 0.5558909467051265, 0.11239828602069468`],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[{0.12965437429396431, 0.8338364200576898, \
0.16859742903104202}]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = 
           RGBColor[
            0.12965437429396431`, 0.8338364200576898, 0.16859742903104202`]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[{0.12965437429396431`, 0.8338364200576898, 
       0.16859742903104202`}],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{
          {GrayLevel[0], RectangleBox[{0, 0}]}, 
          {GrayLevel[0], RectangleBox[{1, -1}]}, 
          {RGBColor[
           0.14189318640501342`, 0.8685451286121387, 0.10426943556314977`], 
           RectangleBox[{0, -1}, {2, 1}]}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[
          0.09459545760334229, 0.5790300857414259, 0.06951295704209985],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[{0.14189318640501342, 0.8685451286121387, \
0.10426943556314977}]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = 
           RGBColor[
            0.14189318640501342`, 0.8685451286121387, 0.10426943556314977`]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[{0.14189318640501342`, 0.8685451286121387, 
       0.10426943556314977`}],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{
          {GrayLevel[0], RectangleBox[{0, 0}]}, 
          {GrayLevel[0], RectangleBox[{1, -1}]}, 
          {RGBColor[
           0.06423181065333894, 0.9361486399945784, 0.08411970647251821], 
           RectangleBox[{0, -1}, {2, 1}]}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[
          0.042821207102225964`, 0.624099093329719, 0.05607980431501214],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[{0.06423181065333894, 0.9361486399945784, \
0.08411970647251821}]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = 
           RGBColor[
            0.06423181065333894, 0.9361486399945784, 0.08411970647251821]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[{0.06423181065333894, 0.9361486399945784, 0.08411970647251821}],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{
          {GrayLevel[0], RectangleBox[{0, 0}]}, 
          {GrayLevel[0], RectangleBox[{1, -1}]}, 
          {RGBColor[
           0.04278634258158939, 0.9055378427790535, 0.0003309996431954121], 
           RectangleBox[{0, -1}, {2, 1}]}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[
          0.028524228387726263`, 0.6036918951860357, 0.0002206664287969414],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[{0.04278634258158939, 0.9055378427790535, \
0.0003309996431954121}]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = 
           RGBColor[
            0.04278634258158939, 0.9055378427790535, 0.0003309996431954121]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[{0.04278634258158939, 0.9055378427790535, 
       0.0003309996431954121}],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{
          {GrayLevel[0], RectangleBox[{0, 0}]}, 
          {GrayLevel[0], RectangleBox[{1, -1}]}, 
          {RGBColor[
           0.006814389873512461, 0.9336694049188562, 0.06907220235176909], 
           RectangleBox[{0, -1}, {2, 1}]}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[
          0.004542926582341641, 0.6224462699459041, 0.04604813490117939],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[{0.006814389873512461, 0.9336694049188562, \
0.06907220235176909}]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = 
           RGBColor[
            0.006814389873512461, 0.9336694049188562, 0.06907220235176909]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[{0.006814389873512461, 0.9336694049188562, 
       0.06907220235176909}],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{
          {GrayLevel[0], RectangleBox[{0, 0}]}, 
          {GrayLevel[0], RectangleBox[{1, -1}]}, 
          {RGBColor[
           0.16590548598015492`, 0.9015045495499641, 0.09828783196817376], 
           RectangleBox[{0, -1}, {2, 1}]}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[
          0.11060365732010329`, 0.6010030330333094, 0.06552522131211584],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[{0.16590548598015492, 0.9015045495499641, \
0.09828783196817376}]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = 
           RGBColor[
            0.16590548598015492`, 0.9015045495499641, 0.09828783196817376]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[{0.16590548598015492`, 0.9015045495499641, 
       0.09828783196817376}],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{
          {GrayLevel[0], RectangleBox[{0, 0}]}, 
          {GrayLevel[0], RectangleBox[{1, -1}]}, 
          {RGBColor[
           0.10048980936842117`, 0.9171495192304465, 0.16131399976146749`], 
           RectangleBox[{0, -1}, {2, 1}]}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[
          0.06699320624561411, 0.6114330128202977, 0.10754266650764499`],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[{0.10048980936842117, 0.9171495192304465, \
0.16131399976146749}]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = 
           RGBColor[
            0.10048980936842117`, 0.9171495192304465, 0.16131399976146749`]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[{0.10048980936842117`, 0.9171495192304465, 
       0.16131399976146749`}],
      Editable->False,
      Selectable->False]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{
          {GrayLevel[0], RectangleBox[{0, 0}]}, 
          {GrayLevel[0], RectangleBox[{1, -1}]}, 
          {RGBColor[
           0.9543437880041175, 0.9364915417894851, 0.08314980598714755], 
           RectangleBox[{0, -1}, {2, 1}]}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[
          0.636229192002745, 0.6243276945263234, 0.0554332039914317],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[{0.9543437880041175, 0.9364915417894851, \
0.08314980598714755}]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = 
           RGBColor[
            0.9543437880041175, 0.9364915417894851, 0.08314980598714755]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[{0.9543437880041175, 0.9364915417894851, 0.08314980598714755}],
      
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{
          {GrayLevel[0], RectangleBox[{0, 0}]}, 
          {GrayLevel[0], RectangleBox[{1, -1}]}, 
          {RGBColor[
           0.8676164929883508, 0.8866580065099905, 0.024086278089002183`], 
           RectangleBox[{0, -1}, {2, 1}]}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[
          0.5784109953255672, 0.5911053376733271, 0.016057518726001457`],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[{0.8676164929883508, 0.8866580065099905, \
0.024086278089002183}]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = 
           RGBColor[
            0.8676164929883508, 0.8866580065099905, 0.024086278089002183`]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[{0.8676164929883508, 0.8866580065099905, 
       0.024086278089002183`}],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{
          {GrayLevel[0], RectangleBox[{0, 0}]}, 
          {GrayLevel[0], RectangleBox[{1, -1}]}, 
          {RGBColor[
           0.8577958146408966, 0.8374035340744639, 0.0071190816223388464`], 
           RectangleBox[{0, -1}, {2, 1}]}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[
          0.5718638764272644, 0.5582690227163093, 0.004746054414892564],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[{0.8577958146408966, 0.8374035340744639, \
0.0071190816223388464}]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = 
           RGBColor[
            0.8577958146408966, 0.8374035340744639, 0.0071190816223388464`]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[{0.8577958146408966, 0.8374035340744639, 
       0.0071190816223388464`}],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{
          {GrayLevel[0], RectangleBox[{0, 0}]}, 
          {GrayLevel[0], RectangleBox[{1, -1}]}, 
          {RGBColor[
           0.9967431643372854, 0.969475575859666, 0.12251095291379577`], 
           RectangleBox[{0, -1}, {2, 1}]}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[
          0.6644954428915236, 0.6463170505731107, 0.08167396860919718],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[{0.9967431643372854, 0.969475575859666, \
0.12251095291379577}]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = 
           RGBColor[
            0.9967431643372854, 0.969475575859666, 0.12251095291379577`]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[{0.9967431643372854, 0.969475575859666, 0.12251095291379577`}],
      
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{
          {GrayLevel[0], RectangleBox[{0, 0}]}, 
          {GrayLevel[0], RectangleBox[{1, -1}]}, 
          {RGBColor[
           0.8500363984900003, 0.9263311671408848, 0.13924242858059316`], 
           RectangleBox[{0, -1}, {2, 1}]}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[
          0.5666909323266669, 0.6175541114272566, 0.09282828572039545],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[{0.8500363984900003, 0.9263311671408848, \
0.13924242858059316}]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = 
           RGBColor[
            0.8500363984900003, 0.9263311671408848, 0.13924242858059316`]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[{0.8500363984900003, 0.9263311671408848, 0.13924242858059316`}],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{
          {GrayLevel[0], RectangleBox[{0, 0}]}, 
          {GrayLevel[0], RectangleBox[{1, -1}]}, 
          {RGBColor[
           0.8058039405531526, 0.8318774133774354, 0.10151558699591279`], 
           RectangleBox[{0, -1}, {2, 1}]}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[
          0.5372026270354351, 0.5545849422516236, 0.06767705799727519],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[{0.8058039405531526, 0.8318774133774354, \
0.10151558699591279}]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = 
           RGBColor[
            0.8058039405531526, 0.8318774133774354, 0.10151558699591279`]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[{0.8058039405531526, 0.8318774133774354, 0.10151558699591279`}],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{
          {GrayLevel[0], RectangleBox[{0, 0}]}, 
          {GrayLevel[0], RectangleBox[{1, -1}]}, 
          {RGBColor[
           0.9450158125329948, 0.9670907305400336, 0.05040029871534907], 
           RectangleBox[{0, -1}, {2, 1}]}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[
          0.6300105416886632, 0.6447271536933558, 0.033600199143566045`],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[{0.9450158125329948, 0.9670907305400336, \
0.05040029871534907}]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = 
           RGBColor[
            0.9450158125329948, 0.9670907305400336, 0.05040029871534907]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[{0.9450158125329948, 0.9670907305400336, 0.05040029871534907}],
      
      Editable->False,
      Selectable->False]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{
          {GrayLevel[0], RectangleBox[{0, 0}]}, 
          {GrayLevel[0], RectangleBox[{1, -1}]}, 
          {RGBColor[
           0.8527294202095301, 0.15459949958575997`, 0.08139444813034824], 
           RectangleBox[{0, -1}, {2, 1}]}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[
          0.5684862801396868, 0.10306633305717332`, 0.054262965420232165`],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[{0.8527294202095301, 0.15459949958575997, \
0.08139444813034824}]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = 
           RGBColor[
            0.8527294202095301, 0.15459949958575997`, 0.08139444813034824]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[{0.8527294202095301, 0.15459949958575997`, 
       0.08139444813034824}],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{
          {GrayLevel[0], RectangleBox[{0, 0}]}, 
          {GrayLevel[0], RectangleBox[{1, -1}]}, 
          {RGBColor[
           0.9244703510275273, 0.001783470411052479, 0.14318146272477922`], 
           RectangleBox[{0, -1}, {2, 1}]}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[
          0.6163135673516849, 0.0011889802740349862`, 0.09545430848318615],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[{0.9244703510275273, 0.001783470411052479, \
0.14318146272477922}]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = 
           RGBColor[
            0.9244703510275273, 0.001783470411052479, 0.14318146272477922`]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[{0.9244703510275273, 0.001783470411052479, 
       0.14318146272477922`}],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{
          {GrayLevel[0], RectangleBox[{0, 0}]}, 
          {GrayLevel[0], RectangleBox[{1, -1}]}, 
          {RGBColor[
           0.8340523614444824, 0.038129646837010533`, 0.09354464468116397], 
           RectangleBox[{0, -1}, {2, 1}]}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[
          0.5560349076296549, 0.025419764558007023`, 0.06236309645410931],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[{0.8340523614444824, 0.038129646837010533, \
0.09354464468116397}]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = 
           RGBColor[
            0.8340523614444824, 0.038129646837010533`, 0.09354464468116397]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[{0.8340523614444824, 0.038129646837010533`, 
       0.09354464468116397}],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{
          {GrayLevel[0], RectangleBox[{0, 0}]}, 
          {GrayLevel[0], RectangleBox[{1, -1}]}, 
          {RGBColor[
           0.8543889209256321, 0.09697598692920356, 0.10750903324099509`], 
           RectangleBox[{0, -1}, {2, 1}]}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[
          0.5695926139504215, 0.06465065795280238, 0.07167268882733006],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[{0.8543889209256321, 0.09697598692920356, \
0.10750903324099509}]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = 
           RGBColor[
            0.8543889209256321, 0.09697598692920356, 0.10750903324099509`]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[{0.8543889209256321, 0.09697598692920356, 
       0.10750903324099509`}],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{
          {GrayLevel[0], RectangleBox[{0, 0}]}, 
          {GrayLevel[0], RectangleBox[{1, -1}]}, 
          {RGBColor[
           0.9573167308698426, 0.1507116093826361, 0.09832234398916928], 
           RectangleBox[{0, -1}, {2, 1}]}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[
          0.6382111539132285, 0.10047440625509074`, 0.06554822932611286],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[{0.9573167308698426, 0.1507116093826361, \
0.09832234398916928}]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = 
           RGBColor[
            0.9573167308698426, 0.1507116093826361, 0.09832234398916928]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[{0.9573167308698426, 0.1507116093826361, 0.09832234398916928}],
      
      Editable->False,
      Selectable->False]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{
          {GrayLevel[0], RectangleBox[{0, 0}]}, 
          {GrayLevel[0], RectangleBox[{1, -1}]}, 
          {RGBColor[
           0.9879209034166253, 0.8377732017482453, 0.15613661869756118`], 
           RectangleBox[{0, -1}, {2, 1}]}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[
          0.6586139356110836, 0.5585154678321635, 0.10409107913170745`],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[{0.9879209034166253, 0.8377732017482453, \
0.15613661869756118}]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = 
           RGBColor[
            0.9879209034166253, 0.8377732017482453, 0.15613661869756118`]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[{0.9879209034166253, 0.8377732017482453, 0.15613661869756118`}],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{
          {GrayLevel[0], RectangleBox[{0, 0}]}, 
          {GrayLevel[0], RectangleBox[{1, -1}]}, 
          {RGBColor[
           0.9752641706478989, 0.8013981246170678, 0.10899973580393796`], 
           RectangleBox[{0, -1}, {2, 1}]}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[
          0.650176113765266, 0.5342654164113786, 0.07266649053595864],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[{0.9752641706478989, 0.8013981246170678, \
0.10899973580393796}]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = 
           RGBColor[
            0.9752641706478989, 0.8013981246170678, 0.10899973580393796`]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[{0.9752641706478989, 0.8013981246170678, 0.10899973580393796`}],
      Editable->False,
      Selectable->False]}], "}"}]}], "}"}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 GraphicsBoxOptions->{BaselinePosition->Scaled[0.1]},
 CellLabel->"Out[18]=",ExpressionUUID->"7f8024c3-f173-4436-8976-f28b42888074"]
}, Open  ]],

Cell["\<\
You can get a different view by connecting each color to the three most \
similar colors in the list, then making a graph out of the connections. In \
the particular example here, there end up being three disconnected subgraphs.\
\
\>", "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->{
  "NearestNeighborGraph", 
   "LastCellOfAPage"},ExpressionUUID->"7aa2628a-dec4-4229-bdd3-de7c07c2ea36"],

Cell["\<\
Create a graph of connections based on nearness in \
\[OpenCurlyDoubleQuote]color space\[CloseCurlyDoubleQuote]:\
\>", "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->{
  "graph-with-disconnected-parts", 
   "i:20"},ExpressionUUID->"0402896f-5498-4406-a05a-985edbd3dde7"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"NearestNeighborGraph", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{
          {GrayLevel[0], RectangleBox[{0, 0}]}, 
          {GrayLevel[0], RectangleBox[{1, -1}]}, 
          {RGBColor[
           0.048175746346922704`, 0.8856231902848692, 0.002187262571789972], 
           RectangleBox[{0, -1}, {2, 1}]}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[
          0.0321171642312818, 0.5904154601899129, 0.0014581750478599813`],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[{0.048175746346922704, 0.8856231902848692, \
0.002187262571789972}]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = 
           RGBColor[
            0.048175746346922704`, 0.8856231902848692, 0.002187262571789972]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[{0.048175746346922704`, 0.8856231902848692, 
       0.002187262571789972}],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{
          {GrayLevel[0], RectangleBox[{0, 0}]}, 
          {GrayLevel[0], RectangleBox[{1, -1}]}, 
          {RGBColor[
           0.9543437880041175, 0.9364915417894851, 0.08314980598714755], 
           RectangleBox[{0, -1}, {2, 1}]}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[
          0.636229192002745, 0.6243276945263234, 0.0554332039914317],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[{0.9543437880041175, 0.9364915417894851, \
0.08314980598714755}]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = 
           RGBColor[
            0.9543437880041175, 0.9364915417894851, 0.08314980598714755]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[{0.9543437880041175, 0.9364915417894851, 0.08314980598714755}],
      
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{
          {GrayLevel[0], RectangleBox[{0, 0}]}, 
          {GrayLevel[0], RectangleBox[{1, -1}]}, 
          {RGBColor[
           0.8527294202095301, 0.15459949958575997`, 0.08139444813034824], 
           RectangleBox[{0, -1}, {2, 1}]}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[
          0.5684862801396868, 0.10306633305717332`, 0.054262965420232165`],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[{0.8527294202095301, 0.15459949958575997, \
0.08139444813034824}]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = 
           RGBColor[
            0.8527294202095301, 0.15459949958575997`, 0.08139444813034824]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[{0.8527294202095301, 0.15459949958575997`, 
       0.08139444813034824}],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{
          {GrayLevel[0], RectangleBox[{0, 0}]}, 
          {GrayLevel[0], RectangleBox[{1, -1}]}, 
          {RGBColor[
           0.12965437429396431`, 0.8338364200576898, 0.16859742903104202`], 
           RectangleBox[{0, -1}, {2, 1}]}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[
          0.08643624952930955, 0.5558909467051265, 0.11239828602069468`],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[{0.12965437429396431, 0.8338364200576898, \
0.16859742903104202}]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = 
           RGBColor[
            0.12965437429396431`, 0.8338364200576898, 0.16859742903104202`]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[{0.12965437429396431`, 0.8338364200576898, 
       0.16859742903104202`}],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{
          {GrayLevel[0], RectangleBox[{0, 0}]}, 
          {GrayLevel[0], RectangleBox[{1, -1}]}, 
          {RGBColor[
           0.14189318640501342`, 0.8685451286121387, 0.10426943556314977`], 
           RectangleBox[{0, -1}, {2, 1}]}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[
          0.09459545760334229, 0.5790300857414259, 0.06951295704209985],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[{0.14189318640501342, 0.8685451286121387, \
0.10426943556314977}]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = 
           RGBColor[
            0.14189318640501342`, 0.8685451286121387, 0.10426943556314977`]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[{0.14189318640501342`, 0.8685451286121387, 
       0.10426943556314977`}],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{
          {GrayLevel[0], RectangleBox[{0, 0}]}, 
          {GrayLevel[0], RectangleBox[{1, -1}]}, 
          {RGBColor[
           0.9244703510275273, 0.001783470411052479, 0.14318146272477922`], 
           RectangleBox[{0, -1}, {2, 1}]}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[
          0.6163135673516849, 0.0011889802740349862`, 0.09545430848318615],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[{0.9244703510275273, 0.001783470411052479, \
0.14318146272477922}]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = 
           RGBColor[
            0.9244703510275273, 0.001783470411052479, 0.14318146272477922`]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[{0.9244703510275273, 0.001783470411052479, 
       0.14318146272477922`}],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{
          {GrayLevel[0], RectangleBox[{0, 0}]}, 
          {GrayLevel[0], RectangleBox[{1, -1}]}, 
          {RGBColor[
           0.8340523614444824, 0.038129646837010533`, 0.09354464468116397], 
           RectangleBox[{0, -1}, {2, 1}]}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[
          0.5560349076296549, 0.025419764558007023`, 0.06236309645410931],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[{0.8340523614444824, 0.038129646837010533, \
0.09354464468116397}]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = 
           RGBColor[
            0.8340523614444824, 0.038129646837010533`, 0.09354464468116397]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[{0.8340523614444824, 0.038129646837010533`, 
       0.09354464468116397}],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{
          {GrayLevel[0], RectangleBox[{0, 0}]}, 
          {GrayLevel[0], RectangleBox[{1, -1}]}, 
          {RGBColor[
           0.06423181065333894, 0.9361486399945784, 0.08411970647251821], 
           RectangleBox[{0, -1}, {2, 1}]}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[
          0.042821207102225964`, 0.624099093329719, 0.05607980431501214],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[{0.06423181065333894, 0.9361486399945784, \
0.08411970647251821}]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = 
           RGBColor[
            0.06423181065333894, 0.9361486399945784, 0.08411970647251821]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[{0.06423181065333894, 0.9361486399945784, 0.08411970647251821}],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{
          {GrayLevel[0], RectangleBox[{0, 0}]}, 
          {GrayLevel[0], RectangleBox[{1, -1}]}, 
          {RGBColor[
           0.8676164929883508, 0.8866580065099905, 0.024086278089002183`], 
           RectangleBox[{0, -1}, {2, 1}]}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[
          0.5784109953255672, 0.5911053376733271, 0.016057518726001457`],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[{0.8676164929883508, 0.8866580065099905, \
0.024086278089002183}]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = 
           RGBColor[
            0.8676164929883508, 0.8866580065099905, 0.024086278089002183`]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[{0.8676164929883508, 0.8866580065099905, 
       0.024086278089002183`}],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{
          {GrayLevel[0], RectangleBox[{0, 0}]}, 
          {GrayLevel[0], RectangleBox[{1, -1}]}, 
          {RGBColor[
           0.8577958146408966, 0.8374035340744639, 0.0071190816223388464`], 
           RectangleBox[{0, -1}, {2, 1}]}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[
          0.5718638764272644, 0.5582690227163093, 0.004746054414892564],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[{0.8577958146408966, 0.8374035340744639, \
0.0071190816223388464}]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = 
           RGBColor[
            0.8577958146408966, 0.8374035340744639, 0.0071190816223388464`]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[{0.8577958146408966, 0.8374035340744639, 
       0.0071190816223388464`}],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{
          {GrayLevel[0], RectangleBox[{0, 0}]}, 
          {GrayLevel[0], RectangleBox[{1, -1}]}, 
          {RGBColor[
           0.9967431643372854, 0.969475575859666, 0.12251095291379577`], 
           RectangleBox[{0, -1}, {2, 1}]}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[
          0.6644954428915236, 0.6463170505731107, 0.08167396860919718],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[{0.9967431643372854, 0.969475575859666, \
0.12251095291379577}]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = 
           RGBColor[
            0.9967431643372854, 0.969475575859666, 0.12251095291379577`]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[{0.9967431643372854, 0.969475575859666, 0.12251095291379577`}],
      
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{
          {GrayLevel[0], RectangleBox[{0, 0}]}, 
          {GrayLevel[0], RectangleBox[{1, -1}]}, 
          {RGBColor[
           0.8543889209256321, 0.09697598692920356, 0.10750903324099509`], 
           RectangleBox[{0, -1}, {2, 1}]}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[
          0.5695926139504215, 0.06465065795280238, 0.07167268882733006],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[{0.8543889209256321, 0.09697598692920356, \
0.10750903324099509}]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = 
           RGBColor[
            0.8543889209256321, 0.09697598692920356, 0.10750903324099509`]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[{0.8543889209256321, 0.09697598692920356, 
       0.10750903324099509`}],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{
          {GrayLevel[0], RectangleBox[{0, 0}]}, 
          {GrayLevel[0], RectangleBox[{1, -1}]}, 
          {RGBColor[
           0.8500363984900003, 0.9263311671408848, 0.13924242858059316`], 
           RectangleBox[{0, -1}, {2, 1}]}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[
          0.5666909323266669, 0.6175541114272566, 0.09282828572039545],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[{0.8500363984900003, 0.9263311671408848, \
0.13924242858059316}]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = 
           RGBColor[
            0.8500363984900003, 0.9263311671408848, 0.13924242858059316`]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[{0.8500363984900003, 0.9263311671408848, 0.13924242858059316`}],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{
          {GrayLevel[0], RectangleBox[{0, 0}]}, 
          {GrayLevel[0], RectangleBox[{1, -1}]}, 
          {RGBColor[
           0.9879209034166253, 0.8377732017482453, 0.15613661869756118`], 
           RectangleBox[{0, -1}, {2, 1}]}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[
          0.6586139356110836, 0.5585154678321635, 0.10409107913170745`],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[{0.9879209034166253, 0.8377732017482453, \
0.15613661869756118}]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = 
           RGBColor[
            0.9879209034166253, 0.8377732017482453, 0.15613661869756118`]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[{0.9879209034166253, 0.8377732017482453, 0.15613661869756118`}],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{
          {GrayLevel[0], RectangleBox[{0, 0}]}, 
          {GrayLevel[0], RectangleBox[{1, -1}]}, 
          {RGBColor[
           0.9573167308698426, 0.1507116093826361, 0.09832234398916928], 
           RectangleBox[{0, -1}, {2, 1}]}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[
          0.6382111539132285, 0.10047440625509074`, 0.06554822932611286],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[{0.9573167308698426, 0.1507116093826361, \
0.09832234398916928}]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = 
           RGBColor[
            0.9573167308698426, 0.1507116093826361, 0.09832234398916928]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[{0.9573167308698426, 0.1507116093826361, 0.09832234398916928}],
      
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{
          {GrayLevel[0], RectangleBox[{0, 0}]}, 
          {GrayLevel[0], RectangleBox[{1, -1}]}, 
          {RGBColor[
           0.04278634258158939, 0.9055378427790535, 0.0003309996431954121], 
           RectangleBox[{0, -1}, {2, 1}]}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[
          0.028524228387726263`, 0.6036918951860357, 0.0002206664287969414],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[{0.04278634258158939, 0.9055378427790535, \
0.0003309996431954121}]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = 
           RGBColor[
            0.04278634258158939, 0.9055378427790535, 0.0003309996431954121]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[{0.04278634258158939, 0.9055378427790535, 
       0.0003309996431954121}],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{
          {GrayLevel[0], RectangleBox[{0, 0}]}, 
          {GrayLevel[0], RectangleBox[{1, -1}]}, 
          {RGBColor[
           0.8058039405531526, 0.8318774133774354, 0.10151558699591279`], 
           RectangleBox[{0, -1}, {2, 1}]}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[
          0.5372026270354351, 0.5545849422516236, 0.06767705799727519],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[{0.8058039405531526, 0.8318774133774354, \
0.10151558699591279}]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = 
           RGBColor[
            0.8058039405531526, 0.8318774133774354, 0.10151558699591279`]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[{0.8058039405531526, 0.8318774133774354, 0.10151558699591279`}],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{
          {GrayLevel[0], RectangleBox[{0, 0}]}, 
          {GrayLevel[0], RectangleBox[{1, -1}]}, 
          {RGBColor[
           0.006814389873512461, 0.9336694049188562, 0.06907220235176909], 
           RectangleBox[{0, -1}, {2, 1}]}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[
          0.004542926582341641, 0.6224462699459041, 0.04604813490117939],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[{0.006814389873512461, 0.9336694049188562, \
0.06907220235176909}]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = 
           RGBColor[
            0.006814389873512461, 0.9336694049188562, 0.06907220235176909]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[{0.006814389873512461, 0.9336694049188562, 
       0.06907220235176909}],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{
          {GrayLevel[0], RectangleBox[{0, 0}]}, 
          {GrayLevel[0], RectangleBox[{1, -1}]}, 
          {RGBColor[
           0.9450158125329948, 0.9670907305400336, 0.05040029871534907], 
           RectangleBox[{0, -1}, {2, 1}]}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[
          0.6300105416886632, 0.6447271536933558, 0.033600199143566045`],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[{0.9450158125329948, 0.9670907305400336, \
0.05040029871534907}]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = 
           RGBColor[
            0.9450158125329948, 0.9670907305400336, 0.05040029871534907]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[{0.9450158125329948, 0.9670907305400336, 0.05040029871534907}],
      
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{
          {GrayLevel[0], RectangleBox[{0, 0}]}, 
          {GrayLevel[0], RectangleBox[{1, -1}]}, 
          {RGBColor[
           0.9752641706478989, 0.8013981246170678, 0.10899973580393796`], 
           RectangleBox[{0, -1}, {2, 1}]}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[
          0.650176113765266, 0.5342654164113786, 0.07266649053595864],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[{0.9752641706478989, 0.8013981246170678, \
0.10899973580393796}]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = 
           RGBColor[
            0.9752641706478989, 0.8013981246170678, 0.10899973580393796`]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[{0.9752641706478989, 0.8013981246170678, 0.10899973580393796`}],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{
          {GrayLevel[0], RectangleBox[{0, 0}]}, 
          {GrayLevel[0], RectangleBox[{1, -1}]}, 
          {RGBColor[
           0.16590548598015492`, 0.9015045495499641, 0.09828783196817376], 
           RectangleBox[{0, -1}, {2, 1}]}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[
          0.11060365732010329`, 0.6010030330333094, 0.06552522131211584],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[{0.16590548598015492, 0.9015045495499641, \
0.09828783196817376}]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = 
           RGBColor[
            0.16590548598015492`, 0.9015045495499641, 0.09828783196817376]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[{0.16590548598015492`, 0.9015045495499641, 
       0.09828783196817376}],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{
          {GrayLevel[0], RectangleBox[{0, 0}]}, 
          {GrayLevel[0], RectangleBox[{1, -1}]}, 
          {RGBColor[
           0.10048980936842117`, 0.9171495192304465, 0.16131399976146749`], 
           RectangleBox[{0, -1}, {2, 1}]}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[
          0.06699320624561411, 0.6114330128202977, 0.10754266650764499`],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[{0.10048980936842117, 0.9171495192304465, \
0.16131399976146749}]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = 
           RGBColor[
            0.10048980936842117`, 0.9171495192304465, 0.16131399976146749`]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[{0.10048980936842117`, 0.9171495192304465, 
       0.16131399976146749`}],
      Editable->False,
      Selectable->False]}], "}"}], ",", "3", ",", 
   RowBox[{"VertexLabels", "\[Rule]", "All"}]}], "]"}]], "Input",
 Deletable->False,
 GraphicsBoxOptions->{BaselinePosition->Scaled[0.1]},
 CellLabel->"In[19]:=",ExpressionUUID->"d97d91b8-2294-4c96-84ef-bc29cd7debf9"],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{
       RGBColor[{0.048175746346922704`, 0.8856231902848692, 
        0.002187262571789972}], 
       RGBColor[{0.9543437880041175, 0.9364915417894851, 
        0.08314980598714755}], 
       RGBColor[{0.8527294202095301, 0.15459949958575997`, 
        0.08139444813034824}], 
       RGBColor[{0.12965437429396431`, 0.8338364200576898, 
        0.16859742903104202`}], 
       RGBColor[{0.14189318640501342`, 0.8685451286121387, 
        0.10426943556314977`}], 
       RGBColor[{0.9244703510275273, 0.001783470411052479, 
        0.14318146272477922`}], 
       RGBColor[{0.8340523614444824, 0.038129646837010533`, 
        0.09354464468116397}], 
       RGBColor[{0.06423181065333894, 0.9361486399945784, 
        0.08411970647251821}], 
       RGBColor[{0.8676164929883508, 0.8866580065099905, 
        0.024086278089002183`}], 
       RGBColor[{0.8577958146408966, 0.8374035340744639, 
        0.0071190816223388464`}], 
       RGBColor[{0.9967431643372854, 0.969475575859666, 
        0.12251095291379577`}], 
       RGBColor[{0.8543889209256321, 0.09697598692920356, 
        0.10750903324099509`}], 
       RGBColor[{0.8500363984900003, 0.9263311671408848, 
        0.13924242858059316`}], 
       RGBColor[{0.9879209034166253, 0.8377732017482453, 
        0.15613661869756118`}], 
       RGBColor[{0.9573167308698426, 0.1507116093826361, 
        0.09832234398916928}], 
       RGBColor[{0.04278634258158939, 0.9055378427790535, 
        0.0003309996431954121}], 
       RGBColor[{0.8058039405531526, 0.8318774133774354, 
        0.10151558699591279`}], 
       RGBColor[{0.006814389873512461, 0.9336694049188562, 
        0.06907220235176909}], 
       RGBColor[{0.9450158125329948, 0.9670907305400336, 
        0.05040029871534907}], 
       RGBColor[{0.9752641706478989, 0.8013981246170678, 
        0.10899973580393796`}], 
       RGBColor[{0.16590548598015492`, 0.9015045495499641, 
        0.09828783196817376}], 
       RGBColor[{0.10048980936842117`, 0.9171495192304465, 
        0.16131399976146749`}]}, {Null, 
       SparseArray[
       Automatic, {22, 22}, 0, {
        1, {{0, 6, 12, 15, 18, 22, 25, 28, 31, 37, 42, 45, 49, 52, 55, 58, 63,
           66, 69, 73, 76, 81, 86}, {{5}, {8}, {16}, {18}, {21}, {22}, {9}, {
          10}, {11}, {14}, {19}, {20}, {7}, {12}, {15}, {5}, {21}, {22}, {
          1}, {4}, {21}, {22}, {7}, {12}, {15}, {3}, {6}, {12}, {1}, {16}, {
          18}, {2}, {10}, {11}, {13}, {17}, {19}, {2}, {9}, {14}, {17}, {
          20}, {2}, {9}, {19}, {3}, {6}, {7}, {15}, {9}, {17}, {19}, {2}, {
          10}, {20}, {3}, {6}, {12}, {1}, {8}, {18}, {21}, {22}, {9}, {10}, {
          13}, {1}, {8}, {16}, {2}, {9}, {11}, {13}, {2}, {10}, {14}, {1}, {
          4}, {5}, {16}, {22}, {1}, {4}, {5}, {16}, {21}}}, Pattern}]}, {
      VertexLabels -> {All}}]]}, 
    TagBox[GraphicsGroupBox[{
       {Hue[0.6, 0.7, 0.5], Opacity[0.7], 
        {Arrowheads[0.], 
         ArrowBox[{{1.6181134503584524`, -3.6792412719415104`}, {
          2.9049729069214085`, -3.427239245696992}}, 0.04390366136190131]}, 
        {Arrowheads[0.], 
         ArrowBox[{{1.6181134503584524`, -3.6792412719415104`}, {
          0.4648511633541359, -4.2325440464552475`}}, 0.04390366136190131]}, 
        {Arrowheads[0.], 
         ArrowBox[{{1.6181134503584524`, -3.6792412719415104`}, {
          1.3700266696218917`, -4.285764605039754}}, 0.04390366136190131]}, 
        {Arrowheads[0.], 
         ArrowBox[{{1.6181134503584524`, -3.6792412719415104`}, {
          0.554186844464825, -3.5080754511825862`}}, 0.04390366136190131]}, 
        {Arrowheads[0.], 
         ArrowBox[{{1.6181134503584524`, -3.6792412719415104`}, {
          2.5077218652244078`, -4.380316734568815}}, 0.04390366136190131]}, 
        {Arrowheads[0.], 
         ArrowBox[{{1.6181134503584524`, -3.6792412719415104`}, {
          2.4353672087938216`, -3.839177553623694}}, 0.04390366136190131]}, 
        {Arrowheads[0.], 
         ArrowBox[{{2.2253063918664857`, -1.1710411563987322`}, {
          1.3924101425548994`, -1.5665478470396907`}}, 
          0.04390366136190131]}, 
        {Arrowheads[0.], 
         ArrowBox[{{2.2253063918664857`, -1.1710411563987322`}, {
          2.35378350863711, -1.995896708686483}}, 0.04390366136190131]}, 
        {Arrowheads[0.], 
         ArrowBox[{{2.2253063918664857`, -1.1710411563987322`}, {
          1.5060840467800003`, -0.4648511633541359}}, 0.04390366136190131]}, 
        {Arrowheads[0.], 
         ArrowBox[{{2.2253063918664857`, -1.1710411563987322`}, {
          3.2294827893937987`, -1.8961619949077049`}}, 
          0.04390366136190131]}, 
        {Arrowheads[0.], 
         ArrowBox[{{2.2253063918664857`, -1.1710411563987322`}, {
          0.9602326263625951, -0.9849055396098816}}, 0.04390366136190131]}, 
        {Arrowheads[0.], 
         ArrowBox[{{2.2253063918664857`, -1.1710411563987322`}, {
          3.223314906392934, -1.2651880018871549`}}, 0.04390366136190131]}, 
        {Arrowheads[0.], 
         ArrowBox[{{5.583543421526646, -0.4648511633541359}, {
          5.615643053752226, -1.6184830560834866`}}, 0.04390366136190131]}, 
        {Arrowheads[0.], 
         ArrowBox[{{5.583543421526646, -0.4648511633541359}, {
          5.022308187187053, -1.056787471678871}}, 0.04390366136190131]}, 
        {Arrowheads[0.], 
         ArrowBox[{{5.583543421526646, -0.4648511633541359}, {
          4.4286179868869135`, -0.4947314325582979}}, 0.04390366136190131]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.4989156601786418`, -4.095482422335041}, {
          2.9049729069214085`, -3.427239245696992}}, 0.04390366136190131]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.4989156601786418`, -4.095482422335041}, {
          2.5077218652244078`, -4.380316734568815}}, 0.04390366136190131]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.4989156601786418`, -4.095482422335041}, {
          2.4353672087938216`, -3.839177553623694}}, 0.04390366136190131]}, 
        {Arrowheads[0.], 
         ArrowBox[{{2.9049729069214085`, -3.427239245696992}, {
          2.5077218652244078`, -4.380316734568815}}, 0.04390366136190131]}, 
        {Arrowheads[0.], 
         ArrowBox[{{2.9049729069214085`, -3.427239245696992}, {
          2.4353672087938216`, -3.839177553623694}}, 0.04390366136190131]}, 
        {Arrowheads[0.], 
         ArrowBox[{{4.461954271213614, -1.6495546496175093`}, {
          5.615643053752226, -1.6184830560834866`}}, 0.04390366136190131]}, 
        {Arrowheads[0.], 
         ArrowBox[{{4.461954271213614, -1.6495546496175093`}, {
          5.022308187187053, -1.056787471678871}}, 0.04390366136190131]}, 
        {Arrowheads[0.], 
         ArrowBox[{{4.461954271213614, -1.6495546496175093`}, {
          4.4286179868869135`, -0.4947314325582979}}, 0.04390366136190131]}, 
        {Arrowheads[0.], 
         ArrowBox[{{5.615643053752226, -1.6184830560834866`}, {
          5.022308187187053, -1.056787471678871}}, 0.04390366136190131]}, 
        {Arrowheads[0.], 
         ArrowBox[{{0.4648511633541359, -4.2325440464552475`}, {
          1.3700266696218917`, -4.285764605039754}}, 0.04390366136190131]}, 
        {Arrowheads[0.], 
         ArrowBox[{{0.4648511633541359, -4.2325440464552475`}, {
          0.554186844464825, -3.5080754511825862`}}, 0.04390366136190131]}, 
        {Arrowheads[0.], 
         ArrowBox[{{1.3924101425548994`, -1.5665478470396907`}, {
          2.35378350863711, -1.995896708686483}}, 0.04390366136190131]}, 
        {Arrowheads[0.], 
         ArrowBox[{{1.3924101425548994`, -1.5665478470396907`}, {
          1.5060840467800003`, -0.4648511633541359}}, 0.04390366136190131]}, 
        {Arrowheads[0.], 
         ArrowBox[{{1.3924101425548994`, -1.5665478470396907`}, {
          0.4648511633541359, -1.8964778601993966`}}, 0.04390366136190131]}, 
        {Arrowheads[0.], 
         ArrowBox[{{1.3924101425548994`, -1.5665478470396907`}, {
          1.2626293529565484`, -2.49753691898872}}, 0.04390366136190131]}, 
        {Arrowheads[0.], 
         ArrowBox[{{1.3924101425548994`, -1.5665478470396907`}, {
          0.9602326263625951, -0.9849055396098816}}, 0.04390366136190131]}, 
        {Arrowheads[0.], 
         ArrowBox[{{2.35378350863711, -1.995896708686483}, {
          3.2294827893937987`, -1.8961619949077049`}}, 
          0.04390366136190131]}, 
        {Arrowheads[0.], 
         ArrowBox[{{2.35378350863711, -1.995896708686483}, {
          1.2626293529565484`, -2.49753691898872}}, 0.04390366136190131]}, 
        {Arrowheads[0.], 
         ArrowBox[{{2.35378350863711, -1.995896708686483}, {
          3.223314906392934, -1.2651880018871549`}}, 0.04390366136190131]}, 
        {Arrowheads[0.], 
         ArrowBox[{{1.5060840467800003`, -0.4648511633541359}, {
          0.9602326263625951, -0.9849055396098816}}, 0.04390366136190131]}, 
        {Arrowheads[0.], 
         ArrowBox[{{5.022308187187053, -1.056787471678871}, {
          4.4286179868869135`, -0.4947314325582979}}, 0.04390366136190131]}, 
        {Arrowheads[0.], 
         ArrowBox[{{0.4648511633541359, -1.8964778601993966`}, {
          1.2626293529565484`, -2.49753691898872}}, 0.04390366136190131]}, 
        {Arrowheads[0.], 
         ArrowBox[{{0.4648511633541359, -1.8964778601993966`}, {
          0.9602326263625951, -0.9849055396098816}}, 0.04390366136190131]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.2294827893937987`, -1.8961619949077049`}, {
          3.223314906392934, -1.2651880018871549`}}, 0.04390366136190131]}, 
        {Arrowheads[0.], 
         ArrowBox[{{1.3700266696218917`, -4.285764605039754}, {
          0.554186844464825, -3.5080754511825862`}}, 0.04390366136190131]}, 
        {Arrowheads[0.], 
         ArrowBox[{{1.3700266696218917`, -4.285764605039754}, {
          2.5077218652244078`, -4.380316734568815}}, 0.04390366136190131]}, 
        {Arrowheads[0.], 
         ArrowBox[{{1.3700266696218917`, -4.285764605039754}, {
          2.4353672087938216`, -3.839177553623694}}, 0.04390366136190131]}, 
        {Arrowheads[0.], 
         ArrowBox[{{2.5077218652244078`, -4.380316734568815}, {
          2.4353672087938216`, -3.839177553623694}}, 0.04390366136190131]}}, 
       {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
        0.7]}], {
         DiskBox[{1.6181134503584524, -3.6792412719415104}, 
          0.04390366136190131], InsetBox[
          InterpretationBox[
           ButtonBox[
            TooltipBox[
             GraphicsBox[{
               {GrayLevel[0], RectangleBox[{0, 0}]}, 
               {GrayLevel[0], RectangleBox[{1, -1}]}, 
               {RGBColor[
                0.048175746346922704`, 0.8856231902848692, 
                 0.002187262571789972], RectangleBox[{0, -1}, {2, 1}]}},
              AspectRatio->1,
              Frame->True,
              
              FrameStyle->RGBColor[
               0.0321171642312818, 0.5904154601899129, 0.0014581750478599813`],
              FrameTicks->None,
              
              ImageSize->
               Dynamic[{
                Automatic, 
                 1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                  Magnification])}],
              PlotRangePadding->None],
             
             "RGBColor[{0.048175746346922704, 0.8856231902848692, \
0.002187262571789972}]"],
            Appearance->None,
            BaseStyle->{},
            BaselinePosition->Baseline,
            ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
              If[
               Not[
                AbsoluteCurrentValue["Deployed"]], 
               SelectionMove[Typeset`box$, All, Expression]; 
               FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
               FrontEnd`Private`$ColorSelectorInitialColor = 
                RGBColor[
                 0.048175746346922704`, 0.8856231902848692, 
                  0.002187262571789972]; 
               FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
               MathLink`CallFrontEnd[
                 FrontEnd`AttachCell[Typeset`box$, 
                  FrontEndResource["RGBColorValueSelector"], {
                  0, {Left, Bottom}}, {Left, Top}, 
                  "ClosingActions" -> {
                   "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
            DefaultBaseStyle->{},
            Evaluator->Automatic,
            Method->"Preemptive"],
           
           RGBColor[{0.048175746346922704`, 0.8856231902848692, 
            0.002187262571789972}],
           Editable->False,
           Selectable->False], 
          Offset[{2, 2}, {1.6620171117203537, -3.635337610579609}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{2.2253063918664857, -1.1710411563987322}, 
          0.04390366136190131], InsetBox[
          InterpretationBox[
           ButtonBox[
            TooltipBox[
             GraphicsBox[{
               {GrayLevel[0], RectangleBox[{0, 0}]}, 
               {GrayLevel[0], RectangleBox[{1, -1}]}, 
               {RGBColor[
                0.9543437880041175, 0.9364915417894851, 0.08314980598714755], 
                RectangleBox[{0, -1}, {2, 1}]}},
              AspectRatio->1,
              Frame->True,
              
              FrameStyle->RGBColor[
               0.636229192002745, 0.6243276945263234, 0.0554332039914317],
              FrameTicks->None,
              
              ImageSize->
               Dynamic[{
                Automatic, 
                 1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                  Magnification])}],
              PlotRangePadding->None],
             
             "RGBColor[{0.9543437880041175, 0.9364915417894851, \
0.08314980598714755}]"],
            Appearance->None,
            BaseStyle->{},
            BaselinePosition->Baseline,
            ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
              If[
               Not[
                AbsoluteCurrentValue["Deployed"]], 
               SelectionMove[Typeset`box$, All, Expression]; 
               FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
               FrontEnd`Private`$ColorSelectorInitialColor = 
                RGBColor[
                 0.9543437880041175, 0.9364915417894851, 0.08314980598714755]; 
               FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
               MathLink`CallFrontEnd[
                 FrontEnd`AttachCell[Typeset`box$, 
                  FrontEndResource["RGBColorValueSelector"], {
                  0, {Left, Bottom}}, {Left, Top}, 
                  "ClosingActions" -> {
                   "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
            DefaultBaseStyle->{},
            Evaluator->Automatic,
            Method->"Preemptive"],
           
           RGBColor[{0.9543437880041175, 0.9364915417894851, 
            0.08314980598714755}],
           Editable->False,
           Selectable->False], 
          Offset[{2, 2}, {2.269210053228387, -1.127137495036831}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{5.583543421526646, -0.4648511633541359}, 
          0.04390366136190131], InsetBox[
          InterpretationBox[
           ButtonBox[
            TooltipBox[
             GraphicsBox[{
               {GrayLevel[0], RectangleBox[{0, 0}]}, 
               {GrayLevel[0], RectangleBox[{1, -1}]}, 
               {RGBColor[
                0.8527294202095301, 0.15459949958575997`, 
                 0.08139444813034824], RectangleBox[{0, -1}, {2, 1}]}},
              AspectRatio->1,
              Frame->True,
              
              FrameStyle->RGBColor[
               0.5684862801396868, 0.10306633305717332`, 
                0.054262965420232165`],
              FrameTicks->None,
              
              ImageSize->
               Dynamic[{
                Automatic, 
                 1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                  Magnification])}],
              PlotRangePadding->None],
             
             "RGBColor[{0.8527294202095301, 0.15459949958575997, \
0.08139444813034824}]"],
            Appearance->None,
            BaseStyle->{},
            BaselinePosition->Baseline,
            ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
              If[
               Not[
                AbsoluteCurrentValue["Deployed"]], 
               SelectionMove[Typeset`box$, All, Expression]; 
               FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
               FrontEnd`Private`$ColorSelectorInitialColor = 
                RGBColor[
                 0.8527294202095301, 0.15459949958575997`, 
                  0.08139444813034824]; 
               FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
               MathLink`CallFrontEnd[
                 FrontEnd`AttachCell[Typeset`box$, 
                  FrontEndResource["RGBColorValueSelector"], {
                  0, {Left, Bottom}}, {Left, Top}, 
                  "ClosingActions" -> {
                   "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
            DefaultBaseStyle->{},
            Evaluator->Automatic,
            Method->"Preemptive"],
           
           RGBColor[{0.8527294202095301, 0.15459949958575997`, 
            0.08139444813034824}],
           Editable->False,
           Selectable->False], 
          Offset[{2, 2}, {5.627447082888548, -0.4209475019922346}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{3.4989156601786418, -4.095482422335041}, 
          0.04390366136190131], InsetBox[
          InterpretationBox[
           ButtonBox[
            TooltipBox[
             GraphicsBox[{
               {GrayLevel[0], RectangleBox[{0, 0}]}, 
               {GrayLevel[0], RectangleBox[{1, -1}]}, 
               {RGBColor[
                0.12965437429396431`, 0.8338364200576898, 
                 0.16859742903104202`], RectangleBox[{0, -1}, {2, 1}]}},
              AspectRatio->1,
              Frame->True,
              
              FrameStyle->RGBColor[
               0.08643624952930955, 0.5558909467051265, 0.11239828602069468`],
              
              FrameTicks->None,
              
              ImageSize->
               Dynamic[{
                Automatic, 
                 1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                  Magnification])}],
              PlotRangePadding->None],
             
             "RGBColor[{0.12965437429396431, 0.8338364200576898, \
0.16859742903104202}]"],
            Appearance->None,
            BaseStyle->{},
            BaselinePosition->Baseline,
            ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
              If[
               Not[
                AbsoluteCurrentValue["Deployed"]], 
               SelectionMove[Typeset`box$, All, Expression]; 
               FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
               FrontEnd`Private`$ColorSelectorInitialColor = 
                RGBColor[
                 0.12965437429396431`, 0.8338364200576898, 
                  0.16859742903104202`]; 
               FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
               MathLink`CallFrontEnd[
                 FrontEnd`AttachCell[Typeset`box$, 
                  FrontEndResource["RGBColorValueSelector"], {
                  0, {Left, Bottom}}, {Left, Top}, 
                  "ClosingActions" -> {
                   "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
            DefaultBaseStyle->{},
            Evaluator->Automatic,
            Method->"Preemptive"],
           
           RGBColor[{0.12965437429396431`, 0.8338364200576898, 
            0.16859742903104202`}],
           Editable->False,
           Selectable->False], 
          Offset[{2, 2}, {3.5428193215405432, -4.05157876097314}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{2.9049729069214085, -3.427239245696992}, 
          0.04390366136190131], InsetBox[
          InterpretationBox[
           ButtonBox[
            TooltipBox[
             GraphicsBox[{
               {GrayLevel[0], RectangleBox[{0, 0}]}, 
               {GrayLevel[0], RectangleBox[{1, -1}]}, 
               {RGBColor[
                0.14189318640501342`, 0.8685451286121387, 
                 0.10426943556314977`], RectangleBox[{0, -1}, {2, 1}]}},
              AspectRatio->1,
              Frame->True,
              
              FrameStyle->RGBColor[
               0.09459545760334229, 0.5790300857414259, 0.06951295704209985],
              FrameTicks->None,
              
              ImageSize->
               Dynamic[{
                Automatic, 
                 1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                  Magnification])}],
              PlotRangePadding->None],
             
             "RGBColor[{0.14189318640501342, 0.8685451286121387, \
0.10426943556314977}]"],
            Appearance->None,
            BaseStyle->{},
            BaselinePosition->Baseline,
            ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
              If[
               Not[
                AbsoluteCurrentValue["Deployed"]], 
               SelectionMove[Typeset`box$, All, Expression]; 
               FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
               FrontEnd`Private`$ColorSelectorInitialColor = 
                RGBColor[
                 0.14189318640501342`, 0.8685451286121387, 
                  0.10426943556314977`]; 
               FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
               MathLink`CallFrontEnd[
                 FrontEnd`AttachCell[Typeset`box$, 
                  FrontEndResource["RGBColorValueSelector"], {
                  0, {Left, Bottom}}, {Left, Top}, 
                  "ClosingActions" -> {
                   "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
            DefaultBaseStyle->{},
            Evaluator->Automatic,
            Method->"Preemptive"],
           RGBColor[{0.14189318640501342`, 0.8685451286121387, 
            0.10426943556314977`}],
           Editable->False,
           Selectable->False], 
          Offset[{2, 2}, {2.94887656828331, -3.3833355843350903}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{4.461954271213614, -1.6495546496175093}, 
          0.04390366136190131], InsetBox[
          InterpretationBox[
           ButtonBox[
            TooltipBox[
             GraphicsBox[{
               {GrayLevel[0], RectangleBox[{0, 0}]}, 
               {GrayLevel[0], RectangleBox[{1, -1}]}, 
               {RGBColor[
                0.9244703510275273, 0.001783470411052479, 
                 0.14318146272477922`], RectangleBox[{0, -1}, {2, 1}]}},
              AspectRatio->1,
              Frame->True,
              
              FrameStyle->RGBColor[
               0.6163135673516849, 0.0011889802740349862`, 
                0.09545430848318615],
              FrameTicks->None,
              
              ImageSize->
               Dynamic[{
                Automatic, 
                 1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                  Magnification])}],
              PlotRangePadding->None],
             
             "RGBColor[{0.9244703510275273, 0.001783470411052479, \
0.14318146272477922}]"],
            Appearance->None,
            BaseStyle->{},
            BaselinePosition->Baseline,
            ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
              If[
               Not[
                AbsoluteCurrentValue["Deployed"]], 
               SelectionMove[Typeset`box$, All, Expression]; 
               FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
               FrontEnd`Private`$ColorSelectorInitialColor = 
                RGBColor[
                 0.9244703510275273, 0.001783470411052479, 
                  0.14318146272477922`]; 
               FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
               MathLink`CallFrontEnd[
                 FrontEnd`AttachCell[Typeset`box$, 
                  FrontEndResource["RGBColorValueSelector"], {
                  0, {Left, Bottom}}, {Left, Top}, 
                  "ClosingActions" -> {
                   "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
            DefaultBaseStyle->{},
            Evaluator->Automatic,
            Method->"Preemptive"],
           
           RGBColor[{0.9244703510275273, 0.001783470411052479, 
            0.14318146272477922`}],
           Editable->False,
           Selectable->False], 
          Offset[{2, 2}, {4.505857932575515, -1.605650988255608}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{5.615643053752226, -1.6184830560834866}, 
          0.04390366136190131], InsetBox[
          InterpretationBox[
           ButtonBox[
            TooltipBox[
             GraphicsBox[{
               {GrayLevel[0], RectangleBox[{0, 0}]}, 
               {GrayLevel[0], RectangleBox[{1, -1}]}, 
               {RGBColor[
                0.8340523614444824, 0.038129646837010533`, 
                 0.09354464468116397], RectangleBox[{0, -1}, {2, 1}]}},
              AspectRatio->1,
              Frame->True,
              
              FrameStyle->RGBColor[
               0.5560349076296549, 0.025419764558007023`, 0.06236309645410931],
              FrameTicks->None,
              
              ImageSize->
               Dynamic[{
                Automatic, 
                 1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                  Magnification])}],
              PlotRangePadding->None],
             
             "RGBColor[{0.8340523614444824, 0.038129646837010533, \
0.09354464468116397}]"],
            Appearance->None,
            BaseStyle->{},
            BaselinePosition->Baseline,
            ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
              If[
               Not[
                AbsoluteCurrentValue["Deployed"]], 
               SelectionMove[Typeset`box$, All, Expression]; 
               FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
               FrontEnd`Private`$ColorSelectorInitialColor = 
                RGBColor[
                 0.8340523614444824, 0.038129646837010533`, 
                  0.09354464468116397]; 
               FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
               MathLink`CallFrontEnd[
                 FrontEnd`AttachCell[Typeset`box$, 
                  FrontEndResource["RGBColorValueSelector"], {
                  0, {Left, Bottom}}, {Left, Top}, 
                  "ClosingActions" -> {
                   "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
            DefaultBaseStyle->{},
            Evaluator->Automatic,
            Method->"Preemptive"],
           
           RGBColor[{0.8340523614444824, 0.038129646837010533`, 
            0.09354464468116397}],
           Editable->False,
           Selectable->False], 
          Offset[{2, 2}, {5.659546715114128, -1.5745793947215854}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{0.4648511633541359, -4.2325440464552475}, 
          0.04390366136190131], InsetBox[
          InterpretationBox[
           ButtonBox[
            TooltipBox[
             GraphicsBox[{
               {GrayLevel[0], RectangleBox[{0, 0}]}, 
               {GrayLevel[0], RectangleBox[{1, -1}]}, 
               {RGBColor[
                0.06423181065333894, 0.9361486399945784, 0.08411970647251821],
                 RectangleBox[{0, -1}, {2, 1}]}},
              AspectRatio->1,
              Frame->True,
              
              FrameStyle->RGBColor[
               0.042821207102225964`, 0.624099093329719, 0.05607980431501214],
              
              FrameTicks->None,
              
              ImageSize->
               Dynamic[{
                Automatic, 
                 1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                  Magnification])}],
              PlotRangePadding->None],
             
             "RGBColor[{0.06423181065333894, 0.9361486399945784, \
0.08411970647251821}]"],
            Appearance->None,
            BaseStyle->{},
            BaselinePosition->Baseline,
            ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
              If[
               Not[
                AbsoluteCurrentValue["Deployed"]], 
               SelectionMove[Typeset`box$, All, Expression]; 
               FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
               FrontEnd`Private`$ColorSelectorInitialColor = 
                RGBColor[
                 0.06423181065333894, 0.9361486399945784, 
                  0.08411970647251821]; 
               FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
               MathLink`CallFrontEnd[
                 FrontEnd`AttachCell[Typeset`box$, 
                  FrontEndResource["RGBColorValueSelector"], {
                  0, {Left, Bottom}}, {Left, Top}, 
                  "ClosingActions" -> {
                   "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
            DefaultBaseStyle->{},
            Evaluator->Automatic,
            Method->"Preemptive"],
           
           RGBColor[{0.06423181065333894, 0.9361486399945784, 
            0.08411970647251821}],
           Editable->False,
           Selectable->False], 
          Offset[{2, 2}, {0.5087548247160372, -4.188640385093346}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{1.3924101425548994, -1.5665478470396907}, 
          0.04390366136190131], InsetBox[
          InterpretationBox[
           ButtonBox[
            TooltipBox[
             GraphicsBox[{
               {GrayLevel[0], RectangleBox[{0, 0}]}, 
               {GrayLevel[0], RectangleBox[{1, -1}]}, 
               {RGBColor[
                0.8676164929883508, 0.8866580065099905, 
                 0.024086278089002183`], RectangleBox[{0, -1}, {2, 1}]}},
              AspectRatio->1,
              Frame->True,
              
              FrameStyle->RGBColor[
               0.5784109953255672, 0.5911053376733271, 0.016057518726001457`],
              
              FrameTicks->None,
              
              ImageSize->
               Dynamic[{
                Automatic, 
                 1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                  Magnification])}],
              PlotRangePadding->None],
             
             "RGBColor[{0.8676164929883508, 0.8866580065099905, \
0.024086278089002183}]"],
            Appearance->None,
            BaseStyle->{},
            BaselinePosition->Baseline,
            ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
              If[
               Not[
                AbsoluteCurrentValue["Deployed"]], 
               SelectionMove[Typeset`box$, All, Expression]; 
               FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
               FrontEnd`Private`$ColorSelectorInitialColor = 
                RGBColor[
                 0.8676164929883508, 0.8866580065099905, 
                  0.024086278089002183`]; 
               FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
               MathLink`CallFrontEnd[
                 FrontEnd`AttachCell[Typeset`box$, 
                  FrontEndResource["RGBColorValueSelector"], {
                  0, {Left, Bottom}}, {Left, Top}, 
                  "ClosingActions" -> {
                   "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
            DefaultBaseStyle->{},
            Evaluator->Automatic,
            Method->"Preemptive"],
           
           RGBColor[{0.8676164929883508, 0.8866580065099905, 
            0.024086278089002183`}],
           Editable->False,
           Selectable->False], 
          Offset[{2, 2}, {1.4363138039168006, -1.5226441856777895}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{2.35378350863711, -1.995896708686483}, 0.04390366136190131],
          InsetBox[
          InterpretationBox[
           ButtonBox[
            TooltipBox[
             GraphicsBox[{
               {GrayLevel[0], RectangleBox[{0, 0}]}, 
               {GrayLevel[0], RectangleBox[{1, -1}]}, 
               {RGBColor[
                0.8577958146408966, 0.8374035340744639, 
                 0.0071190816223388464`], RectangleBox[{0, -1}, {2, 1}]}},
              AspectRatio->1,
              Frame->True,
              
              FrameStyle->RGBColor[
               0.5718638764272644, 0.5582690227163093, 0.004746054414892564],
              FrameTicks->None,
              
              ImageSize->
               Dynamic[{
                Automatic, 
                 1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                  Magnification])}],
              PlotRangePadding->None],
             
             "RGBColor[{0.8577958146408966, 0.8374035340744639, \
0.0071190816223388464}]"],
            Appearance->None,
            BaseStyle->{},
            BaselinePosition->Baseline,
            ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
              If[
               Not[
                AbsoluteCurrentValue["Deployed"]], 
               SelectionMove[Typeset`box$, All, Expression]; 
               FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
               FrontEnd`Private`$ColorSelectorInitialColor = 
                RGBColor[
                 0.8577958146408966, 0.8374035340744639, 
                  0.0071190816223388464`]; 
               FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
               MathLink`CallFrontEnd[
                 FrontEnd`AttachCell[Typeset`box$, 
                  FrontEndResource["RGBColorValueSelector"], {
                  0, {Left, Bottom}}, {Left, Top}, 
                  "ClosingActions" -> {
                   "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
            DefaultBaseStyle->{},
            Evaluator->Automatic,
            Method->"Preemptive"],
           
           RGBColor[{0.8577958146408966, 0.8374035340744639, 
            0.0071190816223388464`}],
           Editable->False,
           Selectable->False], 
          Offset[{2, 2}, {2.3976871699990117, -1.9519930473245817}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{1.5060840467800003, -0.4648511633541359}, 
          0.04390366136190131], InsetBox[
          InterpretationBox[
           ButtonBox[
            TooltipBox[
             GraphicsBox[{
               {GrayLevel[0], RectangleBox[{0, 0}]}, 
               {GrayLevel[0], RectangleBox[{1, -1}]}, 
               {RGBColor[
                0.9967431643372854, 0.969475575859666, 0.12251095291379577`], 
                RectangleBox[{0, -1}, {2, 1}]}},
              AspectRatio->1,
              Frame->True,
              
              FrameStyle->RGBColor[
               0.6644954428915236, 0.6463170505731107, 0.08167396860919718],
              FrameTicks->None,
              
              ImageSize->
               Dynamic[{
                Automatic, 
                 1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                  Magnification])}],
              PlotRangePadding->None],
             
             "RGBColor[{0.9967431643372854, 0.969475575859666, \
0.12251095291379577}]"],
            Appearance->None,
            BaseStyle->{},
            BaselinePosition->Baseline,
            ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
              If[
               Not[
                AbsoluteCurrentValue["Deployed"]], 
               SelectionMove[Typeset`box$, All, Expression]; 
               FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
               FrontEnd`Private`$ColorSelectorInitialColor = 
                RGBColor[
                 0.9967431643372854, 0.969475575859666, 0.12251095291379577`]; 
               FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
               MathLink`CallFrontEnd[
                 FrontEnd`AttachCell[Typeset`box$, 
                  FrontEndResource["RGBColorValueSelector"], {
                  0, {Left, Bottom}}, {Left, Top}, 
                  "ClosingActions" -> {
                   "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
            DefaultBaseStyle->{},
            Evaluator->Automatic,
            Method->"Preemptive"],
           
           RGBColor[{0.9967431643372854, 0.969475575859666, 
            0.12251095291379577`}],
           Editable->False,
           Selectable->False], 
          Offset[{2, 2}, {1.5499877081419016, -0.4209475019922346}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{5.022308187187053, -1.056787471678871}, 
          0.04390366136190131], InsetBox[
          InterpretationBox[
           ButtonBox[
            TooltipBox[
             GraphicsBox[{
               {GrayLevel[0], RectangleBox[{0, 0}]}, 
               {GrayLevel[0], RectangleBox[{1, -1}]}, 
               {RGBColor[
                0.8543889209256321, 0.09697598692920356, 
                 0.10750903324099509`], RectangleBox[{0, -1}, {2, 1}]}},
              AspectRatio->1,
              Frame->True,
              
              FrameStyle->RGBColor[
               0.5695926139504215, 0.06465065795280238, 0.07167268882733006],
              FrameTicks->None,
              
              ImageSize->
               Dynamic[{
                Automatic, 
                 1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                  Magnification])}],
              PlotRangePadding->None],
             
             "RGBColor[{0.8543889209256321, 0.09697598692920356, \
0.10750903324099509}]"],
            Appearance->None,
            BaseStyle->{},
            BaselinePosition->Baseline,
            ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
              If[
               Not[
                AbsoluteCurrentValue["Deployed"]], 
               SelectionMove[Typeset`box$, All, Expression]; 
               FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
               FrontEnd`Private`$ColorSelectorInitialColor = 
                RGBColor[
                 0.8543889209256321, 0.09697598692920356, 
                  0.10750903324099509`]; 
               FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
               MathLink`CallFrontEnd[
                 FrontEnd`AttachCell[Typeset`box$, 
                  FrontEndResource["RGBColorValueSelector"], {
                  0, {Left, Bottom}}, {Left, Top}, 
                  "ClosingActions" -> {
                   "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
            DefaultBaseStyle->{},
            Evaluator->Automatic,
            Method->"Preemptive"],
           
           RGBColor[{0.8543889209256321, 0.09697598692920356, 
            0.10750903324099509`}],
           Editable->False,
           Selectable->False], 
          Offset[{2, 2}, {5.066211848548955, -1.0128838103169697}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{0.4648511633541359, -1.8964778601993966}, 
          0.04390366136190131], InsetBox[
          InterpretationBox[
           ButtonBox[
            TooltipBox[
             GraphicsBox[{
               {GrayLevel[0], RectangleBox[{0, 0}]}, 
               {GrayLevel[0], RectangleBox[{1, -1}]}, 
               {RGBColor[
                0.8500363984900003, 0.9263311671408848, 0.13924242858059316`],
                 RectangleBox[{0, -1}, {2, 1}]}},
              AspectRatio->1,
              Frame->True,
              
              FrameStyle->RGBColor[
               0.5666909323266669, 0.6175541114272566, 0.09282828572039545],
              FrameTicks->None,
              
              ImageSize->
               Dynamic[{
                Automatic, 
                 1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                  Magnification])}],
              PlotRangePadding->None],
             
             "RGBColor[{0.8500363984900003, 0.9263311671408848, \
0.13924242858059316}]"],
            Appearance->None,
            BaseStyle->{},
            BaselinePosition->Baseline,
            ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
              If[
               Not[
                AbsoluteCurrentValue["Deployed"]], 
               SelectionMove[Typeset`box$, All, Expression]; 
               FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
               FrontEnd`Private`$ColorSelectorInitialColor = 
                RGBColor[
                 0.8500363984900003, 0.9263311671408848, 
                  0.13924242858059316`]; 
               FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
               MathLink`CallFrontEnd[
                 FrontEnd`AttachCell[Typeset`box$, 
                  FrontEndResource["RGBColorValueSelector"], {
                  0, {Left, Bottom}}, {Left, Top}, 
                  "ClosingActions" -> {
                   "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
            DefaultBaseStyle->{},
            Evaluator->Automatic,
            Method->"Preemptive"],
           
           RGBColor[{0.8500363984900003, 0.9263311671408848, 
            0.13924242858059316`}],
           Editable->False,
           Selectable->False], 
          Offset[{2, 2}, {0.5087548247160372, -1.8525741988374953}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{3.2294827893937987, -1.8961619949077049}, 
          0.04390366136190131], InsetBox[
          InterpretationBox[
           ButtonBox[
            TooltipBox[
             GraphicsBox[{
               {GrayLevel[0], RectangleBox[{0, 0}]}, 
               {GrayLevel[0], RectangleBox[{1, -1}]}, 
               {RGBColor[
                0.9879209034166253, 0.8377732017482453, 0.15613661869756118`],
                 RectangleBox[{0, -1}, {2, 1}]}},
              AspectRatio->1,
              Frame->True,
              
              FrameStyle->RGBColor[
               0.6586139356110836, 0.5585154678321635, 0.10409107913170745`],
              FrameTicks->None,
              
              ImageSize->
               Dynamic[{
                Automatic, 
                 1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                  Magnification])}],
              PlotRangePadding->None],
             
             "RGBColor[{0.9879209034166253, 0.8377732017482453, \
0.15613661869756118}]"],
            Appearance->None,
            BaseStyle->{},
            BaselinePosition->Baseline,
            ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
              If[
               Not[
                AbsoluteCurrentValue["Deployed"]], 
               SelectionMove[Typeset`box$, All, Expression]; 
               FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
               FrontEnd`Private`$ColorSelectorInitialColor = 
                RGBColor[
                 0.9879209034166253, 0.8377732017482453, 
                  0.15613661869756118`]; 
               FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
               MathLink`CallFrontEnd[
                 FrontEnd`AttachCell[Typeset`box$, 
                  FrontEndResource["RGBColorValueSelector"], {
                  0, {Left, Bottom}}, {Left, Top}, 
                  "ClosingActions" -> {
                   "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
            DefaultBaseStyle->{},
            Evaluator->Automatic,
            Method->"Preemptive"],
           
           RGBColor[{0.9879209034166253, 0.8377732017482453, 
            0.15613661869756118`}],
           Editable->False,
           Selectable->False], 
          Offset[{2, 2}, {3.2733864507557002, -1.8522583335458036}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{4.4286179868869135, -0.4947314325582979}, 
          0.04390366136190131], InsetBox[
          InterpretationBox[
           ButtonBox[
            TooltipBox[
             GraphicsBox[{
               {GrayLevel[0], RectangleBox[{0, 0}]}, 
               {GrayLevel[0], RectangleBox[{1, -1}]}, 
               {RGBColor[
                0.9573167308698426, 0.1507116093826361, 0.09832234398916928], 
                RectangleBox[{0, -1}, {2, 1}]}},
              AspectRatio->1,
              Frame->True,
              
              FrameStyle->RGBColor[
               0.6382111539132285, 0.10047440625509074`, 0.06554822932611286],
              
              FrameTicks->None,
              ImageSize->
               Dynamic[{
                Automatic, 
                 1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                  Magnification])}],
              PlotRangePadding->None],
             
             "RGBColor[{0.9573167308698426, 0.1507116093826361, \
0.09832234398916928}]"],
            Appearance->None,
            BaseStyle->{},
            BaselinePosition->Baseline,
            ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
              If[
               Not[
                AbsoluteCurrentValue["Deployed"]], 
               SelectionMove[Typeset`box$, All, Expression]; 
               FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
               FrontEnd`Private`$ColorSelectorInitialColor = 
                RGBColor[
                 0.9573167308698426, 0.1507116093826361, 0.09832234398916928]; 
               FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
               MathLink`CallFrontEnd[
                 FrontEnd`AttachCell[Typeset`box$, 
                  FrontEndResource["RGBColorValueSelector"], {
                  0, {Left, Bottom}}, {Left, Top}, 
                  "ClosingActions" -> {
                   "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
            DefaultBaseStyle->{},
            Evaluator->Automatic,
            Method->"Preemptive"],
           
           RGBColor[{0.9573167308698426, 0.1507116093826361, 
            0.09832234398916928}],
           Editable->False,
           Selectable->False], 
          Offset[{2, 2}, {4.472521648248815, -0.45082777119639655}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{1.3700266696218917, -4.285764605039754}, 
          0.04390366136190131], InsetBox[
          InterpretationBox[
           ButtonBox[
            TooltipBox[
             GraphicsBox[{
               {GrayLevel[0], RectangleBox[{0, 0}]}, 
               {GrayLevel[0], RectangleBox[{1, -1}]}, 
               {RGBColor[
                0.04278634258158939, 0.9055378427790535, 
                 0.0003309996431954121], RectangleBox[{0, -1}, {2, 1}]}},
              AspectRatio->1,
              Frame->True,
              FrameStyle->RGBColor[
               0.028524228387726263`, 0.6036918951860357, 
                0.0002206664287969414],
              FrameTicks->None,
              
              ImageSize->
               Dynamic[{
                Automatic, 
                 1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                  Magnification])}],
              PlotRangePadding->None],
             
             "RGBColor[{0.04278634258158939, 0.9055378427790535, \
0.0003309996431954121}]"],
            Appearance->None,
            BaseStyle->{},
            BaselinePosition->Baseline,
            ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
              If[
               Not[
                AbsoluteCurrentValue["Deployed"]], 
               SelectionMove[Typeset`box$, All, Expression]; 
               FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
               FrontEnd`Private`$ColorSelectorInitialColor = 
                RGBColor[
                 0.04278634258158939, 0.9055378427790535, 
                  0.0003309996431954121]; 
               FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
               MathLink`CallFrontEnd[
                 FrontEnd`AttachCell[Typeset`box$, 
                  FrontEndResource["RGBColorValueSelector"], {
                  0, {Left, Bottom}}, {Left, Top}, 
                  "ClosingActions" -> {
                   "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
            DefaultBaseStyle->{},
            Evaluator->Automatic,
            Method->"Preemptive"],
           
           RGBColor[{0.04278634258158939, 0.9055378427790535, 
            0.0003309996431954121}],
           Editable->False,
           Selectable->False], 
          Offset[{2, 2}, {1.413930330983793, -4.241860943677852}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{1.2626293529565484, -2.49753691898872}, 
          0.04390366136190131], InsetBox[
          InterpretationBox[
           ButtonBox[
            TooltipBox[
             GraphicsBox[{
               {GrayLevel[0], RectangleBox[{0, 0}]}, 
               {GrayLevel[0], RectangleBox[{1, -1}]}, 
               {RGBColor[
                0.8058039405531526, 0.8318774133774354, 0.10151558699591279`],
                 RectangleBox[{0, -1}, {2, 1}]}},
              AspectRatio->1,
              Frame->True,
              
              FrameStyle->RGBColor[
               0.5372026270354351, 0.5545849422516236, 0.06767705799727519],
              FrameTicks->None,
              
              ImageSize->
               Dynamic[{
                Automatic, 
                 1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                  Magnification])}],
              PlotRangePadding->None],
             
             "RGBColor[{0.8058039405531526, 0.8318774133774354, \
0.10151558699591279}]"],
            Appearance->None,
            BaseStyle->{},
            BaselinePosition->Baseline,
            ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
              If[
               Not[
                AbsoluteCurrentValue["Deployed"]], 
               SelectionMove[Typeset`box$, All, Expression]; 
               FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
               FrontEnd`Private`$ColorSelectorInitialColor = 
                RGBColor[
                 0.8058039405531526, 0.8318774133774354, 
                  0.10151558699591279`]; 
               FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
               MathLink`CallFrontEnd[
                 FrontEnd`AttachCell[Typeset`box$, 
                  FrontEndResource["RGBColorValueSelector"], {
                  0, {Left, Bottom}}, {Left, Top}, 
                  "ClosingActions" -> {
                   "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
            DefaultBaseStyle->{},
            Evaluator->Automatic,
            Method->"Preemptive"],
           
           RGBColor[{0.8058039405531526, 0.8318774133774354, 
            0.10151558699591279`}],
           Editable->False,
           Selectable->False], 
          Offset[{2, 2}, {1.3065330143184497, -2.4536332576268185}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{0.554186844464825, -3.5080754511825862}, 
          0.04390366136190131], InsetBox[
          InterpretationBox[
           ButtonBox[
            TooltipBox[
             GraphicsBox[{
               {GrayLevel[0], RectangleBox[{0, 0}]}, 
               {GrayLevel[0], RectangleBox[{1, -1}]}, 
               {RGBColor[
                0.006814389873512461, 0.9336694049188562, 
                 0.06907220235176909], RectangleBox[{0, -1}, {2, 1}]}},
              AspectRatio->1,
              Frame->True,
              
              FrameStyle->RGBColor[
               0.004542926582341641, 0.6224462699459041, 0.04604813490117939],
              
              FrameTicks->None,
              
              ImageSize->
               Dynamic[{
                Automatic, 
                 1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                  Magnification])}],
              PlotRangePadding->None],
             
             "RGBColor[{0.006814389873512461, 0.9336694049188562, \
0.06907220235176909}]"],
            Appearance->None,
            BaseStyle->{},
            BaselinePosition->Baseline,
            ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
              If[
               Not[
                AbsoluteCurrentValue["Deployed"]], 
               SelectionMove[Typeset`box$, All, Expression]; 
               FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
               FrontEnd`Private`$ColorSelectorInitialColor = 
                RGBColor[
                 0.006814389873512461, 0.9336694049188562, 
                  0.06907220235176909]; 
               FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
               MathLink`CallFrontEnd[
                 FrontEnd`AttachCell[Typeset`box$, 
                  FrontEndResource["RGBColorValueSelector"], {
                  0, {Left, Bottom}}, {Left, Top}, 
                  "ClosingActions" -> {
                   "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
            DefaultBaseStyle->{},
            Evaluator->Automatic,
            Method->"Preemptive"],
           
           RGBColor[{0.006814389873512461, 0.9336694049188562, 
            0.06907220235176909}],
           Editable->False,
           Selectable->False], 
          Offset[{2, 2}, {0.5980905058267263, -3.4641717898206847}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{0.9602326263625951, -0.9849055396098816}, 
          0.04390366136190131], InsetBox[
          InterpretationBox[
           ButtonBox[
            TooltipBox[
             GraphicsBox[{
               {GrayLevel[0], RectangleBox[{0, 0}]}, 
               {GrayLevel[0], RectangleBox[{1, -1}]}, 
               {RGBColor[
                0.9450158125329948, 0.9670907305400336, 0.05040029871534907], 
                RectangleBox[{0, -1}, {2, 1}]}},
              AspectRatio->1,
              Frame->True,
              
              FrameStyle->RGBColor[
               0.6300105416886632, 0.6447271536933558, 0.033600199143566045`],
              
              FrameTicks->None,
              
              ImageSize->
               Dynamic[{
                Automatic, 
                 1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                  Magnification])}],
              PlotRangePadding->None],
             
             "RGBColor[{0.9450158125329948, 0.9670907305400336, \
0.05040029871534907}]"],
            Appearance->None,
            BaseStyle->{},
            BaselinePosition->Baseline,
            ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
              If[
               Not[
                AbsoluteCurrentValue["Deployed"]], 
               SelectionMove[Typeset`box$, All, Expression]; 
               FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
               FrontEnd`Private`$ColorSelectorInitialColor = 
                RGBColor[
                 0.9450158125329948, 0.9670907305400336, 0.05040029871534907]; 
               FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
               MathLink`CallFrontEnd[
                 FrontEnd`AttachCell[Typeset`box$, 
                  FrontEndResource["RGBColorValueSelector"], {
                  0, {Left, Bottom}}, {Left, Top}, 
                  "ClosingActions" -> {
                   "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
            DefaultBaseStyle->{},
            Evaluator->Automatic,
            Method->"Preemptive"],
           
           RGBColor[{0.9450158125329948, 0.9670907305400336, 
            0.05040029871534907}],
           Editable->False,
           Selectable->False], 
          Offset[{2, 2}, {1.0041362877244964, -0.9410018782479803}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{3.223314906392934, -1.2651880018871549}, 
          0.04390366136190131], InsetBox[
          InterpretationBox[
           ButtonBox[
            TooltipBox[
             GraphicsBox[{
               {GrayLevel[0], RectangleBox[{0, 0}]}, 
               {GrayLevel[0], RectangleBox[{1, -1}]}, 
               {RGBColor[
                0.9752641706478989, 0.8013981246170678, 0.10899973580393796`],
                 RectangleBox[{0, -1}, {2, 1}]}},
              AspectRatio->1,
              Frame->True,
              
              FrameStyle->RGBColor[
               0.650176113765266, 0.5342654164113786, 0.07266649053595864],
              FrameTicks->None,
              
              ImageSize->
               Dynamic[{
                Automatic, 
                 1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                  Magnification])}],
              PlotRangePadding->None],
             
             "RGBColor[{0.9752641706478989, 0.8013981246170678, \
0.10899973580393796}]"],
            Appearance->None,
            BaseStyle->{},
            BaselinePosition->Baseline,
            ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
              If[
               Not[
                AbsoluteCurrentValue["Deployed"]], 
               SelectionMove[Typeset`box$, All, Expression]; 
               FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
               FrontEnd`Private`$ColorSelectorInitialColor = 
                RGBColor[
                 0.9752641706478989, 0.8013981246170678, 
                  0.10899973580393796`]; 
               FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
               MathLink`CallFrontEnd[
                 FrontEnd`AttachCell[Typeset`box$, 
                  FrontEndResource["RGBColorValueSelector"], {
                  0, {Left, Bottom}}, {Left, Top}, 
                  "ClosingActions" -> {
                   "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
            DefaultBaseStyle->{},
            Evaluator->Automatic,
            Method->"Preemptive"],
           
           RGBColor[{0.9752641706478989, 0.8013981246170678, 
            0.10899973580393796`}],
           Editable->False,
           Selectable->False], Offset[{2, 2}, 
          {3.2672185677548353, -1.2212843405252536}], ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{2.5077218652244078, -4.380316734568815}, 
          0.04390366136190131], InsetBox[
          InterpretationBox[
           ButtonBox[
            TooltipBox[
             GraphicsBox[{
               {GrayLevel[0], RectangleBox[{0, 0}]}, 
               {GrayLevel[0], RectangleBox[{1, -1}]}, 
               {RGBColor[
                0.16590548598015492`, 0.9015045495499641, 
                 0.09828783196817376], RectangleBox[{0, -1}, {2, 1}]}},
              AspectRatio->1,
              Frame->True,
              
              FrameStyle->RGBColor[
               0.11060365732010329`, 0.6010030330333094, 0.06552522131211584],
              
              FrameTicks->None,
              
              ImageSize->
               Dynamic[{
                Automatic, 
                 1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                  Magnification])}],
              PlotRangePadding->None],
             
             "RGBColor[{0.16590548598015492, 0.9015045495499641, \
0.09828783196817376}]"],
            Appearance->None,
            BaseStyle->{},
            BaselinePosition->Baseline,
            ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
              If[
               Not[
                AbsoluteCurrentValue["Deployed"]], 
               SelectionMove[Typeset`box$, All, Expression]; 
               FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
               FrontEnd`Private`$ColorSelectorInitialColor = 
                RGBColor[
                 0.16590548598015492`, 0.9015045495499641, 
                  0.09828783196817376]; 
               FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
               MathLink`CallFrontEnd[
                 FrontEnd`AttachCell[Typeset`box$, 
                  FrontEndResource["RGBColorValueSelector"], {
                  0, {Left, Bottom}}, {Left, Top}, 
                  "ClosingActions" -> {
                   "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
            DefaultBaseStyle->{},
            Evaluator->Automatic,
            Method->"Preemptive"],
           
           RGBColor[{0.16590548598015492`, 0.9015045495499641, 
            0.09828783196817376}],
           Editable->False,
           Selectable->False], 
          Offset[{2, 2}, {2.5516255265863093, -4.336413073206914}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{2.4353672087938216, -3.839177553623694}, 
          0.04390366136190131], InsetBox[
          InterpretationBox[
           ButtonBox[
            TooltipBox[
             GraphicsBox[{
               {GrayLevel[0], RectangleBox[{0, 0}]}, 
               {GrayLevel[0], RectangleBox[{1, -1}]}, 
               {RGBColor[
                0.10048980936842117`, 0.9171495192304465, 
                 0.16131399976146749`], RectangleBox[{0, -1}, {2, 1}]}},
              AspectRatio->1,
              Frame->True,
              
              FrameStyle->RGBColor[
               0.06699320624561411, 0.6114330128202977, 0.10754266650764499`],
              
              FrameTicks->None,
              
              ImageSize->
               Dynamic[{
                Automatic, 
                 1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                  Magnification])}],
              PlotRangePadding->None],
             
             "RGBColor[{0.10048980936842117, 0.9171495192304465, \
0.16131399976146749}]"],
            Appearance->None,
            BaseStyle->{},
            BaselinePosition->Baseline,
            ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
              If[
               Not[
                AbsoluteCurrentValue["Deployed"]], 
               SelectionMove[Typeset`box$, All, Expression]; 
               FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
               FrontEnd`Private`$ColorSelectorInitialColor = 
                RGBColor[
                 0.10048980936842117`, 0.9171495192304465, 
                  0.16131399976146749`]; 
               FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
               MathLink`CallFrontEnd[
                 FrontEnd`AttachCell[Typeset`box$, 
                  FrontEndResource["RGBColorValueSelector"], {
                  0, {Left, Bottom}}, {Left, Top}, 
                  "ClosingActions" -> {
                   "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
            DefaultBaseStyle->{},
            Evaluator->Automatic,
            Method->"Preemptive"],
           
           RGBColor[{0.10048980936842117`, 0.9171495192304465, 
            0.16131399976146749`}],
           Editable->False,
           Selectable->False], 
          Offset[{2, 2}, {2.479270870155723, -3.7952738922617923}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FormatType->TraditionalForm,
  FrameTicks->None]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[19]=",ExpressionUUID->"b3c568f6-7387-4914-95b8-f0259c6d69ab"]
}, Open  ]],

Cell[TextData[{
 "A ",
 StyleBox["dendrogram",
  FontSlant->"Italic"],
 " is a tree-like plot that lets you see a whole hierarchy of what\
\[CloseCurlyQuote]s near what. "
}], "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:21",ExpressionUUID->"69f952ba-ad63-45ed-b1e9-864c9ea820af"],

Cell["Show nearby colors successively grouped together:", "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"836a38c6-3ea4-4f92-aa92-7ee1742cd7d0"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Dendrogram", "[", 
  RowBox[{"{", 
   RowBox[{
    InterpretationBox[
     ButtonBox[
      TooltipBox[
       GraphicsBox[{
         {GrayLevel[0], RectangleBox[{0, 0}]}, 
         {GrayLevel[0], RectangleBox[{1, -1}]}, 
         {RGBColor[
          0.048175746346922704`, 0.8856231902848692, 0.002187262571789972], 
          RectangleBox[{0, -1}, {2, 1}]}},
        AspectRatio->1,
        Frame->True,
        FrameStyle->RGBColor[
         0.0321171642312818, 0.5904154601899129, 0.0014581750478599813`],
        FrameTicks->None,
        ImageSize->
         Dynamic[{
          Automatic, 
           1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
            Magnification])}],
        PlotRangePadding->None],
       "RGBColor[{0.048175746346922704, 0.8856231902848692, \
0.002187262571789972}]"],
      Appearance->None,
      BaseStyle->{},
      BaselinePosition->Baseline,
      ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
        If[
         Not[
          AbsoluteCurrentValue["Deployed"]], 
         SelectionMove[Typeset`box$, All, Expression]; 
         FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
         FrontEnd`Private`$ColorSelectorInitialColor = 
          RGBColor[
           0.048175746346922704`, 0.8856231902848692, 0.002187262571789972]; 
         FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
         MathLink`CallFrontEnd[
           FrontEnd`AttachCell[Typeset`box$, 
            FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
            Left, Top}, 
            "ClosingActions" -> {
             "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
      DefaultBaseStyle->{},
      Evaluator->Automatic,
      Method->"Preemptive"],
     RGBColor[{0.048175746346922704`, 0.8856231902848692, 
      0.002187262571789972}],
     Editable->False,
     Selectable->False], ",", 
    InterpretationBox[
     ButtonBox[
      TooltipBox[
       GraphicsBox[{
         {GrayLevel[0], RectangleBox[{0, 0}]}, 
         {GrayLevel[0], RectangleBox[{1, -1}]}, 
         {RGBColor[
          0.9543437880041175, 0.9364915417894851, 0.08314980598714755], 
          RectangleBox[{0, -1}, {2, 1}]}},
        AspectRatio->1,
        Frame->True,
        FrameStyle->RGBColor[
         0.636229192002745, 0.6243276945263234, 0.0554332039914317],
        FrameTicks->None,
        ImageSize->
         Dynamic[{
          Automatic, 
           1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
            Magnification])}],
        PlotRangePadding->None],
       "RGBColor[{0.9543437880041175, 0.9364915417894851, \
0.08314980598714755}]"],
      Appearance->None,
      BaseStyle->{},
      BaselinePosition->Baseline,
      ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
        If[
         Not[
          AbsoluteCurrentValue["Deployed"]], 
         SelectionMove[Typeset`box$, All, Expression]; 
         FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
         FrontEnd`Private`$ColorSelectorInitialColor = 
          RGBColor[
           0.9543437880041175, 0.9364915417894851, 0.08314980598714755]; 
         FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
         MathLink`CallFrontEnd[
           FrontEnd`AttachCell[Typeset`box$, 
            FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
            Left, Top}, 
            "ClosingActions" -> {
             "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
      DefaultBaseStyle->{},
      Evaluator->Automatic,
      Method->"Preemptive"],
     RGBColor[{0.9543437880041175, 0.9364915417894851, 0.08314980598714755}],
     Editable->False,
     Selectable->False], ",", 
    InterpretationBox[
     ButtonBox[
      TooltipBox[
       GraphicsBox[{
         {GrayLevel[0], RectangleBox[{0, 0}]}, 
         {GrayLevel[0], RectangleBox[{1, -1}]}, 
         {RGBColor[
          0.8527294202095301, 0.15459949958575997`, 0.08139444813034824], 
          RectangleBox[{0, -1}, {2, 1}]}},
        AspectRatio->1,
        Frame->True,
        FrameStyle->RGBColor[
         0.5684862801396868, 0.10306633305717332`, 0.054262965420232165`],
        FrameTicks->None,
        ImageSize->
         Dynamic[{
          Automatic, 
           1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
            Magnification])}],
        PlotRangePadding->None],
       "RGBColor[{0.8527294202095301, 0.15459949958575997, \
0.08139444813034824}]"],
      Appearance->None,
      BaseStyle->{},
      BaselinePosition->Baseline,
      ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
        If[
         Not[
          AbsoluteCurrentValue["Deployed"]], 
         SelectionMove[Typeset`box$, All, Expression]; 
         FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
         FrontEnd`Private`$ColorSelectorInitialColor = 
          RGBColor[
           0.8527294202095301, 0.15459949958575997`, 0.08139444813034824]; 
         FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
         MathLink`CallFrontEnd[
           FrontEnd`AttachCell[Typeset`box$, 
            FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
            Left, Top}, 
            "ClosingActions" -> {
             "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
      DefaultBaseStyle->{},
      Evaluator->Automatic,
      Method->"Preemptive"],
     RGBColor[{0.8527294202095301, 0.15459949958575997`, 0.08139444813034824}],
     Editable->False,
     Selectable->False], ",", 
    InterpretationBox[
     ButtonBox[
      TooltipBox[
       GraphicsBox[{
         {GrayLevel[0], RectangleBox[{0, 0}]}, 
         {GrayLevel[0], RectangleBox[{1, -1}]}, 
         {RGBColor[
          0.12965437429396431`, 0.8338364200576898, 0.16859742903104202`], 
          RectangleBox[{0, -1}, {2, 1}]}},
        AspectRatio->1,
        Frame->True,
        FrameStyle->RGBColor[
         0.08643624952930955, 0.5558909467051265, 0.11239828602069468`],
        FrameTicks->None,
        ImageSize->
         Dynamic[{
          Automatic, 
           1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
            Magnification])}],
        PlotRangePadding->None],
       "RGBColor[{0.12965437429396431, 0.8338364200576898, \
0.16859742903104202}]"],
      Appearance->None,
      BaseStyle->{},
      BaselinePosition->Baseline,
      ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
        If[
         Not[
          AbsoluteCurrentValue["Deployed"]], 
         SelectionMove[Typeset`box$, All, Expression]; 
         FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
         FrontEnd`Private`$ColorSelectorInitialColor = 
          RGBColor[
           0.12965437429396431`, 0.8338364200576898, 0.16859742903104202`]; 
         FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
         MathLink`CallFrontEnd[
           FrontEnd`AttachCell[Typeset`box$, 
            FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
            Left, Top}, 
            "ClosingActions" -> {
             "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
      DefaultBaseStyle->{},
      Evaluator->Automatic,
      Method->"Preemptive"],
     RGBColor[{0.12965437429396431`, 0.8338364200576898, 
      0.16859742903104202`}],
     Editable->False,
     Selectable->False], ",", 
    InterpretationBox[
     ButtonBox[
      TooltipBox[
       GraphicsBox[{
         {GrayLevel[0], RectangleBox[{0, 0}]}, 
         {GrayLevel[0], RectangleBox[{1, -1}]}, 
         {RGBColor[
          0.14189318640501342`, 0.8685451286121387, 0.10426943556314977`], 
          RectangleBox[{0, -1}, {2, 1}]}},
        AspectRatio->1,
        Frame->True,
        FrameStyle->RGBColor[
         0.09459545760334229, 0.5790300857414259, 0.06951295704209985],
        FrameTicks->None,
        ImageSize->
         Dynamic[{
          Automatic, 
           1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
            Magnification])}],
        PlotRangePadding->None],
       "RGBColor[{0.14189318640501342, 0.8685451286121387, \
0.10426943556314977}]"],
      Appearance->None,
      BaseStyle->{},
      BaselinePosition->Baseline,
      ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
        If[
         Not[
          AbsoluteCurrentValue["Deployed"]], 
         SelectionMove[Typeset`box$, All, Expression]; 
         FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
         FrontEnd`Private`$ColorSelectorInitialColor = 
          RGBColor[
           0.14189318640501342`, 0.8685451286121387, 0.10426943556314977`]; 
         FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
         MathLink`CallFrontEnd[
           FrontEnd`AttachCell[Typeset`box$, 
            FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
            Left, Top}, 
            "ClosingActions" -> {
             "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
      DefaultBaseStyle->{},
      Evaluator->Automatic,
      Method->"Preemptive"],
     RGBColor[{0.14189318640501342`, 0.8685451286121387, 
      0.10426943556314977`}],
     Editable->False,
     Selectable->False], ",", 
    InterpretationBox[
     ButtonBox[
      TooltipBox[
       GraphicsBox[{
         {GrayLevel[0], RectangleBox[{0, 0}]}, 
         {GrayLevel[0], RectangleBox[{1, -1}]}, 
         {RGBColor[
          0.9244703510275273, 0.001783470411052479, 0.14318146272477922`], 
          RectangleBox[{0, -1}, {2, 1}]}},
        AspectRatio->1,
        Frame->True,
        FrameStyle->RGBColor[
         0.6163135673516849, 0.0011889802740349862`, 0.09545430848318615],
        FrameTicks->None,
        ImageSize->
         Dynamic[{
          Automatic, 
           1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
            Magnification])}],
        PlotRangePadding->None],
       "RGBColor[{0.9244703510275273, 0.001783470411052479, \
0.14318146272477922}]"],
      Appearance->None,
      BaseStyle->{},
      BaselinePosition->Baseline,
      ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
        If[
         Not[
          AbsoluteCurrentValue["Deployed"]], 
         SelectionMove[Typeset`box$, All, Expression]; 
         FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
         FrontEnd`Private`$ColorSelectorInitialColor = 
          RGBColor[
           0.9244703510275273, 0.001783470411052479, 0.14318146272477922`]; 
         FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
         MathLink`CallFrontEnd[
           FrontEnd`AttachCell[Typeset`box$, 
            FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
            Left, Top}, 
            "ClosingActions" -> {
             "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
      DefaultBaseStyle->{},
      Evaluator->Automatic,
      Method->"Preemptive"],
     RGBColor[{0.9244703510275273, 0.001783470411052479, 
      0.14318146272477922`}],
     Editable->False,
     Selectable->False], ",", 
    InterpretationBox[
     ButtonBox[
      TooltipBox[
       GraphicsBox[{
         {GrayLevel[0], RectangleBox[{0, 0}]}, 
         {GrayLevel[0], RectangleBox[{1, -1}]}, 
         {RGBColor[
          0.8340523614444824, 0.038129646837010533`, 0.09354464468116397], 
          RectangleBox[{0, -1}, {2, 1}]}},
        AspectRatio->1,
        Frame->True,
        FrameStyle->RGBColor[
         0.5560349076296549, 0.025419764558007023`, 0.06236309645410931],
        FrameTicks->None,
        ImageSize->
         Dynamic[{
          Automatic, 
           1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
            Magnification])}],
        PlotRangePadding->None],
       "RGBColor[{0.8340523614444824, 0.038129646837010533, \
0.09354464468116397}]"],
      Appearance->None,
      BaseStyle->{},
      BaselinePosition->Baseline,
      ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
        If[
         Not[
          AbsoluteCurrentValue["Deployed"]], 
         SelectionMove[Typeset`box$, All, Expression]; 
         FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
         FrontEnd`Private`$ColorSelectorInitialColor = 
          RGBColor[
           0.8340523614444824, 0.038129646837010533`, 0.09354464468116397]; 
         FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
         MathLink`CallFrontEnd[
           FrontEnd`AttachCell[Typeset`box$, 
            FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
            Left, Top}, 
            "ClosingActions" -> {
             "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
      DefaultBaseStyle->{},
      Evaluator->Automatic,
      Method->"Preemptive"],
     RGBColor[{0.8340523614444824, 0.038129646837010533`, 
      0.09354464468116397}],
     Editable->False,
     Selectable->False], ",", 
    InterpretationBox[
     ButtonBox[
      TooltipBox[
       GraphicsBox[{
         {GrayLevel[0], RectangleBox[{0, 0}]}, 
         {GrayLevel[0], RectangleBox[{1, -1}]}, 
         {RGBColor[
          0.06423181065333894, 0.9361486399945784, 0.08411970647251821], 
          RectangleBox[{0, -1}, {2, 1}]}},
        AspectRatio->1,
        Frame->True,
        FrameStyle->RGBColor[
         0.042821207102225964`, 0.624099093329719, 0.05607980431501214],
        FrameTicks->None,
        ImageSize->
         Dynamic[{
          Automatic, 
           1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
            Magnification])}],
        PlotRangePadding->None],
       "RGBColor[{0.06423181065333894, 0.9361486399945784, \
0.08411970647251821}]"],
      Appearance->None,
      BaseStyle->{},
      BaselinePosition->Baseline,
      ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
        If[
         Not[
          AbsoluteCurrentValue["Deployed"]], 
         SelectionMove[Typeset`box$, All, Expression]; 
         FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
         FrontEnd`Private`$ColorSelectorInitialColor = 
          RGBColor[
           0.06423181065333894, 0.9361486399945784, 0.08411970647251821]; 
         FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
         MathLink`CallFrontEnd[
           FrontEnd`AttachCell[Typeset`box$, 
            FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
            Left, Top}, 
            "ClosingActions" -> {
             "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
      DefaultBaseStyle->{},
      Evaluator->Automatic,
      Method->"Preemptive"],
     RGBColor[{0.06423181065333894, 0.9361486399945784, 0.08411970647251821}],
     
     Editable->False,
     Selectable->False], ",", 
    InterpretationBox[
     ButtonBox[
      TooltipBox[
       GraphicsBox[{
         {GrayLevel[0], RectangleBox[{0, 0}]}, 
         {GrayLevel[0], RectangleBox[{1, -1}]}, 
         {RGBColor[
          0.8676164929883508, 0.8866580065099905, 0.024086278089002183`], 
          RectangleBox[{0, -1}, {2, 1}]}},
        AspectRatio->1,
        Frame->True,
        FrameStyle->RGBColor[
         0.5784109953255672, 0.5911053376733271, 0.016057518726001457`],
        FrameTicks->None,
        ImageSize->
         Dynamic[{
          Automatic, 
           1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
            Magnification])}],
        PlotRangePadding->None],
       "RGBColor[{0.8676164929883508, 0.8866580065099905, \
0.024086278089002183}]"],
      Appearance->None,
      BaseStyle->{},
      BaselinePosition->Baseline,
      ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
        If[
         Not[
          AbsoluteCurrentValue["Deployed"]], 
         SelectionMove[Typeset`box$, All, Expression]; 
         FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
         FrontEnd`Private`$ColorSelectorInitialColor = 
          RGBColor[
           0.8676164929883508, 0.8866580065099905, 0.024086278089002183`]; 
         FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
         MathLink`CallFrontEnd[
           FrontEnd`AttachCell[Typeset`box$, 
            FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
            Left, Top}, 
            "ClosingActions" -> {
             "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
      DefaultBaseStyle->{},
      Evaluator->Automatic,
      Method->"Preemptive"],
     RGBColor[{0.8676164929883508, 0.8866580065099905, 0.024086278089002183`}],
     Editable->False,
     Selectable->False], ",", 
    InterpretationBox[
     ButtonBox[
      TooltipBox[
       GraphicsBox[{
         {GrayLevel[0], RectangleBox[{0, 0}]}, 
         {GrayLevel[0], RectangleBox[{1, -1}]}, 
         {RGBColor[
          0.8577958146408966, 0.8374035340744639, 0.0071190816223388464`], 
          RectangleBox[{0, -1}, {2, 1}]}},
        AspectRatio->1,
        Frame->True,
        FrameStyle->RGBColor[
         0.5718638764272644, 0.5582690227163093, 0.004746054414892564],
        FrameTicks->None,
        ImageSize->
         Dynamic[{
          Automatic, 
           1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
            Magnification])}],
        PlotRangePadding->None],
       "RGBColor[{0.8577958146408966, 0.8374035340744639, \
0.0071190816223388464}]"],
      Appearance->None,
      BaseStyle->{},
      BaselinePosition->Baseline,
      ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
        If[
         Not[
          AbsoluteCurrentValue["Deployed"]], 
         SelectionMove[Typeset`box$, All, Expression]; 
         FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
         FrontEnd`Private`$ColorSelectorInitialColor = 
          RGBColor[
           0.8577958146408966, 0.8374035340744639, 0.0071190816223388464`]; 
         FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
         MathLink`CallFrontEnd[
           FrontEnd`AttachCell[Typeset`box$, 
            FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
            Left, Top}, 
            "ClosingActions" -> {
             "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
      DefaultBaseStyle->{},
      Evaluator->Automatic,
      Method->"Preemptive"],
     RGBColor[{0.8577958146408966, 0.8374035340744639, 
      0.0071190816223388464`}],
     Editable->False,
     Selectable->False], ",", 
    InterpretationBox[
     ButtonBox[
      TooltipBox[
       GraphicsBox[{
         {GrayLevel[0], RectangleBox[{0, 0}]}, 
         {GrayLevel[0], RectangleBox[{1, -1}]}, 
         {RGBColor[
          0.9967431643372854, 0.969475575859666, 0.12251095291379577`], 
          RectangleBox[{0, -1}, {2, 1}]}},
        AspectRatio->1,
        Frame->True,
        FrameStyle->RGBColor[
         0.6644954428915236, 0.6463170505731107, 0.08167396860919718],
        FrameTicks->None,
        ImageSize->
         Dynamic[{
          Automatic, 
           1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
            Magnification])}],
        PlotRangePadding->None],
       "RGBColor[{0.9967431643372854, 0.969475575859666, \
0.12251095291379577}]"],
      Appearance->None,
      BaseStyle->{},
      BaselinePosition->Baseline,
      ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
        If[
         Not[
          AbsoluteCurrentValue["Deployed"]], 
         SelectionMove[Typeset`box$, All, Expression]; 
         FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
         FrontEnd`Private`$ColorSelectorInitialColor = 
          RGBColor[
           0.9967431643372854, 0.969475575859666, 0.12251095291379577`]; 
         FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
         MathLink`CallFrontEnd[
           FrontEnd`AttachCell[Typeset`box$, 
            FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
            Left, Top}, 
            "ClosingActions" -> {
             "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
      DefaultBaseStyle->{},
      Evaluator->Automatic,
      Method->"Preemptive"],
     RGBColor[{0.9967431643372854, 0.969475575859666, 0.12251095291379577`}],
     Editable->False,
     Selectable->False], ",", 
    InterpretationBox[
     ButtonBox[
      TooltipBox[
       GraphicsBox[{
         {GrayLevel[0], RectangleBox[{0, 0}]}, 
         {GrayLevel[0], RectangleBox[{1, -1}]}, 
         {RGBColor[
          0.8543889209256321, 0.09697598692920356, 0.10750903324099509`], 
          RectangleBox[{0, -1}, {2, 1}]}},
        AspectRatio->1,
        Frame->True,
        FrameStyle->RGBColor[
         0.5695926139504215, 0.06465065795280238, 0.07167268882733006],
        FrameTicks->None,
        ImageSize->
         Dynamic[{
          Automatic, 
           1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
            Magnification])}],
        PlotRangePadding->None],
       "RGBColor[{0.8543889209256321, 0.09697598692920356, \
0.10750903324099509}]"],
      Appearance->None,
      BaseStyle->{},
      BaselinePosition->Baseline,
      ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
        If[
         Not[
          AbsoluteCurrentValue["Deployed"]], 
         SelectionMove[Typeset`box$, All, Expression]; 
         FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
         FrontEnd`Private`$ColorSelectorInitialColor = 
          RGBColor[
           0.8543889209256321, 0.09697598692920356, 0.10750903324099509`]; 
         FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
         MathLink`CallFrontEnd[
           FrontEnd`AttachCell[Typeset`box$, 
            FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
            Left, Top}, 
            "ClosingActions" -> {
             "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
      DefaultBaseStyle->{},
      Evaluator->Automatic,
      Method->"Preemptive"],
     RGBColor[{0.8543889209256321, 0.09697598692920356, 0.10750903324099509`}],
     Editable->False,
     Selectable->False], ",", 
    InterpretationBox[
     ButtonBox[
      TooltipBox[
       GraphicsBox[{
         {GrayLevel[0], RectangleBox[{0, 0}]}, 
         {GrayLevel[0], RectangleBox[{1, -1}]}, 
         {RGBColor[
          0.8500363984900003, 0.9263311671408848, 0.13924242858059316`], 
          RectangleBox[{0, -1}, {2, 1}]}},
        AspectRatio->1,
        Frame->True,
        FrameStyle->RGBColor[
         0.5666909323266669, 0.6175541114272566, 0.09282828572039545],
        FrameTicks->None,
        ImageSize->
         Dynamic[{
          Automatic, 
           1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
            Magnification])}],
        PlotRangePadding->None],
       "RGBColor[{0.8500363984900003, 0.9263311671408848, \
0.13924242858059316}]"],
      Appearance->None,
      BaseStyle->{},
      BaselinePosition->Baseline,
      ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
        If[
         Not[
          AbsoluteCurrentValue["Deployed"]], 
         SelectionMove[Typeset`box$, All, Expression]; 
         FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
         FrontEnd`Private`$ColorSelectorInitialColor = 
          RGBColor[
           0.8500363984900003, 0.9263311671408848, 0.13924242858059316`]; 
         FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
         MathLink`CallFrontEnd[
           FrontEnd`AttachCell[Typeset`box$, 
            FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
            Left, Top}, 
            "ClosingActions" -> {
             "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
      DefaultBaseStyle->{},
      Evaluator->Automatic,
      Method->"Preemptive"],
     RGBColor[{0.8500363984900003, 0.9263311671408848, 0.13924242858059316`}],
     
     Editable->False,
     Selectable->False], ",", 
    InterpretationBox[
     ButtonBox[
      TooltipBox[
       GraphicsBox[{
         {GrayLevel[0], RectangleBox[{0, 0}]}, 
         {GrayLevel[0], RectangleBox[{1, -1}]}, 
         {RGBColor[
          0.9879209034166253, 0.8377732017482453, 0.15613661869756118`], 
          RectangleBox[{0, -1}, {2, 1}]}},
        AspectRatio->1,
        Frame->True,
        FrameStyle->RGBColor[
         0.6586139356110836, 0.5585154678321635, 0.10409107913170745`],
        FrameTicks->None,
        ImageSize->
         Dynamic[{
          Automatic, 
           1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
            Magnification])}],
        PlotRangePadding->None],
       "RGBColor[{0.9879209034166253, 0.8377732017482453, \
0.15613661869756118}]"],
      Appearance->None,
      BaseStyle->{},
      BaselinePosition->Baseline,
      ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
        If[
         Not[
          AbsoluteCurrentValue["Deployed"]], 
         SelectionMove[Typeset`box$, All, Expression]; 
         FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
         FrontEnd`Private`$ColorSelectorInitialColor = 
          RGBColor[
           0.9879209034166253, 0.8377732017482453, 0.15613661869756118`]; 
         FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
         MathLink`CallFrontEnd[
           FrontEnd`AttachCell[Typeset`box$, 
            FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
            Left, Top}, 
            "ClosingActions" -> {
             "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
      DefaultBaseStyle->{},
      Evaluator->Automatic,
      Method->"Preemptive"],
     RGBColor[{0.9879209034166253, 0.8377732017482453, 0.15613661869756118`}],
     
     Editable->False,
     Selectable->False], ",", 
    InterpretationBox[
     ButtonBox[
      TooltipBox[
       GraphicsBox[{
         {GrayLevel[0], RectangleBox[{0, 0}]}, 
         {GrayLevel[0], RectangleBox[{1, -1}]}, 
         {RGBColor[
          0.9573167308698426, 0.1507116093826361, 0.09832234398916928], 
          RectangleBox[{0, -1}, {2, 1}]}},
        AspectRatio->1,
        Frame->True,
        FrameStyle->RGBColor[
         0.6382111539132285, 0.10047440625509074`, 0.06554822932611286],
        FrameTicks->None,
        ImageSize->
         Dynamic[{
          Automatic, 
           1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
            Magnification])}],
        PlotRangePadding->None],
       "RGBColor[{0.9573167308698426, 0.1507116093826361, \
0.09832234398916928}]"],
      Appearance->None,
      BaseStyle->{},
      BaselinePosition->Baseline,
      ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
        If[
         Not[
          AbsoluteCurrentValue["Deployed"]], 
         SelectionMove[Typeset`box$, All, Expression]; 
         FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
         FrontEnd`Private`$ColorSelectorInitialColor = 
          RGBColor[
           0.9573167308698426, 0.1507116093826361, 0.09832234398916928]; 
         FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
         MathLink`CallFrontEnd[
           FrontEnd`AttachCell[Typeset`box$, 
            FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
            Left, Top}, 
            "ClosingActions" -> {
             "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
      DefaultBaseStyle->{},
      Evaluator->Automatic,
      Method->"Preemptive"],
     RGBColor[{0.9573167308698426, 0.1507116093826361, 0.09832234398916928}],
     Editable->False,
     Selectable->False], ",", 
    InterpretationBox[
     ButtonBox[
      TooltipBox[
       GraphicsBox[{
         {GrayLevel[0], RectangleBox[{0, 0}]}, 
         {GrayLevel[0], RectangleBox[{1, -1}]}, 
         {RGBColor[
          0.04278634258158939, 0.9055378427790535, 0.0003309996431954121], 
          RectangleBox[{0, -1}, {2, 1}]}},
        AspectRatio->1,
        Frame->True,
        FrameStyle->RGBColor[
         0.028524228387726263`, 0.6036918951860357, 0.0002206664287969414],
        FrameTicks->None,
        ImageSize->
         Dynamic[{
          Automatic, 
           1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
            Magnification])}],
        PlotRangePadding->None],
       "RGBColor[{0.04278634258158939, 0.9055378427790535, \
0.0003309996431954121}]"],
      Appearance->None,
      BaseStyle->{},
      BaselinePosition->Baseline,
      ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
        If[
         Not[
          AbsoluteCurrentValue["Deployed"]], 
         SelectionMove[Typeset`box$, All, Expression]; 
         FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
         FrontEnd`Private`$ColorSelectorInitialColor = 
          RGBColor[
           0.04278634258158939, 0.9055378427790535, 0.0003309996431954121]; 
         FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
         MathLink`CallFrontEnd[
           FrontEnd`AttachCell[Typeset`box$, 
            FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
            Left, Top}, 
            "ClosingActions" -> {
             "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
      DefaultBaseStyle->{},
      Evaluator->Automatic,
      Method->"Preemptive"],
     RGBColor[{0.04278634258158939, 0.9055378427790535, 
      0.0003309996431954121}],
     Editable->False,
     Selectable->False], ",", 
    InterpretationBox[
     ButtonBox[
      TooltipBox[
       GraphicsBox[{
         {GrayLevel[0], RectangleBox[{0, 0}]}, 
         {GrayLevel[0], RectangleBox[{1, -1}]}, 
         {RGBColor[
          0.8058039405531526, 0.8318774133774354, 0.10151558699591279`], 
          RectangleBox[{0, -1}, {2, 1}]}},
        AspectRatio->1,
        Frame->True,
        FrameStyle->RGBColor[
         0.5372026270354351, 0.5545849422516236, 0.06767705799727519],
        FrameTicks->None,
        ImageSize->
         Dynamic[{
          Automatic, 
           1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
            Magnification])}],
        PlotRangePadding->None],
       "RGBColor[{0.8058039405531526, 0.8318774133774354, \
0.10151558699591279}]"],
      Appearance->None,
      BaseStyle->{},
      BaselinePosition->Baseline,
      ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
        If[
         Not[
          AbsoluteCurrentValue["Deployed"]], 
         SelectionMove[Typeset`box$, All, Expression]; 
         FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
         FrontEnd`Private`$ColorSelectorInitialColor = 
          RGBColor[
           0.8058039405531526, 0.8318774133774354, 0.10151558699591279`]; 
         FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
         MathLink`CallFrontEnd[
           FrontEnd`AttachCell[Typeset`box$, 
            FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
            Left, Top}, 
            "ClosingActions" -> {
             "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
      DefaultBaseStyle->{},
      Evaluator->Automatic,
      Method->"Preemptive"],
     RGBColor[{0.8058039405531526, 0.8318774133774354, 0.10151558699591279`}],
     
     Editable->False,
     Selectable->False], ",", 
    InterpretationBox[
     ButtonBox[
      TooltipBox[
       GraphicsBox[{
         {GrayLevel[0], RectangleBox[{0, 0}]}, 
         {GrayLevel[0], RectangleBox[{1, -1}]}, 
         {RGBColor[
          0.006814389873512461, 0.9336694049188562, 0.06907220235176909], 
          RectangleBox[{0, -1}, {2, 1}]}},
        AspectRatio->1,
        Frame->True,
        FrameStyle->RGBColor[
         0.004542926582341641, 0.6224462699459041, 0.04604813490117939],
        FrameTicks->None,
        ImageSize->
         Dynamic[{
          Automatic, 
           1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
            Magnification])}],
        PlotRangePadding->None],
       "RGBColor[{0.006814389873512461, 0.9336694049188562, \
0.06907220235176909}]"],
      Appearance->None,
      BaseStyle->{},
      BaselinePosition->Baseline,
      ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
        If[
         Not[
          AbsoluteCurrentValue["Deployed"]], 
         SelectionMove[Typeset`box$, All, Expression]; 
         FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
         FrontEnd`Private`$ColorSelectorInitialColor = 
          RGBColor[
           0.006814389873512461, 0.9336694049188562, 0.06907220235176909]; 
         FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
         MathLink`CallFrontEnd[
           FrontEnd`AttachCell[Typeset`box$, 
            FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
            Left, Top}, 
            "ClosingActions" -> {
             "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
      DefaultBaseStyle->{},
      Evaluator->Automatic,
      Method->"Preemptive"],
     RGBColor[{0.006814389873512461, 0.9336694049188562, 0.06907220235176909}],
     Editable->False,
     Selectable->False], ",", 
    InterpretationBox[
     ButtonBox[
      TooltipBox[
       GraphicsBox[{
         {GrayLevel[0], RectangleBox[{0, 0}]}, 
         {GrayLevel[0], RectangleBox[{1, -1}]}, 
         {RGBColor[
          0.9450158125329948, 0.9670907305400336, 0.05040029871534907], 
          RectangleBox[{0, -1}, {2, 1}]}},
        AspectRatio->1,
        Frame->True,
        FrameStyle->RGBColor[
         0.6300105416886632, 0.6447271536933558, 0.033600199143566045`],
        FrameTicks->None,
        ImageSize->
         Dynamic[{
          Automatic, 
           1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
            Magnification])}],
        PlotRangePadding->None],
       "RGBColor[{0.9450158125329948, 0.9670907305400336, \
0.05040029871534907}]"],
      Appearance->None,
      BaseStyle->{},
      BaselinePosition->Baseline,
      ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
        If[
         Not[
          AbsoluteCurrentValue["Deployed"]], 
         SelectionMove[Typeset`box$, All, Expression]; 
         FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
         FrontEnd`Private`$ColorSelectorInitialColor = 
          RGBColor[
           0.9450158125329948, 0.9670907305400336, 0.05040029871534907]; 
         FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
         MathLink`CallFrontEnd[
           FrontEnd`AttachCell[Typeset`box$, 
            FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
            Left, Top}, 
            "ClosingActions" -> {
             "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
      DefaultBaseStyle->{},
      Evaluator->Automatic,
      Method->"Preemptive"],
     RGBColor[{0.9450158125329948, 0.9670907305400336, 0.05040029871534907}],
     Editable->False,
     Selectable->False], ",", 
    InterpretationBox[
     ButtonBox[
      TooltipBox[
       GraphicsBox[{
         {GrayLevel[0], RectangleBox[{0, 0}]}, 
         {GrayLevel[0], RectangleBox[{1, -1}]}, 
         {RGBColor[
          0.9752641706478989, 0.8013981246170678, 0.10899973580393796`], 
          RectangleBox[{0, -1}, {2, 1}]}},
        AspectRatio->1,
        Frame->True,
        FrameStyle->RGBColor[
         0.650176113765266, 0.5342654164113786, 0.07266649053595864],
        FrameTicks->None,
        ImageSize->
         Dynamic[{
          Automatic, 
           1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
            Magnification])}],
        PlotRangePadding->None],
       "RGBColor[{0.9752641706478989, 0.8013981246170678, \
0.10899973580393796}]"],
      Appearance->None,
      BaseStyle->{},
      BaselinePosition->Baseline,
      ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
        If[
         Not[
          AbsoluteCurrentValue["Deployed"]], 
         SelectionMove[Typeset`box$, All, Expression]; 
         FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
         FrontEnd`Private`$ColorSelectorInitialColor = 
          RGBColor[
           0.9752641706478989, 0.8013981246170678, 0.10899973580393796`]; 
         FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
         MathLink`CallFrontEnd[
           FrontEnd`AttachCell[Typeset`box$, 
            FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
            Left, Top}, 
            "ClosingActions" -> {
             "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
      DefaultBaseStyle->{},
      Evaluator->Automatic,
      Method->"Preemptive"],
     RGBColor[{0.9752641706478989, 0.8013981246170678, 0.10899973580393796`}],
     
     Editable->False,
     Selectable->False], ",", 
    InterpretationBox[
     ButtonBox[
      TooltipBox[
       GraphicsBox[{
         {GrayLevel[0], RectangleBox[{0, 0}]}, 
         {GrayLevel[0], RectangleBox[{1, -1}]}, 
         {RGBColor[
          0.16590548598015492`, 0.9015045495499641, 0.09828783196817376], 
          RectangleBox[{0, -1}, {2, 1}]}},
        AspectRatio->1,
        Frame->True,
        FrameStyle->RGBColor[
         0.11060365732010329`, 0.6010030330333094, 0.06552522131211584],
        FrameTicks->None,
        ImageSize->
         Dynamic[{
          Automatic, 
           1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
            Magnification])}],
        PlotRangePadding->None],
       "RGBColor[{0.16590548598015492, 0.9015045495499641, \
0.09828783196817376}]"],
      Appearance->None,
      BaseStyle->{},
      BaselinePosition->Baseline,
      ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
        If[
         Not[
          AbsoluteCurrentValue["Deployed"]], 
         SelectionMove[Typeset`box$, All, Expression]; 
         FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
         FrontEnd`Private`$ColorSelectorInitialColor = 
          RGBColor[
           0.16590548598015492`, 0.9015045495499641, 0.09828783196817376]; 
         FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
         MathLink`CallFrontEnd[
           FrontEnd`AttachCell[Typeset`box$, 
            FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
            Left, Top}, 
            "ClosingActions" -> {
             "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
      DefaultBaseStyle->{},
      Evaluator->Automatic,
      Method->"Preemptive"],
     RGBColor[{0.16590548598015492`, 0.9015045495499641, 0.09828783196817376}],
     Editable->False,
     Selectable->False], ",", 
    InterpretationBox[
     ButtonBox[
      TooltipBox[
       GraphicsBox[{
         {GrayLevel[0], RectangleBox[{0, 0}]}, 
         {GrayLevel[0], RectangleBox[{1, -1}]}, 
         {RGBColor[
          0.10048980936842117`, 0.9171495192304465, 0.16131399976146749`], 
          RectangleBox[{0, -1}, {2, 1}]}},
        AspectRatio->1,
        Frame->True,
        FrameStyle->RGBColor[
         0.06699320624561411, 0.6114330128202977, 0.10754266650764499`],
        FrameTicks->None,
        ImageSize->
         Dynamic[{
          Automatic, 
           1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
            Magnification])}],
        PlotRangePadding->None],
       "RGBColor[{0.10048980936842117, 0.9171495192304465, \
0.16131399976146749}]"],
      Appearance->None,
      BaseStyle->{},
      BaselinePosition->Baseline,
      ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
        If[
         Not[
          AbsoluteCurrentValue["Deployed"]], 
         SelectionMove[Typeset`box$, All, Expression]; 
         FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
         FrontEnd`Private`$ColorSelectorInitialColor = 
          RGBColor[
           0.10048980936842117`, 0.9171495192304465, 0.16131399976146749`]; 
         FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
         MathLink`CallFrontEnd[
           FrontEnd`AttachCell[Typeset`box$, 
            FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
            Left, Top}, 
            "ClosingActions" -> {
             "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
      DefaultBaseStyle->{},
      Evaluator->Automatic,
      Method->"Preemptive"],
     RGBColor[{0.10048980936842117`, 0.9171495192304465, 
      0.16131399976146749`}],
     Editable->False,
     Selectable->False]}], "}"}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[20]:=",ExpressionUUID->"ebe62368-0d62-4063-ab63-8d9e4c94cb74"],

Cell[BoxData[
 GraphicsBox[{
   {GrayLevel[0.65], 
    LineBox[{{{234.1796875, 0.6134661832729911}, {234.1796875, 
      1.1911923822547177`}}, {{463.375, 0.1396839784478906}, {463.375, 
      1.1911923822547177`}}, {{234.1796875, 1.1911923822547177`}, {463.375, 
      1.1911923822547177`}}, {{152.796875, 0.11441796057835507`}, {152.796875,
       0.6134661832729911}}, {{315.5625, 0.18834740531608185`}, {315.5625, 
      0.6134661832729911}}, {{152.796875, 0.6134661832729911}, {315.5625, 
      0.6134661832729911}}, {{129.59375, 0.06851690328878257}, {129.59375, 
      0.11441796057835507`}}, {{176, 0}, {176., 0.11441796057835507`}}, {{
      129.59375, 0.11441796057835507`}, {176., 0.11441796057835507`}}, {{
      105.1875, 0.05316891350238806}, {105.1875, 
      0.06851690328878257}}, {{154, 0}, {154., 0.06851690328878257}}, {{
      105.1875, 0.06851690328878257}, {154., 0.06851690328878257}}, {{78.375, 
      0.042644427975150445`}, {78.375, 
      0.05316891350238806}}, {{132, 0}, {132., 0.05316891350238806}}, {{
      78.375, 0.05316891350238806}, {132., 0.05316891350238806}}, {{46.75, 
      0.041641475041539366`}, {46.75, 
      0.042644427975150445`}}, {{110, 0}, {110., 0.042644427975150445`}}, {{
      46.75, 0.042644427975150445`}, {110., 
      0.042644427975150445`}}, {{22, 0}, {22., 0.041641475041539366`}}, {{
      71.5, 0.03916898492961829}, {71.5, 0.041641475041539366`}}, {{22., 
      0.041641475041539366`}, {71.5, 0.041641475041539366`}}, {{55., 
      0.008958867580810437}, {55., 
      0.03916898492961829}}, {{88, 0}, {88., 0.03916898492961829}}, {{55., 
      0.03916898492961829}, {88., 
      0.03916898492961829}}, {{44, 0}, {44., 0.008958867580810437}}, {{66, 
       0}, {66., 0.008958867580810437}}, {{44., 0.008958867580810437}, {66., 
      0.008958867580810437}}, {{268.125, 0.11764828142854589`}, {268.125, 
      0.18834740531608185`}}, {{363., 0.05912568371791316}, {363., 
      0.18834740531608185`}}, {{268.125, 0.18834740531608185`}, {363., 
      0.18834740531608185`}}, {{225.5, 0.07185802418920663}, {225.5, 
      0.11764828142854589`}}, {{310.75, 0.10579801665602129`}, {310.75, 
      0.11764828142854589`}}, {{225.5, 0.11764828142854589`}, {310.75, 
      0.11764828142854589`}}, {{209., 0.05091938716612808}, {209., 
      0.07185802418920663}}, {{242, 0}, {242., 0.07185802418920663}}, {{209., 
      0.07185802418920663}, {242., 
      0.07185802418920663}}, {{198, 0}, {198., 0.05091938716612808}}, {{220, 
       0}, {220., 0.05091938716612808}}, {{198., 0.05091938716612808}, {220., 
      0.05091938716612808}}, {{291.5, 0.10519222806091078`}, {291.5, 
      0.10579801665602129`}}, {{330, 0}, {330., 0.10579801665602129`}}, {{
      291.5, 0.10579801665602129`}, {330., 0.10579801665602129`}}, {{275., 
      0.10398437807219396`}, {275., 
      0.10519222806091078`}}, {{308, 0}, {308., 0.10519222806091078`}}, {{
      275., 0.10519222806091078`}, {308., 
      0.10519222806091078`}}, {{264, 0}, {264., 0.10398437807219396`}}, {{286,
        0}, {286., 0.10398437807219396`}}, {{264., 0.10398437807219396`}, {
      286., 0.10398437807219396`}}, {{352, 0}, {352., 
       0.05912568371791316}}, {{374, 0}, {374., 0.05912568371791316}}, {{352.,
       0.05912568371791316}, {374., 0.05912568371791316}}, {{442.75, 
      0.10213059805754876`}, {442.75, 
      0.1396839784478906}}, {{484, 0}, {484., 0.1396839784478906}}, {{442.75, 
      0.1396839784478906}, {484., 0.1396839784478906}}, {{423.5, 
      0.0724066793948489}, {423.5, 
      0.10213059805754876`}}, {{462, 0}, {462., 0.10213059805754876`}}, {{
      423.5, 0.10213059805754876`}, {462., 0.10213059805754876`}}, {{407., 
      0.02247841173441628}, {407., 
      0.0724066793948489}}, {{440, 0}, {440., 0.0724066793948489}}, {{407., 
      0.0724066793948489}, {440., 
      0.0724066793948489}}, {{396, 0}, {396., 0.02247841173441628}}, {{418, 
       0}, {418., 0.02247841173441628}}, {{396., 0.02247841173441628}, {418., 
      0.02247841173441628}}}]}, InsetBox[
    FrameBox[
     TagBox[
      InterpretationBox[
       ButtonBox[
        TooltipBox[
         GraphicsBox[{
           {GrayLevel[0], RectangleBox[{0, 0}]}, 
           {GrayLevel[0], RectangleBox[{1, -1}]}, 
           {RGBColor[
            0.048175746346922704`, 0.8856231902848692, 0.002187262571789972], 
            RectangleBox[{0, -1}, {2, 1}]}},
          AspectRatio->1,
          Frame->True,
          
          FrameStyle->RGBColor[
           0.0321171642312818, 0.5904154601899129, 0.0014581750478599813`],
          FrameTicks->None,
          
          ImageSize->
           Dynamic[{
            Automatic, 
             1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
              Magnification])}],
          PlotRangePadding->None],
         "RGBColor[{0.048175746346922704, 0.8856231902848692, \
0.002187262571789972}]"],
        Appearance->None,
        BaseStyle->{},
        BaselinePosition->Baseline,
        ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
          If[
           Not[
            AbsoluteCurrentValue["Deployed"]], 
           SelectionMove[Typeset`box$, All, Expression]; 
           FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
           FrontEnd`Private`$ColorSelectorInitialColor = 
            RGBColor[
             0.048175746346922704`, 0.8856231902848692, 0.002187262571789972]; 
           FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
           MathLink`CallFrontEnd[
             FrontEnd`AttachCell[Typeset`box$, 
              FrontEndResource["RGBColorValueSelector"], {
              0, {Left, Bottom}}, {Left, Top}, 
              "ClosingActions" -> {
               "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
        DefaultBaseStyle->{},
        Evaluator->Automatic,
        Method->"Preemptive"],
       RGBColor[{0.048175746346922704`, 0.8856231902848692, 
        0.002187262571789972}],
       Editable->False,
       Selectable->False],
      Short],
     Background->GrayLevel[1],
     FrameMargins->{{0, 0}, {0, 0}},
     FrameStyle->GrayLevel[1],
     RoundingRadius->2,
     StripOnInput->False], {22, 0}, Scaled[{0.5, 1}]], InsetBox[
    FrameBox[
     TagBox[
      InterpretationBox[
       ButtonBox[
        TooltipBox[
         GraphicsBox[{
           {GrayLevel[0], RectangleBox[{0, 0}]}, 
           {GrayLevel[0], RectangleBox[{1, -1}]}, 
           {RGBColor[
            0.06423181065333894, 0.9361486399945784, 0.08411970647251821], 
            RectangleBox[{0, -1}, {2, 1}]}},
          AspectRatio->1,
          Frame->True,
          
          FrameStyle->RGBColor[
           0.042821207102225964`, 0.624099093329719, 0.05607980431501214],
          FrameTicks->None,
          
          ImageSize->
           Dynamic[{
            Automatic, 
             1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
              Magnification])}],
          PlotRangePadding->None],
         "RGBColor[{0.06423181065333894, 0.9361486399945784, \
0.08411970647251821}]"],
        Appearance->None,
        BaseStyle->{},
        BaselinePosition->Baseline,
        ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
          If[
           Not[
            AbsoluteCurrentValue["Deployed"]], 
           SelectionMove[Typeset`box$, All, Expression]; 
           FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
           FrontEnd`Private`$ColorSelectorInitialColor = 
            RGBColor[
             0.06423181065333894, 0.9361486399945784, 0.08411970647251821]; 
           FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
           MathLink`CallFrontEnd[
             FrontEnd`AttachCell[Typeset`box$, 
              FrontEndResource["RGBColorValueSelector"], {
              0, {Left, Bottom}}, {Left, Top}, 
              "ClosingActions" -> {
               "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
        DefaultBaseStyle->{},
        Evaluator->Automatic,
        Method->"Preemptive"],
       RGBColor[{0.06423181065333894, 0.9361486399945784, 
        0.08411970647251821}],
       Editable->False,
       Selectable->False],
      Short],
     Background->GrayLevel[1],
     FrameMargins->{{0, 0}, {0, 0}},
     FrameStyle->GrayLevel[1],
     RoundingRadius->2,
     StripOnInput->False], {44, 0}, Scaled[{0.5, 1}]], InsetBox[
    FrameBox[
     TagBox[
      InterpretationBox[
       ButtonBox[
        TooltipBox[
         GraphicsBox[{
           {GrayLevel[0], RectangleBox[{0, 0}]}, 
           {GrayLevel[0], RectangleBox[{1, -1}]}, 
           {RGBColor[
            0.006814389873512461, 0.9336694049188562, 0.06907220235176909], 
            RectangleBox[{0, -1}, {2, 1}]}},
          AspectRatio->1,
          Frame->True,
          
          FrameStyle->RGBColor[
           0.004542926582341641, 0.6224462699459041, 0.04604813490117939],
          FrameTicks->None,
          
          ImageSize->
           Dynamic[{
            Automatic, 
             1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
              Magnification])}],
          PlotRangePadding->None],
         "RGBColor[{0.006814389873512461, 0.9336694049188562, \
0.06907220235176909}]"],
        Appearance->None,
        BaseStyle->{},
        BaselinePosition->Baseline,
        ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
          If[
           Not[
            AbsoluteCurrentValue["Deployed"]], 
           SelectionMove[Typeset`box$, All, Expression]; 
           FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
           FrontEnd`Private`$ColorSelectorInitialColor = 
            RGBColor[
             0.006814389873512461, 0.9336694049188562, 0.06907220235176909]; 
           FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
           MathLink`CallFrontEnd[
             FrontEnd`AttachCell[Typeset`box$, 
              FrontEndResource["RGBColorValueSelector"], {
              0, {Left, Bottom}}, {Left, Top}, 
              "ClosingActions" -> {
               "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
        DefaultBaseStyle->{},
        Evaluator->Automatic,
        Method->"Preemptive"],
       RGBColor[{0.006814389873512461, 0.9336694049188562, 
        0.06907220235176909}],
       Editable->False,
       Selectable->False],
      Short],
     Background->GrayLevel[1],
     FrameMargins->{{0, 0}, {0, 0}},
     FrameStyle->GrayLevel[1],
     RoundingRadius->2,
     StripOnInput->False], {66, 0}, Scaled[{0.5, 1}]], InsetBox[
    FrameBox[
     TagBox[
      InterpretationBox[
       ButtonBox[
        TooltipBox[
         GraphicsBox[{
           {GrayLevel[0], RectangleBox[{0, 0}]}, 
           {GrayLevel[0], RectangleBox[{1, -1}]}, 
           {RGBColor[
            0.04278634258158939, 0.9055378427790535, 0.0003309996431954121], 
            RectangleBox[{0, -1}, {2, 1}]}},
          AspectRatio->1,
          Frame->True,
          
          FrameStyle->RGBColor[
           0.028524228387726263`, 0.6036918951860357, 0.0002206664287969414],
          FrameTicks->None,
          
          ImageSize->
           Dynamic[{
            Automatic, 
             1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
              Magnification])}],
          PlotRangePadding->None],
         "RGBColor[{0.04278634258158939, 0.9055378427790535, \
0.0003309996431954121}]"],
        Appearance->None,
        BaseStyle->{},
        BaselinePosition->Baseline,
        ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
          If[
           Not[
            AbsoluteCurrentValue["Deployed"]], 
           SelectionMove[Typeset`box$, All, Expression]; 
           FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
           FrontEnd`Private`$ColorSelectorInitialColor = 
            RGBColor[
             0.04278634258158939, 0.9055378427790535, 0.0003309996431954121]; 
           FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
           MathLink`CallFrontEnd[
             FrontEnd`AttachCell[Typeset`box$, 
              FrontEndResource["RGBColorValueSelector"], {
              0, {Left, Bottom}}, {Left, Top}, 
              "ClosingActions" -> {
               "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
        DefaultBaseStyle->{},
        Evaluator->Automatic,
        Method->"Preemptive"],
       RGBColor[{0.04278634258158939, 0.9055378427790535, 
        0.0003309996431954121}],
       Editable->False,
       Selectable->False],
      Short],
     Background->GrayLevel[1],
     FrameMargins->{{0, 0}, {0, 0}},
     FrameStyle->GrayLevel[1],
     RoundingRadius->2,
     StripOnInput->False], {88, 0}, Scaled[{0.5, 1}]], InsetBox[
    FrameBox[
     TagBox[
      InterpretationBox[
       ButtonBox[
        TooltipBox[
         GraphicsBox[{
           {GrayLevel[0], RectangleBox[{0, 0}]}, 
           {GrayLevel[0], RectangleBox[{1, -1}]}, 
           {RGBColor[
            0.16590548598015492`, 0.9015045495499641, 0.09828783196817376], 
            RectangleBox[{0, -1}, {2, 1}]}},
          AspectRatio->1,
          Frame->True,
          
          FrameStyle->RGBColor[
           0.11060365732010329`, 0.6010030330333094, 0.06552522131211584],
          FrameTicks->None,
          
          ImageSize->
           Dynamic[{
            Automatic, 
             1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
              Magnification])}],
          PlotRangePadding->None],
         "RGBColor[{0.16590548598015492, 0.9015045495499641, \
0.09828783196817376}]"],
        Appearance->None,
        BaseStyle->{},
        BaselinePosition->Baseline,
        ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
          If[
           Not[
            AbsoluteCurrentValue["Deployed"]], 
           SelectionMove[Typeset`box$, All, Expression]; 
           FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
           FrontEnd`Private`$ColorSelectorInitialColor = 
            RGBColor[
             0.16590548598015492`, 0.9015045495499641, 0.09828783196817376]; 
           FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
           MathLink`CallFrontEnd[
             FrontEnd`AttachCell[Typeset`box$, 
              FrontEndResource["RGBColorValueSelector"], {
              0, {Left, Bottom}}, {Left, Top}, 
              "ClosingActions" -> {
               "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
        DefaultBaseStyle->{},
        Evaluator->Automatic,
        Method->"Preemptive"],
       RGBColor[{0.16590548598015492`, 0.9015045495499641, 
        0.09828783196817376}],
       Editable->False,
       Selectable->False],
      Short],
     Background->GrayLevel[1],
     FrameMargins->{{0, 0}, {0, 0}},
     FrameStyle->GrayLevel[1],
     RoundingRadius->2,
     StripOnInput->False], {110, 0}, Scaled[{0.5, 1}]], InsetBox[
    FrameBox[
     TagBox[
      InterpretationBox[
       ButtonBox[
        TooltipBox[
         GraphicsBox[{
           {GrayLevel[0], RectangleBox[{0, 0}]}, 
           {GrayLevel[0], RectangleBox[{1, -1}]}, 
           {RGBColor[
            0.10048980936842117`, 0.9171495192304465, 0.16131399976146749`], 
            RectangleBox[{0, -1}, {2, 1}]}},
          AspectRatio->1,
          Frame->True,
          
          FrameStyle->RGBColor[
           0.06699320624561411, 0.6114330128202977, 0.10754266650764499`],
          FrameTicks->None,
          
          ImageSize->
           Dynamic[{
            Automatic, 
             1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
              Magnification])}],
          PlotRangePadding->None],
         "RGBColor[{0.10048980936842117, 0.9171495192304465, \
0.16131399976146749}]"],
        Appearance->None,
        BaseStyle->{},
        BaselinePosition->Baseline,
        ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
          If[
           Not[
            AbsoluteCurrentValue["Deployed"]], 
           SelectionMove[Typeset`box$, All, Expression]; 
           FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
           FrontEnd`Private`$ColorSelectorInitialColor = 
            RGBColor[
             0.10048980936842117`, 0.9171495192304465, 0.16131399976146749`]; 
           FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
           MathLink`CallFrontEnd[
             FrontEnd`AttachCell[Typeset`box$, 
              FrontEndResource["RGBColorValueSelector"], {
              0, {Left, Bottom}}, {Left, Top}, 
              "ClosingActions" -> {
               "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
        DefaultBaseStyle->{},
        Evaluator->Automatic,
        Method->"Preemptive"],
       RGBColor[{0.10048980936842117`, 0.9171495192304465, 
        0.16131399976146749`}],
       Editable->False,
       Selectable->False],
      Short],
     Background->GrayLevel[1],
     FrameMargins->{{0, 0}, {0, 0}},
     FrameStyle->GrayLevel[1],
     RoundingRadius->2,
     StripOnInput->False], {132, 0}, Scaled[{0.5, 1}]], InsetBox[
    FrameBox[
     TagBox[
      InterpretationBox[
       ButtonBox[
        TooltipBox[
         GraphicsBox[{
           {GrayLevel[0], RectangleBox[{0, 0}]}, 
           {GrayLevel[0], RectangleBox[{1, -1}]}, 
           {RGBColor[
            0.14189318640501342`, 0.8685451286121387, 0.10426943556314977`], 
            RectangleBox[{0, -1}, {2, 1}]}},
          AspectRatio->1,
          Frame->True,
          
          FrameStyle->RGBColor[
           0.09459545760334229, 0.5790300857414259, 0.06951295704209985],
          FrameTicks->None,
          
          ImageSize->
           Dynamic[{
            Automatic, 
             1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
              Magnification])}],
          PlotRangePadding->None],
         "RGBColor[{0.14189318640501342, 0.8685451286121387, \
0.10426943556314977}]"],
        Appearance->None,
        BaseStyle->{},
        BaselinePosition->Baseline,
        ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
          If[
           Not[
            AbsoluteCurrentValue["Deployed"]], 
           SelectionMove[Typeset`box$, All, Expression]; 
           FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
           FrontEnd`Private`$ColorSelectorInitialColor = 
            RGBColor[
             0.14189318640501342`, 0.8685451286121387, 0.10426943556314977`]; 
           FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
           MathLink`CallFrontEnd[
             FrontEnd`AttachCell[Typeset`box$, 
              FrontEndResource["RGBColorValueSelector"], {
              0, {Left, Bottom}}, {Left, Top}, 
              "ClosingActions" -> {
               "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
        DefaultBaseStyle->{},
        Evaluator->Automatic,
        Method->"Preemptive"],
       RGBColor[{0.14189318640501342`, 0.8685451286121387, 
        0.10426943556314977`}],
       Editable->False,
       Selectable->False],
      Short],
     Background->GrayLevel[1],
     FrameMargins->{{0, 0}, {0, 0}},
     FrameStyle->GrayLevel[1],
     RoundingRadius->2,
     StripOnInput->False], {154, 0}, Scaled[{0.5, 1}]], InsetBox[
    FrameBox[
     TagBox[
      InterpretationBox[
       ButtonBox[
        TooltipBox[
         GraphicsBox[{
           {GrayLevel[0], RectangleBox[{0, 0}]}, 
           {GrayLevel[0], RectangleBox[{1, -1}]}, 
           {RGBColor[
            0.12965437429396431`, 0.8338364200576898, 0.16859742903104202`], 
            RectangleBox[{0, -1}, {2, 1}]}},
          AspectRatio->1,
          Frame->True,
          
          FrameStyle->RGBColor[
           0.08643624952930955, 0.5558909467051265, 0.11239828602069468`],
          FrameTicks->None,
          
          ImageSize->
           Dynamic[{
            Automatic, 
             1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
              Magnification])}],
          PlotRangePadding->None],
         "RGBColor[{0.12965437429396431, 0.8338364200576898, \
0.16859742903104202}]"],
        Appearance->None,
        BaseStyle->{},
        BaselinePosition->Baseline,
        ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
          If[
           Not[
            AbsoluteCurrentValue["Deployed"]], 
           SelectionMove[Typeset`box$, All, Expression]; 
           FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
           FrontEnd`Private`$ColorSelectorInitialColor = 
            RGBColor[
             0.12965437429396431`, 0.8338364200576898, 0.16859742903104202`]; 
           FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
           MathLink`CallFrontEnd[
             FrontEnd`AttachCell[Typeset`box$, 
              FrontEndResource["RGBColorValueSelector"], {
              0, {Left, Bottom}}, {Left, Top}, 
              "ClosingActions" -> {
               "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
        DefaultBaseStyle->{},
        Evaluator->Automatic,
        Method->"Preemptive"],
       RGBColor[{0.12965437429396431`, 0.8338364200576898, 
        0.16859742903104202`}],
       Editable->False,
       Selectable->False],
      Short],
     Background->GrayLevel[1],
     FrameMargins->{{0, 0}, {0, 0}},
     FrameStyle->GrayLevel[1],
     RoundingRadius->2,
     StripOnInput->False], {176, 0}, Scaled[{0.5, 1}]], InsetBox[
    FrameBox[
     TagBox[
      InterpretationBox[
       ButtonBox[
        TooltipBox[
         GraphicsBox[{
           {GrayLevel[0], RectangleBox[{0, 0}]}, 
           {GrayLevel[0], RectangleBox[{1, -1}]}, 
           {RGBColor[
            0.9543437880041175, 0.9364915417894851, 0.08314980598714755], 
            RectangleBox[{0, -1}, {2, 1}]}},
          AspectRatio->1,
          Frame->True,
          
          FrameStyle->RGBColor[
           0.636229192002745, 0.6243276945263234, 0.0554332039914317],
          FrameTicks->None,
          
          ImageSize->
           Dynamic[{
            Automatic, 
             1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
              Magnification])}],
          PlotRangePadding->None],
         "RGBColor[{0.9543437880041175, 0.9364915417894851, \
0.08314980598714755}]"],
        Appearance->None,
        BaseStyle->{},
        BaselinePosition->Baseline,
        ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
          If[
           Not[
            AbsoluteCurrentValue["Deployed"]], 
           SelectionMove[Typeset`box$, All, Expression]; 
           FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
           FrontEnd`Private`$ColorSelectorInitialColor = 
            RGBColor[
             0.9543437880041175, 0.9364915417894851, 0.08314980598714755]; 
           FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
           MathLink`CallFrontEnd[
             FrontEnd`AttachCell[Typeset`box$, 
              FrontEndResource["RGBColorValueSelector"], {
              0, {Left, Bottom}}, {Left, Top}, 
              "ClosingActions" -> {
               "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
        DefaultBaseStyle->{},
        Evaluator->Automatic,
        Method->"Preemptive"],
       RGBColor[{0.9543437880041175, 0.9364915417894851, 0.08314980598714755}],
       Editable->False,
       Selectable->False],
      Short],
     Background->GrayLevel[1],
     FrameMargins->{{0, 0}, {0, 0}},
     FrameStyle->GrayLevel[1],
     RoundingRadius->2,
     StripOnInput->False], {198, 0}, Scaled[{0.5, 1}]], InsetBox[
    FrameBox[
     TagBox[
      InterpretationBox[
       ButtonBox[
        TooltipBox[
         GraphicsBox[{
           {GrayLevel[0], RectangleBox[{0, 0}]}, 
           {GrayLevel[0], RectangleBox[{1, -1}]}, 
           {RGBColor[
            0.9967431643372854, 0.969475575859666, 0.12251095291379577`], 
            RectangleBox[{0, -1}, {2, 1}]}},
          AspectRatio->1,
          Frame->True,
          
          FrameStyle->RGBColor[
           0.6644954428915236, 0.6463170505731107, 0.08167396860919718],
          FrameTicks->None,
          
          ImageSize->
           Dynamic[{
            Automatic, 
             1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
              Magnification])}],
          PlotRangePadding->None],
         "RGBColor[{0.9967431643372854, 0.969475575859666, \
0.12251095291379577}]"],
        Appearance->None,
        BaseStyle->{},
        BaselinePosition->Baseline,
        ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
          If[
           Not[
            AbsoluteCurrentValue["Deployed"]], 
           SelectionMove[Typeset`box$, All, Expression]; 
           FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
           FrontEnd`Private`$ColorSelectorInitialColor = 
            RGBColor[
             0.9967431643372854, 0.969475575859666, 0.12251095291379577`]; 
           FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
           MathLink`CallFrontEnd[
             FrontEnd`AttachCell[Typeset`box$, 
              FrontEndResource["RGBColorValueSelector"], {
              0, {Left, Bottom}}, {Left, Top}, 
              "ClosingActions" -> {
               "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
        DefaultBaseStyle->{},
        Evaluator->Automatic,
        Method->"Preemptive"],
       RGBColor[{0.9967431643372854, 0.969475575859666, 0.12251095291379577`}],
       Editable->False,
       Selectable->False],
      Short],
     Background->GrayLevel[1],
     FrameMargins->{{0, 0}, {0, 0}},
     FrameStyle->GrayLevel[1],
     RoundingRadius->2,
     StripOnInput->False], {220, 0}, Scaled[{0.5, 1}]], InsetBox[
    FrameBox[
     TagBox[
      InterpretationBox[
       ButtonBox[
        TooltipBox[
         GraphicsBox[{
           {GrayLevel[0], RectangleBox[{0, 0}]}, 
           {GrayLevel[0], RectangleBox[{1, -1}]}, 
           {RGBColor[
            0.9450158125329948, 0.9670907305400336, 0.05040029871534907], 
            RectangleBox[{0, -1}, {2, 1}]}},
          AspectRatio->1,
          Frame->True,
          
          FrameStyle->RGBColor[
           0.6300105416886632, 0.6447271536933558, 0.033600199143566045`],
          FrameTicks->None,
          
          ImageSize->
           Dynamic[{
            Automatic, 
             1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
              Magnification])}],
          PlotRangePadding->None],
         "RGBColor[{0.9450158125329948, 0.9670907305400336, \
0.05040029871534907}]"],
        Appearance->None,
        BaseStyle->{},
        BaselinePosition->Baseline,
        ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
          If[
           Not[
            AbsoluteCurrentValue["Deployed"]], 
           SelectionMove[Typeset`box$, All, Expression]; 
           FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
           FrontEnd`Private`$ColorSelectorInitialColor = 
            RGBColor[
             0.9450158125329948, 0.9670907305400336, 0.05040029871534907]; 
           FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
           MathLink`CallFrontEnd[
             FrontEnd`AttachCell[Typeset`box$, 
              FrontEndResource["RGBColorValueSelector"], {
              0, {Left, Bottom}}, {Left, Top}, 
              "ClosingActions" -> {
               "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
        DefaultBaseStyle->{},
        Evaluator->Automatic,
        Method->"Preemptive"],
       RGBColor[{0.9450158125329948, 0.9670907305400336, 0.05040029871534907}],
       Editable->False,
       Selectable->False],
      Short],
     Background->GrayLevel[1],
     FrameMargins->{{0, 0}, {0, 0}},
     FrameStyle->GrayLevel[1],
     RoundingRadius->2,
     StripOnInput->False], {242, 0}, Scaled[{0.5, 1}]], InsetBox[
    FrameBox[
     TagBox[
      InterpretationBox[
       ButtonBox[
        TooltipBox[
         GraphicsBox[{
           {GrayLevel[0], RectangleBox[{0, 0}]}, 
           {GrayLevel[0], RectangleBox[{1, -1}]}, 
           {RGBColor[
            0.8058039405531526, 0.8318774133774354, 0.10151558699591279`], 
            RectangleBox[{0, -1}, {2, 1}]}},
          AspectRatio->1,
          Frame->True,
          
          FrameStyle->RGBColor[
           0.5372026270354351, 0.5545849422516236, 0.06767705799727519],
          FrameTicks->None,
          
          ImageSize->
           Dynamic[{
            Automatic, 
             1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
              Magnification])}],
          PlotRangePadding->None],
         "RGBColor[{0.8058039405531526, 0.8318774133774354, \
0.10151558699591279}]"],
        Appearance->None,
        BaseStyle->{},
        BaselinePosition->Baseline,
        ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
          If[
           Not[
            AbsoluteCurrentValue["Deployed"]], 
           SelectionMove[Typeset`box$, All, Expression]; 
           FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
           FrontEnd`Private`$ColorSelectorInitialColor = 
            RGBColor[
             0.8058039405531526, 0.8318774133774354, 0.10151558699591279`]; 
           FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
           MathLink`CallFrontEnd[
             FrontEnd`AttachCell[Typeset`box$, 
              FrontEndResource["RGBColorValueSelector"], {
              0, {Left, Bottom}}, {Left, Top}, 
              "ClosingActions" -> {
               "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
        DefaultBaseStyle->{},
        Evaluator->Automatic,
        Method->"Preemptive"],
       RGBColor[{0.8058039405531526, 0.8318774133774354, 
        0.10151558699591279`}],
       Editable->False,
       Selectable->False],
      Short],
     Background->GrayLevel[1],
     FrameMargins->{{0, 0}, {0, 0}},
     FrameStyle->GrayLevel[1],
     RoundingRadius->2,
     StripOnInput->False], {264, 0}, Scaled[{0.5, 1}]], InsetBox[
    FrameBox[
     TagBox[
      InterpretationBox[
       ButtonBox[
        TooltipBox[
         GraphicsBox[{
           {GrayLevel[0], RectangleBox[{0, 0}]}, 
           {GrayLevel[0], RectangleBox[{1, -1}]}, 
           {RGBColor[
            0.8577958146408966, 0.8374035340744639, 0.0071190816223388464`], 
            RectangleBox[{0, -1}, {2, 1}]}},
          AspectRatio->1,
          Frame->True,
          
          FrameStyle->RGBColor[
           0.5718638764272644, 0.5582690227163093, 0.004746054414892564],
          FrameTicks->None,
          
          ImageSize->
           Dynamic[{
            Automatic, 
             1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
              Magnification])}],
          PlotRangePadding->None],
         "RGBColor[{0.8577958146408966, 0.8374035340744639, \
0.0071190816223388464}]"],
        Appearance->None,
        BaseStyle->{},
        BaselinePosition->Baseline,
        ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
          If[
           Not[
            AbsoluteCurrentValue["Deployed"]], 
           SelectionMove[Typeset`box$, All, Expression]; 
           FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
           FrontEnd`Private`$ColorSelectorInitialColor = 
            RGBColor[
             0.8577958146408966, 0.8374035340744639, 0.0071190816223388464`]; 
           FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
           MathLink`CallFrontEnd[
             FrontEnd`AttachCell[Typeset`box$, 
              FrontEndResource["RGBColorValueSelector"], {
              0, {Left, Bottom}}, {Left, Top}, 
              "ClosingActions" -> {
               "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
        DefaultBaseStyle->{},
        Evaluator->Automatic,
        Method->"Preemptive"],
       RGBColor[{0.8577958146408966, 0.8374035340744639, 
        0.0071190816223388464`}],
       Editable->False,
       Selectable->False],
      Short],
     Background->GrayLevel[1],
     FrameMargins->{{0, 0}, {0, 0}},
     FrameStyle->GrayLevel[1],
     RoundingRadius->2,
     StripOnInput->False], {286, 0}, Scaled[{0.5, 1}]], InsetBox[
    FrameBox[
     TagBox[
      InterpretationBox[
       ButtonBox[
        TooltipBox[
         GraphicsBox[{
           {GrayLevel[0], RectangleBox[{0, 0}]}, 
           {GrayLevel[0], RectangleBox[{1, -1}]}, 
           {RGBColor[
            0.8676164929883508, 0.8866580065099905, 0.024086278089002183`], 
            RectangleBox[{0, -1}, {2, 1}]}},
          AspectRatio->1,
          Frame->True,
          
          FrameStyle->RGBColor[
           0.5784109953255672, 0.5911053376733271, 0.016057518726001457`],
          FrameTicks->None,
          
          ImageSize->
           Dynamic[{
            Automatic, 
             1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
              Magnification])}],
          PlotRangePadding->None],
         "RGBColor[{0.8676164929883508, 0.8866580065099905, \
0.024086278089002183}]"],
        Appearance->None,
        BaseStyle->{},
        BaselinePosition->Baseline,
        ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
          If[
           Not[
            AbsoluteCurrentValue["Deployed"]], 
           SelectionMove[Typeset`box$, All, Expression]; 
           FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
           FrontEnd`Private`$ColorSelectorInitialColor = 
            RGBColor[
             0.8676164929883508, 0.8866580065099905, 0.024086278089002183`]; 
           FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
           MathLink`CallFrontEnd[
             FrontEnd`AttachCell[Typeset`box$, 
              FrontEndResource["RGBColorValueSelector"], {
              0, {Left, Bottom}}, {Left, Top}, 
              "ClosingActions" -> {
               "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
        DefaultBaseStyle->{},
        Evaluator->Automatic,
        Method->"Preemptive"],
       RGBColor[{0.8676164929883508, 0.8866580065099905, 
        0.024086278089002183`}],
       Editable->False,
       Selectable->False],
      Short],
     Background->GrayLevel[1],
     FrameMargins->{{0, 0}, {0, 0}},
     FrameStyle->GrayLevel[1],
     RoundingRadius->2,
     StripOnInput->False], {308, 0}, Scaled[{0.5, 1}]], InsetBox[
    FrameBox[
     TagBox[
      InterpretationBox[
       ButtonBox[
        TooltipBox[
         GraphicsBox[{
           {GrayLevel[0], RectangleBox[{0, 0}]}, 
           {GrayLevel[0], RectangleBox[{1, -1}]}, 
           {RGBColor[
            0.8500363984900003, 0.9263311671408848, 0.13924242858059316`], 
            RectangleBox[{0, -1}, {2, 1}]}},
          AspectRatio->1,
          Frame->True,
          
          FrameStyle->RGBColor[
           0.5666909323266669, 0.6175541114272566, 0.09282828572039545],
          FrameTicks->None,
          
          ImageSize->
           Dynamic[{
            Automatic, 
             1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
              Magnification])}],
          PlotRangePadding->None],
         "RGBColor[{0.8500363984900003, 0.9263311671408848, \
0.13924242858059316}]"],
        Appearance->None,
        BaseStyle->{},
        BaselinePosition->Baseline,
        ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
          If[
           Not[
            AbsoluteCurrentValue["Deployed"]], 
           SelectionMove[Typeset`box$, All, Expression]; 
           FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
           FrontEnd`Private`$ColorSelectorInitialColor = 
            RGBColor[
             0.8500363984900003, 0.9263311671408848, 0.13924242858059316`]; 
           FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
           MathLink`CallFrontEnd[
             FrontEnd`AttachCell[Typeset`box$, 
              FrontEndResource["RGBColorValueSelector"], {
              0, {Left, Bottom}}, {Left, Top}, 
              "ClosingActions" -> {
               "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
        DefaultBaseStyle->{},
        Evaluator->Automatic,
        Method->"Preemptive"],
       RGBColor[{0.8500363984900003, 0.9263311671408848, 
        0.13924242858059316`}],
       Editable->False,
       Selectable->False],
      Short],
     Background->GrayLevel[1],
     FrameMargins->{{0, 0}, {0, 0}},
     FrameStyle->GrayLevel[1],
     RoundingRadius->2,
     StripOnInput->False], {330, 0}, Scaled[{0.5, 1}]], InsetBox[
    FrameBox[
     TagBox[
      InterpretationBox[
       ButtonBox[
        TooltipBox[
         GraphicsBox[{
           {GrayLevel[0], RectangleBox[{0, 0}]}, 
           {GrayLevel[0], RectangleBox[{1, -1}]}, 
           {RGBColor[
            0.9752641706478989, 0.8013981246170678, 0.10899973580393796`], 
            RectangleBox[{0, -1}, {2, 1}]}},
          AspectRatio->1,
          Frame->True,
          
          FrameStyle->RGBColor[
           0.650176113765266, 0.5342654164113786, 0.07266649053595864],
          FrameTicks->None,
          
          ImageSize->
           Dynamic[{
            Automatic, 
             1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
              Magnification])}],
          PlotRangePadding->None],
         "RGBColor[{0.9752641706478989, 0.8013981246170678, \
0.10899973580393796}]"],
        Appearance->None,
        BaseStyle->{},
        BaselinePosition->Baseline,
        ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
          If[
           Not[
            AbsoluteCurrentValue["Deployed"]], 
           SelectionMove[Typeset`box$, All, Expression]; 
           FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
           FrontEnd`Private`$ColorSelectorInitialColor = 
            RGBColor[
             0.9752641706478989, 0.8013981246170678, 0.10899973580393796`]; 
           FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
           MathLink`CallFrontEnd[
             FrontEnd`AttachCell[Typeset`box$, 
              FrontEndResource["RGBColorValueSelector"], {
              0, {Left, Bottom}}, {Left, Top}, 
              "ClosingActions" -> {
               "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
        DefaultBaseStyle->{},
        Evaluator->Automatic,
        Method->"Preemptive"],
       RGBColor[{0.9752641706478989, 0.8013981246170678, 
        0.10899973580393796`}],
       Editable->False,
       Selectable->False],
      Short],
     Background->GrayLevel[1],
     FrameMargins->{{0, 0}, {0, 0}},
     FrameStyle->GrayLevel[1],
     RoundingRadius->2,
     StripOnInput->False], {352, 0}, Scaled[{0.5, 1}]], InsetBox[
    FrameBox[
     TagBox[
      InterpretationBox[
       ButtonBox[
        TooltipBox[
         GraphicsBox[{
           {GrayLevel[0], RectangleBox[{0, 0}]}, 
           {GrayLevel[0], RectangleBox[{1, -1}]}, 
           {RGBColor[
            0.9879209034166253, 0.8377732017482453, 0.15613661869756118`], 
            RectangleBox[{0, -1}, {2, 1}]}},
          AspectRatio->1,
          Frame->True,
          
          FrameStyle->RGBColor[
           0.6586139356110836, 0.5585154678321635, 0.10409107913170745`],
          FrameTicks->None,
          
          ImageSize->
           Dynamic[{
            Automatic, 
             1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
              Magnification])}],
          PlotRangePadding->None],
         "RGBColor[{0.9879209034166253, 0.8377732017482453, \
0.15613661869756118}]"],
        Appearance->None,
        BaseStyle->{},
        BaselinePosition->Baseline,
        ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
          If[
           Not[
            AbsoluteCurrentValue["Deployed"]], 
           SelectionMove[Typeset`box$, All, Expression]; 
           FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
           FrontEnd`Private`$ColorSelectorInitialColor = 
            RGBColor[
             0.9879209034166253, 0.8377732017482453, 0.15613661869756118`]; 
           FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
           MathLink`CallFrontEnd[
             FrontEnd`AttachCell[Typeset`box$, 
              FrontEndResource["RGBColorValueSelector"], {
              0, {Left, Bottom}}, {Left, Top}, 
              "ClosingActions" -> {
               "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
        DefaultBaseStyle->{},
        Evaluator->Automatic,
        Method->"Preemptive"],
       RGBColor[{0.9879209034166253, 0.8377732017482453, 
        0.15613661869756118`}],
       Editable->False,
       Selectable->False],
      Short],
     Background->GrayLevel[1],
     FrameMargins->{{0, 0}, {0, 0}},
     FrameStyle->GrayLevel[1],
     RoundingRadius->2,
     StripOnInput->False], {374, 0}, Scaled[{0.5, 1}]], InsetBox[
    FrameBox[
     TagBox[
      InterpretationBox[
       ButtonBox[
        TooltipBox[
         GraphicsBox[{
           {GrayLevel[0], RectangleBox[{0, 0}]}, 
           {GrayLevel[0], RectangleBox[{1, -1}]}, 
           {RGBColor[
            0.8340523614444824, 0.038129646837010533`, 0.09354464468116397], 
            RectangleBox[{0, -1}, {2, 1}]}},
          AspectRatio->1,
          Frame->True,
          
          FrameStyle->RGBColor[
           0.5560349076296549, 0.025419764558007023`, 0.06236309645410931],
          FrameTicks->None,
          
          ImageSize->
           Dynamic[{
            Automatic, 
             1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
              Magnification])}],
          PlotRangePadding->None],
         "RGBColor[{0.8340523614444824, 0.038129646837010533, \
0.09354464468116397}]"],
        Appearance->None,
        BaseStyle->{},
        BaselinePosition->Baseline,
        ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
          If[
           Not[
            AbsoluteCurrentValue["Deployed"]], 
           SelectionMove[Typeset`box$, All, Expression]; 
           FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
           FrontEnd`Private`$ColorSelectorInitialColor = 
            RGBColor[
             0.8340523614444824, 0.038129646837010533`, 0.09354464468116397]; 
           FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
           MathLink`CallFrontEnd[
             FrontEnd`AttachCell[Typeset`box$, 
              FrontEndResource["RGBColorValueSelector"], {
              0, {Left, Bottom}}, {Left, Top}, 
              "ClosingActions" -> {
               "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
        DefaultBaseStyle->{},
        Evaluator->Automatic,
        Method->"Preemptive"],
       RGBColor[{0.8340523614444824, 0.038129646837010533`, 
        0.09354464468116397}],
       Editable->False,
       Selectable->False],
      Short],
     Background->GrayLevel[1],
     FrameMargins->{{0, 0}, {0, 0}},
     FrameStyle->GrayLevel[1],
     RoundingRadius->2,
     StripOnInput->False], {396, 0}, Scaled[{0.5, 1}]], InsetBox[
    FrameBox[
     TagBox[
      InterpretationBox[
       ButtonBox[
        TooltipBox[
         GraphicsBox[{
           {GrayLevel[0], RectangleBox[{0, 0}]}, 
           {GrayLevel[0], RectangleBox[{1, -1}]}, 
           {RGBColor[
            0.8543889209256321, 0.09697598692920356, 0.10750903324099509`], 
            RectangleBox[{0, -1}, {2, 1}]}},
          AspectRatio->1,
          Frame->True,
          
          FrameStyle->RGBColor[
           0.5695926139504215, 0.06465065795280238, 0.07167268882733006],
          FrameTicks->None,
          
          ImageSize->
           Dynamic[{
            Automatic, 
             1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
              Magnification])}],
          PlotRangePadding->None],
         "RGBColor[{0.8543889209256321, 0.09697598692920356, \
0.10750903324099509}]"],
        Appearance->None,
        BaseStyle->{},
        BaselinePosition->Baseline,
        ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
          If[
           Not[
            AbsoluteCurrentValue["Deployed"]], 
           SelectionMove[Typeset`box$, All, Expression]; 
           FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
           FrontEnd`Private`$ColorSelectorInitialColor = 
            RGBColor[
             0.8543889209256321, 0.09697598692920356, 0.10750903324099509`]; 
           FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
           MathLink`CallFrontEnd[
             FrontEnd`AttachCell[Typeset`box$, 
              FrontEndResource["RGBColorValueSelector"], {
              0, {Left, Bottom}}, {Left, Top}, 
              "ClosingActions" -> {
               "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
        DefaultBaseStyle->{},
        Evaluator->Automatic,
        Method->"Preemptive"],
       RGBColor[{0.8543889209256321, 0.09697598692920356, 
        0.10750903324099509`}],
       Editable->False,
       Selectable->False],
      Short],
     Background->GrayLevel[1],
     FrameMargins->{{0, 0}, {0, 0}},
     FrameStyle->GrayLevel[1],
     RoundingRadius->2,
     StripOnInput->False], {418, 0}, Scaled[{0.5, 1}]], InsetBox[
    FrameBox[
     TagBox[
      InterpretationBox[
       ButtonBox[
        TooltipBox[
         GraphicsBox[{
           {GrayLevel[0], RectangleBox[{0, 0}]}, 
           {GrayLevel[0], RectangleBox[{1, -1}]}, 
           {RGBColor[
            0.8527294202095301, 0.15459949958575997`, 0.08139444813034824], 
            RectangleBox[{0, -1}, {2, 1}]}},
          AspectRatio->1,
          Frame->True,
          
          FrameStyle->RGBColor[
           0.5684862801396868, 0.10306633305717332`, 0.054262965420232165`],
          FrameTicks->None,
          
          ImageSize->
           Dynamic[{
            Automatic, 
             1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
              Magnification])}],
          PlotRangePadding->None],
         "RGBColor[{0.8527294202095301, 0.15459949958575997, \
0.08139444813034824}]"],
        Appearance->None,
        BaseStyle->{},
        BaselinePosition->Baseline,
        ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
          If[
           Not[
            AbsoluteCurrentValue["Deployed"]], 
           SelectionMove[Typeset`box$, All, Expression]; 
           FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
           FrontEnd`Private`$ColorSelectorInitialColor = 
            RGBColor[
             0.8527294202095301, 0.15459949958575997`, 0.08139444813034824]; 
           FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
           MathLink`CallFrontEnd[
             FrontEnd`AttachCell[Typeset`box$, 
              FrontEndResource["RGBColorValueSelector"], {
              0, {Left, Bottom}}, {Left, Top}, 
              "ClosingActions" -> {
               "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
        DefaultBaseStyle->{},
        Evaluator->Automatic,
        Method->"Preemptive"],
       RGBColor[{0.8527294202095301, 0.15459949958575997`, 
        0.08139444813034824}],
       Editable->False,
       Selectable->False],
      Short],
     Background->GrayLevel[1],
     FrameMargins->{{0, 0}, {0, 0}},
     FrameStyle->GrayLevel[1],
     RoundingRadius->2,
     StripOnInput->False], {440, 0}, Scaled[{0.5, 1}]], InsetBox[
    FrameBox[
     TagBox[
      InterpretationBox[
       ButtonBox[
        TooltipBox[
         GraphicsBox[{
           {GrayLevel[0], RectangleBox[{0, 0}]}, 
           {GrayLevel[0], RectangleBox[{1, -1}]}, 
           {RGBColor[
            0.9244703510275273, 0.001783470411052479, 0.14318146272477922`], 
            RectangleBox[{0, -1}, {2, 1}]}},
          AspectRatio->1,
          Frame->True,
          
          FrameStyle->RGBColor[
           0.6163135673516849, 0.0011889802740349862`, 0.09545430848318615],
          FrameTicks->None,
          
          ImageSize->
           Dynamic[{
            Automatic, 
             1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
              Magnification])}],
          PlotRangePadding->None],
         "RGBColor[{0.9244703510275273, 0.001783470411052479, \
0.14318146272477922}]"],
        Appearance->None,
        BaseStyle->{},
        BaselinePosition->Baseline,
        ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
          If[
           Not[
            AbsoluteCurrentValue["Deployed"]], 
           SelectionMove[Typeset`box$, All, Expression]; 
           FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
           FrontEnd`Private`$ColorSelectorInitialColor = 
            RGBColor[
             0.9244703510275273, 0.001783470411052479, 0.14318146272477922`]; 
           FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
           MathLink`CallFrontEnd[
             FrontEnd`AttachCell[Typeset`box$, 
              FrontEndResource["RGBColorValueSelector"], {
              0, {Left, Bottom}}, {Left, Top}, 
              "ClosingActions" -> {
               "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
        DefaultBaseStyle->{},
        Evaluator->Automatic,
        Method->"Preemptive"],
       RGBColor[{0.9244703510275273, 0.001783470411052479, 
        0.14318146272477922`}],
       Editable->False,
       Selectable->False],
      Short],
     Background->GrayLevel[1],
     FrameMargins->{{0, 0}, {0, 0}},
     FrameStyle->GrayLevel[1],
     RoundingRadius->2,
     StripOnInput->False], {462, 0}, Scaled[{0.5, 1}]], InsetBox[
    FrameBox[
     TagBox[
      InterpretationBox[
       ButtonBox[
        TooltipBox[
         GraphicsBox[{
           {GrayLevel[0], RectangleBox[{0, 0}]}, 
           {GrayLevel[0], RectangleBox[{1, -1}]}, 
           {RGBColor[
            0.9573167308698426, 0.1507116093826361, 0.09832234398916928], 
            RectangleBox[{0, -1}, {2, 1}]}},
          AspectRatio->1,
          Frame->True,
          
          FrameStyle->RGBColor[
           0.6382111539132285, 0.10047440625509074`, 0.06554822932611286],
          FrameTicks->None,
          
          ImageSize->
           Dynamic[{
            Automatic, 
             1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
              Magnification])}],
          PlotRangePadding->None],
         "RGBColor[{0.9573167308698426, 0.1507116093826361, \
0.09832234398916928}]"],
        Appearance->None,
        BaseStyle->{},
        BaselinePosition->Baseline,
        ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
          If[
           Not[
            AbsoluteCurrentValue["Deployed"]], 
           SelectionMove[Typeset`box$, All, Expression]; 
           FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
           FrontEnd`Private`$ColorSelectorInitialColor = 
            RGBColor[
             0.9573167308698426, 0.1507116093826361, 0.09832234398916928]; 
           FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
           MathLink`CallFrontEnd[
             FrontEnd`AttachCell[Typeset`box$, 
              FrontEndResource["RGBColorValueSelector"], {
              0, {Left, Bottom}}, {Left, Top}, 
              "ClosingActions" -> {
               "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
        DefaultBaseStyle->{},
        Evaluator->Automatic,
        Method->"Preemptive"],
       RGBColor[{0.9573167308698426, 0.1507116093826361, 0.09832234398916928}],
       Editable->False,
       Selectable->False],
      Short],
     Background->GrayLevel[1],
     FrameMargins->{{0, 0}, {0, 0}},
     FrameStyle->GrayLevel[1],
     RoundingRadius->2,
     StripOnInput->False], {484, 0}, Scaled[{0.5, 1}]]},
  AlignmentPoint->Center,
  AspectRatio->NCache[2^Rational[-1, 2], 0.7071067811865475],
  Axes->False,
  AxesLabel->None,
  AxesOrigin->Automatic,
  AxesStyle->{},
  Background->None,
  BaseStyle->{},
  BaselinePosition->Automatic,
  ColorOutput->Automatic,
  ContentSelectable->Automatic,
  CoordinatesToolOptions:>Automatic,
  DisplayFunction:>$DisplayFunction,
  Epilog->{},
  FormatType:>TraditionalForm,
  Frame->False,
  FrameLabel->None,
  FrameStyle->{},
  FrameTicks->Automatic,
  FrameTicksStyle->{},
  GridLines->None,
  GridLinesStyle->{},
  ImageMargins->0.,
  ImagePadding->All,
  ImageSize->{230.02734375, Automatic},
  ImageSizeRaw->Automatic,
  LabelStyle->{},
  Method->Automatic,
  PlotLabel->None,
  PlotRange->All,
  PlotRangeClipping->False,
  PlotRangePadding->Automatic,
  PlotRegion->Automatic,
  PreserveImageOptions->Automatic,
  Prolog->{},
  RotateLabel->True,
  Ticks->Automatic,
  TicksStyle->{}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[20]=",ExpressionUUID->"86ea6100-1117-4a65-82b7-44f5cecc2107"]
}, Open  ]],

Cell[TextData[{
 "When we compare things\[LongDash]whether they\[CloseCurlyQuote]re colors or \
pictures of animals\[LongDash]we can think of identifying certain ",
 StyleBox["features",
  FontSlant->"Italic"],
 " that allow us to distinguish them. For colors, a feature might be how \
light the color is, or how much red it contains. For pictures of animals, a \
feature might be how furry the animal looks, or how pointy its ears are."
}], "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:22",ExpressionUUID->"0bf4abb5-532d-4c48-b315-4d06c384a934"],

Cell[TextData[{
 "In the Wolfram Language, ",
 Cell[BoxData[
  ButtonBox["FeatureSpacePlot",
   BaseStyle->"CodeLink"]], "InlineCodeText",ExpressionUUID->
  "68cec2ea-d33d-4616-9e31-fa1ef559ef85"],
 " takes collections of objects and tries to find what it considers the \
\[OpenCurlyDoubleQuote]best\[CloseCurlyDoubleQuote] distinguishing features \
of them, then uses the values of these to position objects in a plot."
}], "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->{
  "LastCellOfAPage", 
   "i:23"},ExpressionUUID->"adff9c50-1544-4e0b-8348-664d3ad0b2c8"],

Cell[TextData[{
 ButtonBox["FeatureSpacePlot",
  BaseStyle->"Link"],
 " doesn\[CloseCurlyQuote]t explicitly say what features \
it\[CloseCurlyQuote]s using\[LongDash]and actually they\[CloseCurlyQuote]re \
usually quite hard to describe. But what happens in the end is that ",
 ButtonBox["FeatureSpacePlot",
  BaseStyle->"Link"],
 " arranges things so that objects that have similar features are drawn \
nearby. "
}], "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:24",ExpressionUUID->"b9896f6e-2e77-427c-9179-6df9e86ca0b0"],

Cell[TextData[{
 ButtonBox["FeatureSpacePlot",
  BaseStyle->"Link"],
 " makes similar colors be placed nearby:"
}], "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"83274f01-a6ff-45cf-8ba8-967c7aa359e3"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FeatureSpacePlot", "[", 
  RowBox[{"{", 
   RowBox[{
    InterpretationBox[
     ButtonBox[
      TooltipBox[
       GraphicsBox[{
         {GrayLevel[0], RectangleBox[{0, 0}]}, 
         {GrayLevel[0], RectangleBox[{1, -1}]}, 
         {RGBColor[
          0.048175746346922704`, 0.8856231902848692, 0.002187262571789972], 
          RectangleBox[{0, -1}, {2, 1}]}},
        AspectRatio->1,
        Frame->True,
        FrameStyle->RGBColor[
         0.0321171642312818, 0.5904154601899129, 0.0014581750478599813`],
        FrameTicks->None,
        ImageSize->
         Dynamic[{
          Automatic, 
           1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
            Magnification])}],
        PlotRangePadding->None],
       "RGBColor[{0.048175746346922704, 0.8856231902848692, \
0.002187262571789972}]"],
      Appearance->None,
      BaseStyle->{},
      BaselinePosition->Baseline,
      ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
        If[
         Not[
          AbsoluteCurrentValue["Deployed"]], 
         SelectionMove[Typeset`box$, All, Expression]; 
         FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
         FrontEnd`Private`$ColorSelectorInitialColor = 
          RGBColor[
           0.048175746346922704`, 0.8856231902848692, 0.002187262571789972]; 
         FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
         MathLink`CallFrontEnd[
           FrontEnd`AttachCell[Typeset`box$, 
            FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
            Left, Top}, 
            "ClosingActions" -> {
             "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
      DefaultBaseStyle->{},
      Evaluator->Automatic,
      Method->"Preemptive"],
     RGBColor[{0.048175746346922704`, 0.8856231902848692, 
      0.002187262571789972}],
     Editable->False,
     Selectable->False], ",", 
    InterpretationBox[
     ButtonBox[
      TooltipBox[
       GraphicsBox[{
         {GrayLevel[0], RectangleBox[{0, 0}]}, 
         {GrayLevel[0], RectangleBox[{1, -1}]}, 
         {RGBColor[
          0.9543437880041175, 0.9364915417894851, 0.08314980598714755], 
          RectangleBox[{0, -1}, {2, 1}]}},
        AspectRatio->1,
        Frame->True,
        FrameStyle->RGBColor[
         0.636229192002745, 0.6243276945263234, 0.0554332039914317],
        FrameTicks->None,
        ImageSize->
         Dynamic[{
          Automatic, 
           1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
            Magnification])}],
        PlotRangePadding->None],
       "RGBColor[{0.9543437880041175, 0.9364915417894851, \
0.08314980598714755}]"],
      Appearance->None,
      BaseStyle->{},
      BaselinePosition->Baseline,
      ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
        If[
         Not[
          AbsoluteCurrentValue["Deployed"]], 
         SelectionMove[Typeset`box$, All, Expression]; 
         FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
         FrontEnd`Private`$ColorSelectorInitialColor = 
          RGBColor[
           0.9543437880041175, 0.9364915417894851, 0.08314980598714755]; 
         FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
         MathLink`CallFrontEnd[
           FrontEnd`AttachCell[Typeset`box$, 
            FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
            Left, Top}, 
            "ClosingActions" -> {
             "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
      DefaultBaseStyle->{},
      Evaluator->Automatic,
      Method->"Preemptive"],
     RGBColor[{0.9543437880041175, 0.9364915417894851, 0.08314980598714755}],
     Editable->False,
     Selectable->False], ",", 
    InterpretationBox[
     ButtonBox[
      TooltipBox[
       GraphicsBox[{
         {GrayLevel[0], RectangleBox[{0, 0}]}, 
         {GrayLevel[0], RectangleBox[{1, -1}]}, 
         {RGBColor[
          0.8527294202095301, 0.15459949958575997`, 0.08139444813034824], 
          RectangleBox[{0, -1}, {2, 1}]}},
        AspectRatio->1,
        Frame->True,
        FrameStyle->RGBColor[
         0.5684862801396868, 0.10306633305717332`, 0.054262965420232165`],
        FrameTicks->None,
        ImageSize->
         Dynamic[{
          Automatic, 
           1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
            Magnification])}],
        PlotRangePadding->None],
       "RGBColor[{0.8527294202095301, 0.15459949958575997, \
0.08139444813034824}]"],
      Appearance->None,
      BaseStyle->{},
      BaselinePosition->Baseline,
      ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
        If[
         Not[
          AbsoluteCurrentValue["Deployed"]], 
         SelectionMove[Typeset`box$, All, Expression]; 
         FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
         FrontEnd`Private`$ColorSelectorInitialColor = 
          RGBColor[
           0.8527294202095301, 0.15459949958575997`, 0.08139444813034824]; 
         FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
         MathLink`CallFrontEnd[
           FrontEnd`AttachCell[Typeset`box$, 
            FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
            Left, Top}, 
            "ClosingActions" -> {
             "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
      DefaultBaseStyle->{},
      Evaluator->Automatic,
      Method->"Preemptive"],
     RGBColor[{0.8527294202095301, 0.15459949958575997`, 0.08139444813034824}],
     Editable->False,
     Selectable->False], ",", 
    InterpretationBox[
     ButtonBox[
      TooltipBox[
       GraphicsBox[{
         {GrayLevel[0], RectangleBox[{0, 0}]}, 
         {GrayLevel[0], RectangleBox[{1, -1}]}, 
         {RGBColor[
          0.12965437429396431`, 0.8338364200576898, 0.16859742903104202`], 
          RectangleBox[{0, -1}, {2, 1}]}},
        AspectRatio->1,
        Frame->True,
        FrameStyle->RGBColor[
         0.08643624952930955, 0.5558909467051265, 0.11239828602069468`],
        FrameTicks->None,
        ImageSize->
         Dynamic[{
          Automatic, 
           1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
            Magnification])}],
        PlotRangePadding->None],
       "RGBColor[{0.12965437429396431, 0.8338364200576898, \
0.16859742903104202}]"],
      Appearance->None,
      BaseStyle->{},
      BaselinePosition->Baseline,
      ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
        If[
         Not[
          AbsoluteCurrentValue["Deployed"]], 
         SelectionMove[Typeset`box$, All, Expression]; 
         FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
         FrontEnd`Private`$ColorSelectorInitialColor = 
          RGBColor[
           0.12965437429396431`, 0.8338364200576898, 0.16859742903104202`]; 
         FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
         MathLink`CallFrontEnd[
           FrontEnd`AttachCell[Typeset`box$, 
            FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
            Left, Top}, 
            "ClosingActions" -> {
             "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
      DefaultBaseStyle->{},
      Evaluator->Automatic,
      Method->"Preemptive"],
     RGBColor[{0.12965437429396431`, 0.8338364200576898, 
      0.16859742903104202`}],
     Editable->False,
     Selectable->False], ",", 
    InterpretationBox[
     ButtonBox[
      TooltipBox[
       GraphicsBox[{
         {GrayLevel[0], RectangleBox[{0, 0}]}, 
         {GrayLevel[0], RectangleBox[{1, -1}]}, 
         {RGBColor[
          0.14189318640501342`, 0.8685451286121387, 0.10426943556314977`], 
          RectangleBox[{0, -1}, {2, 1}]}},
        AspectRatio->1,
        Frame->True,
        FrameStyle->RGBColor[
         0.09459545760334229, 0.5790300857414259, 0.06951295704209985],
        FrameTicks->None,
        ImageSize->
         Dynamic[{
          Automatic, 
           1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
            Magnification])}],
        PlotRangePadding->None],
       "RGBColor[{0.14189318640501342, 0.8685451286121387, \
0.10426943556314977}]"],
      Appearance->None,
      BaseStyle->{},
      BaselinePosition->Baseline,
      ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
        If[
         Not[
          AbsoluteCurrentValue["Deployed"]], 
         SelectionMove[Typeset`box$, All, Expression]; 
         FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
         FrontEnd`Private`$ColorSelectorInitialColor = 
          RGBColor[
           0.14189318640501342`, 0.8685451286121387, 0.10426943556314977`]; 
         FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
         MathLink`CallFrontEnd[
           FrontEnd`AttachCell[Typeset`box$, 
            FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
            Left, Top}, 
            "ClosingActions" -> {
             "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
      DefaultBaseStyle->{},
      Evaluator->Automatic,
      Method->"Preemptive"],
     RGBColor[{0.14189318640501342`, 0.8685451286121387, 
      0.10426943556314977`}],
     Editable->False,
     Selectable->False], ",", 
    InterpretationBox[
     ButtonBox[
      TooltipBox[
       GraphicsBox[{
         {GrayLevel[0], RectangleBox[{0, 0}]}, 
         {GrayLevel[0], RectangleBox[{1, -1}]}, 
         {RGBColor[
          0.9244703510275273, 0.001783470411052479, 0.14318146272477922`], 
          RectangleBox[{0, -1}, {2, 1}]}},
        AspectRatio->1,
        Frame->True,
        FrameStyle->RGBColor[
         0.6163135673516849, 0.0011889802740349862`, 0.09545430848318615],
        FrameTicks->None,
        ImageSize->
         Dynamic[{
          Automatic, 
           1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
            Magnification])}],
        PlotRangePadding->None],
       "RGBColor[{0.9244703510275273, 0.001783470411052479, \
0.14318146272477922}]"],
      Appearance->None,
      BaseStyle->{},
      BaselinePosition->Baseline,
      ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
        If[
         Not[
          AbsoluteCurrentValue["Deployed"]], 
         SelectionMove[Typeset`box$, All, Expression]; 
         FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
         FrontEnd`Private`$ColorSelectorInitialColor = 
          RGBColor[
           0.9244703510275273, 0.001783470411052479, 0.14318146272477922`]; 
         FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
         MathLink`CallFrontEnd[
           FrontEnd`AttachCell[Typeset`box$, 
            FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
            Left, Top}, 
            "ClosingActions" -> {
             "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
      DefaultBaseStyle->{},
      Evaluator->Automatic,
      Method->"Preemptive"],
     RGBColor[{0.9244703510275273, 0.001783470411052479, 
      0.14318146272477922`}],
     Editable->False,
     Selectable->False], ",", 
    InterpretationBox[
     ButtonBox[
      TooltipBox[
       GraphicsBox[{
         {GrayLevel[0], RectangleBox[{0, 0}]}, 
         {GrayLevel[0], RectangleBox[{1, -1}]}, 
         {RGBColor[
          0.8340523614444824, 0.038129646837010533`, 0.09354464468116397], 
          RectangleBox[{0, -1}, {2, 1}]}},
        AspectRatio->1,
        Frame->True,
        FrameStyle->RGBColor[
         0.5560349076296549, 0.025419764558007023`, 0.06236309645410931],
        FrameTicks->None,
        ImageSize->
         Dynamic[{
          Automatic, 
           1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
            Magnification])}],
        PlotRangePadding->None],
       "RGBColor[{0.8340523614444824, 0.038129646837010533, \
0.09354464468116397}]"],
      Appearance->None,
      BaseStyle->{},
      BaselinePosition->Baseline,
      ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
        If[
         Not[
          AbsoluteCurrentValue["Deployed"]], 
         SelectionMove[Typeset`box$, All, Expression]; 
         FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
         FrontEnd`Private`$ColorSelectorInitialColor = 
          RGBColor[
           0.8340523614444824, 0.038129646837010533`, 0.09354464468116397]; 
         FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
         MathLink`CallFrontEnd[
           FrontEnd`AttachCell[Typeset`box$, 
            FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
            Left, Top}, 
            "ClosingActions" -> {
             "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
      DefaultBaseStyle->{},
      Evaluator->Automatic,
      Method->"Preemptive"],
     RGBColor[{0.8340523614444824, 0.038129646837010533`, 
      0.09354464468116397}],
     Editable->False,
     Selectable->False], ",", 
    InterpretationBox[
     ButtonBox[
      TooltipBox[
       GraphicsBox[{
         {GrayLevel[0], RectangleBox[{0, 0}]}, 
         {GrayLevel[0], RectangleBox[{1, -1}]}, 
         {RGBColor[
          0.06423181065333894, 0.9361486399945784, 0.08411970647251821], 
          RectangleBox[{0, -1}, {2, 1}]}},
        AspectRatio->1,
        Frame->True,
        FrameStyle->RGBColor[
         0.042821207102225964`, 0.624099093329719, 0.05607980431501214],
        FrameTicks->None,
        ImageSize->
         Dynamic[{
          Automatic, 
           1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
            Magnification])}],
        PlotRangePadding->None],
       "RGBColor[{0.06423181065333894, 0.9361486399945784, \
0.08411970647251821}]"],
      Appearance->None,
      BaseStyle->{},
      BaselinePosition->Baseline,
      ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
        If[
         Not[
          AbsoluteCurrentValue["Deployed"]], 
         SelectionMove[Typeset`box$, All, Expression]; 
         FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
         FrontEnd`Private`$ColorSelectorInitialColor = 
          RGBColor[
           0.06423181065333894, 0.9361486399945784, 0.08411970647251821]; 
         FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
         MathLink`CallFrontEnd[
           FrontEnd`AttachCell[Typeset`box$, 
            FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
            Left, Top}, 
            "ClosingActions" -> {
             "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
      DefaultBaseStyle->{},
      Evaluator->Automatic,
      Method->"Preemptive"],
     RGBColor[{0.06423181065333894, 0.9361486399945784, 0.08411970647251821}],
     
     Editable->False,
     Selectable->False], ",", 
    InterpretationBox[
     ButtonBox[
      TooltipBox[
       GraphicsBox[{
         {GrayLevel[0], RectangleBox[{0, 0}]}, 
         {GrayLevel[0], RectangleBox[{1, -1}]}, 
         {RGBColor[
          0.8676164929883508, 0.8866580065099905, 0.024086278089002183`], 
          RectangleBox[{0, -1}, {2, 1}]}},
        AspectRatio->1,
        Frame->True,
        FrameStyle->RGBColor[
         0.5784109953255672, 0.5911053376733271, 0.016057518726001457`],
        FrameTicks->None,
        ImageSize->
         Dynamic[{
          Automatic, 
           1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
            Magnification])}],
        PlotRangePadding->None],
       "RGBColor[{0.8676164929883508, 0.8866580065099905, \
0.024086278089002183}]"],
      Appearance->None,
      BaseStyle->{},
      BaselinePosition->Baseline,
      ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
        If[
         Not[
          AbsoluteCurrentValue["Deployed"]], 
         SelectionMove[Typeset`box$, All, Expression]; 
         FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
         FrontEnd`Private`$ColorSelectorInitialColor = 
          RGBColor[
           0.8676164929883508, 0.8866580065099905, 0.024086278089002183`]; 
         FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
         MathLink`CallFrontEnd[
           FrontEnd`AttachCell[Typeset`box$, 
            FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
            Left, Top}, 
            "ClosingActions" -> {
             "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
      DefaultBaseStyle->{},
      Evaluator->Automatic,
      Method->"Preemptive"],
     RGBColor[{0.8676164929883508, 0.8866580065099905, 0.024086278089002183`}],
     Editable->False,
     Selectable->False], ",", 
    InterpretationBox[
     ButtonBox[
      TooltipBox[
       GraphicsBox[{
         {GrayLevel[0], RectangleBox[{0, 0}]}, 
         {GrayLevel[0], RectangleBox[{1, -1}]}, 
         {RGBColor[
          0.8577958146408966, 0.8374035340744639, 0.0071190816223388464`], 
          RectangleBox[{0, -1}, {2, 1}]}},
        AspectRatio->1,
        Frame->True,
        FrameStyle->RGBColor[
         0.5718638764272644, 0.5582690227163093, 0.004746054414892564],
        FrameTicks->None,
        ImageSize->
         Dynamic[{
          Automatic, 
           1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
            Magnification])}],
        PlotRangePadding->None],
       "RGBColor[{0.8577958146408966, 0.8374035340744639, \
0.0071190816223388464}]"],
      Appearance->None,
      BaseStyle->{},
      BaselinePosition->Baseline,
      ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
        If[
         Not[
          AbsoluteCurrentValue["Deployed"]], 
         SelectionMove[Typeset`box$, All, Expression]; 
         FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
         FrontEnd`Private`$ColorSelectorInitialColor = 
          RGBColor[
           0.8577958146408966, 0.8374035340744639, 0.0071190816223388464`]; 
         FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
         MathLink`CallFrontEnd[
           FrontEnd`AttachCell[Typeset`box$, 
            FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
            Left, Top}, 
            "ClosingActions" -> {
             "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
      DefaultBaseStyle->{},
      Evaluator->Automatic,
      Method->"Preemptive"],
     RGBColor[{0.8577958146408966, 0.8374035340744639, 
      0.0071190816223388464`}],
     Editable->False,
     Selectable->False], ",", 
    InterpretationBox[
     ButtonBox[
      TooltipBox[
       GraphicsBox[{
         {GrayLevel[0], RectangleBox[{0, 0}]}, 
         {GrayLevel[0], RectangleBox[{1, -1}]}, 
         {RGBColor[
          0.9967431643372854, 0.969475575859666, 0.12251095291379577`], 
          RectangleBox[{0, -1}, {2, 1}]}},
        AspectRatio->1,
        Frame->True,
        FrameStyle->RGBColor[
         0.6644954428915236, 0.6463170505731107, 0.08167396860919718],
        FrameTicks->None,
        ImageSize->
         Dynamic[{
          Automatic, 
           1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
            Magnification])}],
        PlotRangePadding->None],
       "RGBColor[{0.9967431643372854, 0.969475575859666, \
0.12251095291379577}]"],
      Appearance->None,
      BaseStyle->{},
      BaselinePosition->Baseline,
      ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
        If[
         Not[
          AbsoluteCurrentValue["Deployed"]], 
         SelectionMove[Typeset`box$, All, Expression]; 
         FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
         FrontEnd`Private`$ColorSelectorInitialColor = 
          RGBColor[
           0.9967431643372854, 0.969475575859666, 0.12251095291379577`]; 
         FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
         MathLink`CallFrontEnd[
           FrontEnd`AttachCell[Typeset`box$, 
            FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
            Left, Top}, 
            "ClosingActions" -> {
             "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
      DefaultBaseStyle->{},
      Evaluator->Automatic,
      Method->"Preemptive"],
     RGBColor[{0.9967431643372854, 0.969475575859666, 0.12251095291379577`}],
     Editable->False,
     Selectable->False], ",", 
    InterpretationBox[
     ButtonBox[
      TooltipBox[
       GraphicsBox[{
         {GrayLevel[0], RectangleBox[{0, 0}]}, 
         {GrayLevel[0], RectangleBox[{1, -1}]}, 
         {RGBColor[
          0.8543889209256321, 0.09697598692920356, 0.10750903324099509`], 
          RectangleBox[{0, -1}, {2, 1}]}},
        AspectRatio->1,
        Frame->True,
        FrameStyle->RGBColor[
         0.5695926139504215, 0.06465065795280238, 0.07167268882733006],
        FrameTicks->None,
        ImageSize->
         Dynamic[{
          Automatic, 
           1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
            Magnification])}],
        PlotRangePadding->None],
       "RGBColor[{0.8543889209256321, 0.09697598692920356, \
0.10750903324099509}]"],
      Appearance->None,
      BaseStyle->{},
      BaselinePosition->Baseline,
      ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
        If[
         Not[
          AbsoluteCurrentValue["Deployed"]], 
         SelectionMove[Typeset`box$, All, Expression]; 
         FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
         FrontEnd`Private`$ColorSelectorInitialColor = 
          RGBColor[
           0.8543889209256321, 0.09697598692920356, 0.10750903324099509`]; 
         FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
         MathLink`CallFrontEnd[
           FrontEnd`AttachCell[Typeset`box$, 
            FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
            Left, Top}, 
            "ClosingActions" -> {
             "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
      DefaultBaseStyle->{},
      Evaluator->Automatic,
      Method->"Preemptive"],
     RGBColor[{0.8543889209256321, 0.09697598692920356, 0.10750903324099509`}],
     Editable->False,
     Selectable->False], ",", 
    InterpretationBox[
     ButtonBox[
      TooltipBox[
       GraphicsBox[{
         {GrayLevel[0], RectangleBox[{0, 0}]}, 
         {GrayLevel[0], RectangleBox[{1, -1}]}, 
         {RGBColor[
          0.8500363984900003, 0.9263311671408848, 0.13924242858059316`], 
          RectangleBox[{0, -1}, {2, 1}]}},
        AspectRatio->1,
        Frame->True,
        FrameStyle->RGBColor[
         0.5666909323266669, 0.6175541114272566, 0.09282828572039545],
        FrameTicks->None,
        ImageSize->
         Dynamic[{
          Automatic, 
           1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
            Magnification])}],
        PlotRangePadding->None],
       "RGBColor[{0.8500363984900003, 0.9263311671408848, \
0.13924242858059316}]"],
      Appearance->None,
      BaseStyle->{},
      BaselinePosition->Baseline,
      ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
        If[
         Not[
          AbsoluteCurrentValue["Deployed"]], 
         SelectionMove[Typeset`box$, All, Expression]; 
         FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
         FrontEnd`Private`$ColorSelectorInitialColor = 
          RGBColor[
           0.8500363984900003, 0.9263311671408848, 0.13924242858059316`]; 
         FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
         MathLink`CallFrontEnd[
           FrontEnd`AttachCell[Typeset`box$, 
            FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
            Left, Top}, 
            "ClosingActions" -> {
             "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
      DefaultBaseStyle->{},
      Evaluator->Automatic,
      Method->"Preemptive"],
     RGBColor[{0.8500363984900003, 0.9263311671408848, 0.13924242858059316`}],
     
     Editable->False,
     Selectable->False], ",", 
    InterpretationBox[
     ButtonBox[
      TooltipBox[
       GraphicsBox[{
         {GrayLevel[0], RectangleBox[{0, 0}]}, 
         {GrayLevel[0], RectangleBox[{1, -1}]}, 
         {RGBColor[
          0.9879209034166253, 0.8377732017482453, 0.15613661869756118`], 
          RectangleBox[{0, -1}, {2, 1}]}},
        AspectRatio->1,
        Frame->True,
        FrameStyle->RGBColor[
         0.6586139356110836, 0.5585154678321635, 0.10409107913170745`],
        FrameTicks->None,
        ImageSize->
         Dynamic[{
          Automatic, 
           1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
            Magnification])}],
        PlotRangePadding->None],
       "RGBColor[{0.9879209034166253, 0.8377732017482453, \
0.15613661869756118}]"],
      Appearance->None,
      BaseStyle->{},
      BaselinePosition->Baseline,
      ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
        If[
         Not[
          AbsoluteCurrentValue["Deployed"]], 
         SelectionMove[Typeset`box$, All, Expression]; 
         FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
         FrontEnd`Private`$ColorSelectorInitialColor = 
          RGBColor[
           0.9879209034166253, 0.8377732017482453, 0.15613661869756118`]; 
         FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
         MathLink`CallFrontEnd[
           FrontEnd`AttachCell[Typeset`box$, 
            FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
            Left, Top}, 
            "ClosingActions" -> {
             "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
      DefaultBaseStyle->{},
      Evaluator->Automatic,
      Method->"Preemptive"],
     RGBColor[{0.9879209034166253, 0.8377732017482453, 0.15613661869756118`}],
     
     Editable->False,
     Selectable->False], ",", 
    InterpretationBox[
     ButtonBox[
      TooltipBox[
       GraphicsBox[{
         {GrayLevel[0], RectangleBox[{0, 0}]}, 
         {GrayLevel[0], RectangleBox[{1, -1}]}, 
         {RGBColor[
          0.9573167308698426, 0.1507116093826361, 0.09832234398916928], 
          RectangleBox[{0, -1}, {2, 1}]}},
        AspectRatio->1,
        Frame->True,
        FrameStyle->RGBColor[
         0.6382111539132285, 0.10047440625509074`, 0.06554822932611286],
        FrameTicks->None,
        ImageSize->
         Dynamic[{
          Automatic, 
           1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
            Magnification])}],
        PlotRangePadding->None],
       "RGBColor[{0.9573167308698426, 0.1507116093826361, \
0.09832234398916928}]"],
      Appearance->None,
      BaseStyle->{},
      BaselinePosition->Baseline,
      ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
        If[
         Not[
          AbsoluteCurrentValue["Deployed"]], 
         SelectionMove[Typeset`box$, All, Expression]; 
         FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
         FrontEnd`Private`$ColorSelectorInitialColor = 
          RGBColor[
           0.9573167308698426, 0.1507116093826361, 0.09832234398916928]; 
         FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
         MathLink`CallFrontEnd[
           FrontEnd`AttachCell[Typeset`box$, 
            FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
            Left, Top}, 
            "ClosingActions" -> {
             "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
      DefaultBaseStyle->{},
      Evaluator->Automatic,
      Method->"Preemptive"],
     RGBColor[{0.9573167308698426, 0.1507116093826361, 0.09832234398916928}],
     Editable->False,
     Selectable->False], ",", 
    InterpretationBox[
     ButtonBox[
      TooltipBox[
       GraphicsBox[{
         {GrayLevel[0], RectangleBox[{0, 0}]}, 
         {GrayLevel[0], RectangleBox[{1, -1}]}, 
         {RGBColor[
          0.04278634258158939, 0.9055378427790535, 0.0003309996431954121], 
          RectangleBox[{0, -1}, {2, 1}]}},
        AspectRatio->1,
        Frame->True,
        FrameStyle->RGBColor[
         0.028524228387726263`, 0.6036918951860357, 0.0002206664287969414],
        FrameTicks->None,
        ImageSize->
         Dynamic[{
          Automatic, 
           1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
            Magnification])}],
        PlotRangePadding->None],
       "RGBColor[{0.04278634258158939, 0.9055378427790535, \
0.0003309996431954121}]"],
      Appearance->None,
      BaseStyle->{},
      BaselinePosition->Baseline,
      ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
        If[
         Not[
          AbsoluteCurrentValue["Deployed"]], 
         SelectionMove[Typeset`box$, All, Expression]; 
         FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
         FrontEnd`Private`$ColorSelectorInitialColor = 
          RGBColor[
           0.04278634258158939, 0.9055378427790535, 0.0003309996431954121]; 
         FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
         MathLink`CallFrontEnd[
           FrontEnd`AttachCell[Typeset`box$, 
            FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
            Left, Top}, 
            "ClosingActions" -> {
             "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
      DefaultBaseStyle->{},
      Evaluator->Automatic,
      Method->"Preemptive"],
     RGBColor[{0.04278634258158939, 0.9055378427790535, 
      0.0003309996431954121}],
     Editable->False,
     Selectable->False], ",", 
    InterpretationBox[
     ButtonBox[
      TooltipBox[
       GraphicsBox[{
         {GrayLevel[0], RectangleBox[{0, 0}]}, 
         {GrayLevel[0], RectangleBox[{1, -1}]}, 
         {RGBColor[
          0.8058039405531526, 0.8318774133774354, 0.10151558699591279`], 
          RectangleBox[{0, -1}, {2, 1}]}},
        AspectRatio->1,
        Frame->True,
        FrameStyle->RGBColor[
         0.5372026270354351, 0.5545849422516236, 0.06767705799727519],
        FrameTicks->None,
        ImageSize->
         Dynamic[{
          Automatic, 
           1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
            Magnification])}],
        PlotRangePadding->None],
       "RGBColor[{0.8058039405531526, 0.8318774133774354, \
0.10151558699591279}]"],
      Appearance->None,
      BaseStyle->{},
      BaselinePosition->Baseline,
      ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
        If[
         Not[
          AbsoluteCurrentValue["Deployed"]], 
         SelectionMove[Typeset`box$, All, Expression]; 
         FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
         FrontEnd`Private`$ColorSelectorInitialColor = 
          RGBColor[
           0.8058039405531526, 0.8318774133774354, 0.10151558699591279`]; 
         FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
         MathLink`CallFrontEnd[
           FrontEnd`AttachCell[Typeset`box$, 
            FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
            Left, Top}, 
            "ClosingActions" -> {
             "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
      DefaultBaseStyle->{},
      Evaluator->Automatic,
      Method->"Preemptive"],
     RGBColor[{0.8058039405531526, 0.8318774133774354, 0.10151558699591279`}],
     
     Editable->False,
     Selectable->False], ",", 
    InterpretationBox[
     ButtonBox[
      TooltipBox[
       GraphicsBox[{
         {GrayLevel[0], RectangleBox[{0, 0}]}, 
         {GrayLevel[0], RectangleBox[{1, -1}]}, 
         {RGBColor[
          0.006814389873512461, 0.9336694049188562, 0.06907220235176909], 
          RectangleBox[{0, -1}, {2, 1}]}},
        AspectRatio->1,
        Frame->True,
        FrameStyle->RGBColor[
         0.004542926582341641, 0.6224462699459041, 0.04604813490117939],
        FrameTicks->None,
        ImageSize->
         Dynamic[{
          Automatic, 
           1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
            Magnification])}],
        PlotRangePadding->None],
       "RGBColor[{0.006814389873512461, 0.9336694049188562, \
0.06907220235176909}]"],
      Appearance->None,
      BaseStyle->{},
      BaselinePosition->Baseline,
      ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
        If[
         Not[
          AbsoluteCurrentValue["Deployed"]], 
         SelectionMove[Typeset`box$, All, Expression]; 
         FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
         FrontEnd`Private`$ColorSelectorInitialColor = 
          RGBColor[
           0.006814389873512461, 0.9336694049188562, 0.06907220235176909]; 
         FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
         MathLink`CallFrontEnd[
           FrontEnd`AttachCell[Typeset`box$, 
            FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
            Left, Top}, 
            "ClosingActions" -> {
             "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
      DefaultBaseStyle->{},
      Evaluator->Automatic,
      Method->"Preemptive"],
     RGBColor[{0.006814389873512461, 0.9336694049188562, 0.06907220235176909}],
     Editable->False,
     Selectable->False], ",", 
    InterpretationBox[
     ButtonBox[
      TooltipBox[
       GraphicsBox[{
         {GrayLevel[0], RectangleBox[{0, 0}]}, 
         {GrayLevel[0], RectangleBox[{1, -1}]}, 
         {RGBColor[
          0.9450158125329948, 0.9670907305400336, 0.05040029871534907], 
          RectangleBox[{0, -1}, {2, 1}]}},
        AspectRatio->1,
        Frame->True,
        FrameStyle->RGBColor[
         0.6300105416886632, 0.6447271536933558, 0.033600199143566045`],
        FrameTicks->None,
        ImageSize->
         Dynamic[{
          Automatic, 
           1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
            Magnification])}],
        PlotRangePadding->None],
       "RGBColor[{0.9450158125329948, 0.9670907305400336, \
0.05040029871534907}]"],
      Appearance->None,
      BaseStyle->{},
      BaselinePosition->Baseline,
      ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
        If[
         Not[
          AbsoluteCurrentValue["Deployed"]], 
         SelectionMove[Typeset`box$, All, Expression]; 
         FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
         FrontEnd`Private`$ColorSelectorInitialColor = 
          RGBColor[
           0.9450158125329948, 0.9670907305400336, 0.05040029871534907]; 
         FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
         MathLink`CallFrontEnd[
           FrontEnd`AttachCell[Typeset`box$, 
            FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
            Left, Top}, 
            "ClosingActions" -> {
             "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
      DefaultBaseStyle->{},
      Evaluator->Automatic,
      Method->"Preemptive"],
     RGBColor[{0.9450158125329948, 0.9670907305400336, 0.05040029871534907}],
     Editable->False,
     Selectable->False], ",", 
    InterpretationBox[
     ButtonBox[
      TooltipBox[
       GraphicsBox[{
         {GrayLevel[0], RectangleBox[{0, 0}]}, 
         {GrayLevel[0], RectangleBox[{1, -1}]}, 
         {RGBColor[
          0.9752641706478989, 0.8013981246170678, 0.10899973580393796`], 
          RectangleBox[{0, -1}, {2, 1}]}},
        AspectRatio->1,
        Frame->True,
        FrameStyle->RGBColor[
         0.650176113765266, 0.5342654164113786, 0.07266649053595864],
        FrameTicks->None,
        ImageSize->
         Dynamic[{
          Automatic, 
           1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
            Magnification])}],
        PlotRangePadding->None],
       "RGBColor[{0.9752641706478989, 0.8013981246170678, \
0.10899973580393796}]"],
      Appearance->None,
      BaseStyle->{},
      BaselinePosition->Baseline,
      ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
        If[
         Not[
          AbsoluteCurrentValue["Deployed"]], 
         SelectionMove[Typeset`box$, All, Expression]; 
         FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
         FrontEnd`Private`$ColorSelectorInitialColor = 
          RGBColor[
           0.9752641706478989, 0.8013981246170678, 0.10899973580393796`]; 
         FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
         MathLink`CallFrontEnd[
           FrontEnd`AttachCell[Typeset`box$, 
            FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
            Left, Top}, 
            "ClosingActions" -> {
             "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
      DefaultBaseStyle->{},
      Evaluator->Automatic,
      Method->"Preemptive"],
     RGBColor[{0.9752641706478989, 0.8013981246170678, 0.10899973580393796`}],
     
     Editable->False,
     Selectable->False], ",", 
    InterpretationBox[
     ButtonBox[
      TooltipBox[
       GraphicsBox[{
         {GrayLevel[0], RectangleBox[{0, 0}]}, 
         {GrayLevel[0], RectangleBox[{1, -1}]}, 
         {RGBColor[
          0.16590548598015492`, 0.9015045495499641, 0.09828783196817376], 
          RectangleBox[{0, -1}, {2, 1}]}},
        AspectRatio->1,
        Frame->True,
        FrameStyle->RGBColor[
         0.11060365732010329`, 0.6010030330333094, 0.06552522131211584],
        FrameTicks->None,
        ImageSize->
         Dynamic[{
          Automatic, 
           1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
            Magnification])}],
        PlotRangePadding->None],
       "RGBColor[{0.16590548598015492, 0.9015045495499641, \
0.09828783196817376}]"],
      Appearance->None,
      BaseStyle->{},
      BaselinePosition->Baseline,
      ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
        If[
         Not[
          AbsoluteCurrentValue["Deployed"]], 
         SelectionMove[Typeset`box$, All, Expression]; 
         FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
         FrontEnd`Private`$ColorSelectorInitialColor = 
          RGBColor[
           0.16590548598015492`, 0.9015045495499641, 0.09828783196817376]; 
         FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
         MathLink`CallFrontEnd[
           FrontEnd`AttachCell[Typeset`box$, 
            FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
            Left, Top}, 
            "ClosingActions" -> {
             "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
      DefaultBaseStyle->{},
      Evaluator->Automatic,
      Method->"Preemptive"],
     RGBColor[{0.16590548598015492`, 0.9015045495499641, 0.09828783196817376}],
     Editable->False,
     Selectable->False], ",", 
    InterpretationBox[
     ButtonBox[
      TooltipBox[
       GraphicsBox[{
         {GrayLevel[0], RectangleBox[{0, 0}]}, 
         {GrayLevel[0], RectangleBox[{1, -1}]}, 
         {RGBColor[
          0.10048980936842117`, 0.9171495192304465, 0.16131399976146749`], 
          RectangleBox[{0, -1}, {2, 1}]}},
        AspectRatio->1,
        Frame->True,
        FrameStyle->RGBColor[
         0.06699320624561411, 0.6114330128202977, 0.10754266650764499`],
        FrameTicks->None,
        ImageSize->
         Dynamic[{
          Automatic, 
           1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
            Magnification])}],
        PlotRangePadding->None],
       "RGBColor[{0.10048980936842117, 0.9171495192304465, \
0.16131399976146749}]"],
      Appearance->None,
      BaseStyle->{},
      BaselinePosition->Baseline,
      ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
        If[
         Not[
          AbsoluteCurrentValue["Deployed"]], 
         SelectionMove[Typeset`box$, All, Expression]; 
         FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
         FrontEnd`Private`$ColorSelectorInitialColor = 
          RGBColor[
           0.10048980936842117`, 0.9171495192304465, 0.16131399976146749`]; 
         FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
         MathLink`CallFrontEnd[
           FrontEnd`AttachCell[Typeset`box$, 
            FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
            Left, Top}, 
            "ClosingActions" -> {
             "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
      DefaultBaseStyle->{},
      Evaluator->Automatic,
      Method->"Preemptive"],
     RGBColor[{0.10048980936842117`, 0.9171495192304465, 
      0.16131399976146749`}],
     Editable->False,
     Selectable->False]}], "}"}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[21]:=",ExpressionUUID->"4c16f64c-9e47-4916-a307-d8116fca4292"],

Cell[BoxData[
 GraphicsBox[{{}, {{}, 
    {Hue[0.67, 0.6, 0.6], Opacity[0], PointBox[CompressedData["
1:eJwBcQGO/iFib1JlAgAAABYAAAACAAAAEVx1NbsSX8Dw6oDVpgwAQAEHFPRP
JGNATJe9RlnDOsD7718001U5wFmg6GyXWFBAUo61e1xWY8DuXVi75djmP1Kt
VsxLbGHArdDaGImG9z/n4yjCC2s2wPa3+Ih+U0pALqZK8LhlQcAZF8e9kM5J
QHfOeKW8IV3AI3OQWJBoI8AAG1O9xEFhQJKPajODjjrA7Nugf60hX0C5NCaD
SEo3wMYqKtylvWRAimr0ksCCNsDOn/9oWM9CwHqNmOrFwFBAJjNmbRsCYUCY
2LD6BLsrwHB3CQVKrFxA6bRFRvLkQMCu2GlPREhHwDpE8ajAkExAaxJVl7y/
XcBDT/esLho2wNqlxbOT7FtAk3NNp5UqMsCgM9Ax1YJgwC9A9o7NrjnAIw9l
ONyYY0A2rAwgwxQpwOPOnMtXmV9AKTJAWwh1Q8BPTKwLVFVgwOIOLwRcqyXA
53a6rUb8YcD/oG7KJYcqwFo4rSc=
      "]]}, {}}, {}, {}, {{}, {}}, {{}, {InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.048175746346922704`, 0.8856231902848692, 
                0.002187262571789972], RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.0321171642312818, 0.5904154601899129, 0.0014581750478599813`],
             
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[{0.048175746346922704, 0.8856231902848692, \
0.002187262571789972}]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.048175746346922704`, 0.8856231902848692, 
                 0.002187262571789972]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          
          RGBColor[{0.048175746346922704`, 0.8856231902848692, 
           0.002187262571789972}],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {-124.29267631970312, 2.0061775855987136}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.9543437880041175, 0.9364915417894851, 0.08314980598714755], 
               RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.636229192002745, 0.6243276945263234, 0.0554332039914317],
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[{0.9543437880041175, 0.9364915417894851, \
0.08314980598714755}]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.9543437880041175, 0.9364915417894851, 0.08314980598714755]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          
          RGBColor[{0.9543437880041175, 0.9364915417894851, 
           0.08314980598714755}],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {153.13475994025796, -26.763080998694292}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.8527294202095301, 0.15459949958575997`, 0.08139444813034824],
                RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.5684862801396868, 0.10306633305717332`, 0.054262965420232165`],
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[{0.8527294202095301, 0.15459949958575997, \
0.08139444813034824}]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.8527294202095301, 0.15459949958575997`, 
                 0.08139444813034824]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          
          RGBColor[{0.8527294202095301, 0.15459949958575997`, 
           0.08139444813034824}],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {-25.335253976270888, 65.38424227445047}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.12965437429396431`, 0.8338364200576898, 
                0.16859742903104202`], RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.08643624952930955, 0.5558909467051265, 0.11239828602069468`],
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[{0.12965437429396431, 0.8338364200576898, \
0.16859742903104202}]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.12965437429396431`, 0.8338364200576898, 
                 0.16859742903104202`]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          
          RGBColor[{0.12965437429396431`, 0.8338364200576898, 
           0.16859742903104202`}],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {-154.69878945789475, 0.7139767321668253}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.14189318640501342`, 0.8685451286121387, 
                0.10426943556314977`], RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.09459545760334229, 0.5790300857414259, 0.06951295704209985],
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[{0.14189318640501342, 0.8685451286121387, \
0.10426943556314977}]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.14189318640501342`, 0.8685451286121387, 
                 0.10426943556314977`]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          
          RGBColor[{0.14189318640501342`, 0.8685451286121387, 
           0.10426943556314977`}],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {-139.38425270966633, 1.4703455897224942}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.9244703510275273, 0.001783470411052479, 
                0.14318146272477922`], RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.6163135673516849, 0.0011889802740349862`, 0.09545430848318615],
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[{0.9244703510275273, 0.001783470411052479, \
0.14318146272477922}]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.9244703510275273, 0.001783470411052479, 
                 0.14318146272477922`]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          
          RGBColor[{0.9244703510275273, 0.001783470411052479, 
           0.14318146272477922`}],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {-22.418148169501276, 52.65229904312575}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.8340523614444824, 0.038129646837010533`, 
                0.09354464468116397], RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.5560349076296549, 0.025419764558007023`, 0.06236309645410931],
             
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[{0.8340523614444824, 0.038129646837010533, \
0.09354464468116397}]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.8340523614444824, 0.038129646837010533`, 
                 0.09354464468116397]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          
          RGBColor[{0.8340523614444824, 0.038129646837010533`, 
           0.09354464468116397}],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {-34.79470637936571, 51.613792154514336}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.06423181065333894, 0.9361486399945784, 0.08411970647251821], 
               RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.042821207102225964`, 0.624099093329719, 0.05607980431501214],
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[{0.06423181065333894, 0.9361486399945784, \
0.08411970647251821}]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.06423181065333894, 0.9361486399945784, 0.08411970647251821]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          
          RGBColor[{0.06423181065333894, 0.9361486399945784, 
           0.08411970647251821}],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {-116.52713906095038, -9.704226272233035}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.8676164929883508, 0.8866580065099905, 0.024086278089002183`],
                RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.5784109953255672, 0.5911053376733271, 0.016057518726001457`],
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[{0.8676164929883508, 0.8866580065099905, \
0.024086278089002183}]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.8676164929883508, 0.8866580065099905, 
                 0.024086278089002183`]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          
          RGBColor[{0.8676164929883508, 0.8866580065099905, 
           0.024086278089002183`}],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {138.0552660582689, -26.556689466014696}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.8577958146408966, 0.8374035340744639, 
                0.0071190816223388464`], RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.5718638764272644, 0.5582690227163093, 0.004746054414892564],
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[{0.8577958146408966, 0.8374035340744639, \
0.0071190816223388464}]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.8577958146408966, 0.8374035340744639, 
                 0.0071190816223388464`]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          
          RGBColor[{0.8577958146408966, 0.8374035340744639, 
           0.0071190816223388464`}],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {124.52621451100248, -23.29016894991648}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.9967431643372854, 0.969475575859666, 0.12251095291379577`], 
               RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.6644954428915236, 0.6463170505731107, 0.08167396860919718],
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[{0.9967431643372854, 0.969475575859666, \
0.12251095291379577}]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.9967431643372854, 0.969475575859666, 0.12251095291379577`]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          
          RGBColor[{0.9967431643372854, 0.969475575859666, 
           0.12251095291379577`}],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {165.92649658427962, -22.51075094668571}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.8543889209256321, 0.09697598692920356, 0.10750903324099509`],
                RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.5695926139504215, 0.06465065795280238, 0.07167268882733006],
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[{0.8543889209256321, 0.09697598692920356, \
0.10750903324099509}]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.8543889209256321, 0.09697598692920356, 
                 0.10750903324099509`]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          
          RGBColor[{0.8543889209256321, 0.09697598692920356, 
           0.10750903324099509`}],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {-37.619885563675425, 67.01207985780448}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.8500363984900003, 0.9263311671408848, 0.13924242858059316`], 
               RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.5666909323266669, 0.6175541114272566, 0.09282828572039545],
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[{0.8500363984900003, 0.9263311671408848, \
0.13924242858059316}]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.8500363984900003, 0.9263311671408848, 0.13924242858059316`]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          
          RGBColor[{0.8500363984900003, 0.9263311671408848, 
           0.13924242858059316`}],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {136.0658480640497, -13.865272363746314}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.9879209034166253, 0.8377732017482453, 0.15613661869756118`], 
               RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.6586139356110836, 0.5585154678321635, 0.10409107913170745`],
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[{0.9879209034166253, 0.8377732017482453, \
0.15613661869756118}]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.9879209034166253, 0.8377732017482453, 0.15613661869756118`]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          
          RGBColor[{0.9879209034166253, 0.8377732017482453, 
           0.15613661869756118`}],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {114.69201780247181, -33.78864363101622}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.9573167308698426, 0.1507116093826361, 0.09832234398916928], 
               RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.6382111539132285, 0.10047440625509074`, 0.06554822932611286],
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[{0.9573167308698426, 0.1507116093826361, \
0.09832234398916928}]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.9573167308698426, 0.1507116093826361, 0.09832234398916928]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          
          RGBColor[{0.9573167308698426, 0.1507116093826361, 
           0.09832234398916928}],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {-46.56458466213495, 57.13087951450912}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.04278634258158939, 0.9055378427790535, 
                0.0003309996431954121], RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.028524228387726263`, 0.6036918951860357, 
               0.0002206664287969414],
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[{0.04278634258158939, 0.9055378427790535, \
0.0003309996431954121}]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.04278634258158939, 0.9055378427790535, 
                 0.0003309996431954121]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          
          RGBColor[{0.04278634258158939, 0.9055378427790535, 
           0.0003309996431954121}],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {-118.99588568980987, -22.102274713877033}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.8058039405531526, 0.8318774133774354, 0.10151558699591279`], 
               RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.5372026270354351, 0.5545849422516236, 0.06767705799727519],
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[{0.8058039405531526, 0.8318774133774354, \
0.10151558699591279}]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.8058039405531526, 0.8318774133774354, 0.10151558699591279`]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          
          RGBColor[{0.8058039405531526, 0.8318774133774354, 
           0.10151558699591279`}],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {111.69651502896832, -18.166346031579064}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.006814389873512461, 0.9336694049188562, 0.06907220235176909],
                RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.004542926582341641, 0.6224462699459041, 0.04604813490117939],
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[{0.006814389873512461, 0.9336694049188562, \
0.06907220235176909}]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.006814389873512461, 0.9336694049188562, 
                 0.06907220235176909]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          
          RGBColor[{0.006814389873512461, 0.9336694049188562, 
           0.06907220235176909}],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {-132.08852472938906, -25.682824072952084}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.9450158125329948, 0.9670907305400336, 0.05040029871534907], 
               RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.6300105416886632, 0.6447271536933558, 0.033600199143566045`],
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[{0.9450158125329948, 0.9670907305400336, \
0.05040029871534907}]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.9450158125329948, 0.9670907305400336, 0.05040029871534907]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          
          RGBColor[{0.9450158125329948, 0.9670907305400336, 
           0.05040029871534907}],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {156.77688235986815, -12.540551187083206}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.9752641706478989, 0.8013981246170678, 0.10899973580393796`], 
               RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.650176113765266, 0.5342654164113786, 0.07266649053595864],
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[{0.9752641706478989, 0.8013981246170678, \
0.10899973580393796}]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.9752641706478989, 0.8013981246170678, 0.10899973580393796`]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          
          RGBColor[{0.9752641706478989, 0.8013981246170678, 
           0.10899973580393796`}],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {126.39598360360428, -38.91431751856391}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.16590548598015492`, 0.9015045495499641, 0.09828783196817376],
                RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.11060365732010329`, 0.6010030330333094, 0.06552522131211584],
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[{0.16590548598015492, 0.9015045495499641, \
0.09828783196817376}]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.16590548598015492`, 0.9015045495499641, 
                 0.09828783196817376]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          
          RGBColor[{0.16590548598015492`, 0.9015045495499641, 
           0.09828783196817376}],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {-130.66650947238892, -10.834686403984453}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.10048980936842117`, 0.9171495192304465, 
                0.16131399976146749`], RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.06699320624561411, 0.6114330128202977, 0.10754266650764499`],
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[{0.10048980936842117, 0.9171495192304465, \
0.16131399976146749}]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.10048980936842117`, 0.9171495192304465, 
                 0.16131399976146749`]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          
          RGBColor[{0.10048980936842117`, 0.9171495192304465, 
           0.16131399976146749`}],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {-143.8836277620205, -13.263960195545677}, {0, 0}]}}},
  AspectRatio->1,
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  ImageSize->{170.26953125, Automatic},
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->All,
  PlotRangeClipping->False,
  PlotRangePadding->{{
     Scaled[0.05], 
     Scaled[0.05]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[21]=",ExpressionUUID->"8ed0943d-5e39-43f9-b074-7baca2dceef9"]
}, Open  ]],

Cell[TextData[{
 "If one uses, say, 100 colors picked completely at random, then ",
 ButtonBox["FeatureSpacePlot",
  BaseStyle->"Link"],
 " will again place colors it considers similar nearby. "
}], "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:25",ExpressionUUID->"e4ac5c47-a82e-46d0-a36c-bad0dbf6184c"],

Cell[TextData[{
 "100 random colors laid out by ",
 ButtonBox["FeatureSpacePlot",
  BaseStyle->"Link"],
 ":"
}], "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"dbbe81e9-94c3-49de-9d40-422f27a7ec4a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FeatureSpacePlot", "[", 
  RowBox[{"RandomColor", "[", "100", "]"}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[22]:=",ExpressionUUID->"69b285f3-c8f4-4e38-b3e6-6d0487e4f870"],

Cell[BoxData[
 GraphicsBox[{{}, {{}, 
    {Hue[0.67, 0.6, 0.6], Opacity[0], PointBox[CompressedData["
1:eJwVk/0/FPYDwM85j8edhzsXxyJK7QovUzZLn4+ah3nN5elsstLmdOSqTbHK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      "]]}, {}}, {}, {}, {{}, {}}, {{}, {InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.8621529936884753, 0.8539925788052689, 0.8423617599498234], 
               RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.5747686624589836, 0.5693283858701793, 0.5615745066332156],
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[0.8621529936884753, 0.8539925788052689, \
0.8423617599498234]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.8621529936884753, 0.8539925788052689, 0.8423617599498234]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[0.8621529936884753, 0.8539925788052689, 0.8423617599498234],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {3.178335027234928, -0.8806608965045539}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.48610690963164527`, 0.1510045944518823, 0.3207473634952218], 
               RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.3240712730877635, 0.1006697296345882, 0.2138315756634812],
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[0.48610690963164527, 0.1510045944518823, \
0.3207473634952218]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.48610690963164527`, 0.1510045944518823, 0.3207473634952218]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[
          0.48610690963164527`, 0.1510045944518823, 0.3207473634952218],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {-1.762824521528096, 2.264228290190377}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.33040646103090054`, 0.047110950529081874`, 
                0.7695991072623203], RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.22027097402060036`, 0.031407300352721254`, 0.5130660715082136],
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[0.33040646103090054, 0.047110950529081874, \
0.7695991072623203]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.33040646103090054`, 0.047110950529081874`, 
                 0.7695991072623203]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[
          0.33040646103090054`, 0.047110950529081874`, 0.7695991072623203],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {-0.6019674516260365, 6.333942730008991}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.7417253395512808, 0.24652876245698252`, 
                0.34600439893011736`], RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.4944835597008539, 0.16435250830465503`, 0.2306695992867449],
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[0.7417253395512808, 0.24652876245698252, \
0.34600439893011736]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.7417253395512808, 0.24652876245698252`, 
                 0.34600439893011736`]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[
          0.7417253395512808, 0.24652876245698252`, 0.34600439893011736`],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {-3.041684631520641, 1.838739415915511}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.5412884824950965, 0.8810225604142004, 0.3787556524376299], 
               RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.36085898833006436`, 0.5873483736094669, 0.25250376829175325`],
             
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[0.5412884824950965, 0.8810225604142004, \
0.3787556524376299]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.5412884824950965, 0.8810225604142004, 0.3787556524376299]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[0.5412884824950965, 0.8810225604142004, 0.3787556524376299],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {1.18132831794714, -5.139236983247806}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.5428984834166948, 0.19580443419643112`, 0.8691981904361019], 
               RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.36193232227779654`, 0.1305362894642874, 0.5794654602907346],
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[0.5428984834166948, 0.19580443419643112, \
0.8691981904361019]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.5428984834166948, 0.19580443419643112`, 0.8691981904361019]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[
          0.5428984834166948, 0.19580443419643112`, 0.8691981904361019],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {-1.4409874476589608, 5.5999959253430065}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.5353527189773004, 0.791652624102712, 0.8336791821955654], 
               RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.35690181265153365`, 0.5277684160684747, 0.5557861214637103],
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[0.5353527189773004, 0.791652624102712, \
0.8336791821955654]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.5353527189773004, 0.791652624102712, 0.8336791821955654]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[0.5353527189773004, 0.791652624102712, 0.8336791821955654],
          
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {3.2610491079735593, -2.01057407754001}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.6220393011043692, 0.3981044758227361, 0.8778451906591753], 
               RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.41469286740291283`, 0.2654029838818241, 0.5852301271061169],
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[0.6220393011043692, 0.3981044758227361, \
0.8778451906591753]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.6220393011043692, 0.3981044758227361, 0.8778451906591753]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[0.6220393011043692, 0.3981044758227361, 0.8778451906591753],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {-1.303197600262991, 4.406653639490444}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.7360733076087458, 0.7316303486552604, 0.3031891452119586], 
               RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.49071553840583054`, 0.48775356577017365`, 
               0.20212609680797242`],
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[0.7360733076087458, 0.7316303486552604, \
0.3031891452119586]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.7360733076087458, 0.7316303486552604, 0.3031891452119586]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[0.7360733076087458, 0.7316303486552604, 0.3031891452119586],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {-0.03861926245012009, -4.155079708776868}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.04347222766418746, 0.6784440511066594, 0.5307537775227298], 
               RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.028981485109458305`, 0.4522960340711063, 0.35383585168181986`],
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[0.04347222766418746, 0.6784440511066594, \
0.5307537775227298]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.04347222766418746, 0.6784440511066594, 0.5307537775227298]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[
          0.04347222766418746, 0.6784440511066594, 0.5307537775227298],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {1.82140474192998, -2.842384977609687}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.98819348593841, 0.9637325269582566, 0.5708779135535313], 
               RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.6587956572922734, 0.6424883513055044, 0.38058527570235423`],
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[0.98819348593841, 0.9637325269582566, \
0.5708779135535313]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.98819348593841, 0.9637325269582566, 0.5708779135535313]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[0.98819348593841, 0.9637325269582566, 0.5708779135535313],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {-0.5220578545126493, -5.833392094173399}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.2811086976373349, 0.78647126285187, 0.820918083380151], 
               RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.18740579842488997`, 0.52431417523458, 0.5472787222534341],
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[0.2811086976373349, 0.78647126285187, \
0.820918083380151]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.2811086976373349, 0.78647126285187, 0.820918083380151]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[0.2811086976373349, 0.78647126285187, 0.820918083380151],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {3.2063348322507954, -2.5397000342784524}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.6327994725394193, 0.8082494699987823, 0.4287852365416278], 
               RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.4218663150262795, 0.5388329799991882, 0.2858568243610852],
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[0.6327994725394193, 0.8082494699987823, \
0.4287852365416278]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.6327994725394193, 0.8082494699987823, 0.4287852365416278]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[0.6327994725394193, 0.8082494699987823, 0.4287852365416278],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {0.793455214392412, -4.348539204286523}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.8843464589508392, 0.6759988974886209, 0.6129845664711759], 
               RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.5895643059672262, 0.4506659316590806, 0.40865637764745066`],
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[0.8843464589508392, 0.6759988974886209, \
0.6129845664711759]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.8843464589508392, 0.6759988974886209, 0.6129845664711759]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[0.8843464589508392, 0.6759988974886209, 0.6129845664711759],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {2.2346506854815122, -0.2898101789689803}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.9053754781397554, 0.5887084903659634, 0.14299391608040923`], 
               RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.6035836520931703, 0.39247232691064227`, 0.0953292773869395],
             FrameTicks->None,
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[0.9053754781397554, 0.5887084903659634, \
0.14299391608040923]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.9053754781397554, 0.5887084903659634, 0.14299391608040923`]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[
          0.9053754781397554, 0.5887084903659634, 0.14299391608040923`],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {-2.685855697777095, -1.8475237965346318}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.07728278443218439, 0.8939965579745008, 0.3917318679348081], 
               RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.05152185628812293, 0.5959977053163339, 0.2611545786232054],
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[0.07728278443218439, 0.8939965579745008, \
0.3917318679348081]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.07728278443218439, 0.8939965579745008, 0.3917318679348081]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[
          0.07728278443218439, 0.8939965579745008, 0.3917318679348081],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {2.162938179672294, -5.2166197147151285}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.3108876142766388, 0.7591410921438284, 0.6597295817859201], 
               RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.2072584095177592, 0.506094061429219, 0.4398197211906134],
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[0.3108876142766388, 0.7591410921438284, \
0.6597295817859201]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.3108876142766388, 0.7591410921438284, 0.6597295817859201]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[0.3108876142766388, 0.7591410921438284, 0.6597295817859201],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {2.536591914536455, -2.8757232834406588}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.6216823068013388, 0.6529554671688487, 0.5108132169985915], 
               RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.4144548712008926, 0.43530364477923245`, 0.3405421446657277],
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[0.6216823068013388, 0.6529554671688487, \
0.5108132169985915]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.6216823068013388, 0.6529554671688487, 0.5108132169985915]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[0.6216823068013388, 0.6529554671688487, 0.5108132169985915],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {1.481717640059616, -1.4642718085433386}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.9107422321484435, 0.3028883679860943, 0.6177768725464061], 
               RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.6071614880989624, 0.20192557865739622`, 0.4118512483642708],
             FrameTicks->None,
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[0.9107422321484435, 0.3028883679860943, \
0.6177768725464061]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.9107422321484435, 0.3028883679860943, 0.6177768725464061]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[0.9107422321484435, 0.3028883679860943, 0.6177768725464061],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {-3.0149972109127257, 3.175605070595614}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.8916563476729327, 0.38547641767886254`, 0.3530990274237633], 
               RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.5944375651152884, 0.25698427845257504`, 0.23539935161584222`],
             
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[0.8916563476729327, 0.38547641767886254, \
0.3530990274237633]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.8916563476729327, 0.38547641767886254`, 0.3530990274237633]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[
          0.8916563476729327, 0.38547641767886254`, 0.3530990274237633],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {-3.391554420637159, 0.8543338871754752}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.7723573871163438, 0.07852763394252138, 0.13167110302533813`],
                RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.5149049247442292, 0.05235175596168092, 0.08778073535022543],
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[0.7723573871163438, 0.07852763394252138, \
0.13167110302533813]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.7723573871163438, 0.07852763394252138, 
                 0.13167110302533813`]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[
          0.7723573871163438, 0.07852763394252138, 0.13167110302533813`],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {-3.697202591440489, 1.1864609223666074}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.5724949339583905, 0.22088251136558656`, 
                0.039827519400919664`], RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.3816632893055937, 0.14725500757705773`, 0.02655167960061311],
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[0.5724949339583905, 0.22088251136558656, \
0.039827519400919664]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.5724949339583905, 0.22088251136558656`, 
                 0.039827519400919664`]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[
          0.5724949339583905, 0.22088251136558656`, 0.039827519400919664`],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {-2.5304840394132104, 0.8973386351692384}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.9077213915623286, 0.9311439132675434, 0.18840443474636293`], 
               RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.6051475943748857, 0.620762608845029, 0.1256029564975753],
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[0.9077213915623286, 0.9311439132675434, \
0.18840443474636293]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.9077213915623286, 0.9311439132675434, 0.18840443474636293`]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[
          0.9077213915623286, 0.9311439132675434, 0.18840443474636293`],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {-0.13343375307217908, -5.850688034356041}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.30227362019727133`, 0.046436192752482786`, 
                0.6473084928672772], RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.2015157467981809, 0.030957461834988525`, 0.4315389952448515],
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[0.30227362019727133, 0.046436192752482786, \
0.6473084928672772]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.30227362019727133`, 0.046436192752482786`, 
                 0.6473084928672772]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[
          0.30227362019727133`, 0.046436192752482786`, 0.6473084928672772],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {-0.060819872474523806, 6.136660454875967}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.28449468393566346`, 0.3646950659593611, 0.9725584630060473], 
               RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.18966312262377566`, 0.24313004397290738`, 0.6483723086706983],
             
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[0.28449468393566346, 0.3646950659593611, \
0.9725584630060473]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.28449468393566346`, 0.3646950659593611, 0.9725584630060473]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[
          0.28449468393566346`, 0.3646950659593611, 0.9725584630060473],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {-0.7205775993558209, 5.098131883985356}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.920090078414695, 0.7299890190887308, 0.756431234798356], 
               RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.6133933856097967, 0.4866593460591539, 0.5042874898655707],
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[0.920090078414695, 0.7299890190887308, \
0.756431234798356]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.920090078414695, 0.7299890190887308, 0.756431234798356]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[0.920090078414695, 0.7299890190887308, 0.756431234798356],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {2.686211086387886, -0.2096314600921918}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.5319952890825961, 0.9937909728809746, 0.39498998485044945`], 
               RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.35466352605506407`, 0.6625273152539831, 0.2633266565669663],
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[0.5319952890825961, 0.9937909728809746, \
0.39498998485044945]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.5319952890825961, 0.9937909728809746, 0.39498998485044945`]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[
          0.5319952890825961, 0.9937909728809746, 0.39498998485044945`],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {1.3393701401496805, -5.981627936342793}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.2824781447476685, 0.8750911795394467, 0.8255240967725028], 
               RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.18831876316511237`, 0.5833941196929645, 0.5503493978483353],
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[0.2824781447476685, 0.8750911795394467, \
0.8255240967725028]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.2824781447476685, 0.8750911795394467, 0.8255240967725028]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[0.2824781447476685, 0.8750911795394467, 0.8255240967725028],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {3.3437239237601135, -3.2721907036830005}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.5704393530792522, 0.37860163920908296`, 0.08561862185720326],
                RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.38029290205283484`, 0.2524010928060553, 0.05707908123813551],
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[0.5704393530792522, 0.37860163920908296, \
0.08561862185720326]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.5704393530792522, 0.37860163920908296`, 
                 0.08561862185720326]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[
          0.5704393530792522, 0.37860163920908296`, 0.08561862185720326],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {-2.031250635723133, 0.13204736526975366}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.3484750643833969, 0.199678182183868, 0.18712019151041726`], 
               RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.2323167095889313, 0.13311878812257869`, 0.12474679434027817`],
             
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[0.3484750643833969, 0.199678182183868, \
0.18712019151041726]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.3484750643833969, 0.199678182183868, 0.18712019151041726`]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[
          0.3484750643833969, 0.199678182183868, 0.18712019151041726`],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {-1.290281992010263, 1.6508906485659258}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.6485355347551154, 0.2867518173739385, 0.82835121131418], 
               RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.43235702317007696`, 0.19116787824929235`, 0.55223414087612],
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[0.6485355347551154, 0.2867518173739385, \
0.82835121131418]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.6485355347551154, 0.2867518173739385, 0.82835121131418]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[0.6485355347551154, 0.2867518173739385, 0.82835121131418],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {-1.6251330235447807, 4.955889483371275}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.9916706732804439, 0.54153543401372, 0.9479219691505856], 
               RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.6611137821869626, 0.36102362267581334`, 0.6319479794337237],
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[0.9916706732804439, 0.54153543401372, \
0.9479219691505856]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.9916706732804439, 0.54153543401372, 0.9479219691505856]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[0.9916706732804439, 0.54153543401372, 0.9479219691505856],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {1.5765152254031876, 2.5748814118791534}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.27798780561869263`, 0.9762775451741039, 
                0.36376743297031844`], RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.1853252037457951, 0.650851696782736, 0.2425116219802123],
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[0.27798780561869263, 0.9762775451741039, \
0.36376743297031844]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.27798780561869263`, 0.9762775451741039, 
                 0.36376743297031844`]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[
          0.27798780561869263`, 0.9762775451741039, 0.36376743297031844`],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {1.8946351390450742, -5.88345801559761}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.23680966664392344`, 0.3809751657316154, 0.02954484609319863],
                RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.15787311109594898`, 0.25398344382107696`, 0.01969656406213242],
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[0.23680966664392344, 0.3809751657316154, \
0.02954484609319863]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.23680966664392344`, 0.3809751657316154, 
                 0.02954484609319863]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[
          0.23680966664392344`, 0.3809751657316154, 0.02954484609319863],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {-0.7059094333344419, -0.7938327999599425}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.9009676915905636, 0.13367089879253902`, 0.8423097973934865], 
               RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.6006451277270424, 0.08911393252835935, 0.5615398649289911],
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[0.9009676915905636, 0.13367089879253902, \
0.8423097973934865]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.9009676915905636, 0.13367089879253902`, 0.8423097973934865]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[
          0.9009676915905636, 0.13367089879253902`, 0.8423097973934865],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {-2.5228160626467697, 4.508067607919321}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.5781264131729706, 0.37955493929053885`, 0.5283796661568618], 
               RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.38541760878198045`, 0.2530366261936926, 0.3522531107712412],
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[0.5781264131729706, 0.37955493929053885, \
0.5283796661568618]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.5781264131729706, 0.37955493929053885`, 0.5283796661568618]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[
          0.5781264131729706, 0.37955493929053885`, 0.5283796661568618],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {-0.5748134177666198, 2.5281498810522467}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.037283925171878174`, 0.5283966637471951, 
                0.010896720610697797`], RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.02485595011458545, 0.35226444249813005`, 0.007264480407131865],
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[0.037283925171878174, 0.5283966637471951, \
0.010896720610697797]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.037283925171878174`, 0.5283966637471951, 
                 0.010896720610697797`]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[
          0.037283925171878174`, 0.5283966637471951, 0.010896720610697797`],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {-0.3436943858320546, -2.1763314847080335}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.004243411348575199, 0.4016123289754121, 
                0.41819923987577456`], RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.002828940899050133, 0.26774155265027477`, 0.2787994932505164],
             
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[0.004243411348575199, 0.4016123289754121, \
0.41819923987577456]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.004243411348575199, 0.4016123289754121, 
                 0.41819923987577456`]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[
          0.004243411348575199, 0.4016123289754121, 0.41819923987577456`],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {-0.07917482249971969, 0.6461472169914237}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.396471405231664, 0.18720860577794385`, 0.9053236500613064], 
               RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.2643142701544427, 0.1248057371852959, 0.603549100040871],
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[0.396471405231664, 0.18720860577794385, \
0.9053236500613064]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.396471405231664, 0.18720860577794385`, 0.9053236500613064]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[
          0.396471405231664, 0.18720860577794385`, 0.9053236500613064],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {-0.9799060361269436, 5.895135846545922}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.5384338837322848, 0.0028700348962173994`, 
                0.16254968874142373`], RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.3589559224881899, 0.0019133565974782663`, 
               0.10836645916094916`],
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[0.5384338837322848, 0.0028700348962173994, \
0.16254968874142373]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.5384338837322848, 0.0028700348962173994`, 
                 0.16254968874142373`]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[
          0.5384338837322848, 0.0028700348962173994`, 0.16254968874142373`],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {-2.3644898563159007, 1.7968117656112215}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.9521867189194799, 0.8113359809620313, 0.19476399249060905`], 
               RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.63479114594632, 0.5408906539746876, 0.12984266166040603`],
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[0.9521867189194799, 0.8113359809620313, \
0.19476399249060905]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.9521867189194799, 0.8113359809620313, 0.19476399249060905`]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[
          0.9521867189194799, 0.8113359809620313, 0.19476399249060905`],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {-0.713259413483879, -5.149028312627988}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.24536715813642407`, 0.8524188035481148, 0.2746661160784263], 
               RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.16357810542428272`, 0.56827920236541, 0.1831107440522842],
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[0.24536715813642407, 0.8524188035481148, \
0.2746661160784263]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.24536715813642407`, 0.8524188035481148, 0.2746661160784263]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[
          0.24536715813642407`, 0.8524188035481148, 0.2746661160784263],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {1.8383443337945964, -5.125950108767335}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.3953590653967616, 0.15110543296239687`, 0.9639399212642141], 
               RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.26357271026450774`, 0.10073695530826458`, 0.6426266141761428],
             
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[0.3953590653967616, 0.15110543296239687, \
0.9639399212642141]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.3953590653967616, 0.15110543296239687`, 0.9639399212642141]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[
          0.3953590653967616, 0.15110543296239687`, 0.9639399212642141],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {-1.1793279520537476, 6.290898712126161}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.7720093095803364, 0.2711835751234073, 0.27097050010241364`], 
               RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.5146728730535577, 0.18078905008227153`, 0.18064700006827578`],
             
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[0.7720093095803364, 0.2711835751234073, \
0.27097050010241364]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.7720093095803364, 0.2711835751234073, 0.27097050010241364`]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[
          0.7720093095803364, 0.2711835751234073, 0.27097050010241364`],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {-3.2313619386852666, 1.3332482965885863}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.11601686675626377`, 0.027308664374646963`, 
                0.24161393242383933`], RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.07734457783750918, 0.018205776249764643`, 
               0.16107595494922622`],
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[0.11601686675626377, 0.027308664374646963, \
0.24161393242383933]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.11601686675626377`, 0.027308664374646963`, 
                 0.24161393242383933`]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[
          0.11601686675626377`, 0.027308664374646963`, 0.24161393242383933`],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {1.3178577056224645, 5.191691639674974}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.5051502818318012, 0.3552916631600995, 0.4876401675994917], 
               RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.33676685455453415`, 0.2368611087733997, 0.3250934450663278],
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[0.5051502818318012, 0.3552916631600995, \
0.4876401675994917]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.5051502818318012, 0.3552916631600995, 0.4876401675994917]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[0.5051502818318012, 0.3552916631600995, 0.4876401675994917],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {-0.6049228903433679, 2.2830966364771066}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.7638439371785224, 0.5513285818537395, 0.5456953640037066], 
               RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.5092292914523483, 0.367552387902493, 0.3637969093358044],
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[0.7638439371785224, 0.5513285818537395, \
0.5456953640037066]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.7638439371785224, 0.5513285818537395, 0.5456953640037066]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[0.7638439371785224, 0.5513285818537395, 0.5456953640037066],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {1.523087522949353, 0.12954640580769472}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.8021216666895086, 0.2623275827424829, 0.42485817897964107`], 
               RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.5347477777930058, 0.17488505516165528`, 0.2832387859864274],
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[0.8021216666895086, 0.2623275827424829, \
0.42485817897964107]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.8021216666895086, 0.2623275827424829, 0.42485817897964107`]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[
          0.8021216666895086, 0.2623275827424829, 0.42485817897964107`],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {-3.195291028515436, 2.1959826781512795}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.15478506016254046`, 0.34172516000178654`, 0.737534120274707],
                RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.1031900401083603, 0.22781677333452438`, 0.49168941351647133`],
             
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[0.15478506016254046, 0.34172516000178654, \
0.737534120274707]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.15478506016254046`, 0.34172516000178654`, 
                 0.737534120274707]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[
          0.15478506016254046`, 0.34172516000178654`, 0.737534120274707],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {0.04621279678685875, 4.453623772896127}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.17575686221277675`, 0.2744797018428551, 
                0.0034220380264231576`], RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.11717124147518451`, 0.18298646789523673`, 
               0.002281358684282105],
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[0.17575686221277675, 0.2744797018428551, \
0.0034220380264231576]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.17575686221277675`, 0.2744797018428551, 
                 0.0034220380264231576`]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[
          0.17575686221277675`, 0.2744797018428551, 0.0034220380264231576`],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {-0.78654367281106, -0.08334172789740645}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.4472980642278088, 0.8487063423985328, 0.9752202589259169], 
               RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.2981987094852059, 0.5658042282656885, 0.6501468392839447],
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[0.4472980642278088, 0.8487063423985328, \
0.9752202589259169]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.4472980642278088, 0.8487063423985328, 0.9752202589259169]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[0.4472980642278088, 0.8487063423985328, 0.9752202589259169],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {3.7630221371791723, -2.2756527695653204}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.8298473775733388, 0.8381662170909585, 0.01769586954819924], 
               RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.5532315850488926, 0.558777478060639, 0.01179724636546616],
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[0.8298473775733388, 0.8381662170909585, \
0.01769586954819924]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.8298473775733388, 0.8381662170909585, 0.01769586954819924]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[
          0.8298473775733388, 0.8381662170909585, 0.01769586954819924],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {-0.2228800608190118, -5.304579017640374}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.6638426464244451, 0.4559614823179665, 0.9437851245251812], 
               RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.44256176428296345`, 0.303974321545311, 0.6291900830167875],
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[0.6638426464244451, 0.4559614823179665, \
0.9437851245251812]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.6638426464244451, 0.4559614823179665, 0.9437851245251812]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[0.6638426464244451, 0.4559614823179665, 0.9437851245251812],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {-1.2696276830738937, 4.268445966628354}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.03593236132161293, 0.4525840253045328, 0.2213920463792285], 
               RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.023954907547741953`, 0.30172268353635523`, 
               0.14759469758615235`],
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[0.03593236132161293, 0.4525840253045328, \
0.2213920463792285]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.03593236132161293, 0.4525840253045328, 0.2213920463792285]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[
          0.03593236132161293, 0.4525840253045328, 0.2213920463792285],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {-0.42354819123072307, -1.3175849471201693}, {0, 0}],
      InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.3318571288959007, 0.12058504091476818`, 
                0.25688779373348725`], RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.22123808593060046`, 0.08039002727651212, 0.17125852915565817`],
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[0.3318571288959007, 0.12058504091476818, \
0.25688779373348725]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.3318571288959007, 0.12058504091476818`, 
                 0.25688779373348725`]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[
          0.3318571288959007, 0.12058504091476818`, 0.25688779373348725`],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {-1.3412378665351168, 2.386492312510164}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.1497551151108536, 0.24178340137550713`, 0.7474575213200219], 
               RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.09983674340723574, 0.1611889342503381, 0.49830501421334794`],
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[0.1497551151108536, 0.24178340137550713, \
0.7474575213200219]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.1497551151108536, 0.24178340137550713`, 0.7474575213200219]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[
          0.1497551151108536, 0.24178340137550713`, 0.7474575213200219],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {-0.05565276784205375, 5.482788045282921}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.8720803791180718, 0.9589643515121546, 0.051810765171480755`],
                RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.5813869194120479, 0.6393095676747698, 0.03454051011432051],
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[0.8720803791180718, 0.9589643515121546, \
0.051810765171480755]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.8720803791180718, 0.9589643515121546, 
                 0.051810765171480755`]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[
          0.8720803791180718, 0.9589643515121546, 0.051810765171480755`],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {0.13917478451765142, -6.079892548310897}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.2006516379773573, 0.9809953676138627, 0.8674685087845304], 
               RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.13376775865157153`, 0.6539969117425752, 0.5783123391896869],
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[0.2006516379773573, 0.9809953676138627, \
0.8674685087845304]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.2006516379773573, 0.9809953676138627, 0.8674685087845304]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[0.2006516379773573, 0.9809953676138627, 0.8674685087845304],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {3.4277556684595307, -3.9288666273400055}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.5737528772041558, 0.6446235537353122, 0.34469480060605906`], 
               RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.3825019181361039, 0.4297490358235415, 0.22979653373737272`],
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[0.5737528772041558, 0.6446235537353122, \
0.34469480060605906]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.5737528772041558, 0.6446235537353122, 0.34469480060605906`]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[
          0.5737528772041558, 0.6446235537353122, 0.34469480060605906`],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {0.8093695095717537, -2.3786706258427674}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.07965999949602343, 0.7598508686322274, 0.5764735902709484], 
               RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.053106666330682284`, 0.5065672457548183, 0.3843157268472989],
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[0.07965999949602343, 0.7598508686322274, \
0.5764735902709484]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.07965999949602343, 0.7598508686322274, 0.5764735902709484]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[
          0.07965999949602343, 0.7598508686322274, 0.5764735902709484],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {2.2275794415520886, -3.3789500146654943}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.09584557927445281, 0.8766588820532624, 0.8586435065405409], 
               RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.0638970528496352, 0.584439254702175, 0.5724290043603606],
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[0.09584557927445281, 0.8766588820532624, \
0.8586435065405409]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.09584557927445281, 0.8766588820532624, 0.8586435065405409]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[
          0.09584557927445281, 0.8766588820532624, 0.8586435065405409],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {3.4777314149633387, -3.2232238014726575}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.3334481128598832, 0.836647046321024, 0.23152263038262277`], 
               RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.2222987419065888, 0.5577646975473494, 0.15434842025508186`],
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[0.3334481128598832, 0.836647046321024, \
0.23152263038262277]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.3334481128598832, 0.836647046321024, 0.23152263038262277`]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[
          0.3334481128598832, 0.836647046321024, 0.23152263038262277`],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {1.5722517318065201, -5.102123755063223}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.8761596745438154, 0.6698598917102636, 0.8096144050993532], 
               RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.584106449695877, 0.44657326114017576`, 0.5397429367329022],
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[0.8761596745438154, 0.6698598917102636, \
0.8096144050993532]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.8761596745438154, 0.6698598917102636, 0.8096144050993532]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[0.8761596745438154, 0.6698598917102636, 0.8096144050993532],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {2.5614970195990914, 0.2628675660865238}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.11561100723294038`, 0.12973956098373818`, 0.807595031672633],
                RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.07707400482196025, 0.08649304065582546, 0.5383966877817554],
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[0.11561100723294038, 0.12973956098373818, \
0.807595031672633]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.11561100723294038`, 0.12973956098373818`, 
                 0.807595031672633]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[
          0.11561100723294038`, 0.12973956098373818`, 0.807595031672633],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {-0.3748743369321292, 6.311481691175803}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.01529301117962567, 0.3906934049781663, 0.9280586496036682], 
               RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.010195340786417114`, 0.2604622699854442, 0.6187057664024456],
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[0.01529301117962567, 0.3906934049781663, \
0.9280586496036682]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.01529301117962567, 0.3906934049781663, 0.9280586496036682]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[
          0.01529301117962567, 0.3906934049781663, 0.9280586496036682],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {-0.289816754523273, 4.796857334102064}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.6879407399430642, 0.9228130370567966, 0.10675214509039743`], 
               RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.4586271599620428, 0.6152086913711978, 0.07116809672693163],
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[0.6879407399430642, 0.9228130370567966, \
0.10675214509039743]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.6879407399430642, 0.9228130370567966, 0.10675214509039743`]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[
          0.6879407399430642, 0.9228130370567966, 0.10675214509039743`],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {0.6393461461106769, -5.837841900949759}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.7966094446204655, 0.12373328660897531`, 0.2988546632564981], 
               RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.5310729630803104, 0.08248885773931688, 0.19923644217099876`],
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[0.7966094446204655, 0.12373328660897531, \
0.2988546632564981]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.7966094446204655, 0.12373328660897531`, 0.2988546632564981]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[
          0.7966094446204655, 0.12373328660897531`, 0.2988546632564981],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {-3.455229296411802, 1.7761740522567973}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.005378644784074904, 0.02355763146646095, 0.6766818076618879],
                RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.0035857631893832695`, 0.0157050876443073, 0.4511212051079253],
             
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[0.005378644784074904, 0.02355763146646095, \
0.6766818076618879]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.005378644784074904, 0.02355763146646095, 
                 0.6766818076618879]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[
          0.005378644784074904, 0.02355763146646095, 0.6766818076618879],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {0.09397330290628422, 6.525542380122567}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.549801061885371, 0.5147625883683018, 0.6011265736202107], 
               RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.366534041256914, 0.34317505891220124`, 0.4007510490801405],
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[0.549801061885371, 0.5147625883683018, \
0.6011265736202107]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.549801061885371, 0.5147625883683018, 0.6011265736202107]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[0.549801061885371, 0.5147625883683018, 0.6011265736202107],
          
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {0.9939583493610497, 1.0150551385257125}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.44320102991798915`, 0.4707420474424606, 0.6899734387190597], 
               RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.2954673532786595, 0.3138280316283071, 0.45998229247937317`],
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[0.44320102991798915, 0.4707420474424606, \
0.6899734387190597]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.44320102991798915`, 0.4707420474424606, 0.6899734387190597]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[
          0.44320102991798915`, 0.4707420474424606, 0.6899734387190597],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {0.1621041012019485, 2.75541092082572}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.3434934495918893, 0.6013324234308446, 0.5451074786519825], 
               RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.22899563306125956`, 0.4008882822872297, 0.36340498576798835`],
             
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[0.3434934495918893, 0.6013324234308446, \
0.5451074786519825]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.3434934495918893, 0.6013324234308446, 0.5451074786519825]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[0.3434934495918893, 0.6013324234308446, 0.5451074786519825],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {1.7302998844236546, -1.9500482644885067}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.975810374568266, 0.4792309047402621, 0.02545358753962912], 
               RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.6505402497121774, 0.3194872698268414, 0.016969058359752747`],
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[0.975810374568266, 0.4792309047402621, \
0.02545358753962912]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.975810374568266, 0.4792309047402621, 0.02545358753962912]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[0.975810374568266, 0.4792309047402621, 0.02545358753962912],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {-3.3987712133864254, -0.8945205336979939}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.4648794701960577, 0.35156913218698005`, 
                0.30981542399417084`], RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.30991964679737183`, 0.2343794214579867, 0.2065436159961139],
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[0.4648794701960577, 0.35156913218698005, \
0.30981542399417084]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.4648794701960577, 0.35156913218698005`, 
                 0.30981542399417084`]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[
          0.4648794701960577, 0.35156913218698005`, 0.30981542399417084`],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {-1.1303207373202293, 1.0874040066998782}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.5805347585794931, 0.5388119977984229, 0.3286752359803944], 
               RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.3870231723863288, 0.35920799853228197`, 0.2191168239869296],
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[0.5805347585794931, 0.5388119977984229, \
0.3286752359803944]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.5805347585794931, 0.5388119977984229, 0.3286752359803944]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[0.5805347585794931, 0.5388119977984229, 0.3286752359803944],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {0.6503781811819936, -1.137848063136614}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.9195477409989676, 0.1073469528221187, 0.03013053356355977], 
               RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.6130318273326452, 0.0715646352147458, 0.020087022375706514`],
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[0.9195477409989676, 0.1073469528221187, \
0.03013053356355977]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.9195477409989676, 0.1073469528221187, 0.03013053356355977]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[
          0.9195477409989676, 0.1073469528221187, 0.03013053356355977],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {-3.9584067651334855, 0.5711543493174568}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.6169760848653425, 0.6409298545084974, 0.5017410912849942], 
               RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.41131738991022837`, 0.4272865696723316, 0.33449406085666283`],
             
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[0.6169760848653425, 0.6409298545084974, \
0.5017410912849942]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.6169760848653425, 0.6409298545084974, 0.5017410912849942]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[0.6169760848653425, 0.6409298545084974, 0.5017410912849942],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {1.4327948939553115, -1.4070378700707646}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.3822961606037656, 0.7515375990596722, 0.374359510741719], 
               RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.25486410706917706`, 0.5010250660397815, 0.24957300716114603`],
             
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[0.3822961606037656, 0.7515375990596722, \
0.374359510741719]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.3822961606037656, 0.7515375990596722, 0.374359510741719]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[0.3822961606037656, 0.7515375990596722, 0.374359510741719],
          
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {1.3855683368548055, -3.957165670505758}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.06537587888801255, 0.46741835358355144`, 0.9794603748572839],
                RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.04358391925867504, 0.3116122357223676, 0.6529735832381893],
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[0.06537587888801255, 0.46741835358355144, \
0.9794603748572839]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.06537587888801255, 0.46741835358355144`, 
                 0.9794603748572839]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[
          0.06537587888801255, 0.46741835358355144`, 0.9794603748572839],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {-0.16162992557896655, 4.375776936189934}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.07328135268040747, 0.11240443115715437`, 0.4618298675547332],
                RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.04885423512027165, 0.07493628743810292, 0.30788657836982214`],
             
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[0.07328135268040747, 0.11240443115715437, \
0.4618298675547332]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.07328135268040747, 0.11240443115715437`, 
                 0.4618298675547332]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[
          0.07328135268040747, 0.11240443115715437`, 0.4618298675547332],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {0.8336301707641154, 5.653405657370153}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.6644983557072988, 0.794793202709762, 0.28961295379169205`], 
               RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.44299890380486584`, 0.5298621351398414, 0.1930753025277947],
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[0.6644983557072988, 0.794793202709762, \
0.28961295379169205]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.6644983557072988, 0.794793202709762, 0.28961295379169205`]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[
          0.6644983557072988, 0.794793202709762, 0.28961295379169205`],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {0.43371356615502504, -4.685696318434649}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.7504233829117823, 0.8720488326381608, 0.2402117599039646], 
               RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.5002822552745216, 0.5813658884254406, 0.16014117326930974`],
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[0.7504233829117823, 0.8720488326381608, \
0.2402117599039646]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.7504233829117823, 0.8720488326381608, 0.2402117599039646]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[0.7504233829117823, 0.8720488326381608, 0.2402117599039646],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {0.29784610787565846, -5.347557081990861}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.943001410884913, 0.1885911857771001, 0.0012857522694333934`],
                RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.6286676072566086, 0.1257274571847334, 0.0008571681796222623],
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[0.943001410884913, 0.1885911857771001, \
0.0012857522694333934]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.943001410884913, 0.1885911857771001, 
                 0.0012857522694333934`]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[
          0.943001410884913, 0.1885911857771001, 0.0012857522694333934`],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {-3.9228343123928795, 0.3833569677536064}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.9868218912260509, 0.26921326973029336`, 0.7037539521912619], 
               RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.6578812608173673, 0.17947551315352891`, 0.4691693014608413],
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[0.9868218912260509, 0.26921326973029336, \
0.7037539521912619]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.9868218912260509, 0.26921326973029336`, 0.7037539521912619]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[
          0.9868218912260509, 0.26921326973029336`, 0.7037539521912619],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {-2.94896950404755, 3.665981432571208}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.9338712820762696, 0.03808128083003015, 0.9154924792942054], 
               RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.6225808547175131, 0.025387520553353436`, 0.6103283195294703],
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[0.9338712820762696, 0.03808128083003015, \
0.9154924792942054]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.9338712820762696, 0.03808128083003015, 0.9154924792942054]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[
          0.9338712820762696, 0.03808128083003015, 0.9154924792942054],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {-2.5721171202874533, 4.761320635919877}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.5194257720206772, 0.35637955674162525`, 0.322421086791451], 
               RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.3462838480137848, 0.2375863711610835, 0.21494739119430067`],
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[0.5194257720206772, 0.35637955674162525, \
0.322421086791451]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.5194257720206772, 0.35637955674162525`, 0.322421086791451]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[
          0.5194257720206772, 0.35637955674162525`, 0.322421086791451],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {-1.2886730973735598, 1.1194506774624864}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.5400230732794247, 0.15913934172502886`, 0.8661577477958458], 
               RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.36001538218628315`, 0.10609289448335257`, 0.5774384985305638],
             
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[0.5400230732794247, 0.15913934172502886, \
0.8661577477958458]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.5400230732794247, 0.15913934172502886`, 0.8661577477958458]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[
          0.5400230732794247, 0.15913934172502886`, 0.8661577477958458],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {-1.4371570803878586, 5.7623785291933824}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.13892481026462322`, 0.7792102505362641, 0.719013993529958], 
               RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.09261654017641549, 0.5194735003575095, 0.47934266235330536`],
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[0.13892481026462322, 0.7792102505362641, \
0.719013993529958]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.13892481026462322`, 0.7792102505362641, 0.719013993529958]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[
          0.13892481026462322`, 0.7792102505362641, 0.719013993529958],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {2.8312038989689365, -2.9446207749732505}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.7178510101552242, 0.5375234362344228, 0.04916242757816769], 
               RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.47856734010348284`, 0.3583489574896152, 0.032774951718778464`],
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[0.7178510101552242, 0.5375234362344228, \
0.04916242757816769]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.7178510101552242, 0.5375234362344228, 0.04916242757816769]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[
          0.7178510101552242, 0.5375234362344228, 0.04916242757816769],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {-2.1860099551889873, -1.7539815038330138}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.32743716825100866`, 0.7182019932774555, 0.6341232189228396], 
               RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.21829144550067245`, 0.478801328851637, 0.42274881261522645`],
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[0.32743716825100866, 0.7182019932774555, \
0.6341232189228396]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.32743716825100866`, 0.7182019932774555, 0.6341232189228396]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[
          0.32743716825100866`, 0.7182019932774555, 0.6341232189228396],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {2.33290235725303, -2.5778435727962306}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.7199063860700075, 0.7464267169813132, 0.1444430408697921], 
               RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.4799375907133383, 0.4976178113208755, 0.0962953605798614],
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[0.7199063860700075, 0.7464267169813132, \
0.1444430408697921]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.7199063860700075, 0.7464267169813132, 0.1444430408697921]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[0.7199063860700075, 0.7464267169813132, 0.1444430408697921],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {-0.1542499481995792, -4.5829373785343535}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.45341758967828194`, 0.9647132550051378, 
                0.47480587630909876`], RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.3022783931188546, 0.6431421700034252, 0.31653725087273255`],
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[0.45341758967828194, 0.9647132550051378, \
0.47480587630909876]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.45341758967828194`, 0.9647132550051378, 
                 0.47480587630909876`]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[
          0.45341758967828194`, 0.9647132550051378, 0.47480587630909876`],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {1.708372895134426, -5.641707949276422}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.16277766193742194`, 0.6128097414727505, 
                0.27412354597292055`], RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.10851844129161463`, 0.40853982764850033`, 0.1827490306486137],
             
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[0.16277766193742194, 0.6128097414727505, \
0.27412354597292055]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.16277766193742194`, 0.6128097414727505, 
                 0.27412354597292055`]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[
          0.16277766193742194`, 0.6128097414727505, 0.27412354597292055`],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {0.32476863943478906, -2.6316815422806172}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.06369358101813316, 0.3270926845798263, 0.43658951864023265`],
                RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.04246238734542211, 0.2180617897198842, 0.29105967909348845`],
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[0.06369358101813316, 0.3270926845798263, \
0.43658951864023265]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.06369358101813316, 0.3270926845798263, 
                 0.43658951864023265`]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[
          0.06369358101813316, 0.3270926845798263, 0.43658951864023265`],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {-0.11739461741018885, 1.392357768750982}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.3753041446450196, 0.654081225132394, 0.6934490078435196], 
               RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.25020276309667977`, 0.43605415008826265`, 0.4622993385623464],
             
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[0.3753041446450196, 0.654081225132394, \
0.6934490078435196]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.3753041446450196, 0.654081225132394, 0.6934490078435196]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[0.3753041446450196, 0.654081225132394, 0.6934490078435196],
          
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {2.378857322465236, -1.8585563513553043}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.10449941852557099`, 0.5213694528960531, 
                0.032632686071042194`], RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.06966627901704733, 0.3475796352640354, 0.021755124047361463`],
             
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[0.10449941852557099, 0.5213694528960531, \
0.032632686071042194]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.10449941852557099`, 0.5213694528960531, 
                 0.032632686071042194`]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[
          0.10449941852557099`, 0.5213694528960531, 0.032632686071042194`],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {-0.3514751794983061, -2.102455515871919}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.06766393837393836, 0.9149898394643581, 0.9857802328328009], 
               RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.04510929224929224, 0.6099932263095721, 0.657186821888534],
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[0.06766393837393836, 0.9149898394643581, \
0.9857802328328009]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.06766393837393836, 0.9149898394643581, 0.9857802328328009]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[
          0.06766393837393836, 0.9149898394643581, 0.9857802328328009],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {3.8608897228656667, -3.0050368682376645}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.8238300887302514, 0.6771057467868256, 0.8669327798530875], 
               RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.549220059153501, 0.4514038311912171, 0.577955186568725],
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[0.8238300887302514, 0.6771057467868256, \
0.8669327798530875]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.8238300887302514, 0.6771057467868256, 0.8669327798530875]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[0.8238300887302514, 0.6771057467868256, 0.8669327798530875],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {2.6300104961065194, 0.3378646313408488}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.4016147213269494, 0.38188176221815584`, 0.7760970649691423], 
               RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.26774314755129963`, 0.25458784147877056`, 0.5173980433127616],
             
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[0.4016147213269494, 0.38188176221815584, \
0.7760970649691423]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.4016147213269494, 0.38188176221815584`, 0.7760970649691423]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[
          0.4016147213269494, 0.38188176221815584`, 0.7760970649691423],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {-0.5247687600270162, 4.181429060940748}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.4813224876996798, 0.3273327298264279, 0.8200375838894198], 
               RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.3208816584664532, 0.2182218198842853, 0.5466917225929466],
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[0.4813224876996798, 0.3273327298264279, \
0.8200375838894198]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.4813224876996798, 0.3273327298264279, 0.8200375838894198]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[0.4813224876996798, 0.3273327298264279, 0.8200375838894198],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {-0.9618149744971515, 4.85695001978651}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.1190029876070009, 0.22757459912081002`, 
                0.23891724516663282`], RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.07933532507133394, 0.15171639941387335`, 0.1592781634444219],
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[0.1190029876070009, 0.22757459912081002, \
0.23891724516663282]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.1190029876070009, 0.22757459912081002`, 
                 0.23891724516663282`]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[
          0.1190029876070009, 0.22757459912081002`, 0.23891724516663282`],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {-0.400862951612455, 1.187532305248498}, {0, 0}]}}},
  AspectRatio->1,
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  ImageSize->{220.4921875, Automatic},
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->All,
  PlotRangeClipping->False,
  PlotRangePadding->{{
     Scaled[0.05], 
     Scaled[0.05]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[22]=",ExpressionUUID->"e3823c68-a14d-4ebd-b59f-d7816b3c9394"]
}, Open  ]],

Cell["Let\[CloseCurlyQuote]s try the same kind of thing with images of \
letters.", "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"255ecc97-b8e2-4c69-b455-4e60c4501f3b"],

Cell["Make a rasterized image of each letter in the alphabet:", "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"17a07685-9824-4943-a595-7f75b628e2f8"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"Rasterize", "[", 
    RowBox[{"FromLetterNumber", "[", "n", "]"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"n", ",", "26"}], "}"}]}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[23]:=",ExpressionUUID->"bf08869a-bb0c-4d34-8533-73536ed20aeb"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmIOIAax/1MVfH/36tW7T6hi75YWODJAQEznxAI9Bv/5
IBVPt4MEJm5/8PT60iZ/kKzjjHf///9+sBHITNv+CmLefH+QONjEp51gYwom
rr5052yTHlwcZMWh1RNjHPWgtoDNgTjmN1TB00oGBr3OE2D2p4kghTEzVm+c
UQmyN2bpdagp1w91FvjDXLrxHXWDhsYAALgCdNE=
     "], {{0, 0}, {8, 19}}, {0, 255},
     
     ColorFunction->RGBColor],
    ImageSize->{8, 19},
    PlotRange->{{0, 8}, {0, 19}}], ",", 
   GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmIOIAax/1Md/P7+7tW777/h/E8z/Bkc09L0GCBAr3P7
HYj4fH8wd/Wh65f2FoClVz/4DlLvyOA48RJU96u9QBn/GZdg4mcRxjoyMMQs
xRQHGes/H6qgYON3mDlAHlgZxF6gmsqlq+dDnDX/+ieY+hnzm2LAzvSfCHMn
insQAM1ehPhEPaCvMMX/f//0CSlYqAwAru1ogw==
     "], {{0, 0}, {8, 19}}, {0, 255},
     
     ColorFunction->RGBColor],
    ImageSize->{8, 19},
    PlotRange->{{0, 8}, {0, 19}}], ",", 
   GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmJ2IAax/1MJfHr37tW7T79h3N+vThQ4MsCA/+pLr/7/
f9AEYutN3H72zp0Tnf4MlRsffLo0AyiUtvQOilEgQb29r/5jCDKsfvAbWfD7
9flAQcemQzBbIbLfV6eBba2csXR+px4DQ9MhiFnvtk+EOsq/YMb1dyhGDRIA
AEmSUzY=
     "], {{0, 0}, {7, 19}}, {0, 255},
     ColorFunction->RGBColor],
    ImageSize->{7, 19},
    PlotRange->{{0, 7}, {0, 19}}], ",", 
   GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmIOIAax/1MZfH/36tWn77+Rhd5dWu3PAAWVnU16DAzz
L336//16GkjAf+mJ69dPLIUomHj23adLM4CMzkPvIHo/nZ2IJK63/SnUZIgy
uPqld76jiX+/vhTIcOzcCzMHKg504VKIxZUzls5oYoDZC1L0++nSphig8xj0
/NPADppx9h2a935fn49QjwTg9uIQ/4QRUL8/ffr0G0OUbAAA6cVhWQ==
     "], {{0, 0}, {8,
      19}}, {0, 255},
     ColorFunction->RGBColor],
    ImageSize->{8, 19},
    PlotRange->{{0, 8}, {0, 19}}], ",", 
   GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmJ2IAax/1MJfP/07tWrd99/w/jvzjb5M8BB5dKz//8/
bdIDMvVmbD/74MH1jRMLmlZf/3RpBlBo4tlPyEZBBGOaJs4AgolgcsZqiKBj
QVNnExB0FsSAjPp+fT7I8O1PIRrvzAda2Ql0y+o0kKUFM1ZvnN8E0jXxLFj+
1erOND2we9I6N76jls+pCgBA10GE
     "], {{0, 0}, {7, 19}}, {0, 255},
     ColorFunction->RGBColor],
    ImageSize->{7, 19},
    PlotRange->{{0, 7}, {0, 19}}], ",", 
   GraphicsBox[
    RasterBox[{{{255, 255, 255}, {255, 255, 255}, {255, 255, 255}, {255, 255, 
     255}, {255, 255, 255}}, {{255, 255, 255}, {255, 255, 255}, {255, 255, 
     255}, {255, 255, 255}, {255, 255, 255}}, {{255, 255, 255}, {255, 255, 
     255}, {255, 255, 255}, {255, 255, 255}, {255, 255, 255}}, {{255, 255, 
     255}, {255, 255, 255}, {255, 255, 255}, {255, 255, 255}, {255, 255, 
     255}}, {{255, 255, 255}, {210, 152, 79}, {0, 65, 152}, {242, 255, 255}, {
     255, 255, 255}}, {{255, 255, 255}, {210, 152, 65}, {0, 46, 152}, {242, 
     255, 255}, {255, 255, 255}}, {{255, 255, 255}, {210, 152, 65}, {0, 46, 
     152}, {242, 255, 255}, {255, 255, 255}}, {{255, 255, 255}, {210, 152, 
     65}, {0, 46, 152}, {242, 255, 255}, {255, 255, 255}}, {{255, 255, 255}, {
     210, 152, 65}, {0, 46, 152}, {242, 255, 255}, {255, 255, 255}}, {{255, 
     255, 255}, {215, 159, 79}, {0, 46, 152}, {247, 255, 255}, {255, 255, 
     255}}, {{224, 189, 159}, {92, 65, 0}, {0, 0, 65}, {112, 130, 137}, {189, 
     224, 247}}, {{220, 177, 130}, {46, 0, 0}, {0, 0, 0}, {65, 65, 79}, {165, 
     215, 242}}, {{255, 255, 255}, {215, 159, 79}, {0, 65, 159}, {251, 255, 
     255}, {255, 255, 255}}, {{255, 255, 255}, {205, 145, 65}, {0, 0, 102}, {
     194, 220, 229}, {229, 229, 238}}, {{255, 255, 255}, {242, 210, 165}, {0, 
     0, 0}, {0, 0, 0}, {0, 0, 137}}, {{255, 255, 255}, {255, 255, 255}, {251, 
     242, 229}, {220, 215, 220}, {229, 238, 242}}, {{255, 255, 255}, {255, 
     255, 255}, {255, 255, 255}, {255, 255, 255}, {255, 255, 255}}, {{255, 
     255, 255}, {255, 255, 255}, {255, 255, 255}, {255, 255, 255}, {255, 255, 
     255}}, {{255, 255, 255}, {255, 255, 255}, {255, 255, 255}, {255, 255, 
     255}, {255, 255, 255}}}, {{0, 0}, {5, 19}}, {0, 255},
     ColorFunction->RGBColor],
    ImageSize->{5, 19},
    PlotRange->{{0, 5}, {0, 19}}], ",", 
   GraphicsBox[RasterBox[CompressedData["
1:eJzNkKGOxCAQhic5c36fYF+g78ATkKxGrcBe7VlcJa4vUFVVVXVmFQaDqUFg
MBUVYxAV7ADZ3GWf4L5kkh+Yn3/gev+63T8A4EL1SVV0Lpx79JuzbvM7nrmR
NsXgL1L/pJwPMwB083a0JjcrOlKPHd1I+4vHMyGmhGElN9OWHAO80S3hzGg5
gNCrD8FXXtFRM2C9HrUepzVgfpGWviMzl7LOxU0bAQ0t+9kXfTxIy6bRkh5s
83tBPWusOnzX1yzGTEoUKQYTU/mFaJSod3cUIjnjk/uN/+c8ATefUqA=
     "], {{0, 0}, {8,
      19}}, {0, 255},
     ColorFunction->RGBColor],
    ImageSize->{8, 19},
    PlotRange->{{0, 8}, {0, 19}}], ",", 
   GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmIOIAax/9McfJrhyOA48SyUc2k+A4P/2U+Y4jMYGBzJ
F59xCas4Q9r8d2Dxdyc6geInwOLzYxhAQK9g/tKJ/iCW/9nvUPV6Tas3TkwD
SztO3PsAyf2X8PsLWXyiHoNeJ6b4/++fPn3/TUYAEgUAWvd3fQ==
     "], {{0, 0}, {8, 
     19}}, {0, 255},
     ColorFunction->RGBColor],
    ImageSize->{8, 19},
    PlotRange->{{0, 8}, {0, 19}}], ",", 
   GraphicsBox[
    RasterBox[{{{255, 255, 255}, {255, 255, 255}, {255, 255, 255}, {255, 255, 
     255}}, {{255, 255, 255}, {255, 255, 255}, {255, 255, 255}, {255, 255, 
     255}}, {{255, 255, 255}, {255, 255, 255}, {255, 255, 255}, {255, 255, 
     255}}, {{255, 255, 255}, {255, 255, 255}, {255, 255, 255}, {255, 255, 
     255}}, {{255, 255, 242}, {152, 65, 0}, {65, 145, 205}, {255, 255, 
     255}}, {{255, 255, 242}, {152, 65, 0}, {65, 145, 205}, {255, 255, 
     255}}, {{255, 255, 242}, {152, 65, 0}, {65, 145, 205}, {255, 255, 
     255}}, {{255, 255, 242}, {152, 65, 0}, {65, 145, 205}, {255, 255, 
     255}}, {{255, 255, 242}, {152, 65, 0}, {65, 145, 205}, {255, 255, 
     255}}, {{255, 255, 242}, {152, 65, 0}, {65, 145, 205}, {255, 255, 
     255}}, {{255, 255, 242}, {152, 46, 0}, {46, 145, 205}, {255, 255, 
     255}}, {{255, 255, 242}, {177, 121, 79}, {121, 171, 215}, {255, 255, 
     255}}, {{255, 255, 255}, {251, 247, 247}, {251, 251, 255}, {255, 255, 
     255}}, {{255, 247, 205}, {65, 0, 0}, {0, 46, 145}, {242, 255, 255}}, {{
     255, 251, 224}, {145, 102, 79}, {102, 145, 189}, {251, 255, 255}}, {{255,
      255, 255}, {255, 255, 255}, {255, 255, 255}, {255, 255, 255}}, {{255, 
     255, 255}, {255, 255, 255}, {255, 255, 255}, {255, 255, 255}}, {{255, 
     255, 255}, {255, 255, 255}, {255, 255, 255}, {255, 255, 255}}, {{255, 
     255, 255}, {255, 255, 255}, {255, 255, 255}, {255, 255, 255}}}, {{0, 
     0}, {4, 19}}, {0, 255},
     ColorFunction->RGBColor],
    ImageSize->{4, 19},
    PlotRange->{{0, 4}, {0, 19}}], ",", 
   GraphicsBox[
    RasterBox[{{{247, 242, 234}, {224, 224, 224}, {234, 242, 255}, {255, 255, 
     255}}, {{177, 92, 0}, {0, 0, 0}, {0, 0, 46}, {177, 224, 247}}, {{247, 
     238, 234}, {224, 210, 177}, {65, 0, 0}, {79, 145, 205}}, {{255, 255, 
     255}, {255, 255, 242}, {159, 65, 0}, {65, 145, 205}}, {{255, 255, 255}, {
     255, 255, 242}, {152, 65, 0}, {65, 145, 205}}, {{255, 255, 255}, {255, 
     255, 242}, {152, 65, 0}, {65, 145, 205}}, {{255, 255, 255}, {255, 255, 
     242}, {152, 65, 0}, {65, 145, 205}}, {{255, 255, 255}, {255, 255, 242}, {
     152, 65, 0}, {65, 145, 205}}, {{255, 255, 255}, {255, 255, 242}, {152, 
     65, 0}, {65, 145, 205}}, {{255, 255, 255}, {255, 255, 242}, {152, 65, 
     0}, {65, 145, 205}}, {{255, 255, 255}, {255, 255, 242}, {152, 46, 0}, {
     46, 145, 205}}, {{255, 255, 255}, {255, 255, 242}, {177, 121, 79}, {121, 
     171, 215}}, {{255, 255, 255}, {255, 255, 255}, {251, 247, 247}, {251, 
     251, 255}}, {{255, 255, 255}, {255, 247, 205}, {65, 0, 0}, {0, 46, 
     145}}, {{255, 255, 255}, {255, 251, 224}, {152, 102, 79}, {102, 145, 
     189}}, {{255, 255, 255}, {255, 255, 255}, {255, 255, 255}, {255, 255, 
     255}}, {{255, 255, 255}, {255, 255, 255}, {255, 255, 255}, {255, 255, 
     255}}, {{255, 255, 255}, {255, 255, 255}, {255, 255, 255}, {255, 255, 
     255}}, {{255, 255, 255}, {255, 255, 255}, {255, 255, 255}, {255, 255, 
     255}}}, {{0, 0}, {4, 19}}, {0, 255},
     ColorFunction->RGBColor],
    ImageSize->{4, 19},
    PlotRange->{{0, 4}, {0, 19}}], ",", 
   GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmJ2IAax/9MEfJrhyOA44yyEc2d1AdgisODES2D5E/5A
obSlIEEw69Kn73sr9RgYHA+9AknPBwlCQcHq6xAzQYKOMWCZmDvIFs2//u7s
DJDo/LMIwYkg9tkZMUDxpr1PkQWB7I1NMY7+naiCqI7HEJyox6DXiSb4//un
T99/UynMwAAAWXY8rQ==
     "], {{0, 0}, {7, 19}}, {0, 255},
     ColorFunction->RGBColor],
    ImageSize->{7, 19},
    PlotRange->{{0, 7}, {0, 19}}], ",", 
   GraphicsBox[
    RasterBox[{{{255, 255, 255}, {255, 255, 255}, {255, 255, 255}, {255, 255, 
     255}}, {{255, 255, 255}, {255, 255, 255}, {255, 255, 255}, {255, 255, 
     255}}, {{255, 255, 255}, {255, 255, 255}, {255, 255, 255}, {255, 255, 
     255}}, {{255, 255, 255}, {255, 255, 251}, {238, 234, 238}, {247, 251, 
     255}}, {{255, 255, 247}, {171, 102, 0}, {0, 0, 0}, {130, 200, 238}}, {{
     255, 255, 242}, {152, 65, 0}, {0, 112, 165}, {234, 251, 255}}, {{255, 
     255, 242}, {152, 65, 0}, {65, 145, 210}, {255, 255, 255}}, {{255, 255, 
     242}, {152, 65, 0}, {65, 145, 205}, {255, 255, 255}}, {{255, 255, 242}, {
     152, 65, 0}, {65, 145, 205}, {255, 255, 255}}, {{255, 255, 242}, {152, 
     65, 0}, {65, 145, 205}, {255, 255, 255}}, {{255, 255, 242}, {152, 65, 
     0}, {65, 145, 205}, {255, 255, 255}}, {{255, 255, 242}, {152, 65, 0}, {
     65, 145, 205}, {255, 255, 255}}, {{255, 255, 242}, {152, 65, 0}, {65, 
     145, 205}, {255, 255, 255}}, {{255, 255, 242}, {152, 65, 0}, {65, 145, 
     205}, {255, 255, 255}}, {{255, 255, 242}, {145, 46, 0}, {46, 137, 205}, {
     255, 255, 255}}, {{255, 255, 255}, {247, 242, 242}, {247, 251, 255}, {
     255, 255, 255}}, {{255, 255, 255}, {255, 255, 255}, {255, 255, 255}, {
     255, 255, 255}}, {{255, 255, 255}, {255, 255, 255}, {255, 255, 255}, {
     255, 255, 255}}, {{255, 255, 255}, {255, 255, 255}, {255, 255, 255}, {
     255, 255, 255}}}, {{0, 0}, {4, 19}}, {0, 255},
     ColorFunction->RGBColor],
    ImageSize->{4, 19},
    PlotRange->{{0, 4}, {0, 19}}], ",", 
   GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmIeIAax/w868GmGI4PjxLMQzvWlaQwMMWe/gznfL/kz
MEw8+w5NzaUZQGH/E58gas464lZzlmw1My6hqIG65yyyexjSlr5DqNFbfR2s
6NVePbgaoDAQOBbMn9HkyAAFlTNmVILFl4LUf1pdEDP/0NnVTWAhvZjtd949
2DsDorhg/onftAv1oQAAv+g8EQ==
     "], {{0, 0}, {12, 19}}, {0, 255},
     ColorFunction->RGBColor],
    ImageSize->{12, 19},
    PlotRange->{{0, 12}, {0, 19}}], ",", 
   GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmIOIAax/9McfJrhyOA48SyUc2k+A4P/2U+Y4jMYGBzJ
F59xCas4Q8z8d2Dxdyc6geInIOL+DCCgVzB/6UQw0//sd5D46oKY+ScubeyM
AUs7Ttz7gPaBQzUAADjwg9Q=
     "], {{0, 0}, {8, 19}}, {0, 255},
     ColorFunction->RGBColor],
    ImageSize->{8, 19},
    PlotRange->{{0, 8}, {0, 19}}], ",", 
   GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmIOIAax/1MbfHr37tW7T7+Rhd6drXRkgAK9mO13PoFF
nzbpgfgz9l66c3a1P0gu5tL3/58uzQCyClbfgZoG4W68A2bo7X0HM/P7pRgG
BseJZyEKNj6AWfj9rD9Y/Pv1+UBx/4knIMIPNlYCuU2HXgFVrE4DW9a5dPWM
SrCTmp5CNb9a3ZmmB3ZmTMEMqDOHCAAAMu92wA==
     "], {{0, 0}, {8, 19}}, {0, 255},
     
     ColorFunction->RGBColor],
    ImageSize->{8, 19},
    PlotRange->{{0, 8}, {0, 19}}], ",", 
   GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmIOIAax//////v799+//2OATzP0GPQmnsUi7sjgiEt8
xnWgee9evfuOMPDTfH+gPQx6DBCg17n9DpK4XufqQ9cv7S0AS69+8B1m/iWo
7ld7gTL+My5h2AviMsQsxRQHGes/H6qgYON3mDlAHljZpxlg9zA4Vi5dPT8N
bO/865+A4qsLYiZu3Du/EuJc/4nbr2MGyqAFAB6AaRc=
     "], {{0, 0}, {8, 19}}, {0, 
     255},
     ColorFunction->RGBColor],
    ImageSize->{8, 19},
    PlotRange->{{0, 8}, {0, 19}}], ",", 
   GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmIOIAax/2OA799/Ywp+ujQDqHjGpU9YxSeefQfX/e7V
q0+//3+/sxQu/u7San8GKHAEkzOA4t+vp4GY/ktPXL9+YilEHKgeYmDnIaiB
38/OQBLX2/70N5q9EMbSO9/RxL9fBznAsXMvVPzsRJh7vi+FWFw5Y+mMJj2Y
vSBFv58ubYoBizg2zZiY5h+zEWbs4AcALexiLw==
     "], {{0, 0}, {8, 19}}, {0, 255},
     
     ColorFunction->RGBColor],
    ImageSize->{8, 19},
    PlotRange->{{0, 8}, {0, 19}}], ",", 
   GraphicsBox[
    RasterBox[{{{255, 255, 255}, {255, 255, 255}, {255, 255, 255}, {255, 255, 
     255}, {255, 255, 255}}, {{255, 255, 255}, {255, 255, 255}, {255, 255, 
     255}, {255, 255, 255}, {255, 255, 255}}, {{255, 255, 255}, {255, 255, 
     255}, {255, 255, 255}, {255, 255, 255}, {255, 255, 255}}, {{255, 255, 
     255}, {255, 255, 255}, {255, 255, 255}, {255, 255, 255}, {255, 255, 
     255}}, {{255, 255, 242}, {152, 65, 0}, {65, 145, 205}, {255, 255, 255}, {
     255, 255, 255}}, {{255, 255, 242}, {152, 65, 0}, {65, 145, 205}, {255, 
     255, 255}, {255, 255, 255}}, {{255, 255, 242}, {152, 65, 0}, {65, 145, 
     205}, {255, 255, 255}, {255, 255, 255}}, {{255, 255, 242}, {152, 65, 
     0}, {65, 145, 205}, {255, 255, 255}, {255, 255, 255}}, {{255, 255, 
     242}, {152, 65, 0}, {46, 145, 205}, {255, 255, 255}, {255, 255, 255}}, {{
     255, 255, 242}, {152, 79, 0}, {0, 0, 112}, {210, 247, 255}, {255, 255, 
     255}}, {{255, 255, 242}, {159, 79, 0}, {0, 0, 0}, {0, 46, 92}, {130, 137,
      145}}, {{255, 255, 242}, {171, 112, 102}, {159, 200, 205}, {165, 112, 
     65}, {0, 0, 0}}, {{255, 255, 255}, {255, 255, 255}, {255, 255, 255}, {
     255, 255, 255}, {255, 255, 255}}, {{255, 255, 255}, {255, 255, 255}, {
     255, 255, 255}, {255, 255, 255}, {255, 255, 255}}, {{255, 255, 255}, {
     255, 255, 255}, {255, 255, 255}, {255, 255, 255}, {255, 255, 255}}, {{
     255, 255, 255}, {255, 255, 255}, {255, 255, 255}, {255, 255, 255}, {255, 
     255, 255}}, {{255, 255, 255}, {255, 255, 255}, {255, 255, 255}, {255, 
     255, 255}, {255, 255, 255}}, {{255, 255, 255}, {255, 255, 255}, {255, 
     255, 255}, {255, 255, 255}, {255, 255, 255}}, {{255, 255, 255}, {255, 
     255, 255}, {255, 255, 255}, {255, 255, 255}, {255, 255, 255}}}, {{0, 
     0}, {5, 19}}, {0, 255},
     ColorFunction->RGBColor],
    ImageSize->{5, 19},
    PlotRange->{{0, 5}, {0, 19}}], ",", 
   GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmI2IAax/1MAPr179+rdu99g9tOzq9P0GGDAf+P1T2dn
+DPoFey99ODVg7Od/gwMejOQta4uAIpMBDF/v9q7tNMRrC1mxon/ny4VgNmO
aU3bzz4FKT07EcidcfYTXPPvO6tBdlTO3759KdDSmPnXgYLXt0/0BztAL6Zy
751P/wcUAADbsxXI
     "], {{0, 0}, {6, 19}}, {0, 255},
     ColorFunction->RGBColor],
    ImageSize->{6, 19},
    PlotRange->{{0, 6}, {0, 19}}], ",", 
   GraphicsBox[
    RasterBox[{{{255, 255, 255}, {255, 255, 255}, {255, 255, 255}, {255, 255, 
     255}, {255, 255, 255}}, {{255, 255, 255}, {255, 255, 255}, {255, 255, 
     255}, {255, 255, 255}, {255, 255, 255}}, {{255, 255, 255}, {255, 255, 
     255}, {255, 255, 255}, {255, 255, 255}, {255, 255, 255}}, {{255, 255, 
     255}, {255, 255, 255}, {255, 251, 247}, {234, 234, 238}, {247, 251, 
     255}}, {{255, 255, 255}, {251, 229, 189}, {79, 0, 0}, {0, 0, 0}, {0, 0, 
     92}}, {{255, 255, 255}, {210, 145, 79}, {0, 0, 65}, {165, 200, 210}, {
     210, 205, 220}}, {{255, 255, 255}, {210, 152, 65}, {0, 46, 152}, {247, 
     255, 255}, {255, 255, 255}}, {{255, 255, 255}, {210, 152, 65}, {0, 46, 
     152}, {242, 255, 255}, {255, 255, 255}}, {{255, 255, 255}, {210, 152, 
     65}, {0, 46, 152}, {242, 255, 255}, {255, 255, 255}}, {{255, 255, 255}, {
     215, 159, 79}, {0, 46, 152}, {247, 255, 255}, {255, 255, 255}}, {{200, 
     165, 137}, {102, 79, 0}, {0, 0, 65}, {121, 137, 130}, {137, 159, 
     194}}, {{177, 130, 92}, {46, 46, 0}, {0, 0, 0}, {79, 79, 79}, {79, 121, 
     177}}, {{255, 255, 255}, {215, 152, 65}, {0, 46, 152}, {247, 255, 255}, {
     255, 255, 255}}, {{255, 255, 255}, {220, 177, 130}, {92, 130, 177}, {247,
      255, 255}, {255, 255, 255}}, {{255, 255, 255}, {255, 255, 255}, {255, 
     255, 255}, {255, 255, 255}, {255, 255, 255}}, {{255, 255, 255}, {255, 
     255, 255}, {255, 255, 255}, {255, 255, 255}, {255, 255, 255}}, {{255, 
     255, 255}, {255, 255, 255}, {255, 255, 255}, {255, 255, 255}, {255, 255, 
     255}}, {{255, 255, 255}, {255, 255, 255}, {255, 255, 255}, {255, 255, 
     255}, {255, 255, 255}}, {{255, 255, 255}, {255, 255, 255}, {255, 255, 
     255}, {255, 255, 255}, {255, 255, 255}}}, {{0, 0}, {5, 19}}, {0, 255},
     ColorFunction->RGBColor],
    ImageSize->{5, 19},
    PlotRange->{{0, 5}, {0, 19}}], ",", 
   GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmIOIAax/1MV/P7+7tWrd99RBZ8emsgABTEzJhYAybOf
gMKvJuoBRdI2nr20d34BWNYfJP7prD+QNeMSRO/11QVQ8e8gcceJZyHi36/P
APIwxT9dIiT+CU0c6DbHE0Dx33c6/R2bNt6Bmb/a37HyOppPBjEAAGsvgAA=

     "], {{0, 0}, {8, 19}}, {0, 255},
     ColorFunction->RGBColor],
    ImageSize->{8, 19},
    PlotRange->{{0, 8}, {0, 19}}], ",", 
   GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmJ2IAax/9MM3FldADQ/Zv4lJLF3M/wZQECv8ylM6PeD
jUCBzvkT9RgYll7/DhG8BFKX9uD70yaQ2hNgMRCboXI7kHV2oiMDQ8GD//+/
X58PFJt44t1/EHspkD3j0qe9TUCTYmAmPagE61pd4J828dBvmKWX5hc4Fiyl
nd/JBgCNoFMq
     "], {{0, 0}, {7, 19}}, {0, 255},
     ColorFunction->RGBColor],
    ImageSize->{7, 19},
    PlotRange->{{0, 7}, {0, 19}}], ",", 
   GraphicsBox[RasterBox[CompressedData["
1:eJzNUKEOwyAQvWRycl+wH+g/8AVNplEVtaudravEzaFQU6gqTFUNBlODwNRM
IGoQFeyALPuDbSSX3Lv37t0L5+Z6aQ4AcMI6YqU+/st7MoJx6nlLIBiOoOrk
/uFV4gGY9ogMpxl19q1Y1Q03KAEyzGhwJwjaCkAsIfP72KE9N0nG/KbRjWvd
p9mSeYs8YSZ6hTMhBwBqY1R5C0MFK/J1bNe+ysepwONOJoUOJRIp+aesaIVN
xk6W2BNr6+6R+eg1rwkdXcnmGCXD6L7yz79/LxCaB3E=
     "], {{0, 0}, {11, 19}}, {0, 
     255},
     ColorFunction->RGBColor],
    ImageSize->{11, 19},
    PlotRange->{{0, 11}, {0, 19}}], ",", 
   GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmJ2IAax/9MALI1hYNBregpmf7q0FGhL2tLr36+DGDFL
7/z//6pJD8isfABWcKjTESg8sROoh2H+pU9QI35fL2AAAf/OQ0gGPwVrZNCr
3P4bJnR2BsiyzomVQPGJZ9+BtD7YCFLTBNT4fb4/yKI7v/+fnV/g6N906TtI
y/c7G2P0/JfC7RpMAACyCUvs
     "], {{0, 0}, {7, 19}}, {0, 255},
     ColorFunction->RGBColor],
    ImageSize->{7, 19},
    PlotRange->{{0, 7}, {0, 19}}], ",", 
   GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmJ2IAax///+/unTp9//UcDZTj2gFINewdl3CMHvr+6c
PbExBijuP/8TqvpPZ2cAhZfe+Y4s+PvpRqApjhNPIAue6PQHmcxQ+QCh7jrQ
TP/KSqDi+ZegBr/a2wS0/sS7VzP0GPSaDkEsme8Pshpox6UZQFbBnd//fz/Y
CDJr+1OQMQ9WA9kzzn460ekIVHcWatLTJrCK1QX+MRMPwb15aWmBY9rS/4MP
AADCf0PM
     "], {{0, 0}, {7, 19}}, {0, 255},
     ColorFunction->RGBColor],
    ImageSize->{7, 19},
    PlotRange->{{0, 7}, {0, 19}}], ",", 
   GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmI2IAax/1MJnJ3hz4ACHF8d6gTRep2Hzp44dOjQ3r0n
/v//vbFAj4HB/9A7JJ3fL8WAlE9EFnt3YiJQLGbpdWQrDnUCrdDb+OD376cn
OiubOjsndoJMA1nx/c7GGEf/GDBIS4vxj2milr/IAwCABhbm
     "], {{0, 0}, {6, 19}}, {
     0, 255},
     ColorFunction->RGBColor],
    ImageSize->{6, 19},
    PlotRange->{{0, 6}, {0, 19}}]}], "}"}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellTags->"LastCellOfAPage",
 CellLabel->"Out[23]=",ExpressionUUID->"e7b53d17-22a8-41a1-a364-cf618517cc6b"]
}, Open  ]],

Cell[TextData[{
 ButtonBox["FeatureSpacePlot",
  BaseStyle->"Link"],
 " will use visual features of these images to lay them out. The result is \
that letters that look similar\[LongDash]like y and v or e and \
c\[LongDash]will wind up nearby. "
}], "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:26",ExpressionUUID->"4a2b7a34-3920-47aa-bf87-f2322dd962af"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FeatureSpacePlot", "[", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"Rasterize", "[", 
     RowBox[{"FromLetterNumber", "[", "n", "]"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"n", ",", "26"}], "}"}]}], "]"}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[24]:=",ExpressionUUID->"7e312daf-346b-411d-9c64-a08bd8d01ea6"],

Cell[BoxData[
 GraphicsBox[{{}, {{}, 
    {Hue[0.67, 0.6, 0.6], Opacity[0], PointBox[CompressedData["
1:eJwBsQFO/iFib1JlAgAAABoAAAACAAAARXgCznH78D/2HmyIevfoP9nQErJ2
DBJAQ3swYAQf97+KLQfKEK3SP827TxRQggPAFb1HxYmtDkD9NSX3Jp8OwHhf
cbQXjNI/00AjxC0iAMDm+ECNln8TwOrQ3vnJkee/LpxWQ1No1z+90jNNQPET
wGTQ0plBCBJA/fEXWDEwsL8bEpnInfEVwC8/aO23qgFAAiWhFKLiEcD3giH6
9x4RQMVgXBrRLPo/87f3AbbDDUCJhxz4kjUWwJtf4IZs5Pw/nhT9SwJMB8AL
qgjG/Oz9v21r0QRYPAxA2YMW/ehr5L9x7BaQw04MQJPDkCYtGwPAlyP5MBcD
E0B6vn47qRIBwE6fN9/Z8wNAfeJxoz4DDMAUvITA0OoKwAB9G/aFEuq/Wax0
90NI4b/71El5xjzwv1X1VFuNrxDA6SJ9Xwnj4r8VPMwIgu4DQO+nFWXEN/i/
9z/ct7cWAcBCB3zrpnkWQFzrLS3AwgNAN6OVgIYe7D+D9miVhcDqP6JH2d6M
GwpAxwJLxw4+BMCT10M4gl8WQIdxDdbqWOK/dU8KAL5H/T9bi8ov
      
      "]]}, {}}, {}, {}, {{}, {}}, {{}, {InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmIOIAax/1MVfH/36tW7T6hi75YWODJAQEznxAI9Bv/5
IBVPt4MEJm5/8PT60iZ/kKzjjHf///9+sBHITNv+CmLefH+QONjEp51gYwom
rr5052yTHlwcZMWh1RNjHPWgtoDNgTjmN1TB00oGBr3OE2D2p4kghTEzVm+c
UQmyN2bpdagp1w91FvjDXLrxHXWDhsYAALgCdNE=
           "], {{0, 0}, {8, 19}}, {0,
            255},
           ColorFunction->RGBColor],
          ImageSize->{8, 19},
          PlotRange->{{0, 8}, {0, 19}}],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {1.0613878295184958, 0.7802097954272245}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmIOIAax/1Md/P7+7tW777/h/E8z/Bkc09L0GCBAr3P7
HYj4fH8wd/Wh65f2FoClVz/4DlLvyOA48RJU96u9QBn/GZdg4mcRxjoyMMQs
xRQHGes/H6qgYON3mDlAHlgZxF6gmsqlq+dDnDX/+ieY+hnzm2LAzvSfCHMn
insQAM1ehPhEPaCvMMX/f//0CSlYqAwAru1ogw==
           "], {{0, 0}, {8, 19}}, {0,
            255},
           ColorFunction->RGBColor],
          ImageSize->{8, 19},
          PlotRange->{{0, 8}, {0, 19}}],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {4.512171537779261, -1.4450725324056328}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmJ2IAax/1MJfHr37tW7T79h3N+vThQ4MsCA/+pLr/7/
f9AEYutN3H72zp0Tnf4MlRsffLo0AyiUtvQOilEgQb29r/5jCDKsfvAbWfD7
9flAQcemQzBbIbLfV6eBba2csXR+px4DQ9MhiFnvtk+EOsq/YMb1dyhGDRIA
AEmSUzY=
           "], {{0, 0}, {7, 19}}, {0, 255},
           ColorFunction->RGBColor],
          ImageSize->{7, 19},
          PlotRange->{{0, 7}, {0, 19}}],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {0.2918130848817887, -2.43862930172279}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmIOIAax/1MZfH/36tWn77+Rhd5dWu3PAAWVnU16DAzz
L336//16GkjAf+mJ69dPLIUomHj23adLM4CMzkPvIHo/nZ2IJK63/SnUZIgy
uPqld76jiX+/vhTIcOzcCzMHKg504VKIxZUzls5oYoDZC1L0++nSphig8xj0
/NPADppx9h2a935fn49QjwTg9uIQ/4QRUL8/ffr0G0OUbAAA6cVhWQ==
           "], {{0, 
           0}, {8, 19}}, {0, 255},
           ColorFunction->RGBColor],
          ImageSize->{8, 19},
          PlotRange->{{0, 8}, {0, 19}}],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {3.834735432864941, -3.827711039374434}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmJ2IAax/1MJfP/07tWrd99/w/jvzjb5M8BB5dKz//8/
bdIDMvVmbD/74MH1jRMLmlZf/3RpBlBo4tlPyEZBBGOaJs4AgolgcsZqiKBj
QVNnExB0FsSAjPp+fT7I8O1PIRrvzAda2Ql0y+o0kKUFM1ZvnN8E0jXxLFj+
1erOND2we9I6N76jls+pCgBA10GE
           "], {{0, 0}, {7, 19}}, {0, 255},
           ColorFunction->RGBColor],
          ImageSize->{7, 19},
          PlotRange->{{0, 7}, {0, 19}}],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {0.28980057355283106, -2.0166888545282773}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         GraphicsBox[
          RasterBox[{{{255, 255, 255}, {255, 255, 255}, {255, 255, 255}, {255,
            255, 255}, {255, 255, 255}}, {{255, 255, 255}, {255, 255, 255}, {
           255, 255, 255}, {255, 255, 255}, {255, 255, 255}}, {{255, 255, 
           255}, {255, 255, 255}, {255, 255, 255}, {255, 255, 255}, {255, 255,
            255}}, {{255, 255, 255}, {255, 255, 255}, {255, 255, 255}, {255, 
           255, 255}, {255, 255, 255}}, {{255, 255, 255}, {210, 152, 79}, {0, 
           65, 152}, {242, 255, 255}, {255, 255, 255}}, {{255, 255, 255}, {
           210, 152, 65}, {0, 46, 152}, {242, 255, 255}, {255, 255, 255}}, {{
           255, 255, 255}, {210, 152, 65}, {0, 46, 152}, {242, 255, 255}, {
           255, 255, 255}}, {{255, 255, 255}, {210, 152, 65}, {0, 46, 152}, {
           242, 255, 255}, {255, 255, 255}}, {{255, 255, 255}, {210, 152, 
           65}, {0, 46, 152}, {242, 255, 255}, {255, 255, 255}}, {{255, 255, 
           255}, {215, 159, 79}, {0, 46, 152}, {247, 255, 255}, {255, 255, 
           255}}, {{224, 189, 159}, {92, 65, 0}, {0, 0, 65}, {112, 130, 
           137}, {189, 224, 247}}, {{220, 177, 130}, {46, 0, 0}, {0, 0, 0}, {
           65, 65, 79}, {165, 215, 242}}, {{255, 255, 255}, {215, 159, 79}, {
           0, 65, 159}, {251, 255, 255}, {255, 255, 255}}, {{255, 255, 255}, {
           205, 145, 65}, {0, 0, 102}, {194, 220, 229}, {229, 229, 238}}, {{
           255, 255, 255}, {242, 210, 165}, {0, 0, 0}, {0, 0, 0}, {0, 0, 
           137}}, {{255, 255, 255}, {255, 255, 255}, {251, 242, 229}, {220, 
           215, 220}, {229, 238, 242}}, {{255, 255, 255}, {255, 255, 255}, {
           255, 255, 255}, {255, 255, 255}, {255, 255, 255}}, {{255, 255, 
           255}, {255, 255, 255}, {255, 255, 255}, {255, 255, 255}, {255, 255,
            255}}, {{255, 255, 255}, {255, 255, 255}, {255, 255, 255}, {255, 
           255, 255}, {255, 255, 255}}}, {{0, 0}, {5, 19}}, {0, 255},
           ColorFunction->RGBColor],
          ImageSize->{5, 19},
          PlotRange->{{0, 5}, {0, 19}}],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {-4.874597746935455, -0.7365465050011413}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         GraphicsBox[RasterBox[CompressedData["
1:eJzNkKGOxCAQhic5c36fYF+g78ATkKxGrcBe7VlcJa4vUFVVVXVmFQaDqUFg
MBUVYxAV7ADZ3GWf4L5kkh+Yn3/gev+63T8A4EL1SVV0Lpx79JuzbvM7nrmR
NsXgL1L/pJwPMwB083a0JjcrOlKPHd1I+4vHMyGmhGElN9OWHAO80S3hzGg5
gNCrD8FXXtFRM2C9HrUepzVgfpGWviMzl7LOxU0bAQ0t+9kXfTxIy6bRkh5s
83tBPWusOnzX1yzGTEoUKQYTU/mFaJSod3cUIjnjk/uN/+c8ATefUqA=
           "], {{0, 
           0}, {8, 19}}, {0, 255},
           ColorFunction->RGBColor],
          ImageSize->{8, 19},
          PlotRange->{{0, 8}, {0, 19}}],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {0.36574250770576355, -4.985596853530919}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmIOIAax/9McfJrhyOA48SyUc2k+A4P/2U+Y4jMYGBzJ
F59xCas4Q9r8d2Dxdyc6geInwOLzYxhAQK9g/tKJ/iCW/9nvUPV6Tas3TkwD
SztO3PsAyf2X8PsLWXyiHoNeJ6b4/++fPn3/TUYAEgUAWvd3fQ==
           "], {{0, 0}, {
           8, 19}}, {0, 255},
           ColorFunction->RGBColor],
          ImageSize->{8, 19},
          PlotRange->{{0, 8}, {0, 19}}],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {4.50806274747092, -0.06323536301346873}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         GraphicsBox[
          RasterBox[{{{255, 255, 255}, {255, 255, 255}, {255, 255, 255}, {255,
            255, 255}}, {{255, 255, 255}, {255, 255, 255}, {255, 255, 255}, {
           255, 255, 255}}, {{255, 255, 255}, {255, 255, 255}, {255, 255, 
           255}, {255, 255, 255}}, {{255, 255, 255}, {255, 255, 255}, {255, 
           255, 255}, {255, 255, 255}}, {{255, 255, 242}, {152, 65, 0}, {65, 
           145, 205}, {255, 255, 255}}, {{255, 255, 242}, {152, 65, 0}, {65, 
           145, 205}, {255, 255, 255}}, {{255, 255, 242}, {152, 65, 0}, {65, 
           145, 205}, {255, 255, 255}}, {{255, 255, 242}, {152, 65, 0}, {65, 
           145, 205}, {255, 255, 255}}, {{255, 255, 242}, {152, 65, 0}, {65, 
           145, 205}, {255, 255, 255}}, {{255, 255, 242}, {152, 65, 0}, {65, 
           145, 205}, {255, 255, 255}}, {{255, 255, 242}, {152, 46, 0}, {46, 
           145, 205}, {255, 255, 255}}, {{255, 255, 242}, {177, 121, 79}, {
           121, 171, 215}, {255, 255, 255}}, {{255, 255, 255}, {251, 247, 
           247}, {251, 251, 255}, {255, 255, 255}}, {{255, 247, 205}, {65, 0, 
           0}, {0, 46, 145}, {242, 255, 255}}, {{255, 251, 224}, {145, 102, 
           79}, {102, 145, 189}, {251, 255, 255}}, {{255, 255, 255}, {255, 
           255, 255}, {255, 255, 255}, {255, 255, 255}}, {{255, 255, 255}, {
           255, 255, 255}, {255, 255, 255}, {255, 255, 255}}, {{255, 255, 
           255}, {255, 255, 255}, {255, 255, 255}, {255, 255, 255}}, {{255, 
           255, 255}, {255, 255, 255}, {255, 255, 255}, {255, 255, 255}}}, {{
           0, 0}, {4, 19}}, {0, 255},
           ColorFunction->RGBColor],
          ImageSize->{4, 19},
          PlotRange->{{0, 4}, {0, 19}}],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {-5.485953459112831, 2.2083586261213877}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         GraphicsBox[
          RasterBox[{{{247, 242, 234}, {224, 224, 224}, {234, 242, 255}, {255,
            255, 255}}, {{177, 92, 0}, {0, 0, 0}, {0, 0, 46}, {177, 224, 
           247}}, {{247, 238, 234}, {224, 210, 177}, {65, 0, 0}, {79, 145, 
           205}}, {{255, 255, 255}, {255, 255, 242}, {159, 65, 0}, {65, 145, 
           205}}, {{255, 255, 255}, {255, 255, 242}, {152, 65, 0}, {65, 145, 
           205}}, {{255, 255, 255}, {255, 255, 242}, {152, 65, 0}, {65, 145, 
           205}}, {{255, 255, 255}, {255, 255, 242}, {152, 65, 0}, {65, 145, 
           205}}, {{255, 255, 255}, {255, 255, 242}, {152, 65, 0}, {65, 145, 
           205}}, {{255, 255, 255}, {255, 255, 242}, {152, 65, 0}, {65, 145, 
           205}}, {{255, 255, 255}, {255, 255, 242}, {152, 65, 0}, {65, 145, 
           205}}, {{255, 255, 255}, {255, 255, 242}, {152, 46, 0}, {46, 145, 
           205}}, {{255, 255, 255}, {255, 255, 242}, {177, 121, 79}, {121, 
           171, 215}}, {{255, 255, 255}, {255, 255, 255}, {251, 247, 247}, {
           251, 251, 255}}, {{255, 255, 255}, {255, 247, 205}, {65, 0, 0}, {0,
            46, 145}}, {{255, 255, 255}, {255, 251, 224}, {152, 102, 79}, {
           102, 145, 189}}, {{255, 255, 255}, {255, 255, 255}, {255, 255, 
           255}, {255, 255, 255}}, {{255, 255, 255}, {255, 255, 255}, {255, 
           255, 255}, {255, 255, 255}}, {{255, 255, 255}, {255, 255, 255}, {
           255, 255, 255}, {255, 255, 255}}, {{255, 255, 255}, {255, 255, 
           255}, {255, 255, 255}, {255, 255, 255}}}, {{0, 0}, {4, 19}}, {0, 
           255},
           ColorFunction->RGBColor],
          ImageSize->{4, 19},
          PlotRange->{{0, 4}, {0, 19}}],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {-4.471321413360103, 4.280242832465539}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmJ2IAax/9MEfJrhyOA44yyEc2d1AdgisODES2D5E/5A
obSlIEEw69Kn73sr9RgYHA+9AknPBwlCQcHq6xAzQYKOMWCZmDvIFs2//u7s
DJDo/LMIwYkg9tkZMUDxpr1PkQWB7I1NMY7+naiCqI7HEJyox6DXiSb4//un
T99/UynMwAAAWXY8rQ==
           "], {{0, 0}, {7, 19}}, {0, 255},
           ColorFunction->RGBColor],
          ImageSize->{7, 19},
          PlotRange->{{0, 7}, {0, 19}}],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {1.6359416036339536, 3.720561995861311}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         GraphicsBox[
          RasterBox[{{{255, 255, 255}, {255, 255, 255}, {255, 255, 255}, {255,
            255, 255}}, {{255, 255, 255}, {255, 255, 255}, {255, 255, 255}, {
           255, 255, 255}}, {{255, 255, 255}, {255, 255, 255}, {255, 255, 
           255}, {255, 255, 255}}, {{255, 255, 255}, {255, 255, 251}, {238, 
           234, 238}, {247, 251, 255}}, {{255, 255, 247}, {171, 102, 0}, {0, 
           0, 0}, {130, 200, 238}}, {{255, 255, 242}, {152, 65, 0}, {0, 112, 
           165}, {234, 251, 255}}, {{255, 255, 242}, {152, 65, 0}, {65, 145, 
           210}, {255, 255, 255}}, {{255, 255, 242}, {152, 65, 0}, {65, 145, 
           205}, {255, 255, 255}}, {{255, 255, 242}, {152, 65, 0}, {65, 145, 
           205}, {255, 255, 255}}, {{255, 255, 242}, {152, 65, 0}, {65, 145, 
           205}, {255, 255, 255}}, {{255, 255, 242}, {152, 65, 0}, {65, 145, 
           205}, {255, 255, 255}}, {{255, 255, 242}, {152, 65, 0}, {65, 145, 
           205}, {255, 255, 255}}, {{255, 255, 242}, {152, 65, 0}, {65, 145, 
           205}, {255, 255, 255}}, {{255, 255, 242}, {152, 65, 0}, {65, 145, 
           205}, {255, 255, 255}}, {{255, 255, 242}, {145, 46, 0}, {46, 137, 
           205}, {255, 255, 255}}, {{255, 255, 255}, {247, 242, 242}, {247, 
           251, 255}, {255, 255, 255}}, {{255, 255, 255}, {255, 255, 255}, {
           255, 255, 255}, {255, 255, 255}}, {{255, 255, 255}, {255, 255, 
           255}, {255, 255, 255}, {255, 255, 255}}, {{255, 255, 255}, {255, 
           255, 255}, {255, 255, 255}, {255, 255, 255}}}, {{0, 0}, {4, 19}}, {
           0, 255},
           ColorFunction->RGBColor],
          ImageSize->{4, 19},
          PlotRange->{{0, 4}, {0, 19}}],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {-5.552318455449389, 1.8057675617801354}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmIeIAax/w868GmGI4PjxLMQzvWlaQwMMWe/gznfL/kz
MEw8+w5NzaUZQGH/E58gas464lZzlmw1My6hqIG65yyyexjSlr5DqNFbfR2s
6NVePbgaoDAQOBbMn9HkyAAFlTNmVILFl4LUf1pdEDP/0NnVTWAhvZjtd949
2DsDorhg/onftAv1oQAAv+g8EQ==
           "], {{0, 0}, {12, 19}}, {0, 255},
           ColorFunction->RGBColor],
          ImageSize->{12, 19},
          PlotRange->{{0, 12}, {0, 19}}],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {-2.9121137558564234, -1.8703582511612946}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmIOIAax/9McfJrhyOA48SyUc2k+A4P/2U+Y4jMYGBzJ
F59xCas4Q8z8d2Dxdyc6geInIOL+DCCgVzB/6UQw0//sd5D46oKY+ScubeyM
AUs7Ttz7gPaBQzUAADjwg9Q=
           "], {{0, 0}, {8, 19}}, {0, 255},
           ColorFunction->RGBColor],
          ImageSize->{8, 19},
          PlotRange->{{0, 8}, {0, 19}}],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {3.5294647575769234, -0.6381726210712443}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmIOIAax/1MbfHr37tW7T7+Rhd6drXRkgAK9mO13PoFF
nzbpgfgz9l66c3a1P0gu5tL3/58uzQCyClbfgZoG4W68A2bo7X0HM/P7pRgG
BseJZyEKNj6AWfj9rD9Y/Pv1+UBx/4knIMIPNlYCuU2HXgFVrE4DW9a5dPWM
SrCTmp5CNb9a3ZmmB3ZmTMEMqDOHCAAAMu92wA==
           "], {{0, 0}, {8, 19}}, {0,
            255},
           ColorFunction->RGBColor],
          ImageSize->{8, 19},
          PlotRange->{{0, 8}, {0, 19}}],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {3.538458944034169, -2.388269711773725}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmIOIAax//////v799+//2OATzP0GPQmnsUi7sjgiEt8
xnWgee9evfuOMPDTfH+gPQx6DBCg17n9DpK4XufqQ9cv7S0AS69+8B1m/iWo
7ld7gTL+My5h2AviMsQsxRQHGes/H6qgYON3mDlAHljZpxlg9zA4Vi5dPT8N
bO/865+A4qsLYiZu3Du/EuJc/4nbr2MGyqAFAB6AaRc=
           "], {{0, 0}, {8, 
           19}}, {0, 255},
           ColorFunction->RGBColor],
          ImageSize->{8, 19},
          PlotRange->{{0, 8}, {0, 19}}],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {4.753018155294646, -2.134111847691938}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmIOIAax/2OA799/Ywp+ujQDqHjGpU9YxSeefQfX/e7V
q0+//3+/sxQu/u7San8GKHAEkzOA4t+vp4GY/ktPXL9+YilEHKgeYmDnIaiB
38/OQBLX2/70N5q9EMbSO9/RxL9fBznAsXMvVPzsRJh7vi+FWFw5Y+mMJj2Y
vSBFv58ubYoBizg2zZiY5h+zEWbs4AcALexiLw==
           "], {{0, 0}, {8, 19}}, {0,
            255},
           ColorFunction->RGBColor],
          ImageSize->{8, 19},
          PlotRange->{{0, 8}, {0, 19}}],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {2.494067901501615, -3.5015843171243533}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         GraphicsBox[
          RasterBox[{{{255, 255, 255}, {255, 255, 255}, {255, 255, 255}, {255,
            255, 255}, {255, 255, 255}}, {{255, 255, 255}, {255, 255, 255}, {
           255, 255, 255}, {255, 255, 255}, {255, 255, 255}}, {{255, 255, 
           255}, {255, 255, 255}, {255, 255, 255}, {255, 255, 255}, {255, 255,
            255}}, {{255, 255, 255}, {255, 255, 255}, {255, 255, 255}, {255, 
           255, 255}, {255, 255, 255}}, {{255, 255, 242}, {152, 65, 0}, {65, 
           145, 205}, {255, 255, 255}, {255, 255, 255}}, {{255, 255, 242}, {
           152, 65, 0}, {65, 145, 205}, {255, 255, 255}, {255, 255, 255}}, {{
           255, 255, 242}, {152, 65, 0}, {65, 145, 205}, {255, 255, 255}, {
           255, 255, 255}}, {{255, 255, 242}, {152, 65, 0}, {65, 145, 205}, {
           255, 255, 255}, {255, 255, 255}}, {{255, 255, 242}, {152, 65, 0}, {
           46, 145, 205}, {255, 255, 255}, {255, 255, 255}}, {{255, 255, 
           242}, {152, 79, 0}, {0, 0, 112}, {210, 247, 255}, {255, 255, 
           255}}, {{255, 255, 242}, {159, 79, 0}, {0, 0, 0}, {0, 46, 92}, {
           130, 137, 145}}, {{255, 255, 242}, {171, 112, 102}, {159, 200, 
           205}, {165, 112, 65}, {0, 0, 0}}, {{255, 255, 255}, {255, 255, 
           255}, {255, 255, 255}, {255, 255, 255}, {255, 255, 255}}, {{255, 
           255, 255}, {255, 255, 255}, {255, 255, 255}, {255, 255, 255}, {255,
            255, 255}}, {{255, 255, 255}, {255, 255, 255}, {255, 255, 255}, {
           255, 255, 255}, {255, 255, 255}}, {{255, 255, 255}, {255, 255, 
           255}, {255, 255, 255}, {255, 255, 255}, {255, 255, 255}}, {{255, 
           255, 255}, {255, 255, 255}, {255, 255, 255}, {255, 255, 255}, {255,
            255, 255}}, {{255, 255, 255}, {255, 255, 255}, {255, 255, 255}, {
           255, 255, 255}, {255, 255, 255}}, {{255, 255, 255}, {255, 255, 
           255}, {255, 255, 255}, {255, 255, 255}, {255, 255, 255}}}, {{0, 
           0}, {5, 19}}, {0, 255},
           ColorFunction->RGBColor],
          ImageSize->{5, 19},
          PlotRange->{{0, 5}, {0, 19}}],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {-3.3646559753901872, -0.8147611433777513}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmI2IAax/1MAPr179+rdu99g9tOzq9P0GGDAf+P1T2dn
+DPoFey99ODVg7Od/gwMejOQta4uAIpMBDF/v9q7tNMRrC1mxon/ny4VgNmO
aU3bzz4FKT07EcidcfYTXPPvO6tBdlTO3759KdDSmPnXgYLXt0/0BztAL6Zy
751P/wcUAADbsxXI
           "], {{0, 0}, {6, 19}}, {0, 255},
           ColorFunction->RGBColor],
          ImageSize->{6, 19},
          PlotRange->{{0, 6}, {0, 19}}],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {-0.540071471511861, -1.014837716849171}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         GraphicsBox[
          RasterBox[{{{255, 255, 255}, {255, 255, 255}, {255, 255, 255}, {255,
            255, 255}, {255, 255, 255}}, {{255, 255, 255}, {255, 255, 255}, {
           255, 255, 255}, {255, 255, 255}, {255, 255, 255}}, {{255, 255, 
           255}, {255, 255, 255}, {255, 255, 255}, {255, 255, 255}, {255, 255,
            255}}, {{255, 255, 255}, {255, 255, 255}, {255, 251, 247}, {234, 
           234, 238}, {247, 251, 255}}, {{255, 255, 255}, {251, 229, 189}, {
           79, 0, 0}, {0, 0, 0}, {0, 0, 92}}, {{255, 255, 255}, {210, 145, 
           79}, {0, 0, 65}, {165, 200, 210}, {210, 205, 220}}, {{255, 255, 
           255}, {210, 152, 65}, {0, 46, 152}, {247, 255, 255}, {255, 255, 
           255}}, {{255, 255, 255}, {210, 152, 65}, {0, 46, 152}, {242, 255, 
           255}, {255, 255, 255}}, {{255, 255, 255}, {210, 152, 65}, {0, 46, 
           152}, {242, 255, 255}, {255, 255, 255}}, {{255, 255, 255}, {215, 
           159, 79}, {0, 46, 152}, {247, 255, 255}, {255, 255, 255}}, {{200, 
           165, 137}, {102, 79, 0}, {0, 0, 65}, {121, 137, 130}, {137, 159, 
           194}}, {{177, 130, 92}, {46, 46, 0}, {0, 0, 0}, {79, 79, 79}, {79, 
           121, 177}}, {{255, 255, 255}, {215, 152, 65}, {0, 46, 152}, {247, 
           255, 255}, {255, 255, 255}}, {{255, 255, 255}, {220, 177, 130}, {
           92, 130, 177}, {247, 255, 255}, {255, 255, 255}}, {{255, 255, 
           255}, {255, 255, 255}, {255, 255, 255}, {255, 255, 255}, {255, 255,
            255}}, {{255, 255, 255}, {255, 255, 255}, {255, 255, 255}, {255, 
           255, 255}, {255, 255, 255}}, {{255, 255, 255}, {255, 255, 255}, {
           255, 255, 255}, {255, 255, 255}, {255, 255, 255}}, {{255, 255, 
           255}, {255, 255, 255}, {255, 255, 255}, {255, 255, 255}, {255, 255,
            255}}, {{255, 255, 255}, {255, 255, 255}, {255, 255, 255}, {255, 
           255, 255}, {255, 255, 255}}}, {{0, 0}, {5, 19}}, {0, 255},
           ColorFunction->RGBColor],
          ImageSize->{5, 19},
          PlotRange->{{0, 5}, {0, 19}}],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {-4.171437670765347, -0.5902144303336999}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmIOIAax/1MV/P7+7tWrd99RBZ8emsgABTEzJhYAybOf
gMKvJuoBRdI2nr20d34BWNYfJP7prD+QNeMSRO/11QVQ8e8gcceJZyHi36/P
APIwxT9dIiT+CU0c6DbHE0Dx33c6/R2bNt6Bmb/a37HyOppPBjEAAGsvgAA=

           "], {{0, 0}, {8, 19}}, {0, 255},
           ColorFunction->RGBColor],
          ImageSize->{8, 19},
          PlotRange->{{0, 8}, {0, 19}}],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {2.4914589583709223, -1.513615031110472}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmJ2IAax/9MM3FldADQ/Zv4lJLF3M/wZQECv8ylM6PeD
jUCBzvkT9RgYll7/DhG8BFKX9uD70yaQ2hNgMRCboXI7kHV2oiMDQ8GD//+/
X58PFJt44t1/EHspkD3j0qe9TUCTYmAmPagE61pd4J828dBvmKWX5hc4Fiyl
nd/JBgCNoFMq
           "], {{0, 0}, {7, 19}}, {0, 255},
           ColorFunction->RGBColor],
          ImageSize->{7, 19},
          PlotRange->{{0, 7}, {0, 19}}],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {-2.1360926021661686, 5.6188008112383745}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         GraphicsBox[RasterBox[CompressedData["
1:eJzNUKEOwyAQvWRycl+wH+g/8AVNplEVtaudravEzaFQU6gqTFUNBlODwNRM
IGoQFeyALPuDbSSX3Lv37t0L5+Z6aQ4AcMI6YqU+/st7MoJx6nlLIBiOoOrk
/uFV4gGY9ogMpxl19q1Y1Q03KAEyzGhwJwjaCkAsIfP72KE9N0nG/KbRjWvd
p9mSeYs8YSZ6hTMhBwBqY1R5C0MFK/J1bNe+ysepwONOJoUOJRIp+aesaIVN
xk6W2BNr6+6R+eg1rwkdXcnmGCXD6L7yz79/LxCaB3E=
           "], {{0, 0}, {11, 
           19}}, {0, 255},
           ColorFunction->RGBColor],
          ImageSize->{11, 19},
          PlotRange->{{0, 11}, {0, 19}}],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {2.4700931100500565, 0.8787262450615348}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmJ2IAax/9MALI1hYNBregpmf7q0FGhL2tLr36+DGDFL
7/z//6pJD8isfABWcKjTESg8sROoh2H+pU9QI35fL2AAAf/OQ0gGPwVrZNCr
3P4bJnR2BsiyzomVQPGJZ9+BtD7YCFLTBNT4fb4/yKI7v/+fnV/g6N906TtI
y/c7G2P0/JfC7RpMAACyCUvs
           "], {{0, 0}, {7, 19}}, {0, 255},
           ColorFunction->RGBColor],
          ImageSize->{7, 19},
          PlotRange->{{0, 7}, {0, 19}}],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {0.8360011976398741, 3.263452282911161}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmJ2IAax///+/unTp9//UcDZTj2gFINewdl3CMHvr+6c
PbExBijuP/8TqvpPZ2cAhZfe+Y4s+PvpRqApjhNPIAue6PQHmcxQ+QCh7jrQ
TP/KSqDi+ZegBr/a2wS0/sS7VzP0GPSaDkEsme8Pshpox6UZQFbBnd//fz/Y
CDJr+1OQMQ9WA9kzzn460ekIVHcWatLTJrCK1QX+MRMPwb15aWmBY9rS/4MP
AADCf0PM
           "], {{0, 0}, {7, 19}}, {0, 255},
           ColorFunction->RGBColor],
          ImageSize->{7, 19},
          PlotRange->{{0, 7}, {0, 19}}],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {-2.530301625229501, 5.593270186558487}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmI2IAax/1MJnJ3hz4ACHF8d6gTRep2Hzp44dOjQ3r0n
/v//vbFAj4HB/9A7JJ3fL8WAlE9EFnt3YiJQLGbpdWQrDnUCrdDb+OD376cn
OiubOjsndoJMA1nx/c7GGEf/GDBIS4vxj2milr/IAwCABhbm
           "], {{0, 0}, {6, 
           19}}, {0, 255},
           ColorFunction->RGBColor],
          ImageSize->{6, 19},
          PlotRange->{{0, 6}, {0, 19}}],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {-0.5733541660988956, 1.830015182645153}, {0, 0}]}}},
  
  AspectRatio->1,
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  ImageSize->{321.74609375, Automatic},
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->All,
  PlotRangeClipping->False,
  PlotRangePadding->{{
     Scaled[0.05], 
     Scaled[0.05]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[24]=",ExpressionUUID->"a572d25b-fe37-48d0-9f6e-4ff151cdb627"]
}, Open  ]],

Cell[TextData[{
 "Here\[CloseCurlyQuote]s the same thing, but now with pictures of cats, cars \
and chairs. ",
 ButtonBox["FeatureSpacePlot",
  BaseStyle->"Link"],
 " immediately separates the different kinds of things."
}], "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:27",ExpressionUUID->"0e762fda-aafc-49c3-8d9a-e9308eae53f9"],

Cell[TextData[{
 ButtonBox["FeatureSpacePlot",
  BaseStyle->"Link"],
 " places photographs of different kinds of things quite far apart:"
}], "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"0319f114-1d32-4efa-a630-915c6f332214"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FeatureSpacePlot", "[", 
  RowBox[{"{", 
   RowBox[{
    GraphicsBox[
     TagBox[RasterBox[CompressedData["
1:eJyNmHdU0+f+xwWUHZKQvTcQEvZeMgVBZO+dhLAJe8gUww4JSUjIAMKerntr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       "], {{0, 40}, {53, 
       0}}, {0, 255},
       ColorFunction->RGBColor],
      BoxForm`ImageTag[
      "Byte", ColorSpace -> "RGB", ImageResolution -> {96, 96}, Interleaving -> 
       True],
      Selectable->False],
     DefaultBaseStyle->"ImageGraphics",
     ImageSizeRaw->{53, 40},
     PlotRange->{{0, 53}, {0, 40}}], ",", 
    GraphicsBox[
     TagBox[RasterBox[CompressedData["
1:eJytlgdMW9max592pd0n7a600kqrp/d2NJMyCZlMJpkUkkAgEELv3WCDbcBg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       "], {{0, 40}, {53, 0}}, {0, 255},
       ColorFunction->RGBColor],
      BoxForm`ImageTag[
      "Byte", ColorSpace -> "RGB", ImageResolution -> {96, 96}, Interleaving -> 
       True],
      Selectable->False],
     DefaultBaseStyle->"ImageGraphics",
     ImageSizeRaw->{53, 40},
     PlotRange->{{0, 53}, {0, 40}}], ",", 
    GraphicsBox[
     TagBox[RasterBox[CompressedData["
1:eJw9lwdQm1m256d2a7fmvelgu22SyEkIgQKSiCKKIDIiI6ISkhCSUBYoIyFA
QgGRM9iAySYYY5OxDdhknNvZHneY7md3u3dev+7XM92rqdraqv89db9bX9X3
q3P+5373uhHZmeX/409/+hPvz9aQSRBFc7mE6qwz1occFo9OZVHIiSw+hUrh
BhP/p3XRxzpQ1vGvuX0owikiAJAa7JQd5pmJ8kzz88R6AWMAYIw9ON7RFnXu
HPwzr2hATCEynRoGinX0SbwAz7f3zznvkfwX9+T/Dc+38Y5wcESc9Utz8ktz
84m3ytU/0c0318k9FQBJ9sxWxms2+OSBDM88GzukgxPEBhh2Boyx9cUA4tnQ
FEmgL9bVHmRrD7NBUwMz1ck+Ke7AJGd4rkcYyT2c7OIcGeQchbRPRjlmBHhl
wiDZYP9kV1iSh1ckwD3KEUODxDD83BLOARPsovGwTFY4hgLyLzkDLj4Hzvui
uAGSrQBd8P03t1A7YKqbX5qXH9YDlgaC4VwhhfYQhq1H/tlkJZo2iE9pQmCM
Hn4kG+/QLyDos8DQ8+AE50QhKlGCAmNd7YA2LsGAbE0qrb80ihEMKQB6pjkG
l3jnygOdI4Kco1H2iSiHBJgrFuSMdnIOPBtdCIku9gNinePYcPUCjdKaFUb2
90g6F850QtDPBVSeCWDYoyvdJi9x96cM+bQQd+znaAIYhfcHJbh7x7sCY12B
GIB/uU1wrQOS43Um4qxfiYv4dlHppRjPpE/hyTYInIc/zi1VFhYvRvineLgi
nIBxHlhJdLYhKYruj8h388LapXGRFeZk1wCYYzDEMRIKzYZGEsFheD/vGBtg
pB0k1tE57AwA+xmlJblmmhjHA2PYTrGSCwju+SiZZ1K9P7MpZN7MvNUmu3nV
GM3ySOFCEAW+wGRgEgsLL/B3CgF4ZjoECgDhYu8QJiJGHNb1TsffKMSpAyPK
XMndabn6yHgJNKEamcCNSK6KjaYGh5TDg2h+YTRwTIV3LM1XMlgi7M90g3g5
gT0doZ6wNPdYKjC+wj+GAiSr0snSbDe0rVvseaIxprAZHc52TFG4orkXYFQ7
BA2QZkSZLpautYjWLNyTS3UdvaXxMnBQCcg7w6tUl11qSEvgosOZgVDWhbQW
1NBR/ciUqG+KhmlwSNBBgFgbTBWcOIDFqiFp6sB0ZXSCJCRTER1NQwKizqPL
kOz2IuGlfNUcgWqJcYY7Ofo724Oc3EPsAnDOIcVANNGNbUnjWHIDs73RBfAi
TRKaAQTn2PjiAc6p51ySzvqXnI/XhLV1CafqKpc7RFs9ktOrDbnVMNf0L4AZ
7vAij2JtQmVvPnu4IN0YLjBhb0/WHg7Vr/QK0PILYPkZR8x5IM4ptSkoRgkp
bI/nThGLBlJIXWnZMox/his00zmyPKC0KaHcjMWW+7rAbR0hdo4QByekg0uY
vUesbSIDUqwMzZWhI8qA0ExHSJ6jX5a1Nc45hZy3Df6zS+KfQUV/cc7+vF5O
uigtX+5UrXbJD0brxvo5yURQYI5LCMktluUPKwJ6pHyh0OfsjikfjDU/n+0+
mmrIMwb5qc67Zp4NqfJJM6MKW2JLupK4C2WmB8qatQp8GyZFCQ0je4aTQUV1
kQWKSGS66//HAyBtHILsHILtEmnBFYYUkiYWx4D742yBmdadxBaSYeU/4xr3
777kT31J/x5EcOpp5naJydNmyZSev94m+P5W5/0p2fogd2uO22pJq2RHKkUZ
+4OyB8NNzxe6n02an91oVa+yECp331LbMLGXtcrknni8JRSj9LESWu7JSzti
ozkeaLJnujigpD46oRISSfR1Rtg5Qu0AfvYAmL0j0tEeBQCEXYgh++I48KRy
UBQJmC4MCy5yQeQAPNNsAdhPvHM/8S78X4zmuLVJk4VT2lCRdb1NstNbfdDP
eTwqeDWpeDut/P6q5um4/NWc9u6g7N5Ex9vF3vsDqpPFFvkSNbMLDaEAwOX2
oSKPmDrP+FpXGO1cGA9EH8zJqUcncMBJfGiGBJopRSRzA9JFIU6of4EBfO3t
Qfb2EHsnlIMt5Kyd76f+sfYhBW7oAg+CIi6DGeQa/plL/Dnb8E88MJ9Aiz+h
msLXR/SqokQdLbmvJm9KXbJipiw0FO0PcE4H2QfdjINe9uGg8Gikbn/YfGpN
4IhpolvulvWXGC0YSfcCF9nHStwipPbJCu9YoW8kGxLJhURywFgRPK4KFM30
iueAE/mwLNn/w3O04vna2/jb2kIvXPA5c9bl0y+8PvWJBgTjPDPowQXceGiC
u1Pop67RNl5JX8QKXIu1AZdNvEFpmakqsV2QvNTC3OkTr1gYi01l682kvQ7a
bkfFVmvFyWj9Zrf2irLi0bjZ1FNpdR2EZxcj8vTLOB/Fd4lXuiRV+2EF0HC6
DxzvFE73ThD7FWhReeqg3Fp0cROGYE5wRP6rKez9bQEQO2eEzQVfW3uIjRP0
MwfwvznDzgVg3TLoURg8Eh4LcAB/bgf9zCnkcw/sGTw/aNwimrfwpvTlS12i
xVbunKFyf1izYiIdDde8mG/c6+Mu6ghb7eyN9ppBbtGzzX5RWwmE6ATm2KQq
XIMotgEMW4zIM4TijSpxiaB6RVd4pkv8C3UhrL4wVndUqSmB2pXCG8m1g9lY
LWcLtfXHOITiXD1CbKFYB1SyjV/kJ/DYL5ApDtn8KF5rcUSRKyrTKbzMMZzo
BMtwJvGjBxvo3XzcpI5hUHAjgoL4hLzjKfO9y9Xv98buThhvDigeTmh2uysP
hmq2u2XPb1/GlaODiB5Q9oUMmTOaZwdh2gYzACHlLpF0jyiKc6YUlCmBEHVx
pfWwLLFLMMk7kR8SXxUQV4b0CHd0CbJLIrvjKt2jiz1SmH6xZW6huDOZFYBU
micyxZHVmFlaG8Y0YSgGOE7ijFcE8RsTmkSZehp2qV3Q2ygMCQ6p5jCPr5i+
2+786vBGaV4WPidjZ1h3eon/dLb2/W7PyVpnKQOdKwmJ5DgRm7wrB6LiJXCc
HJqjBCXzXNK5XlkSQIbAn6BJYprgRPW5VB6Q0pBO16ex61NiS0GQRJsiiVuR
xDmB5FgghLN1SUVCBK0OlsvzyKT5MdVZ5XWR1MYQqgFKrkeJujOUrbim6uz2
GnyXKON6e9XGsGZcz9weknx7s3d/uqcIl06nVzxeHd5qJu30sj4eDX19t9ti
xgm60vh9iZwW2KUnvKa1CtUIltsekMI5y2kJE/VEsJujWIakmn5U3TRI1Ifk
tcaKOpOJNYHZXK9cgQ9F40Ot88tiu5TJQJL21LoBgqQDS6v3Y+uCWDoMtyWq
ROVbpvbmtIRLBmMlbal6WaGMFCMhRjZVpe1P6qa01Dkd6263+PGY4tvbQydX
dPcm5Qd9nN1+/n89ufLxVtvJNHd0nDZ5V22YyGzbwXdslzdOpckGg+kGX6IW
KGgPkfdjlP1ZtaOxdTMBjbPhqmGMZCC8qiGRooHR9BBWUyC9LpimQTH1gSxD
ANccUalDVJlQVU2BNZ0xbDOaoYfTG/zJtcAKox/PEt3cRFRXpskqM/qM4oe3
r56sTDcyCrYHNe9Pr//9zcF2D3ezlXIyIn2+ZP716fyHdePf5qXbY7T2yULL
TJFiFC3sD5QPB9RNIap7w5nNULYRwm+G8I0YaT9GdgmunQ6WX4ySDgULjWli
SzLfFF1lCOY0YRU9cRQNnKEPJSp98mqcswROOC6AovXjGWMpGg9aA7CiHsI2
ggSW4PYuZqeuSsrDm3T88eHmix1NZjlnqrPh0Z31n9+/frk7tdkrWG2j/nQy
+fHOyLtZzQ/LDa/nRUN9OFELVjWUXl7vUWnybJwKVw0kV5mseYAK2yHK3rTq
tmhBl3fDTGTdWHx1XzBFgRCbccquwlKZa4kEyjEiKpogRDWUooQQ5AF5Ancs
/Xy+EMzURtC0YGKtK7MJUWH2rmgEN5nwLVpOh6nGrBNqFBUNisqRdvXCsOXl
/Vu/fnz9/fOdx2v9350s/PPtnddXdC/GxR/XjP9xXXt9mCw2Yml1sRSdU4XZ
ntvqK+6Esk3+NZ0RgjZETWes2IKh6px43e6cdlilCcrRYdnaZK4uvVwDJddC
iHI4TRtSqvAhSb0rNfF0NTKF4UCQoSvUUXxzFNsE4phR8u7kxvY8s7bUqGC2
6Wsseom+jttpEk8P1T/au/rj3x7+5w8vf/vxxX99ffT7h8c/Pbj6dIz/Zlr0
07rpl63Wg2mepjWrRIbKEjsWqu2IGkd6g1uJ9VuNCJbRj2NCyjqSyutAxUon
SqMXWQtmqaOEDfk0aRxVFcYw+hDrQBRFWLkCjucBCFIkQx9CVMDyeZ41zQW6
ixVsI5xah+Ab4syt+A4tVScmNdeL2gyqXkvd/FjvyuzAweb08/tb798cfnh2
89XuxIfT+Y97Q69nar6arvm4bvxjv//lSr2kDlMk9sWLQYXVPgU8r2yWB6kO
Rmv0xFd/ztR7M3XhHHMwSeHPa7LmM5ogc6/QhFOkaFoNhqGOZBtDpB1ZFGlg
OtmxhIcslQQUiXwLhSC+IUnckk5UeVUZkcwGVENT2qCZ29ckGmyrG+4xLU4O
HN2+/uBg/euXhz++Pf7m3vXHy91Pl5q/3uj+drX5w7r+63nVh/Xm34+Hfz4c
aLbkUOQRPdZfnTI8jQHIsO4VSmeCHFgmBZWrgYUif7o6iqH3JyjgXHNomdQP
x7bL5/kqLMUUGZrdGM/Qhqs6c1i10ZkUH5oyslDogxf40tVh9f1ERl1IhQ4k
akM3NFsbln3JVDPeZ1iYGtzbvPr4YPPB4dbzB7e+frB6f6nt4VzDs3nt2yXD
uyXdD5umN9PKv90w/OP08u8PpubGeKlUj8F5df+crEIVUsLzoYkhVdpoVn10
LhPOqk9nNUYSlCC83INlBBbSI0p4gTGFAKIClcsFEaRBLG2CojO/2pJWIoaU
VIOJCu8yCdjaQXJLoqgpmaGNELWm1XcVd5tZ3UrGSLtmbqrvYOvaw/2N493r
x5uTp0vdhzMN92brni01vltr+W6j9dsV46tJ+U+bzb88GP/lZPLqiLBcHYhj
+OgG+f1zSqEuqpjjxVbHVSjDuJoskihRYMggSJBFcm+a1i+fhmKrM0pF4cUC
/0K+S36VD1UZnsfxLpdHkaRhpdVwvjmUb0ZnMl2Jci+iBFjKgTIkUezahJY2
ZqeG3tXIH+7V767N3b+7dry9uLvYtzao3BlRPVk0vVtv++ZW33/s9H+12vxi
VvnL0cV/vFz559O55TGJpqeMKAlKJAAVbSRNT1GxyJeuDKRKkVwtlqVNYjXE
EqXIIjGkWOBVqQwlCqJI4qg8JqhcDiJYF4VwgSmVUB2cxXQiSvxKJWC2Dk2o
gZFUUKrahyTyo/LRZEmguiXPqCIZaoij3Y23lqdPdq8/vnvt9oxlvV+yP6F9
fM387JrpxXLbq5XWJ7PaR1cUPz+c+v3bnX++WDxaNRsGWYZRCrMeXakJq9RE
5rDAZBmY24jl1CeUKwPkXbkSc3q5HEWUevEbItgKHCbbLYMEtvYCszYOz4XT
VKE0RThBEEwSwwsF8NJqFF0RQlFEUBQwuhLGVsYRa/xpSphRR26tpc0MGbau
Xz7cmHx0e2J3xrw5KNsd15zON92fa3h01Xh/Rrvbxz25LPnl1Y3ffzj47e3a
8U67rCWbUBOWx0YSRWiKIECoDKDJYSIj3mrvKj3CMMzuviyrUCLLpL4UcbBl
QFZQCcuhQegSLL8umylPoUoRFfJQSnV4uRTB0MQX8cPI1WFWcoYstrACTGQh
KdXQwip7gymnxyic6q+/cdm8M9d+uNB2Z6ppY0i1MaI5mDVYCQ8mNMcTtds9
7Gdz6t++2f79t9f/+OHo6oyS15iIYwCLBCiGEstRYvgyJEnoXi73zGe60ur8
BQ3RDGlSpTSyQhGWQ/MR1pWSREEFHF+iCEOpjuaqcAUcEKsBkcfyKmD7E6XB
xWIkSRpUyPSjCCP4mkxMlkMBzatMDOKr0I3y4o5G/nSv6s7VzuMbfcc3+k9W
hg5XBhcHajcvqe/N6vdHFSst9Eez9b++3fz911e//fRAb8pPo4KIohi6NLqE
50uRIKLz7PFsQD7LIYnggSkG5DNcCxheuXQPXmNIiSighBdTzA/LYDhls12L
uSGpJX7ReW48XYLxIolThy1iBpQwA6nCyIa20gppNFOdmlMBonCDshnwUi5K
wscq2XkDRsnmbP/e6tjhxsTzoxuHN6e7GtjD9fT1HuHNXt7hcM2b9a5fny3/
/n8ePzqZrRSFlAhhORXgbBIol+ZRwPbJZXhVKBDFXBS2BBRf4JVQ4JxJdi7g
2hPEXgQujMCKySRCkinOqVS7YhEykeAeme5VRIut1uZQrGXlB9Krg8qFgTJ9
htScKGiKr1RGkXmovErfQiZUJMgQlcXW84ssWsFYv+HmteHd1YnF8e5GUVmX
rGBWT7BekTZay7/a6vn5y6U/fn3Z3sbPKHJlyGB0FSq1yBudeiGu0BbPdWXU
Q+TtyWU8cHIhIC7PNaHsAkF2Hs9zLKRBcUXgVLxPQqF7ATMgqdQtJv+LhAKv
TGIoJgvEkRQQq4LIXE+OCkkWQbia6M6Jqip5BFsaVCr0LWbDJJKcBnZ2PTPV
IC5sUVdODRjGenTNGp6Ojx9S4uf1pTudtJcL2g+H4//91513z2/lExBZJd7x
2c55VR6JpYCw+DPJOLu8UpeUUls8y03SiNBaEmqaEot5/oUVXuSKgMxSVFii
Y1SaS2SqEwbnmpIPySYgEnKcY7KAfmF2ZA4uuywgBecglGUQ+eFsFbZKjaXV
+PMUkYLGVKIAVcmPalbhu6Q5s83UK608BSNXXlWiEhA7laReEW5BX7LVRnm9
Ynl/MvPH+4dri4P1jcRaNb5eW9nZJbwyq58cbRofqr863To72bw013735tjx
3tzD0xsPTlfuHd148/huJsEnPBkAQ58Nj3P2R52FBJ2DBtuEYgAR8d5RyWBh
IyEx16+cHlbJS6BWYiSynNr6QnVjrllPbW3mGc1MfWNlu4berypZbmccjmu0
zCxGcXKXQdKhIo9ry9ZaqUej1T/en/355eaPb/e3lkb2Vsef7F17frR6emvh
0e7Sy3ubz07W//pk+7tnB9aT2OnejdOD9QcHK28e3nx1f+vLo5XsAmAxFYVJ
dcrPh6elQHKzQwsKIsjkxCadqLdTNzPeNtqnX5zoXJnvuzbROdii7tRL2/XS
AYumScnts2jH+lpaNTyLqGCpmXFnuLpFgmeXZakElFYJftJQvtXLer6o/fX9
g99++fjd168nBy0zg6blyd6dlfGdjcm9W1ce7l873Jx8dHfx+cnqvd35/a3J
uxtT1mPP06OVV/dvvnpwKy0FkJsFqWJkWnSC3lbN+IB5frR1atDYbVY119cs
DLcuT/WM9+rHe/TWONSq7m9W9rco+1uVrTrxlZGu2dFuYy13QF8128xe66gc
baTmZ8TmpUa2iXNH1TnLFtLf9i79/cOz54+P//jjjzsb88MdWqs5p4fMN6+P
3l4e21ke21wY3L4+cm97/unh8tsHN797cffbp7vfWPV87/s3x/lFCFwazKjh
XmpvmL7YvDTVc+PKwNRFS59FPdBSO9pWOzNguDHdOz/ScuVi8+wly3ifvqOp
xlBbZakXtjTKhJVlUxdbX5+u7s213hrWjDRxSHkx1Yy8iTbxnaWu10dLf//+
6Xd/vb92ZfDj+3cvH93dnB+aHjRdG+vYW5ncW5nYmBuwsm3OD+4uX76/s/D8
eO3LgxsvT9dfnK5bi/7V0ztpuUgeK39lqm9jfmhz4eLW4qWVK70zF03Xxttv
Ll68vTRsjVtXh+aHLVMDTWM9Db0mqUXLMyiZOnmlXFjOIGdPX2z77svDb+6v
ff90e7xHFxvkZazl7CxPvHm088d/v7cm7cmjg36z/P7OtdPb80frE7vXLu1Y
Tbg2tTLdtzjW/vx4/d72Vase3b2+vzHz5GD1y8M168uv79+0KiHdj4CPG21r
mBkyWzV3yTI/YlmZ6dlcGFgca5sbscwMGacHDZe7661swx2awRalNU706boM
NZ0GSY9J2qKrnrhkubM2sTzdw6fl4eKQKgF5uLPx7trUty+Ofvzw1Ztnx3dW
Jt493nl+tPbozvUv95efHa5ZrfX0cPXNg1svTjae7C/f31k8vb1wtDV7d216
+8b46qy14pcPN69AAs+z6FmTvVYGk7V8c8OWueHmhdEWK5JV1rkVz8q5NNFh
NcmdlTFrJlev9F693Hp3dWx1pnP+kmlvY3Treu/alfaJ3vp+i9K69U30NY31
Nc0Ntz64ffXJ8epP33z5n98++fju3rvHu89Ot56dWD2//fJ089nRupXtYGPG
inF8c253eWJ/feb09uLuyuTWtZHT7at769P/F0ajS2Q=
       "], {{0, 40}, {53, 0}}, {
       0, 255},
       ColorFunction->RGBColor],
      BoxForm`ImageTag[
      "Byte", ColorSpace -> "RGB", ImageResolution -> {96, 96}, Interleaving -> 
       True],
      Selectable->False],
     DefaultBaseStyle->"ImageGraphics",
     ImageSizeRaw->{53, 40},
     PlotRange->{{0, 53}, {0, 40}}], ",", 
    GraphicsBox[
     TagBox[RasterBox[CompressedData["
1:eJyNlwlQYmmW793SDdm3C/eyCIi4goqgIogKIqKigLigoqi4Iu4r7vu+oum+
pmmaZqa5Z5a5V2VWdXZVTeVUVWdXdXV3zfRE95vXEfPem4l58SZexOt3s3K6
pqJj3psh/py43xf3+/id851z7sXfYtdZ3VxcXJq9YaMrbU9sairt1GPgQU59
c3VlfUW5ur6lorKiKcbiDk/y4K8c/r67JgJIWGQqmgJhqTTcj4KH8CSZgvqz
kCQAgQe8iXQEnuaFJ7qisR5YvC+XhpExSBoGITMAlxNCyRfQ8kIoBjZex8bp
2NgsJkpNJyUHBQhCeXQ6mUTyI5N8yWQfIsWTCHkCoO97USEECPlRQQSNgaEx
CBQQQ4WwEISDRaGgqVQMCGLfCx7+VPDMf5Kf+E5+IIjgcXHRAnIEF0kHvMl4
ryAaKpZJlEF4GR2bzCEpuZRkf6KMipKBaBmIklH8JCRcjD89NIjDYABkMvI/
5Ifo+L/g/6kLf8EPi0RBwXrP/6P+kp+KpkJoXgBOm8iryYqcqFSOWRJKU4Jk
fEjIJQnouHAqLpSCFdCIkQxyOETkkVE8MjqIggkn48IJOAGTFsxjM5lUAECR
ib4A2YcMepNoXv8OPx0DwtGDAf7MD5PDq37Uj9jwPGzfbUjFvBcFwv0k/nhY
AIglwcupaICK8megdYqg3b6iD+erXi2WvpguOnPoDx0mR7k2TxmXzA+I5BBj
eFBMACT2p0ZR8dEAJpaKiwPwYiI+ikYJYkF0BhGg+gGAD0D1pUC+FJrvj/wU
2AWaH0hD0ugoiIam0jAUWCCaCsKoGBL5XQwBCpoMu0D5V1FgKjjyZD8yFfte
MD/s+3tRaQRYFAhPht45QgVRkWHQdJf5l3eX3x46XszkPh3KfNCU8Gqy4Hy1
9dQ50F9XpBb6q/jMJC6koBNTyCgNyS8bQGYR0WkEtIyMCaGTaEw4IAgK1ZsC
IWBaiI6CLSx4CPzADzFQNAaSRkNSaWiAhgFAJOwvCUDjiX5EwA8OIwnO8z/n
M/BDbhD/v/ywABoeTqRAHjjoqPvq+cnfvDr55v7Ks8Wq8770W1be5WLWvZ6M
Ty8Pvby1NdNu1URwZEyylIqXEhAKvE86GZlJQKtxmDgCigcRYP53tFSf96g/
CEmlv3PhPT9IR9KZKAbsF4QigigK+MMFGYXF+RBICDLlp83kP8UPwSdOw9NZ
QGt77TdfPP3d5w/efnjy9snerx6uf7puv2uP3NYgtzSEe46sbx7tvbyz02HN
jWYS+FR8GIDnEzFRBLQIhxUSCDwi3p+KpzHgbZEU8N/4aUwMSEe9jz+c/3Dy
0P3RDDr6HTYVnof5MXiCHwbrQyTDC99l1PtOSKbCR/PugkhG/KRm8SCdCItK
JwJ0IsQkASAGifFWpqecP77z/ZdPfvnhyZunV97cXf3rG3M/P+y63Zm8riGO
CFyXtZwvDhzff3xy93DJqBBFQ5hwOsimQgEUMgck+YMAnUqhg8R3zYSOpjBQ
VDocdiTERNOZcKzg4npXuXDyM1g4fxYeor/rn3CqwPBwJHF4JArtQyD6wbQU
EEl9ZxEUpi9Ah4sI8UMq/mu3BOlwwEnvBTJJZDqJFcKpb2n++ttv//j777/+
8ObT4/lH+xOvjmdeH48/326+M5S9Y+IMRHm2hHnd6df/6vn610+vjNeVKOEq
5rFC/JlhTCjcnxbEoLGpVCZEgmj/D34QyYRQZLoXmeUT4I+n/Xv88Cm85wfh
c/mBn8J4l28/CP9ecLa8h6cxSbA7YnnszedP/+f/+dN/+8d/+faLTz+6sXFt
uWmjWz/frL0+V/dg3X5lQLdeEjQuw1XRXGazaJ8ftL0939sZa9dGB8SF+Au4
LGEAQ8zlCFgsfzJAJqBpdDyViYX5Qca736XBqeKPgxhYiI7BkH34TGSlLo4V
QHrf/3/Kj0R54/AIOGHgvKLBTQnyozB8qH/mBxgEMryESaQxyXQmmcaigCwS
hQU4phb+7h//5b/8wz//7W+///rlww/2RlY7s/qLhENViZdm7IfT5QcjBUtl
4l45qYLtagt1P+vJ/PTG3N50V2IoK4JN57EZQSxQwIICAUpKCFsVFUjCeeMA
bwoTRYKQZBqSCPqhCV4Y/AUc2UcYDi3lCA7GHMxgOpmOJoM4gAw3PfgpgMOR
MEgsfCcST/Ej01AUGhago4hMeB/Ee34yg0CC+VlkiE2hsgGAA+BZBKaA5zy+
+/0f/9evv//DL9781ScPT0+cHcsOw3i9fmnQNtpd5uw3bfUZF62yplhsPt21
mO4ynkF7uGRbG2xODguMpAHhDCiYDgRDcLNHGSTC05GG8YZSaaQ/j4UJD2cy
GTh+OKMoK746M8KRE3LUrHg+Zd3fvwwxyCCEAqk4CMDRQSwNwpEADAyPIiEx
AJIAVzQdR4Z7bAiGFQI3BJgfQfUnAQwilUUGAihYLhnNJXn7o1lxkVu3nn/z
t//05stvPv7ow7tXD/acQxcnWnYWx6prywUi1niTbrlBPWAMrRNhcqhuRpJ7
Nc9twyqdqzWouKDCn5IAUeJBII5GDsOiNbHCg/GOezuzp8t9l3pMz+bKXq7U
vVy1/fb2+Kdr1icDKa9mc+/sTozPzBHJBCLZF4CQJBocbQSJhsSCSCTgiyZ5
I4m+SAICBz+jw0nC7PBQuT+R5klielMDyBQ2Ga4xUiAVfuojAkmuNERQkuTk
6euff/37jz/+/PbZ2dHexsHmyszocHtXE0XAxHJQbSVJs1ZZu5pZHOSlBy9o
MBeyiK49UvKILkLLAbJZUBaDmkYD1AyiikmKYVF6W+pneluXmvPvj5nu92U8
G8p+5FCdD2uezhc9W654tGo/WO6NDOO6e3h6+rn7Ub2xAb6EQBSeh0FwUd4M
H2+8u7uvm5uP2wXInSwhsXUcghjtyXDxYblRoyBqKJXOgyhBEA5+ZeGSECwc
LohW0mLfPL15fO3awaXdixtL9va6uExpmIbvKfDliqndZll7BrNC4GdgeauJ
7lJfl1TihTo+3qERpnFZGjZdzYYS2fQkDk3MJMjDGSfzPa2GxLkq9SNn3esD
x5Uew60h442xrNfHnb9/svBg2nx71aGQit+9E3u6uQOeflxfcgQGjCFhIlEe
PA9X0M3Fz9WT4I7k+/rE+LpFuvoI3AkJGA/BBUDGJERRiWFUUhiVCL+HBZPQ
wQRkGIkpDY5Ii1cUpmXXGOIN8XQpHZcEEBKJEVmBAz2FUyWyEr63ieOVx0Ea
mQhLGKUjNXS1In2/tcogihRQsKEMcmAgk8MFORzS8Ubfy8OegdyIW3N1T7f7
jvqsSx1FD3aHN7qLR+t02/3lX14bfXU0+N3rewmxUS6uLh50X88ALzTfGxCj
8RE+FwJd3BmurngXb5Y3U8Wiqhl+Il9KIl5QFkHIpGCTab4iIkJAxEaDWDHk
Fwn4RZJQIgJWRMQL8dg4MlYGYwNUFYRNJMlL4w93x893HGOZIYWcCy1CyoiC
O5TMceaKTpqzn0zZXy51XulvtKpihYFw0yd7EhGSZNFXz7bvrTas1ymeLzdO
1BvVEbTRivQPFjuuDDfkSUImarK+vDF+f7Hydx8fP7tz2Q+JcCddcAddPTge
XjxPT383d9DFneDqhnJ3I13AxpIZmYEUOYAIu8DQ0kOrwgAliInHoWLQWAkR
HUv0jkJ5CvwQEWiMCEOIwxAVGLKGTEmhUGNIRdWZV3f7P9ztverImdQHr+ZH
HFTEnzSoPpwqf71U/9G8/bP1zoej5c/nGz9Z63o4bdtqL55uMl7sr3p1bfHa
tGW0OHrdnnp71vZsq3u1JuXFjP1ab/FXH5w8vjS73Vdy76LjaLLh799+JEuW
uLi5eKA8XFFuLmg3F6Sri5+Lu4+HxwUvV29XF7wLIRLPTmJ7BXshRD7cAjZN
BcGiKimERBJKivcSIy9E+vhFIDHRGHwsDpdAQMXj8EJ0XpHsg/2BV9sdZ50Z
C7mCjYr42z1Z9wdzHo+aP3bWv9nt+fpw6JdHI28vDb92NsCTT0bNX211vT3u
+/J06unO0EiJZLxSM1CdO9RU+eajB68fnLYV5G72tD29u3W85WwsLRiwm8aq
tZ+czh8drnv7+bp5uru7u8Byc4Otu4fbuz+WLhgXBM/PN9CPEksLyAgBUmiY
eCQxkURRUqFUiJxEwkkxfmJfn0hPjBiJjyNgxQTvUCSej7I3Z784HX99ufds
OP+oIemwMfXOYN79oZwnE+ZPlu2fb3X96urkb06nfnc2D9vfnoy/2Wh/s9nx
xXrno6mSu3P2y9ONM7WpzQaZKSWuq8F+6+Hzm/eeN5Ta6opLJ4fat9dWWmut
Fl3iWm/lk72xo/V5BNLP/YKnh4e7u5sbbH4oau/g0PDwBAFVTIe98KB4YMNJ
flF4L743UuBNjMNS5GRSLI4YjSHH4YkxeLwYB8TiMXw0Mwqw2dKfXul/vtny
cKn6dMhwbSD3ap/xcrv2dm/Oi/mqLy/3/+ps6rubM789m/67uwt/uL/87dWx
r45Hv7w0+Fdb7Q8milbsmQttJcsdOSWJDK2I1mAp6Osbqq22N5RX2issHbV1
zZWl9WXGrZnuG0udT/eH7uxNp0jjXX7y4QYFPDu/84vXL7779quf/eIzSYbM
xdPFBeXi4e+Fl1FChSRBPBQcC0BhaJCPB6OIZAGeFIqi8xFggI+1IuPj23Pn
a3WPlms/mLYcdWmu9hqvO/LWK5N369NujhQ/XW/8/Lj37Y3R39yeens6/NdH
fZ/udXx2eeDNcd/5VNGWTT5s5HcVJHVZtaONOY76vLqK3Ori7Nz0BEtemiUr
NiOeo08KHWkvcw433Fzr++PXj//0T99899m9ifHhqhqLVJ2UmSobKks7nR87
Pz6Yaqx78fjxm+++wjPwrl6uHlRPuhJMkXEUCRyZhMmPBnhRRFoIkhqKoIkQ
/jEIlUZw7Ox9vuvY7sjY7dTOW2LW6pKd1bLFUslccex2repSR/btmfKPtlp+
ftD9yWbrw5nKh9PWT3baHq83w/OHbWkbNUkThaKy5EBzpqTDXjbU3z4+1N5g
zTVmJmQqhDppmCGBX5uXVpMdO1KX/fMPjv7+uy/+8NnN//7rB3/60//+0z//
1//xD9+f7487UhgmSVSDtbomM63DWja1MBWrjXbHvatltpKYkhKWlBKsTA9T
ZPBFCg43msSTAtwsAFAiG/uLf3F/6+FM1UiRsCc3ZNAYMlMiWa2VjRv5MwWi
XVvqUafuZNh0c7L07kz5+VzV2UjRixX7y+2W842W87X6o87MnXr1cH6kSQrm
JnOMGQkVRcWOltauzvaO1taG+jpbjaU0J8Ug5TXro08na246u758uHZvuvg3
H5795te/fPvpk5fHYy2Z/JyYQKk/GB9IMaTJu2xVC5uLAWo2EOvnFehOkPjk
mg1ZZVpzfZ6l3lRYl1dQZSytL+IlswlJuIpGxdO1lkOHcbg4rjkzqCc/crgw
qtcQ5EjnDurCL9aoNuzq/c7M476cox79jdHCB7Plz1frHztrz7fbn++0btbK
B3IELdrgylSWNhrIFLOLU+OKMhTlhbkt9bX1tVW1ZTlFqYJSdVirTtSaEb47
WHI4Zp4oDPlgZ+pnLx4cTNmbNdziSKwqlCQPgUIJ3pmKGGu1WWNW4uJ8QQUW
SEAT5ShrWa65wlRSZ861GYobi+rb6+09zdmlOdU9xSvzVRuNmnFLfFd+jCWZ
05oj7MqNbtBwWzJ4rencxcqElTrlZpt2r9twMlx4fcryeK3xgbPu5qzlfK/1
bKZk0hjcrGRaZbQaFS8rAp0uwGQKKSYlvzBVXJwhrSzIsBZoDAlBVoPMIguw
KYKWHDX7iwPDloSRmpylCcdYfV5HvrI2XSxjYmUBkD5LHqOOYkv8yTE4qhLL
0oHcXH9/I91SlFFo0qVXyoUWboJRlGvKUuYlFVTr7lxbvLPVPVcWX5lIkwf4
aSKpuhhGlUagjyRZlOzO/Igxc8Rmq2bbYVxu0Gx26Q/HS44mSk/nqk7nzMcL
JXvd6T0KUlcqpz2NXxbPM0Zis/koJQehCMLJgvFxQUS9IlKTwFdE0rIUQmtm
tFEMNhVrWqqLbIZkbTg1J0VoK8poqC4rLzHmGZWG8rTYPCFbQeeoGIEaGicV
H6QHOTkQlEW01OTprer40tBgE6SqkWvLUrjJUFaFqrE7v642qTc/Mj3QI0sM
pUcz0vhgRjRdGk7Qy2gN2WHDlrj1lkxnS9ZKT+66I3+zO9fZoVtqzdpw6LaG
claa1bXxQGdmaEMyw5rAzBeS86Op+ghqGp8i4WH5oFeKkJmVKMiSh+mV0QXp
oiKNwKqPMyhiSjJVpjRxZnKEVicTpYkDxP4BcYRgvX+wkROhZ0Ybg8Q5gcJM
elAqmZUK4CWIbGumpCwyyhQoLgpKbZBq6hJkuYJGR0V0MkurD2nMlajDiTkS
pl7CThHQEsIpIjGUlRJYrgm36aIcxbJhq3Kx07jYkj1ZnzJcLp2sTJyqUS62
Z881pplEpGoFZ7pMMlOT3GeKr00NLYijy7k4ZQQ7S8LNSQoyqsTq+NA8dWxl
kaZEH5+vFrU1W42VOnlOhKo0hiunenPdcHzvgCRkeA7IzQYj8mgJjUJFqzjS
zKBp/AAFAhvtZrDqI4qC4guj1OYYXgahfqrkyt0Nx2CVQEZOyQg2Z0hLtAn6
BL4+SaCRhxbnJqVkRau0UcUGSb4y1G6S91jT+uvU+nRWtpbdVhjTUyTpLU3q
tSq6zOISCakuNbjbFFej8m/LDu/Oi23LEZmUAkk4Kz6cnpsWq1PFauSRsK21
5JTmprTZzM7N2dKmrJLa5NaZSmu/xdJaam4pMbXoLb0FxtYciyOvxllXtVSV
25etbkrKatPoGzQr2+vRxvCOiY6u4aa0aln3Unu7o6GoPE2uZSenh5i1SQXp
ybYKy8igo7ertsScoS1SpeYnV5RlZ6dElxoSGspTTZYYthxBDPHIzRDYTDJ7
Xrw9P7YhP6qnSFypCi5N43eZYtp0YbYMXmVqYEl6pCI+RCER5WWmZ6ll+nR5
SV6GvcLU316zujbdOd2eaY7pGagbXZ+cP3Yenh7fffTi5sNH1+/cv3L3/tHZ
tZM7D2Cd3X94/f796+fnZ4+e9SwN5tcVTFyc658f2ri5f/F0o7A6S5wazBUS
1TrJ+FDfztrajRtnV07OdjZ32xtqHL1tpdXmKmuhQafSGeThMgiIQ4EJfoIE
SCH3N6gC81MD8pUssyasuVCql9D1irCBesN4Xep8q2axPaetUKFXStQKTYY6
TaNRFObrbBXF7baKwd7mMrvZ2lFtKNAXV2dqm6La1ir6Vjvzywv6J0YuXtrY
Pr2yfXrj5gcv7zx6dfvRq0unD67efHLv0c90TRnDG/PtE03zB3Oj+4tp1cnS
7KDsYlWFvaR71HHj1o3bt+48fPDo5s0PTq+ctdiqh0f6LdUlpaU5eYWpYXKO
q78rWuRNj/OTJ7IUQjCJT1aJqRopPV3K1iUGqaJp8DtXcbZ0ttMy32GcatA6
iuXVRkVCbJxKmaSQi4w6TU1FaU9vZ+9At8ViGuzpb6qzp+eEDK5WdA5UGnIV
IITJLkrUWiX1XbVDozPTy9vbl892rtzaunT9+t3Hd84/KmzM5WsClZXStpWe
0tEqSVmEMD3AMdCxebQ1uz06tTJz5dqt05NbB3vXz+89721rda4sD4z1l1Xk
qvTRCIabJ8sDI/IFxX6SOFAaTlbH8aRCMEEEKiQBCkmQhA8mRoDCcGZ9iaGr
XNNXrujIjeouS0tJkAYHsYVhjOL87OHBfqfTubqysrO+cbi5NT422Nvb2V1f
Xq5NKNTE52pTyooN2RmJGamK/JxcU56ptLi0rbm1saWjd2Tq4s6lyaWJggZ9
qi21a73HBO9uDA7TsHvne3qXBmwj9cvby5Pbs/NHy/VNDSNTU/29fQf7l5yb
G9m5qY4RW2yKUKyOiUgOlaaHSJKCxaLAQAbEhEgRIrZMHsLnQdFh/oniMIiA
ZtOprdWm2bbC+SbtXKvJmCIND2OaC/OXFxZ2d3Z3N/e2V9Z2lhe6m+rqaqo7
W5pWp3p/draxP+0oKzD0dXaMOnrGe3t7W5o2nLODfR0d7U1Nzc2t7V3DoxN9
2w6lVRVnlqjsyQkVMfHFwtBMjsqWbJ0s07Xqq7pttZONjU67slhiHjTnVuTk
F+WX2UrTsiWV1bpCkzJVHZuoiYtWhwtTwwNELDwbE5cqkmXEBEcw/WmEQBY1
0J8mDAuN4IuqSkyro7adgeIpq6SpUDo+NLG/f/34+NbJlduXL9/a37+6t7O/
sb4xMz3vXFhad65srmysO7dWF9emp50Lzu3FpeUb104uH2yvLM0vLi4MD4/B
dy4vrQKJSJ8AH0oglisB5eZYtpLhnwIF6OmKOklRn15TlqwyJyeaRaJ8pqJV
mF0vSykQZdUmGqsUxpJ4e02aViPSmORsOd0H9A5UMgTFjGSbSG1O4oWyWSwI
opAiwkKEgkixSFZuLtpfG92Zbbs013pxqmtr+8rIuHNienV5ZX/l4uHC0s7S
+uHm4fXNvRura4fbW5fWdy7vHp3OLsKZtb69trE8M/nR+e2bJ1cnRyYHB8bm
5lZWnJu720eRBpATBFCwXiAJERbJSTKIaQoqW00K0VBY8djs6sSyrhyhmhuc
QJAXhwgz6BITJ8kWEWcKtbRpLC1phZa0lPI4WVlokIwdrvWPq2FLa0NSzHHR
0tDE1FhlagIvKCCcHwRSgWAed2vd+dGHzw4PT64c39o+ONTlmIRiaZY+31pR
b7e3dXQPwvU2Mbc179ybXdxeWt5Zdu4vrlza2j/d3D9a3zmenlufnVyanlia
m1ufn99YWFyHK4at8s3SiXXZMYEcBIB3yUiP6drs0TZo022K1KqUkcvTXbvd
xY48hT5OniaOTuIzpRRhATcyn52UH5nWKknKD42rCkrpCsvokqZ3JaY0yTIa
Zfn2ZENZgq40Obs4NSVT3tRRZjYZstLTKyqqbLbm9rYeW11TnrGw3FJVYq4o
L6uurm6uszXX25ubmnu6+0Z6BsaGx+fHpudHJpamF9ZmF5yLSxszi1sLFw+d
q/uLi9s7O1eX4HLfvbSysa8q45U0qZub82w1iZ092pbmAnWVbubh5dn7x0PX
NpVVBdld5oKhkgSjJNei0ZWlJWnjg2R0eXWQ1WFMrIrQ9ERkOsIUPTyVIyKh
IULZpjSP6LNLRAazjBSCjkoIEctDYqRh9TUV48Mj42OTCwsrszNLiwure7tH
21sHG+u7R5dOdravrG/sbe8crqwerG1fWnaub29u7R1eXts6Xtu+vL61uwHP
Hl3fOTjd2z/Z2zve2bl8dOVs5+Bka//4/wISzEG4
       "], {{0, 40}, {64, 0}}, {0, 
       255},
       ColorFunction->RGBColor],
      BoxForm`ImageTag[
      "Byte", ColorSpace -> "RGB", ImageResolution -> {96, 96}, Interleaving -> 
       True],
      Selectable->False],
     DefaultBaseStyle->"ImageGraphics",
     ImageSizeRaw->{64, 40},
     PlotRange->{{0, 64}, {0, 40}}], ",", 
    GraphicsBox[
     TagBox[RasterBox[CompressedData["
1:eJxNVwVQW+vWrdut0lLXW6N621tX6u5eKhSKFErR4u7u7gGSQNzdgxUobsXd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       "], {{0, 40}, {64, 0}}, {0, 255},
       ColorFunction->RGBColor],
      BoxForm`ImageTag[
      "Byte", ColorSpace -> "RGB", ImageResolution -> {96, 96}, Interleaving -> 
       True],
      Selectable->False],
     DefaultBaseStyle->"ImageGraphics",
     ImageSizeRaw->{64, 40},
     PlotRange->{{0, 64}, {0, 40}}], ",", 
    GraphicsBox[
     TagBox[RasterBox[CompressedData["
1:eJytmXdUnOeVxiWQ7WDZsWJHkXQcSxai92EaM8wwvcIUpvfKFMrA0IYqECB6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       "], {{0, 40}, {53, 0}}, {0, 255},
       ColorFunction->RGBColor],
      BoxForm`ImageTag[
      "Byte", ColorSpace -> "RGB", ImageResolution -> {96, 96}, Interleaving -> 
       True],
      Selectable->False],
     DefaultBaseStyle->"ImageGraphics",
     ImageSizeRaw->{53, 40},
     PlotRange->{{0, 53}, {0, 40}}], ",", 
    GraphicsBox[
     TagBox[RasterBox[CompressedData["
1:eJztl3dc0+e+xyPZzEBCyF7skQAh7B0QUVnqwb0LKiioOEBre0urOFtbqdZq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       "], {{0, 40}, {68, 0}}, {0, 255},
       ColorFunction->RGBColor],
      BoxForm`ImageTag[
      "Byte", ColorSpace -> "RGB", ImageResolution -> {96, 96}, Interleaving -> 
       True],
      Selectable->False],
     DefaultBaseStyle->"ImageGraphics",
     ImageSizeRaw->{68, 40},
     PlotRange->{{0, 68}, {0, 40}}], ",", 
    GraphicsBox[
     TagBox[RasterBox[CompressedData["
1:eJyN2AdQU/m+B/B9++7u6kpR6UhJ6L0KUkIPvfcSOgGSQAghISEJkNBCLyII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       "], {{0, 40}, {53, 0}}, {0, 255},
       ColorFunction->RGBColor],
      BoxForm`ImageTag[
      "Byte", ColorSpace -> "RGB", ImageResolution -> {96, 96}, Interleaving -> 
       True],
      Selectable->False],
     DefaultBaseStyle->"ImageGraphics",
     ImageSizeRaw->{53, 40},
     PlotRange->{{0, 53}, {0, 40}}], ",", 
    GraphicsBox[
     TagBox[RasterBox[CompressedData["
1:eJx1mAVYldm6+JUN7O7uYicbEJAQRNpBUCkDMcYWlJA2ZzAIEdx0t3R3C1KK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       "], {{0, 40}, {64, 0}}, {0, 255},
       ColorFunction->RGBColor],
      BoxForm`ImageTag[
      "Byte", ColorSpace -> "RGB", ImageResolution -> {96, 96}, Interleaving -> 
       True],
      Selectable->False],
     DefaultBaseStyle->"ImageGraphics",
     ImageSizeRaw->{64, 40},
     PlotRange->{{0, 64}, {0, 40}}], ",", 
    GraphicsBox[
     TagBox[RasterBox[CompressedData["
1:eJzt2HlUU9e6APAzZiCAqBAGCRAmW5FJJiEKJIQwhEkGZaxoy6QIAhImGWSe
CVNAoNaiohZBBQK04nDF2jqhVSxOdbr1Vn1qbxUBBc3dJwGK2r571+of9/3x
9vrxrW9/Z5+c74SzEtjM9fG+kQgEQUkUEHzXpbATE9el+SmBSUBcUkxUXMRn
bnFbIqIiEpevR0HxI/BjBX6IHP7/8ZcG8q4PD/0XuvmggEAzPpiiRAU8O8QU
hYjpH4/ZBX/u39/s7NKZ5nAZGCFACAlCKASYJKvAEFUKgxEURmQNQzKzY3oq
7VC67E+AWwOvMw2Vwt4zey+yKYqooOjvEEwZwhcCIJmuIMoIsgBB5kEIDUKo
EEyFEfIMigy4KTCV3hQVQuRgAP0jCA1G5AEEUUBQKWSarA5AqIKMbAFK00Vo
uugMkEM0JiTHnC0ickxYhspEpBGW0ybQtGFFBkGegcgxYBoDFOculiY604t/
r7y34N18TpFog8ZEVEznglVMIbopJE3mFt9dZoYom4MIqxsTVE2Q9xdMQ+km
qKoJEelmKN0cxD9bOecUMxlI2gmsZS+DMAgggXQIsxVEy2EaY2YNw5GgBXCk
2LCmPSA9REAYKxEtGXspkKyYsfJ/h2rby0DaKwHYwBM29CSiHp+gz4cNpQw8
EH1PxMBzOs4uAN475Q+4w/ruiAGfOJc43QMxcJVyI4r/lj4RZW0gxkGwSRCI
iFEgsiQQMQqCjUMAxDgYWxoEoKA+a8kaEOHZU5YETp81m0xPwaFggDh9WiBm
HISbBJFMZwUSTEJIJmEk47DZCr40BF8aihuHoqZhALIsGrGIBhFdFgUghBgZ
dFk0ZkFEWV2aSFkAMUQERSKPwiwjMYtI1DICsfqMYBGFmEcj5lGoZTRuFUW2
isStokmAdTTZBsQoknUMbr0RINvEUmw2ASAh24DpRswmFrPZhFlvwq03kazj
0eUpBFsgGcBsBZht6izcLg2zExB1u2SclSaVDopEYpcqrQsIrGTcLhljJaGs
RHRFImo3XUdYKTgrmcxKwlkCwgoByT4VRHxlGm6/FSDbZ1CkSA6ZuEMWgDpk
ymD2W0kO21DH3Bk5MojDNkRax6br22YOTa/E2XlSYAFRxxy3YY55iGM+7phL
dswhO2ST2Tlkp21kp1yMU4Sz80nsXBK7AMA5hahzEcYrwXnFJF4RQOYWk51K
AMS5DJbCeBU4rxzjlSO8CtSlGmEXzIIdfze3LpU/XXcEVylGncphTjnqVIo6
V0BOpRCnAncCFy3EedVkXjnqUg7zhDCnEuKWUF1KqW4lZNdiOZdKOZ6Q5FqJ
84W4u5DsRsBdq1EpzK0GA4mLEHGpRVzqUNc6zL0Wd29AOfng0rNXn9Ne/ntg
RxALMKcSlCekuFYpuhQrsjMUHQRKDuk0boacax60vBRfkU5mJcotF6hw0vW9
MrRXlUPsamhlGcauxLmgmVrEtQZzryHxa6keIoqHCHerJrkLKR5CCr+a7F5N
chOiLqBPEe4uAstAe5hTIcop+LA9GLxjnFyUsw3m5MOyDp2KcV4F2bmEtDwe
0vXCNewMrHz4UaXrCzq8UtpsvDb4+nEWKi2iUOk0hXkLF9B1tHX0PjbLFASm
50R6rU3kBm+xC0wzDUjX4BeTeXUQtxbh1Smuaqbw6yBONeQogjgiyLkOcm3E
PetJ/AacX0fiN2KcUpRThLDzMHY+gII+OQUAeFTkHMBjU0bmllG4RWSXUoyd
Cy1dC6mskF+0wtpj0/qC3ryOX4q/HvUrOK1qGRYfy2rM91Kbr0h8+c4Z9SkM
yc/m40N2r6/wn5+wv9XButntJG5ib90amp/qnxXJzUz2bRRuyimIW79FwA3P
0vGpQHmNqAfRHuLRgHHK5rRHPPNkx20U8L6t3AaxSiCHYoiVBxlFQRrg64Ct
y4r029RSsOfHpuNjdccmkrZfWrpy7SJlpeZ8+96BhrK9PxbuGyzbKa5qEVe0
dJbUtqbl1xw4WPPq2aF/DEW8uPrR2xG9I5XmV3udJfd4krt+kuHVPWX+A22x
ktv+kovakvMGr86Y/XzCvKbkUwr4LXvUInzRTHsFoD2cXUh2zMPschC7HF33
rbHRn7aXrq7N8t0ctSpmQ6Snj2dSQfnOUz+3HH0i6rgcFJ8nN19LT0Oprz2x
qDS1tef8hZHhwR/u9F/85+CNZ5d/fn7n8esnz988eHjr+W8/vXxy/OXdvIn7
W8duFzy7mv3yp+TRq9Evhv0kNwIkl6zenFKVnFWRfEeXnKRLBuhTR43t1uZA
4D3ki3BuCQYeKqcizCkXPPw0TpapT3LVVv/7ex0kx10kQ+sl9+okY9+/mbw3
8WLk8U+Dj+72PLqWdfEQ/9Zpzxsn3Z7dLhSVCHI/sz9c5vtTT9Bw+6qrg9m/
XN/+/Fb56M2c8R83v7oSPHbeYey08cQJ7amjqm++WSD5WuFNH1XSS33bi092
UySnVO60M5qTtJo2aj3epTX6lYpkHz08Nhlyaibxm4kPBKcS2KkQYuUv8Ula
yolsy/aVfB82/kPuxO29k79dkUw9HB/9+5vRB+P/HJl80Dh5K+T1nQDJw9QH
gzHiL30uDySMXo1qS1DeFa/1pNd6VKz3dlB7alBj6ojSlJj6pg9/042+7SK9
7ZZ/3aU42bNwSkyfBLpVJw+rTh1We9vPLPtMW1mBJvu/LMJB7XGL3ojQkBWS
AruLcH4Txa0Y45Yo8fLyM0KOVXt3N2x8ea3p6Y2D4w+HJp+cvv/j4fziyrSc
PFHltsvHc8duB49eDnx72bc4xkRDab6yqrYCiZK2Rkly9KMXexjPWxeOd6m9
7lGfFKtNiRlvevXe9jKnxMxXXbqvO7Um2xdNHmBMfqX5sk3zeavqP3eqve1U
r45Qg6B5K/w3O6/NVWaY6CpQLhTpnytn7sj1kvcRYvxGqms55FCdsDlecjF8
9FTA+LmUl0MVTy/W/nq56fXt+p4a9nrnRTsrvG6fjnt20vfZoWUPd+o0hy+Q
I9O91yYXfd6/Oe9LnKYlXKs52mH2626LF/ttxw7YPN+/7Nkek/9p/fhhi/4/
Gpn3Gxg3atVvljLPFepeyNS9VsV81Mx8sJ35eA/T0lDe2Tfab2MpK6TQPbZO
bR7tbIne00ZGSbwP5lZP8miQ45VB7JKyjPBLO4Offpf+8gfRy+vi8WcX3j4Z
PLcz8nqRw1Sr0Vi78YMm3evFGiOFC88XMPVV5vE/SVmXXJGY2+gXsdX9kww7
A/mHX5jc3W48Uq5/IVdzMFP9WAb9G8GC/gR6Xzy9J06lJ1b7wGeM2mDtogBG
ppfGpSq9m3X080KmgcZ8z7CscEGTT2RRWuPfWOZLzuQolyRyFdyKEf521KtF
yb8Fc29ZHRNfEGzYlmB+Y6fdcLPbvvzAtqrEb2vXimM/7o5V7d5M742ZdyhO
6USaiiicrjSfzg1KScndFblVVNp8KCylyUZX/btM7WPZGsfS6CfT1c/mMC4U
6FwqNbxeqX+jUv+mUO+uUOvopkUtwTqN4fq5PrriBPqTepVjWVpqC+nrUuuj
MxpcQlJTanq51iZh64IQ13LErZnkuR3z3mGS2Lc4uj+28PPrhyPudQdNnkqZ
/Db9tNBNwKXVxvOLw3RFoepfxWmIE9UHUhYM5WhmeqvKz9d0CUnakFqTUd7m
ujrR1j/Jw1zlQdPiOzXGI422ZxrY31Rxu4o4+/M5Hdk2B7OtOrOtD6QZ7Y7T
qYsxbIwyaohcKlynXR2pu8lTnUpVcgnYkCXqEg9eTMqqlLOKwd22Y+7NsHcj
5NEMee5kCQ6bRe/RDajS885irUkMjYrNykvfURl5tIZ3RuR8tnAJeCsuFeqd
z9UcSNc8lWkY78pAEDwirTo2d7db+LbSHUfs7L2MNBWTvbS8zNTNmPPpC+RJ
GAL9xwPDKVy/T9dEbJZT1kUNvWmsCEVe3ny/7eqhezTCO6Lrvg8tGnAXdJl/
0qjiJICMwiBVBwhjQpAShuLKFGiRAqROg9SokLIcpEGDZN9YJOq8kE8TErKq
OR5hcy4FPhxwDKNRaQsVFixaqMbU0FrCNDBfbGRrZMo2teJZr/S0dV7t6PmJ
q1+0V9gWv/XZ/hGZqyOyVkfmBG0qjyo+FF/ztaD+dMrnV5Jbrwq+vJb85Y2y
zvtAdc+Dut6fhV13C/ePJLecjSjr993yhdPaIlvvLRbcT6ydV9vxAliuofae
n/L8ozwDY3xCNoRGpyZmVsWnl2VWteU19ZbvOlq373Rzx4XWnuG2I3f3HXvQ
/rdf2k8/6jz3tGvot55zY70XXvVdnOi7NN5/+VXfpQnx0MShodcHzgOv2s9N
tJ2ZaP32xY4Tz5qOPKrrf1jZ80vpwb+XdNzP2XM9Z/f1vL03KjpvVXfda+i9
t3Pg/q6Tj9tPPe3+7lfx2ec9F172Xxof+GH0yJWxI8PjA1fHjwyPHbs2eXzk
1fEfX568PnHsyujAxedHhn77ZujX/qGn4nOPu888Ovzdw85TDw6cvN9+4t7+
43fbjt/bdfRO65E7rf13v+i9/XnPze2Hr9Udui48eKu84yZQ2n6tpH2kYO9w
Qdtw9u7h9C+vpu0YTmn5ISBlHxCU0R6S3R6a0xGe2xlZ0BFTfDCh7GBy+cHk
iq5UoTi9WpxRI86u7c2p7QUxs64/s/7rzPr+bFEvoR7oy67vzxL1ZTb0bRX1
Zor6M0VfZ9T3pdeK06p7Uqq6UivEaZW9qZXdyRWdyRUdSeUH44o7Y/LbI/I7
1ud3rMttD8v6KjTjq+D0vQGp+30F+zyT2tziW13jdhs5bzDibTR22WjmtsHc
PdbSI3a510Zb79gVq+IcfOMBtn8Sd3WKc2CqyxqBDC9IJsUlOAPgBaU7B6aB
yANRynmNgLtmi3OgAJzI8U929Nvi4Jvk6LvFYVXSSu+Eld6bWV4Jy/kJy903
gz/MLD02WLjHmLttNHHZYOwc/bHzhsVO0QbsSKZjhI59FI2xTF7LQlHbUlnb
RoVpq6xjpay7jK5vpapvo2pgq25op2Zgq2Zop76YpWkwDRRlFn3EAjQWExUQ
gUUfrQBmc+LQYvAKy+n6llJWdD0bgq61irYFXduSrmOpomOprGWxQMdCUctM
gWFK0DSV01hKVl9CVjeBUDkZGJcHIJwGk6RweQRTRHBAAQE5Lo9iCiiqiIKi
rA6mmPwMaQ5WkhQRkoJ0Kl1JkkdINIR4QTkZBKcBMC4Ho1QYpUgjsTsEoWRi
cwwFqBBGhVDpLhlKnd65gjEIeQc8d4Psj8aHh+GZnTT494psHwydflkYe3cD
jbju9NWJbUPp1tlsA7INtHe3+37flCSKKApLSRN4xocVGURWh4hkeuX7e4l/
ui85e+S9fcj/YCf1r/ir4//y5jzojUwm/7e7+NNBIpH+BVr7Oyw=
       "], {{0, 40}, {53,
        0}}, {0, 255},
       ColorFunction->RGBColor],
      BoxForm`ImageTag[
      "Byte", ColorSpace -> "RGB", ImageResolution -> {96, 96}, Interleaving -> 
       True],
      Selectable->False],
     DefaultBaseStyle->"ImageGraphics",
     ImageSizeRaw->{53, 40},
     PlotRange->{{0, 53}, {0, 40}}], ",", 
    GraphicsBox[
     TagBox[RasterBox[CompressedData["
1:eJx9mAdYk1cb9wPZm4QMRgh7740IskRBENlDZO8heyQkrAAJIYwQwhYQcY/a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       "], {{0, 40}, {71, 0}}, {0, 255},
       ColorFunction->RGBColor],
      BoxForm`ImageTag[
      "Byte", ColorSpace -> "RGB", ImageResolution -> {96, 96}, Interleaving -> 
       True],
      Selectable->False],
     DefaultBaseStyle->"ImageGraphics",
     ImageSizeRaw->{71, 40},
     PlotRange->{{0, 71}, {0, 40}}], ",", 
    GraphicsBox[
     TagBox[RasterBox[CompressedData["
1:eJzNWEmT28YVViWXHPMXcstPyDXHXJ3KD7ArisuHKGUpVYnLPrlKTpyTk1LF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       "], {{0, 40}, {40, 0}}, {0, 255},
       ColorFunction->RGBColor],
      BoxForm`ImageTag[
      "Byte", ColorSpace -> "RGB", ImageResolution -> {96, 96}, Interleaving -> 
       True],
      Selectable->False],
     DefaultBaseStyle->"ImageGraphics",
     ImageSizeRaw->{40, 40},
     PlotRange->{{0, 40}, {0, 40}}], ",", 
    GraphicsBox[
     TagBox[RasterBox[CompressedData["
1:eJy9mGlQU1cUgGnrD8dpx9biwk72FbJhgCQgirIKyr6IGlBAGwtIEIoLjqDi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       "], {{0, 40}, {40, 0}}, {
       0, 255},
       ColorFunction->RGBColor],
      BoxForm`ImageTag[
      "Byte", ColorSpace -> "RGB", ImageResolution -> {96, 96}, Interleaving -> 
       True],
      Selectable->False],
     DefaultBaseStyle->"ImageGraphics",
     ImageSizeRaw->{40, 40},
     PlotRange->{{0, 40}, {0, 40}}], ",", 
    GraphicsBox[
     TagBox[RasterBox[CompressedData["
1:eJzdl3lQE1ccx532n/7Z6b9t/7BOO20dHQ9U2g6CShF0FDxQDgHFQkQREImA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       "], {{0, 40}, {40,
        0}}, {0, 255},
       ColorFunction->RGBColor],
      BoxForm`ImageTag[
      "Byte", ColorSpace -> "RGB", ImageResolution -> {96, 96}, Interleaving -> 
       True],
      Selectable->False],
     DefaultBaseStyle->"ImageGraphics",
     ImageSizeRaw->{40, 40},
     PlotRange->{{0, 40}, {0, 40}}], ",", 
    GraphicsBox[
     TagBox[RasterBox[CompressedData["
1:eJytmFlTG9kVx13JSx7zFfKWb5BUKpWqVGV/yGTsTGaxKw4uOwx2gW2MPWa8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       "], {{0, 40}, {40, 
       0}}, {0, 255},
       ColorFunction->RGBColor],
      BoxForm`ImageTag[
      "Byte", ColorSpace -> "RGB", ImageResolution -> {96, 96}, Interleaving -> 
       True],
      Selectable->False],
     DefaultBaseStyle->"ImageGraphics",
     ImageSizeRaw->{40, 40},
     PlotRange->{{0, 40}, {0, 40}}]}], "}"}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[25]:=",ExpressionUUID->"8b26e3c2-012a-4bd7-84cf-62e01854f4c0"],

Cell[BoxData[
 GraphicsBox[{{}, {{}, 
    {Hue[0.67, 0.6, 0.6], Opacity[0], 
     PointBox[{{-48.8332943145472, -33.50465550012418}, {-82.85793475114673, \
-57.58938559958467}, {-61.17437387304301, -54.251762852463614`}, \
{-65.42723984219596, -73.55880391714472}, {-81.4217590184258, \
-92.18039139831386}, {-39.888497411758024`, -54.45289180627676}, \
{-48.585148917150306`, 58.39154294516718}, {-7.894295715041444, 
      63.041134968444865`}, {-34.23335177916469, 
      74.90242332370299}, {-25.43510036386343, 
      55.04473645333421}, {-51.23861591860722, 85.86755585010356}, {
      129.37961899700517`, -4.934200029468172}, {141.3716240335427, 
      14.616713395957786`}, {124.62146646255074`, 21.16033110883442}, {
      151.61690241184533`, -2.552346942169099}}]}, {}}, {}, {}, {{}, {}}, \
{{}, {InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         GraphicsBox[
          TagBox[RasterBox[CompressedData["
1:eJyNmHdU0+f+xwWUHZKQvTcQEvZeMgVBZO+dhLAJe8gUww4JSUjIAMKerntr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            "], {{0, 40}, {
            53, 0}}, {0, 255},
            ColorFunction->RGBColor],
           BoxForm`ImageTag[
           "Byte", ColorSpace -> "RGB", ImageResolution -> {96, 96}, 
            Interleaving -> True, Magnification -> Automatic],
           Selectable->False],
          DefaultBaseStyle->"ImageGraphics",
          ImageSize->{30, 
            Rational[1200, 53]},
          ImageSizeRaw->{53, 40},
          PlotRange->{{0, 53}, {0, 40}}],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {-48.8332943145472, -33.50465550012418}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         GraphicsBox[
          TagBox[RasterBox[CompressedData["
1:eJytlgdMW9max592pd0n7a600kqrp/d2NJMyCZlMJpkUkkAgEELv3WCDbcBg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            "], {{0, 40}, {53, 0}}, {0, 
            255},
            ColorFunction->RGBColor],
           BoxForm`ImageTag[
           "Byte", ColorSpace -> "RGB", ImageResolution -> {96, 96}, 
            Interleaving -> True, Magnification -> Automatic],
           Selectable->False],
          DefaultBaseStyle->"ImageGraphics",
          ImageSize->{30, 
            Rational[1200, 53]},
          ImageSizeRaw->{53, 40},
          PlotRange->{{0, 53}, {0, 40}}],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {-82.85793475114673, -57.58938559958467}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         GraphicsBox[
          TagBox[RasterBox[CompressedData["
1:eJw9lwdQm1m256d2a7fmvelgu22SyEkIgQKSiCKKIDIiI6ISkhCSUBYoIyFA
QgGRM9iAySYYY5OxDdhknNvZHneY7md3u3dev+7XM92rqdraqv89db9bX9X3
q3P+5373uhHZmeX/409/+hPvz9aQSRBFc7mE6qwz1occFo9OZVHIiSw+hUrh
BhP/p3XRxzpQ1vGvuX0owikiAJAa7JQd5pmJ8kzz88R6AWMAYIw9ON7RFnXu
HPwzr2hATCEynRoGinX0SbwAz7f3zznvkfwX9+T/Dc+38Y5wcESc9Utz8ktz
84m3ytU/0c0318k9FQBJ9sxWxms2+OSBDM88GzukgxPEBhh2Boyx9cUA4tnQ
FEmgL9bVHmRrD7NBUwMz1ck+Ke7AJGd4rkcYyT2c7OIcGeQchbRPRjlmBHhl
wiDZYP9kV1iSh1ckwD3KEUODxDD83BLOARPsovGwTFY4hgLyLzkDLj4Hzvui
uAGSrQBd8P03t1A7YKqbX5qXH9YDlgaC4VwhhfYQhq1H/tlkJZo2iE9pQmCM
Hn4kG+/QLyDos8DQ8+AE50QhKlGCAmNd7YA2LsGAbE0qrb80ihEMKQB6pjkG
l3jnygOdI4Kco1H2iSiHBJgrFuSMdnIOPBtdCIku9gNinePYcPUCjdKaFUb2
90g6F850QtDPBVSeCWDYoyvdJi9x96cM+bQQd+znaAIYhfcHJbh7x7sCY12B
GIB/uU1wrQOS43Um4qxfiYv4dlHppRjPpE/hyTYInIc/zi1VFhYvRvineLgi
nIBxHlhJdLYhKYruj8h388LapXGRFeZk1wCYYzDEMRIKzYZGEsFheD/vGBtg
pB0k1tE57AwA+xmlJblmmhjHA2PYTrGSCwju+SiZZ1K9P7MpZN7MvNUmu3nV
GM3ySOFCEAW+wGRgEgsLL/B3CgF4ZjoECgDhYu8QJiJGHNb1TsffKMSpAyPK
XMndabn6yHgJNKEamcCNSK6KjaYGh5TDg2h+YTRwTIV3LM1XMlgi7M90g3g5
gT0doZ6wNPdYKjC+wj+GAiSr0snSbDe0rVvseaIxprAZHc52TFG4orkXYFQ7
BA2QZkSZLpautYjWLNyTS3UdvaXxMnBQCcg7w6tUl11qSEvgosOZgVDWhbQW
1NBR/ciUqG+KhmlwSNBBgFgbTBWcOIDFqiFp6sB0ZXSCJCRTER1NQwKizqPL
kOz2IuGlfNUcgWqJcYY7Ofo724Oc3EPsAnDOIcVANNGNbUnjWHIDs73RBfAi
TRKaAQTn2PjiAc6p51ySzvqXnI/XhLV1CafqKpc7RFs9ktOrDbnVMNf0L4AZ
7vAij2JtQmVvPnu4IN0YLjBhb0/WHg7Vr/QK0PILYPkZR8x5IM4ptSkoRgkp
bI/nThGLBlJIXWnZMox/his00zmyPKC0KaHcjMWW+7rAbR0hdo4QByekg0uY
vUesbSIDUqwMzZWhI8qA0ExHSJ6jX5a1Nc45hZy3Df6zS+KfQUV/cc7+vF5O
uigtX+5UrXbJD0brxvo5yURQYI5LCMktluUPKwJ6pHyh0OfsjikfjDU/n+0+
mmrIMwb5qc67Zp4NqfJJM6MKW2JLupK4C2WmB8qatQp8GyZFCQ0je4aTQUV1
kQWKSGS66//HAyBtHILsHILtEmnBFYYUkiYWx4D742yBmdadxBaSYeU/4xr3
777kT31J/x5EcOpp5naJydNmyZSev94m+P5W5/0p2fogd2uO22pJq2RHKkUZ
+4OyB8NNzxe6n02an91oVa+yECp331LbMLGXtcrknni8JRSj9LESWu7JSzti
ozkeaLJnujigpD46oRISSfR1Rtg5Qu0AfvYAmL0j0tEeBQCEXYgh++I48KRy
UBQJmC4MCy5yQeQAPNNsAdhPvHM/8S78X4zmuLVJk4VT2lCRdb1NstNbfdDP
eTwqeDWpeDut/P6q5um4/NWc9u6g7N5Ex9vF3vsDqpPFFvkSNbMLDaEAwOX2
oSKPmDrP+FpXGO1cGA9EH8zJqUcncMBJfGiGBJopRSRzA9JFIU6of4EBfO3t
Qfb2EHsnlIMt5Kyd76f+sfYhBW7oAg+CIi6DGeQa/plL/Dnb8E88MJ9Aiz+h
msLXR/SqokQdLbmvJm9KXbJipiw0FO0PcE4H2QfdjINe9uGg8Gikbn/YfGpN
4IhpolvulvWXGC0YSfcCF9nHStwipPbJCu9YoW8kGxLJhURywFgRPK4KFM30
iueAE/mwLNn/w3O04vna2/jb2kIvXPA5c9bl0y+8PvWJBgTjPDPowQXceGiC
u1Pop67RNl5JX8QKXIu1AZdNvEFpmakqsV2QvNTC3OkTr1gYi01l682kvQ7a
bkfFVmvFyWj9Zrf2irLi0bjZ1FNpdR2EZxcj8vTLOB/Fd4lXuiRV+2EF0HC6
DxzvFE73ThD7FWhReeqg3Fp0cROGYE5wRP6rKez9bQEQO2eEzQVfW3uIjRP0
MwfwvznDzgVg3TLoURg8Eh4LcAB/bgf9zCnkcw/sGTw/aNwimrfwpvTlS12i
xVbunKFyf1izYiIdDde8mG/c6+Mu6ghb7eyN9ppBbtGzzX5RWwmE6ATm2KQq
XIMotgEMW4zIM4TijSpxiaB6RVd4pkv8C3UhrL4wVndUqSmB2pXCG8m1g9lY
LWcLtfXHOITiXD1CbKFYB1SyjV/kJ/DYL5ApDtn8KF5rcUSRKyrTKbzMMZzo
BMtwJvGjBxvo3XzcpI5hUHAjgoL4hLzjKfO9y9Xv98buThhvDigeTmh2uysP
hmq2u2XPb1/GlaODiB5Q9oUMmTOaZwdh2gYzACHlLpF0jyiKc6YUlCmBEHVx
pfWwLLFLMMk7kR8SXxUQV4b0CHd0CbJLIrvjKt2jiz1SmH6xZW6huDOZFYBU
micyxZHVmFlaG8Y0YSgGOE7ijFcE8RsTmkSZehp2qV3Q2ygMCQ6p5jCPr5i+
2+786vBGaV4WPidjZ1h3eon/dLb2/W7PyVpnKQOdKwmJ5DgRm7wrB6LiJXCc
HJqjBCXzXNK5XlkSQIbAn6BJYprgRPW5VB6Q0pBO16ex61NiS0GQRJsiiVuR
xDmB5FgghLN1SUVCBK0OlsvzyKT5MdVZ5XWR1MYQqgFKrkeJujOUrbim6uz2
GnyXKON6e9XGsGZcz9weknx7s3d/uqcIl06nVzxeHd5qJu30sj4eDX19t9ti
xgm60vh9iZwW2KUnvKa1CtUIltsekMI5y2kJE/VEsJujWIakmn5U3TRI1Ifk
tcaKOpOJNYHZXK9cgQ9F40Ot88tiu5TJQJL21LoBgqQDS6v3Y+uCWDoMtyWq
ROVbpvbmtIRLBmMlbal6WaGMFCMhRjZVpe1P6qa01Dkd6263+PGY4tvbQydX
dPcm5Qd9nN1+/n89ufLxVtvJNHd0nDZ5V22YyGzbwXdslzdOpckGg+kGX6IW
KGgPkfdjlP1ZtaOxdTMBjbPhqmGMZCC8qiGRooHR9BBWUyC9LpimQTH1gSxD
ANccUalDVJlQVU2BNZ0xbDOaoYfTG/zJtcAKox/PEt3cRFRXpskqM/qM4oe3
r56sTDcyCrYHNe9Pr//9zcF2D3ezlXIyIn2+ZP716fyHdePf5qXbY7T2yULL
TJFiFC3sD5QPB9RNIap7w5nNULYRwm+G8I0YaT9GdgmunQ6WX4ySDgULjWli
SzLfFF1lCOY0YRU9cRQNnKEPJSp98mqcswROOC6AovXjGWMpGg9aA7CiHsI2
ggSW4PYuZqeuSsrDm3T88eHmix1NZjlnqrPh0Z31n9+/frk7tdkrWG2j/nQy
+fHOyLtZzQ/LDa/nRUN9OFELVjWUXl7vUWnybJwKVw0kV5mseYAK2yHK3rTq
tmhBl3fDTGTdWHx1XzBFgRCbccquwlKZa4kEyjEiKpogRDWUooQQ5AF5Ancs
/Xy+EMzURtC0YGKtK7MJUWH2rmgEN5nwLVpOh6nGrBNqFBUNisqRdvXCsOXl
/Vu/fnz9/fOdx2v9350s/PPtnddXdC/GxR/XjP9xXXt9mCw2Yml1sRSdU4XZ
ntvqK+6Esk3+NZ0RgjZETWes2IKh6px43e6cdlilCcrRYdnaZK4uvVwDJddC
iHI4TRtSqvAhSb0rNfF0NTKF4UCQoSvUUXxzFNsE4phR8u7kxvY8s7bUqGC2
6Wsseom+jttpEk8P1T/au/rj3x7+5w8vf/vxxX99ffT7h8c/Pbj6dIz/Zlr0
07rpl63Wg2mepjWrRIbKEjsWqu2IGkd6g1uJ9VuNCJbRj2NCyjqSyutAxUon
SqMXWQtmqaOEDfk0aRxVFcYw+hDrQBRFWLkCjucBCFIkQx9CVMDyeZ41zQW6
ixVsI5xah+Ab4syt+A4tVScmNdeL2gyqXkvd/FjvyuzAweb08/tb798cfnh2
89XuxIfT+Y97Q69nar6arvm4bvxjv//lSr2kDlMk9sWLQYXVPgU8r2yWB6kO
Rmv0xFd/ztR7M3XhHHMwSeHPa7LmM5ogc6/QhFOkaFoNhqGOZBtDpB1ZFGlg
OtmxhIcslQQUiXwLhSC+IUnckk5UeVUZkcwGVENT2qCZ29ckGmyrG+4xLU4O
HN2+/uBg/euXhz++Pf7m3vXHy91Pl5q/3uj+drX5w7r+63nVh/Xm34+Hfz4c
aLbkUOQRPdZfnTI8jQHIsO4VSmeCHFgmBZWrgYUif7o6iqH3JyjgXHNomdQP
x7bL5/kqLMUUGZrdGM/Qhqs6c1i10ZkUH5oyslDogxf40tVh9f1ERl1IhQ4k
akM3NFsbln3JVDPeZ1iYGtzbvPr4YPPB4dbzB7e+frB6f6nt4VzDs3nt2yXD
uyXdD5umN9PKv90w/OP08u8PpubGeKlUj8F5df+crEIVUsLzoYkhVdpoVn10
LhPOqk9nNUYSlCC83INlBBbSI0p4gTGFAKIClcsFEaRBLG2CojO/2pJWIoaU
VIOJCu8yCdjaQXJLoqgpmaGNELWm1XcVd5tZ3UrGSLtmbqrvYOvaw/2N493r
x5uTp0vdhzMN92brni01vltr+W6j9dsV46tJ+U+bzb88GP/lZPLqiLBcHYhj
+OgG+f1zSqEuqpjjxVbHVSjDuJoskihRYMggSJBFcm+a1i+fhmKrM0pF4cUC
/0K+S36VD1UZnsfxLpdHkaRhpdVwvjmUb0ZnMl2Jci+iBFjKgTIkUezahJY2
ZqeG3tXIH+7V767N3b+7dry9uLvYtzao3BlRPVk0vVtv++ZW33/s9H+12vxi
VvnL0cV/vFz559O55TGJpqeMKAlKJAAVbSRNT1GxyJeuDKRKkVwtlqVNYjXE
EqXIIjGkWOBVqQwlCqJI4qg8JqhcDiJYF4VwgSmVUB2cxXQiSvxKJWC2Dk2o
gZFUUKrahyTyo/LRZEmguiXPqCIZaoij3Y23lqdPdq8/vnvt9oxlvV+yP6F9
fM387JrpxXLbq5XWJ7PaR1cUPz+c+v3bnX++WDxaNRsGWYZRCrMeXakJq9RE
5rDAZBmY24jl1CeUKwPkXbkSc3q5HEWUevEbItgKHCbbLYMEtvYCszYOz4XT
VKE0RThBEEwSwwsF8NJqFF0RQlFEUBQwuhLGVsYRa/xpSphRR26tpc0MGbau
Xz7cmHx0e2J3xrw5KNsd15zON92fa3h01Xh/Rrvbxz25LPnl1Y3ffzj47e3a
8U67rCWbUBOWx0YSRWiKIECoDKDJYSIj3mrvKj3CMMzuviyrUCLLpL4UcbBl
QFZQCcuhQegSLL8umylPoUoRFfJQSnV4uRTB0MQX8cPI1WFWcoYstrACTGQh
KdXQwip7gymnxyic6q+/cdm8M9d+uNB2Z6ppY0i1MaI5mDVYCQ8mNMcTtds9
7Gdz6t++2f79t9f/+OHo6oyS15iIYwCLBCiGEstRYvgyJEnoXi73zGe60ur8
BQ3RDGlSpTSyQhGWQ/MR1pWSREEFHF+iCEOpjuaqcAUcEKsBkcfyKmD7E6XB
xWIkSRpUyPSjCCP4mkxMlkMBzatMDOKr0I3y4o5G/nSv6s7VzuMbfcc3+k9W
hg5XBhcHajcvqe/N6vdHFSst9Eez9b++3fz911e//fRAb8pPo4KIohi6NLqE
50uRIKLz7PFsQD7LIYnggSkG5DNcCxheuXQPXmNIiSighBdTzA/LYDhls12L
uSGpJX7ReW48XYLxIolThy1iBpQwA6nCyIa20gppNFOdmlMBonCDshnwUi5K
wscq2XkDRsnmbP/e6tjhxsTzoxuHN6e7GtjD9fT1HuHNXt7hcM2b9a5fny3/
/n8ePzqZrRSFlAhhORXgbBIol+ZRwPbJZXhVKBDFXBS2BBRf4JVQ4JxJdi7g
2hPEXgQujMCKySRCkinOqVS7YhEykeAeme5VRIut1uZQrGXlB9Krg8qFgTJ9
htScKGiKr1RGkXmovErfQiZUJMgQlcXW84ssWsFYv+HmteHd1YnF8e5GUVmX
rGBWT7BekTZay7/a6vn5y6U/fn3Z3sbPKHJlyGB0FSq1yBudeiGu0BbPdWXU
Q+TtyWU8cHIhIC7PNaHsAkF2Hs9zLKRBcUXgVLxPQqF7ATMgqdQtJv+LhAKv
TGIoJgvEkRQQq4LIXE+OCkkWQbia6M6Jqip5BFsaVCr0LWbDJJKcBnZ2PTPV
IC5sUVdODRjGenTNGp6Ojx9S4uf1pTudtJcL2g+H4//91513z2/lExBZJd7x
2c55VR6JpYCw+DPJOLu8UpeUUls8y03SiNBaEmqaEot5/oUVXuSKgMxSVFii
Y1SaS2SqEwbnmpIPySYgEnKcY7KAfmF2ZA4uuywgBecglGUQ+eFsFbZKjaXV
+PMUkYLGVKIAVcmPalbhu6Q5s83UK608BSNXXlWiEhA7laReEW5BX7LVRnm9
Ynl/MvPH+4dri4P1jcRaNb5eW9nZJbwyq58cbRofqr863To72bw013735tjx
3tzD0xsPTlfuHd148/huJsEnPBkAQ58Nj3P2R52FBJ2DBtuEYgAR8d5RyWBh
IyEx16+cHlbJS6BWYiSynNr6QnVjrllPbW3mGc1MfWNlu4berypZbmccjmu0
zCxGcXKXQdKhIo9ry9ZaqUej1T/en/355eaPb/e3lkb2Vsef7F17frR6emvh
0e7Sy3ubz07W//pk+7tnB9aT2OnejdOD9QcHK28e3nx1f+vLo5XsAmAxFYVJ
dcrPh6elQHKzQwsKIsjkxCadqLdTNzPeNtqnX5zoXJnvuzbROdii7tRL2/XS
AYumScnts2jH+lpaNTyLqGCpmXFnuLpFgmeXZakElFYJftJQvtXLer6o/fX9
g99++fjd168nBy0zg6blyd6dlfGdjcm9W1ce7l873Jx8dHfx+cnqvd35/a3J
uxtT1mPP06OVV/dvvnpwKy0FkJsFqWJkWnSC3lbN+IB5frR1atDYbVY119cs
DLcuT/WM9+rHe/TWONSq7m9W9rco+1uVrTrxlZGu2dFuYy13QF8128xe66gc
baTmZ8TmpUa2iXNH1TnLFtLf9i79/cOz54+P//jjjzsb88MdWqs5p4fMN6+P
3l4e21ke21wY3L4+cm97/unh8tsHN797cffbp7vfWPV87/s3x/lFCFwazKjh
XmpvmL7YvDTVc+PKwNRFS59FPdBSO9pWOzNguDHdOz/ScuVi8+wly3ifvqOp
xlBbZakXtjTKhJVlUxdbX5+u7s213hrWjDRxSHkx1Yy8iTbxnaWu10dLf//+
6Xd/vb92ZfDj+3cvH93dnB+aHjRdG+vYW5ncW5nYmBuwsm3OD+4uX76/s/D8
eO3LgxsvT9dfnK5bi/7V0ztpuUgeK39lqm9jfmhz4eLW4qWVK70zF03Xxttv
Ll68vTRsjVtXh+aHLVMDTWM9Db0mqUXLMyiZOnmlXFjOIGdPX2z77svDb+6v
ff90e7xHFxvkZazl7CxPvHm088d/v7cm7cmjg36z/P7OtdPb80frE7vXLu1Y
Tbg2tTLdtzjW/vx4/d72Vase3b2+vzHz5GD1y8M168uv79+0KiHdj4CPG21r
mBkyWzV3yTI/YlmZ6dlcGFgca5sbscwMGacHDZe7661swx2awRalNU706boM
NZ0GSY9J2qKrnrhkubM2sTzdw6fl4eKQKgF5uLPx7trUty+Ofvzw1Ztnx3dW
Jt493nl+tPbozvUv95efHa5ZrfX0cPXNg1svTjae7C/f31k8vb1wtDV7d216
+8b46qy14pcPN69AAs+z6FmTvVYGk7V8c8OWueHmhdEWK5JV1rkVz8q5NNFh
NcmdlTFrJlev9F693Hp3dWx1pnP+kmlvY3Treu/alfaJ3vp+i9K69U30NY31
Nc0Ntz64ffXJ8epP33z5n98++fju3rvHu89Ot56dWD2//fJ089nRupXtYGPG
inF8c253eWJ/feb09uLuyuTWtZHT7at769P/F0ajS2Q=
            "], {{0, 40}, {53, 
            0}}, {0, 255},
            ColorFunction->RGBColor],
           BoxForm`ImageTag[
           "Byte", ColorSpace -> "RGB", ImageResolution -> {96, 96}, 
            Interleaving -> True, Magnification -> Automatic],
           Selectable->False],
          DefaultBaseStyle->"ImageGraphics",
          ImageSize->{30, 
            Rational[1200, 53]},
          ImageSizeRaw->{53, 40},
          PlotRange->{{0, 53}, {0, 40}}],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {-61.17437387304301, -54.251762852463614}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         GraphicsBox[
          TagBox[RasterBox[CompressedData["
1:eJyNlwlQYmmW793SDdm3C/eyCIi4goqgIogKIqKigLigoqi4Iu4r7vu+oum+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            "], {{0, 40}, {64, 0}}, {
            0, 255},
            ColorFunction->RGBColor],
           BoxForm`ImageTag[
           "Byte", ColorSpace -> "RGB", ImageResolution -> {96, 96}, 
            Interleaving -> True, Magnification -> Automatic],
           Selectable->False],
          DefaultBaseStyle->"ImageGraphics",
          ImageSize->{30, 
            Rational[75, 4]},
          ImageSizeRaw->{64, 40},
          PlotRange->{{0, 64}, {0, 40}}],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {-65.42723984219596, -73.55880391714472}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         GraphicsBox[
          TagBox[RasterBox[CompressedData["
1:eJxNVwVQW+vWrdut0lLXW6N621tX6u5eKhSKFErR4u7u7gGSQNzdgxUobsXd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            "], {{0, 40}, {64, 0}}, {0, 255},
            ColorFunction->RGBColor],
           BoxForm`ImageTag[
           "Byte", ColorSpace -> "RGB", ImageResolution -> {96, 96}, 
            Interleaving -> True, Magnification -> Automatic],
           Selectable->False],
          DefaultBaseStyle->"ImageGraphics",
          ImageSize->{30, 
            Rational[75, 4]},
          ImageSizeRaw->{64, 40},
          PlotRange->{{0, 64}, {0, 40}}],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {-81.4217590184258, -92.18039139831386}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         GraphicsBox[
          TagBox[RasterBox[CompressedData["
1:eJytmXdUnOeVxiWQ7WDZsWJHkXQcSxai92EaM8wwvcIUpvfKFMrA0IYqECB6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            "], {{0, 40}, {53, 0}}, {0, 255},
            ColorFunction->RGBColor],
           BoxForm`ImageTag[
           "Byte", ColorSpace -> "RGB", ImageResolution -> {96, 96}, 
            Interleaving -> True, Magnification -> Automatic],
           Selectable->False],
          DefaultBaseStyle->"ImageGraphics",
          ImageSize->{30, 
            Rational[1200, 53]},
          ImageSizeRaw->{53, 40},
          PlotRange->{{0, 53}, {0, 40}}],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {-39.888497411758024, -54.45289180627676}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         GraphicsBox[
          TagBox[RasterBox[CompressedData["
1:eJztl3dc0+e+xyPZzEBCyF7skQAh7B0QUVnqwb0LKiioOEBre0urOFtbqdZq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            "], {{0, 40}, {68, 0}}, {0, 
            255},
            ColorFunction->RGBColor],
           BoxForm`ImageTag[
           "Byte", ColorSpace -> "RGB", ImageResolution -> {96, 96}, 
            Interleaving -> True, Magnification -> Automatic],
           Selectable->False],
          DefaultBaseStyle->"ImageGraphics",
          ImageSize->{30, 
            Rational[300, 17]},
          ImageSizeRaw->{68, 40},
          PlotRange->{{0, 68}, {0, 40}}],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {-48.585148917150306, 58.39154294516718}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         GraphicsBox[
          TagBox[RasterBox[CompressedData["
1:eJyN2AdQU/m+B/B9++7u6kpR6UhJ6L0KUkIPvfcSOgGSQAghISEJkNBCLyII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            "], {{0, 40}, {53, 0}}, {0, 255},
            ColorFunction->RGBColor],
           BoxForm`ImageTag[
           "Byte", ColorSpace -> "RGB", ImageResolution -> {96, 96}, 
            Interleaving -> True, Magnification -> Automatic],
           Selectable->False],
          DefaultBaseStyle->"ImageGraphics",
          ImageSize->{30, 
            Rational[1200, 53]},
          ImageSizeRaw->{53, 40},
          PlotRange->{{0, 53}, {0, 40}}],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {-7.894295715041444, 63.041134968444865}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         GraphicsBox[
          TagBox[RasterBox[CompressedData["
1:eJx1mAVYldm6+JUN7O7uYicbEJAQRNpBUCkDMcYWlJA2ZzAIEdx0t3R3C1KK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            "], {{0, 40}, {64, 0}}, {0, 255},
            ColorFunction->RGBColor],
           BoxForm`ImageTag[
           "Byte", ColorSpace -> "RGB", ImageResolution -> {96, 96}, 
            Interleaving -> True, Magnification -> Automatic],
           Selectable->False],
          DefaultBaseStyle->"ImageGraphics",
          ImageSize->{30, 
            Rational[75, 4]},
          ImageSizeRaw->{64, 40},
          PlotRange->{{0, 64}, {0, 40}}],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {-34.23335177916469, 74.90242332370299}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         GraphicsBox[
          TagBox[RasterBox[CompressedData["
1:eJzt2HlUU9e6APAzZiCAqBAGCRAmW5FJJiEKJIQwhEkGZaxoy6QIAhImGWSe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            "], {{0, 
            40}, {53, 0}}, {0, 255},
            ColorFunction->RGBColor],
           BoxForm`ImageTag[
           "Byte", ColorSpace -> "RGB", ImageResolution -> {96, 96}, 
            Interleaving -> True, Magnification -> Automatic],
           Selectable->False],
          DefaultBaseStyle->"ImageGraphics",
          ImageSize->{30, 
            Rational[1200, 53]},
          ImageSizeRaw->{53, 40},
          PlotRange->{{0, 53}, {0, 40}}],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {-25.43510036386343, 55.04473645333421}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         GraphicsBox[
          TagBox[RasterBox[CompressedData["
1:eJx9mAdYk1cb9wPZm4QMRgh7740IskRBENlDZO8heyQkrAAJIYwQwhYQcY/a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            "], {{0, 40}, {71, 0}}, {0, 255},
            ColorFunction->RGBColor],
           BoxForm`ImageTag[
           "Byte", ColorSpace -> "RGB", ImageResolution -> {96, 96}, 
            Interleaving -> True, Magnification -> Automatic],
           Selectable->False],
          DefaultBaseStyle->"ImageGraphics",
          ImageSize->{30, 
            Rational[1200, 71]},
          ImageSizeRaw->{71, 40},
          PlotRange->{{0, 71}, {0, 40}}],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {-51.23861591860722, 85.86755585010356}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         GraphicsBox[
          TagBox[RasterBox[CompressedData["
1:eJzNWEmT28YVViWXHPMXcstPyDXHXJ3KD7ArisuHKGUpVYnLPrlKTpyTk1LF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            "], {{0, 40}, {40, 0}}, {0, 255},
            ColorFunction->RGBColor],
           BoxForm`ImageTag[
           "Byte", ColorSpace -> "RGB", ImageResolution -> {96, 96}, 
            Interleaving -> True, Magnification -> Automatic],
           Selectable->False],
          DefaultBaseStyle->"ImageGraphics",
          ImageSize->{30, 30},
          ImageSizeRaw->{40, 40},
          PlotRange->{{0, 40}, {0, 40}}],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {129.37961899700517, -4.934200029468172}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         GraphicsBox[
          TagBox[RasterBox[CompressedData["
1:eJy9mGlQU1cUgGnrD8dpx9biwk72FbJhgCQgirIKyr6IGlBAGwtIEIoLjqDi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            "], {{0, 40}, {40, 
            0}}, {0, 255},
            ColorFunction->RGBColor],
           BoxForm`ImageTag[
           "Byte", ColorSpace -> "RGB", ImageResolution -> {96, 96}, 
            Interleaving -> True, Magnification -> Automatic],
           Selectable->False],
          DefaultBaseStyle->"ImageGraphics",
          ImageSize->{30, 30},
          ImageSizeRaw->{40, 40},
          PlotRange->{{0, 40}, {0, 40}}],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {141.3716240335427, 14.616713395957786}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         GraphicsBox[
          TagBox[RasterBox[CompressedData["
1:eJzdl3lQE1ccx532n/7Z6b9t/7BOO20dHQ9U2g6CShF0FDxQDgHFQkQREImA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            "], {{0, 
            40}, {40, 0}}, {0, 255},
            ColorFunction->RGBColor],
           BoxForm`ImageTag[
           "Byte", ColorSpace -> "RGB", ImageResolution -> {96, 96}, 
            Interleaving -> True, Magnification -> Automatic],
           Selectable->False],
          DefaultBaseStyle->"ImageGraphics",
          ImageSize->{30, 30},
          ImageSizeRaw->{40, 40},
          PlotRange->{{0, 40}, {0, 40}}],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {124.62146646255074, 21.16033110883442}, {0, 0}], 
     InsetBox[
      PaneBox[
       FrameBox[
        StyleBox[
         GraphicsBox[
          TagBox[RasterBox[CompressedData["
1:eJytmFlTG9kVx13JSx7zFfKWb5BUKpWqVGV/yGTsTGaxKw4uOwx2gW2MPWa8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            "], {{0, 40}, {
            40, 0}}, {0, 255},
            ColorFunction->RGBColor],
           BoxForm`ImageTag[
           "Byte", ColorSpace -> "RGB", ImageResolution -> {96, 96}, 
            Interleaving -> True, Magnification -> Automatic],
           Selectable->False],
          DefaultBaseStyle->"ImageGraphics",
          ImageSize->{30, 30},
          ImageSizeRaw->{40, 40},
          PlotRange->{{0, 40}, {0, 40}}],
         StripOnInput->False,
         Opacity->1,
         FontOpacity->1,
         $CellContext`LineOpacity -> 1,
         $CellContext`FrontFaceOpacity -> 1,
         $CellContext`BackFaceOpacity -> 1],
        LabelStyle -> {},
        Frame -> True,
        Background->Directive[
          Opacity[0]],
        ContentPadding->False,
        FrameMargins->2,
        FrameStyle->None,
        RoundingRadius->4,
        StripOnInput->False],
       FrameMargins->0], {151.61690241184533, -2.552346942169099}, {0, 0}]}}},
  
  AspectRatio->1,
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  ImageSize->{274.63671875, Automatic},
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->All,
  PlotRangeClipping->False,
  PlotRangePadding->{{
     Scaled[0.05], 
     Scaled[0.05]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellTags->"LastCellOfAPage",
 CellLabel->"Out[25]=",ExpressionUUID->"b943b35d-bd3c-4cc6-b824-2af21a10d7b0"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Vocabulary", "VocabularySection",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"p:126",ExpressionUUID->"131c42fc-a098-4b2c-ac1c-fceab7d2cc6e"],

Cell[BoxData[GridBox[{
   {
    RowBox[{
     ButtonBox["LanguageIdentify",
      BaseStyle->"CodeLink"], "[", 
     StyleBox["text", "CodeVariableLrg"], "]"}], " ", Cell[
    "identify what human language text is in ", "VocabularyText",
     ExpressionUUID->"e27db78a-2d0a-408a-80fc-5692e3a3308c"]},
   {
    RowBox[{
     ButtonBox["ImageIdentify",
      BaseStyle->"CodeLink"], "[", 
     StyleBox["image", "CodeVariableLrg"], "]"}], " ", Cell[
    "identify what an image is of ", "VocabularyText",ExpressionUUID->
     "63b4c5f8-1be4-43e3-9ea4-330f0f230929"]},
   {
    RowBox[{
     ButtonBox["TextRecognize",
      BaseStyle->"CodeLink"], "[", 
     StyleBox["text", "CodeVariableLrg"], "]"}], " ", Cell[
    "recognize text from an image (OCR) ", "VocabularyText",ExpressionUUID->
     "67552656-0687-4db2-ae5b-4d0b3b0ffc34"]},
   {
    RowBox[{
     ButtonBox["Classify",
      BaseStyle->"CodeLink"], "[", 
     RowBox[{
      StyleBox["training", "CodeVariableLrg"], ",", 
      StyleBox["data", "CodeVariableLrg"]}], "]"}], " ", Cell[
    "classify data on the basis of training examples ", "VocabularyText",
     ExpressionUUID->"3a3d6a65-8fd1-4f30-a502-6a2d5e8be41a"]},
   {
    RowBox[{
     ButtonBox["Nearest",
      BaseStyle->"CodeLink"], "[", 
     RowBox[{
      StyleBox["list", "CodeVariableLrg"], ",", 
      StyleBox["item", "CodeVariableLrg"]}], "]"}], " ", Cell[TextData[{
     "find what element of ",
     Cell[BoxData[
      StyleBox["list", "CodeVariable"]], "InlineCode",ExpressionUUID->
      "86a28470-21de-4589-a717-4b723dc497bb"],
     " is nearest to ",
     Cell[BoxData[
      StyleBox["item", "CodeVariable"]], "InlineCode",ExpressionUUID->
      "41387ec3-f6e1-47d7-a81b-a7a19dd02df7"],
     " "
    }], "VocabularyText",ExpressionUUID->
     "50ad0d04-2ac2-4a86-9c77-8dadb9c8a532"]},
   {
    RowBox[{
     ButtonBox["FindClusters",
      BaseStyle->"CodeLink"], "[", 
     StyleBox["list", "CodeVariableLrg"], "]"}], " ", Cell[
    "find clusters of similar items ", "VocabularyText",ExpressionUUID->
     "dc86213e-e909-44eb-86ed-a13374d22e5d"]},
   {
    RowBox[{
     ButtonBox["NearestNeighborGraph",
      BaseStyle->"CodeLink"], "[", 
     RowBox[{
      StyleBox["list", "CodeVariableLrg"], ",", 
      StyleBox["n", "CodeVariableLrg"]}], "]"}], " ", Cell[TextData[{
     "connect elements of ",
     Cell[BoxData[
      StyleBox["list", "CodeVariable"]], "InlineCode",ExpressionUUID->
      "f97430cb-1e93-47a6-9545-b6d0f2b173be"],
     " to their ",
     Cell[BoxData[
      StyleBox["n", "CodeVariable"]], "InlineCode",ExpressionUUID->
      "e09e0635-1bdf-442d-9a72-ec3a21bfff02"],
     " nearest neighbors "
    }], "VocabularyText",ExpressionUUID->
     "d360e2db-4fec-4c7e-8044-79f0e88a72bd"]},
   {
    RowBox[{
     ButtonBox["Dendrogram",
      BaseStyle->"CodeLink"], "[", 
     StyleBox["list", "CodeVariableLrg"], "]"}], " ", Cell[
    "make a hierarchical tree of relations between items", "VocabularyText",
     ExpressionUUID->"f3c65144-0eba-4133-a307-b8842f1d0bd4"]},
   {
    RowBox[{
     ButtonBox["FeatureSpacePlot",
      BaseStyle->"CodeLink"], "[", 
     StyleBox["list", "CodeVariableLrg"], "]"}], " ", Cell[TextData[{
     "plot elements of ",
     StyleBox["list",
      FontSlant->"Italic"],
     " in an inferred \[OpenCurlyDoubleQuote]feature space\
\[CloseCurlyDoubleQuote] "
    }], "VocabularyText",ExpressionUUID->
     "e14f497d-c2a6-4956-8ad1-22694ebe7da8"]}
  }]], "VocabularyTable",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 GridBoxOptions->{
 GridBoxDividers->{
  "Columns" -> {{
     False}}}},ExpressionUUID->"d0bad373-73cc-49c7-9807-23e082b7ee6b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 DynamicModuleBox[{$CellContext`open$$ = False}, 
  TagBox[GridBox[{
     {
      StyleBox["\<\"Exercises\"\>",
       StripOnInput->False,
       FontSlant->"Italic"], 
      PaneBox[
       TagBox[
        ButtonBox[
         DynamicBox[ToBoxes[
           If[$CellContext`open$$, 
            Row[{
              Style["-", "ExercisePreviewButtonTextHighlight"], 
              Style[" Preview Exercises", "ExercisePreviewButtonText"]}], 
            Row[{
              Style["+", "ExercisePreviewButtonTextHighlight"], 
              Style[" Preview Exercises", "ExercisePreviewButtonText"]}]], 
           StandardForm],
          ImageSizeCache->{115., {1., 10.}}],
         Appearance->None,
         ButtonFunction:>(
          If[$CellContext`open$$, $CellContext`open$$ = 
            False, $CellContext`open$$ = True]; NotebookFind[
            EvaluationNotebook[], "ExerciseSummaryCell", Next, CellStyle, 
            WrapAround -> True, AutoScroll -> False]; FrontEndTokenExecute[
            EvaluationNotebook[], "ExpandSelection"]; FrontEndExecute[
            FrontEndToken[
             EvaluationNotebook[], "OpenCloseGroup"]]),
         Evaluator->Automatic,
         Method->"Preemptive"],
        MouseAppearanceTag["LinkHand"]],
       Alignment->Right,
       ImageSize->Full]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {Left, Right}, "Rows" -> {{Center}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"],
  DynamicModuleValues:>{}]], "ExerciseSection",
 Editable->False,
 ShowCellBracket->False,
 GeneratedCell->True,
 CellAutoOverwrite->True,
 CellChangeTimes->{3.669991951589675*^9},
 ShowStringCharacters->
  False,ExpressionUUID->"c98854ab-51db-4961-8037-03152812aaca"],

Cell[CellGroupData[{

Cell[BoxData[
 TagBox[GridBox[{
    {
     TagBox[GridBox[{
        {
         PaneBox[
          
          StyleBox["\<\"16 Exercises Available\"\>", "ExerciseSummaryHeading",
           
           StripOnInput->False],
          ImageMargins->{{20, 0}, {0, 10}}]},
        {
         PaneBox[
          StyleBox["\<\"with 7 extras\"\>", "ExerciseSummarySubheading",
           StripOnInput->False],
          ImageMargins->{{20, 0}, {10, 0}}]}
       },
       DefaultBaseStyle->"Column",
       GridBoxAlignment->{"Columns" -> {{Left}}},
       GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
       
       GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{0}}}],
      "Column"], 
     PaneBox[
      ButtonBox[
       StyleBox["\<\"Get Started \[RightGuillemet]\"\>", 
        "ExerciseSummaryHeading",
        StripOnInput->False],
       Appearance->None,
       ButtonFunction:>
        NotebookLocate[{"EIWL2-22-machine-learning-exercises.nb", ""}],
       Evaluator->Automatic,
       Method->"Preemptive"],
      FrameMargins->{{10, 0}, {10, 10}},
      ImageSize->Full]}
   },
   AutoDelete->False,
   GridBoxAlignment->{"Columns" -> {{Left}}},
   GridBoxItemSize->{"Columns" -> {
       Scaled[0.7], 
       Scaled[0.3]}, "Rows" -> {{Automatic}}}],
  "Grid"]], "ExerciseSummaryCell",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"b8aa3732-2c32-4a23-ae59-afe25d253386"],

Cell[CellGroupData[{

Cell[TextData[{
 "Identify what language the word \[OpenCurlyDoubleQuote]ajatella\
\[CloseCurlyDoubleQuote] comes from.",
 StyleBox[ButtonBox["\[NonBreakingSpace]\[RightGuillemet]",
  Appearance->None,
  Evaluator->Automatic,
  Method->"Preemptive",
  ButtonFunction:>(SelectionMove[
     ButtonNotebook[], All, ButtonCell, AutoScroll -> False]; 
   FrontEndExecute[
     FrontEndToken[
      ButtonNotebook[], "OpenCloseGroup"]])],
  FontColor->RGBColor[1, 0.501961, 0]]
}], "Exercise",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellDingbat->Cell[
  "22.1", "ExerciseNumber", FontColor -> 
   RGBColor[0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]],
 ShowCellBracket->
  False,ExpressionUUID->"c483262e-1c68-40ee-b0d6-e6545dc1c981"],

Cell[BoxData[
 PaneBox[GridBox[{
    {" ", 
     StyleBox[
      RowBox[{"Expected", " ", 
       RowBox[{"output", ":"}]}],
      Editable->False,
      Selectable->False,
      StripOnInput->False,
      FontColor->RGBColor[0.45, 0.45, 0.45]], " "},
    {" ", 
     InterpretationBox[Cell[BoxData[
       TemplateBox[{"\"Finnish\"",RowBox[{"Entity", "[", 
           RowBox[{"\"Language\"", ",", "\"Finnish\""}], "]"}],
         "\"Entity[\\\"Language\\\", \\\"Finnish\\\"]\"","\"language\""},
        "Entity"]], "ExerciseOutput",ExpressionUUID->
       "5e1fd64f-8057-4220-88ed-4ec742d31c03"],
      Apply[TextCell, 
       Cell[
        BoxData[
         TemplateBox[{"\"Finnish\"", 
           RowBox[{"Entity", "[", 
             RowBox[{"\"Language\"", ",", "\"Finnish\""}], "]"}], 
           "\"Entity[\\\"Language\\\", \\\"Finnish\\\"]\"", "\"language\""}, 
          "Entity"]], "ExerciseOutput", Selectable -> False, Copyable -> 
        False, Editable -> False, ShowCellBracket -> False]]], " "}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Center}}},
   GridBoxBackground->{"Columns" -> {{
        RGBColor[1, 1, 1]}}},
   GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{1}}}],
  FrameMargins->0]], "ExerciseOutput",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellFrame->{{1, 1}, {1, 1}},
 ShowCellBracket->False,
 CellFrameColor->RGBColor[0.85, 0.85, 0.85],
 LineBreakWithin->
  Automatic,ExpressionUUID->"63c61321-0efc-4a41-a8c0-be0495de3626"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Apply ",
 ButtonBox["ImageIdentify",
  BaseStyle->"Link"],
 " to an image of a tiger, getting the image using ",
 Cell[TextData[Cell[BoxData[
  TemplateBox[{"ctrl","="},
   "Key1"]],ExpressionUUID->"64ae54bd-56d1-4fb1-aa71-67fec70fe3e8"]],
  ExpressionUUID->"050d81f5-f8b5-486a-b5cf-44ba0942e379"],
 ".",
 StyleBox[ButtonBox["\[NonBreakingSpace]\[RightGuillemet]",
  Appearance->None,
  Evaluator->Automatic,
  Method->"Preemptive",
  ButtonFunction:>(SelectionMove[
     ButtonNotebook[], All, ButtonCell, AutoScroll -> False]; 
   FrontEndExecute[
     FrontEndToken[
      ButtonNotebook[], "OpenCloseGroup"]])],
  FontColor->RGBColor[1, 0.501961, 0]]
}], "Exercise",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellDingbat->Cell[
  "22.2", "ExerciseNumber", FontColor -> 
   RGBColor[0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]],
 ShowCellBracket->
  False,ExpressionUUID->"8035c55a-2b29-4398-a7e1-3b307234a023"],

Cell[BoxData[
 PaneBox[GridBox[{
    {" ", 
     StyleBox[
      RowBox[{"Expected", " ", 
       RowBox[{"output", ":"}]}],
      Editable->False,
      Selectable->False,
      StripOnInput->False,
      FontColor->RGBColor[0.45, 0.45, 0.45]], " "},
    {" ", 
     InterpretationBox[Cell[BoxData[
       TemplateBox[{"\"tiger\"",RowBox[{"Entity", "[", 
           RowBox[{"\"Concept\"", ",", "\"PantheraTigris::2mpmq\""}], "]"}],
         "\"Entity[\\\"Concept\\\", \\\"PantheraTigris::2mpmq\\\"]\"",
         "\"concept\""},
        "Entity"]], "ExerciseOutput",ExpressionUUID->
       "1924244a-a7a4-4a2f-aba9-8cbbb1d85e2b"],
      Apply[TextCell, 
       Cell[
        BoxData[
         TemplateBox[{"\"tiger\"", 
           RowBox[{"Entity", "[", 
             RowBox[{"\"Concept\"", ",", "\"PantheraTigris::2mpmq\""}], "]"}],
            "\"Entity[\\\"Concept\\\", \\\"PantheraTigris::2mpmq\\\"]\"", 
           "\"concept\""}, "Entity"]], "ExerciseOutput", Selectable -> False, 
        Copyable -> False, Editable -> False, ShowCellBracket -> False]]], " "}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Center}}},
   GridBoxBackground->{"Columns" -> {{
        RGBColor[1, 1, 1]}}},
   GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{1}}}],
  FrameMargins->0]], "ExerciseOutput",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellFrame->{{1, 1}, {1, 1}},
 ShowCellBracket->False,
 CellFrameColor->RGBColor[0.85, 0.85, 0.85],
 LineBreakWithin->
  Automatic,ExpressionUUID->"22ec36be-c223-4e4d-a174-8327a0cfe71a"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Make a table of image identifications for an image of a tiger, blurred by \
an amount from 1 to 5.",
 StyleBox[ButtonBox["\[NonBreakingSpace]\[RightGuillemet]",
  Appearance->None,
  Evaluator->Automatic,
  Method->"Preemptive",
  ButtonFunction:>(SelectionMove[
     ButtonNotebook[], All, ButtonCell, AutoScroll -> False]; 
   FrontEndExecute[
     FrontEndToken[
      ButtonNotebook[], "OpenCloseGroup"]])],
  FontColor->RGBColor[1, 0.501961, 0]]
}], "Exercise",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellDingbat->Cell[
  "22.3", "ExerciseNumber", FontColor -> 
   RGBColor[0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]],
 ShowCellBracket->
  False,ExpressionUUID->"5785c93a-425e-408b-9100-73146976e125"],

Cell[BoxData[
 PaneBox[GridBox[{
    {" ", 
     StyleBox[
      RowBox[{"Expected", " ", 
       RowBox[{"output", ":"}]}],
      Editable->False,
      Selectable->False,
      StripOnInput->False,
      FontColor->RGBColor[0.45, 0.45, 0.45]], " "},
    {" ", 
     InterpretationBox[Cell[BoxData[
       RowBox[{"{", 
        RowBox[{
         TemplateBox[{"\"tiger\"",RowBox[{"Entity", "[", 
             RowBox[{"\"Concept\"", ",", "\"PantheraTigris::2mpmq\""}], "]"}],
           "\"Entity[\\\"Concept\\\", \\\"PantheraTigris::2mpmq\\\"]\"",
           "\"concept\""},
          "Entity"], ",", 
         TemplateBox[{"\"tiger\"",RowBox[{"Entity", "[", 
             RowBox[{"\"Concept\"", ",", "\"PantheraTigris::2mpmq\""}], "]"}],
           "\"Entity[\\\"Concept\\\", \\\"PantheraTigris::2mpmq\\\"]\"",
           "\"concept\""},
          "Entity"], ",", 
         TemplateBox[{"\"domestic cat\"",RowBox[{"Entity", "[", 
             RowBox[{"\"Concept\"", ",", "\"DomesticCat::jpx55\""}], "]"}],
           "\"Entity[\\\"Concept\\\", \\\"DomesticCat::jpx55\\\"]\"",
           "\"concept\""},
          "Entity"], ",", 
         TemplateBox[{"\"domestic cat\"",RowBox[{"Entity", "[", 
             RowBox[{"\"Concept\"", ",", "\"DomesticCat::jpx55\""}], "]"}],
           "\"Entity[\\\"Concept\\\", \\\"DomesticCat::jpx55\\\"]\"",
           "\"concept\""},
          "Entity"], ",", 
         TemplateBox[{"\"person\"",RowBox[{"Entity", "[", 
             RowBox[{"\"Concept\"", ",", "\"Person::93r37\""}], "]"}],
           "\"Entity[\\\"Concept\\\", \\\"Person::93r37\\\"]\"","\"concept\""},
          "Entity"]}], "}"}]], "ExerciseOutput",ExpressionUUID->
       "44d61ee6-1896-498b-98f9-1a922355bf30"],
      Apply[TextCell, 
       Cell[
        BoxData[
         RowBox[{"{", 
           RowBox[{
             TemplateBox[{"\"tiger\"", 
               RowBox[{"Entity", "[", 
                 RowBox[{"\"Concept\"", ",", "\"PantheraTigris::2mpmq\""}], 
                 "]"}], "\"Entity[\\\"Concept\\\", \
\\\"PantheraTigris::2mpmq\\\"]\"", "\"concept\""}, "Entity"], ",", 
             TemplateBox[{"\"tiger\"", 
               RowBox[{"Entity", "[", 
                 RowBox[{"\"Concept\"", ",", "\"PantheraTigris::2mpmq\""}], 
                 "]"}], "\"Entity[\\\"Concept\\\", \
\\\"PantheraTigris::2mpmq\\\"]\"", "\"concept\""}, "Entity"], ",", 
             TemplateBox[{"\"domestic cat\"", 
               RowBox[{"Entity", "[", 
                 RowBox[{"\"Concept\"", ",", "\"DomesticCat::jpx55\""}], 
                 "]"}], "\"Entity[\\\"Concept\\\", \
\\\"DomesticCat::jpx55\\\"]\"", "\"concept\""}, "Entity"], ",", 
             TemplateBox[{"\"domestic cat\"", 
               RowBox[{"Entity", "[", 
                 RowBox[{"\"Concept\"", ",", "\"DomesticCat::jpx55\""}], 
                 "]"}], "\"Entity[\\\"Concept\\\", \
\\\"DomesticCat::jpx55\\\"]\"", "\"concept\""}, "Entity"], ",", 
             TemplateBox[{"\"person\"", 
               RowBox[{"Entity", "[", 
                 RowBox[{"\"Concept\"", ",", "\"Person::93r37\""}], "]"}], 
               "\"Entity[\\\"Concept\\\", \\\"Person::93r37\\\"]\"", 
               "\"concept\""}, "Entity"]}], "}"}]], "ExerciseOutput", 
        Selectable -> False, Copyable -> False, Editable -> False, 
        ShowCellBracket -> False]]], " "}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Center}}},
   GridBoxBackground->{"Columns" -> {{
        RGBColor[1, 1, 1]}}},
   GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{1}}}],
  FrameMargins->0]], "ExerciseOutput",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellFrame->{{1, 1}, {1, 1}},
 ShowCellBracket->False,
 CellFrameColor->RGBColor[0.85, 0.85, 0.85],
 LineBreakWithin->
  Automatic,ExpressionUUID->"0bec625a-275a-42f0-ba91-6414ee3fa541"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Classify the sentiment of \[OpenCurlyDoubleQuote]I\[CloseCurlyQuote]m so \
happy to be here\[CloseCurlyDoubleQuote].",
 StyleBox[ButtonBox["\[NonBreakingSpace]\[RightGuillemet]",
  Appearance->None,
  Evaluator->Automatic,
  Method->"Preemptive",
  ButtonFunction:>(SelectionMove[
     ButtonNotebook[], All, ButtonCell, AutoScroll -> False]; 
   FrontEndExecute[
     FrontEndToken[
      ButtonNotebook[], "OpenCloseGroup"]])],
  FontColor->RGBColor[1, 0.501961, 0]]
}], "Exercise",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellDingbat->Cell[
  "22.4", "ExerciseNumber", FontColor -> 
   RGBColor[0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]],
 ShowCellBracket->
  False,ExpressionUUID->"4425d5ea-34cf-4a43-856b-e4e2e6def2a7"],

Cell[BoxData[
 PaneBox[GridBox[{
    {" ", 
     StyleBox[
      RowBox[{"Expected", " ", 
       RowBox[{"output", ":"}]}],
      Editable->False,
      Selectable->False,
      StripOnInput->False,
      FontColor->RGBColor[0.45, 0.45, 0.45]], " "},
    {" ", 
     InterpretationBox[Cell[
      BoxData["\<\"Positive\"\>"], "ExerciseOutput",ExpressionUUID->
       "43aa1443-232d-431d-9b5e-fd8b556a0efb"],
      Apply[TextCell, 
       Cell[
        BoxData["\"Positive\""], "ExerciseOutput", Selectable -> False, 
        Copyable -> False, Editable -> False, ShowCellBracket -> False]]], " "}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Center}}},
   GridBoxBackground->{"Columns" -> {{
        RGBColor[1, 1, 1]}}},
   GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{1}}}],
  FrameMargins->0]], "ExerciseOutput",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellFrame->{{1, 1}, {1, 1}},
 ShowCellBracket->False,
 CellFrameColor->RGBColor[0.85, 0.85, 0.85],
 LineBreakWithin->
  Automatic,ExpressionUUID->"6cee5022-87d4-4424-875c-597e225c86fa"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Find the 10 words in ",
 Cell[BoxData[
  RowBox[{
   ButtonBox["WordList",
    BaseStyle->"CodeLink"], "[", " ", "]"}]], "InlineCode",ExpressionUUID->
  "b6384f87-cd03-44d5-8909-c2ac8219b889"],
 " that are nearest to \
\[OpenCurlyDoubleQuote]happy\[CloseCurlyDoubleQuote].",
 StyleBox[ButtonBox["\[NonBreakingSpace]\[RightGuillemet]",
  Appearance->None,
  Evaluator->Automatic,
  Method->"Preemptive",
  ButtonFunction:>(SelectionMove[
     ButtonNotebook[], All, ButtonCell, AutoScroll -> False]; 
   FrontEndExecute[
     FrontEndToken[
      ButtonNotebook[], "OpenCloseGroup"]])],
  FontColor->RGBColor[1, 0.501961, 0]]
}], "Exercise",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellDingbat->Cell[
  "22.5", "ExerciseNumber", FontColor -> 
   RGBColor[0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]],
 ShowCellBracket->
  False,ExpressionUUID->"0e2b209f-2f5a-44d4-be32-ae9b9e413e1a"],

Cell[BoxData[
 PaneBox[GridBox[{
    {" ", 
     StyleBox[
      RowBox[{"Expected", " ", 
       RowBox[{"output", ":"}]}],
      Editable->False,
      Selectable->False,
      StripOnInput->False,
      FontColor->RGBColor[0.45, 0.45, 0.45]], " "},
    {" ", 
     InterpretationBox[Cell[BoxData[
       RowBox[{"{", 
        RowBox[{"\<\"happy\"\>", ",", "\<\"haply\"\>", ",", "\<\"harpy\"\>", 
         ",", "\<\"nappy\"\>", ",", "\<\"sappy\"\>", ",", "\<\"apply\"\>", 
         ",", "\<\"campy\"\>", ",", "\<\"choppy\"\>", ",", "\<\"guppy\"\>", 
         ",", "\<\"hairy\"\>"}], "}"}]], "ExerciseOutput",ExpressionUUID->
       "0c97bd6d-443c-49b8-b9e2-7f17748297ae"],
      Apply[TextCell, 
       Cell[
        BoxData[
         RowBox[{"{", 
           
           RowBox[{"\"happy\"", ",", "\"haply\"", ",", "\"harpy\"", ",", 
             "\"nappy\"", ",", "\"sappy\"", ",", "\"apply\"", ",", 
             "\"campy\"", ",", "\"choppy\"", ",", "\"guppy\"", ",", 
             "\"hairy\""}], "}"}]], "ExerciseOutput", Selectable -> False, 
        Copyable -> False, Editable -> False, ShowCellBracket -> False]]], " "}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Center}}},
   GridBoxBackground->{"Columns" -> {{
        RGBColor[1, 1, 1]}}},
   GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{1}}}],
  FrameMargins->0]], "ExerciseOutput",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellFrame->{{1, 1}, {1, 1}},
 ShowCellBracket->False,
 CellFrameColor->RGBColor[0.85, 0.85, 0.85],
 LineBreakWithin->
  Automatic,ExpressionUUID->"6c942a88-d8bb-4e3d-a81a-0ba29200e50d"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Generate 20 random numbers up to 1000 and find which 3 are nearest to \
100.",
 StyleBox[ButtonBox["\[NonBreakingSpace]\[RightGuillemet]",
  Appearance->None,
  Evaluator->Automatic,
  Method->"Preemptive",
  ButtonFunction:>(SelectionMove[
     ButtonNotebook[], All, ButtonCell, AutoScroll -> False]; 
   FrontEndExecute[
     FrontEndToken[
      ButtonNotebook[], "OpenCloseGroup"]])],
  FontColor->RGBColor[1, 0.501961, 0]]
}], "Exercise",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellDingbat->Cell[
  "22.6", "ExerciseNumber", FontColor -> 
   RGBColor[0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]],
 ShowCellBracket->
  False,ExpressionUUID->"c94f3659-86d5-4dfa-8d8a-cbd72703f16d"],

Cell[BoxData[
 PaneBox[GridBox[{
    {" ", 
     StyleBox[
      RowBox[{"Sample", " ", "expected", " ", 
       RowBox[{"output", ":"}]}],
      Editable->False,
      Selectable->False,
      StripOnInput->False,
      FontColor->RGBColor[0.45, 0.45, 0.45]], " "},
    {" ", 
     InterpretationBox[Cell[BoxData[
       RowBox[{"{", 
        RowBox[{"94", ",", "91", ",", "133"}], "}"}]], "ExerciseOutput",
       ExpressionUUID->"0e9d9372-6a86-4049-b7a9-67306f7b9e38"],
      Apply[TextCell, 
       Cell[
        BoxData[
         RowBox[{"{", 
           RowBox[{"94", ",", "91", ",", "133"}], "}"}]], "ExerciseOutput", 
        Selectable -> False, Copyable -> False, Editable -> False, 
        ShowCellBracket -> False]]], " "}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Center}}},
   GridBoxBackground->{"Columns" -> {{
        RGBColor[1, 1, 1]}}},
   GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{1}}}],
  FrameMargins->0]], "ExerciseOutput",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellFrame->{{1, 1}, {1, 1}},
 ShowCellBracket->False,
 CellFrameColor->RGBColor[0.85, 0.85, 0.85],
 LineBreakWithin->
  Automatic,ExpressionUUID->"cef03ea9-d81d-43c9-8ad1-bd35237e59b3"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Generate a list of 10 random colors, and find which 5 are closest to ",
 ButtonBox["Red",
  BaseStyle->"Link"],
 ".",
 StyleBox[ButtonBox["\[NonBreakingSpace]\[RightGuillemet]",
  Appearance->None,
  Evaluator->Automatic,
  Method->"Preemptive",
  ButtonFunction:>(SelectionMove[
     ButtonNotebook[], All, ButtonCell, AutoScroll -> False]; 
   FrontEndExecute[
     FrontEndToken[
      ButtonNotebook[], "OpenCloseGroup"]])],
  FontColor->RGBColor[1, 0.501961, 0]]
}], "Exercise",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellDingbat->Cell[
  "22.7", "ExerciseNumber", FontColor -> 
   RGBColor[0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]],
 ShowCellBracket->
  False,ExpressionUUID->"af443c34-261e-4a8b-a59f-877a63c4db71"],

Cell[BoxData[
 PaneBox[GridBox[{
    {" ", 
     StyleBox[
      RowBox[{"Sample", " ", "expected", " ", 
       RowBox[{"output", ":"}]}],
      Editable->False,
      Selectable->False,
      StripOnInput->False,
      FontColor->RGBColor[0.45, 0.45, 0.45]], " "},
    {" ", 
     InterpretationBox[Cell[BoxData[
       RowBox[{"{", 
        RowBox[{
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.9132382296127133, 0.1052875704634939, 0.1081561232856334], 
               RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.6088254864084756, 0.07019171364232928, 0.07210408219042228],
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[0.9132382296127133, 0.1052875704634939, \
0.1081561232856334]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.9132382296127133, 0.1052875704634939, 0.1081561232856334]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[0.9132382296127133, 0.1052875704634939, 0.1081561232856334],
          Editable->False,
          Selectable->False], ",", 
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.9771026336083766, 0.363796063619348, 0.01077019070224905], 
               RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.6514017557389178, 0.24253070907956537`, 0.0071801271348327],
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[0.9771026336083766, 0.363796063619348, \
0.01077019070224905]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.9771026336083766, 0.363796063619348, 0.01077019070224905]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[0.9771026336083766, 0.363796063619348, 0.01077019070224905],
          Editable->False,
          Selectable->False], ",", 
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.9549993293169798, 0.21676827484502326`, 0.2513102591499172], 
               RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.6366662195446533, 0.14451218323001552`, 0.16754017276661148`],
             
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[0.9549993293169798, 0.21676827484502326, \
0.2513102591499172]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.9549993293169798, 0.21676827484502326`, 0.2513102591499172]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[
          0.9549993293169798, 0.21676827484502326`, 0.2513102591499172],
          Editable->False,
          Selectable->False], ",", 
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.8483679553563124, 0.30385712208149696`, 
                0.15484335046598763`], RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.5655786369042083, 0.202571414720998, 0.10322890031065843`],
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[0.8483679553563124, 0.30385712208149696, \
0.15484335046598763]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.8483679553563124, 0.30385712208149696`, 
                 0.15484335046598763`]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[
          0.8483679553563124, 0.30385712208149696`, 0.15484335046598763`],
          Editable->False,
          Selectable->False], ",", 
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[
               0.9594790623807896, 0.5046051552943853, 0.18946774256928367`], 
               RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.6396527082538598, 0.33640343686292357`, 0.12631182837952246`],
             
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[0.9594790623807896, 0.5046051552943853, \
0.18946774256928367]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.9594790623807896, 0.5046051552943853, 0.18946774256928367`]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[
          0.9594790623807896, 0.5046051552943853, 0.18946774256928367`],
          Editable->False,
          Selectable->False]}], "}"}]], "ExerciseOutput",ExpressionUUID->
       "8c103660-1236-42a8-87a3-5790b8972229"],
      Apply[TextCell, 
       Cell[
        BoxData[
         RowBox[{"{", 
           RowBox[{
             InterpretationBox[
              ButtonBox[
               TooltipBox[
                GraphicsBox[{{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}}, {{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.9132382296127133, 0.1052875704634939, 
                    0.1081561232856334], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}}, AspectRatio -> 1, 
                 Frame -> True, FrameStyle -> 
                 RGBColor[
                  0.6088254864084756, 0.07019171364232928, 
                   0.07210408219042228], FrameTicks -> None, ImageSize -> 
                 Dynamic[{
                   Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                "RGBColor[0.9132382296127133, 0.1052875704634939, \
0.1081561232856334]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
               Baseline, ButtonFunction :> 
               With[{Typeset`box$ = EvaluationBox[]}, 
                 If[
                  Not[
                   AbsoluteCurrentValue["Deployed"]], 
                  SelectionMove[Typeset`box$, All, Expression]; 
                  FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                  FrontEnd`Private`$ColorSelectorInitialColor = 
                   RGBColor[
                    0.9132382296127133, 0.1052875704634939, 
                    0.1081561232856334]; 
                  FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                  MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
               Automatic, Method -> "Preemptive"], 
              RGBColor[
              0.9132382296127133, 0.1052875704634939, 0.1081561232856334], 
              Editable -> False, Selectable -> False], ",", 
             InterpretationBox[
              ButtonBox[
               TooltipBox[
                GraphicsBox[{{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}}, {{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.9771026336083766, 0.363796063619348, 
                    0.01077019070224905], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}}, AspectRatio -> 1, 
                 Frame -> True, FrameStyle -> 
                 RGBColor[
                  0.6514017557389178, 0.24253070907956537`, 
                   0.0071801271348327], FrameTicks -> None, ImageSize -> 
                 Dynamic[{
                   Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                "RGBColor[0.9771026336083766, 0.363796063619348, \
0.01077019070224905]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
               Baseline, ButtonFunction :> 
               With[{Typeset`box$ = EvaluationBox[]}, 
                 If[
                  Not[
                   AbsoluteCurrentValue["Deployed"]], 
                  SelectionMove[Typeset`box$, All, Expression]; 
                  FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                  FrontEnd`Private`$ColorSelectorInitialColor = 
                   RGBColor[
                    0.9771026336083766, 0.363796063619348, 
                    0.01077019070224905]; 
                  FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                  MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
               Automatic, Method -> "Preemptive"], 
              RGBColor[
              0.9771026336083766, 0.363796063619348, 0.01077019070224905], 
              Editable -> False, Selectable -> False], ",", 
             InterpretationBox[
              ButtonBox[
               TooltipBox[
                GraphicsBox[{{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}}, {{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.9549993293169798, 0.21676827484502326`, 
                    0.2513102591499172], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}}, AspectRatio -> 1, 
                 Frame -> True, FrameStyle -> 
                 RGBColor[
                  0.6366662195446533, 0.14451218323001552`, 
                   0.16754017276661148`], FrameTicks -> None, ImageSize -> 
                 Dynamic[{
                   Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                "RGBColor[0.9549993293169798, 0.21676827484502326, \
0.2513102591499172]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
               Baseline, ButtonFunction :> 
               With[{Typeset`box$ = EvaluationBox[]}, 
                 If[
                  Not[
                   AbsoluteCurrentValue["Deployed"]], 
                  SelectionMove[Typeset`box$, All, Expression]; 
                  FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                  FrontEnd`Private`$ColorSelectorInitialColor = 
                   RGBColor[
                    0.9549993293169798, 0.21676827484502326`, 
                    0.2513102591499172]; 
                  FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                  MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
               Automatic, Method -> "Preemptive"], 
              RGBColor[
              0.9549993293169798, 0.21676827484502326`, 0.2513102591499172], 
              Editable -> False, Selectable -> False], ",", 
             InterpretationBox[
              ButtonBox[
               TooltipBox[
                GraphicsBox[{{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}}, {{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8483679553563124, 0.30385712208149696`, 
                    0.15484335046598763`], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}}, AspectRatio -> 1, 
                 Frame -> True, FrameStyle -> 
                 RGBColor[
                  0.5655786369042083, 0.202571414720998, 
                   0.10322890031065843`], FrameTicks -> None, ImageSize -> 
                 Dynamic[{
                   Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                "RGBColor[0.8483679553563124, 0.30385712208149696, \
0.15484335046598763]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
               Baseline, ButtonFunction :> 
               With[{Typeset`box$ = EvaluationBox[]}, 
                 If[
                  Not[
                   AbsoluteCurrentValue["Deployed"]], 
                  SelectionMove[Typeset`box$, All, Expression]; 
                  FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                  FrontEnd`Private`$ColorSelectorInitialColor = 
                   RGBColor[
                    0.8483679553563124, 0.30385712208149696`, 
                    0.15484335046598763`]; 
                  FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                  MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
               Automatic, Method -> "Preemptive"], 
              RGBColor[
              0.8483679553563124, 0.30385712208149696`, 0.15484335046598763`],
               Editable -> False, Selectable -> False], ",", 
             InterpretationBox[
              ButtonBox[
               TooltipBox[
                GraphicsBox[{{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}}, {{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.9594790623807896, 0.5046051552943853, 
                    0.18946774256928367`], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}}, AspectRatio -> 1, 
                 Frame -> True, FrameStyle -> 
                 RGBColor[
                  0.6396527082538598, 0.33640343686292357`, 
                   0.12631182837952246`], FrameTicks -> None, ImageSize -> 
                 Dynamic[{
                   Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                "RGBColor[0.9594790623807896, 0.5046051552943853, \
0.18946774256928367]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
               Baseline, ButtonFunction :> 
               With[{Typeset`box$ = EvaluationBox[]}, 
                 If[
                  Not[
                   AbsoluteCurrentValue["Deployed"]], 
                  SelectionMove[Typeset`box$, All, Expression]; 
                  FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                  FrontEnd`Private`$ColorSelectorInitialColor = 
                   RGBColor[
                    0.9594790623807896, 0.5046051552943853, 
                    0.18946774256928367`]; 
                  FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                  MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
               Automatic, Method -> "Preemptive"], 
              RGBColor[
              0.9594790623807896, 0.5046051552943853, 0.18946774256928367`], 
              Editable -> False, Selectable -> False]}], "}"}]], 
        "ExerciseOutput", Selectable -> False, Copyable -> False, Editable -> 
        False, ShowCellBracket -> False]]], " "}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Center}}},
   GridBoxBackground->{"Columns" -> {{
        RGBColor[1, 1, 1]}}},
   GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{1}}}],
  FrameMargins->0]], "ExerciseOutput",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellFrame->{{1, 1}, {1, 1}},
 ShowCellBracket->False,
 CellFrameColor->RGBColor[0.85, 0.85, 0.85],
 LineBreakWithin->
  Automatic,ExpressionUUID->"5e585379-7b05-407f-bbc5-dff17e65c83e"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Of the first 100 squares, find the one nearest to 2000.",
 StyleBox[ButtonBox["\[NonBreakingSpace]\[RightGuillemet]",
  Appearance->None,
  Evaluator->Automatic,
  Method->"Preemptive",
  ButtonFunction:>(SelectionMove[
     ButtonNotebook[], All, ButtonCell, AutoScroll -> False]; 
   FrontEndExecute[
     FrontEndToken[
      ButtonNotebook[], "OpenCloseGroup"]])],
  FontColor->RGBColor[1, 0.501961, 0]]
}], "Exercise",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellDingbat->Cell[
  "22.8", "ExerciseNumber", FontColor -> 
   RGBColor[0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]],
 ShowCellBracket->
  False,ExpressionUUID->"612e4812-d260-4ba8-a2e3-97093bd88bf6"],

Cell[BoxData[
 PaneBox[GridBox[{
    {" ", 
     StyleBox[
      RowBox[{"Expected", " ", 
       RowBox[{"output", ":"}]}],
      Editable->False,
      Selectable->False,
      StripOnInput->False,
      FontColor->RGBColor[0.45, 0.45, 0.45]], " "},
    {" ", 
     InterpretationBox[Cell[BoxData[
      "2025"], "ExerciseOutput",ExpressionUUID->
       "555adc7a-b8f6-49ca-92ca-7bab07279d30"],
      Apply[TextCell, 
       Cell[
        BoxData["2025"], "ExerciseOutput", Selectable -> False, Copyable -> 
        False, Editable -> False, ShowCellBracket -> False]]], " "}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Center}}},
   GridBoxBackground->{"Columns" -> {{
        RGBColor[1, 1, 1]}}},
   GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{1}}}],
  FrameMargins->0]], "ExerciseOutput",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellFrame->{{1, 1}, {1, 1}},
 ShowCellBracket->False,
 CellFrameColor->RGBColor[0.85, 0.85, 0.85],
 LineBreakWithin->
  Automatic,ExpressionUUID->"6ba9273f-b00a-4858-910d-9cfebd81a79e"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Find the 3 European flags nearest to the flag of Brazil.",
 StyleBox[ButtonBox["\[NonBreakingSpace]\[RightGuillemet]",
  Appearance->None,
  Evaluator->Automatic,
  Method->"Preemptive",
  ButtonFunction:>(SelectionMove[
     ButtonNotebook[], All, ButtonCell, AutoScroll -> False]; 
   FrontEndExecute[
     FrontEndToken[
      ButtonNotebook[], "OpenCloseGroup"]])],
  FontColor->RGBColor[1, 0.501961, 0]]
}], "Exercise",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellDingbat->Cell[
  "22.9", "ExerciseNumber", FontColor -> 
   RGBColor[0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]],
 ShowCellBracket->
  False,ExpressionUUID->"a0507145-5aa8-480d-95f9-cf1a2690c435"],

Cell[BoxData[
 PaneBox[GridBox[{
    {" ", 
     StyleBox[
      RowBox[{"Expected", " ", 
       RowBox[{"output", ":"}]}],
      Editable->False,
      Selectable->False,
      StripOnInput->False,
      FontColor->RGBColor[0.45, 0.45, 0.45]], " "},
    {" ", 
     InterpretationBox[Cell[BoxData[
       RowBox[{"{", 
        RowBox[{
         GraphicsBox[
          {Thickness[0.00078125], 
           {FaceForm[{RGBColor[0., 0.321569, 0.5764710000000001], Opacity[
            1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0., 
             0.}, {0., 800.}, {1280., 800.}, {1280., 0.}}}]}, 
           {FaceForm[{RGBColor[0.996078, 0.796078, 0.], Opacity[1.]}], 
            FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{400., 
             800.}, {560., 800.}, {560., 0.}, {400., 0.}}}], 
            FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0., 
             480.}, {1280., 480.}, {1280., 320.}, {0., 320.}}}]}},
          AspectRatio->Automatic,
          ImageSize->{{128}, {85}},
          PlotRange->{{0., 1280.}, {0., 800.}}], ",", 
         GraphicsBox[{
           {Thickness[0.000992063492063492], 
            {FaceForm[{RGBColor[0.141176, 0.290196, 0.647059], Opacity[1.]}], 
             FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0., 0.}, {
              0., 720.}, {1008., 720.}, {1008., 0.}}}]}, 
            {FaceForm[{RGBColor[0.815686, 0.65098, 0.313726], Opacity[1.]}], 
             FilledCurveBox[CompressedData["
1:eJxTTMoPSmJmYGBgBGJPJgYGMJuFmZGZmghoOnUNHBArqOXOoeLUYYBIDWpc
6kejjKaIkuCladQM13inir+IMQRNDS4uFcMZv1EAebsRkw==
              
              "], CompressedData["
1:eJyNXQm4jeX2V8mcqUEaFJcUlQpJlE8RoZIpB+fgDPucs8+4z57n+chViJt5
SJRcEVFIKiUpQxINhkRlKJEUSvLfe/1+3/s+8Tx/9z7Pvfuu833f+671W7+1
3vnVNLusX95lVapUuST137eqValyaep3h+fwLXcf8hgdl29wvTPfbZwvf/fS
9HU3V/Made94feax1W5j4rVVB9Vt4DXSj2e/4zaqpP9zg9cYkttp7xNr3cbL
qdeXPOQ1Hqz15dzyzReX2+xpXi061It6d7pRboGWtzbb9UfIpWV5/zmv0bvD
6K4jNrqNj9L/Z5rWR+QXvcaNaYWWUr8tXqPHPt9Vi6dfXBY7f/IaV8bf+2TO
c27j/nTBx/Xzhum/n/Li7y+5jcmlqb9U9RnJn55c2WSR23gjrUdDLYv+N2tZ
7G/mQz2rtCx6rNPyr9sey66/hd/f6jP8Vy3usW8nn9/jM4oPnllw/IDb6JnW
6wEf9DvhNm5eUlHwXH/Wd+bi8gNpP9h8xg1pvKp7jJ8DXdpnOXzAt7EHfnX7
jJT0w9ZWHsP9zuzr2jzvQzkdPND7ZR9wv98Dvd/0GSVp/Trr51JuNw9w+8wH
HLt4jKbpcs7q76Xey/x471E+v9wPHAZ58FvDbxQ8lyoxRz+Xesupb1M/yinx
GC92f/PE2c5++MXqAZ97XSjLr0/LgvfTHtiR7cfveNrfwY84mEl9a/uN1qOu
+XrLAo+xskkK2bp+xM9s/Vz4uEzrL/pu0M/l90OPcVea3z/71HPB+VOfMSXN
s088wG0v8f/agzja44Odqbj9LF3+Th/qP0V5m89oldbvHOvbTP7V9KKcj8i/
q7yIrxUXyuL/ZlqW7+72Gu//fuuwcct9iJeOXtg37zz5P1oWWMZeKO994tnJ
pT21LDg/Rf2eo745jMs5Whb+L9Xyt+ly3iJe5Vpf+Q1rfcVPY7UsfHrtQlnw
+4TlbbhQFr7UoX/PeoFbQ79xRVqf6sS9kZ9/90HfO/yIu8Y+vNeBfL6ccf4Q
+ZXKO/K8hx/xncpLEv99/caqtP77vdBjsN9Yn3bsV8TL5idPiKfLj3oP0x8B
8vOE10irvyTkRznX0u5nyf/bfbBruh/xa5CXL/uBcy8f4nSB3/ggjdsQ5o1F
LM/qQ/nL/cjfHh9+12tZ7PpSyxKX+/1G5luP1rl0nJaFHzO0LHotoN8P+2Fn
Ku8IbueId4oHgstVAei1hry6KQC/pfwoeNwSUN9LHN8RwHtzWV57LUseeCig
9BG8nwwAh+dpryUAfj3D98v1c9HbHwAvZvN5JAA/v8Y4Hh/Aey+Rpy8E4K/p
9M9C/VzagcW0b5UPfng9gHjdRPvfDMCOgxeXpdxVAeDymw9826ZliaOftCw4
7yR+Vf2w62AAONSl304GyC8ti7+bmXEShD9uMOMiiLx2Nf3cPoj3mzNv3hoE
Lu30+1JuNz7/k/pk+eGf2kHgUeFHu3cjv68kr5sHget88r5hEDj+l3n5kiB4
tkjbZ74v/vue9r3FON5H+7b4FT4Sj7v8aGePBcDvvX74u2rQOJrWYz/j5lYt
S3y0pX1HyPMHg8D/JON6ZBB56y8tC57XBZQs5XQgLsVB+LtTAP4vD4LfvQOw
0x5EOzpUy5J3gwH8PS8IPj8bQP9nUBB+mhkA3l2DwO0Nfv9A0Hg6jf87Abbz
QeC8gXF0exA4fEVeXUN99wYU/vLegQD8l8JP4vSwlqWeP7QsPKhFPc8GgM/J
gJJFz6b6uejfO6j8J3mm34WyGS/Cp+ILZcnL1gDsiZA3A7Us8dNVy+KnVrR7
kn4u380lbwcTh6VBxFUW9f9Yly883k0/PsZ8dYx+7EG//0V7WjI+q4aAV3X6
sU4I5fztR71XhcDvOuRvyxDqvT6A/H9/CH5pEgCve4TA97v083/Ye3tI6W+W
J++7AuD7PSHY+Sz9+EAI+EyiPd1D8PscXb7kiUUB8KVNCH5/OwC9m4fQP9zM
/NY+hN+9ujz5Paf1Fz5cEUScdyEeNwSRfztQvy5BVb+U11u/b8aDWb7oUxrE
72AtC77ZWhY9S4hPIIh6IyH4awz5/3QIPJ3K+B9PfRYy3haGOK7QsvB+g5al
3C3k2WotC4/Xa1n8tZX67WR9B0L4+27mm6Mh4LY3CH6dJB5nae+lYdTTgHYc
p34tyLt9IeRJIwR8d11cFjsyqecX5E+xfi5526fLRz8ipPSX9mIu9fya+q8I
gY8b+fcd/7uMcZmuz5TFTz9p2cRH2tNvqUfNsCoPOIVh38eMs8ZhtishtFfN
w4iHbYy7dsT3MP3cTctSf9cweFYlrGTB81otC19vCYOvXcLgwX1axjhMy9Lf
sFDvNlqW3yZalnxfN4y8WREGH6qGwYNoGH77K4S4GRcGL06EkK/mhBV+Ys/0
MOz9JoT27Pmw4qcpm/wVPeeHEf8biPfKsPKX8OCdMPzynpbFH8u0jHErebaO
+s0krjvCwHsK+XiQ+ExkvvolrOLVlLPSPPRr2Yx3+e7nMMZ9eeTXibDKF6Ln
6TB43YvvXx5R+exisuB9dQT21QuRDxG0w81C4NdXYfW+2L01rPKvfLc2rPKd
fP96WOVD0fO/4X/m3/9HNv0l7WQr2jtKy4K/R8uCd2FYtU8mfwT36uT9FPrr
Us0fs70zZfQXtCx54cug+t5sPwXvZ8jjLUFVn/BwbVDpZ7a/Yl+uloVnT2jZ
jB/BcZWWRY8FwX/G11T2O/uR/9PNfhj5NFbXZ/YfzPiS/BDS+op/xgRVfJnl
m/Ek781h3p9H/49m3n+V8ZHqF5rxY8qSPz7Rsvh1l5bF7n1aNvku8egJwo9/
h//Z/6kRUc/F/prka07Q8Kaqq1E7gvh7LGhsT4dFwwj07037G0dg38NBY9LD
Y4oP3hwBfzsRvxYR4Nye9d8SAV6pfvax+SkEbo1A3+uCRuc00LdHEI9Xs7y2
EcTrjWzXO0XQH24RRPvxSATx3Zr4944A15vZLj6hy3s+Xd6gCMY9qX7H+bLw
ejDj94eAYX3bMfFaB+N124Wy8N4dQVyu07Lw5C0tCw6vBYx1aQf5iecC9gNj
Eej5asBI0+XUaP2++Geyfn4x+fO0f+ZEOO7XsqmfKYu/tweMm9KOeimCeN9J
fRdpWfRYrmX5fl2E82L8fkNEjRcEn80R8D41DihM+2Mn+fF7wEixbrvne/Lj
54BxewqG+Uc13oJLjagq/2Ky8LNaFPzZFDDqD05FXt0o7EiNw9OsGNUoivom
cxzS8n+XpfzboshHIfqndRRx6GC/9c4o4qWQ+HWOMk8Qv4ejaI9LA0anNL97
UX8vxy0DosiHowKIv0wtD01/b9HysHEpDYsvlCW+ntOy5MkZ5FtOFHbN07LJ
D1M2+WF+b8oS3yVRxRfxb1lU+Wteecpyt36eds/8oPaH5Lu4Lk9w+HcUcbZC
yyZ/TVny7xzyZVIU8RwIGA3S/p0ZNXzp8l0cZ74URT02+mulxlvKWaO/T9N4
5QdRtIOjie822jOO9mzV34uenxK/x6nPJurXm/H7BfmSGmdJvvo2ivbs3gDy
5f4o2vn6AeS3r8nParo+yVtn/OD3ZtZ3Wsvi3x+0LHhv4/zGxijGYWv8yh7x
2+t+VZ/wdL4f/N0T5fyXlsX+57Us8f5vP/A6EEW9GReXJR/9RH7f5gcfDhPP
Jn7kgUOMj6v8RtoNPX6g/Zf4wcdfWd5lfsTvOfKjmh/4Xxq7QBb8j/uUjPke
nzE3jW+1GPT53KfKE75s5HzeacbvB5x/O0H8X/EhHs5E1fyjWb70Z2b6oH+N
mJpfFD/XjKE9GuND+1Y7Bv5FuM5zTQz+KvEZnnS5TWJq/nVFuvwWMfg3xvnp
W2JoL5/2gf+36/IFh3ti4POznA/soPUR/e+OKf0lH7Umfkt84N9tMfjjHc6f
tonBj+t9Rq80Xu2p3xYfcLovBr4cvrgs9neN/dO/vfVz4enAGPLFVh/yy1O0
/yuf0Scdf1lalv5QnpaF3wUx5U9TNu0xZdNewcEdAw7LtGz605RNvLEuRfwG
/u+y8K8D/R2Lqfl80WMM8W3mMzLT/vl3DLjdRP8mY2q94sM0XtEY+FhVlyf4
HfMqWfT9XstYn/Kq8sR/27n+EGJ9H3uVveL3d7zgs4P+WupF/HoYX3O8yK/B
GOfJuV7jJ78rvfhuFMu3e9G/mkD8R3jB7+doz2AtS/m9tYx1Va7vzCR+rbQs
8XOjliVO6nHd+aWYWm8T+xax/LMexO/yGMZTf3qg75oY+nP7tSzt1XYtSzvw
kYc4xTAemHdx2fxe2oMZXI9dr2XpD2/RsvB1O/032gNef0l/z/YgfnYSv+W0
7zv6awXLP0y83/Yg/x0ln973IP/9GUO9mzzoz1WJQ+91HuSjanH1vfSbr9Cy
xM2VWpb80ljLgn+7OOfBLi6L/p3199L/MeLw13wP3usW534Arm/3i4NfXg/6
e72ofyn9+zDLz9Gy+ONx+qOPlgWXgVqW/J15oSx8N7Qs/mnrQX4bHgdfbuX6
siUOvt7lwd9L4shX9xHfijjyQycP8p1Tvy/6eOLg9S0e5OeglgXvZBw4NPEA
h2fi+O4ari+Pi+P3evJrov5efqfo+iT/LtD6XEyW/sF7cfD1EQ/6/x9rfATv
bfp9yW/f6PouJosd32t7xM59cfDmcv2+tG+/u+HPXfTXabd6LvnoW7f6Huv5
+n2s97uRX3fo5xJXn8a53u9W9p0vC2/f0LKMf2a70f/7II7+0zQtSxyP0rLw
1aFl0cdNfd+JI87K3ODXyjj0zud+lzfjaK8yuB/nXcbLU27k7w3EY4Ab8f0h
46erlqX/fK+WhRe3a30kfq68uGx+L7yvxv1Kq7Us7y/RsvD3FeJX043+48tx
zJecccHOl+Joz466kA+mMr6+cqE9m0u8NrrAk8XUZ40L8bSQfHlDlyf1L3Eh
f84mXgtdaM+mky/jXUofaS+fdqH/8TrxibiUPeInj0vFh9RT4kJ//8U49ilk
u1T8SXszRMvCj15alvrud8HO8VqWep4mfzq4wIsw8WjnQrvnI19ucqn8IP6v
6lL5QPLVYaexP+34CXGMZ486Fb6mLLi9cKFslncxWfpnqxifl7hUvjBlk5+m
bOYLUxY7viK/a7pUPEs9DVzGL+l4OKrtNWWso2nZ1F/8dpz8P+5EvjxN/h9w
wt/n6N/dTvDykgTw/94JflVPwA/bncjHdRLg2wdOjLfqJoDzZ07EdUP9vXzX
KIHx+ikn/HZTQtkn9bZMgO+/OcHPOxMYL32jZbM88W8HLYseXbQs7f1DCWWP
KYteW7QsfF3rxHxEby2LfgO1fRIfIxJon9c70R8YmQBOq8iPvATid6ET8z1W
2jOLeBQl0D684MR4wqZl5D0tS74Laln6Q1FdvvApmUA8v0l9x2h9JR6fS6D/
t8wJfk1OID/PJX5zE2i/XqZ/Xtb2iL8XJPC7ifx5U+Mp7cUajYfk/3UJ8G+p
E+3HJ1oWvnyWQHwsZnlfa3skf36nZeHjQY2f5LMjCbSP44nnn+Sb3wkcfqH/
ihjfB1j/UPp3ZwL8767rk3xnnFf+/eTT8QT83N6JfHuK/L+V+J5NIG9cR//U
TwK/q1l+4yTyX0OW3ywJf9Qjfrclod8VTuDYNgn9b6Q/H0iif38H+ddTy2LP
I0mMcxoRz+5JrF9fSn70SiIefnRcVBa+9mP9H2lZ4nOVloUvrzqAR98kxicL
HMArM4n8OtUBnIqSyDOjHcCnMMl9Xg7YZ08ivsc6YF8oiXw1i+VFksgX87Us
/FmuZSl/74Wy9O/HJVHP9w60X88n4d8jDsTX9CT6o785wNfXtT8k36zUeEo+
fSfJfbcOxO+HSbRffzrYDicRX+dY/mdJjFcuZ37YrWXh934tC48OaVnaw191
/WLX35pf4u9alYqPpiy8bEZ+NahU70t8XluJ+KquZdMeaUeuqlT4CJ71KlHu
fv1c/v4x8W2iZewX0rL4uTXrf1fL0r4t1bLE9zwH6rmjkvuqHeD3nZXAoZJ8
uqsS+SigZewrdCC+jEr4sdSB/Na3kuMQB3j9WCX8018/l/h/hOX1rwRf7tOy
/N7pQPvWS8vir65alvn7B6nfLQ7Y/QD1udYBf3eqBL9qa/sEj8svlGX831S/
f75s+s+UTf9IfFbR/pN897sd+lSnP7+1I96uqAQum+3IIw0ruW9Vy4LXa/p9
4ct8XZ7E+2w7+jNVWZ7brviKfpod8X86iTgZZcffjyfhv4Ad7dNPSfW98PiH
JOLGZod/Dybhrz52FR+SPx7U9Un5d9uRfy8h/k0ulIUXden/kxUXyGY8SX48
WqHsFZ5/W6HsFTs+r0A8nGF+WqmfSzwvq1D4Sb5cVIH5pBr0x/gK9KfPJZUs
/DylZfHnEebrKRUKL8EpVgHe/cj8VVKh8JP2p6JC5R+xw0n7trP9cFeo/GaW
Z+Y/szwzP4r/n6qAP5Yy3z9RgXJeTmL+qF8F+r8zmF8HVCBO5iSh5z0VaH/m
JlFuc/291NdIly/5oerFZelfrEqiP3vSpmSpb7eWpfy1NvhjOdvjD2yYj1hM
Pn5hA19eYXty2KbsEd4dsKn2Q/j6mQ28mJpEfl1tg/+nJLnObYO+Y7Us/ohr
GfvC6e9JNvz6yecxNuQPF/WL2KBXGdvnEi0L33K0LPgMtgHvkiTWjx+zcX8w
28NeNtQznPzqaVPtueS5VheXhS99yK8WNtW/EDwa2dCPepTtZS39vuTb38pV
f0fs/rUc+LYh/sfKwfdbaP/uctWfkvo+LUc+vDGJ/Lm2HH65gf2HFfp94euC
cujfkvXNKEcc305+2MpVf0zwLCzH/O39SfTHR5TD3wbxzSqHv7vQnp7aHim3
bTn43576/kt/b8r/wC8li7/70783loOPTySx3lG7XOH73+Opgn8pU7I8/6kM
fH6I/t1Zhn5jxyTnb8qUPufLT6WBma3ldNjMdZQhju7TssTDXUnj2XRA5Jap
/qzoM0DLUv+DWpb80kTL2OdZqvwr+NcsU/6sSDvyu1LYd1XSSP1v/+/WlALv
mlrGvhvqt6FUjQ/SaXTY56Xgwx9aNvvzA9P2nihF+34ygbi8sgx+OKxlyc/7
EsindcvUeMLUV+Jna8JIf7bnUOlFZdHng4TSV/j5ccI4mQqn9xeVYj5jC8cj
E2jfpgTyZD71X8vxTkkp8uiKBPfhlCJ+XkgYabc/8FAp+D5FPzfHh8KXuaVq
vNmiWvT5hz8oxfjJlwA/YqVqfGqWJ/kznjAGpQvuUarGp3I8p3op54nM8WGJ
Kt+UzfIwPixR42Epb7qW7WkDx5TwXFXCsElCKEE5pcRrYAnay5KEsS3tn+tK
/jmerlqi9JPyjhWr8bPwdbmWRe//aFn8b9ey8KV/MfgxXssSv9O0bI6vpf7B
xah/HvEPFavxNvY9FaP/8RbtWcX6VpNvpcVqvC3++ZeWpX93tkiNv2Wcs6dI
8UXwXVOkxt8t767x6g0TihAfXyaMbilan4kWAe89CcSTrYj7CRPGzj9C1rcP
WS+QzfG7+GO3Ffl9B/kyge9v4vxBwspxJfH0WxV/0d+wAo811NdphX2rEhj/
WLUs/BtkRfwvTxjvpuOpjxX2L6A9Ha3ojy3U9cn6yCzOL+RYEW8TWd7jVug5
IYF8dq0VfI0S7zZW5CdPwhifDrROfN/O99dZ0U6l+Lkrjc/3VvgvxU/JX6es
an5IvrurCPGdneC+9CLok0E8A0Wwt7t+jn2vjNf+RWgP2tNfJfR/R/J7ehH6
Ka2IzwtF4Fcd8vEV8qMZ5+OeKuL+TPK/WxHar784n9tUy1L+7CLkmx/j4Gte
EeLxuzj6f32LwIffuZ7xUJGaf8S5lyKMZ36OA/+/rcinu+LA+1Mr2pfdcdi7
0KrmP0UfrxXjrZ/iih8iH4sDf8MKff7k/PO2QvDxUNxYk4K5amUh7N/M9ZXd
hahvTdxYmM4HdciXt7i+YyE/58bRPg63Ip5n8nmWFXhPj8PfPazIn5OoTzer
ms+W5w9b1XoV8gPtryQe/axqvUvi9RHGV5L632lF/MaJf+MLZXP9TPD/tRD9
ARfndw8VAp8y+uPDQuhnY/0vF6LfUhBHPI2mPILl2wrB1yFx8DVSCD4+SX8N
LUT89CS+7QrB4x60588C1NcpjvjZXoB4ac/y11K+m/jUKYR9reLGLWl+7CoA
/rfp73E+OY542FwAf7SMoz36qID7/ePI9ysL0G9twfnwpQXI3y25vjCnAP2v
e1lf6wLgdQ3x/Dsfea4O42FhPvhVI472/Ol8+Pcq1leQD/3rxeHHx/JRXx3y
uWM++P13DPhcmg++naV80gI8zsTgj8MWtX4t9n3K56diwO9DC/LH79wfs9qC
8eaRGPR5z8Lz5VzvX2JBfknJ0n7MtKD+1PeSn8dawM9U+RJPMQv6Ian6JZ/a
LdD/ZAx4DLfArlOUh1oQn9WJd2ML/J+yT/x1h0WttwtffstDfq9O+Uiewktw
/zMP49W6xO+HPPRH6pPPn/F5LcbnNv299C9W5yn/SX5cngd/XUt/ebQs+dGd
p9b3xf/ZedD3UtN/ecpfpiz8PxYDTh3yEHc1Tb7kga+/xpQs/jmkZelvHuR+
iyfz4JcfuH+hJ/H5nnI36rdLPxc+fKVl+f4TLUt79F4M7dm5XOC3Oob2/XQu
8FoRQ3/5RC70eC2GfFaF9S2IGbvT8l+5iP+5530/g/7dl4v2bpKWRf+JWjb3
u0i8/ZQLfo8l34/nwp5Run7hrz+GfFo9Dzx1xODP+pTLY8hn1xCPAq2v6Gfh
95cR/5HEv14e2oNC7pe5Ow/5JIv+eJT4ZxLPPpQHUt+peWo/l+TrWXyeEVP8
NL+X+KthQf9iKN9/0KLel/znsKD+h7lfap4F/Hgghvy31YL+W0cTL4varyY8
75XP+dUY4m9kPvzdnPnCm4/8dn0M45NX8tX+PNF3cz7PwZLPX+Yjfhuz/B/z
4a/U+5LfzvL7hqyvAfNvbdbXuIDzazHky3YFnA9jvuulnwu+4wtg72Wsb1YB
/n6W+2sXFwC/rVHE77oCzs9Hgc+GAuTfd6Oo/+MCtGertSz8fDOq2hep/40o
8NxXgHh/Pcr+SgH0WKJl4cWrUfDnXAHP5UaZvwuAx4tR8Pe3AuTT2VHw7wTr
mxYFf/8qQP6YrN8X/j4dVe2bxFsyyvmLArX/WPJdBd8vjCIeexYg/w6JKnyl
/90nqvwhfOhGPP/Mh70PUp8l9H/7KPg5Nh/f3x1F+xPOV/vBzeeS31pF0Z8b
lc95jSjao5x8+K9xVLWHEm8NuJ+4dT7sr8/9xC3yub4WRf5ulK/2twv+DfPR
HzkX+Wf7eSZCf1gQ7ycijHfGwy/6ueB3KKLaW4z/I7DvSwvH7zxf8YEF/d8t
PH+xlvG6MaLaW4mPjyOYj3zTgvmj9TzfsdjC8VoEPHqR76+lPI3t+bs8X/K8
heNDPp9lAT4rIqq9Fv8tjUDPqRb8fVGE84zsL8zneYMo8ZgWQf/Zx/Y6qb+X
8vysfzT1c/D8StiCeMqJwL9tLcjfmRHjoTRerSlnRMCvFsRrUMQYm47H29lf
6Ke/F3ufiCBeb2X/ohf13cH29dEI/P2+liU/vsf8fntEtc/Cj1YR+Hkw29+W
EdX+Sb5pEQGu9zIfN2V5zdleNqF8bZ463yP112X7eZWWBa96Wpb+f7UIxgs3
5anzbtJf+hfb/yNh4N8qT513Enzb0L5pPD/VMo/3BIRVeTJP+wzPZS7OVeez
xL55uVwX4fmqmbmcZw+j/zaB7Xl1nq97Npf7VrQs8/a/hoDDS7noD+3jubwZ
ueo8qfhpci70/jCEfFGsZfQHtSz+7nGe/HAu5mU3huD/drnA65MQ+NQ2F/W8
G2L/MRfzsvPN87w53BfK87ef50C/GSHki405aH+mhsifHOA5ifq+nYPvxoWQ
H5blAN/SEPLt1BzuK6D8LOUcngvNy+E8Bs8JdsnBulmY57jb5GBd2xVCf+tM
Nt7rT3s+zgbePWnP1Gyeo+U550Q22ucBrL+r/h7nvbIxj9TXPO87EnzoHkJ7
Nn0k+g+P0J+ZWpb6nhzJfcch5L+G/P4x6lt7JPToS3+dG8Fxawjt9+kRiK8s
6vfzCIWP+O+7EdBrdAjx32cE1zVCGG93HgH8JoSMYCoc3po6HOtkXenPg8PR
rpWTHzWGYx3KHUJ++SEL7UiQ/HyPcjIEvr+Ypfwr7bk3S/EtbXZyYyb4sInl
r8yE3zaHgOuUTLazIeNc+j/uTOg/MWTMSeMwIBPxGqD+fwxDeQUsr+8w2PMk
+ffrUODxcMh4NU3sFUMRXx1o76mhXEcJoR9TOhT+bxIyjqT17aSfiz4fDYF8
I7+fP0Sdd5fy3UOASw0+XzEEeP4VhD4vDuF4LWjUTsvThnAfVtA4kE5UWXx+
jPLjQ2Dv/iDz5hDecxU00s3cmdsysI6cHUT8d8kAn4exvl4Z0GcQz31OyUD5
A4PAa0kG1uX6B43mab5tzEC+7BNEO1ZtCNqfR1h/4yHqvhKxNzwE+ePPAOqb
MARxtofn4K6hfV8EDNkOdDID62I7Aui/rM+AvzcFwK+XMtR9DsKLsgzesxVQ
9gnPpgWMNKxv1cwAvyYHgNffg7nPheeuvhgMf40JQP+vB3P9j+cIvxnMdTzW
NzwDfhvK+11iGeDD4wHg9V4G+k+3BozHU93CjgOGsB0LKH+asvSTRw+F/Sf9
4H98mLrPSPb5lGTy3IAfdlkzUd/NAa4PZEL/RrxPY0YW130Dxg9pex9hfGUE
4I+yLHV/CPTJUvcTCX9XZKG+Itr3fhbyjzOAON6cxXNBvLfl2yzEj4lfxnDw
Zy7vJ5o4QuEt7cCWEeBfIIB8VXUk+FAYQD64ZCTnrVj/kJGwdxC/rxip7guR
/uA4/b58v2Ak+xnkw7sjec8c3++Sre4fkfp7ZoM/DwQwvu6fjfi/O4D+/ohs
rq8F0B7lZ3PemHyuyEb+ax3A/Ntf2eq+KCmveg74el0Aetpz1P1WUt4KPt/u
x3rFBzlcL+C9RHsor+M9QH+zvVvtR3nX58LvS/zI5521LPHzeC74sdAPfUv5
/BXeMxTIRf2zWN9o9l9m8t6iqbnqvi/B7Y1cpY/Y+0su5u/e571JzfJg/1ry
9Z48VZ/ZHxT/LPYjnoN50G+ZX43XcQ6E+nydp/CQ707nob5P+H1TC/Sby/sB
/RbwbRbff8UC/szwg2drLKp+c77OvK9M2ss9fH+eH/7/xQIe+3k/4P0cPzlZ
fl+Ob8r9iIcRHG8lqJ8zH/2d1PvCh4kcrxfQH4vzOW/H+ubp8jA/lg++FBGP
Hfn4zeQ5yyP58NdTfoxvqhUgPvux/hsL8H4bP/q31xWi/9aG/r2tEPW1Ir/u
L0T830R/P1qIv1/nV/PJguPVfvQXigsRL1eSb2MLkS/r+bn+UajuP5T5nhmF
iJeDPvB9WSF4860P64WfFKr7CkW/PSzvax/6L9dbYecWn1pfEv997MN8SU8r
2ve1PjVfL/xY7UP/si/XB970qfl+8z5A8UM+31/G+zBtVuD5Cu+xe85cP+C5
TLsV+ERY349W2Ffkg/+qc33pKZ9avxH9uvPetO5FwP8h3nfZpwj+6cJ72AYU
4b1OPsynDC5S5/ZEzi3CvGgjH9qfgiLERy0f/BEqAj8u0zL2bXi5XlCk7gnE
ekwR7Prci/7mGNb/qZfjIq43bfLCb4u5nrSS8pt8Pony60XwX5Ln4D7l+pmb
5+QOFYEfDpY/rFjd/4r1xGJ1Lk/GW08Ucx+Tl+szxew38/u+XA/u6kW8+orB
j5q8hzFSDL+e8ADHaSz/iIfr78Xg85ce+GOGlgXvV7g+vNuD/PFuMezb5QEf
PytG/KRk7C8o5nlt3jtapUSd28P+Yq6fv8NzXHeWoL4FPBd1XwnwWEq5cwlw
nUf9+pSAL2EP4vLJEp4r572g3UtgZ65HrceLvsN572o96tPfw/22XN/v41Hr
9ZJ/unjA51PFwLGzB+OZjcWI11Ye8GVvMdrn5h7Ew4FilHOzB/78pRj23sDy
Txejf9rQg/xUi3jU0XiJ/dWJV9MSnhvhOaOuJbwXwa3wF/zibvDtphL0J51u
ha/YW8Tn19O+4Twn1K5EnWMSfI0S5IUyt9ovId+1dSO/ni0Bjl3d6I9dWQr/
9KU+TUvRb8p0A497S6HvSDfw6FaKfDSM9woP1bL4y6pl0Ttaynsc3Gp/iuiT
Ks/cf2PaI/G8pRTj3UFu5ONd3L8ywI34Oar1Fb0uKUN9A3gurXEZ769xw447
uP+ojxu8uqcMfOpq4lUG/3fWsuSfO6hvRhni7QbqW1gG3Ou7ES9Pl6HeK6jv
OJZf2839KNzfU93N8xhlmC/5y8X9K9wP9ZWL/irjPdEu6HOojPMlLsT7CT7f
70J8/1YGPL53Ib7PUd8DLsRVtXLU84MLebdeOfftu6Dn1eUo9wzPIbXm85vd
4FXTcrbDvFe7Tzn42siN8oaXc18e/VFWDjyr0R/xcuBVxY12ZVQ58DjHc1nj
yxEff/Ac13/KeZ8Yz/VMKVd4CN/WlAPHTS7guL6c51B4burbct5b5QIOW8sR
d8tc3O9pg39XmfbbeI8uz4G14X7DJM99dbShfpdL7W/EfAG/z7eBv24X2wkb
7HDw3FzYhr8PZXnPUu7Pc2pTbGwHWP4MG++ldSE/LrKhf/iIC7x+jfs9e7jw
3XIb99FSn9Usvzf1+Yjl96Q+n3L/6MMu9PM+t/FcLc8JbrPhvfZ8vsMGHjZ0
IS/9bgNOB53Q5zLuH37LCb5cXYH3FjmRZ6/j/mfzXE/zCp7LcLI/VwGeznIy
7iiPcIL3Pbn/eKiTdnM/8QAn7H60Anx8wgn78yp4LpD6lHD/c3eeo3BW8N45
ngNKaFmqTfL99k7022ax/hZO3steAT81dHJ/ewVwuNKp9msLHvWdiIfV58nv
alnweb+C+1pY39EKnsuj/b9VwD/NnODp3xXQsw3rq8799HfQ3gZ26NmK50Ka
2dU5D+FbZzvvrSV+vc397Dy3FWF5p3juwWvHe5ex/DV8vxrPOW20835Tfr/d
Dj3rOLnf3Q47avEcyj7ut2/g5D39doUn7v2z855d6nfMznlKJ+LhDzvy5J0m
HtSvI/G9gudBDJ6DudMBvR5n+R0dqG8wy+/K8zdOJ+PQAb/46N+nHPBLiHhn
OrCelSSfShzAJcpzWA4HynXznJeP5Zc4ETduB/TMId+9Dug1nPil3pd82498
jNOenk7WS790J75Pa3vFv89o2TwPI/2BTk7E5fPm+RfybZJD8Qtx6FD4455y
B/hd26nOU4lefziAz3x+f8QBfF5z4LsdDvDkbZ4vWU079zngl3nE9QD1qXRA
v59pfwX99D3Pwwzkua/9DvD7IV2eKZvnj9DOU4/j1KOJQ51XwnyHrl/8cc7O
8y7EN8Uz83yW+OVSB/JyLeJ+KcutT16fsavzetIO/arjCvd729X72L9rx98b
k0efMU46M69+ZOd5I/2+4JtBeZkdfn2K5S+0I4+leI35Af0+5jP4fJh+Ljhk
kmeLqN8IlpcqX/KHlbyeYQevEuTtTMbxKCfnL+zwxzjyaIsd/bhJ5OV2xulk
8uhL4j3TCb22Ms7nMu4+pf4LdHnmeVXze4mnj6j/Lrs6Xyx4fk19v2Ie2ET9
9jrRX9jAPPkj24G3Wf8Jxlkqz6G/T/lD6nPWCbvW28Gby9gu7qE9XdnvqOLA
OKce2+GbHBhHP8p+TTPGS6rdxr0s5GGmS/FTyrGw3W/L8vJdKo+ZzzGucLBf
zfPfPSjnuIBnb57rKnSpeBK5yAVch1EuccGv+YyD1HPB6wXGvdnPmcj4fIb9
uOXMB3PZr0nFPXjGftcXDvj5Vd43sN+h7hOQvx91qPsEcI8g43Uy+y2NmK/G
ulR7Zt4vgPvBeQ45QP2K6NdUv83Mx1JuGfuRXifGvcNd7AewfcugP19i+9KT
/aIJ5jlt9ouW6u+l3m1sfzJo7xHy5EH242vR7/fQP/Uo3+VCHF9P3O6hvk3Z
H2zHfl1ryvfyuyy+14X45FDvB/h+IZ93Ip9s+nuzv2ref4B7+cijtvx7wsV/
J4D2jqYdKRn3nrmUfeLHF3T54o815PV99Me7Wjb77yL/26XGN6Z/pd79/Pt4
6nOa/We/65/jB59LjT9Mfkq++luXL/qfdSm+muMdqWcC8fiJfvmQfD9Cnn7C
cdrP5Mkm/b08X0+cL+G/w7OB/fYG1GczcW3Jf6fmM+LRluOpb6hvO84P7HUh
3zzG8dRlfO9x/js6Vd1qfCvtTS3KPTjev5bjrt6s/0Y3cH2cclO3Gp/jHlE3
7M4xx8tu3gPvVvebSP4t5XivB8vxc/yf0lPsec2N9rEf7VzL+Qsf5yl+4W+E
//7SCS2Lvmcpx/j9OeIRdcNPNXivTQXnQWpTLuX3rXkP0lA3/HcX7xEy7WzH
55lu8PZeD/JnLu3vxHuS8vh+N/3cnH8y75uR90byXqAA/z2jbM53hWjHMA/8
Vqm/F56Mob4jKY/jfTUx/e9ViZ6jPMDzv/THBC3L97M96t9jknr+S3kBcV/i
QV592a3m43A/Fp+v5PzhdJb/nkfdt2PO/0kcz2R9O/T35nyh+b3g8A3re4Xy
Aa3P/wF0yRoU
              "]]}}, 
           {RGBColor[1., 1., 1.], 
            PolygonBox[{{{538.5090715034606, 568.7105746996907}, {528.809, 
              538.8589999999999}, {554.2020729483969, 557.3083203441713}, {
              554.2020729483969, 557.3083203441714}, {579.594, 
              538.8589999999999}, {569.8952096853275, 568.7101584538358}, {
              569.8952096853276, 568.7101584538358}, {595.2890000000001, 
              587.16}, {563.9007641172633, 587.16}, {554.2030000000001, 
              617.008}, {544.5040900715301, 587.16}, {513.117, 587.16}}, {{
              637.3860620645678, 551.273238537617}, {627.6880000000001, 
              521.4219999999999}, {653.0795450860053, 539.8713203441714}, {
              678.4730000000001, 521.4219999999999}, {668.7728026714439, 
              551.2739323339763}, {694.164, 569.7230000000001}, {
              662.7778943725049, 569.7230000000001}, {653.0780000000001, 
              599.5740000000001}, {643.380015431467, 569.7230000000001}, {
              611.992, 569.7230000000001}}, {{731.7349490873759, 
              516.9356405308232}, {722.035, 487.08599999999996`}, {
              747.4284549139948, 505.5337924817798}, {772.8199999999999, 
              487.08599999999996`}, {763.1221861348666, 516.9349467480281}, {
              788.516, 535.383}, {757.1284809592055, 535.383}, {747.43, 
              565.234}, {737.7296091390695, 535.383}, {706.3439999999999, 
              535.383}}, {{438.10479031467247`, 568.7101584538357}, {
              428.40599999999995`, 538.8589999999999}, {453.7979270516031, 
              557.3083203441714}, {479.191, 538.8589999999999}, {
              469.4909284965393, 568.7105746996907}, {494.883, 587.16}, {
              463.4959099284699, 587.16}, {453.79699999999997`, 617.008}, {
              444.09923588273676`, 587.16}, {412.71099999999996`, 587.16}}, {{
              339.2271973285562, 551.2739323339763}, {329.527, 
              521.4219999999999}, {354.9204549139947, 539.8713203441714}, {
              380.312, 521.4219999999999}, {370.61393793543226`, 
              551.273238537617}, {396.008, 569.7230000000001}, {
              364.6199845685331, 569.7230000000001}, {354.92199999999997`, 
              599.5740000000001}, {345.2221056274951, 569.7230000000001}, {
              313.83599999999996`, 569.7230000000001}}, {{244.87781386513328`,
               516.9349467480281}, {235.18, 487.08599999999996`}, {
              260.57154508600524`, 505.5337924817798}, {285.965, 
              487.08599999999996`}, {276.265050912624, 516.9356405308232}, {
              301.656, 535.383}, {270.27039086093055`, 535.383}, {260.57, 
              565.234}, {250.8715190407944, 535.383}, {219.484, 535.383}}}]}},
          
          AspectRatio->Automatic,
          ImageSize->{{128}, {85}},
          PlotRange->{{0., 1008.}, {0., 720.}}], ",", 
         GraphicsBox[{
           {Thickness[0.0015625], 
            {FaceForm[{RGBColor[0., 0.13725500000000002`, 0.5843139999999999],
              Opacity[1.]}], 
             FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0., 
              341.99399999999997`}, {640., 341.99399999999997`}, {640., 
              21.99399999999997}, {0., 21.99399999999997}}}]}, 
            {FaceForm[{RGBColor[0.996078, 0.796078, 0.], Opacity[1.]}], 
             FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{169.602, 
              341.99399999999997`}, {489.60200000000003`, 
              341.99399999999997`}, {489.60200000000003`, 21.994}}}]}}, 
           {RGBColor[1., 1., 1.], 
            PolygonBox[{{{100.95657021107493`, 342.00394621634484`}, {94.133, 
              321.002}, {112., 333.98146020820417`}, {129.86700000000002`, 
              321.002}, {123.04342978892507`, 342.00394621634484`}, {140.914, 
              354.98599999999993`}, {118.82553709630494`, 
              354.98599999999993`}, {112., 375.99399999999997`}, {
              105.17446290369506`, 354.98599999999993`}, {83.086, 
              354.98599999999993`}}, {{140.95657021107493`, 
              302.00394621634484`}, {134.13299999999998`, 281.002}, {152., 
              293.98146020820417`}, {169.86700000000002`, 281.002}, {
              163.04342978892507`, 302.00394621634484`}, {180.914, 
              314.98599999999993`}, {158.82553709630494`, 
              314.98599999999993`}, {152., 335.99399999999997`}, {
              145.17446290369506`, 314.98599999999993`}, {123.086, 
              314.98599999999993`}}, {{180.95657021107493`, 
              262.00394621634484`}, {174.13299999999998`, 241.002}, {192., 
              253.98146020820417`}, {209.86700000000002`, 241.002}, {
              203.04342978892507`, 262.00394621634484`}, {220.914, 
              274.98599999999993`}, {198.82553709630494`, 
              274.98599999999993`}, {192., 295.99399999999997`}, {
              185.17446290369506`, 274.98599999999993`}, {163.086, 
              274.98599999999993`}}, {{220.95657021107493`, 
              222.0039462163449}, {220.95657021107496`, 222.0039462163449}, {
              214.13299999999998`, 201.002}, {232., 213.9814602082042}, {232.,
               213.98146020820423`}, {249.86700000000002`, 201.002}, {
              243.04342978892504`, 222.0039462163449}, {260.914, 
              234.98600000000002`}, {238.8255370963049, 
              234.98600000000002`}, {232., 255.994}, {225.1744629036951, 
              234.98600000000002`}, {203.086, 234.98600000000002`}}, {{
              260.95657021107496`, 182.0039462163449}, {254.13299999999998`, 
              161.002}, {272., 173.9814602082042}, {272., 
              173.98146020820423`}, {289.867, 161.002}, {283.04342978892504`, 
              182.0039462163449}, {300.914, 194.98600000000002`}, {
              278.8255370963049, 194.98600000000002`}, {272., 215.994}, {
              265.1744629036951, 194.98600000000002`}, {243.086, 
              194.98600000000002`}}, {{300.95657021107496`, 
              142.00394621634487`}, {294.133, 121.002}, {312., 
              133.9814602082042}, {329.867, 121.002}, {323.04342978892504`, 
              142.00394621634487`}, {340.914, 154.98600000000002`}, {
              318.8255370963049, 154.98600000000002`}, {312., 175.994}, {
              305.1744629036951, 154.98600000000002`}, {283.08599999999996`, 
              154.98600000000002`}}, {{340.95657021107496`, 
              102.00394621634486`}, {340.95657021107496`, 
              102.00394621634484`}, {334.133, 81.002}, {352., 
              93.98146020820418}, {352., 93.9814602082042}, {369.867, 
              81.002}, {363.04342978892504`, 102.00394621634487`}, {380.914, 
              114.986}, {358.8255370963049, 114.986}, {352., 135.994}, {
              345.1744629036951, 114.986}, {323.08599999999996`, 114.986}}, {{
              380.95657021107496`, 62.00394621634486}, {374.133, 41.002}, {
              392., 53.9814602082042}, {409.867, 41.002}, {
              403.04342978892504`, 62.00394621634488}, {420.914, 74.986}, {
              398.8255370963049, 74.986}, {392., 95.99400000000001}, {
              385.1744629036951, 74.986}, {363.08599999999996`, 74.986}}, {{
              420.95657021107496`, 22.00394621634485}, {420.95657021107496`, 
              22.003946216344847`}, {414.133, 1.002}, {432., 
              13.981460208204187`}, {432., 13.981460208204194`}, {449.867, 
              1.002}, {443.04342978892504`, 22.003946216344875`}, {
              443.04342978892504`, 22.00394621634488}, {460.914, 34.986}, {
              438.8255370963049, 34.986}, {432., 55.994}, {425.1744629036951, 
              34.986}, {403.08599999999996`, 34.986}}}]}},
          AspectRatio->Automatic,
          ImageSize->{{128}, {85}},
          
          PlotRange->{{0., 640.}, {21.99399999999997, 
           341.99399999999997`}}]}], "}"}]], "ExerciseOutput",ExpressionUUID->
       "d3c05f56-497e-459c-8902-4680ebec5bdd"],
      Apply[TextCell, 
       Cell[
        BoxData[
         RowBox[{"{", 
           RowBox[{
             GraphicsBox[{{{{{{{
                    Thickness[0.00078125], {{{{{{{
                    FaceForm[{
                    RGBColor[0., 0.321569, 0.5764710000000001], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {0., 800.}, {1280., 800.}, {1280., 
                    0.}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0.996078, 0.796078, 0.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    400., 800.}, {560., 800.}, {560., 0.}, {400., 0.}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     480.}, {1280., 480.}, {1280., 320.}, {0., 
                    320.}}}]}}}}}}}}}}}}}}, AspectRatio -> Automatic, 
              ImageSize -> {{128}, {85}}, 
              PlotRange -> {{0., 1280.}, {0., 800.}}], ",", 
             GraphicsBox[{{{{{{{{
                    Thickness[0.000992063492063492], {{{{{{{
                    FaceForm[{
                    RGBColor[0.141176, 0.290196, 0.647059], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {0., 720.}, {1008., 720.}, {1008., 
                    0.}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0.815686, 0.65098, 0.313726], 
                    Opacity[1.]}], 
                    FilledCurveBox[CompressedData["
1:eJxTTMoPSmJmYGBgBGJPJgYGMJuFmZGZmghoOnUNHBArqOXOoeLUYYBIDWpc
6kejjKaIkuCladQM13inir+IMQRNDS4uFcMZv1EAebsRkw==
                    
                    "], CompressedData["
1:eJyNXQm4jeX2V8mcqUEaFJcUlQpJlE8RoZIpB+fgDPucs8+4z57n+chViJt5
SJRcEVFIKiUpQxINhkRlKJEUSvLfe/1+3/s+8Tx/9z7Pvfuu833f+671W7+1
3vnVNLusX95lVapUuST137eqValyaep3h+fwLXcf8hgdl29wvTPfbZwvf/fS
9HU3V/Made94feax1W5j4rVVB9Vt4DXSj2e/4zaqpP9zg9cYkttp7xNr3cbL
qdeXPOQ1Hqz15dzyzReX2+xpXi061It6d7pRboGWtzbb9UfIpWV5/zmv0bvD
6K4jNrqNj9L/Z5rWR+QXvcaNaYWWUr8tXqPHPt9Vi6dfXBY7f/IaV8bf+2TO
c27j/nTBx/Xzhum/n/Li7y+5jcmlqb9U9RnJn55c2WSR23gjrUdDLYv+N2tZ
7G/mQz2rtCx6rNPyr9sey66/hd/f6jP8Vy3usW8nn9/jM4oPnllw/IDb6JnW
6wEf9DvhNm5eUlHwXH/Wd+bi8gNpP9h8xg1pvKp7jJ8DXdpnOXzAt7EHfnX7
jJT0w9ZWHsP9zuzr2jzvQzkdPND7ZR9wv98Dvd/0GSVp/Trr51JuNw9w+8wH
HLt4jKbpcs7q76Xey/x471E+v9wPHAZ58FvDbxQ8lyoxRz+Xesupb1M/yinx
GC92f/PE2c5++MXqAZ97XSjLr0/LgvfTHtiR7cfveNrfwY84mEl9a/uN1qOu
+XrLAo+xskkK2bp+xM9s/Vz4uEzrL/pu0M/l90OPcVea3z/71HPB+VOfMSXN
s088wG0v8f/agzja44Odqbj9LF3+Th/qP0V5m89oldbvHOvbTP7V9KKcj8i/
q7yIrxUXyuL/ZlqW7+72Gu//fuuwcct9iJeOXtg37zz5P1oWWMZeKO994tnJ
pT21LDg/Rf2eo745jMs5Whb+L9Xyt+ly3iJe5Vpf+Q1rfcVPY7UsfHrtQlnw
+4TlbbhQFr7UoX/PeoFbQ79xRVqf6sS9kZ9/90HfO/yIu8Y+vNeBfL6ccf4Q
+ZXKO/K8hx/xncpLEv99/caqtP77vdBjsN9Yn3bsV8TL5idPiKfLj3oP0x8B
8vOE10irvyTkRznX0u5nyf/bfbBruh/xa5CXL/uBcy8f4nSB3/ggjdsQ5o1F
LM/qQ/nL/cjfHh9+12tZ7PpSyxKX+/1G5luP1rl0nJaFHzO0LHotoN8P+2Fn
Ku8IbueId4oHgstVAei1hry6KQC/pfwoeNwSUN9LHN8RwHtzWV57LUseeCig
9BG8nwwAh+dpryUAfj3D98v1c9HbHwAvZvN5JAA/v8Y4Hh/Aey+Rpy8E4K/p
9M9C/VzagcW0b5UPfng9gHjdRPvfDMCOgxeXpdxVAeDymw9826ZliaOftCw4
7yR+Vf2w62AAONSl304GyC8ti7+bmXEShD9uMOMiiLx2Nf3cPoj3mzNv3hoE
Lu30+1JuNz7/k/pk+eGf2kHgUeFHu3cjv68kr5sHget88r5hEDj+l3n5kiB4
tkjbZ74v/vue9r3FON5H+7b4FT4Sj7v8aGePBcDvvX74u2rQOJrWYz/j5lYt
S3y0pX1HyPMHg8D/JON6ZBB56y8tC57XBZQs5XQgLsVB+LtTAP4vD4LfvQOw
0x5EOzpUy5J3gwH8PS8IPj8bQP9nUBB+mhkA3l2DwO0Nfv9A0Hg6jf87Abbz
QeC8gXF0exA4fEVeXUN99wYU/vLegQD8l8JP4vSwlqWeP7QsPKhFPc8GgM/J
gJJFz6b6uejfO6j8J3mm34WyGS/Cp+ILZcnL1gDsiZA3A7Us8dNVy+KnVrR7
kn4u380lbwcTh6VBxFUW9f9Yly883k0/PsZ8dYx+7EG//0V7WjI+q4aAV3X6
sU4I5fztR71XhcDvOuRvyxDqvT6A/H9/CH5pEgCve4TA97v083/Ye3tI6W+W
J++7AuD7PSHY+Sz9+EAI+EyiPd1D8PscXb7kiUUB8KVNCH5/OwC9m4fQP9zM
/NY+hN+9ujz5Paf1Fz5cEUScdyEeNwSRfztQvy5BVb+U11u/b8aDWb7oUxrE
72AtC77ZWhY9S4hPIIh6IyH4awz5/3QIPJ3K+B9PfRYy3haGOK7QsvB+g5al
3C3k2WotC4/Xa1n8tZX67WR9B0L4+27mm6Mh4LY3CH6dJB5nae+lYdTTgHYc
p34tyLt9IeRJIwR8d11cFjsyqecX5E+xfi5526fLRz8ipPSX9mIu9fya+q8I
gY8b+fcd/7uMcZmuz5TFTz9p2cRH2tNvqUfNsCoPOIVh38eMs8ZhtishtFfN
w4iHbYy7dsT3MP3cTctSf9cweFYlrGTB81otC19vCYOvXcLgwX1axjhMy9Lf
sFDvNlqW3yZalnxfN4y8WREGH6qGwYNoGH77K4S4GRcGL06EkK/mhBV+Ys/0
MOz9JoT27Pmw4qcpm/wVPeeHEf8biPfKsPKX8OCdMPzynpbFH8u0jHErebaO
+s0krjvCwHsK+XiQ+ExkvvolrOLVlLPSPPRr2Yx3+e7nMMZ9eeTXibDKF6Ln
6TB43YvvXx5R+exisuB9dQT21QuRDxG0w81C4NdXYfW+2L01rPKvfLc2rPKd
fP96WOVD0fO/4X/m3/9HNv0l7WQr2jtKy4K/R8uCd2FYtU8mfwT36uT9FPrr
Us0fs70zZfQXtCx54cug+t5sPwXvZ8jjLUFVn/BwbVDpZ7a/Yl+uloVnT2jZ
jB/BcZWWRY8FwX/G11T2O/uR/9PNfhj5NFbXZ/YfzPiS/BDS+op/xgRVfJnl
m/Ek781h3p9H/49m3n+V8ZHqF5rxY8qSPz7Rsvh1l5bF7n1aNvku8egJwo9/
h//Z/6kRUc/F/prka07Q8Kaqq1E7gvh7LGhsT4dFwwj07037G0dg38NBY9LD
Y4oP3hwBfzsRvxYR4Nye9d8SAV6pfvax+SkEbo1A3+uCRuc00LdHEI9Xs7y2
EcTrjWzXO0XQH24RRPvxSATx3Zr4944A15vZLj6hy3s+Xd6gCMY9qX7H+bLw
ejDj94eAYX3bMfFaB+N124Wy8N4dQVyu07Lw5C0tCw6vBYx1aQf5iecC9gNj
Eej5asBI0+XUaP2++Geyfn4x+fO0f+ZEOO7XsqmfKYu/tweMm9KOeimCeN9J
fRdpWfRYrmX5fl2E82L8fkNEjRcEn80R8D41DihM+2Mn+fF7wEixbrvne/Lj
54BxewqG+Uc13oJLjagq/2Ky8LNaFPzZFDDqD05FXt0o7EiNw9OsGNUoivom
cxzS8n+XpfzboshHIfqndRRx6GC/9c4o4qWQ+HWOMk8Qv4ejaI9LA0anNL97
UX8vxy0DosiHowKIv0wtD01/b9HysHEpDYsvlCW+ntOy5MkZ5FtOFHbN07LJ
D1M2+WF+b8oS3yVRxRfxb1lU+Wteecpyt36eds/8oPaH5Lu4Lk9w+HcUcbZC
yyZ/TVny7xzyZVIU8RwIGA3S/p0ZNXzp8l0cZ74URT02+mulxlvKWaO/T9N4
5QdRtIOjie822jOO9mzV34uenxK/x6nPJurXm/H7BfmSGmdJvvo2ivbs3gDy
5f4o2vn6AeS3r8nParo+yVtn/OD3ZtZ3Wsvi3x+0LHhv4/zGxijGYWv8yh7x
2+t+VZ/wdL4f/N0T5fyXlsX+57Us8f5vP/A6EEW9GReXJR/9RH7f5gcfDhPP
Jn7kgUOMj6v8RtoNPX6g/Zf4wcdfWd5lfsTvOfKjmh/4Xxq7QBb8j/uUjPke
nzE3jW+1GPT53KfKE75s5HzeacbvB5x/O0H8X/EhHs5E1fyjWb70Z2b6oH+N
mJpfFD/XjKE9GuND+1Y7Bv5FuM5zTQz+KvEZnnS5TWJq/nVFuvwWMfg3xvnp
W2JoL5/2gf+36/IFh3ti4POznA/soPUR/e+OKf0lH7Umfkt84N9tMfjjHc6f
tonBj+t9Rq80Xu2p3xYfcLovBr4cvrgs9neN/dO/vfVz4enAGPLFVh/yy1O0
/yuf0Scdf1lalv5QnpaF3wUx5U9TNu0xZdNewcEdAw7LtGz605RNvLEuRfwG
/u+y8K8D/R2Lqfl80WMM8W3mMzLT/vl3DLjdRP8mY2q94sM0XtEY+FhVlyf4
HfMqWfT9XstYn/Kq8sR/27n+EGJ9H3uVveL3d7zgs4P+WupF/HoYX3O8yK/B
GOfJuV7jJ78rvfhuFMu3e9G/mkD8R3jB7+doz2AtS/m9tYx1Va7vzCR+rbQs
8XOjliVO6nHd+aWYWm8T+xax/LMexO/yGMZTf3qg75oY+nP7tSzt1XYtSzvw
kYc4xTAemHdx2fxe2oMZXI9dr2XpD2/RsvB1O/032gNef0l/z/YgfnYSv+W0
7zv6awXLP0y83/Yg/x0ln973IP/9GUO9mzzoz1WJQ+91HuSjanH1vfSbr9Cy
xM2VWpb80ljLgn+7OOfBLi6L/p3199L/MeLw13wP3usW534Arm/3i4NfXg/6
e72ofyn9+zDLz9Gy+ONx+qOPlgWXgVqW/J15oSx8N7Qs/mnrQX4bHgdfbuX6
siUOvt7lwd9L4shX9xHfijjyQycP8p1Tvy/6eOLg9S0e5OeglgXvZBw4NPEA
h2fi+O4ari+Pi+P3evJrov5efqfo+iT/LtD6XEyW/sF7cfD1EQ/6/x9rfATv
bfp9yW/f6PouJosd32t7xM59cfDmcv2+tG+/u+HPXfTXabd6LvnoW7f6Huv5
+n2s97uRX3fo5xJXn8a53u9W9p0vC2/f0LKMf2a70f/7II7+0zQtSxyP0rLw
1aFl0cdNfd+JI87K3ODXyjj0zud+lzfjaK8yuB/nXcbLU27k7w3EY4Ab8f0h
46erlqX/fK+WhRe3a30kfq68uGx+L7yvxv1Kq7Us7y/RsvD3FeJX043+48tx
zJecccHOl+Joz466kA+mMr6+cqE9m0u8NrrAk8XUZ40L8bSQfHlDlyf1L3Eh
f84mXgtdaM+mky/jXUofaS+fdqH/8TrxibiUPeInj0vFh9RT4kJ//8U49ilk
u1T8SXszRMvCj15alvrud8HO8VqWep4mfzq4wIsw8WjnQrvnI19ucqn8IP6v
6lL5QPLVYaexP+34CXGMZ486Fb6mLLi9cKFslncxWfpnqxifl7hUvjBlk5+m
bOYLUxY7viK/a7pUPEs9DVzGL+l4OKrtNWWso2nZ1F/8dpz8P+5EvjxN/h9w
wt/n6N/dTvDykgTw/94JflVPwA/bncjHdRLg2wdOjLfqJoDzZ07EdUP9vXzX
KIHx+ikn/HZTQtkn9bZMgO+/OcHPOxMYL32jZbM88W8HLYseXbQs7f1DCWWP
KYteW7QsfF3rxHxEby2LfgO1fRIfIxJon9c70R8YmQBOq8iPvATid6ET8z1W
2jOLeBQl0D684MR4wqZl5D0tS74Laln6Q1FdvvApmUA8v0l9x2h9JR6fS6D/
t8wJfk1OID/PJX5zE2i/XqZ/Xtb2iL8XJPC7ifx5U+Mp7cUajYfk/3UJ8G+p
E+3HJ1oWvnyWQHwsZnlfa3skf36nZeHjQY2f5LMjCbSP44nnn+Sb3wkcfqH/
ihjfB1j/UPp3ZwL8767rk3xnnFf+/eTT8QT83N6JfHuK/L+V+J5NIG9cR//U
TwK/q1l+4yTyX0OW3ywJf9Qjfrclod8VTuDYNgn9b6Q/H0iif38H+ddTy2LP
I0mMcxoRz+5JrF9fSn70SiIefnRcVBa+9mP9H2lZ4nOVloUvrzqAR98kxicL
HMArM4n8OtUBnIqSyDOjHcCnMMl9Xg7YZ08ivsc6YF8oiXw1i+VFksgX87Us
/FmuZSl/74Wy9O/HJVHP9w60X88n4d8jDsTX9CT6o785wNfXtT8k36zUeEo+
fSfJfbcOxO+HSbRffzrYDicRX+dY/mdJjFcuZ37YrWXh934tC48OaVnaw191
/WLX35pf4u9alYqPpiy8bEZ+NahU70t8XluJ+KquZdMeaUeuqlT4CJ71KlHu
fv1c/v4x8W2iZewX0rL4uTXrf1fL0r4t1bLE9zwH6rmjkvuqHeD3nZXAoZJ8
uqsS+SigZewrdCC+jEr4sdSB/Na3kuMQB3j9WCX8018/l/h/hOX1rwRf7tOy
/N7pQPvWS8vir65alvn7B6nfLQ7Y/QD1udYBf3eqBL9qa/sEj8svlGX831S/
f75s+s+UTf9IfFbR/pN897sd+lSnP7+1I96uqAQum+3IIw0ruW9Vy4LXa/p9
4ct8XZ7E+2w7+jNVWZ7brviKfpod8X86iTgZZcffjyfhv4Ad7dNPSfW98PiH
JOLGZod/Dybhrz52FR+SPx7U9Un5d9uRfy8h/k0ulIUXden/kxUXyGY8SX48
WqHsFZ5/W6HsFTs+r0A8nGF+WqmfSzwvq1D4Sb5cVIH5pBr0x/gK9KfPJZUs
/DylZfHnEebrKRUKL8EpVgHe/cj8VVKh8JP2p6JC5R+xw0n7trP9cFeo/GaW
Z+Y/szwzP4r/n6qAP5Yy3z9RgXJeTmL+qF8F+r8zmF8HVCBO5iSh5z0VaH/m
JlFuc/291NdIly/5oerFZelfrEqiP3vSpmSpb7eWpfy1NvhjOdvjD2yYj1hM
Pn5hA19eYXty2KbsEd4dsKn2Q/j6mQ28mJpEfl1tg/+nJLnObYO+Y7Us/ohr
GfvC6e9JNvz6yecxNuQPF/WL2KBXGdvnEi0L33K0LPgMtgHvkiTWjx+zcX8w
28NeNtQznPzqaVPtueS5VheXhS99yK8WNtW/EDwa2dCPepTtZS39vuTb38pV
f0fs/rUc+LYh/sfKwfdbaP/uctWfkvo+LUc+vDGJ/Lm2HH65gf2HFfp94euC
cujfkvXNKEcc305+2MpVf0zwLCzH/O39SfTHR5TD3wbxzSqHv7vQnp7aHim3
bTn43576/kt/b8r/wC8li7/70783loOPTySx3lG7XOH73+Opgn8pU7I8/6kM
fH6I/t1Zhn5jxyTnb8qUPufLT6WBma3ldNjMdZQhju7TssTDXUnj2XRA5Jap
/qzoM0DLUv+DWpb80kTL2OdZqvwr+NcsU/6sSDvyu1LYd1XSSP1v/+/WlALv
mlrGvhvqt6FUjQ/SaXTY56Xgwx9aNvvzA9P2nihF+34ygbi8sgx+OKxlyc/7
EsindcvUeMLUV+Jna8JIf7bnUOlFZdHng4TSV/j5ccI4mQqn9xeVYj5jC8cj
E2jfpgTyZD71X8vxTkkp8uiKBPfhlCJ+XkgYabc/8FAp+D5FPzfHh8KXuaVq
vNmiWvT5hz8oxfjJlwA/YqVqfGqWJ/kznjAGpQvuUarGp3I8p3op54nM8WGJ
Kt+UzfIwPixR42Epb7qW7WkDx5TwXFXCsElCKEE5pcRrYAnay5KEsS3tn+tK
/jmerlqi9JPyjhWr8bPwdbmWRe//aFn8b9ey8KV/MfgxXssSv9O0bI6vpf7B
xah/HvEPFavxNvY9FaP/8RbtWcX6VpNvpcVqvC3++ZeWpX93tkiNv2Wcs6dI
8UXwXVOkxt8t767x6g0TihAfXyaMbilan4kWAe89CcSTrYj7CRPGzj9C1rcP
WS+QzfG7+GO3Ffl9B/kyge9v4vxBwspxJfH0WxV/0d+wAo811NdphX2rEhj/
WLUs/BtkRfwvTxjvpuOpjxX2L6A9Ha3ojy3U9cn6yCzOL+RYEW8TWd7jVug5
IYF8dq0VfI0S7zZW5CdPwhifDrROfN/O99dZ0U6l+Lkrjc/3VvgvxU/JX6es
an5IvrurCPGdneC+9CLok0E8A0Wwt7t+jn2vjNf+RWgP2tNfJfR/R/J7ehH6
Ka2IzwtF4Fcd8vEV8qMZ5+OeKuL+TPK/WxHar784n9tUy1L+7CLkmx/j4Gte
EeLxuzj6f32LwIffuZ7xUJGaf8S5lyKMZ36OA/+/rcinu+LA+1Mr2pfdcdi7
0KrmP0UfrxXjrZ/iih8iH4sDf8MKff7k/PO2QvDxUNxYk4K5amUh7N/M9ZXd
hahvTdxYmM4HdciXt7i+YyE/58bRPg63Ip5n8nmWFXhPj8PfPazIn5OoTzer
ms+W5w9b1XoV8gPtryQe/axqvUvi9RHGV5L632lF/MaJf+MLZXP9TPD/tRD9
ARfndw8VAp8y+uPDQuhnY/0vF6LfUhBHPI2mPILl2wrB1yFx8DVSCD4+SX8N
LUT89CS+7QrB4x60588C1NcpjvjZXoB4ac/y11K+m/jUKYR9reLGLWl+7CoA
/rfp73E+OY542FwAf7SMoz36qID7/ePI9ysL0G9twfnwpQXI3y25vjCnAP2v
e1lf6wLgdQ3x/Dsfea4O42FhPvhVI472/Ol8+Pcq1leQD/3rxeHHx/JRXx3y
uWM++P13DPhcmg++naV80gI8zsTgj8MWtX4t9n3K56diwO9DC/LH79wfs9qC
8eaRGPR5z8Lz5VzvX2JBfknJ0n7MtKD+1PeSn8dawM9U+RJPMQv6Ian6JZ/a
LdD/ZAx4DLfArlOUh1oQn9WJd2ML/J+yT/x1h0WttwtffstDfq9O+Uiewktw
/zMP49W6xO+HPPRH6pPPn/F5LcbnNv299C9W5yn/SX5cngd/XUt/ebQs+dGd
p9b3xf/ZedD3UtN/ecpfpiz8PxYDTh3yEHc1Tb7kga+/xpQs/jmkZelvHuR+
iyfz4JcfuH+hJ/H5nnI36rdLPxc+fKVl+f4TLUt79F4M7dm5XOC3Oob2/XQu
8FoRQ3/5RC70eC2GfFaF9S2IGbvT8l+5iP+5530/g/7dl4v2bpKWRf+JWjb3
u0i8/ZQLfo8l34/nwp5Run7hrz+GfFo9Dzx1xODP+pTLY8hn1xCPAq2v6Gfh
95cR/5HEv14e2oNC7pe5Ow/5JIv+eJT4ZxLPPpQHUt+peWo/l+TrWXyeEVP8
NL+X+KthQf9iKN9/0KLel/znsKD+h7lfap4F/Hgghvy31YL+W0cTL4varyY8
75XP+dUY4m9kPvzdnPnCm4/8dn0M45NX8tX+PNF3cz7PwZLPX+Yjfhuz/B/z
4a/U+5LfzvL7hqyvAfNvbdbXuIDzazHky3YFnA9jvuulnwu+4wtg72Wsb1YB
/n6W+2sXFwC/rVHE77oCzs9Hgc+GAuTfd6Oo/+MCtGertSz8fDOq2hep/40o
8NxXgHh/Pcr+SgH0WKJl4cWrUfDnXAHP5UaZvwuAx4tR8Pe3AuTT2VHw7wTr
mxYFf/8qQP6YrN8X/j4dVe2bxFsyyvmLArX/WPJdBd8vjCIeexYg/w6JKnyl
/90nqvwhfOhGPP/Mh70PUp8l9H/7KPg5Nh/f3x1F+xPOV/vBzeeS31pF0Z8b
lc95jSjao5x8+K9xVLWHEm8NuJ+4dT7sr8/9xC3yub4WRf5ulK/2twv+DfPR
HzkX+Wf7eSZCf1gQ7ycijHfGwy/6ueB3KKLaW4z/I7DvSwvH7zxf8YEF/d8t
PH+xlvG6MaLaW4mPjyOYj3zTgvmj9TzfsdjC8VoEPHqR76+lPI3t+bs8X/K8
heNDPp9lAT4rIqq9Fv8tjUDPqRb8fVGE84zsL8zneYMo8ZgWQf/Zx/Y6qb+X
8vysfzT1c/D8StiCeMqJwL9tLcjfmRHjoTRerSlnRMCvFsRrUMQYm47H29lf
6Ke/F3ufiCBeb2X/ohf13cH29dEI/P2+liU/vsf8fntEtc/Cj1YR+Hkw29+W
EdX+Sb5pEQGu9zIfN2V5zdleNqF8bZ463yP112X7eZWWBa96Wpb+f7UIxgs3
5anzbtJf+hfb/yNh4N8qT513Enzb0L5pPD/VMo/3BIRVeTJP+wzPZS7OVeez
xL55uVwX4fmqmbmcZw+j/zaB7Xl1nq97Npf7VrQs8/a/hoDDS7noD+3jubwZ
ueo8qfhpci70/jCEfFGsZfQHtSz+7nGe/HAu5mU3huD/drnA65MQ+NQ2F/W8
G2L/MRfzsvPN87w53BfK87ef50C/GSHki405aH+mhsifHOA5ifq+nYPvxoWQ
H5blAN/SEPLt1BzuK6D8LOUcngvNy+E8Bs8JdsnBulmY57jb5GBd2xVCf+tM
Nt7rT3s+zgbePWnP1Gyeo+U550Q22ucBrL+r/h7nvbIxj9TXPO87EnzoHkJ7
Nn0k+g+P0J+ZWpb6nhzJfcch5L+G/P4x6lt7JPToS3+dG8Fxawjt9+kRiK8s
6vfzCIWP+O+7EdBrdAjx32cE1zVCGG93HgH8JoSMYCoc3po6HOtkXenPg8PR
rpWTHzWGYx3KHUJ++SEL7UiQ/HyPcjIEvr+Ypfwr7bk3S/EtbXZyYyb4sInl
r8yE3zaHgOuUTLazIeNc+j/uTOg/MWTMSeMwIBPxGqD+fwxDeQUsr+8w2PMk
+ffrUODxcMh4NU3sFUMRXx1o76mhXEcJoR9TOhT+bxIyjqT17aSfiz4fDYF8
I7+fP0Sdd5fy3UOASw0+XzEEeP4VhD4vDuF4LWjUTsvThnAfVtA4kE5UWXx+
jPLjQ2Dv/iDz5hDecxU00s3cmdsysI6cHUT8d8kAn4exvl4Z0GcQz31OyUD5
A4PAa0kG1uX6B43mab5tzEC+7BNEO1ZtCNqfR1h/4yHqvhKxNzwE+ePPAOqb
MARxtofn4K6hfV8EDNkOdDID62I7Aui/rM+AvzcFwK+XMtR9DsKLsgzesxVQ
9gnPpgWMNKxv1cwAvyYHgNffg7nPheeuvhgMf40JQP+vB3P9j+cIvxnMdTzW
NzwDfhvK+11iGeDD4wHg9V4G+k+3BozHU93CjgOGsB0LKH+asvSTRw+F/Sf9
4H98mLrPSPb5lGTy3IAfdlkzUd/NAa4PZEL/RrxPY0YW130Dxg9pex9hfGUE
4I+yLHV/CPTJUvcTCX9XZKG+Itr3fhbyjzOAON6cxXNBvLfl2yzEj4lfxnDw
Zy7vJ5o4QuEt7cCWEeBfIIB8VXUk+FAYQD64ZCTnrVj/kJGwdxC/rxip7guR
/uA4/b58v2Ak+xnkw7sjec8c3++Sre4fkfp7ZoM/DwQwvu6fjfi/O4D+/ohs
rq8F0B7lZ3PemHyuyEb+ax3A/Ntf2eq+KCmveg74el0Aetpz1P1WUt4KPt/u
x3rFBzlcL+C9RHsor+M9QH+zvVvtR3nX58LvS/zI5521LPHzeC74sdAPfUv5
/BXeMxTIRf2zWN9o9l9m8t6iqbnqvi/B7Y1cpY/Y+0su5u/e571JzfJg/1ry
9Z48VZ/ZHxT/LPYjnoN50G+ZX43XcQ6E+nydp/CQ707nob5P+H1TC/Sby/sB
/RbwbRbff8UC/szwg2drLKp+c77OvK9M2ss9fH+eH/7/xQIe+3k/4P0cPzlZ
fl+Ob8r9iIcRHG8lqJ8zH/2d1PvCh4kcrxfQH4vzOW/H+ubp8jA/lg++FBGP
Hfn4zeQ5yyP58NdTfoxvqhUgPvux/hsL8H4bP/q31xWi/9aG/r2tEPW1Ir/u
L0T830R/P1qIv1/nV/PJguPVfvQXigsRL1eSb2MLkS/r+bn+UajuP5T5nhmF
iJeDPvB9WSF4860P64WfFKr7CkW/PSzvax/6L9dbYecWn1pfEv997MN8SU8r
2ve1PjVfL/xY7UP/si/XB970qfl+8z5A8UM+31/G+zBtVuD5Cu+xe85cP+C5
TLsV+ERY349W2Ffkg/+qc33pKZ9avxH9uvPetO5FwP8h3nfZpwj+6cJ72AYU
4b1OPsynDC5S5/ZEzi3CvGgjH9qfgiLERy0f/BEqAj8u0zL2bXi5XlCk7gnE
ekwR7Prci/7mGNb/qZfjIq43bfLCb4u5nrSS8pt8Pony60XwX5Ln4D7l+pmb
5+QOFYEfDpY/rFjd/4r1xGJ1Lk/GW08Ucx+Tl+szxew38/u+XA/u6kW8+orB
j5q8hzFSDL+e8ADHaSz/iIfr78Xg85ce+GOGlgXvV7g+vNuD/PFuMezb5QEf
PytG/KRk7C8o5nlt3jtapUSd28P+Yq6fv8NzXHeWoL4FPBd1XwnwWEq5cwlw
nUf9+pSAL2EP4vLJEp4r572g3UtgZ65HrceLvsN572o96tPfw/22XN/v41Hr
9ZJ/unjA51PFwLGzB+OZjcWI11Ye8GVvMdrn5h7Ew4FilHOzB/78pRj23sDy
Txejf9rQg/xUi3jU0XiJ/dWJV9MSnhvhOaOuJbwXwa3wF/zibvDtphL0J51u
ha/YW8Tn19O+4Twn1K5EnWMSfI0S5IUyt9ovId+1dSO/ni0Bjl3d6I9dWQr/
9KU+TUvRb8p0A497S6HvSDfw6FaKfDSM9woP1bL4y6pl0Ttaynsc3Gp/iuiT
Ks/cf2PaI/G8pRTj3UFu5ONd3L8ywI34Oar1Fb0uKUN9A3gurXEZ769xw447
uP+ojxu8uqcMfOpq4lUG/3fWsuSfO6hvRhni7QbqW1gG3Ou7ES9Pl6HeK6jv
OJZf2839KNzfU93N8xhlmC/5y8X9K9wP9ZWL/irjPdEu6HOojPMlLsT7CT7f
70J8/1YGPL53Ib7PUd8DLsRVtXLU84MLebdeOfftu6Dn1eUo9wzPIbXm85vd
4FXTcrbDvFe7Tzn42siN8oaXc18e/VFWDjyr0R/xcuBVxY12ZVQ58DjHc1nj
yxEff/Ac13/KeZ8Yz/VMKVd4CN/WlAPHTS7guL6c51B4burbct5b5QIOW8sR
d8tc3O9pg39XmfbbeI8uz4G14X7DJM99dbShfpdL7W/EfAG/z7eBv24X2wkb
7HDw3FzYhr8PZXnPUu7Pc2pTbGwHWP4MG++ldSE/LrKhf/iIC7x+jfs9e7jw
3XIb99FSn9Usvzf1+Yjl96Q+n3L/6MMu9PM+t/FcLc8JbrPhvfZ8vsMGHjZ0
IS/9bgNOB53Q5zLuH37LCb5cXYH3FjmRZ6/j/mfzXE/zCp7LcLI/VwGeznIy
7iiPcIL3Pbn/eKiTdnM/8QAn7H60Anx8wgn78yp4LpD6lHD/c3eeo3BW8N45
ngNKaFmqTfL99k7022ax/hZO3steAT81dHJ/ewVwuNKp9msLHvWdiIfV58nv
alnweb+C+1pY39EKnsuj/b9VwD/NnODp3xXQsw3rq8799HfQ3gZ26NmK50Ka
2dU5D+FbZzvvrSV+vc397Dy3FWF5p3juwWvHe5ex/DV8vxrPOW20835Tfr/d
Dj3rOLnf3Q47avEcyj7ut2/g5D39doUn7v2z855d6nfMznlKJ+LhDzvy5J0m
HtSvI/G9gudBDJ6DudMBvR5n+R0dqG8wy+/K8zdOJ+PQAb/46N+nHPBLiHhn
OrCelSSfShzAJcpzWA4HynXznJeP5Zc4ETduB/TMId+9Dug1nPil3pd82498
jNOenk7WS790J75Pa3vFv89o2TwPI/2BTk7E5fPm+RfybZJD8Qtx6FD4455y
B/hd26nOU4lefziAz3x+f8QBfF5z4LsdDvDkbZ4vWU079zngl3nE9QD1qXRA
v59pfwX99D3Pwwzkua/9DvD7IV2eKZvnj9DOU4/j1KOJQ51XwnyHrl/8cc7O
8y7EN8Uz83yW+OVSB/JyLeJ+KcutT16fsavzetIO/arjCvd729X72L9rx98b
k0efMU46M69+ZOd5I/2+4JtBeZkdfn2K5S+0I4+leI35Af0+5jP4fJh+Ljhk
kmeLqN8IlpcqX/KHlbyeYQevEuTtTMbxKCfnL+zwxzjyaIsd/bhJ5OV2xulk
8uhL4j3TCb22Ms7nMu4+pf4LdHnmeVXze4mnj6j/Lrs6Xyx4fk19v2Ie2ET9
9jrRX9jAPPkj24G3Wf8Jxlkqz6G/T/lD6nPWCbvW28Gby9gu7qE9XdnvqOLA
OKce2+GbHBhHP8p+TTPGS6rdxr0s5GGmS/FTyrGw3W/L8vJdKo+ZzzGucLBf
zfPfPSjnuIBnb57rKnSpeBK5yAVch1EuccGv+YyD1HPB6wXGvdnPmcj4fIb9
uOXMB3PZr0nFPXjGftcXDvj5Vd43sN+h7hOQvx91qPsEcI8g43Uy+y2NmK/G
ulR7Zt4vgPvBeQ45QP2K6NdUv83Mx1JuGfuRXifGvcNd7AewfcugP19i+9KT
/aIJ5jlt9ouW6u+l3m1sfzJo7xHy5EH242vR7/fQP/Uo3+VCHF9P3O6hvk3Z
H2zHfl1ryvfyuyy+14X45FDvB/h+IZ93Ip9s+nuzv2ref4B7+cijtvx7wsV/
J4D2jqYdKRn3nrmUfeLHF3T54o815PV99Me7Wjb77yL/26XGN6Z/pd79/Pt4
6nOa/We/65/jB59LjT9Mfkq++luXL/qfdSm+muMdqWcC8fiJfvmQfD9Cnn7C
cdrP5Mkm/b08X0+cL+G/w7OB/fYG1GczcW3Jf6fmM+LRluOpb6hvO84P7HUh
3zzG8dRlfO9x/js6Vd1qfCvtTS3KPTjev5bjrt6s/0Y3cH2cclO3Gp/jHlE3
7M4xx8tu3gPvVvebSP4t5XivB8vxc/yf0lPsec2N9rEf7VzL+Qsf5yl+4W+E
//7SCS2Lvmcpx/j9OeIRdcNPNXivTQXnQWpTLuX3rXkP0lA3/HcX7xEy7WzH
55lu8PZeD/JnLu3vxHuS8vh+N/3cnH8y75uR90byXqAA/z2jbM53hWjHMA/8
Vqm/F56Mob4jKY/jfTUx/e9ViZ6jPMDzv/THBC3L97M96t9jknr+S3kBcV/i
QV592a3m43A/Fp+v5PzhdJb/nkfdt2PO/0kcz2R9O/T35nyh+b3g8A3re4Xy
Aa3P/wF0yRoU
                    "]]}}}}}}}}}}}}}}, {{{{{{{
                    RGBColor[1., 1., 1.], 
                    
                    PolygonBox[{{{538.5090715034606, 568.7105746996907}, {
                    528.809, 538.8589999999999}, {554.2020729483969, 
                    557.3083203441713}, {554.2020729483969, 
                    557.3083203441714}, {579.594, 538.8589999999999}, {
                    569.8952096853275, 568.7101584538358}, {569.8952096853276,
                     568.7101584538358}, {595.2890000000001, 587.16}, {
                    563.9007641172633, 587.16}, {554.2030000000001, 
                    617.008}, {544.5040900715301, 587.16}, {513.117, 
                    587.16}}, {{637.3860620645678, 551.273238537617}, {
                    627.6880000000001, 521.4219999999999}, {653.0795450860053,
                     539.8713203441714}, {678.4730000000001, 
                    521.4219999999999}, {668.7728026714439, 
                    551.2739323339763}, {694.164, 569.7230000000001}, {
                    662.7778943725049, 569.7230000000001}, {653.0780000000001,
                     599.5740000000001}, {643.380015431467, 
                    569.7230000000001}, {611.992, 569.7230000000001}}, {{
                    731.7349490873759, 516.9356405308232}, {722.035, 
                    487.08599999999996`}, {747.4284549139948, 
                    505.5337924817798}, {772.8199999999999, 
                    487.08599999999996`}, {763.1221861348666, 
                    516.9349467480281}, {788.516, 535.383}, {
                    757.1284809592055, 535.383}, {747.43, 565.234}, {
                    737.7296091390695, 535.383}, {706.3439999999999, 
                    535.383}}, {{438.10479031467247`, 568.7101584538357}, {
                    428.40599999999995`, 538.8589999999999}, {
                    453.7979270516031, 557.3083203441714}, {479.191, 
                    538.8589999999999}, {469.4909284965393, 
                    568.7105746996907}, {494.883, 587.16}, {463.4959099284699,
                     587.16}, {453.79699999999997`, 617.008}, {
                    444.09923588273676`, 587.16}, {412.71099999999996`, 
                    587.16}}, {{339.2271973285562, 551.2739323339763}, {
                    329.527, 521.4219999999999}, {354.9204549139947, 
                    539.8713203441714}, {380.312, 521.4219999999999}, {
                    370.61393793543226`, 551.273238537617}, {396.008, 
                    569.7230000000001}, {364.6199845685331, 
                    569.7230000000001}, {354.92199999999997`, 
                    599.5740000000001}, {345.2221056274951, 
                    569.7230000000001}, {313.83599999999996`, 
                    569.7230000000001}}, {{244.87781386513328`, 
                    516.9349467480281}, {235.18, 487.08599999999996`}, {
                    260.57154508600524`, 505.5337924817798}, {285.965, 
                    487.08599999999996`}, {276.265050912624, 
                    516.9356405308232}, {301.656, 535.383}, {
                    270.27039086093055`, 535.383}, {260.57, 565.234}, {
                    250.8715190407944, 535.383}, {219.484, 
                    535.383}}}]}}}}}}}}, AspectRatio -> Automatic, 
              ImageSize -> {{128}, {85}}, 
              PlotRange -> {{0., 1008.}, {0., 720.}}], ",", 
             GraphicsBox[{{{{{{{{
                    Thickness[0.0015625], {{{{{{{
                    FaceForm[{
                    RGBColor[0., 0.13725500000000002`, 0.5843139999999999], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     341.99399999999997`}, {640., 341.99399999999997`}, {640.,
                     21.99399999999997}, {0., 
                    21.99399999999997}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0.996078, 0.796078, 0.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{169.602, 
                    341.99399999999997`}, {489.60200000000003`, 
                    341.99399999999997`}, {489.60200000000003`, 
                    21.994}}}]}}}}}}}}}}}}}}, {{{{{{{
                    RGBColor[1., 1., 1.], 
                    
                    PolygonBox[{{{100.95657021107493`, 342.00394621634484`}, {
                    94.133, 321.002}, {112., 333.98146020820417`}, {
                    129.86700000000002`, 321.002}, {123.04342978892507`, 
                    342.00394621634484`}, {140.914, 354.98599999999993`}, {
                    118.82553709630494`, 354.98599999999993`}, {112., 
                    375.99399999999997`}, {105.17446290369506`, 
                    354.98599999999993`}, {83.086, 354.98599999999993`}}, {{
                    140.95657021107493`, 302.00394621634484`}, {
                    134.13299999999998`, 281.002}, {152., 
                    293.98146020820417`}, {169.86700000000002`, 281.002}, {
                    163.04342978892507`, 302.00394621634484`}, {180.914, 
                    314.98599999999993`}, {158.82553709630494`, 
                    314.98599999999993`}, {152., 335.99399999999997`}, {
                    145.17446290369506`, 314.98599999999993`}, {123.086, 
                    314.98599999999993`}}, {{180.95657021107493`, 
                    262.00394621634484`}, {174.13299999999998`, 241.002}, {
                    192., 253.98146020820417`}, {209.86700000000002`, 
                    241.002}, {203.04342978892507`, 262.00394621634484`}, {
                    220.914, 274.98599999999993`}, {198.82553709630494`, 
                    274.98599999999993`}, {192., 295.99399999999997`}, {
                    185.17446290369506`, 274.98599999999993`}, {163.086, 
                    274.98599999999993`}}, {{220.95657021107493`, 
                    222.0039462163449}, {220.95657021107496`, 
                    222.0039462163449}, {214.13299999999998`, 201.002}, {232.,
                     213.9814602082042}, {232., 213.98146020820423`}, {
                    249.86700000000002`, 201.002}, {243.04342978892504`, 
                    222.0039462163449}, {260.914, 234.98600000000002`}, {
                    238.8255370963049, 234.98600000000002`}, {232., 
                    255.994}, {225.1744629036951, 234.98600000000002`}, {
                    203.086, 234.98600000000002`}}, {{260.95657021107496`, 
                    182.0039462163449}, {254.13299999999998`, 161.002}, {272.,
                     173.9814602082042}, {272., 173.98146020820423`}, {
                    289.867, 161.002}, {283.04342978892504`, 
                    182.0039462163449}, {300.914, 194.98600000000002`}, {
                    278.8255370963049, 194.98600000000002`}, {272., 
                    215.994}, {265.1744629036951, 194.98600000000002`}, {
                    243.086, 194.98600000000002`}}, {{300.95657021107496`, 
                    142.00394621634487`}, {294.133, 121.002}, {312., 
                    133.9814602082042}, {329.867, 121.002}, {
                    323.04342978892504`, 142.00394621634487`}, {340.914, 
                    154.98600000000002`}, {318.8255370963049, 
                    154.98600000000002`}, {312., 175.994}, {305.1744629036951,
                     154.98600000000002`}, {283.08599999999996`, 
                    154.98600000000002`}}, {{340.95657021107496`, 
                    102.00394621634486`}, {340.95657021107496`, 
                    102.00394621634484`}, {334.133, 81.002}, {352., 
                    93.98146020820418}, {352., 93.9814602082042}, {369.867, 
                    81.002}, {363.04342978892504`, 102.00394621634487`}, {
                    380.914, 114.986}, {358.8255370963049, 114.986}, {352., 
                    135.994}, {345.1744629036951, 114.986}, {
                    323.08599999999996`, 114.986}}, {{380.95657021107496`, 
                    62.00394621634486}, {374.133, 41.002}, {392., 
                    53.9814602082042}, {409.867, 41.002}, {
                    403.04342978892504`, 62.00394621634488}, {420.914, 
                    74.986}, {398.8255370963049, 74.986}, {392., 
                    95.99400000000001}, {385.1744629036951, 74.986}, {
                    363.08599999999996`, 74.986}}, {{420.95657021107496`, 
                    22.00394621634485}, {420.95657021107496`, 
                    22.003946216344847`}, {414.133, 1.002}, {432., 
                    13.981460208204187`}, {432., 13.981460208204194`}, {
                    449.867, 1.002}, {443.04342978892504`, 
                    22.003946216344875`}, {443.04342978892504`, 
                    22.00394621634488}, {460.914, 34.986}, {438.8255370963049,
                     34.986}, {432., 55.994}, {425.1744629036951, 34.986}, {
                    403.08599999999996`, 34.986}}}]}}}}}}}}, AspectRatio -> 
              Automatic, ImageSize -> {{128}, {85}}, 
              PlotRange -> {{0., 640.}, {21.99399999999997, 
               341.99399999999997`}}]}], "}"}]], "ExerciseOutput", Selectable -> 
        False, Copyable -> False, Editable -> False, ShowCellBracket -> 
        False]]], " "}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Center}}},
   GridBoxBackground->{"Columns" -> {{
        RGBColor[1, 1, 1]}}},
   GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{1}}}],
  FrameMargins->0]], "ExerciseOutput",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellFrame->{{1, 1}, {1, 1}},
 ShowCellBracket->False,
 CellFrameColor->RGBColor[0.85, 0.85, 0.85],
 LineBreakWithin->
  Automatic,ExpressionUUID->"48ef6d41-3747-4fe3-99b8-67a38dc4535e"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Make a graph of the 2 nearest neighbors of each color in ",
 Cell[BoxData[
  RowBox[{
   ButtonBox["Table",
    BaseStyle->"CodeLink"], "[", 
   RowBox[{
    RowBox[{
     ButtonBox["Hue",
      BaseStyle->"CodeLink"], "[", "h", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"h", ",", "0", ",", "1", ",", ".05"}], "}"}]}], "]"}]], 
  "InlineCode",ExpressionUUID->"f58a084c-3574-4f60-826b-f8e4ab81ba3b"],
 ".",
 StyleBox[ButtonBox["\[NonBreakingSpace]\[RightGuillemet]",
  Appearance->None,
  Evaluator->Automatic,
  Method->"Preemptive",
  ButtonFunction:>(SelectionMove[
     ButtonNotebook[], All, ButtonCell, AutoScroll -> False]; 
   FrontEndExecute[
     FrontEndToken[
      ButtonNotebook[], "OpenCloseGroup"]])],
  FontColor->RGBColor[1, 0.501961, 0]]
}], "Exercise",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellDingbat->Cell[
  "22.10", "ExerciseNumber", FontColor -> 
   RGBColor[0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]],
 ShowCellBracket->
  False,ExpressionUUID->"c2b22cc7-af72-4898-95de-9732b372ae81"],

Cell[BoxData[
 PaneBox[GridBox[{
    {" ", 
     StyleBox[
      RowBox[{"Expected", " ", 
       RowBox[{"output", ":"}]}],
      Editable->False,
      Selectable->False,
      StripOnInput->False,
      FontColor->RGBColor[0.45, 0.45, 0.45]], " "},
    {" ", 
     InterpretationBox[Cell[BoxData[
       GraphicsBox[
        NamespaceBox["NetworkGraphics",
         DynamicModuleBox[{Typeset`graph = HoldComplete[
           Graph[{
             Hue[0.], 
             Hue[0.05], 
             Hue[0.1], 
             Hue[0.15000000000000002`], 
             Hue[0.2], 
             Hue[0.25], 
             Hue[0.30000000000000004`], 
             Hue[0.35000000000000003`], 
             Hue[0.4], 
             Hue[0.45], 
             Hue[0.5], 
             Hue[0.55], 
             Hue[0.6000000000000001], 
             Hue[0.65], 
             Hue[0.7000000000000001], 
             Hue[0.75], 
             Hue[0.8], 
             Hue[0.8500000000000001], 
             Hue[0.9], 
             Hue[0.9500000000000001], 
             Hue[1.]}, {
            Null, SparseArray[
             Automatic, {21, 21}, 0, {
              1, {{0, 3, 5, 6, 7, 8, 10, 12, 13, 14, 15, 16, 17, 19, 21, 22, 
                23, 24, 25, 26, 27, 28}, {{2}, {20}, {21}, {3}, {21}, {4}, {
                5}, {6}, {7}, {8}, {8}, {9}, {9}, {10}, {11}, {12}, {13}, {
                14}, {16}, {15}, {16}, {16}, {17}, {18}, {19}, {20}, {21}, {
                21}}}, {1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 
               1, 1, 1, 1, 1, 1, 1, 1, 1, 1}}]}, {VertexLabels -> {All}}]]}, 
          TagBox[GraphicsGroupBox[{
             {Hue[0.6, 0.7, 0.5], Opacity[0.7], 
              {Arrowheads[0.], 
               ArrowBox[{{1.8420641773179816`, 0.32130855815221615`}, {
                1.0665491794795048`, 0.6664282988476327}}, 
                0.05313657305292026]}, 
              {Arrowheads[0.], 
               ArrowBox[{{1.8420641773179816`, 0.32130855815221615`}, {
                2.676282077786261, 0.1403920737348341}}, 
                0.05313657305292026]}, 
              {Arrowheads[0.], 
               ArrowBox[{{1.8420641773179816`, 0.32130855815221615`}, {
                1.7338217213167764`, 0.}}, 0.05313657305292026]}, 
              {Arrowheads[0.], 
               ArrowBox[{{1.0665491794795048`, 0.6664282988476327}, {
                0.3615364546912514, 1.6198742882711907`}}, 
                0.05313657305292026]}, 
              {Arrowheads[0.], 
               ArrowBox[{{1.0665491794795048`, 0.6664282988476327}, {
                1.7338217213167764`, 0.}}, 0.05313657305292026]}, 
              {Arrowheads[0.], 
               ArrowBox[{{0.3615364546912514, 1.6198742882711907`}, {0., 
                2.7298745776939786`}}, 0.05313657305292026]}, 
              {Arrowheads[0.], 
               ArrowBox[{{0., 2.7298745776939786`}, {0.008096224632337279, 
                3.8985025760512433`}}, 0.05313657305292026]}, 
              {Arrowheads[0.], 
               ArrowBox[{{0.008096224632337279, 3.8985025760512433`}, {
                0.38155111188984403`, 5.023510173106498}}, 
                0.05313657305292026]}, 
              {Arrowheads[0.], 
               ArrowBox[{{0.38155111188984403`, 5.023510173106498}, {
                1.0114596044540423`, 5.586558862825587}}, 
                0.05313657305292026]}, 
              {Arrowheads[0.], 
               ArrowBox[{{0.38155111188984403`, 5.023510173106498}, {
                0.8046472974003689, 5.858184517107867}}, 
                0.05313657305292026]}, 
              {Arrowheads[0.], 
               ArrowBox[{{1.0114596044540423`, 5.586558862825587}, {
                0.8046472974003689, 5.858184517107867}}, 
                0.05313657305292026]}, 
              {Arrowheads[0.], 
               ArrowBox[{{1.0114596044540423`, 5.586558862825587}, {
                1.7440609967717833`, 6.0094120741862245`}}, 
                0.05313657305292026]}, 
              {Arrowheads[0.], 
               ArrowBox[{{0.8046472974003689, 5.858184517107867}, {
                1.7440609967717833`, 6.0094120741862245`}}, 
                0.05313657305292026]}, 
              {Arrowheads[0.], 
               ArrowBox[{{1.7440609967717833`, 6.0094120741862245`}, {
                2.9402331599797185`, 6.0328115146098735`}}, 
                0.05313657305292026]}, 
              {Arrowheads[0.], 
               ArrowBox[{{2.9402331599797185`, 6.0328115146098735`}, {
                4.078457348971693, 5.70968647057631}}, 0.05313657305292026]}, 
              
              {Arrowheads[0.], 
               ArrowBox[{{4.078457348971693, 5.70968647057631}, {
                5.083763280895914, 5.07568280270236}}, 
                0.05313657305292026]}, 
              {Arrowheads[0.], 
               ArrowBox[{{5.083763280895914, 5.07568280270236}, {
                5.895165294053269, 4.167299935372059}}, 0.05313657305292026]}, 
              {Arrowheads[0.], 
               ArrowBox[{{5.895165294053269, 4.167299935372059}, {
                6.544562546983033, 3.722896998494484}}, 0.05313657305292026]}, 
              {Arrowheads[0.], 
               ArrowBox[{{5.895165294053269, 4.167299935372059}, {
                6.195587386399872, 3.1426908693667572`}}, 
                0.05313657305292026]}, 
              {Arrowheads[0.], 
               ArrowBox[{{6.544562546983033, 3.722896998494484}, {
                6.947627933840062, 3.2860017960095638`}}, 
                0.05313657305292026]}, 
              {Arrowheads[0.], 
               ArrowBox[{{6.544562546983033, 3.722896998494484}, {
                6.195587386399872, 3.1426908693667572`}}, 
                0.05313657305292026]}, 
              {Arrowheads[0.], 
               ArrowBox[{{6.947627933840062, 3.2860017960095638`}, {
                6.195587386399872, 3.1426908693667572`}}, 
                0.05313657305292026]}, 
              {Arrowheads[0.], 
               ArrowBox[{{6.195587386399872, 3.1426908693667572`}, {
                5.6415439480131315`, 2.0435185778788427`}}, 
                0.05313657305292026]}, 
              {Arrowheads[0.], 
               ArrowBox[{{5.6415439480131315`, 2.0435185778788427`}, {
                4.847828130982734, 1.13524507606749}}, 
                0.05313657305292026]}, 
              {Arrowheads[0.], 
               ArrowBox[{{4.847828130982734, 1.13524507606749}, {
                3.8373612505403942`, 0.4748705591256823}}, 
                0.05313657305292026]}, 
              {Arrowheads[0.], 
               ArrowBox[{{3.8373612505403942`, 0.4748705591256823}, {
                2.676282077786261, 0.1403920737348341}}, 
                0.05313657305292026]}, 
              {Arrowheads[0.], 
               ArrowBox[{{2.676282077786261, 0.1403920737348341}, {
                1.7338217213167764`, 0.}}, 0.05313657305292026]}, 
              {Arrowheads[0.], 
               ArrowBox[BezierCurveBox[{{1.7338217213167764`, 0.}, {
                1.887311388804487, -0.1437631971404884}, {
                1.878605419667176, -0.350299855128179}, {
                1.7827966771059367`, -0.4526179362073518}, {
                1.4252776229244422`, -0.3347567502208345}, {
                1.4091005131900425`, -0.19552095745356066`}, {
                1.5249281615125974`, -0.024298468056254574`}, {
                1.7338217213167764`, 0.}},
                SplineDegree->7], 0.05313657305292026]}}, 
             {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
              0.7]}], {
               DiskBox[{1.8420641773179816, 0.32130855815221615}, 
                0.05313657305292026], InsetBox[
                InterpretationBox[
                 ButtonBox[
                  TooltipBox[
                   GraphicsBox[{
                    {GrayLevel[0], RectangleBox[{0, 0}]}, 
                    {GrayLevel[0], RectangleBox[{1, -1}]}, 
                    {Hue[0.], RectangleBox[{0, -1}, {2, 1}]}},
                    AspectRatio->1,
                    Frame->True,
                    FrameStyle->Hue[0., 1., 0.6666666666666667],
                    FrameTicks->None,
                    
                    ImageSize->
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}],
                    PlotRangePadding->None],
                   "Hue[0.]"],
                  Appearance->None,
                  BaseStyle->{},
                  BaselinePosition->Baseline,
                  ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    Hue[0., 0.5, 0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
                  DefaultBaseStyle->{},
                  Evaluator->Automatic,
                  Method->"Preemptive"],
                 Hue[0.],
                 Editable->False,
                 Selectable->False], 
                Offset[{2, 2}, {1.8952007503709019, 0.3744451312051364}], 
                ImageScaled[{0, 0}],
                BaseStyle->"Graphics"]}, {
               DiskBox[{1.0665491794795048, 0.6664282988476327}, 
                0.05313657305292026], InsetBox[
                InterpretationBox[
                 ButtonBox[
                  TooltipBox[
                   GraphicsBox[{
                    {GrayLevel[0], RectangleBox[{0, 0}]}, 
                    {GrayLevel[0], RectangleBox[{1, -1}]}, 
                    {Hue[0.05], RectangleBox[{0, -1}, {2, 1}]}},
                    AspectRatio->1,
                    Frame->True,
                    
                    FrameStyle->Hue[
                    0.05000000000000001, 1., 0.6666666666666667],
                    FrameTicks->None,
                    
                    ImageSize->
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}],
                    PlotRangePadding->None],
                   "Hue[0.05]"],
                  Appearance->None,
                  BaseStyle->{},
                  BaselinePosition->Baseline,
                  ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    Hue[0.05, 0.5, 0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
                  DefaultBaseStyle->{},
                  Evaluator->Automatic,
                  Method->"Preemptive"],
                 Hue[0.05],
                 Editable->False,
                 Selectable->False], 
                Offset[{2, 2}, {1.119685752532425, 0.719564871900553}], 
                ImageScaled[{0, 0}],
                BaseStyle->"Graphics"]}, {
               DiskBox[{0.3615364546912514, 1.6198742882711907}, 
                0.05313657305292026], InsetBox[
                InterpretationBox[
                 ButtonBox[
                  TooltipBox[
                   GraphicsBox[{
                    {GrayLevel[0], RectangleBox[{0, 0}]}, 
                    {GrayLevel[0], RectangleBox[{1, -1}]}, 
                    {Hue[0.1], RectangleBox[{0, -1}, {2, 1}]}},
                    AspectRatio->1,
                    Frame->True,
                    
                    FrameStyle->Hue[
                    0.10000000000000002`, 1., 0.6666666666666667],
                    FrameTicks->None,
                    
                    ImageSize->
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}],
                    PlotRangePadding->None],
                   "Hue[0.1]"],
                  Appearance->None,
                  BaseStyle->{},
                  BaselinePosition->Baseline,
                  ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    Hue[0.1, 0.5, 0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
                  DefaultBaseStyle->{},
                  Evaluator->Automatic,
                  Method->"Preemptive"],
                 Hue[0.1],
                 Editable->False,
                 Selectable->False], 
                Offset[{2, 2}, {0.41467302774417164, 1.673010861324111}], 
                ImageScaled[{0, 0}],
                BaseStyle->"Graphics"]}, {
               DiskBox[{0., 2.7298745776939786}, 0.05313657305292026], 
               InsetBox[
                InterpretationBox[
                 ButtonBox[
                  TooltipBox[
                   GraphicsBox[{
                    {GrayLevel[0], RectangleBox[{0, 0}]}, 
                    {GrayLevel[0], RectangleBox[{1, -1}]}, 
                    {Hue[0.15000000000000002`], 
                    RectangleBox[{0, -1}, {2, 1}]}},
                    AspectRatio->1,
                    Frame->True,
                    FrameStyle->Hue[0.15, 1., 0.6666666666666667],
                    FrameTicks->None,
                    
                    ImageSize->
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}],
                    PlotRangePadding->None],
                   "Hue[0.15000000000000002]"],
                  Appearance->None,
                  BaseStyle->{},
                  BaselinePosition->Baseline,
                  ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    Hue[0.15000000000000002`, 0.5, 0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
                  DefaultBaseStyle->{},
                  Evaluator->Automatic,
                  Method->"Preemptive"],
                 Hue[0.15000000000000002`],
                 Editable->False,
                 Selectable->False], 
                Offset[{2, 2}, {0.05313657305292026, 2.7830111507468986}], 
                ImageScaled[{0, 0}],
                BaseStyle->"Graphics"]}, {
               DiskBox[{0.008096224632337279, 3.8985025760512433}, 
                0.05313657305292026], InsetBox[
                InterpretationBox[
                 ButtonBox[
                  TooltipBox[
                   GraphicsBox[{
                    {GrayLevel[0], RectangleBox[{0, 0}]}, 
                    {GrayLevel[0], RectangleBox[{1, -1}]}, 
                    {Hue[0.2], RectangleBox[{0, -1}, {2, 1}]}},
                    AspectRatio->1,
                    Frame->True,
                    
                    FrameStyle->Hue[
                    0.20000000000000004`, 1., 0.6666666666666667],
                    FrameTicks->None,
                    
                    ImageSize->
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}],
                    PlotRangePadding->None],
                   "Hue[0.2]"],
                  Appearance->None,
                  BaseStyle->{},
                  BaselinePosition->Baseline,
                  ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    Hue[0.2, 0.5, 0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
                  DefaultBaseStyle->{},
                  Evaluator->Automatic,
                  Method->"Preemptive"],
                 Hue[0.2],
                 Editable->False,
                 Selectable->False], 
                Offset[{2, 2}, {0.06123279768525754, 3.9516391491041634}], 
                ImageScaled[{0, 0}],
                BaseStyle->"Graphics"]}, {
               DiskBox[{0.38155111188984403, 5.023510173106498}, 
                0.05313657305292026], InsetBox[
                InterpretationBox[
                 ButtonBox[
                  TooltipBox[
                   GraphicsBox[{
                    {GrayLevel[0], RectangleBox[{0, 0}]}, 
                    {GrayLevel[0], RectangleBox[{1, -1}]}, 
                    {Hue[0.25], RectangleBox[{0, -1}, {2, 1}]}},
                    AspectRatio->1,
                    Frame->True,
                    FrameStyle->Hue[0.25, 1., 0.6666666666666667],
                    FrameTicks->None,
                    
                    ImageSize->
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}],
                    PlotRangePadding->None],
                   "Hue[0.25]"],
                  Appearance->None,
                  BaseStyle->{},
                  BaselinePosition->Baseline,
                  ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    Hue[0.25, 0.5, 0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
                  DefaultBaseStyle->{},
                  Evaluator->Automatic,
                  Method->"Preemptive"],
                 Hue[0.25],
                 Editable->False,
                 Selectable->False], 
                Offset[{2, 2}, {0.4346876849427643, 5.076646746159418}], 
                ImageScaled[{0, 0}],
                BaseStyle->"Graphics"]}, {
               DiskBox[{1.0114596044540423, 5.586558862825587}, 
                0.05313657305292026], InsetBox[
                InterpretationBox[
                 ButtonBox[
                  TooltipBox[
                   GraphicsBox[{
                    {GrayLevel[0], RectangleBox[{0, 0}]}, 
                    {GrayLevel[0], RectangleBox[{1, -1}]}, 
                    {Hue[0.30000000000000004`], 
                    RectangleBox[{0, -1}, {2, 1}]}},
                    AspectRatio->1,
                    Frame->True,
                    
                    FrameStyle->Hue[
                    0.30000000000000004`, 1., 0.6666666666666667],
                    FrameTicks->None,
                    
                    ImageSize->
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}],
                    PlotRangePadding->None],
                   "Hue[0.30000000000000004]"],
                  Appearance->None,
                  BaseStyle->{},
                  BaselinePosition->Baseline,
                  ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    Hue[0.30000000000000004`, 0.5, 0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
                  DefaultBaseStyle->{},
                  Evaluator->Automatic,
                  Method->"Preemptive"],
                 Hue[0.30000000000000004`],
                 Editable->False,
                 Selectable->False], 
                Offset[{2, 2}, {1.0645961775069626, 5.639695435878507}], 
                ImageScaled[{0, 0}],
                BaseStyle->"Graphics"]}, {
               DiskBox[{0.8046472974003689, 5.858184517107867}, 
                0.05313657305292026], InsetBox[
                InterpretationBox[
                 ButtonBox[
                  TooltipBox[
                   GraphicsBox[{
                    {GrayLevel[0], RectangleBox[{0, 0}]}, 
                    {GrayLevel[0], RectangleBox[{1, -1}]}, 
                    {Hue[0.35000000000000003`], 
                    RectangleBox[{0, -1}, {2, 1}]}},
                    AspectRatio->1,
                    Frame->True,
                    
                    FrameStyle->Hue[
                    0.35000000000000003`, 1., 0.6666666666666667],
                    FrameTicks->None,
                    
                    ImageSize->
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}],
                    PlotRangePadding->None],
                   "Hue[0.35000000000000003]"],
                  Appearance->None,
                  BaseStyle->{},
                  BaselinePosition->Baseline,
                  ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    Hue[0.35000000000000003`, 0.5, 0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
                  DefaultBaseStyle->{},
                  Evaluator->Automatic,
                  Method->"Preemptive"],
                 Hue[0.35000000000000003`],
                 Editable->False,
                 Selectable->False], 
                Offset[{2, 2}, {0.8577838704532892, 5.911321090160787}], 
                ImageScaled[{0, 0}],
                BaseStyle->"Graphics"]}, {
               DiskBox[{1.7440609967717833, 6.0094120741862245}, 
                0.05313657305292026], InsetBox[
                InterpretationBox[
                 ButtonBox[
                  TooltipBox[
                   GraphicsBox[{
                    {GrayLevel[0], RectangleBox[{0, 0}]}, 
                    {GrayLevel[0], RectangleBox[{1, -1}]}, 
                    {Hue[0.4], RectangleBox[{0, -1}, {2, 1}]}},
                    AspectRatio->1,
                    Frame->True,
                    
                    FrameStyle->Hue[
                    0.4000000000000001, 1., 0.6666666666666667],
                    FrameTicks->None,
                    
                    ImageSize->
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}],
                    PlotRangePadding->None],
                   "Hue[0.4]"],
                  Appearance->None,
                  BaseStyle->{},
                  BaselinePosition->Baseline,
                  ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    Hue[0.4, 0.5, 0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
                  DefaultBaseStyle->{},
                  Evaluator->Automatic,
                  Method->"Preemptive"],
                 Hue[0.4],
                 Editable->False,
                 Selectable->False], 
                Offset[{2, 2}, {1.7971975698247036, 6.0625486472391446}], 
                ImageScaled[{0, 0}],
                BaseStyle->"Graphics"]}, {
               DiskBox[{2.9402331599797185, 6.0328115146098735}, 
                0.05313657305292026], InsetBox[
                InterpretationBox[
                 ButtonBox[
                  TooltipBox[
                   GraphicsBox[{
                    {GrayLevel[0], RectangleBox[{0, 0}]}, 
                    {GrayLevel[0], RectangleBox[{1, -1}]}, 
                    {Hue[0.45], RectangleBox[{0, -1}, {2, 1}]}},
                    AspectRatio->1,
                    Frame->True,
                    FrameStyle->Hue[0.45, 1., 0.6666666666666667],
                    FrameTicks->None,
                    
                    ImageSize->
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}],
                    PlotRangePadding->None],
                   "Hue[0.45]"],
                  Appearance->None,
                  BaseStyle->{},
                  BaselinePosition->Baseline,
                  ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    Hue[0.45, 0.5, 0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
                  DefaultBaseStyle->{},
                  Evaluator->Automatic,
                  Method->"Preemptive"],
                 Hue[0.45],
                 Editable->False,
                 Selectable->False], 
                Offset[{2, 2}, {2.9933697330326385, 6.085948087662794}], 
                ImageScaled[{0, 0}],
                BaseStyle->"Graphics"]}, {
               DiskBox[{4.078457348971693, 5.70968647057631}, 
                0.05313657305292026], InsetBox[
                InterpretationBox[
                 ButtonBox[
                  TooltipBox[
                   GraphicsBox[{
                    {GrayLevel[0], RectangleBox[{0, 0}]}, 
                    {GrayLevel[0], RectangleBox[{1, -1}]}, 
                    {Hue[0.5], RectangleBox[{0, -1}, {2, 1}]}},
                    AspectRatio->1,
                    Frame->True,
                    FrameStyle->Hue[0.5, 1., 0.6666666666666667],
                    FrameTicks->None,
                    
                    ImageSize->
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}],
                    PlotRangePadding->None],
                   "Hue[0.5]"],
                  Appearance->None,
                  BaseStyle->{},
                  BaselinePosition->Baseline,
                  ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    Hue[0.5, 0.5, 0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
                  DefaultBaseStyle->{},
                  Evaluator->Automatic,
                  Method->"Preemptive"],
                 Hue[0.5],
                 Editable->False,
                 Selectable->False], 
                Offset[{2, 2}, {4.131593922024613, 5.76282304362923}], 
                ImageScaled[{0, 0}],
                BaseStyle->"Graphics"]}, {
               DiskBox[{5.083763280895914, 5.07568280270236}, 
                0.05313657305292026], InsetBox[
                InterpretationBox[
                 ButtonBox[
                  TooltipBox[
                   GraphicsBox[{
                    {GrayLevel[0], RectangleBox[{0, 0}]}, 
                    {GrayLevel[0], RectangleBox[{1, -1}]}, 
                    {Hue[0.55], RectangleBox[{0, -1}, {2, 1}]}},
                    AspectRatio->1,
                    Frame->True,
                    FrameStyle->Hue[0.55, 1., 0.6666666666666667],
                    FrameTicks->None,
                    
                    ImageSize->
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}],
                    PlotRangePadding->None],
                   "Hue[0.55]"],
                  Appearance->None,
                  BaseStyle->{},
                  BaselinePosition->Baseline,
                  ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    Hue[0.55, 0.5, 0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
                  DefaultBaseStyle->{},
                  Evaluator->Automatic,
                  Method->"Preemptive"],
                 Hue[0.55],
                 Editable->False,
                 Selectable->False], 
                Offset[{2, 2}, {5.136899853948834, 5.12881937575528}], 
                ImageScaled[{0, 0}],
                BaseStyle->"Graphics"]}, {
               DiskBox[{5.895165294053269, 4.167299935372059}, 
                0.05313657305292026], InsetBox[
                InterpretationBox[
                 ButtonBox[
                  TooltipBox[
                   GraphicsBox[{
                    {GrayLevel[0], RectangleBox[{0, 0}]}, 
                    {GrayLevel[0], RectangleBox[{1, -1}]}, 
                    {Hue[0.6000000000000001], RectangleBox[{0, -1}, {2, 1}]}},
                    
                    AspectRatio->1,
                    Frame->True,
                    
                    FrameStyle->Hue[
                    0.6000000000000001, 1., 0.6666666666666667],
                    FrameTicks->None,
                    
                    ImageSize->
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}],
                    PlotRangePadding->None],
                   "Hue[0.6000000000000001]"],
                  Appearance->None,
                  BaseStyle->{},
                  BaselinePosition->Baseline,
                  ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    Hue[0.6000000000000001, 0.5, 0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
                  DefaultBaseStyle->{},
                  Evaluator->Automatic,
                  Method->"Preemptive"],
                 Hue[0.6000000000000001],
                 Editable->False,
                 Selectable->False], 
                Offset[{2, 2}, {5.948301867106189, 4.220436508424979}], 
                ImageScaled[{0, 0}],
                BaseStyle->"Graphics"]}, {
               DiskBox[{6.544562546983033, 3.722896998494484}, 
                0.05313657305292026], InsetBox[
                InterpretationBox[
                 ButtonBox[
                  TooltipBox[
                   GraphicsBox[{
                    {GrayLevel[0], RectangleBox[{0, 0}]}, 
                    {GrayLevel[0], RectangleBox[{1, -1}]}, 
                    {Hue[0.65], RectangleBox[{0, -1}, {2, 1}]}},
                    AspectRatio->1,
                    Frame->True,
                    FrameStyle->Hue[0.65, 1., 0.6666666666666667],
                    FrameTicks->None,
                    
                    ImageSize->
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}],
                    PlotRangePadding->None],
                   "Hue[0.65]"],
                  Appearance->None,
                  BaseStyle->{},
                  BaselinePosition->Baseline,
                  ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    Hue[0.65, 0.5, 0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
                  DefaultBaseStyle->{},
                  Evaluator->Automatic,
                  Method->"Preemptive"],
                 Hue[0.65],
                 Editable->False,
                 Selectable->False], 
                Offset[{2, 2}, {6.597699120035953, 3.776033571547404}], 
                ImageScaled[{0, 0}],
                BaseStyle->"Graphics"]}, {
               DiskBox[{6.947627933840062, 3.2860017960095638}, 
                0.05313657305292026], InsetBox[
                InterpretationBox[
                 ButtonBox[
                  TooltipBox[
                   GraphicsBox[{
                    {GrayLevel[0], RectangleBox[{0, 0}]}, 
                    {GrayLevel[0], RectangleBox[{1, -1}]}, 
                    {Hue[0.7000000000000001], RectangleBox[{0, -1}, {2, 1}]}},
                    
                    AspectRatio->1,
                    Frame->True,
                    
                    FrameStyle->Hue[
                    0.7000000000000001, 1., 0.6666666666666667],
                    FrameTicks->None,
                    
                    ImageSize->
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}],
                    PlotRangePadding->None],
                   "Hue[0.7000000000000001]"],
                  Appearance->None,
                  BaseStyle->{},
                  BaselinePosition->Baseline,
                  ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    Hue[0.7000000000000001, 0.5, 0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
                  DefaultBaseStyle->{},
                  Evaluator->Automatic,
                  Method->"Preemptive"],
                 Hue[0.7000000000000001],
                 Editable->False,
                 Selectable->False], 
                Offset[{2, 2}, {7.000764506892982, 3.339138369062484}], 
                ImageScaled[{0, 0}],
                BaseStyle->"Graphics"]}, {
               DiskBox[{6.195587386399872, 3.1426908693667572}, 
                0.05313657305292026], InsetBox[
                InterpretationBox[
                 ButtonBox[
                  TooltipBox[
                   GraphicsBox[{
                    {GrayLevel[0], RectangleBox[{0, 0}]}, 
                    {GrayLevel[0], RectangleBox[{1, -1}]}, 
                    {Hue[0.75], RectangleBox[{0, -1}, {2, 1}]}},
                    AspectRatio->1,
                    Frame->True,
                    FrameStyle->Hue[0.75, 1., 0.6666666666666667],
                    FrameTicks->None,
                    
                    ImageSize->
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}],
                    PlotRangePadding->None],
                   "Hue[0.75]"],
                  Appearance->None,
                  BaseStyle->{},
                  BaselinePosition->Baseline,
                  ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    Hue[0.75, 0.5, 0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
                  DefaultBaseStyle->{},
                  Evaluator->Automatic,
                  Method->"Preemptive"],
                 Hue[0.75],
                 Editable->False,
                 Selectable->False], 
                Offset[{2, 2}, {6.248723959452792, 3.1958274424196773}], 
                ImageScaled[{0, 0}],
                BaseStyle->"Graphics"]}, {
               DiskBox[{5.6415439480131315, 2.0435185778788427}, 
                0.05313657305292026], InsetBox[
                InterpretationBox[
                 ButtonBox[
                  TooltipBox[
                   GraphicsBox[{
                    {GrayLevel[0], RectangleBox[{0, 0}]}, 
                    {GrayLevel[0], RectangleBox[{1, -1}]}, 
                    {Hue[0.8], RectangleBox[{0, -1}, {2, 1}]}},
                    AspectRatio->1,
                    Frame->True,
                    
                    FrameStyle->Hue[
                    0.8000000000000002, 1., 0.6666666666666667],
                    FrameTicks->None,
                    
                    ImageSize->
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}],
                    PlotRangePadding->None],
                   "Hue[0.8]"],
                  Appearance->None,
                  BaseStyle->{},
                  BaselinePosition->Baseline,
                  ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    Hue[0.8, 0.5, 0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
                  DefaultBaseStyle->{},
                  Evaluator->Automatic,
                  Method->"Preemptive"],
                 Hue[0.8],
                 Editable->False,
                 Selectable->False], 
                Offset[{2, 2}, {5.694680521066052, 2.096655150931763}], 
                ImageScaled[{0, 0}],
                BaseStyle->"Graphics"]}, {
               DiskBox[{4.847828130982734, 1.13524507606749}, 
                0.05313657305292026], InsetBox[
                InterpretationBox[
                 ButtonBox[
                  TooltipBox[
                   GraphicsBox[{
                    {GrayLevel[0], RectangleBox[{0, 0}]}, 
                    {GrayLevel[0], RectangleBox[{1, -1}]}, 
                    {Hue[0.8500000000000001], RectangleBox[{0, -1}, {2, 1}]}},
                    
                    AspectRatio->1,
                    Frame->True,
                    
                    FrameStyle->Hue[
                    0.8500000000000001, 1., 0.6666666666666667],
                    FrameTicks->None,
                    
                    ImageSize->
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}],
                    PlotRangePadding->None],
                   "Hue[0.8500000000000001]"],
                  Appearance->None,
                  BaseStyle->{},
                  BaselinePosition->Baseline,
                  ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    Hue[0.8500000000000001, 0.5, 0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
                  DefaultBaseStyle->{},
                  Evaluator->Automatic,
                  Method->"Preemptive"],
                 Hue[0.8500000000000001],
                 Editable->False,
                 Selectable->False], 
                Offset[{2, 2}, {4.900964704035654, 1.1883816491204102}], 
                ImageScaled[{0, 0}],
                BaseStyle->"Graphics"]}, {
               DiskBox[{3.8373612505403942, 0.4748705591256823}, 
                0.05313657305292026], InsetBox[
                InterpretationBox[
                 ButtonBox[
                  TooltipBox[
                   GraphicsBox[{
                    {GrayLevel[0], RectangleBox[{0, 0}]}, 
                    {GrayLevel[0], RectangleBox[{1, -1}]}, 
                    {Hue[0.9], RectangleBox[{0, -1}, {2, 1}]}},
                    AspectRatio->1,
                    Frame->True,
                    FrameStyle->Hue[0.9, 1., 0.6666666666666667],
                    FrameTicks->None,
                    
                    ImageSize->
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}],
                    PlotRangePadding->None],
                   "Hue[0.9]"],
                  Appearance->None,
                  BaseStyle->{},
                  BaselinePosition->Baseline,
                  ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    Hue[0.9, 0.5, 0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
                  DefaultBaseStyle->{},
                  Evaluator->Automatic,
                  Method->"Preemptive"],
                 Hue[0.9],
                 Editable->False,
                 Selectable->False], 
                Offset[{2, 2}, {3.8904978235933143, 0.5280071321786026}], 
                ImageScaled[{0, 0}],
                BaseStyle->"Graphics"]}, {
               DiskBox[{2.676282077786261, 0.1403920737348341}, 
                0.05313657305292026], InsetBox[
                InterpretationBox[
                 ButtonBox[
                  TooltipBox[
                   GraphicsBox[{
                    {GrayLevel[0], RectangleBox[{0, 0}]}, 
                    {GrayLevel[0], RectangleBox[{1, -1}]}, 
                    {Hue[0.9500000000000001], RectangleBox[{0, -1}, {2, 1}]}},
                    
                    AspectRatio->1,
                    Frame->True,
                    
                    FrameStyle->Hue[
                    0.9500000000000001, 1., 0.6666666666666667],
                    FrameTicks->None,
                    
                    ImageSize->
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}],
                    PlotRangePadding->None],
                   "Hue[0.9500000000000001]"],
                  Appearance->None,
                  BaseStyle->{},
                  BaselinePosition->Baseline,
                  ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    Hue[0.9500000000000001, 0.5, 0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
                  DefaultBaseStyle->{},
                  Evaluator->Automatic,
                  Method->"Preemptive"],
                 Hue[0.9500000000000001],
                 Editable->False,
                 Selectable->False], 
                Offset[{2, 2}, {2.729418650839181, 0.19352864678775433}], 
                ImageScaled[{0, 0}],
                BaseStyle->"Graphics"]}, {
               DiskBox[{1.7338217213167764, 0.}, 0.05313657305292026], 
               InsetBox[
                InterpretationBox[
                 ButtonBox[
                  TooltipBox[
                   GraphicsBox[{
                    {GrayLevel[0], RectangleBox[{0, 0}]}, 
                    {GrayLevel[0], RectangleBox[{1, -1}]}, 
                    {Hue[1.], RectangleBox[{0, -1}, {2, 1}]}},
                    AspectRatio->1,
                    Frame->True,
                    FrameStyle->Hue[0., 1., 0.6666666666666667],
                    FrameTicks->None,
                    
                    ImageSize->
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}],
                    PlotRangePadding->None],
                   "Hue[1.]"],
                  Appearance->None,
                  BaseStyle->{},
                  BaselinePosition->Baseline,
                  ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    Hue[1., 0.5, 0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
                  DefaultBaseStyle->{},
                  Evaluator->Automatic,
                  Method->"Preemptive"],
                 Hue[1.],
                 Editable->False,
                 Selectable->False], 
                Offset[{2, 2}, {1.7869582943696967, 0.05313657305292026}], 
                ImageScaled[{0, 0}],
                BaseStyle->"Graphics"]}}}],
           MouseAppearanceTag["NetworkGraphics"]],
          AllowKernelInitialization->False]],
        DefaultBaseStyle->{
         "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
          Hue[0.8, 1., 0.6]},
        FrameTicks->None,
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]]]], "ExerciseOutput",ExpressionUUID->
       "19d468ae-f48c-40c5-80b2-87242e6e3eff"],
      Apply[TextCell, 
       Cell[
        BoxData[
         GraphicsBox[
          NamespaceBox["NetworkGraphics", 
           DynamicModuleBox[{Typeset`graph = HoldComplete[
               Graph[{
                 Hue[0.], 
                 Hue[0.05], 
                 Hue[0.1], 
                 Hue[0.15000000000000002`], 
                 Hue[0.2], 
                 Hue[0.25], 
                 Hue[0.30000000000000004`], 
                 Hue[0.35000000000000003`], 
                 Hue[0.4], 
                 Hue[0.45], 
                 Hue[0.5], 
                 Hue[0.55], 
                 Hue[0.6000000000000001], 
                 Hue[0.65], 
                 Hue[0.7000000000000001], 
                 Hue[0.75], 
                 Hue[0.8], 
                 Hue[0.8500000000000001], 
                 Hue[0.9], 
                 Hue[0.9500000000000001], 
                 Hue[1.]}, {
                Null, SparseArray[
                 Automatic, {21, 21}, 0, {
                  1, {{0, 3, 5, 6, 7, 8, 10, 12, 13, 14, 15, 16, 17, 19, 21, 
                    22, 23, 24, 25, 26, 27, 28}, {{2}, {20}, {21}, {3}, {
                    21}, {4}, {5}, {6}, {7}, {8}, {8}, {9}, {9}, {10}, {11}, {
                    12}, {13}, {14}, {16}, {15}, {16}, {16}, {17}, {18}, {
                    19}, {20}, {21}, {21}}}, {1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
                    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1}}]}, {
                VertexLabels -> {All}}]]}, 
            TagBox[
             GraphicsGroupBox[{{{{{{{
                    Hue[0.6, 0.7, 0.5], 
                    Opacity[0.7], {{{{{{
                    Arrowheads[0.], 
                    
                    ArrowBox[{{1.8420641773179816`, 0.32130855815221615`}, {
                    1.0665491794795048`, 0.6664282988476327}}, 
                    0.05313657305292026]}}}}}}, {{{{{{
                    Arrowheads[0.], 
                    
                    ArrowBox[{{1.8420641773179816`, 0.32130855815221615`}, {
                    2.676282077786261, 0.1403920737348341}}, 
                    0.05313657305292026]}}}}}}, {{{{{{
                    Arrowheads[0.], 
                    
                    ArrowBox[{{1.8420641773179816`, 0.32130855815221615`}, {
                    1.7338217213167764`, 0.}}, 
                    0.05313657305292026]}}}}}}, {{{{{{
                    Arrowheads[0.], 
                    
                    ArrowBox[{{1.0665491794795048`, 0.6664282988476327}, {
                    0.3615364546912514, 1.6198742882711907`}}, 
                    0.05313657305292026]}}}}}}, {{{{{{
                    Arrowheads[0.], 
                    
                    ArrowBox[{{1.0665491794795048`, 0.6664282988476327}, {
                    1.7338217213167764`, 0.}}, 
                    0.05313657305292026]}}}}}}, {{{{{{
                    Arrowheads[0.], 
                    
                    ArrowBox[{{0.3615364546912514, 1.6198742882711907`}, {0., 
                    2.7298745776939786`}}, 0.05313657305292026]}}}}}}, {{{{{{
                    Arrowheads[0.], 
                    
                    ArrowBox[{{0., 2.7298745776939786`}, {
                    0.008096224632337279, 3.8985025760512433`}}, 
                    0.05313657305292026]}}}}}}, {{{{{{
                    Arrowheads[0.], 
                    
                    ArrowBox[{{0.008096224632337279, 3.8985025760512433`}, {
                    0.38155111188984403`, 5.023510173106498}}, 
                    0.05313657305292026]}}}}}}, {{{{{{
                    Arrowheads[0.], 
                    
                    ArrowBox[{{0.38155111188984403`, 5.023510173106498}, {
                    1.0114596044540423`, 5.586558862825587}}, 
                    0.05313657305292026]}}}}}}, {{{{{{
                    Arrowheads[0.], 
                    
                    ArrowBox[{{0.38155111188984403`, 5.023510173106498}, {
                    0.8046472974003689, 5.858184517107867}}, 
                    0.05313657305292026]}}}}}}, {{{{{{
                    Arrowheads[0.], 
                    
                    ArrowBox[{{1.0114596044540423`, 5.586558862825587}, {
                    0.8046472974003689, 5.858184517107867}}, 
                    0.05313657305292026]}}}}}}, {{{{{{
                    Arrowheads[0.], 
                    
                    ArrowBox[{{1.0114596044540423`, 5.586558862825587}, {
                    1.7440609967717833`, 6.0094120741862245`}}, 
                    0.05313657305292026]}}}}}}, {{{{{{
                    Arrowheads[0.], 
                    
                    ArrowBox[{{0.8046472974003689, 5.858184517107867}, {
                    1.7440609967717833`, 6.0094120741862245`}}, 
                    0.05313657305292026]}}}}}}, {{{{{{
                    Arrowheads[0.], 
                    
                    ArrowBox[{{1.7440609967717833`, 6.0094120741862245`}, {
                    2.9402331599797185`, 6.0328115146098735`}}, 
                    0.05313657305292026]}}}}}}, {{{{{{
                    Arrowheads[0.], 
                    
                    ArrowBox[{{2.9402331599797185`, 6.0328115146098735`}, {
                    4.078457348971693, 5.70968647057631}}, 
                    0.05313657305292026]}}}}}}, {{{{{{
                    Arrowheads[0.], 
                    
                    ArrowBox[{{4.078457348971693, 5.70968647057631}, {
                    5.083763280895914, 5.07568280270236}}, 
                    0.05313657305292026]}}}}}}, {{{{{{
                    Arrowheads[0.], 
                    
                    ArrowBox[{{5.083763280895914, 5.07568280270236}, {
                    5.895165294053269, 4.167299935372059}}, 
                    0.05313657305292026]}}}}}}, {{{{{{
                    Arrowheads[0.], 
                    
                    ArrowBox[{{5.895165294053269, 4.167299935372059}, {
                    6.544562546983033, 3.722896998494484}}, 
                    0.05313657305292026]}}}}}}, {{{{{{
                    Arrowheads[0.], 
                    
                    ArrowBox[{{5.895165294053269, 4.167299935372059}, {
                    6.195587386399872, 3.1426908693667572`}}, 
                    0.05313657305292026]}}}}}}, {{{{{{
                    Arrowheads[0.], 
                    
                    ArrowBox[{{6.544562546983033, 3.722896998494484}, {
                    6.947627933840062, 3.2860017960095638`}}, 
                    0.05313657305292026]}}}}}}, {{{{{{
                    Arrowheads[0.], 
                    
                    ArrowBox[{{6.544562546983033, 3.722896998494484}, {
                    6.195587386399872, 3.1426908693667572`}}, 
                    0.05313657305292026]}}}}}}, {{{{{{
                    Arrowheads[0.], 
                    
                    ArrowBox[{{6.947627933840062, 3.2860017960095638`}, {
                    6.195587386399872, 3.1426908693667572`}}, 
                    0.05313657305292026]}}}}}}, {{{{{{
                    Arrowheads[0.], 
                    
                    ArrowBox[{{6.195587386399872, 3.1426908693667572`}, {
                    5.6415439480131315`, 2.0435185778788427`}}, 
                    0.05313657305292026]}}}}}}, {{{{{{
                    Arrowheads[0.], 
                    
                    ArrowBox[{{5.6415439480131315`, 2.0435185778788427`}, {
                    4.847828130982734, 1.13524507606749}}, 
                    0.05313657305292026]}}}}}}, {{{{{{
                    Arrowheads[0.], 
                    
                    ArrowBox[{{4.847828130982734, 1.13524507606749}, {
                    3.8373612505403942`, 0.4748705591256823}}, 
                    0.05313657305292026]}}}}}}, {{{{{{
                    Arrowheads[0.], 
                    
                    ArrowBox[{{3.8373612505403942`, 0.4748705591256823}, {
                    2.676282077786261, 0.1403920737348341}}, 
                    0.05313657305292026]}}}}}}, {{{{{{
                    Arrowheads[0.], 
                    
                    ArrowBox[{{2.676282077786261, 0.1403920737348341}, {
                    1.7338217213167764`, 0.}}, 
                    0.05313657305292026]}}}}}}, {{{{{{
                    Arrowheads[0.], 
                    ArrowBox[
                    
                    BezierCurveBox[{{1.7338217213167764`, 0.}, {
                    1.887311388804487, -0.1437631971404884}, {
                    1.878605419667176, -0.350299855128179}, {
                    1.7827966771059367`, -0.4526179362073518}, {
                    1.4252776229244422`, -0.3347567502208345}, {
                    1.4091005131900425`, -0.19552095745356066`}, {
                    1.5249281615125974`, -0.024298468056254574`}, {
                    1.7338217213167764`, 0.}}, SplineDegree -> 7], 
                    0.05313657305292026]}}}}}}}}}}}}, {{{{{{
                    Hue[0.6, 0.2, 0.8], 
                    EdgeForm[{
                    GrayLevel[0], 
                    Opacity[0.7]}], {
                    
                    DiskBox[{1.8420641773179816`, 0.32130855815221615`}, 
                    0.05313657305292026], 
                    InsetBox[
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}, {{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}, {{{{{{
                    Hue[0.], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    Hue[0., 1., 0.6666666666666667], FrameTicks -> None, 
                    ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], "Hue[0.]"], 
                    Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                    Baseline, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    Hue[0., 0.5, 0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    Hue[0.], Editable -> False, Selectable -> False], 
                    Offset[{2, 2}, {1.8952007503709019`, 0.3744451312051364}], 
                    ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                    
                    DiskBox[{1.0665491794795048`, 0.6664282988476327}, 
                    0.05313657305292026], 
                    InsetBox[
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}, {{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}, {{{{{{
                    Hue[0.05], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    Hue[0.05000000000000001, 1., 0.6666666666666667], 
                    FrameTicks -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "Hue[0.05]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    Hue[0.05, 0.5, 0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    Hue[0.05], Editable -> False, Selectable -> False], 
                    Offset[{2, 2}, {1.119685752532425, 0.719564871900553}], 
                    ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                    
                    DiskBox[{0.3615364546912514, 1.6198742882711907`}, 
                    0.05313657305292026], 
                    InsetBox[
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}, {{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}, {{{{{{
                    Hue[0.1], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    Hue[0.10000000000000002`, 1., 0.6666666666666667], 
                    FrameTicks -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], "Hue[0.1]"],
                     Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                    Baseline, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    Hue[0.1, 0.5, 0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    Hue[0.1], Editable -> False, Selectable -> False], 
                    Offset[{2, 2}, {0.41467302774417164`, 1.673010861324111}], 
                    ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                    DiskBox[{0., 2.7298745776939786`}, 0.05313657305292026], 
                    InsetBox[
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}, {{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}, {{{{{{
                    Hue[0.15000000000000002`], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    Hue[0.15, 1., 0.6666666666666667], FrameTicks -> None, 
                    ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "Hue[0.15000000000000002]"], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    Hue[0.15000000000000002`, 0.5, 0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    Hue[0.15000000000000002`], Editable -> False, Selectable -> 
                    False], 
                    
                    Offset[{2, 2}, {0.05313657305292026, 
                    2.7830111507468986`}], 
                    ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                    
                    DiskBox[{0.008096224632337279, 3.8985025760512433`}, 
                    0.05313657305292026], 
                    InsetBox[
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}, {{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}, {{{{{{
                    Hue[0.2], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    Hue[0.20000000000000004`, 1., 0.6666666666666667], 
                    FrameTicks -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], "Hue[0.2]"],
                     Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                    Baseline, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    Hue[0.2, 0.5, 0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    Hue[0.2], Editable -> False, Selectable -> False], 
                    
                    Offset[{2, 2}, {0.06123279768525754, 
                    3.9516391491041634`}], 
                    ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                    
                    DiskBox[{0.38155111188984403`, 5.023510173106498}, 
                    0.05313657305292026], 
                    InsetBox[
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}, {{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}, {{{{{{
                    Hue[0.25], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    Hue[0.25, 1., 0.6666666666666667], FrameTicks -> None, 
                    ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "Hue[0.25]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    Hue[0.25, 0.5, 0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    Hue[0.25], Editable -> False, Selectable -> False], 
                    Offset[{2, 2}, {0.4346876849427643, 5.076646746159418}], 
                    ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                    
                    DiskBox[{1.0114596044540423`, 5.586558862825587}, 
                    0.05313657305292026], 
                    InsetBox[
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}, {{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}, {{{{{{
                    Hue[0.30000000000000004`], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    Hue[0.30000000000000004`, 1., 0.6666666666666667], 
                    FrameTicks -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "Hue[0.30000000000000004]"], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    Hue[0.30000000000000004`, 0.5, 0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    Hue[0.30000000000000004`], Editable -> False, Selectable -> 
                    False], 
                    Offset[{2, 2}, {1.0645961775069626`, 5.639695435878507}], 
                    
                    ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                    
                    DiskBox[{0.8046472974003689, 5.858184517107867}, 
                    0.05313657305292026], 
                    InsetBox[
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}, {{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}, {{{{{{
                    Hue[0.35000000000000003`], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    Hue[0.35000000000000003`, 1., 0.6666666666666667], 
                    FrameTicks -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "Hue[0.35000000000000003]"], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    Hue[0.35000000000000003`, 0.5, 0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    Hue[0.35000000000000003`], Editable -> False, Selectable -> 
                    False], 
                    Offset[{2, 2}, {0.8577838704532892, 5.911321090160787}], 
                    ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                    
                    DiskBox[{1.7440609967717833`, 6.0094120741862245`}, 
                    0.05313657305292026], 
                    InsetBox[
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}, {{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}, {{{{{{
                    Hue[0.4], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    Hue[0.4000000000000001, 1., 0.6666666666666667], 
                    FrameTicks -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], "Hue[0.4]"],
                     Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                    Baseline, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    Hue[0.4, 0.5, 0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    Hue[0.4], Editable -> False, Selectable -> False], 
                    
                    Offset[{2, 2}, {1.7971975698247036`, 
                    6.0625486472391446`}], 
                    ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                    
                    DiskBox[{2.9402331599797185`, 6.0328115146098735`}, 
                    0.05313657305292026], 
                    InsetBox[
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}, {{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}, {{{{{{
                    Hue[0.45], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    Hue[0.45, 1., 0.6666666666666667], FrameTicks -> None, 
                    ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "Hue[0.45]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    Hue[0.45, 0.5, 0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    Hue[0.45], Editable -> False, Selectable -> False], 
                    Offset[{2, 2}, {2.9933697330326385`, 6.085948087662794}], 
                    
                    ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                    
                    DiskBox[{4.078457348971693, 5.70968647057631}, 
                    0.05313657305292026], 
                    InsetBox[
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}, {{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}, {{{{{{
                    Hue[0.5], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    Hue[0.5, 1., 0.6666666666666667], FrameTicks -> None, 
                    ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], "Hue[0.5]"],
                     Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                    Baseline, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    Hue[0.5, 0.5, 0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    Hue[0.5], Editable -> False, Selectable -> False], 
                    Offset[{2, 2}, {4.131593922024613, 5.76282304362923}], 
                    ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                    
                    DiskBox[{5.083763280895914, 5.07568280270236}, 
                    0.05313657305292026], 
                    InsetBox[
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}, {{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}, {{{{{{
                    Hue[0.55], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    Hue[0.55, 1., 0.6666666666666667], FrameTicks -> None, 
                    ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "Hue[0.55]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    Hue[0.55, 0.5, 0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    Hue[0.55], Editable -> False, Selectable -> False], 
                    Offset[{2, 2}, {5.136899853948834, 5.12881937575528}], 
                    ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                    DiskBox[{5.895165294053269, 4.167299935372059}, 
                    0.05313657305292026], 
                    InsetBox[
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}, {{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}, {{{{{{
                    Hue[0.6000000000000001], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    Hue[0.6000000000000001, 1., 0.6666666666666667], 
                    FrameTicks -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "Hue[0.6000000000000001]"], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    Hue[0.6000000000000001, 0.5, 0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    Hue[0.6000000000000001], Editable -> False, Selectable -> 
                    False], 
                    Offset[{2, 2}, {5.948301867106189, 4.220436508424979}], 
                    ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                    DiskBox[{6.544562546983033, 3.722896998494484}, 
                    0.05313657305292026], 
                    InsetBox[
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}, {{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}, {{{{{{
                    Hue[0.65], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    Hue[0.65, 1., 0.6666666666666667], FrameTicks -> None, 
                    ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "Hue[0.65]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    Hue[0.65, 0.5, 0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    Hue[0.65], Editable -> False, Selectable -> False], 
                    Offset[{2, 2}, {6.597699120035953, 3.776033571547404}], 
                    ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                    
                    DiskBox[{6.947627933840062, 3.2860017960095638`}, 
                    0.05313657305292026], 
                    InsetBox[
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}, {{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}, {{{{{{
                    Hue[0.7000000000000001], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    Hue[0.7000000000000001, 1., 0.6666666666666667], 
                    FrameTicks -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "Hue[0.7000000000000001]"], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    Hue[0.7000000000000001, 0.5, 0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    Hue[0.7000000000000001], Editable -> False, Selectable -> 
                    False], 
                    Offset[{2, 2}, {7.000764506892982, 3.339138369062484}], 
                    ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                    
                    DiskBox[{6.195587386399872, 3.1426908693667572`}, 
                    0.05313657305292026], 
                    InsetBox[
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}, {{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}, {{{{{{
                    Hue[0.75], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    Hue[0.75, 1., 0.6666666666666667], FrameTicks -> None, 
                    ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "Hue[0.75]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    Hue[0.75, 0.5, 0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    Hue[0.75], Editable -> False, Selectable -> False], 
                    Offset[{2, 2}, {6.248723959452792, 3.1958274424196773`}], 
                    
                    ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                    
                    DiskBox[{5.6415439480131315`, 2.0435185778788427`}, 
                    0.05313657305292026], 
                    InsetBox[
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}, {{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}, {{{{{{
                    Hue[0.8], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    Hue[0.8000000000000002, 1., 0.6666666666666667], 
                    FrameTicks -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], "Hue[0.8]"],
                     Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                    Baseline, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    Hue[0.8, 0.5, 0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    Hue[0.8], Editable -> False, Selectable -> False], 
                    Offset[{2, 2}, {5.694680521066052, 2.096655150931763}], 
                    ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                    
                    DiskBox[{4.847828130982734, 1.13524507606749}, 
                    0.05313657305292026], 
                    InsetBox[
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}, {{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}, {{{{{{
                    Hue[0.8500000000000001], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    Hue[0.8500000000000001, 1., 0.6666666666666667], 
                    FrameTicks -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "Hue[0.8500000000000001]"], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    Hue[0.8500000000000001, 0.5, 0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    Hue[0.8500000000000001], Editable -> False, Selectable -> 
                    False], 
                    Offset[{2, 2}, {4.900964704035654, 1.1883816491204102`}], 
                    
                    ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                    
                    DiskBox[{3.8373612505403942`, 0.4748705591256823}, 
                    0.05313657305292026], 
                    InsetBox[
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}, {{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}, {{{{{{
                    Hue[0.9], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    Hue[0.9, 1., 0.6666666666666667], FrameTicks -> None, 
                    ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], "Hue[0.9]"],
                     Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                    Baseline, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    Hue[0.9, 0.5, 0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    Hue[0.9], Editable -> False, Selectable -> False], 
                    Offset[{2, 2}, {3.8904978235933143`, 0.5280071321786026}], 
                    ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                    
                    DiskBox[{2.676282077786261, 0.1403920737348341}, 
                    0.05313657305292026], 
                    InsetBox[
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}, {{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}, {{{{{{
                    Hue[0.9500000000000001], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    Hue[0.9500000000000001, 1., 0.6666666666666667], 
                    FrameTicks -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "Hue[0.9500000000000001]"], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    Hue[0.9500000000000001, 0.5, 0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    Hue[0.9500000000000001], Editable -> False, Selectable -> 
                    False], 
                    Offset[{2, 2}, {2.729418650839181, 0.19352864678775433`}], 
                    ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                    DiskBox[{1.7338217213167764`, 0.}, 0.05313657305292026], 
                    InsetBox[
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}, {{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}, {{{{{{
                    Hue[1.], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    Hue[0., 1., 0.6666666666666667], FrameTicks -> None, 
                    ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], "Hue[1.]"], 
                    Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                    Baseline, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    Hue[1., 0.5, 0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    Hue[1.], Editable -> False, Selectable -> False], 
                    
                    Offset[{2, 2}, {1.7869582943696967`, 
                    0.05313657305292026}], 
                    ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}}}}}}}}], 
             MouseAppearanceTag["NetworkGraphics"]], 
            AllowKernelInitialization -> False]], 
          DefaultBaseStyle -> {
           "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
            Hue[0.8, 1., 0.6]}, FrameTicks -> None, GridLinesStyle -> 
          Directive[
            GrayLevel[0.5, 0.4]]]], "ExerciseOutput", Selectable -> False, 
        Copyable -> False, Editable -> False, ShowCellBracket -> False]]], " "}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Center}}},
   GridBoxBackground->{"Columns" -> {{
        RGBColor[1, 1, 1]}}},
   GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{1}}}],
  FrameMargins->0]], "ExerciseOutput",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellFrame->{{1, 1}, {1, 1}},
 ShowCellBracket->False,
 CellFrameColor->RGBColor[0.85, 0.85, 0.85],
 LineBreakWithin->
  Automatic,ExpressionUUID->"4744fa2d-77db-4f26-978a-facb1764b980"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Generate a list of 100 random numbers from 0 to 100, and make a graph of \
the 2 nearest neighbors of each one.",
 StyleBox[ButtonBox["\[NonBreakingSpace]\[RightGuillemet]",
  Appearance->None,
  Evaluator->Automatic,
  Method->"Preemptive",
  ButtonFunction:>(SelectionMove[
     ButtonNotebook[], All, ButtonCell, AutoScroll -> False]; 
   FrontEndExecute[
     FrontEndToken[
      ButtonNotebook[], "OpenCloseGroup"]])],
  FontColor->RGBColor[1, 0.501961, 0]]
}], "Exercise",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellDingbat->Cell[
  "22.11", "ExerciseNumber", FontColor -> 
   RGBColor[0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]],
 ShowCellBracket->
  False,ExpressionUUID->"1b21d344-c47f-49e8-90e4-a55c8ec57007"],

Cell[BoxData[
 PaneBox[GridBox[{
    {" ", 
     StyleBox[
      RowBox[{"Sample", " ", "expected", " ", 
       RowBox[{"output", ":"}]}],
      Editable->False,
      Selectable->False,
      StripOnInput->False,
      FontColor->RGBColor[0.45, 0.45, 0.45]], " "},
    {" ", 
     InterpretationBox[Cell[BoxData[
       GraphicsBox[
        NamespaceBox["NetworkGraphics",
         DynamicModuleBox[{Typeset`graph = HoldComplete[
           
           Graph[{10, 69, 30, 19, 48, 99, 93, 75, 36, 5, 43, 79, 47, 82, 21, 
            68, 62, 88, 11, 26, 90, 100, 65, 35, 1, 13, 27, 24, 96, 95, 16, 
            29, 77}, {Null, 
             SparseArray[
             Automatic, {33, 33}, 0, {
              1, {{0, 4, 6, 10, 12, 14, 16, 19, 21, 23, 25, 27, 30, 32, 34, 
                36, 39, 41, 43, 45, 47, 49, 51, 54, 56, 58, 61, 64, 66, 69, 
                71, 73, 75, 78}, {{10}, {19}, {25}, {26}, {16}, {23}, {9}, {
                24}, {27}, {32}, {15}, {31}, {11}, {13}, {22}, {29}, {18}, {
                21}, {30}, {12}, {33}, {3}, {24}, {1}, {25}, {5}, {13}, {8}, {
                14}, {33}, {5}, {11}, {12}, {33}, {4}, {28}, {2}, {17}, {
                23}, {16}, {23}, {7}, {21}, {1}, {26}, {27}, {28}, {7}, {
                18}, {6}, {29}, {2}, {16}, {17}, {3}, {9}, {1}, {10}, {1}, {
                19}, {31}, {3}, {20}, {32}, {15}, {20}, {6}, {22}, {30}, {
                7}, {29}, {4}, {26}, {3}, {27}, {8}, {12}, {14}}}, 
               Pattern}]}, {VertexLabels -> {All}}]]}, 
          TagBox[GraphicsGroupBox[{
             {Hue[0.6, 0.7, 0.5], Opacity[0.7], 
              {Arrowheads[0.], 
               ArrowBox[{{1.4698040750396784`, -1.0073312235012324`}, {
                0.623558208516048, -0.8270698415161517}}, 
                0.07160324889883254]}, 
              {Arrowheads[0.], 
               ArrowBox[{{1.4698040750396784`, -1.0073312235012324`}, {
                2.015707524455916, -0.7226833125475514}}, 
                0.07160324889883254]}, 
              {Arrowheads[0.], 
               ArrowBox[{{1.4698040750396784`, -1.0073312235012324`}, {
                0.6791981456723262, -1.3396955594051985`}}, 
                0.07160324889883254]}, 
              {Arrowheads[0.], 
               ArrowBox[{{1.4698040750396784`, -1.0073312235012324`}, {
                2.653820635964625, -0.9498121495677305}}, 
                0.07160324889883254]}, 
              {Arrowheads[0.], 
               ArrowBox[{{8.524927318764899, -3.0222888665686773`}, {
                7.590896303435223, -3.4563823756146217`}}, 
                0.07160324889883254]}, 
              {Arrowheads[0.], 
               ArrowBox[{{8.524927318764899, -3.0222888665686773`}, {
                7.59229833972008, -2.5868119764372937`}}, 
                0.07160324889883254]}, 
              {Arrowheads[0.], 
               ArrowBox[{{11.589914111179747`, -0.9531546477444116}, {
                12.382432199836519`, -0.6235582085160476}}, 
                0.07160324889883254]}, 
              {Arrowheads[0.], 
               ArrowBox[{{11.589914111179747`, -0.9531546477444116}, {
                12.434819477737406`, -1.1358513111828343`}}, 
                0.07160324889883254]}, 
              {Arrowheads[0.], 
               ArrowBox[{{11.589914111179747`, -0.9531546477444116}, {
                10.40614867754882, -1.007246725936377}}, 
                0.07160324889883254]}, 
              {Arrowheads[0.], 
               ArrowBox[{{11.589914111179747`, -0.9531546477444116}, {
                11.043565088476479`, -1.2354364283172665`}}, 
                0.07160324889883254]}, 
              {Arrowheads[0.], 
               ArrowBox[{{5.2373001125987155`, -0.9688678620846822}, {
                6.531320260404658, -0.9761739225168616}}, 
                0.07160324889883254]}, 
              {Arrowheads[0.], 
               ArrowBox[{{5.2373001125987155`, -0.9688678620846822}, {
                3.9456718437450693`, -0.9612421302664788}}, 
                0.07160324889883254]}, 
              {Arrowheads[0.], 
               ArrowBox[{{1.120480423897308, -5.571293816276586}, {
                1.6235518653185617`, -4.707048875930637}}, 
                0.07160324889883254]}, 
              {Arrowheads[0.], 
               ArrowBox[{{1.120480423897308, -5.571293816276586}, {
                0.6235582085160476, -4.703498792646718}}, 
                0.07160324889883254]}, 
              {Arrowheads[0.], 
               ArrowBox[{{0.6241064896393222, -3.363097265353095}, {
                0.6235582085160472, -2.6801962813960865`}}, 
                0.07160324889883254]}, 
              {Arrowheads[0.], 
               ArrowBox[{{0.6241064896393222, -3.363097265353095}, {
                1.5288506598086575`, -3.0214509266159544`}}, 
                0.07160324889883254]}, 
              {Arrowheads[0.], 
               ArrowBox[{{4.1086213229066155`, -3.021537814968986}, {
                5.012655262003232, -2.6798811194161076`}}, 
                0.07160324889883254]}, 
              {Arrowheads[0.], 
               ArrowBox[{{4.1086213229066155`, -3.021537814968986}, {
                5.012416985273892, -3.363313232635808}}, 
                0.07160324889883254]}, 
              {Arrowheads[0.], 
               ArrowBox[{{4.1086213229066155`, -3.021537814968986}, {
                2.8194457901038503`, -3.0214690769113344`}}, 
                0.07160324889883254]}, 
              {Arrowheads[0.], 
               ArrowBox[{{12.037199375526567`, -3.0222888665686773`}, {
                11.103168360196891`, -3.4563823756146217`}}, 
                0.07160324889883254]}, 
              {Arrowheads[0.], 
               ArrowBox[{{12.037199375526567`, -3.0222888665686773`}, {
                11.104570396481748`, -2.5868119764372937`}}, 
                0.07160324889883254]}, 
              {Arrowheads[0.], 
               ArrowBox[{{12.382432199836519`, -0.6235582085160476}, {
                12.434819477737406`, -1.1358513111828343`}}, 
                0.07160324889883254]}, 
              {Arrowheads[0.], 
               ArrowBox[{{0.623558208516048, -0.8270698415161517}, {
                0.6791981456723262, -1.3396955594051985`}}, 
                0.07160324889883254]}, 
              {Arrowheads[0.], 
               ArrowBox[{{1.6235518653185617`, -4.707048875930637}, {
                0.6235582085160476, -4.703498792646718}}, 
                0.07160324889883254]}, 
              {Arrowheads[0.], 
               ArrowBox[{{11.103168360196891`, -3.4563823756146217`}, {
                10.169663838007835`, -3.021635872839666}}, 
                0.07160324889883254]}, 
              {Arrowheads[0.], 
               ArrowBox[{{11.103168360196891`, -3.4563823756146217`}, {
                11.104570396481748`, -2.5868119764372937`}}, 
                0.07160324889883254]}, 
              {Arrowheads[0.], 
               ArrowBox[{{10.169663838007835`, -3.021635872839666}, {
                11.104570396481748`, -2.5868119764372937`}}, 
                0.07160324889883254]}, 
              {Arrowheads[0.], 
               ArrowBox[{{6.531320260404658, -0.9761739225168616}, {
                7.825205362065807, -0.9844603878267566}}, 
                0.07160324889883254]}, 
              {Arrowheads[0.], 
               ArrowBox[{{7.590896303435223, -3.4563823756146217`}, {
                6.657391781246168, -3.021635872839666}}, 
                0.07160324889883254]}, 
              {Arrowheads[0.], 
               ArrowBox[{{7.590896303435223, -3.4563823756146217`}, {
                7.59229833972008, -2.5868119764372937`}}, 
                0.07160324889883254]}, 
              {Arrowheads[0.], 
               ArrowBox[{{6.657391781246168, -3.021635872839666}, {
                7.59229833972008, -2.5868119764372937`}}, 
                0.07160324889883254]}, 
              {Arrowheads[0.], 
               ArrowBox[{{5.012655262003232, -2.6798811194161076`}, {
                5.012416985273892, -3.363313232635808}}, 
                0.07160324889883254]}, 
              {Arrowheads[0.], 
               ArrowBox[{{2.015707524455916, -0.7226833125475514}, {
                2.653820635964625, -0.9498121495677305}}, 
                0.07160324889883254]}, 
              {Arrowheads[0.], 
               ArrowBox[{{9.11446929725064, -0.9936774985177124}, {
                10.40614867754882, -1.007246725936377}}, 
                0.07160324889883254]}, 
              {Arrowheads[0.], 
               ArrowBox[{{9.11446929725064, -0.9936774985177124}, {
                7.825205362065807, -0.9844603878267566}}, 
                0.07160324889883254]}, 
              {Arrowheads[0.], 
               ArrowBox[{{0.6235582085160472, -2.6801962813960865`}, {
                1.5288506598086575`, -3.0214509266159544`}}, 
                0.07160324889883254]}, 
              {Arrowheads[0.], 
               ArrowBox[{{2.653820635964625, -0.9498121495677305}, {
                3.9456718437450693`, -0.9612421302664788}}, 
                0.07160324889883254]}, 
              {Arrowheads[0.], 
               ArrowBox[{{10.40614867754882, -1.007246725936377}, {
                11.043565088476479`, -1.2354364283172665`}}, 
                0.07160324889883254]}, 
              {Arrowheads[0.], 
               ArrowBox[{{1.5288506598086575`, -3.0214509266159544`}, {
                2.8194457901038503`, -3.0214690769113344`}}, 
                0.07160324889883254]}}, 
             {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
              0.7]}], {
               DiskBox[{1.4698040750396784, -1.0073312235012324}, 
                0.07160324889883254], 
               InsetBox["10", 
                Offset[{2, 2}, {1.5414073239385109, -0.9357279746023999}], 
                ImageScaled[{0, 0}],
                BaseStyle->"Graphics"]}, {
               DiskBox[{8.524927318764899, -3.0222888665686773}, 
                0.07160324889883254], 
               InsetBox["69", 
                Offset[{2, 2}, {8.59653056766373, -2.9506856176698446}], 
                ImageScaled[{0, 0}],
                BaseStyle->"Graphics"]}, {
               DiskBox[{11.589914111179747, -0.9531546477444116}, 
                0.07160324889883254], 
               InsetBox["30", 
                Offset[{2, 2}, {11.661517360078578, -0.8815513988455791}], 
                ImageScaled[{0, 0}],
                BaseStyle->"Graphics"]}, {
               DiskBox[{5.2373001125987155, -0.9688678620846822}, 
                0.07160324889883254], 
               InsetBox["19", 
                Offset[{2, 2}, {5.308903361497548, -0.8972646131858497}], 
                ImageScaled[{0, 0}],
                BaseStyle->"Graphics"]}, {
               DiskBox[{1.120480423897308, -5.571293816276586}, 
                0.07160324889883254], 
               InsetBox["48", 
                Offset[{2, 2}, {1.1920836727961406, -5.499690567377753}], 
                ImageScaled[{0, 0}],
                BaseStyle->"Graphics"]}, {
               DiskBox[{0.6241064896393222, -3.363097265353095}, 
                0.07160324889883254], 
               InsetBox["99", 
                Offset[{2, 2}, {0.6957097385381548, -3.291494016454262}], 
                ImageScaled[{0, 0}],
                BaseStyle->"Graphics"]}, {
               DiskBox[{4.1086213229066155, -3.021537814968986}, 
                0.07160324889883254], 
               InsetBox["93", 
                Offset[{2, 2}, {4.180224571805448, -2.9499345660701533}], 
                ImageScaled[{0, 0}],
                BaseStyle->"Graphics"]}, {
               DiskBox[{12.037199375526567, -3.0222888665686773}, 
                0.07160324889883254], 
               InsetBox["75", 
                Offset[{2, 2}, {12.1088026244254, -2.9506856176698446}], 
                ImageScaled[{0, 0}],
                BaseStyle->"Graphics"]}, {
               DiskBox[{12.382432199836519, -0.6235582085160476}, 
                0.07160324889883254], 
               InsetBox["36", 
                Offset[{2, 2}, {12.45403544873535, -0.5519549596172151}], 
                ImageScaled[{0, 0}],
                BaseStyle->"Graphics"]}, {
               DiskBox[{0.623558208516048, -0.8270698415161517}, 
                0.07160324889883254], 
               InsetBox["5", 
                Offset[{2, 2}, {0.6951614574148806, -0.7554665926173192}], 
                ImageScaled[{0, 0}],
                BaseStyle->"Graphics"]}, {
               DiskBox[{1.6235518653185617, -4.707048875930637}, 
                0.07160324889883254], 
               InsetBox["43", 
                Offset[{2, 2}, {1.6951551142173942, -4.635445627031804}], 
                ImageScaled[{0, 0}],
                BaseStyle->"Graphics"]}, {
               DiskBox[{11.103168360196891, -3.4563823756146217}, 
                0.07160324889883254], 
               InsetBox["79", 
                Offset[{2, 2}, {11.174771609095723, -3.384779126715789}], 
                ImageScaled[{0, 0}],
                BaseStyle->"Graphics"]}, {
               DiskBox[{0.6235582085160476, -4.703498792646718}, 
                0.07160324889883254], 
               InsetBox["47", 
                Offset[{2, 2}, {0.6951614574148801, -4.631895543747885}], 
                ImageScaled[{0, 0}],
                BaseStyle->"Graphics"]}, {
               DiskBox[{10.169663838007835, -3.021635872839666}, 
                0.07160324889883254], 
               InsetBox["82", 
                Offset[{2, 2}, {10.241267086906667, -2.9500326239408334}], 
                ImageScaled[{0, 0}],
                BaseStyle->"Graphics"]}, {
               DiskBox[{6.531320260404658, -0.9761739225168616}, 
                0.07160324889883254], 
               InsetBox["21", 
                Offset[{2, 2}, {6.602923509303491, -0.9045706736180291}], 
                ImageScaled[{0, 0}],
                BaseStyle->"Graphics"]}, {
               DiskBox[{7.590896303435223, -3.4563823756146217}, 
                0.07160324889883254], 
               InsetBox["68", 
                Offset[{2, 2}, {7.662499552334055, -3.384779126715789}], 
                ImageScaled[{0, 0}],
                BaseStyle->"Graphics"]}, {
               DiskBox[{6.657391781246168, -3.021635872839666}, 
                0.07160324889883254], 
               InsetBox["62", 
                Offset[{2, 2}, {6.7289950301450006, -2.9500326239408334}], 
                ImageScaled[{0, 0}],
                BaseStyle->"Graphics"]}, {
               DiskBox[{5.012655262003232, -2.6798811194161076}, 
                0.07160324889883254], 
               InsetBox["88", 
                Offset[{2, 2}, {5.084258510902065, -2.608277870517275}], 
                ImageScaled[{0, 0}],
                BaseStyle->"Graphics"]}, {
               DiskBox[{2.015707524455916, -0.7226833125475514}, 
                0.07160324889883254], 
               InsetBox["11", 
                Offset[{2, 2}, {2.0873107733547487, -0.6510800636487188}], 
                ImageScaled[{0, 0}],
                BaseStyle->"Graphics"]}, {
               DiskBox[{9.11446929725064, -0.9936774985177124}, 
                0.07160324889883254], 
               InsetBox["26", 
                Offset[{2, 2}, {9.186072546149472, -0.9220742496188798}], 
                ImageScaled[{0, 0}],
                BaseStyle->"Graphics"]}, {
               DiskBox[{5.012416985273892, -3.363313232635808}, 
                0.07160324889883254], 
               InsetBox["90", 
                Offset[{2, 2}, {5.0840202341727245, -3.2917099837369754}], 
                ImageScaled[{0, 0}],
                BaseStyle->"Graphics"]}, {
               DiskBox[{0.6235582085160472, -2.6801962813960865}, 
                0.07160324889883254], 
               InsetBox["100", 
                Offset[{2, 2}, {0.6951614574148797, -2.6085930324972537}], 
                ImageScaled[{0, 0}],
                BaseStyle->"Graphics"]}, {
               DiskBox[{7.59229833972008, -2.5868119764372937}, 
                0.07160324889883254], 
               InsetBox["65", 
                Offset[{2, 2}, {7.663901588618913, -2.515208727538461}], 
                ImageScaled[{0, 0}],
                BaseStyle->"Graphics"]}, {
               DiskBox[{12.434819477737406, -1.1358513111828343}, 
                0.07160324889883254], 
               InsetBox["35", 
                Offset[{2, 2}, {12.506422726636238, -1.0642480622840018}], 
                ImageScaled[{0, 0}],
                BaseStyle->"Graphics"]}, {
               DiskBox[{0.6791981456723262, -1.3396955594051985}, 
                0.07160324889883254], 
               InsetBox["1", 
                Offset[{2, 2}, {0.7508013945711587, -1.268092310506366}], 
                ImageScaled[{0, 0}],
                BaseStyle->"Graphics"]}, {
               DiskBox[{2.653820635964625, -0.9498121495677305}, 
                0.07160324889883254], 
               InsetBox["13", 
                Offset[{2, 2}, {2.7254238848634578, -0.878208900668898}], 
                ImageScaled[{0, 0}],
                BaseStyle->"Graphics"]}, {
               DiskBox[{10.40614867754882, -1.007246725936377}, 
                0.07160324889883254], 
               InsetBox["27", 
                Offset[{2, 2}, {10.477751926447652, -0.9356434770375446}], 
                ImageScaled[{0, 0}],
                BaseStyle->"Graphics"]}, {
               DiskBox[{7.825205362065807, -0.9844603878267566}, 
                0.07160324889883254], 
               InsetBox["24", 
                Offset[{2, 2}, {7.89680861096464, -0.9128571389279241}], 
                ImageScaled[{0, 0}],
                BaseStyle->"Graphics"]}, {
               DiskBox[{1.5288506598086575, -3.0214509266159544}, 
                0.07160324889883254], 
               InsetBox["96", 
                Offset[{2, 2}, {1.60045390870749, -2.9498476777171216}], 
                ImageScaled[{0, 0}],
                BaseStyle->"Graphics"]}, {
               DiskBox[{2.8194457901038503, -3.0214690769113344}, 
                0.07160324889883254], 
               InsetBox["95", 
                Offset[{2, 2}, {2.891049039002683, -2.9498658280125016}], 
                ImageScaled[{0, 0}],
                BaseStyle->"Graphics"]}, {
               DiskBox[{3.9456718437450693, -0.9612421302664788}, 
                0.07160324889883254], 
               InsetBox["16", 
                Offset[{2, 2}, {4.017275092643902, -0.8896388813676462}], 
                ImageScaled[{0, 0}],
                BaseStyle->"Graphics"]}, {
               DiskBox[{11.043565088476479, -1.2354364283172665}, 
                0.07160324889883254], 
               InsetBox["29", 
                Offset[{2, 2}, {11.11516833737531, -1.163833179418434}], 
                ImageScaled[{0, 0}],
                BaseStyle->"Graphics"]}, {
               DiskBox[{11.104570396481748, -2.5868119764372937}, 
                0.07160324889883254], 
               InsetBox["77", 
                Offset[{2, 2}, {11.17617364538058, -2.515208727538461}], 
                ImageScaled[{0, 0}],
                BaseStyle->"Graphics"]}}}],
           MouseAppearanceTag["NetworkGraphics"]],
          AllowKernelInitialization->False]],
        DefaultBaseStyle->{
         "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
          Hue[0.8, 1., 0.6]},
        FormatType->TraditionalForm,
        FrameTicks->None,
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        ImageMargins->{{24.23828125, 250.20703125}, {1.734375, 0.34765625}},
        ImageSize->{563.10546875, Automatic}]], "ExerciseOutput",
       ExpressionUUID->"05ea23fa-aa65-45bc-8e7b-9f0fdc67b098"],
      Apply[TextCell, 
       Cell[
        BoxData[
         GraphicsBox[
          NamespaceBox["NetworkGraphics", 
           DynamicModuleBox[{Typeset`graph = HoldComplete[
               
               Graph[{10, 69, 30, 19, 48, 99, 93, 75, 36, 5, 43, 79, 47, 82, 
                21, 68, 62, 88, 11, 26, 90, 100, 65, 35, 1, 13, 27, 24, 96, 
                95, 16, 29, 77}, {Null, 
                 SparseArray[
                 Automatic, {33, 33}, 0, {
                  1, {{0, 4, 6, 10, 12, 14, 16, 19, 21, 23, 25, 27, 30, 32, 
                    34, 36, 39, 41, 43, 45, 47, 49, 51, 54, 56, 58, 61, 64, 
                    66, 69, 71, 73, 75, 78}, {{10}, {19}, {25}, {26}, {16}, {
                    23}, {9}, {24}, {27}, {32}, {15}, {31}, {11}, {13}, {
                    22}, {29}, {18}, {21}, {30}, {12}, {33}, {3}, {24}, {1}, {
                    25}, {5}, {13}, {8}, {14}, {33}, {5}, {11}, {12}, {33}, {
                    4}, {28}, {2}, {17}, {23}, {16}, {23}, {7}, {21}, {1}, {
                    26}, {27}, {28}, {7}, {18}, {6}, {29}, {2}, {16}, {17}, {
                    3}, {9}, {1}, {10}, {1}, {19}, {31}, {3}, {20}, {32}, {
                    15}, {20}, {6}, {22}, {30}, {7}, {29}, {4}, {26}, {3}, {
                    27}, {8}, {12}, {14}}}, Pattern}]}, {
                VertexLabels -> {All}}]]}, 
            TagBox[
             GraphicsGroupBox[{{{{{{{
                    Hue[0.6, 0.7, 0.5], 
                    Opacity[0.7], {{{{{{
                    Arrowheads[0.], 
                    
                    ArrowBox[{{1.4698040750396784`, -1.0073312235012324`}, {
                    0.623558208516048, -0.8270698415161517}}, 
                    0.07160324889883254]}}}}}}, {{{{{{
                    Arrowheads[0.], 
                    
                    ArrowBox[{{1.4698040750396784`, -1.0073312235012324`}, {
                    2.015707524455916, -0.7226833125475514}}, 
                    0.07160324889883254]}}}}}}, {{{{{{
                    Arrowheads[0.], 
                    
                    ArrowBox[{{1.4698040750396784`, -1.0073312235012324`}, {
                    0.6791981456723262, -1.3396955594051985`}}, 
                    0.07160324889883254]}}}}}}, {{{{{{
                    Arrowheads[0.], 
                    
                    ArrowBox[{{1.4698040750396784`, -1.0073312235012324`}, {
                    2.653820635964625, -0.9498121495677305}}, 
                    0.07160324889883254]}}}}}}, {{{{{{
                    Arrowheads[0.], 
                    
                    ArrowBox[{{8.524927318764899, -3.0222888665686773`}, {
                    7.590896303435223, -3.4563823756146217`}}, 
                    0.07160324889883254]}}}}}}, {{{{{{
                    Arrowheads[0.], 
                    
                    ArrowBox[{{8.524927318764899, -3.0222888665686773`}, {
                    7.59229833972008, -2.5868119764372937`}}, 
                    0.07160324889883254]}}}}}}, {{{{{{
                    Arrowheads[0.], 
                    
                    ArrowBox[{{11.589914111179747`, -0.9531546477444116}, {
                    12.382432199836519`, -0.6235582085160476}}, 
                    0.07160324889883254]}}}}}}, {{{{{{
                    Arrowheads[0.], 
                    
                    ArrowBox[{{11.589914111179747`, -0.9531546477444116}, {
                    12.434819477737406`, -1.1358513111828343`}}, 
                    0.07160324889883254]}}}}}}, {{{{{{
                    Arrowheads[0.], 
                    
                    ArrowBox[{{11.589914111179747`, -0.9531546477444116}, {
                    10.40614867754882, -1.007246725936377}}, 
                    0.07160324889883254]}}}}}}, {{{{{{
                    Arrowheads[0.], 
                    
                    ArrowBox[{{11.589914111179747`, -0.9531546477444116}, {
                    11.043565088476479`, -1.2354364283172665`}}, 
                    0.07160324889883254]}}}}}}, {{{{{{
                    Arrowheads[0.], 
                    
                    ArrowBox[{{5.2373001125987155`, -0.9688678620846822}, {
                    6.531320260404658, -0.9761739225168616}}, 
                    0.07160324889883254]}}}}}}, {{{{{{
                    Arrowheads[0.], 
                    
                    ArrowBox[{{5.2373001125987155`, -0.9688678620846822}, {
                    3.9456718437450693`, -0.9612421302664788}}, 
                    0.07160324889883254]}}}}}}, {{{{{{
                    Arrowheads[0.], 
                    
                    ArrowBox[{{1.120480423897308, -5.571293816276586}, {
                    1.6235518653185617`, -4.707048875930637}}, 
                    0.07160324889883254]}}}}}}, {{{{{{
                    Arrowheads[0.], 
                    
                    ArrowBox[{{1.120480423897308, -5.571293816276586}, {
                    0.6235582085160476, -4.703498792646718}}, 
                    0.07160324889883254]}}}}}}, {{{{{{
                    Arrowheads[0.], 
                    
                    ArrowBox[{{0.6241064896393222, -3.363097265353095}, {
                    0.6235582085160472, -2.6801962813960865`}}, 
                    0.07160324889883254]}}}}}}, {{{{{{
                    Arrowheads[0.], 
                    
                    ArrowBox[{{0.6241064896393222, -3.363097265353095}, {
                    1.5288506598086575`, -3.0214509266159544`}}, 
                    0.07160324889883254]}}}}}}, {{{{{{
                    Arrowheads[0.], 
                    
                    ArrowBox[{{4.1086213229066155`, -3.021537814968986}, {
                    5.012655262003232, -2.6798811194161076`}}, 
                    0.07160324889883254]}}}}}}, {{{{{{
                    Arrowheads[0.], 
                    
                    ArrowBox[{{4.1086213229066155`, -3.021537814968986}, {
                    5.012416985273892, -3.363313232635808}}, 
                    0.07160324889883254]}}}}}}, {{{{{{
                    Arrowheads[0.], 
                    
                    ArrowBox[{{4.1086213229066155`, -3.021537814968986}, {
                    2.8194457901038503`, -3.0214690769113344`}}, 
                    0.07160324889883254]}}}}}}, {{{{{{
                    Arrowheads[0.], 
                    
                    ArrowBox[{{12.037199375526567`, -3.0222888665686773`}, {
                    11.103168360196891`, -3.4563823756146217`}}, 
                    0.07160324889883254]}}}}}}, {{{{{{
                    Arrowheads[0.], 
                    
                    ArrowBox[{{12.037199375526567`, -3.0222888665686773`}, {
                    11.104570396481748`, -2.5868119764372937`}}, 
                    0.07160324889883254]}}}}}}, {{{{{{
                    Arrowheads[0.], 
                    
                    ArrowBox[{{12.382432199836519`, -0.6235582085160476}, {
                    12.434819477737406`, -1.1358513111828343`}}, 
                    0.07160324889883254]}}}}}}, {{{{{{
                    Arrowheads[0.], 
                    
                    ArrowBox[{{0.623558208516048, -0.8270698415161517}, {
                    0.6791981456723262, -1.3396955594051985`}}, 
                    0.07160324889883254]}}}}}}, {{{{{{
                    Arrowheads[0.], 
                    
                    ArrowBox[{{1.6235518653185617`, -4.707048875930637}, {
                    0.6235582085160476, -4.703498792646718}}, 
                    0.07160324889883254]}}}}}}, {{{{{{
                    Arrowheads[0.], 
                    
                    ArrowBox[{{11.103168360196891`, -3.4563823756146217`}, {
                    10.169663838007835`, -3.021635872839666}}, 
                    0.07160324889883254]}}}}}}, {{{{{{
                    Arrowheads[0.], 
                    
                    ArrowBox[{{11.103168360196891`, -3.4563823756146217`}, {
                    11.104570396481748`, -2.5868119764372937`}}, 
                    0.07160324889883254]}}}}}}, {{{{{{
                    Arrowheads[0.], 
                    
                    ArrowBox[{{10.169663838007835`, -3.021635872839666}, {
                    11.104570396481748`, -2.5868119764372937`}}, 
                    0.07160324889883254]}}}}}}, {{{{{{
                    Arrowheads[0.], 
                    
                    ArrowBox[{{6.531320260404658, -0.9761739225168616}, {
                    7.825205362065807, -0.9844603878267566}}, 
                    0.07160324889883254]}}}}}}, {{{{{{
                    Arrowheads[0.], 
                    
                    ArrowBox[{{7.590896303435223, -3.4563823756146217`}, {
                    6.657391781246168, -3.021635872839666}}, 
                    0.07160324889883254]}}}}}}, {{{{{{
                    Arrowheads[0.], 
                    
                    ArrowBox[{{7.590896303435223, -3.4563823756146217`}, {
                    7.59229833972008, -2.5868119764372937`}}, 
                    0.07160324889883254]}}}}}}, {{{{{{
                    Arrowheads[0.], 
                    
                    ArrowBox[{{6.657391781246168, -3.021635872839666}, {
                    7.59229833972008, -2.5868119764372937`}}, 
                    0.07160324889883254]}}}}}}, {{{{{{
                    Arrowheads[0.], 
                    
                    ArrowBox[{{5.012655262003232, -2.6798811194161076`}, {
                    5.012416985273892, -3.363313232635808}}, 
                    0.07160324889883254]}}}}}}, {{{{{{
                    Arrowheads[0.], 
                    
                    ArrowBox[{{2.015707524455916, -0.7226833125475514}, {
                    2.653820635964625, -0.9498121495677305}}, 
                    0.07160324889883254]}}}}}}, {{{{{{
                    Arrowheads[0.], 
                    
                    ArrowBox[{{9.11446929725064, -0.9936774985177124}, {
                    10.40614867754882, -1.007246725936377}}, 
                    0.07160324889883254]}}}}}}, {{{{{{
                    Arrowheads[0.], 
                    
                    ArrowBox[{{9.11446929725064, -0.9936774985177124}, {
                    7.825205362065807, -0.9844603878267566}}, 
                    0.07160324889883254]}}}}}}, {{{{{{
                    Arrowheads[0.], 
                    
                    ArrowBox[{{0.6235582085160472, -2.6801962813960865`}, {
                    1.5288506598086575`, -3.0214509266159544`}}, 
                    0.07160324889883254]}}}}}}, {{{{{{
                    Arrowheads[0.], 
                    
                    ArrowBox[{{2.653820635964625, -0.9498121495677305}, {
                    3.9456718437450693`, -0.9612421302664788}}, 
                    0.07160324889883254]}}}}}}, {{{{{{
                    Arrowheads[0.], 
                    
                    ArrowBox[{{10.40614867754882, -1.007246725936377}, {
                    11.043565088476479`, -1.2354364283172665`}}, 
                    0.07160324889883254]}}}}}}, {{{{{{
                    Arrowheads[0.], 
                    
                    ArrowBox[{{1.5288506598086575`, -3.0214509266159544`}, {
                    2.8194457901038503`, -3.0214690769113344`}}, 
                    0.07160324889883254]}}}}}}}}}}}}, {{{{{{
                    Hue[0.6, 0.2, 0.8], 
                    EdgeForm[{
                    GrayLevel[0], 
                    Opacity[0.7]}], {
                    
                    DiskBox[{1.4698040750396784`, -1.0073312235012324`}, 
                    0.07160324889883254], 
                    InsetBox["10", 
                    
                    Offset[{2, 2}, {
                    1.5414073239385109`, -0.9357279746023999}], 
                    ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                    
                    DiskBox[{8.524927318764899, -3.0222888665686773`}, 
                    0.07160324889883254], 
                    InsetBox["69", 
                    Offset[{2, 2}, {8.59653056766373, -2.9506856176698446`}], 
                    
                    ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                    
                    DiskBox[{11.589914111179747`, -0.9531546477444116}, 
                    0.07160324889883254], 
                    InsetBox["30", 
                    
                    Offset[{2, 2}, {
                    11.661517360078578`, -0.8815513988455791}], 
                    ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                    
                    DiskBox[{5.2373001125987155`, -0.9688678620846822}, 
                    0.07160324889883254], 
                    InsetBox["19", 
                    Offset[{2, 2}, {5.308903361497548, -0.8972646131858497}], 
                    
                    ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                    
                    DiskBox[{1.120480423897308, -5.571293816276586}, 
                    0.07160324889883254], 
                    InsetBox["48", 
                    Offset[{2, 2}, {1.1920836727961406`, -5.499690567377753}], 
                    ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                    
                    DiskBox[{0.6241064896393222, -3.363097265353095}, 
                    0.07160324889883254], 
                    InsetBox["99", 
                    Offset[{2, 2}, {0.6957097385381548, -3.291494016454262}], 
                    
                    ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                    
                    DiskBox[{4.1086213229066155`, -3.021537814968986}, 
                    0.07160324889883254], 
                    InsetBox["93", 
                    Offset[{2, 2}, {4.180224571805448, -2.9499345660701533`}], 
                    ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                    
                    DiskBox[{12.037199375526567`, -3.0222888665686773`}, 
                    0.07160324889883254], 
                    InsetBox["75", 
                    Offset[{2, 2}, {12.1088026244254, -2.9506856176698446`}], 
                    
                    ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                    
                    DiskBox[{12.382432199836519`, -0.6235582085160476}, 
                    0.07160324889883254], 
                    InsetBox["36", 
                    Offset[{2, 2}, {12.45403544873535, -0.5519549596172151}], 
                    
                    ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                    
                    DiskBox[{0.623558208516048, -0.8270698415161517}, 
                    0.07160324889883254], 
                    InsetBox["5", 
                    Offset[{2, 2}, {0.6951614574148806, -0.7554665926173192}], 
                    ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                    DiskBox[{1.6235518653185617`, -4.707048875930637}, 
                    0.07160324889883254], 
                    InsetBox["43", 
                    Offset[{2, 2}, {1.6951551142173942`, -4.635445627031804}], 
                    ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                    
                    DiskBox[{11.103168360196891`, -3.4563823756146217`}, 
                    0.07160324889883254], 
                    InsetBox["79", 
                    Offset[{2, 2}, {11.174771609095723`, -3.384779126715789}], 
                    ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                    
                    DiskBox[{0.6235582085160476, -4.703498792646718}, 
                    0.07160324889883254], 
                    InsetBox["47", 
                    Offset[{2, 2}, {0.6951614574148801, -4.631895543747885}], 
                    
                    ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                    
                    DiskBox[{10.169663838007835`, -3.021635872839666}, 
                    0.07160324889883254], 
                    InsetBox["82", 
                    
                    Offset[{2, 2}, {
                    10.241267086906667`, -2.9500326239408334`}], 
                    ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                    
                    DiskBox[{6.531320260404658, -0.9761739225168616}, 
                    0.07160324889883254], 
                    InsetBox["21", 
                    Offset[{2, 2}, {6.602923509303491, -0.9045706736180291}], 
                    
                    ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                    
                    DiskBox[{7.590896303435223, -3.4563823756146217`}, 
                    0.07160324889883254], 
                    InsetBox["68", 
                    Offset[{2, 2}, {7.662499552334055, -3.384779126715789}], 
                    ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                    
                    DiskBox[{6.657391781246168, -3.021635872839666}, 
                    0.07160324889883254], 
                    InsetBox["62", 
                    
                    Offset[{2, 2}, {
                    6.7289950301450006`, -2.9500326239408334`}], 
                    ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                    
                    DiskBox[{5.012655262003232, -2.6798811194161076`}, 
                    0.07160324889883254], 
                    InsetBox["88", 
                    Offset[{2, 2}, {5.084258510902065, -2.608277870517275}], 
                    ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                    
                    DiskBox[{2.015707524455916, -0.7226833125475514}, 
                    0.07160324889883254], 
                    InsetBox["11", 
                    
                    Offset[{2, 2}, {
                    2.0873107733547487`, -0.6510800636487188}], 
                    ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                    
                    DiskBox[{9.11446929725064, -0.9936774985177124}, 
                    0.07160324889883254], 
                    InsetBox["26", 
                    Offset[{2, 2}, {9.186072546149472, -0.9220742496188798}], 
                    
                    ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                    
                    DiskBox[{5.012416985273892, -3.363313232635808}, 
                    0.07160324889883254], 
                    InsetBox["90", 
                    
                    Offset[{2, 2}, {
                    5.0840202341727245`, -3.2917099837369754`}], 
                    ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                    
                    DiskBox[{0.6235582085160472, -2.6801962813960865`}, 
                    0.07160324889883254], 
                    InsetBox["100", 
                    
                    Offset[{2, 2}, {
                    0.6951614574148797, -2.6085930324972537`}], 
                    ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                    
                    DiskBox[{7.59229833972008, -2.5868119764372937`}, 
                    0.07160324889883254], 
                    InsetBox["65", 
                    Offset[{2, 2}, {7.663901588618913, -2.515208727538461}], 
                    ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                    
                    DiskBox[{12.434819477737406`, -1.1358513111828343`}, 
                    0.07160324889883254], 
                    InsetBox["35", 
                    Offset[{2, 2}, {
                    12.506422726636238`, -1.0642480622840018`}], 
                    ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                    
                    DiskBox[{0.6791981456723262, -1.3396955594051985`}, 
                    0.07160324889883254], 
                    InsetBox["1", 
                    Offset[{2, 2}, {0.7508013945711587, -1.268092310506366}], 
                    
                    ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                    
                    DiskBox[{2.653820635964625, -0.9498121495677305}, 
                    0.07160324889883254], 
                    InsetBox["13", 
                    Offset[{2, 2}, {2.7254238848634578`, -0.878208900668898}], 
                    ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                    
                    DiskBox[{10.40614867754882, -1.007246725936377}, 
                    0.07160324889883254], 
                    InsetBox["27", 
                    
                    Offset[{2, 2}, {
                    10.477751926447652`, -0.9356434770375446}], 
                    ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                    
                    DiskBox[{7.825205362065807, -0.9844603878267566}, 
                    0.07160324889883254], 
                    InsetBox["24", 
                    Offset[{2, 2}, {7.89680861096464, -0.9128571389279241}], 
                    ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                    
                    DiskBox[{1.5288506598086575`, -3.0214509266159544`}, 
                    0.07160324889883254], 
                    InsetBox["96", 
                    Offset[{2, 2}, {1.60045390870749, -2.9498476777171216`}], 
                    
                    ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                    
                    DiskBox[{2.8194457901038503`, -3.0214690769113344`}, 
                    0.07160324889883254], 
                    InsetBox["95", 
                    Offset[{2, 2}, {2.891049039002683, -2.9498658280125016`}], 
                    ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                    
                    DiskBox[{3.9456718437450693`, -0.9612421302664788}, 
                    0.07160324889883254], 
                    InsetBox["16", 
                    Offset[{2, 2}, {4.017275092643902, -0.8896388813676462}], 
                    
                    ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                    
                    DiskBox[{11.043565088476479`, -1.2354364283172665`}, 
                    0.07160324889883254], 
                    InsetBox["29", 
                    Offset[{2, 2}, {11.11516833737531, -1.163833179418434}], 
                    ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                    
                    DiskBox[{11.104570396481748`, -2.5868119764372937`}, 
                    0.07160324889883254], 
                    InsetBox["77", 
                    Offset[{2, 2}, {11.17617364538058, -2.515208727538461}], 
                    ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}}}}}}}}], 
             MouseAppearanceTag["NetworkGraphics"]], 
            AllowKernelInitialization -> False]], 
          DefaultBaseStyle -> {
           "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
            Hue[0.8, 1., 0.6]}, FormatType -> TraditionalForm, FrameTicks -> 
          None, GridLinesStyle -> Directive[
            GrayLevel[0.5, 0.4]], 
          ImageMargins -> {{24.23828125, 250.20703125}, {1.734375, 
           0.34765625}}, ImageSize -> {563.10546875, Automatic}]], 
        "ExerciseOutput", Selectable -> False, Copyable -> False, Editable -> 
        False, ShowCellBracket -> False]]], " "}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Center}}},
   GridBoxBackground->{"Columns" -> {{
        RGBColor[1, 1, 1]}}},
   GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{1}}}],
  FrameMargins->0]], "ExerciseOutput",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellFrame->{{1, 1}, {1, 1}},
 ShowCellBracket->False,
 CellFrameColor->RGBColor[0.85, 0.85, 0.85],
 LineBreakWithin->
  Automatic,ExpressionUUID->"b9459cc2-e2ce-4d82-af94-7abe75776e33"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Collect the flags of Asia into clusters of similar flags.",
 StyleBox[ButtonBox["\[NonBreakingSpace]\[RightGuillemet]",
  Appearance->None,
  Evaluator->Automatic,
  Method->"Preemptive",
  ButtonFunction:>(SelectionMove[
     ButtonNotebook[], All, ButtonCell, AutoScroll -> False]; 
   FrontEndExecute[
     FrontEndToken[
      ButtonNotebook[], "OpenCloseGroup"]])],
  FontColor->RGBColor[1, 0.501961, 0]]
}], "Exercise",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellDingbat->Cell[
  "22.12", "ExerciseNumber", FontColor -> 
   RGBColor[0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]],
 ShowCellBracket->
  False,ExpressionUUID->"64f00d50-ec23-450f-9f15-64dce316ff7c"],

Cell[BoxData[
 PaneBox[GridBox[{
    {" ", 
     StyleBox[
      RowBox[{"Expected", " ", 
       RowBox[{"output", ":"}]}],
      Editable->False,
      Selectable->False,
      StripOnInput->False,
      FontColor->RGBColor[0.45, 0.45, 0.45]], " "},
    {" ", 
     InterpretationBox[Cell[BoxData[
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           GraphicsBox[
            {Thickness[0.0010416666666666667`], 
             {Thickness[0.0010416666666666667`], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0., 
               0.}, {0., 480.}, {960., 480.}, {960., 0.}}}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0., 
               320.}, {960., 320.}, {960., 160.}, {0., 160.}}}]}, 
             {FaceForm[{RGBColor[0., 0.478431, 0.23921600000000004`], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               0., 160.}, {960., 160.}, {960., 0.}, {0., 0.}}}]}, 
             {FaceForm[{RGBColor[
              0.8078430000000001, 0.06666670000000002, 0.14902], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{480., 
               240.}, {0., 0.}, {0., 480.}}}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{180.32800000000003`, 
               231.71099999999998`}, {159.875, 229.80100000000002`}, {162.57, 
               209.36700000000002`}, {148.32800000000003`, 
               224.22299999999998`}, {134.086, 209.36700000000002`}, {136.781,
                229.80100000000002`}, {116.32799999999999`, 
               231.71099999999998`}, {133.93, 242.33200000000002`}, {122.664, 
               259.57}, {141.92200000000003`, 252.38700000000003`}, {
               148.32800000000003`, 271.969}, {154.73399999999998`, 
               252.38700000000003`}, {173.99200000000002`, 259.57}, {162.727, 
               242.33200000000002`}}}]}},
            AspectRatio->Automatic,
            ImageSize->{{128}, {85}},
            PlotRange->{{0., 960.}, {0., 480.}}], ",", 
           GraphicsBox[
            {Thickness[0.0020833333333333333`], 
             {FaceForm[{RGBColor[0., 0.6, 0.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0., 
               0.}, {0., 320.}, {480., 320.}, {480., 0.}}}]}, 
             {FaceForm[{RGBColor[0.74902, 0., 0.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0., 
               320.}, {320., 320.}, {320., 0.}, {0., 0.}}}]}, 
             {Thickness[0.0020833333333333333`], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0., 
               320.}, {160., 320.}, {160., 0.}, {0., 0.}}}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
               3}}}, {{{255.602, 139.32800000000003`}, {262.28099999999995`, 
               139.32800000000003`}, {262.309, 136.80100000000002`}, {263.789,
                134.09}, {265.867, 132.531}, {253.062, 132.531}, {255.066, 
               134.35200000000003`}, {255.61299999999997`, 136.504}, {255.602,
                139.32800000000003`}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
               3}}}, {{{255.602, 139.328}, {262.28099999999995`, 139.328}, {
               262.309, 136.80100000000002`}, {263.789, 134.09}, {265.867, 
               132.531}, {253.062, 132.531}, {255.066, 134.352}, {
               255.61299999999997`, 136.504}, {255.602, 139.328}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{213.36700000000002`, 
               177.176}, {217.02700000000002`, 173.14499999999998`}, {262.574,
                173.07}, {266.309, 177.102}, {254.66, 177.25}, {248.984, 
               181.207}, {230.691, 181.281}, {225.39100000000002`, 
               177.176}}}], 
              FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIpIGYC4t7peULNDLkON899D368M83BcsuJsn3f8xze
1dibxu1Kc2AAAZt8h7cg/r00h4yJQFZgvoP+XRW2xsB0h/3zpfTvBuRD9E9M
d5CNSrG+758P0ReQ4VAtss794ak8BzW2xqnOqzMcfMw7HRNc8yDyGzIcvEF8
wzyHRa7bPv8F8rmvLy6wlcpzKLTlur74QAbEfJE8iDmXMiDuY89zeLx09hGF
PxkOTglPLyhx5zlcULr9s04s0+HOz7qsPX9yIeaJZELs+ZDr0Po6cIecaCZE
/+dciLlA/cdBDniR68AFsvdahoNLd87z3w9zIfYdynBY/fGSb9KZXLh7QcF1
YBtUfl0GxJ0CuRD7l2VAwmVpDiScdDMchJsPnFq4Msfhm0ZM/yFg+PSBDFiT
4xC3y5OHSTvdYRXI/B05EHVv0xzQ4wMAqua5vQ==
               "]]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIpIGYC4t7peULNDLkON899D368M83BcsuJsn3f8xze
1dibxu1Kc2AAAZt8h7cg/r00h4yJQFZgvoP+XRW2xsB0h/3zpfTvBuRD9E9M
d5CNSrG+758P0ReQ4VAtss794ak8B1W2xqnOqzMcfMw7HRNc8yDyGzIcvEF8
wzyHRa7bPv8F8rmvLy6wlcpzKLDlur74QAbEfJE8hyqQOZcyIO5jz3N4snT2
EYU/GQ5OCU8vKHHnOVxQuv2zTizT4c7Puqw9f3Ih5olkQuz5kOvQ+jpwh5xo
JkT/51yHfSBzgfqPgxzwIteBC2TvtQwHl+6c578f5kLsO5ThsPrjJd+kM7lw
94KC68C2XIi/1mU4FILcKZALsX9ZBiRcluZAwkk3w0G4+cCphStzHL5pxPQf
AoZPH8iANTkOcbs8eZi00x1WgczfkQNR9zbNAT0+AKdmubk=
               "],
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{206.129, 
               125.73400000000001`}, {273.703, 125.73400000000001`}, {267.656,
                130.664}, {212.176, 130.664}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{
                0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1,
                 0}}, {{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}, {0, 1, 
                0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {0,
                 1, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}, {0, 1, 
                0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {0,
                 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {
                0, 1, 0}, {0, 1, 0}}}, {{{237.11299999999997`, 
                144.24599999999998`}, {238.344, 140.55100000000002`}, {
                241.14499999999998`, 140.55100000000002`}, {
                238.90200000000002`, 144.25}, {237.11299999999997`, 
                144.25}}, {{235.54299999999998`, 140.55100000000002`}, {
                236.254, 136.895}, {239.539, 136.85500000000002`}, {238.344, 
                140.555}}, {{241.105, 140.516}, {243.383, 136.895}, {
                248.05100000000002`, 136.895}, {244.39100000000002`, 
                140.555}}, CompressedData["
1:eJxTTMoPSmViYGAwB2IQ/U0jpv/QxiwHVbbGqc7tCQ6LXLd9/suQ7bB/vpT+
3QsJDkUZE9/WGGc7yEalWN/nT3RgAAGTbAfu64sLbLMSHfTvqrA1fkXwb577
HvwYyA/j09001zzR4bi3eacjR44DiEqQTHR4vHT2EQWVHIcJh75qxEhDzXuR
41Boy3V9sUyiQ5XIOveHz3IceqfnCTVPSHQoAIlH4OBzpEDcF5zjIANy3/MU
iH0ZuQ7qhhxrZLJSIfbezHXYB/JPRqrDrZ91WXsssuHyMP7bGnvTuLpUB6Hm
A6cWxhfA+VcrXqoZJhTA1XOB/CmWBzcP7O4HeRD3APmhIH8vzoeE44oUB5Dz
7JfmQ8KXHcEHh0NIskPcLk8epm4EHxwfnfmQ8GdJgfPB9NYUB6eEpxeUVudB
9EWnOqz6eMk36UcuRD40FRL+sbkQfwemQtydl+Owt2SyBMu+FIg7C6B8NgTf
EWTu+WSIO+/nOtwBhcuZZAerLSfK9t3OdfABmdebDHG/aB4kHjKSIe7uyIPE
o0uywwWl2z/r2vIcWl8H7pB7mgQJ3xt5EP+cSYKkl5t5EPvzkiD6bfIh4eaM
4IPd/zDRYQbQeQeq8h2qQeliVyIknsvzIe4NT4S6Mx81PbEg+GBzGvMdwkHm
9ydA0seJPFR+Th5cPTjeP+Wi6teEun9CAsTe5bkOLt05z39PTIDY14FQD/b3
S0T6fgcy71UOPH8BANfndxw=
                "], {{231.289, 
                144.21099999999998`}, {231.289, 140.555}, {235.547, 
                140.555}, {234.684, 144.21099999999998`}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{
                0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1,
                 0}}, {{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}, {0, 1, 
                0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {0,
                 1, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}, {0, 1, 
                0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {0,
                 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {
                0, 1, 0}, {0, 1, 0}}}, {{{237.11299999999997`, 144.246}, {
                238.344, 140.55100000000002`}, {241.14499999999998`, 
                140.55100000000002`}, {238.90200000000002`, 144.25}, {
                237.11299999999997`, 144.25}}, {{235.54299999999998`, 
                140.55100000000002`}, {236.254, 136.895}, {239.539, 
                136.85500000000002`}, {238.344, 140.555}}, {{241.105, 
                140.516}, {243.383, 136.895}, {248.05100000000002`, 
                136.895}, {244.39100000000002`, 140.555}}, CompressedData["
1:eJxTTMoPSmViYGAwB2IQ/U0jpv/QxiwHNbbGqc7tCQ6LXLd9/suQ7bB/vpT+
3QsJDkUZE9/WGGc7yEalWN/nT3RgAAGTbAeu64sLbLMSHfTvqrA1fkXwb577
HvwYyA/j09001zzR4bi3eacjR46DD5BKkEx0eLx09hEFlRyHCYe+asRIQ817
keNQaAs0QSbRoUpknfvDZzkOvdPzhJonJDoUgMQjMPl9ID5HCsR9wTkQ9z1P
gdiXkeugbsixRiYr1QHETbiZC/FPRqrDrZ91WXsssuHyMP7bGnvTuLpUB6Hm
A6cWxhfA+VcrXqoZJhTA1YP9KZYHNw/s7gd5EPcA+aEgfy/Od1gMCscVKQ4g
59kvzYeELzuCDw6HkGSHuF2ePEzdCD44PjrzHfaBzGdJgfO/guitKQ5OCU8v
KK3Og+iLTnVY9fGSb9KPXIh8aCok/GNzIf4OTIW4Oy/HYU/JZAmWfSmQcCyA
8tkQfEeQueeTHVRB7ryf63AbFC5nkh2stpwo23cbal5vMsT9onkQf2ckQ9zd
kQeJR5dkhwtKQJ1teQ6trwN3yD1NgoTvjTyIf84kQdLLzTyI/XlJEP02+ZBw
c0bwwfY9THSYAXTegap8h2pQutiV6CADiufyfEg4hCc63AG7Mx81PbEg+GBz
GvMh6bE/AZI+TuSh8nPy4OrB8f4pF1W/JjS+JyRAwml5roNzd87z3xMTIPZ1
INSD/f0Skb7fgcx7lQPPXwDcN3ca
                "], {{231.289, 144.211}, {
                231.289, 140.555}, {235.547, 140.555}, {234.684, 144.211}}},
               CurveClosed->{1, 1, 1, 1, 1}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{231.512, 
               150.67199999999997`}, {234.164, 150.67199999999997`}, {234.164,
                144.58599999999996`}, {231.512, 144.58599999999996`}}},
               CurveClosed->{1}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               227.76999999999998`, 144.16}, {230.35500000000002`, 144.16}, {
               230.34, 148.637}, {230.305, 150.582}, {232.05100000000002`, 
               152.547}, {232.89100000000002`, 152.60899999999998`}, {233.816,
                152.64499999999998`}, {235.184, 150.773}, {235.227, 
               148.78900000000002`}, {235.266, 144.14499999999998`}, {238.012,
                144.152}, {238.012, 155.67999999999998`}, {
               227.76999999999998`, 155.625}}},
               CurveClosed->{1}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{248.238, 
               141.488}, {251.449, 141.488}, {251.449, 138.988}, {248.238, 
               138.988}}},
               CurveClosed->{1}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{246.336, 
               145.78500000000003`}, {249.54700000000003`, 
               145.78500000000003`}, {249.54700000000003`, 
               143.28100000000003`}, {246.336, 143.28100000000003`}}},
               CurveClosed->{1}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{243.238, 
               150.07799999999997`}, {246.449, 150.07799999999997`}, {246.449,
                147.57799999999997`}, {243.238, 147.57799999999997`}}},
               CurveClosed->{1}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{240.594, 
               153.695}, {243.805, 153.695}, {243.805, 151.195}, {240.594, 
               151.195}}},
               CurveClosed->{1}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}}}, {{{238.465, 144.14499999999998`}, {241.75, 144.031}, {
               247.60899999999998`, 138.844}, {247.60899999999998`, 
               141.902}, {245.63299999999998`, 143.32}, {245.63299999999998`, 
               145.75}, {242.758, 147.39100000000002`}, {242.758, 150.004}, {
               239.95700000000002`, 150.938}, {239.95700000000002`, 
               154.484}, {238.539, 155.64499999999998`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{252.344, 
               151.71899999999997`}, {253.129, 151.71899999999997`}, {253.129,
                146.08199999999997`}, {252.344, 146.08199999999997`}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{252.344, 
               151.719}, {253.129, 151.719}, {253.129, 146.082}, {252.344, 
               146.082}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4gmHvmrE7M502DdfSv9uRKqD1ZYTZftmZzqE
8elumtud6rC3ZLIES1mmw0Wl2z/rhFIdGEDgS4bDcW/zTscdKQ5FGRPf1mzP
cHBMeHpBqT/FwQconNCb4aB/V4WtUTHFYZHrts9/ezIcQMrsbyY7xO3y5GHq
znCwBNmzPBli7qQMB67riwtsy5Lh6sF8t2SIOZ0ZEHs1kh1unvse/Dgzw6HA
FqjiSZJDMcjg+gyHfpA/LidBxHdkQPyzIslhRp5Q8wGmTIdVHy/5JnkkQcxX
yXSIBblDHSrvlAkR50ly6JsOFIjJhPhjLVS+KNOh9XXgDrmvSQ5bgc6e35Xp
oG7IsUbGKRniroZMSDjNS4aIH4Kqf5oMoT9C+aLQ8ErPcjgGCj+XFAdukD+j
shyEmw+cWhiZ4gAAUFevAg==
               "]]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4gmHvmrE7M502D9fSv9uRKqD1ZYTZftmZzqE
8elumtud6rC3ZLIES1mmwwWl2z/rhFIdGEDgS4bDcW/zTscdKQ5FGRPf1mzP
cHBMeHpBqT/FwQconNCb4aB/V4WtUTHFYZHrts9/ezIcMoHK7G8mO8Tt8uRh
6s5wsATZszzZ4SLI3EkZDlzXFxfYliXD1YP5bskQczozIPZqJDvcPPc9+HFm
hkOBLVDFkySHYpD99RkO/SB/XE6CiO/IgPhnRZLDjDyh5gNMmQ6rPl7yTfJI
gpivkglxhzpU3ikTIs6T5NA3HSgQk+kA8l7CWqh8UaZD6+vAHXJfkxy2Ap09
vyvTQd2QY42MUzLEXQ2ZDntA4TQvGSJ+CKr+aTKE/gjli0LDKz3L4RjIApcU
B26QP6OyHISbD5xaGJniAABSL68D
               "],
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[0.74902, 0., 0.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGI9IGYC4ts/67L2bMl0kI1Ksb5/PtmhWmSd+8NVmQ4X
lIAyz5IdjnubdzrOyXTYWzJZguVfssO7GnvTuK5MB67riwtshVIceqfnCTVX
QNWrpTiosjVOdU7OdAjj09001zwFYq431Hz7FAcfoHEJppkQcz1SHN6CzJPL
dHBKeHpBKRjK58t0cATx06F8tkyHRa7bPv8tSHGYcOirRsz/DAfh5gOnFtam
ODCAwJ8Mh0JboIt6UhxugfzzI8Nh64myffNnIfhg96xOgdjzOwNi/v4Uh1Uf
L/kmAeXB5u9JcagC+f9bhsMMoLcO7IKa/yXDoQBk/o4Uh6KMiW9rtmc4FIPo
/hSH1teBO+R6oe5RTHG4A7KvJ8NB/64KW+PNZIh+GP9oMiQcujMc1A051shs
SoarB4fnvGQHkLH2EzMcbp77Hvx4YjJE39QMh28aMf2HWqHmzYGqr0t2OAYK
xyUZkHgoSYaIr8uAxFdeMsT/O6D2ZyZDzD0LVZ+QDHHHM2h4xUHd8wdqfliy
w+Ols48oiEDj3w/K14HGl3WyAzj9OGRCwkclGRKeIZmQdMCfDAkvYHrYAjL/
W5KDAcgduZmQ+HqQBFGXnwkJ92dJEHcWZkLs+ZAEsac4EyL+NQninw6E/eB4
a4Gmpx6oe5DSMwC1Tkwb
               "]]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGI9IGYC4ts/67L2bMl0kI1Ksb5/PtmhWmSd+8NVmQ4X
lYAyz5IdjnubdzrOyXTYUzJZguVfssO7GnvTuK5MB67riwtshVIceqfnCTVX
QNWrpTiosjVOdU7OdAjj09001zwFYq431Hz7FAcfoHEJppkQcz1SHN6CzJPL
dHBMeHpBKRjK58t0cALx06F8tkyHRa7bPv8tSHGYcOirRsz/DAfh5gOnFtam
ODCAwJ8Mh0JboIt6UhxugfzzI8Nhy4myffNnIfhg96xOgZj7OwNi3/4Uh1Uf
L/kmAeXB5u9JcagC+f9bhsMMoLcO7IKa/wVq/o4Uh6KMiW9rtmc4FIPo/hSH
1teBO+R6oe5RTHG4A7KvJ8PB4K4KW+PNZIh+IF8PxD+aDAmH7gwHdUOONTKb
kuHqweE5L9kBZKz9xAyHm+e+Bz+emOygD9I3NcMB6Ov+Q61Q8+ZA1dclOxwD
heOSDEg8lCRDxNdlQOIrLxni/x1Q92QmQ8w9C1WfkAxxx7MMh62g8IqDuucP
1PywZIfHS2cfURCBxr8flK8DjS/rZAdw+nHIdCgAhY9KMiQ8QzIh6YA/GRJe
wPQANv9bEsQduVD1D5Ig6vIzIenuWRLEv4WZEHs+JEHiqzgTEn5fkyD+6UDY
D463Fmh66oG6Byk9AwC1BkwY
               "],
               CurveClosed->{1}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{199.85500000000002`,
                166.09}, {199.469, 163.402}, {200.965, 162.51199999999997`}, {
               202.375, 161.988}, {203.836, 161.47299999999998`}, {205.031, 
               159.906}, {205.648, 158.488}}},
               CurveClosed->{0}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{196.238, 157.246}, {
               196.85500000000002`, 154.934}, {198.477, 155.223}, {
               199.89100000000002`, 154.703}, {201.348, 154.184}, {
               202.88700000000003`, 152.336}, {203.5, 150.922}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               204.48800000000003`, 172.414}, {205.227, 
               172.89100000000002`}, {219.43, 148.97299999999998`}, {218.691, 
               148.496}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               204.48800000000003`, 172.414}, {205.227, 
               172.89100000000002`}, {219.43, 148.97299999999998`}, {218.691, 
               148.496}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{206.016, 173.36700000000002`}, {206.016, 172.512}, {
               205.23399999999998`, 171.73}, {204.379, 171.73}, {203.523, 
               171.73}, {202.742, 172.512}, {202.742, 173.36700000000002`}, {
               202.742, 174.227}, {203.523, 175.004}, {204.379, 175.004}, {
               205.23399999999998`, 175.004}, {206.016, 174.227}, {206.016, 
               173.36700000000002`}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{206.016, 173.36700000000002`}, {206.016, 
               172.51199999999997`}, {205.23399999999998`, 
               171.73000000000002`}, {204.379, 171.73000000000002`}, {203.523,
                171.73000000000002`}, {202.742, 172.51199999999997`}, {
               202.742, 173.36700000000002`}, {202.742, 
               174.22700000000003`}, {203.523, 175.004}, {204.379, 175.004}, {
               205.23399999999998`, 175.004}, {206.016, 
               174.22700000000003`}, {206.016, 173.36700000000002`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{218.16, 
               192.586}, {223.914, 192.586}, {223.914, 191.26600000000002`}, {
               218.16, 191.26600000000002`}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{218.16, 
               192.58599999999998`}, {223.914, 192.58599999999998`}, {223.914,
                191.266}, {218.16, 191.266}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{218.16, 
               190.078}, {223.914, 190.078}, {223.914, 179.055}, {218.16, 
               179.055}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{218.16, 
               190.07799999999997`}, {223.914, 190.07799999999997`}, {223.914,
                179.05499999999998`}, {218.16, 179.05499999999998`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}}}, {{{217.809, 
               194.09}, {224.191, 194.05100000000002`}, {224.441, 
               196.21499999999997`}, {222.281, 198.555}, {221.02, 198.531}, {
               219.77299999999997`, 198.469}, {217.758, 196.164}, {217.809, 
               194.09}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}}}, {{{217.809, 
               194.08999999999997`}, {224.191, 194.051}, {224.441, 196.215}, {
               222.281, 198.555}, {221.02, 198.531}, {219.77299999999997`, 
               198.469}, {217.758, 196.164}, {217.809, 194.08999999999997`}}},
               
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[0.741176, 0.41960800000000004`, 0.], Opacity[
              1.]}], FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                 3, 3}, {1, 3, 3}, {1, 3, 3}}}, {CompressedData["
1:eJxTTMoPSmViYGBQBmIQ7ZTw9IKSc65D3/Q8oeacDIfHS2cfUZDJhdAxGQ5c
1xcX2P7LcQjn0900Vz/DQTYqxfr+6xyI+j/pDvp3Vdgab+Y4eJt3OiacTHe4
qHT7Z92lHAdVtsapzv3pDmDzb+c49ILUJyD4VltOlO2LT3d4W2NvGncPar5/
usMMoLIDj3IcGEDAJd1BBmTfc6h663SHRa7bPv99k+NQlDHxbY1xusNWoPD8
TzkQWg/qnp85Dj4g9+imOxwHOYwB6h+ddAeQMfPZciHm6ac7cIP8x5ULUW+a
7nDz3Pfgx7y5DnG7PHmYgPaB1fHnQtzplO7gCHI/P1TeO91hwqGvGjHcUH51
ukMYyB9A/iVQOKyCqheHmn8VGj5KuVB3ZUDCzRJqvloGJHySoepdMyD+ysp1
qBZZ5/7QKwNiT36uA8j79oHQ+ADyLUHuDM9wAJqetacgFxJvcRkQc3JzIeqS
MxyAnr2+OAOqPj0D4v74XIdikIH5GQ6FIPmAXAd1Q441MkVQ9yClDwAIJfB7

                "], CompressedData["
1:eJxTTMoPSmViYGBQAmIQ7Zjw9IKSe66Dt3mnY0JihkPv9Dyh5oBch4yJb2vs
UzMcCm25ri+OyXWI2+XJw5Sc4aB/V4WtMRHKj89wkI1Ksb6fnOuwf76U/t2Y
DIfHS2cfUUjJdSgGGRCNkAebH5nhUAQSB/LB9oZnONw89z34MdC8/kNfNWKC
oeqjoeb7ZzgwgIBBrgPQNaZxehkOMiB58VyIO1ih6rlzIe6+kQ7h/89xCOPT
3TR3dTrEPQy5DtUi69wfVkHlmXMd1A051sh4pTus+njJN4klF+Iu53SHi0q3
f9Yx5UJou3SI/4H6rbacKNtnnQ4x51+OwyLXbZ//WqRD3P83B2KPBdT83zkQ
9wD53zRi+g/9zHHYBwofIB/s7q85kPCxhvI/5kDc45Tu4AMKp7c5Drd+1mXt
8UiHhNvLHEh4BKc7AF1TYPsMqj4Jyr+X47C3ZLIESx9U/9McB1W2xqnOx9Mh
4fwd6p4f6RB3cORC3K2ZAYln1VwHJ5A6YPijpwcAtQ3lmA==
                "]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
               1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, CompressedData["
1:eJxlU1tIVFEUHcaSiLDQKInRJlHHnk6FWiPi1oqCsidUiNkk2j5G20or6Ali
ffjRU6IgJjFzwEl6SEUfZSJBESEmQUVIhPQVfURURESdc/eSggaGw71n77XX
XmvdWTV7NtYl+Xw+v/3PxPmofUb+yAmh0MIJPYGIoYf729LHVQt9y6s6MzDb
kHe/XOjswNe8qt9MOcnNF5YVCR2ZemPl+0FGndCno6UF1VeYNqfM742FhA67
+51Mo12XHwfDQqcuNqS2LGFyR3+haN10Jp/7rRKa+Kpzb0kyU5+bt1Vo6Z2n
B/uSmMw5i7wD+H6m/JHs5OZ68BvP9CLr7Y/jDUKnHfAkpkbX0CTKM43p5McN
9zMPCF3/PFxRE0B9I/BDmGew/1rMqxN6M/h90+gx8N8t+r6bdW/bb1F2PXiJ
e6tfkyv4yarXNeiTanRuj1DCnelG+24JXXI6ZBpKa+l/1nEb+DmG7lpa7b1C
GZW1xe/mGiqLfhjKugl9FhkadvwT4FtodL8O8C0xut95oYjbrxT+/eOvN68V
/BYYKnf4bXi2+Ooj/Aob1bET+s4zqnuXKI85Rv2Mi/KweRly7+PwP9fo3Dj0
yjaqu8XzeAXBJwb8gFF/D0EfP/ZnoSeri1rLXkPvKPgmmK6uuPfll81L2PVZ
v9bYsug28KlAXnlMXyYHE60HXuDvvcdzGvyrHfMPeakR2uLyOpn1O9iO+hRW
HSpRb5/3lVin1sPvKchTGfhkMOW6ecWoj7Dqvxh5ZeS7AH7GML8c+jxnzdk6
0T6bN09Py9+bG/zf3z+xPLCC
               "]]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{217.848, 
               170.09}, {224.27, 170.09}, {224.27, 161.203}, {217.848, 
               161.203}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{217.848, 
               170.09}, {224.27, 170.09}, {224.27, 161.203}, {217.848, 
               161.203}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               218.22299999999998`, 156.121}, {224.422, 156.121}, {224.422, 
               154.25400000000002`}, {218.22299999999998`, 
               154.25400000000002`}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               218.22299999999998`, 156.121}, {224.422, 156.121}, {224.422, 
               154.25400000000002`}, {218.22299999999998`, 
               154.25400000000002`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{218.07, 
               152.84}, {224.418, 152.84}, {224.418, 145.895}, {218.07, 
               145.895}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{218.07, 
               152.84}, {224.418, 152.84}, {224.418, 145.895}, {218.07, 
               145.895}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{217.625, 
               144.47299999999998`}, {224.566, 144.47299999999998`}, {224.566,
                140.58999999999997`}, {217.625, 140.58999999999997`}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{217.625, 
               144.47299999999998`}, {224.566, 144.47299999999998`}, {224.566,
                140.58999999999997`}, {217.625, 140.58999999999997`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               218.48000000000002`, 157.79299999999998`}, {
               224.07399999999998`, 157.79299999999998`}, {225.184, 
               159.641}, {217.477, 159.641}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               218.48000000000002`, 157.793}, {224.07399999999998`, 
               157.793}, {225.184, 159.641}, {217.477, 159.641}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {1, 3, 3}}}, {{{226.023, 
               164.602}, {226.078, 169.45700000000002`}, {229.93, 
               169.45700000000002`}, {228.418, 168.207}, {227.008, 166.695}, {
               226.023, 164.602}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {1, 3, 3}}}, {{{226.023, 
               164.60199999999998`}, {226.078, 169.45700000000002`}, {229.93, 
               169.45700000000002`}, {228.418, 168.20700000000002`}, {227.008,
                166.695}, {226.023, 164.60199999999998`}}},
               CurveClosed->{1}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYCYqeEpxeUorMdijImvq0JTnFY/fGSb1JMtgPX
9cUFtkYpDi7dOc9/N2Y7LHLd9vmvA4L/TSOm/1AgmnxLisPWE2X75jdlO/RN
zxNq3pPiUGgLNKkh2+H2z7qsPQ9SHFaBzAfyw/h0N839DeUfyHbYN19K/+6X
FAcGEADyweJPUhyOe5t3OgL5ba8Dd8jtTIGYcwBqf20KxF4gP26XJw+Td4pD
L8heIP9tjb1pHND970D0q2yIuEkKRN9LhHr9uypsjUB+KMg9zQj+zXPfgx9f
RagvBoXP/xQHdUOONTJA81pB7jFNhdgPDC+wu01SHWSjUqzvR0P9y4Dgg8Pl
WooDLLxV2RqnOncj+LDwBwDld7xQ
               "],
               CurveClosed->{1}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               218.85500000000002`, 152.016}, {223.41000000000003`, 
               152.016}, {223.41000000000003`, 146.34}, {218.85500000000002`, 
               146.34}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               221.76999999999998`, 149.664}, {223.37499999999997`, 
               149.664}, {223.37499999999997`, 148.73}, {221.76999999999998`, 
               148.73}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               221.76999999999998`, 149.664}, {223.37499999999997`, 
               149.664}, {223.37499999999997`, 148.73}, {221.76999999999998`, 
               148.73}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{218.969, 
               149.664}, {220.535, 149.664}, {220.535, 148.73}, {218.969, 
               148.73}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{218.969, 
               149.664}, {220.535, 149.664}, {220.535, 148.73}, {218.969, 
               148.73}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{220.535, 
               151.945}, {221.769, 151.945}, {221.769, 149.629}, {220.535, 
               149.629}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{220.535, 
               151.945}, {221.769, 151.945}, {221.769, 149.629}, {220.535, 
               149.629}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{220.535, 
               148.76999999999998`}, {221.769, 148.76999999999998`}, {221.769,
                146.30499999999998`}, {220.535, 146.30499999999998`}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{220.535, 
               148.77}, {221.769, 148.77}, {221.769, 146.305}, {220.535, 
               146.305}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{195.191, 208.824}, {
               195.477, 204.371}, {194.094, 201.92600000000002`}, {
               191.73399999999998`, 202.297}, {191.086, 
               204.76999999999998`}, {192.566, 206.42600000000002`}, {195.191,
                208.824}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{195.191, 208.824}, {
               195.477, 204.371}, {194.094, 201.926}, {191.73399999999998`, 
               202.297}, {191.086, 204.76999999999998`}, {192.566, 206.426}, {
               195.191, 208.824}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{190.016, 198.953}, {
               187.918, 200.02}, {189.434, 208.164}, {190.238, 
               211.57399999999998`}, {190.83200000000002`, 207.18}, {
               191.82800000000003`, 200.93}, {190.016, 198.953}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{190.016, 
               198.95299999999997`}, {187.918, 200.01999999999998`}, {189.434,
                208.164}, {190.238, 211.574}, {190.83200000000002`, 207.18}, {
               191.82800000000003`, 200.93}, {190.016, 198.95299999999997`}}},
               
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{190.762, 198.566}, {
               194.285, 197.344}, {197.07399999999998`, 201.137}, {198.02, 
               205.535}, {195.10899999999998`, 201.52}, {190.375, 201.516}, {
               190.762, 198.566}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{190.762, 
               198.56599999999997`}, {194.285, 197.344}, {197.07399999999998`,
                201.137}, {198.02, 205.535}, {195.10899999999998`, 
               201.51999999999998`}, {190.375, 201.516}, {190.762, 
               198.56599999999997`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{188.09, 
               194.45700000000002`}, {185.33200000000002`, 195.184}, {
               186.99200000000002`, 203.824}, {187.49200000000002`, 
               207.281}, {188.098, 203.71099999999998`}, {190., 195.637}, {
               188.09, 194.45700000000002`}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{188.09, 194.457}, {
               185.33200000000002`, 195.184}, {186.99200000000002`, 
               203.824}, {187.49200000000002`, 207.281}, {188.098, 203.711}, {
               190., 195.637}, {188.09, 194.457}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{189.031, 194.727}, {
               189.18800000000002`, 197.707}, {192.156, 196.848}, {194.207, 
               198.43800000000002`}, {193.871, 196.94899999999998`}, {
               192.60899999999998`, 194.309}, {189.031, 194.727}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{189.031, 194.727}, {
               189.18800000000002`, 197.707}, {192.156, 196.848}, {194.207, 
               198.438}, {193.871, 196.949}, {192.60899999999998`, 194.309}, {
               189.031, 194.727}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{185.656, 
               190.73399999999998`}, {182.92600000000002`, 
               191.47299999999998`}, {184.566, 200.76999999999998`}, {184.41, 
               204.598}, {185.21099999999998`, 201.29299999999998`}, {187.75, 
               191.63299999999998`}, {185.656, 190.73399999999998`}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{185.656, 190.734}, {
               182.92600000000002`, 191.47299999999998`}, {184.566, 
               200.76999999999998`}, {184.41, 204.598}, {185.21099999999998`, 
               201.293}, {187.75, 191.63299999999998`}, {185.656, 190.734}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{186.93, 191.137}, {
               189.164, 190.41}, {192.129, 191.863}, {192.363, 
               194.52700000000002`}, {190.434, 193.21899999999997`}, {187.359,
                194.21899999999997`}, {186.93, 191.137}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{186.93, 191.137}, {
               189.164, 190.41}, {192.129, 191.863}, {192.363, 194.527}, {
               190.434, 193.219}, {187.359, 194.219}, {186.93, 191.137}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{183.617, 
               186.63299999999998`}, {181.004, 186.42200000000003`}, {182.172,
                194.344}, {182.176, 201.71899999999997`}, {
               183.13299999999998`, 194.824}, {185.75, 188.512}, {183.617, 
               186.63299999999998`}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{183.617, 
               186.63299999999998`}, {181.004, 186.422}, {182.172, 194.344}, {
               182.176, 201.719}, {183.13299999999998`, 194.824}, {185.75, 
               188.51199999999997`}, {183.617, 186.63299999999998`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{184.52, 
               186.99200000000002`}, {186.285, 186.105}, {189.445, 187.52}, {
               190.348, 190.5}, {187.16, 189.117}, {185.02700000000002`, 
               190.469}, {184.52, 186.99200000000002`}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{184.52, 186.992}, {
               186.285, 186.105}, {189.445, 187.51999999999998`}, {190.348, 
               190.5}, {187.16, 189.117}, {185.02700000000002`, 190.469}, {
               184.52, 186.992}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{205.023, 204.695}, {
               204.559, 200.83200000000002`}, {202.98000000000002`, 
               198.586}, {200.621, 198.95700000000002`}, {199.97299999999998`,
                201.42600000000002`}, {201.883, 203.008}, {205.023, 
               204.695}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{205.023, 204.695}, {
               204.559, 200.832}, {202.98000000000002`, 
               198.58599999999998`}, {200.621, 198.957}, {199.97299999999998`,
                201.426}, {201.883, 203.00799999999998`}, {205.023, 204.695}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{198.785, 194.785}, {
               202.70299999999997`, 194.227}, {204.11299999999997`, 
               197.23399999999998`}, {206.75, 201.08200000000002`}, {203.055, 
               198.406}, {198.637, 197.848}, {198.785, 194.785}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{198.785, 194.785}, {
               202.70299999999997`, 194.227}, {204.11299999999997`, 
               197.23399999999998`}, {206.75, 201.082}, {203.055, 198.406}, {
               198.637, 197.848}, {198.785, 194.785}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{197.672, 
               195.22299999999998`}, {195.535, 197.789}, {197.602, 201.008}, {
               199.23399999999998`, 203.75}, {198.883, 199.668}, {
               200.27299999999997`, 197.39800000000002`}, {197.672, 
               195.22299999999998`}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{197.672, 195.223}, {
               195.535, 197.789}, {197.602, 201.00799999999998`}, {
               199.23399999999998`, 203.75}, {198.883, 199.668}, {
               200.27299999999997`, 197.39800000000002`}, {197.672, 195.223}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{196.727, 
               190.99200000000002`}, {196.48800000000003`, 193.5}, {200.758, 
               194.055}, {202.691, 195.44899999999998`}, {202.039, 194.}, {
               201.055, 190.102}, {196.727, 190.99200000000002`}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{196.727, 190.992}, {
               196.48800000000003`, 193.5}, {200.758, 194.055}, {202.691, 
               195.449}, {202.039, 194.}, {201.055, 190.10199999999998`}, {
               196.727, 190.992}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{195.83200000000002`,
                190.93800000000002`}, {192.879, 191.26999999999998`}, {
               194.105, 196.285}, {196.22299999999998`, 199.07}, {
               195.33200000000002`, 195.227}, {197.781, 
               192.55100000000002`}, {195.83200000000002`, 
               190.93800000000002`}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{195.83200000000002`,
                190.938}, {192.879, 191.27}, {194.105, 196.285}, {
               196.22299999999998`, 199.07}, {195.33200000000002`, 195.227}, {
               197.781, 192.551}, {195.83200000000002`, 190.938}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{193.60899999999998`,
                186.762}, {190.24599999999998`, 188.24599999999998`}, {
               192.40200000000002`, 192.461}, {193.664, 
               194.94899999999998`}, {193.125, 191.684}, {195.82000000000002`,
                189.191}, {193.60899999999998`, 186.762}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{193.60899999999998`,
                186.762}, {190.24599999999998`, 188.246}, {
               192.40200000000002`, 192.461}, {193.664, 194.949}, {193.125, 
               191.684}, {195.82000000000002`, 189.191}, {193.60899999999998`,
                186.762}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{194.27299999999997`,
                187.15200000000002`}, {196.035, 184.848}, {
               199.47299999999998`, 187.84}, {200.18, 191.33200000000002`}, {
               197.18800000000002`, 188.84}, {194.977, 189.25}, {
               194.27299999999997`, 187.15200000000002`}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{194.27299999999997`,
                187.152}, {196.035, 184.84799999999998`}, {
               199.47299999999998`, 187.84}, {200.18, 191.332}, {
               197.18800000000002`, 188.84}, {194.977, 189.25}, {
               194.27299999999997`, 187.152}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIZIGYC4rhdnjxMwekOXNcXF9jGpTrIRKVY33dPd2AA
gTOpDpeUbv+sm5XuUJQx8W3N5DQHWZB8fLrD3pLJEiz/0iDqw9MdCm2BJvCk
O3ibdzomFKY79B/6qhFjnO5w89z34MeN6RB90ukOYXy6m+bOhtr3Lc1B3ZBj
jcy2dAenhKcXlLrTHEDW2B9Md5iRJ9R8YFOawyLXbZ//nkl3+KYR03/obhpE
/ByUr5nusH++lP7dL+kOvdOBEhbpDq2vA3fI8WZAaMd0h2KQgfoZDlUi69wf
uqVD7FPLgLhXId3hzs+6rD0yGRD3/U6D+JsDqv9kmgM4fOQzIPYdTXPoA9mj
A1V/GCofnAEJh+9pkHAqhsrzQ93Zm+HgAwoX1XSH2yD7tmQ4WG45UbaPOd3h
Iih8+zIcQkHh8jjNwaU75/lvwQyH1R8v+SbVpDno31Vha5wJDUffNIdqkD+C
EPEFABcywTw=
               "]]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIZIGYC4rhdnjxMwekOXNcXF9jGpTrIRKVY33dPd2AA
gTOpDpeUbv+sm5XuUJQx8W3N5DQHWZB8fLrDnpLJEiz/0iDqw9MdCm2BJvCk
O3ibdzomFKY79B/6qhFjnO5w89z34MeN6RB90ukOYXy6m+bOhtr3Lc1B3ZBj
jcy2dAfHhKcXlLrTHEDW2B9Md5iRJ9R8YFOawyLXbZ//nkl3+KYR03/obhpE
/ByUr5nusH++lP7dL+kOfdOBEhbpDq2vA3fI8WZAaMd0h2KQgfoZDtUi69wf
uqVD7FPLcCgAuVch3eHOz7qsPTIZEPf9ToP4myPDoQ2k/2SaAzh85DMcvoLs
O5oGsUcHqv4wVD4Yyv+eBgmnYiifH+rO3gxIuKimO9wG2bclw8Fyy4myfczp
DhdB4duX4RAKCpfHaQ4u3TnPfwtmOKz+eMk3qSbNQf+uClvjTGg4+qZB/BGE
iC8AFarBOw==
               "],
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIZIGYC4qKMiW9ritMcRNa5P6y6Euuwf76U/t2UNAeX
7pznv29C+QFpDu1iN899fxzrELfLk4cpOc0BSGq3b4t1WPXxkm/SlzSH3ul5
Qs0BMQ4XlW7/rJNLd/imEdN/6G00hP8p3YEBBBRiHApsua4vPpEBUR8R4xDG
p7tp7u8MB78kgQjLMzEOws0HTi2cmAlxT0kshP8wE2LOpVgHkLYDYVkOxSB3
P4+F0OuzHDKBlP3aWId9IPfeyHIA2lJgOynWAejq4McfsyD2TYh1OOZt3ul4
Jcth09z3y4+djnXYcqJs3/xtWQ5PLwAtYItzCAW5Z3KWgyVIIjzOwTEBKJOf
5bBGJirFuj/OYcKhrxox8lkONfamcbs44x1AwvenZzo8A+m3i3cAGZ+gmQlx
l3i8Q+vrwB1yvRmQ8HoWBwkHngyIvHwcJJwK0yH+B4Z/ISh8FNIh9q2Phbjj
eJoD0PdZe7bEOqDHFwBlE80j
               "]]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIZIGYC4qKMiW9ritMcRNa5P6y6Euuwf76U/t2UNAeX
7pznv29C+QFpDm1iN899fxzrELfLk4cpOc3Bi4dJu31brMOqj5d8k76kOfRN
zxNqDohxuKh0+2edXLrDN42Y/kNvoyH8T+kODCCgEONQYMt1ffGJDIj6iBiH
MD7dTXN/Zzj4JQlEWJ6JcRBuPnBq4cRMiHtKYiH8h5kOl0DmXIp1AGk7EJbl
AHb381iHYhC9PsshC0jZr4112Ady740sB57riwtsJ8U6AF0d/PhjFsS+CbEO
x7zNOx2vZDlsmvt++bHTsQ5bTpTtm78ty+HJBaAFbHEOoSD3TM5ysAJJhMc5
OCY8vaCUn+WwRiYqxbo/zmHCoa8aMfJZDjX2pnG7OOMdQML3p2c6PAPpt4t3
ABmfoJnpUAJyl3i8Q+vrwB1yvRkOHqDwehYHCQeeDIj75eMg4VSYDvE/MPwL
QeGjkA6xb32sgyXIHcfTHO78rMvasyXWAT2+AGtDzSk=
               "],
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{217.84, 
               109.32}, {218.684, 109.215}, {219.21899999999997`, 
               107.57799999999999`}, {219.637, 108.68799999999999`}, {220.34, 
               110.48}, {219.848, 111.906}, {219.055, 111.75}, {218.117, 
               111.5}, {216.535, 109.402}, {217.84, 109.32}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{217.84, 
               109.32}, {218.684, 109.215}, {219.21899999999997`, 
               107.57799999999997`}, {219.637, 108.68799999999999`}, {220.34, 
               110.47999999999999`}, {219.848, 111.906}, {219.055, 111.75}, {
               218.117, 111.5}, {216.535, 109.40199999999999`}, {217.84, 
               109.32}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4gmHvmrE8Kc5ZEx8W2O/NdXhuLd5p+OHVIdv
GjH9h66mQsR/pjqoG3KskXmU6qDK1jjVWT3NYeuJsn3zgXyrLUCGd5rDItdt
n/8+SXVgAIEpaRBzzqQ6FIMMWA/lP0h1KLDlur74RJrDRaXbP+s+pULM2ZcG
0eeQBrH3ZJqDJcjcZKg959Icwvh0N80tT3MoBOm/k+ZQJbLO/eG0NAfZqBTr
+7/TIO5LS4OYH5HuoH9Xha3xYqpD3/Q8oeYz6Q6OCU8vKMmnOuwtmSzB8i/d
YdXHS75JBSkQd0tkOAB9aRrHlwJx73+o/tJkCL00HeIOvmSHWz/rsvasSHcA
2lJgm5bs8Hjp7CMKHemQcFqYDPFnQrrDJZD/XiVD7NVPd5gBdMYBrxSIvRVp
DuEg//inOqCHPwBV9Ldy
               "]], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{188.42600000000002`,
                149.24599999999998`}, {191.60899999999998`, 
               149.23399999999998`}, {192.156, 153.504}, {192.156, 
               154.69899999999998`}, {190.59, 154.39800000000002`}, {
               187.82800000000003`, 151.785}, {188.42600000000002`, 
               149.24599999999998`}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{188.42600000000002`,
                149.246}, {191.60899999999998`, 149.234}, {192.156, 
               153.504}, {192.156, 154.69899999999998`}, {190.59, 154.398}, {
               187.82800000000003`, 151.78500000000003`}, {
               188.42600000000002`, 149.246}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{215.961, 107.793}, {
               218.227, 107.277}, {218.195, 112.73400000000001`}, {215.879, 
               115.04700000000001`}, {216.89800000000002`, 111.543}, {214.176,
                108.336}, {215.961, 107.793}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{215.961, 107.793}, {
               218.227, 107.27700000000002`}, {218.195, 
               112.73400000000001`}, {215.879, 115.047}, {216.89800000000002`,
                111.54299999999998`}, {214.176, 108.33600000000001`}, {
               215.961, 107.793}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{215.078, 107.84}, {
               215.23, 105.24600000000001`}, {208.71499999999997`, 
               108.17999999999999`}, {207.039, 110.195}, {210.88700000000003`,
                108.562}, {214.89100000000002`, 109.91400000000002`}, {
               215.078, 107.84}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{215.078, 107.84}, {
               215.23, 105.24600000000001`}, {208.71499999999997`, 
               108.17999999999998`}, {207.039, 110.195}, {210.88700000000003`,
                108.56199999999998`}, {214.89100000000002`, 
               109.91399999999999`}, {215.078, 107.84}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{212.22299999999998`,
                111.543}, {212.45700000000002`, 109.031}, {
               206.57399999999998`, 111.242}, {204.83200000000002`, 
               113.203}, {208.69899999999998`, 111.953}, {211.969, 113.613}, {
               212.22299999999998`, 111.543}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{212.22299999999998`,
                111.54299999999998`}, {212.45700000000002`, 109.031}, {
               206.57399999999998`, 111.24199999999999`}, {
               204.83200000000002`, 113.203}, {208.69899999999998`, 
               111.953}, {211.969, 113.61299999999997`}, {212.22299999999998`,
                111.54299999999998`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{213.305, 111.191}, {
               215.57, 110.67599999999999`}, {215.20299999999997`, 116.32}, {
               213., 118.262}, {214.059, 114.49600000000001`}, {211.523, 
               111.738}, {213.305, 111.191}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{213.305, 111.191}, {
               215.57, 110.67599999999999`}, {215.20299999999997`, 116.32}, {
               213., 118.262}, {214.059, 114.49600000000001`}, {211.523, 
               111.738}, {213.305, 111.191}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{210.92200000000003`,
                114.62499999999999`}, {213.18800000000002`, 114.109}, {
               211.88700000000003`, 118.96900000000001`}, {210.207, 
               120.91000000000001`}, {210.48000000000002`, 117.367}, {209.363,
                114.91000000000001`}, {210.92200000000003`, 
               114.62499999999999`}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{210.92200000000003`,
                114.625}, {213.18800000000002`, 114.10899999999998`}, {
               211.88700000000003`, 118.969}, {210.207, 120.91}, {
               210.48000000000002`, 117.36700000000002`}, {209.363, 114.91}, {
               210.92200000000003`, 114.625}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{209.71899999999997`,
                114.641}, {209.953, 112.051}, {205.375, 114.039}, {203.598, 
               116.488}, {207.42600000000002`, 115.238}, {209.465, 
               116.70700000000001`}, {209.71899999999997`, 114.641}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{209.71899999999997`,
                114.64099999999999`}, {209.953, 112.05100000000002`}, {
               205.375, 114.03899999999999`}, {203.598, 116.488}, {
               207.42600000000002`, 115.238}, {209.465, 
               116.70700000000002`}, {209.71899999999997`, 
               114.64099999999999`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{208.47299999999998`,
                116.609}, {209.95700000000002`, 117.67599999999999`}, {
               208.383, 120.5}, {205.555, 120.324}, {205.83200000000002`, 
               118.617}, {206.809, 115.621}, {208.47299999999998`, 
               116.609}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{208.47299999999998`,
                116.60899999999998`}, {209.95700000000002`, 
               117.67599999999999`}, {208.383, 120.5}, {205.555, 
               120.32400000000001`}, {205.83200000000002`, 
               118.61699999999999`}, {206.809, 115.62100000000001`}, {
               208.47299999999998`, 116.60899999999998`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{219.63299999999998`,
                104.902}, {219.781, 102.309}, {213.266, 
               103.60199999999999`}, {211.21899999999997`, 106.363}, {
               215.32800000000003`, 105.586}, {219.441, 106.98}, {
               219.63299999999998`, 104.902}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{219.63299999999998`,
                104.90199999999999`}, {219.781, 102.309}, {213.266, 
               103.60199999999998`}, {211.21899999999997`, 106.363}, {
               215.32800000000003`, 105.58600000000001`}, {219.441, 
               106.97999999999999`}, {219.63299999999998`, 
               104.90199999999999`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{193.742, 109.543}, {
               193.977, 106.95700000000001`}, {186.863, 109.801}, {185.086, 
               112.25}, {188.91, 111.}, {193.48800000000003`, 111.613}, {
               193.742, 109.543}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{193.742, 
               109.54299999999998`}, {193.977, 106.95700000000002`}, {186.863,
                109.80100000000002`}, {185.086, 112.25}, {188.91, 111.}, {
               193.48800000000003`, 111.61299999999997`}, {193.742, 
               109.54299999999998`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{198.105, 
               108.44100000000002`}, {199.59, 109.508}, {196.559, 112.258}, {
               194.14499999999998`, 112.902}, {194.418, 111.199}, {196.441, 
               107.453}, {198.105, 108.44100000000002`}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{198.105, 108.441}, {
               199.59, 109.50799999999998`}, {196.559, 112.25800000000001`}, {
               194.14499999999998`, 112.90199999999999`}, {194.418, 
               111.19899999999998`}, {196.441, 107.453}, {198.105, 108.441}}},
               
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{198.559, 106.648}, {
               198.71899999999997`, 104.32}, {190.93, 105.598}, {188.895, 
               107.74600000000001`}, {195.594, 106.535}, {198.34, 108.641}, {
               198.559, 106.648}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{198.559, 
               106.64799999999997`}, {198.71899999999997`, 104.32}, {190.93, 
               105.59799999999998`}, {188.895, 107.74600000000001`}, {195.594,
                106.535}, {198.34, 108.64099999999999`}, {198.559, 
               106.64799999999997`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{202.207, 105.098}, {
               203.07399999999998`, 102.93400000000001`}, {195.598, 
               103.46100000000001`}, {192.97299999999998`, 
               104.71900000000001`}, {197.21499999999997`, 104.754}, {
               201.61299999999997`, 106.60199999999999`}, {202.207, 
               105.098}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{202.207, 
               105.09799999999998`}, {203.07399999999998`, 102.934}, {195.598,
                103.46100000000001`}, {192.97299999999998`, 104.719}, {
               197.21499999999997`, 104.75400000000002`}, {
               201.61299999999997`, 106.60199999999998`}, {202.207, 
               105.09799999999998`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{205.70299999999997`,
                103.52}, {206.531, 101.582}, {199.617, 101.62499999999999`}, {
               196.24599999999998`, 102.695}, {200.71099999999998`, 102.73}, {
               204.88700000000003`, 105.438}, {205.70299999999997`, 
               103.52}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{205.70299999999997`,
                103.51999999999998`}, {206.531, 101.582}, {199.617, 
               101.625}, {196.24599999999998`, 102.695}, {200.71099999999998`,
                102.73000000000002`}, {204.88700000000003`, 
               105.43799999999999`}, {205.70299999999997`, 
               103.51999999999998`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{210.73399999999998`,
                102.48}, {211.961, 100.18799999999999`}, {204.664, 99.965}, {
               202.297, 101.09400000000001`}, {206.516, 
               101.67199999999998`}, {209.691, 104.285}, {210.73399999999998`,
                102.48}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{210.73399999999998`,
                102.47999999999999`}, {211.961, 100.18799999999999`}, {
               204.664, 99.965}, {202.297, 101.094}, {206.516, 
               101.67199999999997`}, {209.691, 104.28500000000003`}, {
               210.73399999999998`, 102.47999999999999`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{202.191, 106.398}, {
               199.871, 104.938}, {199.996, 109.25}, {198.148, 112.238}, {
               201.05100000000002`, 109.598}, {203.766, 
               107.79700000000001`}, {202.191, 106.398}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{202.191, 106.398}, {
               199.871, 104.93799999999999`}, {199.996, 109.25}, {198.148, 
               112.238}, {201.05100000000002`, 109.59799999999998`}, {203.766,
                107.79700000000003`}, {202.191, 106.398}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{206.305, 104.848}, {
               204.35500000000002`, 103.12499999999999`}, {
               202.80100000000002`, 109.043}, {201.02700000000002`, 
               112.367}, {203.895, 109.203}, {208.102, 106.281}, {206.305, 
               104.848}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{206.305, 
               104.84799999999998`}, {204.35500000000002`, 103.125}, {
               202.80100000000002`, 109.04299999999998`}, {
               201.02700000000002`, 112.36700000000002`}, {203.895, 
               109.203}, {208.102, 106.28100000000003`}, {206.305, 
               104.84799999999998`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{211.742, 103.199}, {
               210.094, 101.289}, {205.32800000000003`, 108.816}, {203.594, 
               112.73400000000001`}, {206.23399999999998`, 109.684}, {213.055,
                104.82}, {211.742, 103.199}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{211.742, 
               103.19899999999998`}, {210.094, 101.28900000000002`}, {
               205.32800000000003`, 108.816}, {203.594, 
               112.73400000000001`}, {206.23399999999998`, 109.684}, {213.055,
                104.82}, {211.742, 103.19899999999998`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{207.105, 
               97.45700000000001}, {206.281, 94.551}, {194.15200000000002`, 
               100.195}, {192.797, 103.117}, {199.738, 99.44100000000002}, {
               207.26999999999998`, 100.21100000000001`}, {207.105, 
               97.45700000000001}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{207.105, 
               97.45700000000002}, {206.281, 94.55100000000002}, {
               194.15200000000002`, 100.195}, {192.797, 
               103.11699999999999`}, {199.738, 99.441}, {207.26999999999998`, 
               100.21100000000001`}, {207.105, 97.45700000000002}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYCYtmoFOv7zKkOYLo/2WFGnlDzgV8pDmF8upvm
zk52KLTlur74QYpDOIgPlHdMeHpB6XmKgxOILk52yJj4tsb+bYrDnZ91WXt8
kh1unvse/Fg1FaK/PclBla1xqnN7qoPllhNl+5yTIOadSXX4phHTf0gwyUH/
rgpbo2W6Q+vrwB1yBxMd4nZ58jDdT3eoFlnn/nBeooNLd87z35YZEH09iQ5A
ssC2LQPijnio/MEMh+kgd4slQtyzMgNibmmig495p2PC1AyIe3YnQsUzHISb
D5xaCLT/gtLtn3VhGQ6LXLd9/huT5LDq4yXfJJYMiH/XQ92/Pt2BAQS2JEHc
KZgOcf/OJIdekMUuaRB1x5Mg4bge6l/2ZEg4JUP56tDwMk2F+DM42QE9/AFt
n6we
               "]]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYCYtmoFOv7zKkOYLo/2WFGnlDzgV8pDmF8upvm
zk52KLTlur74AZQPlHdMeHpB6XkKhC5OdsiY+LbG/m2Kw+2fdVl7fJIdbp77
HvxYNRWivj3JQZWtcapze6qD5ZYTZfuckyDmnUl1+KYR039IMMlB/64KW6Nl
ukPr68AdcgcTHeJ2efIw3U93qBZZ5/5wXqKDS3fO89+WGRB9PYkOQLLAti0D
Yn88VP5gBsTdYokQ96zMcNADmVua6OBj3umYMDUD4p7diRD7SjMchJsPnFoI
tP+CEtDlYRkOi1y3ff4bk+Sw6uMl3yQWqPr1UPevT3dgAIEtSRB3CqZD3L8z
yaF3OtBilzQHNZC640mQcFwP9S97soMTyJ3JUL46NLxMUyH+DE52QA9/AGl3
rBs=
               "],
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{196.434, 132.105}, {
               197.98800000000003`, 130.95700000000002`}, {199.707, 
               135.066}, {197.73, 138.97299999999998`}, {197.668, 
               135.21499999999997`}, {194.68, 133.94899999999998`}, {196.434, 
               132.105}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{196.434, 132.105}, {
               197.98800000000003`, 130.95700000000002`}, {199.707, 
               135.066}, {197.73, 138.97299999999998`}, {197.668, 135.215}, {
               194.68, 133.94899999999998`}, {196.434, 132.105}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{197.93, 128.336}, {
               200.08200000000002`, 127.67599999999999`}, {200.758, 
               131.484}, {199.34, 134.535}, {199.57399999999998`, 131.258}, {
               195.953, 129.285}, {197.93, 128.336}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{197.93, 128.336}, {
               200.08200000000002`, 127.67599999999999`}, {200.758, 
               131.484}, {199.34, 134.535}, {199.57399999999998`, 131.258}, {
               195.953, 129.28500000000003`}, {197.93, 128.336}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{199.566, 125.312}, {
               201.648, 124.277}, {202.43800000000002`, 128.125}, {200.941, 
               130.984}, {201.105, 127.34}, {197.965, 126.262}, {199.566, 
               125.312}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{199.566, 
               125.31199999999998`}, {201.648, 124.27700000000002`}, {
               202.43800000000002`, 128.125}, {200.941, 130.984}, {201.105, 
               127.34}, {197.965, 126.262}, {199.566, 125.31199999999998`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{198.71099999999998`,
                125.07799999999999`}, {197.88700000000003`, 122.617}, {
               193.105, 127.203}, {192.30100000000002`, 
               129.69899999999998`}, {195.26999999999998`, 126.75}, {199.305, 
               127.07799999999999`}, {198.71099999999998`, 
               125.07799999999999`}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{198.71099999999998`,
                125.07799999999997`}, {197.88700000000003`, 
               122.61699999999999`}, {193.105, 127.203}, {192.30100000000002`,
                129.69899999999998`}, {195.26999999999998`, 126.75}, {199.305,
                127.07799999999997`}, {198.71099999999998`, 
               125.07799999999997`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{196.54299999999998`,
                128.848}, {195.605, 126.383}, {189.594, 132.727}, {188.266, 
               135.781}, {191.23399999999998`, 132.836}, {197.21099999999998`,
                130.586}, {196.54299999999998`, 128.848}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{196.54299999999998`,
                128.84799999999998`}, {195.605, 126.38300000000001`}, {
               189.594, 132.72700000000003`}, {188.266, 
               135.78100000000003`}, {191.23399999999998`, 132.836}, {
               197.21099999999998`, 130.586}, {196.54299999999998`, 
               128.84799999999998`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{195.35200000000003`,
                132.54299999999998`}, {194.414, 129.742}, {187.879, 
               137.207}, {186.02700000000002`, 139.85200000000003`}, {
               189.14499999999998`, 136.941}, {196.059, 134.578}, {
               195.35200000000003`, 132.54299999999998`}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{195.35200000000003`,
                132.54299999999998`}, {194.414, 129.742}, {187.879, 
               137.20700000000002`}, {186.02700000000002`, 139.852}, {
               189.14499999999998`, 136.941}, {196.059, 
               134.57799999999997`}, {195.35200000000003`, 
               132.54299999999998`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{195.14499999999998`,
                135.312}, {197.445, 135.758}, {195.012, 137.676}, {192.191, 
               140.79299999999998`}, {192.062, 137.512}, {192.598, 
               135.21899999999997`}, {195.14499999999998`, 135.312}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{195.14499999999998`,
                135.31199999999998`}, {197.445, 135.758}, {195.012, 
               137.676}, {192.191, 140.793}, {192.062, 137.51199999999997`}, {
               192.598, 135.219}, {195.14499999999998`, 135.31199999999998`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{191.266, 137.176}, {
               192.258, 138.258}, {190.312, 138.71899999999997`}, {
               187.90200000000002`, 141.42200000000003`}, {187.547, 
               139.602}, {190.137, 136.262}, {191.266, 137.176}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{191.266, 137.176}, {
               192.258, 138.258}, {190.312, 138.719}, {187.90200000000002`, 
               141.422}, {187.547, 139.60199999999998`}, {190.137, 136.262}, {
               191.266, 137.176}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{202.39800000000002`,
                125.016}, {203.66, 124.277}, {204.52, 126.859}, {202.953, 
               129.195}, {202.594, 126.66799999999999`}, {201.24599999999998`,
                125.965}, {202.39800000000002`, 125.016}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{202.39800000000002`,
                125.01599999999999`}, {203.66, 124.27700000000002`}, {204.52, 
               126.85900000000001`}, {202.953, 129.195}, {202.594, 
               126.66799999999998`}, {201.24599999999998`, 125.965}, {
               202.39800000000002`, 125.01599999999999`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{175.047, 141.297}, {
               172.375, 139.691}, {168.125, 146.09}, {166.99200000000002`, 
               148.72299999999998`}, {169.34, 145.69899999999998`}, {175.555, 
               142.941}, {175.047, 141.297}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{175.047, 
               141.29700000000003`}, {172.375, 139.691}, {168.125, 146.09}, {
               166.99200000000002`, 148.723}, {169.34, 145.69899999999998`}, {
               175.555, 142.941}, {175.047, 141.29700000000003`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{177.32000000000002`,
                137.566}, {175.84, 135.92600000000002`}, {171.184, 140.383}, {
               169.566, 142.641}, {172.062, 140.48000000000002`}, {
               177.97299999999998`, 140.22299999999998`}, {
               177.32000000000002`, 137.566}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{177.32000000000002`,
                137.566}, {175.84, 135.92600000000002`}, {171.184, 140.383}, {
               169.566, 142.641}, {172.062, 140.48}, {177.97299999999998`, 
               140.223}, {177.32000000000002`, 137.566}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{179.85500000000002`,
                134.22299999999998`}, {179.36700000000002`, 131.984}, {172.57,
                137.02}, {170.98000000000002`, 139.406}, {173.914, 
               136.64499999999998`}, {180.30100000000002`, 136.895}, {
               179.85500000000002`, 134.22299999999998`}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{179.85500000000002`,
                134.223}, {179.36700000000002`, 131.984}, {172.57, 
               137.01999999999998`}, {170.98000000000002`, 139.406}, {173.914,
                136.64499999999998`}, {180.30100000000002`, 136.895}, {
               179.85500000000002`, 134.223}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{178.816, 
               131.80100000000002`}, {177.766, 129.781}, {172.238, 134.781}, {
               170.914, 137.39100000000002`}, {174.289, 134.441}, {179.672, 
               133.797}, {178.816, 131.80100000000002`}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{178.816, 
               131.80100000000002`}, {177.766, 129.78100000000003`}, {172.238,
                134.78100000000003`}, {170.914, 137.39100000000002`}, {
               174.289, 134.441}, {179.672, 133.79700000000003`}, {178.816, 
               131.80100000000002`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{175.977, 141.625}, {
               177.71899999999997`, 143.465}, {176.977, 144.324}, {175.707, 
               147.22299999999998`}, {175.012, 144.24599999999998`}, {173.961,
                143.059}, {175.977, 141.625}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{175.977, 141.625}, {
               177.71899999999997`, 143.465}, {176.977, 144.324}, {175.707, 
               147.223}, {175.012, 144.246}, {173.961, 143.059}, {175.977, 
               141.625}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{178.289, 
               138.15200000000002`}, {181.453, 138.012}, {178.32000000000002`,
                141.863}, {177.57, 145.094}, {177.844, 141.41}, {176.758, 
               138.504}, {178.289, 138.15200000000002`}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{178.289, 138.152}, {
               181.453, 138.01199999999997`}, {178.32000000000002`, 
               141.863}, {177.57, 145.094}, {177.844, 141.41}, {176.758, 
               138.504}, {178.289, 138.152}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{180.305, 135.098}, {
               182.496, 135.59}, {181.863, 138.695}, {180.184, 
               142.44899999999998`}, {180.531, 138.39100000000002`}, {
               178.32800000000003`, 136.047}, {180.305, 135.098}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{180.305, 
               135.09799999999998`}, {182.496, 135.59}, {181.863, 138.695}, {
               180.184, 142.44899999999998`}, {180.531, 
               138.39100000000002`}, {178.32800000000003`, 136.047}, {180.305,
                135.09799999999998`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{179.559, 128.961}, {
               178.73399999999998`, 126.49600000000001`}, {172.5, 
               132.20299999999997`}, {171.508, 134.363}, {174.66, 
               131.71499999999997`}, {180.117, 130.809}, {179.559, 
               128.961}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{179.559, 128.961}, {
               178.73399999999998`, 126.49600000000001`}, {172.5, 132.203}, {
               171.508, 134.363}, {174.66, 131.715}, {180.117, 130.809}, {
               179.559, 128.961}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{183.297, 125.113}, {
               182.359, 122.648}, {175.824, 127.645}, {173.824, 
               130.36700000000002`}, {177.762, 127.27}, {183.777, 
               127.55499999999999`}, {183.297, 125.113}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{183.297, 
               125.11299999999997`}, {182.359, 122.64799999999997`}, {175.824,
                127.64499999999998`}, {173.824, 130.36700000000002`}, {
               177.762, 127.27000000000001`}, {183.777, 127.555}, {183.297, 
               125.11299999999997`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{187.105, 121.23}, {
               186.055, 117.79700000000001`}, {179.22299999999998`, 
               123.281}, {177.184, 125.965}, {181.535, 122.645}, {187.66, 
               123.67599999999999`}, {187.105, 121.23}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{187.105, 
               121.23000000000002`}, {186.055, 117.79700000000003`}, {
               179.22299999999998`, 123.28100000000003`}, {177.184, 
               125.965}, {181.535, 122.64499999999998`}, {187.66, 
               123.67599999999999`}, {187.105, 121.23000000000002`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{180.68, 130.055}, {
               182.535, 129.094}, {183.285, 134.363}, {182.238, 
               138.08200000000002`}, {182.254, 134.023}, {178.516, 131.008}, {
               180.68, 130.055}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{180.68, 130.055}, {
               182.535, 129.094}, {183.285, 134.363}, {182.238, 138.082}, {
               182.254, 134.023}, {178.516, 131.00799999999998`}, {180.68, 
               130.055}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{183.848, 125.871}, {
               186.078, 125.21100000000001`}, {185.371, 
               130.88700000000003`}, {183.465, 134.57}, {183.21899999999997`, 
               130.92200000000003`}, {181.57399999999998`, 
               127.45700000000001`}, {183.848, 125.871}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{183.848, 
               125.87100000000001`}, {186.078, 125.21100000000001`}, {185.371,
                130.88700000000003`}, {183.465, 134.57}, {183.21899999999997`,
                130.922}, {181.57399999999998`, 127.45700000000002`}, {
               183.848, 125.87100000000001`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{187.809, 121.953}, {
               190.30100000000002`, 121.812}, {188.586, 126.82}, {186.531, 
               129.641}, {186.879, 125.95700000000001`}, {185.71899999999997`,
                122.37899999999999`}, {187.809, 121.953}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{187.809, 121.953}, {
               190.30100000000002`, 121.81199999999998`}, {188.586, 126.82}, {
               186.531, 129.641}, {186.879, 125.95700000000002`}, {
               185.71899999999997`, 122.37899999999999`}, {187.809, 121.953}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{183.441, 119.816}, {
               182.691, 118.54700000000001`}, {180.859, 120.895}, {
               177.85200000000003`, 122.60499999999999`}, {180.555, 
               121.898}, {183.77299999999997`, 120.992}, {183.441, 
               119.816}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{183.441, 119.816}, {
               182.691, 118.547}, {180.859, 120.89500000000001`}, {
               177.85200000000003`, 122.60499999999999`}, {180.555, 
               121.898}, {183.77299999999997`, 120.99199999999999`}, {183.441,
                119.816}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{182.016, 162.008}, {
               184.34, 163.727}, {182.566, 166.945}, {182.016, 170.008}, {
               181.26999999999998`, 167.105}, {179.297, 163.297}, {182.016, 
               162.008}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{182.016, 
               162.00799999999998`}, {184.34, 163.72700000000003`}, {182.566, 
               166.945}, {182.016, 170.00799999999998`}, {181.26999999999998`,
                167.105}, {179.297, 163.29700000000003`}, {182.016, 
               162.00799999999998`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{181.93800000000002`,
                157.71899999999997`}, {178.441, 158.141}, {178.969, 
               162.656}, {178.863, 165.52}, {179.914, 161.63299999999998`}, {
               182.777, 160.977}, {181.93800000000002`, 
               157.71899999999997`}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{181.93800000000002`,
                157.719}, {178.441, 158.141}, {178.969, 162.656}, {178.863, 
               165.51999999999998`}, {179.914, 161.63299999999998`}, {182.777,
                160.977}, {181.93800000000002`, 157.719}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{182.48800000000003`,
                158.305}, {185.441, 158.477}, {185.285, 161.836}, {185.445, 
               165.238}, {183.945, 162.11299999999997`}, {182.172, 161.629}, {
               182.48800000000003`, 158.305}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{182.48800000000003`,
                158.305}, {185.441, 158.477}, {185.285, 161.836}, {185.445, 
               165.238}, {183.945, 162.11299999999997`}, {182.172, 161.629}, {
               182.48800000000003`, 158.305}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{182.36700000000002`,
                154.129}, {180.07, 153.945}, {178.875, 156.20299999999997`}, {
               178.348, 159.72299999999998`}, {180.52700000000002`, 
               156.48000000000002`}, {182.512, 157.48800000000003`}, {
               182.36700000000002`, 154.129}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{182.36700000000002`,
                154.129}, {180.07, 153.945}, {178.875, 156.203}, {178.348, 
               159.723}, {180.52700000000002`, 156.48}, {182.512, 157.488}, {
               182.36700000000002`, 154.129}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{183.191, 154.406}, {
               186.148, 154.02700000000002`}, {185.676, 157.469}, {185.555, 
               160.004}, {184.65200000000002`, 157.586}, {182.24599999999998`,
                156.824}, {183.191, 154.406}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{183.191, 154.406}, {
               186.148, 154.02700000000002`}, {185.676, 157.469}, {185.555, 
               160.004}, {184.65200000000002`, 157.586}, {182.24599999999998`,
                156.824}, {183.191, 154.406}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{178.586, 155.863}, {
               178.82000000000002`, 153.617}, {180.238, 149.758}, {182.523, 
               150.625}, {183.469, 153.383}, {180.516, 153.934}, {178.586, 
               155.863}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{178.586, 155.863}, {
               178.82000000000002`, 153.617}, {180.238, 149.758}, {182.523, 
               150.625}, {183.469, 153.383}, {180.516, 153.934}, {178.586, 
               155.863}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{183.23, 150.383}, {
               182.207, 152.35500000000002`}, {185.555, 153.34}, {186.266, 
               155.89800000000002`}, {186.672, 152.23399999999998`}, {
               186.33200000000002`, 149.83200000000002`}, {183.23, 
               150.383}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{183.23, 150.383}, {
               182.207, 152.35500000000002`}, {185.555, 153.34}, {186.266, 
               155.898}, {186.672, 152.234}, {186.33200000000002`, 149.832}, {
               183.23, 150.383}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{173.70299999999997`,
                173.727}, {175.54299999999998`, 175.71099999999998`}, {
               173.918, 178.85200000000003`}, {173.36700000000002`, 
               181.914}, {172.621, 179.012}, {171.324, 175.164}, {
               173.70299999999997`, 173.727}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{173.70299999999997`,
                173.72700000000003`}, {175.54299999999998`, 175.711}, {
               173.918, 178.852}, {173.36700000000002`, 181.914}, {172.621, 
               179.01199999999997`}, {171.324, 175.164}, {173.70299999999997`,
                173.72700000000003`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{173.648, 170.039}, {
               170.418, 169.71099999999998`}, {169.637, 176.285}, {169.305, 
               179.10899999999998`}, {170.35500000000002`, 
               175.22299999999998`}, {174.078, 173.445}, {173.648, 
               170.039}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{173.648, 170.039}, {
               170.418, 169.711}, {169.637, 176.28500000000003`}, {169.305, 
               179.10899999999998`}, {170.35500000000002`, 175.223}, {174.078,
                173.445}, {173.648, 170.039}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{174.312, 170.105}, {
               176.594, 171.285}, {176.066, 173.824}, {176.781, 175.73}, {
               175.24599999999998`, 173.39100000000002`}, {173.848, 
               173.055}, {174.312, 170.105}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{174.312, 170.105}, {
               176.594, 171.28500000000003`}, {176.066, 173.824}, {176.781, 
               175.73000000000002`}, {175.24599999999998`, 
               173.39100000000002`}, {173.848, 173.055}, {174.312, 170.105}}},
               
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{173.672, 
               165.80100000000002`}, {170.29299999999998`, 165.512}, {168.277,
                172.789}, {168.172, 175.656}, {169.22299999999998`, 
               171.766}, {174.066, 169.656}, {173.672, 
               165.80100000000002`}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{173.672, 
               165.80100000000002`}, {170.29299999999998`, 
               165.51199999999997`}, {168.277, 172.78900000000002`}, {168.172,
                175.656}, {169.22299999999998`, 171.76600000000002`}, {
               174.066, 169.656}, {173.672, 165.80100000000002`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{174.32000000000002`,
                165.91}, {177.5, 166.64499999999998`}, {177.117, 
               168.69899999999998`}, {176.641, 172.02700000000002`}, {175.629,
                168.676}, {173.85500000000002`, 169.38700000000003`}, {
               174.32000000000002`, 165.91}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{174.32000000000002`,
                165.91}, {177.5, 166.64499999999998`}, {177.117, 
               168.69899999999998`}, {176.641, 172.02700000000002`}, {175.629,
                168.676}, {173.85500000000002`, 169.38700000000003`}, {
               174.32000000000002`, 165.91}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{173.63299999999998`,
                161.602}, {169.914, 160.969}, {170.176, 166.848}, {167.227, 
               171.11299999999997`}, {169.777, 167.945}, {174.375, 163.953}, {
               173.63299999999998`, 161.602}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{173.63299999999998`,
                161.60199999999998`}, {169.914, 160.969}, {170.176, 
               166.84799999999998`}, {167.227, 171.11299999999997`}, {169.777,
                167.945}, {174.375, 163.953}, {173.63299999999998`, 
               161.60199999999998`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{174.47299999999998`,
                161.80100000000002`}, {177.277, 161.71899999999997`}, {
               177.55100000000002`, 165.941}, {177.395, 167.656}, {176.75, 
               165.94899999999998`}, {173.453, 164.32800000000003`}, {
               174.47299999999998`, 161.80100000000002`}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{174.47299999999998`,
                161.80100000000002`}, {177.277, 161.719}, {
               177.55100000000002`, 165.941}, {177.395, 167.656}, {176.75, 
               165.94899999999998`}, {173.453, 164.328}, {174.47299999999998`,
                161.80100000000002`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{167.824, 166.129}, {
               169.21899999999997`, 161.605}, {171.195, 157.07}, {
               173.63299999999998`, 157.414}, {174.80100000000002`, 
               159.98800000000003`}, {171.32000000000002`, 160.316}, {167.824,
                166.129}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{167.824, 166.129}, {
               169.21899999999997`, 161.605}, {171.195, 157.07}, {
               173.63299999999998`, 157.414}, {174.80100000000002`, 
               159.988}, {171.32000000000002`, 160.316}, {167.824, 166.129}}},
               
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{174.512, 158.078}, {
               173.48800000000003`, 160.05100000000002`}, {176.836, 
               161.035}, {177.547, 163.598}, {177.953, 159.934}, {
               177.61299999999997`, 157.52700000000002`}, {174.512, 
               158.078}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{174.512, 
               158.07799999999997`}, {173.48800000000003`, 
               160.05100000000002`}, {176.836, 161.035}, {177.547, 
               163.59799999999998`}, {177.953, 159.934}, {177.61299999999997`,
                157.52700000000002`}, {174.512, 158.07799999999997`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{168.785, 160.961}, {
               170.77299999999997`, 156.88700000000003`}, {171.672, 
               152.20299999999997`}, {174.40200000000002`, 152.883}, {
               175.42200000000003`, 156.05100000000002`}, {
               171.38700000000003`, 156.71499999999997`}, {168.785, 
               160.961}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{168.785, 160.961}, {
               170.77299999999997`, 156.88700000000003`}, {171.672, 
               152.203}, {174.40200000000002`, 152.883}, {175.42200000000003`,
                156.05100000000002`}, {171.38700000000003`, 156.715}, {
               168.785, 160.961}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{174.969, 153.656}, {
               173.79299999999998`, 155.812}, {177.14499999999998`, 
               156.57399999999998`}, {177.965, 159.547}, {178.41, 155.656}, {
               177.99200000000002`, 152.883}, {174.969, 153.656}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{174.969, 153.656}, {
               173.79299999999998`, 155.81199999999998`}, {
               177.14499999999998`, 156.57399999999998`}, {177.965, 
               159.547}, {178.41, 155.656}, {177.99200000000002`, 152.883}, {
               174.969, 153.656}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{180.695, 181.238}, {
               182.656, 180.71099999999998`}, {184.71499999999997`, 182.91}, {
               184., 186.207}, {181.758, 185.648}, {180.73, 
               183.61299999999997`}, {180.695, 181.238}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{180.695, 181.238}, {
               182.656, 180.711}, {184.71499999999997`, 182.91}, {184., 
               186.20700000000002`}, {181.758, 185.64799999999997`}, {180.73, 
               183.61299999999997`}, {180.695, 181.238}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC0c0HTi08m+qw+uMl36Q7aQ5xuzx5mC6nOszI
E2o+sC/NwTHh6QWl76kODCCwJ82h0Jbr+uI3qQ57SyZLsDxLc5CNSrG+/xgq
z5Hu8LbG3jTuUaqD/l0VtkbFdLj61teBO+Rs0x22nijbN/9XKkRffDrEnG+p
DtUi69wfzkp3KM6Y+LbmdapDEYjenO5w+2dd1p4HqQ4+5p2OCWfTHQxA5u5N
dQCaWmC7Lx3i7jOpDjfPfQ9+vDLd4Q5I/R2o/CSo+rupDiDj7BOh7ruU6vAO
RHulO4Ty6W6aezjVoXc60MMa6Q5hIP7xVAj9O80BPXwAlGyLqw==
               "]]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC0c0HTi08m+qw+uMl36Q7aQ5xuzx5mC6nOszI
E2o+sC/NwTHh6QWl76kODCCwJ82h0Jbr+uI3qQ57SiZLsDxLc5CNSrG+/xgq
z5Hu8LbG3jTuUaqD/l0VtkbFdLj61teBO+Rs0x22nijbN/9XKkRffLrDXpA5
31IdqkXWuT+cle5QnDHxbc3rVIciEL053eH2z7qsPQ9SHbzNOx0TzqY7GIDM
3ZvqADS1wHZfOsTdZ1Idbp77Hvx4ZbrDHZD6O1D5SVD1d1MdQMbZJ0LddynV
4R2I9kp3COXT3TT3cKpD33SghzXSHcJA/OOpEPp3mgN6+AAAkxSLqg==
               "],
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4thdnjxM4hkO++dL6d91SXWYkSfUfOBfukPG
xLc19oqpEPpsugNYnXmqQxyI/pzuwAACGakON899D34smOEQzqe7aW5/qsPe
kskSLHYZEPkNUP2OGQ6LXLd9/nsj1cFyy4myfc5Q+3jSHLiuLy6wTcpwsAKJ
R6dB9NdlQMTL0hy2AoXnz8qA0JPSHMJA9uzOgLgzKw1i7pwMB5moFOv74VD1
VRkOws0HTi10THNY9fGSb1JKhsM3jZj+Q09THVpfB+6QS81wuKh0+2fdoVQH
WZC+5AwHVbbGqc5A94PdZZDhwA2yPyvVAT18ADOmhG0=
               "]]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4thdnjxM4hkO++ZL6d91SXWYkSfUfOBfukPG
xLc19oqpEPpsukMcSJ15KoT+nO7AAAIZqQ43z30PfiyY4RDGp7tpbn+qw96S
yRIsdhkQ+Q1Q/Y4ZDotdt33+eyPVwXLLibJ9zlD7eNIcuK4vLrBNynCwAolH
p0H012VAxMvSHLYChefPynAASc+flAaxZ3cGxJ1ZaQ6LQObOyXCQjUqxvh8O
VV+V4SDcfODUQsc0h1UfL/kmpWQ4fNWI6T/0NNWh9XXgDrnUDIcLSrd/1h1K
hehLznBQZWuc6gx0/36Quwyg9melOqCHDwAx7oRo
               "],
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4hl5Qs0HTqU7cF1fXGBbl+pwUen2z7pN6Q6X
QHRUqoNsVIr1/e50B1W2xqnO+akO3zRi+g8tTHfonQ7UuCLV4Zi3eafjlnSH
x0tnH1G4kAoxZ1u6Q8bEtzX2jGkO1SLr3B/CzJdLcwjj090093m6AzeI75Xm
sOrjJd8kiQyIurw0iDkmGQ4gYxM60xyArsjaE5ABsXdpGsTejAyHdzX2pnFd
aRBz/TIc1A051sgUpTm8BYnrZUDEg9IcrLacKNvHneGwFUjN10pzKLAFyvxI
d+gDmcMDNf9KOkT/pVSI+U/SHUJB7lyc6oAePgBisIf1
               "]]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4hl5Qs0HTqU7cF1fXGBbl+pwUen2z7pN6RA6
KtVBNirF+n53uoMqW+NU5/xUh28aMf2HFqY79E0HalyR6nDM27zTcUu6w+Ol
s48oXEiFmLMt3SFj4tsae8Y0h2qRde4PYebLpTmE8elumvscyvdKc1j18ZJv
kkQGRF1eGsQckwwHH6CxCZ1pDkBXZO0JyHD4CrJ3aZpDL8jejAyHdzX2pnFd
aRBz/DIc1A051sgUpTm8BYnrZUDEg9IcrLacKNvHneEAouZrpTkU2AJlfkDd
zwM1/0o6RP+lVIj5T9IdQkHuXJzqgB4+AGGgh/M=
               "],
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYCYsstJ8r2mac5TM8Taj5gluawf76U/l2TNIdV
Hy/5JrGkORjcVWFrjE1zOO5t3un4I9UhjE9309zoNIeMiW9r7B3THG6e+x78
OBKqrjfNQTYqxfq+cpqDKlvjVOfLaQ6LXLd9/usC5bunOwB1mcaFpTkwgEBD
ugPI+vlA/uOls48ovEiH0D5pDhMOfdWIkc9wqBZZ5/7QKc2B6/riAtuwDIj5
0mkQc4wyHLaC9GulQdzFnuEQt8uTh8k6zUHdkGONzLV0iLh6moNjwtMLSuXp
Dk4gGqi/H2Q+0D1AX59a+DUV4r89aQ4u3TnPf1umOfSCAqQizQE9fAAfS4EP

               "]]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYCYsstJ8r2mac5zMgTaj5gluawf76U/l2TNIdV
Hy/5JrGkORjcVWFrjE1zOO5t3un4I9UhjE9309zoNIeMiW9r7B3THG6e+x78
ODLNQR+krjfNQTYqxfq+cpoDkDfV+XKawyLXbZ//uqQ5qIH47ukOQF2mcWFp
Dgwg0JDuALJ+PpD/ZOnsIwov0h0eg2ifNIcJh75qxMhnOFSLrHN/6JTmwHV9
cYFtWAbEfOk0h3cgc4wyHLaC9GulQdzFnuEQt8uTh8k6zUHdkGONzLV0iLh6
moNTwtMLSuXpEFoaaj7QPUBfn1r4NRXivz1pDi7dOc9/W6Y59E0HBkhFmgN6
+AAAITuBFQ==
               "],
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4rc19qZxy9IcMiYCWb7pDr3T84SaF6Q5xO3y
5GGST4eIV6Y5zAAKH5BKdyiw5bq+uCXN4bi3eadjTLqDuiHHGpm+NAcQN2Fi
uoPVlhNl+/qh5u1EqAeb+yTdwQekrjTN4ZLS7Z91UhkQuirNASR9oCzD4ea5
78GPW9McWl8H7pCbm+Ggf1eFrXFimsM3jZj+Q0czHGSiUqzvb09z2FsyWYJl
XYaDJci+5WkOQFsKbPsyIOLToO7JzHBY5Lrt898paQ53ftZl7ZHJgLhrYRpE
/AfUfxvTHB4vnX1E4Ui6w/75Uvp310DNr0t3gIUP2N3A8AEAehyKbA==
               
               "]]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4rc19qZxy9IcMiYCWb7pDr3T84SaF6Q5xO3y
5GGST4eIV6Y5zAAKH5BKdyiw5bq+uCXN4bi3eadjTLqDuiHHGpm+NAcQN2Fi
uoPVlhNl+/rTHDJB+nYi1IPNfZLu4ANSV5rmcEnp9s86qQwIXQU1vyzD4ea5
78GPW9McWl8H7pCbm+Ggf1eFrXFimsM3jZj+Q0czHGSiUqzvb09z2FMyWYJl
XYaDJci+5WkOQFsKbPsyHPaCxKelQezJzHBY5Lrt898paQ53ftZl7ZHJgPhn
YZrDYpD4D6j/NqY5PF46+4jCkXSH/fOl9O+ugZpfl+4ACx+w/4DhAwB7lIpt

               "],
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4sdLZx9RkEh1EG4+cGrhzGSH4oyJb2u0Ux0u
Kt3+WdeU7ACW90l1cOnOef57YrLD2xp70zi9VAeQMvuNyQ57SyZLsIilOlwC
qT8F5ctB9V9KdnBMeHpBiR+q/mOyQ+/0PKFmhlSHUD7dTXOFUyDijKkOW06U
7ZuvlgKx/30KRJ99ioMVSOJ+isMFkHlhKRD3nEhx2ApSb5fiwAACN1IcnEDq
tVMcZKNSrO+/htJA88HufZbiMANo7QGmFIi7PqU4rP54yTfpTbLDvvlS+nc5
Uh1unvse/PhoskMRyH7mVIdvGjH9hzZC/Y8UPgCcGY/J
               "]]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4sdLZx9RkEh1EG4+cGrhzGSH4oyJb2u0Ux0u
KN3+WdeU7ACW90l1cO7Oef57YrLD2xp70zi9VAeQMvuNyQ57SyZLsIilOlwE
qT8F5ctB9V9KdnBMeHpBiR+q/mOyQ+/0PKFmhlSHUD7dTXOFUyDijKkOW0+U
7ZuvlgKx/30KRJ99ioPVFqDE/RSI+WEpEPecSIGot0txYACBG1D12ikOslEp
1vdfQ2mg+WD3PktxmAG09gAT1JxPKQ6rP17yTXqT7LBvvpT+XY5Uh5vnvgc/
PprsUASynznV4ZtGTP+hjVD/I4UPAJkBj8Y=
               "],
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{185.07, 137.11299999999997`}, {187.023, 
               136.15200000000002`}, {188.504, 133.754}, {188.602, 131.805}, {
               188.76999999999998`, 129.555}, {189.09, 127.66}, {190.102, 
               126.062}, {188.496, 126.508}, {187.727, 129.07}, {187.496, 
               131.523}, {187.266, 134.059}, {185.89800000000002`, 135.16}, {
               185.07, 137.11299999999997`}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{185.07, 137.11299999999997`}, {187.023, 136.152}, {
               188.504, 133.75400000000002`}, {188.602, 131.805}, {
               188.76999999999998`, 129.555}, {189.09, 127.66}, {190.102, 
               126.06199999999998`}, {188.496, 126.50799999999998`}, {187.727,
                129.07}, {187.496, 131.523}, {187.266, 134.059}, {
               185.89800000000002`, 135.16}, {185.07, 137.11299999999997`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{189.137, 132.406}, {190.48800000000003`, 129.914}, {
               192.375, 128.965}, {192.47299999999998`, 127.113}, {192.637, 
               124.98400000000001`}, {192.797, 124.87899999999999`}, {193.375,
                122.785}, {191.785, 123.20700000000001`}, {191.383, 
               123.348}, {190.953, 126.531}, {190.691, 128.76999999999998`}, {
               188.89800000000002`, 130.348}, {189.137, 132.406}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{189.137, 132.406}, {190.48800000000003`, 129.914}, {
               192.375, 128.965}, {192.47299999999998`, 
               127.11299999999997`}, {192.637, 124.98400000000001`}, {192.797,
                124.87899999999999`}, {193.375, 122.78500000000003`}, {
               191.785, 123.20700000000002`}, {191.383, 
               123.34799999999998`}, {190.953, 126.531}, {190.691, 128.77}, {
               188.89800000000002`, 130.34799999999998`}, {189.137, 132.406}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{231.176, 
               109.34400000000001`}, {231.934, 107.91400000000002`}, {232.805,
                105.73400000000001`}, {234.38700000000003`, 106.133}, {234.41,
                107.23}, {232.68, 107.988}, {231.176, 109.34400000000001`}}}],
               FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
               233.52700000000002`, 108.85499999999999`}, {236.598, 
               107.598}, {239.24599999999998`, 107.91000000000001`}, {
               239.57399999999998`, 105.98}, {236.69899999999998`, 
               105.66799999999999`}, {235.64499999999998`, 
               106.85199999999999`}, {233.52700000000002`, 
               108.85499999999999`}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{220.68, 119.008}, {222.74599999999998`, 117.316}, {
               224.086, 115.383}, {224.71099999999998`, 112.887}, {225.363, 
               110.559}, {226.281, 108.703}, {227.625, 106.613}, {225.434, 
               108.10499999999999`}, {224.059, 110.141}, {223.36700000000002`,
                112.586}, {222.762, 114.992}, {222.05100000000002`, 
               116.793}, {220.68, 119.008}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{223.22299999999998`, 119.016}, {225.43800000000002`, 
               117.24600000000001`}, {227.52700000000002`, 115.242}, {
               228.15200000000002`, 112.742}, {228.805, 110.418}, {
               229.19899999999998`, 108.637}, {230.691, 106.324}, {
               228.35200000000003`, 107.816}, {227.42200000000003`, 
               110.074}, {226.73399999999998`, 112.52}, {226.129, 114.926}, {
               224.742, 116.727}, {223.22299999999998`, 119.016}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4tbXgTvkLuY4NB84tdDVL8ZBla1xqvP5HAeu
64sLbLNiHG79rMvacyPHYUaeUPOBphiHY97mnY5Pchycu3Oe/+6Mcdh6omzf
/F9Q+VkxDotct33+K5Dr0DsdKLAixsEx4ekFJfVch4Ug8S0xDqs+XvJNcsh1
kNa/q8J2MMbhotLtn3V+uRB9c6DmAfkZE9/W2LfGQMwF8r9pxPQfio1xCOfT
3TTXP9dBdJ37wyobhHovHibtdrkYiD7fXAegaVcqfkY7CIM85pnrIAfy6Ldo
h5vnvgc/toXa/zHaIW6XJ1BnrgPIuQdeRUPsE8p18EsSiLB8Eu1gtQVowf8c
h1iQutPRDrdB4fEhB+K/HdGQcHqU4wD05e2fx6D6b+U4FIMc8hxq39Uch+Og
cGOAhu/lHIj9hjEO6OEPAG3WvnI=
               "]], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4oyJb2vsH+Y6NB84tdDVL8YhbpcnD9PjXAeu
64sLbLNiHML4dDfNvZ3rsNB12+e/LTEO3uadjgkXcx1E1rk/rOqJcfAB8ffm
OmSCzJkb46B/V4WtcWWuw8MqoIqFMQ690/OEmqfkOhSDLJof49D6OnCHXG2u
w3GQQQtiHFTZGqc6l+c6fNOI6T80NcbBMeHpBSUgf2/JZAmWuhiHWJB7gHw5
kMawGIi7ynIh5hog1M8Acg8IxTis+njJN6ki18EA5I630Q4MIADkg5QfeBXt
cFHp9s+6plwHsL+fRjv0H/qqETM510EeZP69aIi7NuQ6LAL59040xL0Hcx02
zX2//NjhaIetJ8r2zT8H9d/GaIg77+VC7DkAlb8Hdc+jaAegLaZx96Dm/YmG
hMP9XAdpUEAZxjighz8ADGG3Xg==
               "]], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4p1yra8DlQod9s2X0r8bkerweOnsIwpGhQ5h
fLqb5nanOixy3fb5r0uhw0Wl2z/rhFIdGECgrdDhuLd5p+OOFIdjIHpJoYNj
wtMLSv0pDlEp1vf9dxY66N9VYWtUTIHQQH7GxLc19jeTIebsKnSw3HKibN/y
ZIfpeULNB7YVOnBdX1xgW5YMVw/muyVD9O0uhNirkewwWYIljO90oUOBLVDF
kySI/QcKHfoPfdWIuZzk4P6wSmTdYqh/ViQ5gKyZX1fosOrjJd8kjyQHA5D5
uYUOsbs8eZjUofJxhRB/8iQ5WIEEAgsdfIDGJqyFyrsVOgBDaYfc1ySHZcDg
2WBV6KBuyLFGxikZ4i6HQoe9JUCXzUt2yHn+e+VHOaj6p8kOIGcWsEP5otDw
OlMAoV1SHKpF1rk/vFTgINx84NTCyBQHAD+Yrl4=
               "]]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4p1yra8DlQod9s+X0r8bkerweOnsIwpGhQ5h
fLqb5nanOixy3fb5r0uhwwWl2z/rhFIdGECgrdDhuLd5p+OOFIdjIHpJoYNj
wtMLSv0pDlEp1vf9dxY66N9VYWtUTIHQQH7mxLc19jeTHS6CzNlV6GC55UTZ
vuXJDtPzhJoPbCt04Lq+uMC2LBmuHsx3S3bIAOnbXQixVyPZYbIESxjf6UKH
AlugiidJEPsPFDr0H/qqEXM5ycH9YZXIusVQ/6xIcgBZM7+u0GHVx0u+SR5J
DgYg83MLHeJ2efIwqUPl4woh/uRJcrACCQQWOoCMTVgLlXcrdACG0g65r0kO
y4DBs8Gq0EHdkGONjFMyxF0OhQ57SoAum5fskPP898qPclD1T5MdQM4sYIfy
RaHhdaYAQrukOFSLrHN/eKnAQbj5wKmFkSkOAEFwrl8=
               "],
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[0.74902, 0., 0.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGI9IGYCYuHmA6cWqhY6yEalWN8/n+xw+KtGTL9WocMF
pds/654lQ8QNCx32lkyWYPmX7NDpmPD0glWhA9f1xQW2QikOlltOlO1zhqpX
S3F4W2NvGudX6BDGp7tprnmKw6dLvkkCUVDz7VMcQJR/aqHDcW/zTkePFIh5
BYUOTkBKKRjKryh0AFFK6VB+TaHDItdtn/8WpDjskGt9HdhQ6AB2d22KAwMI
NBU6FNoCXdST4iAEEm8udNgKdNb8WQg+2D2rUxwe+PdOz2uCmr8/xUGrXezm
uWao+XtSHA6B/N9S6DAjD6hzF9T8tkKHApD5O1IcjoHcvaTQoThj4tua/hQH
kHDBTqh7FFMgNJCvf1eFrfFmMkT/Lij/aDIkPIB8dUOONTKbkuHqweE5L9kB
ZHzC9kKHm+e+Bz+emOwAssZ+a6HDN6CzDrVCzdsEVV8HjZ+1hQ5AXwk1lyQ7
VIusc3+4AhpfeckQ/y+G2p+Z7AAUDeObCVWfkOyQ+/z3yo890PCKg7qnEWp+
WLIDKNjel0LN84PyM6HxZQ01Px4aPirJDtqg8AwtdFBla5zqzJ8MCS9gegAl
k/nfkiD+8YTG14MkSHrxKHSoArn7GVTevdDh8dLZRxQ+JDncB8WXG9T9X5Mg
9lkj7DcAidtC01MP1P1I6RkA3wVEIA==
               "]]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGI9IGYCYuHmA6cWqhY6yEalWN8/n+xw+KtGTL9WocNF
pds/654lQ8QNCx32lEyWYPmX7NDpmPD0glWhA9f1xQW2QikOlltOlO1zhqpX
S3F4W2NvGudX6BDGp7tprnmKw6dLvkkCUVDz7VMcQJR/aqHDcW/zTkePFIh5
BYUOIEopGMqvKHRwAvHTofyaQodFrts+/y1Icdgh1/o6sKHQAezu2hQHBhBo
KnQotAW6qCfFQQgk3lzoAHLW/FkIPtg9q1McHvj3Ts9rgtq3P8VBq13s5rlm
qPl7UhwOgfzfUugwIw+ocxfU/Dao+TtSHI6B3L2k0KE4Y+Lbmv4UB5BwwU6o
exRTIDSQb3BXha3xZjJE/65CBz0Q/2gyJDyAfHVDjjUym5Lh6sHhOS/ZAWR8
wvZCh5vnvgc/npjsALLGfmuhA8hZh1qh5m2Cqq+Dxs/aQgegr4SaS5IdqkXW
uT9cAY2vvGSI/xdD3ZOZ7AAUDeObCVWfkOyQ+/z3yo89hQ5bQeEVB3VPI9T8
sGQHULC9L4Wa5wflZ0LDzxpqfnyhQwEoIFSSHbRB4Rla6KDK1jjVmT8ZEl5+
UPO/JUH84wlV/yAJkl48CiHufgaVdy90eLx09hGFD0kO90Hx5QYNv69JEPus
EfaD/WULTU89UPcjpWcA3r1EHQ==
               "],
               CurveClosed->{1}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{280.14500000000004`,
                166.09}, {280.53099999999995`, 163.402}, {279.03499999999997`,
                162.51199999999997`}, {277.625, 161.988}, {
               276.16400000000004`, 161.47299999999998`}, {274.969, 
               159.906}, {274.35200000000003`, 158.488}}},
               CurveClosed->{0}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{283.762, 157.246}, {
               283.14500000000004`, 154.934}, {281.52299999999997`, 
               155.223}, {280.10900000000004`, 154.703}, {278.65200000000004`,
                154.184}, {277.113, 152.336}, {276.5, 150.922}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{275.512, 
               172.414}, {274.77299999999997`, 172.89100000000002`}, {260.57, 
               148.97299999999998`}, {261.309, 148.496}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{275.512, 
               172.414}, {274.77299999999997`, 172.89100000000002`}, {260.57, 
               148.97299999999998`}, {261.309, 148.496}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{273.984, 173.36700000000002`}, {273.984, 172.512}, {
               274.76599999999996`, 171.73}, {275.621, 171.73}, {276.477, 
               171.73}, {277.258, 172.512}, {277.258, 173.36700000000002`}, {
               277.258, 174.227}, {276.477, 175.004}, {275.621, 175.004}, {
               274.76599999999996`, 175.004}, {273.984, 174.227}, {273.984, 
               173.36700000000002`}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{273.984, 173.36700000000002`}, {273.984, 
               172.51199999999997`}, {274.76599999999996`, 
               171.73000000000002`}, {275.621, 171.73000000000002`}, {276.477,
                171.73000000000002`}, {277.258, 172.51199999999997`}, {
               277.258, 173.36700000000002`}, {277.258, 
               174.22700000000003`}, {276.477, 175.004}, {275.621, 175.004}, {
               274.76599999999996`, 175.004}, {273.984, 
               174.22700000000003`}, {273.984, 173.36700000000002`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               256.08599999999996`, 192.586}, {261.84, 192.586}, {261.84, 
               191.26600000000002`}, {256.08599999999996`, 
               191.26600000000002`}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               256.08599999999996`, 192.58599999999998`}, {261.84, 
               192.58599999999998`}, {261.84, 191.266}, {256.08599999999996`, 
               191.266}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               256.08599999999996`, 190.078}, {261.84, 190.078}, {261.84, 
               179.055}, {256.08599999999996`, 179.055}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               256.08599999999996`, 190.07799999999997`}, {261.84, 
               190.07799999999997`}, {261.84, 179.05499999999998`}, {
               256.08599999999996`, 179.05499999999998`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}}}, {{{262.191, 
               194.09}, {255.809, 194.05100000000002`}, {255.559, 
               196.21499999999997`}, {257.719, 198.555}, {258.97999999999996`,
                198.531}, {260.227, 198.469}, {262.242, 196.164}, {262.191, 
               194.09}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}}}, {{{262.191, 
               194.08999999999997`}, {255.809, 194.051}, {255.559, 196.215}, {
               257.719, 198.555}, {258.97999999999996`, 198.531}, {260.227, 
               198.469}, {262.242, 196.164}, {262.191, 194.08999999999997`}}},
               
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[0.741176, 0.41960800000000004`, 0.], Opacity[
              1.]}], FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                 3, 3}, {1, 3, 3}, {1, 3, 3}}}, {CompressedData["
1:eJxTTMoPSmViYGBQBmIQvX++lP7dPXkOfdPzhJpzMhxko1Ks7z/Oc3i8dPYR
hZgMh28aMf2HGPMdwvl0N83Vz4CIi+RD1P9Jd7igdPtnnVq+g7d5p2PCyXQH
g7sqbI26+Q6qbI1TnfvTHcDmq+Q79ILUJyD4VltOlO2LT3cQbj5waqEi1Hz/
dIeMiW9r7GXzHRhAwCUdYp8EVL11ukPcLk8eJuF8hyKQQuN0Bx+Qvbz5DluB
0vP1oO5hy4eI66ZD9P2H+kcnHeLOn3kQcf10iP++5kHUm6Y7qBtyrJH5lAex
B2jfcZCGD3kOQFeZxjlB3f8BKu+d7lBgy3V98RcovzrdYdXHS75JQP4lkDtW
pTvsA6l/ATX/KjR87uZBzGXIcAA5Y/4xqPlqGRDz50DVu2ZA6Kl5DtUi69wf
emU4LHLd9vnvhDxIOAVC4wPItwQZFJ4BDfc8B6CrCmzjMiDhMikPEq/JGQ5A
z2rETIeqT89wKAS5f0GeQzHIwPwMhwkg+fV5kHAogroHKX0AAM/u82U=
                
                "], CompressedData["
1:eJxTTMoPSmViYGBQAmIQvW++lP7dHXkO3uadjgmJGQ7FGRPf1qzPcwBR9qkZ
Dv2HvmrELM5ziNvlycOUnOFwUen2z7p5UH58hsPjpbOPKMzJc9gPMicmw0E2
KsX6/uw8iDnRCHmw+ZEZDn3T84SagXzHhKcXlMIzHNQNOdbIAM0D2xMMVb8E
ar5/hgMDCFzIcwC6xjRODyr/Is9B/64KWyMrlP8lz6EXZO6NdAifId8hjE93
09zV6RD3/M9zqBZZ5/6wCir/Jw9ir1c6RN3vPIcikHud0x0MQOb+zYP40y7d
YQLIXUD9VltOlO2zTndofR24Q44x32GR67bPfy3SIeYw5UPMtYCaz5IPcQ+Q
z3V9cYEtW74DOJyB/Esgc7nyIeEDNA9sD18+xByndIetQGvmC+U73PpZl7XH
I90BZO18sXxIeASnO3zTiOk/JAlVnwTlK+Y77C2ZLMHSB9Uvle+gytY41fl4
OsReDqh7fqRDwv17nsPNc9+DH2tmOMwACh+4lefgBBIHhj96egAAMkbv9g==

                "]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
               1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, CompressedData["
1:eJxlk1tIVFEUhoeRJEosNCpiNBNN7aYF3YzBZQURpV3EQpvEpFqbsFUR+JAl
iBR0sZJIh2KcLCLSqIgC6TKJBJmIiURZJhERPUQPPVSID7X3Wb8UNHA4HPba
//rW/6+ZU3Vg6544n8/nt89svFdXfh5IrxXKWjzxViDf0NrT1V/G2oR+ZofO
decY8s4fCZ3v/pEd+s30brRu3+Meodppt9d97Gea9ObaweBroW9HC5ZWtDK1
fx8sqhoSOuLO9zKllO9e9eGlUGOLJDWsYDJNtvKF0LbEhfciM5h87tcpqhPP
VOj63RBaeb+nJhbHFLbXulqh72caSB8erWsG3wSm3JGM+PomobNOP4H1fUYo
M77+4ppkVs5TQh2OK8CU5+oboZ+Ffi2Yvxj9Lgm97f9V8ukY+C+Ict9kOv51
S2eqvT/sfHiFc+vfYVcwxurXDviTZKjUzVki6stMo1ybRPukGp2rGPqZhjYu
P1lYWSSqO9/Q0+is3JHN8GeJ0XlLwbvMaJ8K8AaNzrdfKN/NV4D8/snX61cD
vkXQr8a31U9u6Opt24W88gy9d3OG4O8CQ5MdR7nQoMthnlHuMlFfcsBXhvzn
GuUqg18Zhp5vsANaPa9vGniqoB8wmu8J+OM3FHN1YdF7Q/A7Ct52pp0P1yf4
7b54c9u8Htixo1fBU4R9DY/7y+RsiTZDL/D33PNnOvK7PJ4f9iUitN3lOIXp
UNAmcQX1idi/66i3397/5A7ynop9ioEnhdWHZ6jPZ/WhD/vKrL72Is8I+j+B
P32sudwV5bT75s1h+T2utP/z/QOeprBY
               "]]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{255.73, 
               170.09}, {262.152, 170.09}, {262.152, 161.203}, {255.73, 
               161.203}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{255.73, 
               170.09}, {262.152, 170.09}, {262.152, 161.203}, {255.73, 
               161.203}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{255.578, 
               156.121}, {261.777, 156.121}, {261.777, 154.25400000000002`}, {
               255.57799999999997`, 154.25400000000002`}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{255.578, 
               156.121}, {261.777, 156.121}, {261.777, 154.25400000000002`}, {
               255.57799999999997`, 154.25400000000002`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               255.58200000000002`, 152.84}, {261.93, 152.84}, {261.93, 
               145.895}, {255.582, 145.895}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               255.58200000000002`, 152.84}, {261.93, 152.84}, {261.93, 
               145.895}, {255.582, 145.895}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{255.434, 
               144.47299999999998`}, {262.375, 144.47299999999998`}, {262.375,
                140.58999999999997`}, {255.434, 140.58999999999997`}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{255.434, 
               144.47299999999998`}, {262.375, 144.47299999999998`}, {262.375,
                140.58999999999997`}, {255.434, 140.58999999999997`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{261.52, 
               157.79299999999998`}, {255.92600000000002`, 
               157.79299999999998`}, {254.816, 159.641}, {262.52299999999997`,
                159.641}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{261.52, 
               157.793}, {255.92600000000002`, 157.793}, {254.816, 159.641}, {
               262.52299999999997`, 159.641}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {1, 3, 3}}}, {{{253.977, 
               164.602}, {253.92200000000003`, 169.45700000000002`}, {250.07, 
               169.45700000000002`}, {251.58200000000002`, 168.207}, {
               252.99200000000002`, 166.695}, {253.977, 164.602}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {1, 3, 3}}}, {{{253.977, 
               164.60199999999998`}, {253.92200000000003`, 
               169.45700000000002`}, {250.07, 169.45700000000002`}, {
               251.58200000000002`, 168.20700000000002`}, {
               252.99200000000002`, 166.695}, {253.977, 164.60199999999998`}}},
               CurveClosed->{1}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4gf+vdPzggocijImvq0JTnHQbhe7eS6wwIHr
+uICW6MUh9hdnjxM9gUOi1y3ff7rgOB/04jpPxSIJt+S4rB09hGFDXYFDn3T
84Sa96Q4uD+sElkHlL/9sy5rz4MUBy2Q+UB+GJ/uprm/oXz5Aod986X0735J
cWAAAYUCh1UfL/kmPUlxkIlKsb4PlG97HbhDbmeKg1DzgVML5aH216Y46N9V
YWsE8uNA7vBOcbDccqJsH5D/tsbeNA7o/k7HhKcXuAocekHuMUlxaAWZw41Q
D/K2PZAfCnJPM4J/89z34MdXEeqLQRL/Uxxyn/9e+RFoHljcNBViPzC8wO42
SXX4BHS2QBDUvwwI/lags+ZfS3GAhbcqW+NU524EHxb+ACCvraM=
               "],
               CurveClosed->{1}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{256.59, 
               152.016}, {261.145, 152.016}, {261.145, 146.34}, {256.59, 
               146.34}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{256.625, 
               149.664}, {258.23, 149.664}, {258.23, 148.73}, {256.625, 
               148.73}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{256.625, 
               149.664}, {258.23, 149.664}, {258.23, 148.73}, {256.625, 
               148.73}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{259.465, 
               149.664}, {261.03099999999995`, 149.664}, {261.03099999999995`,
                148.73}, {259.465, 148.73}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{259.465, 
               149.664}, {261.03099999999995`, 149.664}, {261.03099999999995`,
                148.73}, {259.465, 148.73}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               258.22999999999996`, 151.945}, {259.46399999999994`, 
               151.945}, {259.46399999999994`, 149.629}, {258.22999999999996`,
                149.629}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               258.22999999999996`, 151.945}, {259.46399999999994`, 
               151.945}, {259.46399999999994`, 149.629}, {258.22999999999996`,
                149.629}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               258.22999999999996`, 148.76999999999998`}, {
               259.46399999999994`, 148.76999999999998`}, {
               259.46399999999994`, 146.30499999999998`}, {
               258.22999999999996`, 146.30499999999998`}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               258.22999999999996`, 148.77}, {259.46399999999994`, 148.77}, {
               259.46399999999994`, 146.305}, {258.22999999999996`, 146.305}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{284.809, 208.824}, {
               284.52299999999997`, 204.371}, {285.90599999999995`, 
               201.92600000000002`}, {288.26599999999996`, 202.297}, {288.914,
                204.76999999999998`}, {287.43399999999997`, 
               206.42600000000002`}, {284.809, 208.824}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{284.809, 208.824}, {
               284.52299999999997`, 204.371}, {285.90599999999995`, 
               201.926}, {288.26599999999996`, 202.297}, {288.914, 
               204.76999999999998`}, {287.43399999999997`, 206.426}, {284.809,
                208.824}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{289.984, 198.953}, {
               292.082, 200.02}, {290.566, 208.164}, {289.762, 
               211.57399999999998`}, {289.168, 207.18}, {288.172, 200.93}, {
               289.984, 198.953}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{289.984, 
               198.95299999999997`}, {292.082, 200.01999999999998`}, {290.566,
                208.164}, {289.762, 211.574}, {289.168, 207.18}, {288.172, 
               200.93}, {289.984, 198.95299999999997`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{289.23799999999994`,
                198.566}, {285.715, 197.344}, {282.92599999999993`, 
               201.137}, {281.97999999999996`, 205.535}, {284.89099999999996`,
                201.52}, {289.625, 201.516}, {289.23799999999994`, 
               198.566}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{289.23799999999994`,
                198.56599999999997`}, {285.715, 197.344}, {
               282.92599999999993`, 201.137}, {281.97999999999996`, 
               205.535}, {284.89099999999996`, 201.51999999999998`}, {289.625,
                201.516}, {289.23799999999994`, 198.56599999999997`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{291.90999999999997`,
                194.45700000000002`}, {294.668, 195.184}, {293.008, 
               203.824}, {292.508, 207.281}, {291.902, 203.71099999999998`}, {
               290., 195.637}, {291.90999999999997`, 194.45700000000002`}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{291.90999999999997`,
                194.457}, {294.668, 195.184}, {293.008, 203.824}, {292.508, 
               207.281}, {291.902, 203.711}, {290., 195.637}, {
               291.90999999999997`, 194.457}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{290.969, 194.727}, {
               290.812, 197.707}, {287.84400000000005`, 196.848}, {
               285.79299999999995`, 198.43800000000002`}, {286.129, 
               196.94899999999998`}, {287.39099999999996`, 194.309}, {290.969,
                194.727}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{290.969, 194.727}, {
               290.812, 197.707}, {287.84400000000005`, 196.848}, {
               285.79299999999995`, 198.438}, {286.129, 196.949}, {
               287.39099999999996`, 194.309}, {290.969, 194.727}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{294.34400000000005`,
                190.73399999999998`}, {297.074, 191.47299999999998`}, {
               295.43399999999997`, 200.76999999999998`}, {295.59, 204.598}, {
               294.789, 201.29299999999998`}, {292.25, 191.63299999999998`}, {
               294.34400000000005`, 190.73399999999998`}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{294.34400000000005`,
                190.734}, {297.074, 191.47299999999998`}, {
               295.43399999999997`, 200.76999999999998`}, {295.59, 204.598}, {
               294.789, 201.293}, {292.25, 191.63299999999998`}, {
               294.34400000000005`, 190.734}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{293.07, 191.137}, {
               290.83599999999996`, 190.41}, {287.871, 191.863}, {287.637, 
               194.52700000000002`}, {289.566, 193.21899999999997`}, {292.641,
                194.21899999999997`}, {293.07, 191.137}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{293.07, 191.137}, {
               290.83599999999996`, 190.41}, {287.871, 191.863}, {287.637, 
               194.527}, {289.566, 193.219}, {292.641, 194.219}, {293.07, 
               191.137}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{296.383, 
               186.63299999999998`}, {298.9959999999999, 
               186.42200000000003`}, {297.828, 194.344}, {297.824, 
               201.71899999999997`}, {296.867, 194.824}, {294.25, 188.512}, {
               296.383, 186.63299999999998`}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{296.383, 
               186.63299999999998`}, {298.9959999999999, 186.422}, {297.828, 
               194.344}, {297.824, 201.719}, {296.867, 194.824}, {294.25, 
               188.51199999999997`}, {296.383, 186.63299999999998`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{295.47999999999996`,
                186.99200000000002`}, {293.715, 186.105}, {290.555, 187.52}, {
               289.65200000000004`, 190.5}, {292.84000000000003`, 189.117}, {
               294.97299999999996`, 190.469}, {295.47999999999996`, 
               186.99200000000002`}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{295.47999999999996`,
                186.992}, {293.715, 186.105}, {290.555, 
               187.51999999999998`}, {289.65200000000004`, 190.5}, {
               292.84000000000003`, 189.117}, {294.97299999999996`, 
               190.469}, {295.47999999999996`, 186.992}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{274.977, 204.695}, {
               275.441, 200.83200000000002`}, {277.02, 198.586}, {279.379, 
               198.95700000000002`}, {280.027, 201.42600000000002`}, {278.117,
                203.008}, {274.977, 204.695}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{274.977, 204.695}, {
               275.441, 200.832}, {277.02, 198.58599999999998`}, {279.379, 
               198.957}, {280.027, 201.426}, {278.117, 203.00799999999998`}, {
               274.977, 204.695}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{281.215, 194.785}, {
               277.29699999999997`, 194.227}, {275.887, 
               197.23399999999998`}, {273.25, 201.08200000000002`}, {276.945, 
               198.406}, {281.363, 197.848}, {281.215, 194.785}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{281.215, 194.785}, {
               277.29699999999997`, 194.227}, {275.887, 
               197.23399999999998`}, {273.25, 201.082}, {276.945, 198.406}, {
               281.363, 197.848}, {281.215, 194.785}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{282.328, 
               195.22299999999998`}, {284.465, 197.789}, {282.39799999999997`,
                201.008}, {280.76599999999996`, 203.75}, {281.117, 199.668}, {
               279.727, 197.39800000000002`}, {282.328, 
               195.22299999999998`}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{282.328, 195.223}, {
               284.465, 197.789}, {282.39799999999997`, 
               201.00799999999998`}, {280.76599999999996`, 203.75}, {281.117, 
               199.668}, {279.727, 197.39800000000002`}, {282.328, 195.223}}},
               
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{283.27299999999997`,
                190.99200000000002`}, {283.512, 193.5}, {279.242, 194.055}, {
               277.309, 195.44899999999998`}, {277.96099999999996`, 194.}, {
               278.945, 190.102}, {283.27299999999997`, 
               190.99200000000002`}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{283.27299999999997`,
                190.992}, {283.512, 193.5}, {279.242, 194.055}, {277.309, 
               195.449}, {277.96099999999996`, 194.}, {278.945, 
               190.10199999999998`}, {283.27299999999997`, 190.992}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{284.168, 
               190.93800000000002`}, {287.121, 191.26999999999998`}, {285.895,
                196.285}, {283.777, 199.07}, {284.668, 195.227}, {282.219, 
               192.55100000000002`}, {284.168, 190.93800000000002`}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{284.168, 190.938}, {
               287.121, 191.27}, {285.895, 196.285}, {283.777, 199.07}, {
               284.668, 195.227}, {282.219, 192.551}, {284.168, 190.938}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{286.39099999999996`,
                186.762}, {289.754, 188.24599999999998`}, {
               287.59799999999996`, 192.461}, {286.33599999999996`, 
               194.94899999999998`}, {286.875, 191.684}, {284.18, 189.191}, {
               286.39099999999996`, 186.762}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{286.39099999999996`,
                186.762}, {289.754, 188.246}, {287.59799999999996`, 
               192.461}, {286.33599999999996`, 194.949}, {286.875, 191.684}, {
               284.18, 189.191}, {286.39099999999996`, 186.762}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{285.727, 
               187.15200000000002`}, {283.965, 184.848}, {280.527, 187.84}, {
               279.82, 191.33200000000002`}, {282.812, 188.84}, {
               285.02299999999997`, 189.25}, {285.727, 
               187.15200000000002`}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{285.727, 187.152}, {
               283.965, 184.84799999999998`}, {280.527, 187.84}, {279.82, 
               191.332}, {282.812, 188.84}, {285.02299999999997`, 189.25}, {
               285.727, 187.152}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIZIGYC4gtKt3/WhRU5cF1fXGAbl+rw6ZJvkkBMkQMD
CJxJdZiRJ9R8wKjIoShj4tuayWkQ+YAih70lkyVY/kH5IUUOhbZAE3jSHaJS
rO/7uxc59B/6qhFjnO4AVBXGZ1/kIAuSkE53uFrxUs3QCGrftzSH3Oe/V35U
KXJwSnh6Qak7zcHbvNMxQb4IYu+mNAf9uypsjZJFDt80YvoP3U1z2HKibN98
CShfM91BcQPQZaxFDr3TgRos0h1Azij4WejQ+jpwh5xjusMxkIEvCh2qRNa5
P3RLh9j3phDiXoV0B+HmA6cWfiyEuO93GsTff6D6T6Y5gMPnQyHEvqNpDlYg
B7yEqj8Mlb9W6CAD4n9Pg9h3DCrPnw4xZ2ehgw/IX6pQ+5YWOliCzGFOh/hz
R6FDKJ/uprmP0xxid3nyMH0vdFj9ERiwNWkOoGC3Ny5yuHnue/Bj3zQHULD2
I8UXAIuTyOo=
               "]]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIZIGYC4gtKt3/WhRU5cF1fXGAbl+rw6ZJvkkBMkQMD
CJxJdZiRJ9R8wKjIoShj4tuayWkQ+YAihz0lkyVY/kH5IUUOhbZAE3jSHaJS
rO/7uxc59B/6qhFjnO4AVBXGZ1/kIAuSkE53uFrxUs3QCGrftzSH3Oe/V35U
KXJwTHh6Qak7zcHbvNMxQb4IYu+mNAf9uypsjZJFDt80YvoP3U1z2HKibN98
CShfM91BcQPQZaxFDn3TgRos0h1Azij4WejQ+jpwh5xjusMxkIEvCh2qRda5
P3RLh9j3ptChAKRQId1BuPnAqYUfCyHu+50G8fefQoc2kP6TaQ7g8PlQ6PAV
ZN/RNAcrkANeQtUfhspfg/K/p0HsOwbl86dD3LGzEOIvVah9SwsdLEHmMKdD
/Lmj0CGUT3fT3MdpDrG7PHmYvhc6rP4IDNiaNAdQsNsbFzncPPc9+LFvmgMo
WPuR4gsAigvI6Q==
               "],
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIZIGYC4mPe5p2Ox4ocRNa5P6y6EuuguKEoY+LZIgeX
7pznv2/GOiiA+NeLHNrFbp77/jjW4YLS7Z9154ocPHmYtNu3xTpogyRaixx6
p+cJNQfEOMwAUgcKihy+acT0H3ob7QASPsBW5MAAAgoxDkBbRNbNLoSoj4hx
uFrxUs2wqdDBL0kgwvJMjEP5vvlS+uaFEPeUxEL4/IUOF0H2Xop12HKibN/8
KwUOxRkT39Y8j3UAu39FgUMmkGu/FureyQUOXNcXF9hOinWYLMESxtdeALFv
QqyDbFSK9f2pBQ6b5r5ffux0rMPS2UcUNiwpcHgK8hhbHMQ92wocLEEWhcc5
3PcH6jxR4LBGBqixP85hh1zr68APBQ419qZxuzjjHT5d8k0SMCl0eAbSbxfv
ADLeP7sQ4j7xeAdbkEN2FkLC61kcJBx+QeXl4xyApu2Qcy+C+B8Y/uDwyS+C
2Lc+1uExyIFzihyAvs/aswXqX6T4AgDJDcnj
               "]]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIZIGYC4mPe5p2Ox4ocRNa5P6y6EuuguKEoY+LZIgeX
7pznv2/GOiiA+NeLHNrEbp77/jjW4YLS7Z9154ocvHiYtNu3xTpotwMlWosc
+qbnCTUHxDjMAFIHCoocvmnE9B96G+0AEj7AVuTAAAIKMQ5AW0TWzS6EqI+I
cbha8VLNsKnQwS9JIMLyTIxD+b75UvrmhRD3lMRC+PyFDpdA9l6Kddhyomzf
/CsFDkBXva15HusAdv+KAocsINd+LdS9kwsceK4vLrCdFOswWYIljK+9AGLf
hFgH2agU6/tTCxw2zX2//NjpWIels48obFhS4PAE5DG2OIh7thU4WIEsCo9z
uO/fOz3vRIHDGhmgxv44hx1yra8DPxQ41Nibxu3ijHf4dMk3ScCk0OEZSL9d
vAPIeP/sQocSkPvE4x1suYAO2Vno4AEKr2dxkHD4VQhxv3ycA9C0HXLuRRD/
A8MfHD75RRD71sc6PAY5cE6Rw52fdVl7tkD9ixRfAM89yek=
               "],
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{262.16, 
               109.32}, {261.316, 109.215}, {260.78099999999995`, 
               107.57799999999999`}, {260.363, 108.68799999999999`}, {259.66, 
               110.48}, {260.15200000000004`, 111.906}, {260.945, 111.75}, {
               261.883, 111.5}, {263.465, 109.402}, {262.16, 109.32}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{262.16, 
               109.32}, {261.316, 109.215}, {260.78099999999995`, 
               107.57799999999997`}, {260.363, 108.68799999999999`}, {259.66, 
               110.47999999999999`}, {260.15200000000004`, 111.906}, {260.945,
                111.75}, {261.883, 111.5}, {263.465, 109.40199999999999`}, {
               262.16, 109.32}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4h1yra8DfxQ5ZEx8W2O/NdVBJirF+j57scM3
jZj+Q1dTHbzNOx0TmIsd1A051sg8SnUAqjKNe1PksPVE2b75QP7jpbOPKNwq
cljkuu3z3yepDgwgsK3I4ThI45lUh2MgegWU/yDVwf1hlci62UUOF5Vu/6z7
lOqwDKh9w4IiiD6HNAega3bIAeUttwAtSE6DyM8ocgjj0900tzzNwQOkf2KR
A5B0fzgtzeHTJd8kgaYiiPvS0iDmBxc56N9VYWu8mOpgBTJHssjBMeHpBSX5
VIg7GYocVn0EaixIgaj7XAjxF18KxL0MUP2lyZBw0YX6ly/ZQaj5wKmF2kUO
XNcXF9imJTuAnPXeGhp+C5Mh4edf5HAJ5L9XyQ73/Xun52UUOczIA+r0SnHQ
ahe7ee5wkUM4SKN/qgN6+AMAUBKzZA==
               "]], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{291.574, 
               149.24599999999998`}, {288.39099999999996`, 
               149.23399999999998`}, {287.84400000000005`, 153.504}, {
               287.84400000000005`, 154.69899999999998`}, {
               289.40999999999997`, 154.39800000000002`}, {292.172, 
               151.785}, {291.574, 149.24599999999998`}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{291.574, 149.246}, {
               288.39099999999996`, 149.234}, {287.84400000000005`, 
               153.504}, {287.84400000000005`, 154.69899999999998`}, {
               289.40999999999997`, 154.398}, {292.172, 
               151.78500000000003`}, {291.574, 149.246}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{264.039, 107.793}, {
               261.77299999999997`, 107.277}, {261.805, 
               112.73400000000001`}, {264.121, 115.04700000000001`}, {
               263.10200000000003`, 111.543}, {265.824, 108.336}, {264.039, 
               107.793}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{264.039, 107.793}, {
               261.77299999999997`, 107.27700000000002`}, {261.805, 
               112.73400000000001`}, {264.121, 115.047}, {263.10200000000003`,
                111.54299999999998`}, {265.824, 108.33600000000001`}, {
               264.039, 107.793}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{264.92199999999997`,
                107.84}, {264.77, 105.24600000000001`}, {271.28499999999997`, 
               108.17999999999999`}, {272.96099999999996`, 110.195}, {269.113,
                108.562}, {265.10900000000004`, 109.91400000000002`}, {
               264.92199999999997`, 107.84}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{264.92199999999997`,
                107.84}, {264.77, 105.24600000000001`}, {271.28499999999997`, 
               108.17999999999998`}, {272.96099999999996`, 110.195}, {269.113,
                108.56199999999998`}, {265.10900000000004`, 
               109.91399999999999`}, {264.92199999999997`, 107.84}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{267.777, 111.543}, {
               267.543, 109.031}, {273.42599999999993`, 111.242}, {275.168, 
               113.203}, {271.301, 111.953}, {268.03099999999995`, 113.613}, {
               267.777, 111.543}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{267.777, 
               111.54299999999998`}, {267.543, 109.031}, {273.42599999999993`,
                111.24199999999999`}, {275.168, 113.203}, {271.301, 
               111.953}, {268.03099999999995`, 113.61299999999997`}, {267.777,
                111.54299999999998`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{266.695, 111.191}, {
               264.42999999999995`, 110.67599999999999`}, {
               264.79699999999997`, 116.32}, {267., 118.262}, {265.941, 
               114.49600000000001`}, {268.477, 111.738}, {266.695, 
               111.191}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{266.695, 111.191}, {
               264.42999999999995`, 110.67599999999999`}, {
               264.79699999999997`, 116.32}, {267., 118.262}, {265.941, 
               114.49600000000001`}, {268.477, 111.738}, {266.695, 111.191}}},
               
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{269.078, 
               114.62499999999999`}, {266.812, 114.109}, {268.113, 
               118.96900000000001`}, {269.79299999999995`, 
               120.91000000000001`}, {269.52, 117.367}, {270.637, 
               114.91000000000001`}, {269.078, 114.62499999999999`}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{269.078, 114.625}, {
               266.812, 114.10899999999998`}, {268.113, 118.969}, {
               269.79299999999995`, 120.91}, {269.52, 117.36700000000002`}, {
               270.637, 114.91}, {269.078, 114.625}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{270.28099999999995`,
                114.641}, {270.047, 112.051}, {274.625, 114.039}, {276.402, 
               116.488}, {272.574, 115.238}, {270.53499999999997`, 
               116.70700000000001`}, {270.28099999999995`, 114.641}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{270.28099999999995`,
                114.64099999999999`}, {270.047, 112.05100000000002`}, {
               274.625, 114.03899999999999`}, {276.402, 116.488}, {272.574, 
               115.238}, {270.53499999999997`, 116.70700000000002`}, {
               270.28099999999995`, 114.64099999999999`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{271.527, 116.609}, {
               270.043, 117.67599999999999`}, {271.617, 120.5}, {274.445, 
               120.324}, {274.168, 118.617}, {273.191, 115.621}, {271.527, 
               116.609}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{271.527, 
               116.60899999999998`}, {270.043, 117.67599999999999`}, {271.617,
                120.5}, {274.445, 120.32400000000001`}, {274.168, 
               118.61699999999999`}, {273.191, 115.62100000000001`}, {271.527,
                116.60899999999998`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{260.367, 104.902}, {
               260.219, 102.309}, {266.734, 103.60199999999999`}, {
               268.78099999999995`, 106.363}, {264.672, 105.586}, {260.559, 
               106.98}, {260.367, 104.902}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{260.367, 
               104.90199999999999`}, {260.219, 102.309}, {266.734, 
               103.60199999999998`}, {268.78099999999995`, 106.363}, {264.672,
                105.58600000000001`}, {260.559, 106.97999999999999`}, {
               260.367, 104.90199999999999`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{286.258, 109.543}, {
               286.02299999999997`, 106.95700000000001`}, {293.137, 
               109.801}, {294.914, 112.25}, {291.09, 111.}, {286.512, 
               111.613}, {286.258, 109.543}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{286.258, 
               109.54299999999998`}, {286.02299999999997`, 
               106.95700000000002`}, {293.137, 109.80100000000002`}, {294.914,
                112.25}, {291.09, 111.}, {286.512, 111.61299999999997`}, {
               286.258, 109.54299999999998`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{281.895, 
               108.44100000000002`}, {280.40999999999997`, 109.508}, {283.441,
                112.258}, {285.855, 112.902}, {285.582, 111.199}, {283.559, 
               107.453}, {281.895, 108.44100000000002`}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{281.895, 108.441}, {
               280.40999999999997`, 109.50799999999998`}, {283.441, 
               112.25800000000001`}, {285.855, 112.90199999999999`}, {285.582,
                111.19899999999998`}, {283.559, 107.453}, {281.895, 108.441}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{281.441, 106.648}, {
               281.28099999999995`, 104.32}, {289.07, 105.598}, {291.105, 
               107.74600000000001`}, {284.40599999999995`, 106.535}, {281.66, 
               108.641}, {281.441, 106.648}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{281.441, 
               106.64799999999997`}, {281.28099999999995`, 104.32}, {289.07, 
               105.59799999999998`}, {291.105, 107.74600000000001`}, {
               284.40599999999995`, 106.535}, {281.66, 108.64099999999999`}, {
               281.441, 106.64799999999997`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{277.79299999999995`,
                105.098}, {276.92599999999993`, 102.93400000000001`}, {
               284.402, 103.46100000000001`}, {287.027, 
               104.71900000000001`}, {282.78499999999997`, 104.754}, {278.387,
                106.60199999999999`}, {277.79299999999995`, 105.098}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{277.79299999999995`,
                105.09799999999998`}, {276.92599999999993`, 102.934}, {
               284.402, 103.46100000000001`}, {287.027, 104.719}, {
               282.78499999999997`, 104.75400000000002`}, {278.387, 
               106.60199999999998`}, {277.79299999999995`, 
               105.09799999999998`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{274.29699999999997`,
                103.52}, {273.469, 101.582}, {280.383, 101.62499999999999`}, {
               283.754, 102.695}, {279.289, 102.73}, {275.113, 105.438}, {
               274.29699999999997`, 103.52}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{274.29699999999997`,
                103.51999999999998`}, {273.469, 101.582}, {280.383, 
               101.625}, {283.754, 102.695}, {279.289, 102.73000000000002`}, {
               275.113, 105.43799999999999`}, {274.29699999999997`, 
               103.51999999999998`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{269.26599999999996`,
                102.48}, {268.039, 100.18799999999999`}, {275.33599999999996`,
                99.965}, {277.703, 101.09400000000001`}, {273.484, 
               101.67199999999998`}, {270.309, 104.285}, {269.26599999999996`,
                102.48}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{269.26599999999996`,
                102.47999999999999`}, {268.039, 100.18799999999999`}, {
               275.33599999999996`, 99.965}, {277.703, 101.094}, {273.484, 
               101.67199999999997`}, {270.309, 104.28500000000003`}, {
               269.26599999999996`, 102.47999999999999`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{277.809, 106.398}, {
               280.129, 104.938}, {280.004, 109.25}, {281.85200000000003`, 
               112.238}, {278.949, 109.598}, {276.234, 107.79700000000001`}, {
               277.809, 106.398}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{277.809, 106.398}, {
               280.129, 104.93799999999999`}, {280.004, 109.25}, {
               281.85200000000003`, 112.238}, {278.949, 
               109.59799999999998`}, {276.234, 107.79700000000003`}, {277.809,
                106.398}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{273.695, 104.848}, {
               275.64500000000004`, 103.12499999999999`}, {277.199, 
               109.043}, {278.97299999999996`, 112.367}, {276.105, 109.203}, {
               271.89799999999997`, 106.281}, {273.695, 104.848}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{273.695, 
               104.84799999999998`}, {275.64500000000004`, 103.125}, {277.199,
                109.04299999999998`}, {278.97299999999996`, 
               112.36700000000002`}, {276.105, 109.203}, {271.89799999999997`,
                106.28100000000003`}, {273.695, 104.84799999999998`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{268.258, 103.199}, {
               269.90599999999995`, 101.289}, {274.672, 108.816}, {
               276.40599999999995`, 112.73400000000001`}, {
               273.76599999999996`, 109.684}, {266.945, 104.82}, {268.258, 
               103.199}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{268.258, 
               103.19899999999998`}, {269.90599999999995`, 
               101.28900000000002`}, {274.672, 108.816}, {276.40599999999995`,
                112.73400000000001`}, {273.76599999999996`, 109.684}, {
               266.945, 104.82}, {268.258, 103.19899999999998`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{272.895, 
               97.45700000000001}, {273.719, 94.551}, {285.848, 100.195}, {
               287.203, 103.117}, {280.262, 99.44100000000002}, {
               272.72999999999996`, 100.21100000000001`}, {272.895, 
               97.45700000000001}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{272.895, 
               97.45700000000002}, {273.719, 94.55100000000002}, {285.848, 
               100.195}, {287.203, 103.11699999999999`}, {280.262, 99.441}, {
               272.72999999999996`, 100.21100000000001`}, {272.895, 
               97.45700000000002}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4k+XfJME6oodZKNSrO/3JztsPVG2b35TsUMY
n+6mubOTHdwfVoms6y92CAfxgfL3/Xun5/UUOzglPL2gVJzs4G3e6ZjQWexw
52dd1h6fZIfJEixhfLlQ/e1JDm9r7E3jbIodLLcADXZOcvAAmSdZ7PBNI6b/
kGCSQ8ZEoIrkIofW14E75A4mOlxQuv2zTqDIoVpknfvDeYkOcbs8eZgeFzoU
2nJdX9yTCBHfU+jgCLI/PtEhFiQ/v9Bhep5Q8wGxRIh7Vhc66N9VYWssTXQA
ect/ayHEPbsTIfYdLXQQbj5waiHQfrC+K4UOi1y3ff4bk+Sg3S5289zfQoh/
10Pdr1HkwAACW5IcQM4oKC+CuH9nkoMVyF93ixxU2RqnOh9PcgCHpwbUv+zQ
8PKD8tWh4ZVaDPFXcLIDevgDAJdbrTE=
               "]]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4k+XfJME6oodZKNSrO/3JztsPVG2b35TsUMY
n+6mubOTHdwfVoms64fygfL3/Xun5/UUOzgmPL2gVJzs4G3e6ZjQWexw+2dd
1h6fZIfJEixhfLlQ9e1JDm9r7E3jbIodLLcADXZOcvAAmSdZ7PBNI6b/kGCS
Q8ZEoIrkIofW14E75A4mOlxQApokUORQLbLO/eG8RIe4XZ48TI8LHQptua4v
7kmEiO8phNgfn+gQC5KfX+gwI0+o+YBYIsQ9qwsd9O6qsDWWJjqAvOW/tRDi
nt2JEPuOFjoINx84tRBo/3SQviuFDotct33+G5PkoN0udvPcX6j69VD3axQ5
MIDAliQHkDMKyosg7t+Z5GAF8tfdIgc1tsapzseTHMDhqQH1Lzs0vPygfHVo
eKUWQ/wVnOyAHv4AkzOtLg==
               "],
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{283.566, 132.105}, {
               282.012, 130.95700000000002`}, {280.29299999999995`, 
               135.066}, {282.27, 138.97299999999998`}, {282.332, 
               135.21499999999997`}, {285.32, 133.94899999999998`}, {283.566, 
               132.105}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{283.566, 132.105}, {
               282.012, 130.95700000000002`}, {280.29299999999995`, 
               135.066}, {282.27, 138.97299999999998`}, {282.332, 135.215}, {
               285.32, 133.94899999999998`}, {283.566, 132.105}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{282.07, 128.336}, {
               279.91799999999995`, 127.67599999999999`}, {279.242, 
               131.484}, {280.66, 134.535}, {280.42599999999993`, 131.258}, {
               284.047, 129.285}, {282.07, 128.336}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{282.07, 128.336}, {
               279.91799999999995`, 127.67599999999999`}, {279.242, 
               131.484}, {280.66, 134.535}, {280.42599999999993`, 131.258}, {
               284.047, 129.28500000000003`}, {282.07, 128.336}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{280.43399999999997`,
                125.312}, {278.35200000000003`, 124.277}, {277.562, 
               128.125}, {279.059, 130.984}, {278.895, 127.34}, {
               282.03499999999997`, 126.262}, {280.43399999999997`, 
               125.312}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{280.43399999999997`,
                125.31199999999998`}, {278.35200000000003`, 
               124.27700000000002`}, {277.562, 128.125}, {279.059, 130.984}, {
               278.895, 127.34}, {282.03499999999997`, 126.262}, {
               280.43399999999997`, 125.31199999999998`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{281.289, 
               125.07799999999999`}, {282.113, 122.617}, {286.895, 127.203}, {
               287.699, 129.69899999999998`}, {284.72999999999996`, 126.75}, {
               280.695, 127.07799999999999`}, {281.289, 
               125.07799999999999`}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{281.289, 
               125.07799999999997`}, {282.113, 122.61699999999999`}, {286.895,
                127.203}, {287.699, 129.69899999999998`}, {
               284.72999999999996`, 126.75}, {280.695, 127.07799999999997`}, {
               281.289, 125.07799999999997`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{283.457, 128.848}, {
               284.395, 126.383}, {290.40599999999995`, 132.727}, {291.734, 
               135.781}, {288.76599999999996`, 132.836}, {282.789, 130.586}, {
               283.457, 128.848}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{283.457, 
               128.84799999999998`}, {284.395, 126.38300000000001`}, {
               290.40599999999995`, 132.72700000000003`}, {291.734, 
               135.78100000000003`}, {288.76599999999996`, 132.836}, {282.789,
                130.586}, {283.457, 128.84799999999998`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{284.648, 
               132.54299999999998`}, {285.58599999999996`, 129.742}, {292.121,
                137.207}, {293.97299999999996`, 139.85200000000003`}, {
               290.855, 136.941}, {283.941, 134.578}, {284.648, 
               132.54299999999998`}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{284.648, 
               132.54299999999998`}, {285.58599999999996`, 129.742}, {292.121,
                137.20700000000002`}, {293.97299999999996`, 139.852}, {
               290.855, 136.941}, {283.941, 134.57799999999997`}, {284.648, 
               132.54299999999998`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{284.855, 135.312}, {
               282.555, 135.758}, {284.98799999999994`, 137.676}, {287.809, 
               140.79299999999998`}, {287.93799999999993`, 137.512}, {287.402,
                135.21899999999997`}, {284.855, 135.312}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{284.855, 
               135.31199999999998`}, {282.555, 135.758}, {284.98799999999994`,
                137.676}, {287.809, 140.793}, {287.93799999999993`, 
               137.51199999999997`}, {287.402, 135.219}, {284.855, 
               135.31199999999998`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{288.734, 137.176}, {
               287.742, 138.258}, {289.688, 138.71899999999997`}, {
               292.09799999999996`, 141.42200000000003`}, {292.453, 
               139.602}, {289.863, 136.262}, {288.734, 137.176}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{288.734, 137.176}, {
               287.742, 138.258}, {289.688, 138.719}, {292.09799999999996`, 
               141.422}, {292.453, 139.60199999999998`}, {289.863, 136.262}, {
               288.734, 137.176}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{277.60200000000003`,
                125.016}, {276.34000000000003`, 124.277}, {
               275.47999999999996`, 126.859}, {277.047, 129.195}, {
               277.40599999999995`, 126.66799999999999`}, {278.754, 
               125.965}, {277.60200000000003`, 125.016}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{277.60200000000003`,
                125.01599999999999`}, {276.34000000000003`, 
               124.27700000000002`}, {275.47999999999996`, 
               126.85900000000001`}, {277.047, 129.195}, {277.40599999999995`,
                126.66799999999998`}, {278.754, 125.965}, {
               277.60200000000003`, 125.01599999999999`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{304.953, 141.297}, {
               307.625, 139.691}, {311.875, 146.09}, {313.008, 
               148.72299999999998`}, {310.66, 145.69899999999998`}, {304.445, 
               142.941}, {304.953, 141.297}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{304.953, 
               141.29700000000003`}, {307.625, 139.691}, {311.875, 146.09}, {
               313.008, 148.723}, {310.66, 145.69899999999998`}, {304.445, 
               142.941}, {304.953, 141.29700000000003`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{302.68, 137.566}, {
               304.16, 135.92600000000002`}, {308.816, 140.383}, {
               310.43399999999997`, 142.641}, {307.93799999999993`, 
               140.48000000000002`}, {302.027, 140.22299999999998`}, {302.68, 
               137.566}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{302.68, 137.566}, {
               304.16, 135.92600000000002`}, {308.816, 140.383}, {
               310.43399999999997`, 142.641}, {307.93799999999993`, 140.48}, {
               302.027, 140.223}, {302.68, 137.566}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{300.14500000000004`,
                134.22299999999998`}, {300.633, 131.984}, {
               307.42999999999995`, 137.02}, {309.02, 139.406}, {
               306.08599999999996`, 136.64499999999998`}, {299.699, 
               136.895}, {300.14500000000004`, 134.22299999999998`}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{300.14500000000004`,
                134.223}, {300.633, 131.984}, {307.42999999999995`, 
               137.01999999999998`}, {309.02, 139.406}, {306.08599999999996`, 
               136.64499999999998`}, {299.699, 136.895}, {300.14500000000004`,
                134.223}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{301.184, 
               131.80100000000002`}, {302.234, 129.781}, {307.762, 134.781}, {
               309.08599999999996`, 137.39100000000002`}, {
               305.71099999999996`, 134.441}, {300.328, 133.797}, {301.184, 
               131.80100000000002`}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{301.184, 
               131.80100000000002`}, {302.234, 129.78100000000003`}, {307.762,
                134.78100000000003`}, {309.08599999999996`, 
               137.39100000000002`}, {305.71099999999996`, 134.441}, {300.328,
                133.79700000000003`}, {301.184, 131.80100000000002`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{304.02299999999997`,
                141.625}, {302.28099999999995`, 143.465}, {
               303.02299999999997`, 144.324}, {304.29299999999995`, 
               147.22299999999998`}, {304.98799999999994`, 
               144.24599999999998`}, {306.039, 143.059}, {304.02299999999997`,
                141.625}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{304.02299999999997`,
                141.625}, {302.28099999999995`, 143.465}, {
               303.02299999999997`, 144.324}, {304.29299999999995`, 
               147.223}, {304.98799999999994`, 144.246}, {306.039, 143.059}, {
               304.02299999999997`, 141.625}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{301.71099999999996`,
                138.15200000000002`}, {298.547, 138.012}, {301.68, 141.863}, {
               302.42999999999995`, 145.094}, {302.156, 141.41}, {303.242, 
               138.504}, {301.71099999999996`, 138.15200000000002`}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{301.71099999999996`,
                138.152}, {298.547, 138.01199999999997`}, {301.68, 141.863}, {
               302.42999999999995`, 145.094}, {302.156, 141.41}, {303.242, 
               138.504}, {301.71099999999996`, 138.152}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{299.695, 135.098}, {
               297.504, 135.59}, {298.137, 138.695}, {299.816, 
               142.44899999999998`}, {299.469, 138.39100000000002`}, {301.672,
                136.047}, {299.695, 135.098}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{299.695, 
               135.09799999999998`}, {297.504, 135.59}, {298.137, 138.695}, {
               299.816, 142.44899999999998`}, {299.469, 
               138.39100000000002`}, {301.672, 136.047}, {299.695, 
               135.09799999999998`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{300.441, 128.961}, {
               301.26599999999996`, 126.49600000000001`}, {307.5, 
               132.20299999999997`}, {308.49199999999996`, 134.363}, {
               305.34000000000003`, 131.71499999999997`}, {299.883, 
               130.809}, {300.441, 128.961}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{300.441, 128.961}, {
               301.26599999999996`, 126.49600000000001`}, {307.5, 132.203}, {
               308.49199999999996`, 134.363}, {305.34000000000003`, 
               131.715}, {299.883, 130.809}, {300.441, 128.961}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{296.703, 125.113}, {
               297.641, 122.648}, {304.176, 127.645}, {306.176, 
               130.36700000000002`}, {302.23799999999994`, 127.27}, {
               296.22299999999996`, 127.55499999999999`}, {296.703, 
               125.113}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{296.703, 
               125.11299999999997`}, {297.641, 122.64799999999997`}, {304.176,
                127.64499999999998`}, {306.176, 130.36700000000002`}, {
               302.23799999999994`, 127.27000000000001`}, {
               296.22299999999996`, 127.555}, {296.703, 125.11299999999997`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{292.895, 121.23}, {
               293.945, 117.79700000000001`}, {300.777, 123.281}, {302.816, 
               125.965}, {298.465, 122.645}, {292.34000000000003`, 
               123.67599999999999`}, {292.895, 121.23}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{292.895, 
               121.23000000000002`}, {293.945, 117.79700000000003`}, {300.777,
                123.28100000000003`}, {302.816, 125.965}, {298.465, 
               122.64499999999998`}, {292.34000000000003`, 
               123.67599999999999`}, {292.895, 121.23000000000002`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{299.32, 130.055}, {
               297.465, 129.094}, {296.715, 134.363}, {297.762, 
               138.08200000000002`}, {297.746, 134.023}, {301.484, 131.008}, {
               299.32, 130.055}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{299.32, 130.055}, {
               297.465, 129.094}, {296.715, 134.363}, {297.762, 138.082}, {
               297.746, 134.023}, {301.484, 131.00799999999998`}, {299.32, 
               130.055}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{296.15200000000004`,
                125.871}, {293.92199999999997`, 125.21100000000001`}, {
               294.629, 130.88700000000003`}, {296.53499999999997`, 134.57}, {
               296.78099999999995`, 130.92200000000003`}, {
               298.42599999999993`, 127.45700000000001`}, {
               296.15200000000004`, 125.871}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{296.15200000000004`,
                125.87100000000001`}, {293.92199999999997`, 
               125.21100000000001`}, {294.629, 130.88700000000003`}, {
               296.53499999999997`, 134.57}, {296.78099999999995`, 130.922}, {
               298.42599999999993`, 127.45700000000002`}, {
               296.15200000000004`, 125.87100000000001`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{292.191, 121.953}, {
               289.699, 121.812}, {291.414, 126.82}, {293.469, 129.641}, {
               293.121, 125.95700000000001`}, {294.28099999999995`, 
               122.37899999999999`}, {292.191, 121.953}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{292.191, 121.953}, {
               289.699, 121.81199999999998`}, {291.414, 126.82}, {293.469, 
               129.641}, {293.121, 125.95700000000002`}, {294.28099999999995`,
                122.37899999999999`}, {292.191, 121.953}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{296.559, 119.816}, {
               297.309, 118.54700000000001`}, {299.141, 120.895}, {302.148, 
               122.60499999999999`}, {299.445, 121.898}, {296.227, 120.992}, {
               296.559, 119.816}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{296.559, 119.816}, {
               297.309, 118.547}, {299.141, 120.89500000000001`}, {302.148, 
               122.60499999999999`}, {299.445, 121.898}, {296.227, 
               120.99199999999999`}, {296.559, 119.816}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{297.984, 162.008}, {
               295.66, 163.727}, {297.43399999999997`, 166.945}, {297.984, 
               170.008}, {298.72999999999996`, 167.105}, {300.703, 163.297}, {
               297.984, 162.008}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{297.984, 
               162.00799999999998`}, {295.66, 163.72700000000003`}, {
               297.43399999999997`, 166.945}, {297.984, 
               170.00799999999998`}, {298.72999999999996`, 167.105}, {300.703,
                163.29700000000003`}, {297.984, 162.00799999999998`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{298.062, 
               157.71899999999997`}, {301.559, 158.141}, {301.03099999999995`,
                162.656}, {301.137, 165.52}, {300.08599999999996`, 
               161.63299999999998`}, {297.22299999999996`, 160.977}, {298.062,
                157.71899999999997`}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{298.062, 157.719}, {
               301.559, 158.141}, {301.03099999999995`, 162.656}, {301.137, 
               165.51999999999998`}, {300.08599999999996`, 
               161.63299999999998`}, {297.22299999999996`, 160.977}, {298.062,
                157.719}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{297.512, 158.305}, {
               294.559, 158.477}, {294.715, 161.836}, {294.555, 165.238}, {
               296.055, 162.11299999999997`}, {297.828, 161.629}, {297.512, 
               158.305}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{297.512, 158.305}, {
               294.559, 158.477}, {294.715, 161.836}, {294.555, 165.238}, {
               296.055, 162.11299999999997`}, {297.828, 161.629}, {297.512, 
               158.305}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{297.633, 154.129}, {
               299.92999999999995`, 153.945}, {301.125, 
               156.20299999999997`}, {301.65200000000004`, 
               159.72299999999998`}, {299.47299999999996`, 
               156.48000000000002`}, {297.48799999999994`, 
               157.48800000000003`}, {297.633, 154.129}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{297.633, 154.129}, {
               299.92999999999995`, 153.945}, {301.125, 156.203}, {
               301.65200000000004`, 159.723}, {299.47299999999996`, 156.48}, {
               297.48799999999994`, 157.488}, {297.633, 154.129}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{296.809, 154.406}, {
               293.85200000000003`, 154.02700000000002`}, {294.324, 
               157.469}, {294.445, 160.004}, {295.348, 157.586}, {297.754, 
               156.824}, {296.809, 154.406}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{296.809, 154.406}, {
               293.85200000000003`, 154.02700000000002`}, {294.324, 
               157.469}, {294.445, 160.004}, {295.348, 157.586}, {297.754, 
               156.824}, {296.809, 154.406}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{301.414, 155.863}, {
               301.18, 153.617}, {299.762, 149.758}, {297.477, 150.625}, {
               296.53099999999995`, 153.383}, {299.484, 153.934}, {301.414, 
               155.863}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{301.414, 155.863}, {
               301.18, 153.617}, {299.762, 149.758}, {297.477, 150.625}, {
               296.53099999999995`, 153.383}, {299.484, 153.934}, {301.414, 
               155.863}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{296.77, 150.383}, {
               297.79299999999995`, 152.35500000000002`}, {294.445, 153.34}, {
               293.734, 155.89800000000002`}, {293.328, 
               152.23399999999998`}, {293.668, 149.83200000000002`}, {296.77, 
               150.383}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{296.77, 150.383}, {
               297.79299999999995`, 152.35500000000002`}, {294.445, 153.34}, {
               293.734, 155.898}, {293.328, 152.234}, {293.668, 149.832}, {
               296.77, 150.383}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{306.29699999999997`,
                173.727}, {304.457, 175.71099999999998`}, {306.082, 
               178.85200000000003`}, {306.633, 181.914}, {307.379, 179.012}, {
               308.676, 175.164}, {306.29699999999997`, 173.727}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{306.29699999999997`,
                173.72700000000003`}, {304.457, 175.711}, {306.082, 
               178.852}, {306.633, 181.914}, {307.379, 179.01199999999997`}, {
               308.676, 175.164}, {306.29699999999997`, 173.72700000000003`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{306.35200000000003`,
                170.039}, {309.582, 169.71099999999998`}, {310.363, 
               176.285}, {310.695, 179.10899999999998`}, {309.64500000000004`,
                175.22299999999998`}, {305.92199999999997`, 173.445}, {
               306.35200000000003`, 170.039}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{306.35200000000003`,
                170.039}, {309.582, 169.711}, {310.363, 
               176.28500000000003`}, {310.695, 179.10899999999998`}, {
               309.64500000000004`, 175.223}, {305.92199999999997`, 
               173.445}, {306.35200000000003`, 170.039}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{305.688, 170.105}, {
               303.40599999999995`, 171.285}, {303.93399999999997`, 
               173.824}, {303.219, 175.73}, {304.754, 173.39100000000002`}, {
               306.15200000000004`, 173.055}, {305.688, 170.105}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{305.688, 170.105}, {
               303.40599999999995`, 171.28500000000003`}, {
               303.93399999999997`, 173.824}, {303.219, 
               175.73000000000002`}, {304.754, 173.39100000000002`}, {
               306.15200000000004`, 173.055}, {305.688, 170.105}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{306.328, 
               165.80100000000002`}, {309.707, 165.512}, {311.72299999999996`,
                172.789}, {311.828, 175.656}, {310.777, 171.766}, {
               305.93399999999997`, 169.656}, {306.328, 
               165.80100000000002`}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{306.328, 
               165.80100000000002`}, {309.707, 165.51199999999997`}, {
               311.72299999999996`, 172.78900000000002`}, {311.828, 
               175.656}, {310.777, 171.76600000000002`}, {305.93399999999997`,
                169.656}, {306.328, 165.80100000000002`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{305.68, 165.91}, {
               302.5, 166.64499999999998`}, {302.883, 168.69899999999998`}, {
               303.35900000000004`, 172.02700000000002`}, {304.371, 
               168.676}, {306.14500000000004`, 169.38700000000003`}, {305.68, 
               165.91}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{305.68, 165.91}, {
               302.5, 166.64499999999998`}, {302.883, 168.69899999999998`}, {
               303.35900000000004`, 172.02700000000002`}, {304.371, 
               168.676}, {306.14500000000004`, 169.38700000000003`}, {305.68, 
               165.91}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{306.367, 161.602}, {
               310.08599999999996`, 160.969}, {309.824, 166.848}, {
               312.77299999999997`, 171.11299999999997`}, {
               310.22299999999996`, 167.945}, {305.625, 163.953}, {306.367, 
               161.602}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{306.367, 
               161.60199999999998`}, {310.08599999999996`, 160.969}, {309.824,
                166.84799999999998`}, {312.77299999999997`, 
               171.11299999999997`}, {310.22299999999996`, 167.945}, {305.625,
                163.953}, {306.367, 161.60199999999998`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{305.527, 
               161.80100000000002`}, {302.72299999999996`, 
               161.71899999999997`}, {302.449, 165.941}, {302.605, 167.656}, {
               303.25, 165.94899999999998`}, {306.547, 164.32800000000003`}, {
               305.527, 161.80100000000002`}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{305.527, 
               161.80100000000002`}, {302.72299999999996`, 161.719}, {302.449,
                165.941}, {302.605, 167.656}, {303.25, 165.94899999999998`}, {
               306.547, 164.328}, {305.527, 161.80100000000002`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{312.176, 166.129}, {
               310.78099999999995`, 161.605}, {308.805, 157.07}, {306.367, 
               157.414}, {305.199, 159.98800000000003`}, {308.68, 160.316}, {
               312.176, 166.129}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{312.176, 166.129}, {
               310.78099999999995`, 161.605}, {308.805, 157.07}, {306.367, 
               157.414}, {305.199, 159.988}, {308.68, 160.316}, {312.176, 
               166.129}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{305.48799999999994`,
                158.078}, {306.512, 160.05100000000002`}, {
               303.16400000000004`, 161.035}, {302.453, 163.598}, {302.047, 
               159.934}, {302.387, 157.52700000000002`}, {305.48799999999994`,
                158.078}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{305.48799999999994`,
                158.07799999999997`}, {306.512, 160.05100000000002`}, {
               303.16400000000004`, 161.035}, {302.453, 
               163.59799999999998`}, {302.047, 159.934}, {302.387, 
               157.52700000000002`}, {305.48799999999994`, 
               158.07799999999997`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{311.215, 160.961}, {
               309.227, 156.88700000000003`}, {308.328, 
               152.20299999999997`}, {305.59799999999996`, 152.883}, {304.578,
                156.05100000000002`}, {308.613, 156.71499999999997`}, {
               311.215, 160.961}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{311.215, 160.961}, {
               309.227, 156.88700000000003`}, {308.328, 152.203}, {
               305.59799999999996`, 152.883}, {304.578, 
               156.05100000000002`}, {308.613, 156.715}, {311.215, 160.961}}},
               
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{305.03099999999995`,
                153.656}, {306.207, 155.812}, {302.855, 
               156.57399999999998`}, {302.03499999999997`, 159.547}, {301.59, 
               155.656}, {302.008, 152.883}, {305.03099999999995`, 
               153.656}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{305.03099999999995`,
                153.656}, {306.207, 155.81199999999998`}, {302.855, 
               156.57399999999998`}, {302.03499999999997`, 159.547}, {301.59, 
               155.656}, {302.008, 152.883}, {305.03099999999995`, 153.656}}},
               
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{299.305, 181.238}, {
               297.34400000000005`, 180.71099999999998`}, {
               295.28499999999997`, 182.91}, {296., 186.207}, {298.242, 
               185.648}, {299.27, 183.61299999999997`}, {299.305, 
               181.238}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{299.305, 181.238}, {
               297.34400000000005`, 180.711}, {295.28499999999997`, 182.91}, {
               296., 186.20700000000002`}, {298.242, 185.64799999999997`}, {
               299.27, 183.61299999999997`}, {299.305, 181.238}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4vJ986X0JYsdVn+85Jt0J83hgtLtn3VixQ4z
8oSaD+xLc7jv3zs9j6XYgQEE9qQ5eDysElnHWeywt2SyBMuzNIdPQG0CfFB5
jnSHDseEpxeAfP27KmyNiulw9a2vA3fI2aY7LJt9RGEDU7GDbFSK9f34dIdF
rts+/wWaXy2yzv3hrHSH497mnY5cxQ5FGRPf1mxOdwC64tRC/mIHH6Bwwtl0
B5CwvWKxA9f1xQW2+9IdtNvFbp4Duv/mue/Bj1emOwiD1AtC5SdB1QP5YDoR
6j6g/97V2JvGeaU7XK14qWYoV+wA9KVQswaUL1PsEManu2nu7zQH9PABACpY
gi4=
               "]]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4vJ986X0JYsdVn+85Jt0J83hgtLtn3VixQ4z
8oSaD+xLc7jv3zs9j6XYgQEE9qQ5eDysElnHWeywp2SyBMuzNIdPQG0CfFB5
jnSHDseEpxeAfP27KmyNiulw9a2vA3fI2aY7LJt9RGEDU7GDbFSK9f34dIdF
rts+/wWaXy2yzv3hrHSH497mnY5cxQ5FGRPf1mxOdwC64tRC/mIHkHDC2XQH
kLC9YrED1/XFBbb70h2028VungO6/+a578GPV6Y7CIPUC0LlJ0HVA/lgOhHq
PqD/3tXYm8Z5pTtcrXipZihX7NA3HehhDShfptghjE9309zfaQ7o4QMAKQCC
LQ==
               "],
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4gtKt3/WfSl02D9fSv+uS6rDlhNl++YzFDlk
THxbY6+Y6uBt3umYIFnkELvLk4fJPNUBrJ6tyIEBBDJSHSZLsITxfS90COfT
3TS3P9Vhkeu2z38fFELkN0D13y+EiN9IdXi8dPYRhXtQ+3jSHKpE1rk/PFfo
YAWyODoNou5AoQPX9cUFtmVpDsuAyjdsKnTYCnLXpDSHqxUv1QwXFTrMyBNq
PpCV5qB/V4WtcWOhg0xUivX9cKj6Q4UOws0HTi10THPQbhe7ee5socM3jZj+
Q09THexABgP5F0H+OJTq8OmSb5IA0H5VtsapzkD3K2woypj4vNCBG2R/FtS/
SOEDAIZxjIA=
               "]]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4gtKt3/WfSl02DdfSv+uS6rDlhNl++YzFDlk
THxbY6+Y6uBt3umYIFnkELfLk4fJPNUBrJ6tyIEBBDJSHSZLsITxfS90COPT
3TS3P9Vhkeu2z38fFELkN0D13y90WAwSv5Hq8Hjp7CMK96D28aQ5VImsc394
rtDBCmRxdBpE/4FCB67riwtsy9IclgGVb9hUCHHXpDSHqxUv1QwXFTrMyBNq
PpCV5qB/V4WtcWOhg2xUivX9cKj6Q4UOws0HTi10THPQbhe7ee5socNXjZj+
Q09THexABgP5YH8cSnX4dMk3SQBovypb41RnoPsVNhRlTHwOtT8L6l+k8AEA
hLmMew==
               "],
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4q0nyvbNlypy4Lq+uMC2LtVhep5Q8wG1IodL
Srd/1kWlOny65JskYFXkoMrWONU5P9Wh9XXgDjn9IodekMIVqQ6yUSnW91WL
HB4vnX1E4UKqQ7XIOveHKkUOGRPf1tgzpjkc/qoR0w8zXy7N4WrFSzVDniIH
bhDfK81Bq13s5rnPhRB9eWkOfLqb5r5/Wujgbd7pmNCZ5gB0zamF1wsdvgGN
ObQ0zcFyC9DBpwsd3tXYm8Z1pUH03Sh0UDfkWCNTlOYA1PX0wotCiH1BaRB3
/Sp0APtTK83B/WGVyDrmIoc+kPt50hyEQeaLFkH0X0p1sAKZz1vkEApyyOJU
B/TwAQAz4ogA
               "]]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4q0nyvbNlypy4Lq+uMC2LtVhep5Q8wG1IoeL
Srd/1kWlOny65JskYFXkoMrWONU5P9Wh9XXgDjn9Ioc+kMIVqQ6yUSnW91WL
HB4vnX1E4UKqQ7XIOveHKkUOGRPf1tgzpjkc/qoR0w8zXy7N4WrFSzVDHijf
K81Bq13s5rnPhRB9eWkOfLqb5r5/WujgY97pmNCZ5gB0zamF1wsdQMYcWprm
YLkF6ODThQ7vauxN47rSIPpuFDqoG3KskSlKcwDqenrhRSHE/KA0iLt+FTqA
tM3XSnNwf1glso4Z6n6eNAdhkPmiRRD9l1IdrEAKeYscQkEOWZzqgB4+ADLS
h/4=
               "],
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4sdLZx9ReFLkMD1PqPmAWZqD4oaijIlPixxW
fbzkm8SS5pAx8W2N/cUih+Pe5p2OP1Idrla8VDO8VAQRd0xzmCzBEsZ3ucjB
4K4KW2NvmsMnoDaBd0UOqmyNU50vp0HE70L57ukOnY4JTy9cKXJgAIGGdAeQ
9RuAfLA7XqQ78Olumvv+ZpHDhENfNWLkMxxAVP+9Igeu64sLbMMyIOZ/KnIA
2m4aZ5ThsAyk/1WRQxhII3uGw0Wl2z/rHhU5qBtyrJG5lg5x75siB5C1SuXp
Dg/8e6fnAfX3gwwGuqd833wpfdZiiP/2pDnE7fLkYXpc5NALCpCKNAf08AEA
G6SKkQ==
               "]]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4sdLZx9ReFLkMCNPqPmAWZqD4oaijIlPixxW
fbzkm8SS5pAx8W2N/cUih+Pe5p2OP1Idrla8VDO8VAQRd0xzmCzBEsZ3uchB
/64KW2NvmsMnoDaBd0UOQN5U58tpDgYg8btFDmogvnu6Q6djwtMLV4ocGECg
Id0BZP0GIP8JiPEi3YFPd9Pc9zeLHCYc+qoRI5/hAKL67xU5cF1fXGAblgEx
/1ORw7sae9M4owyHZSD9r4ocwkAa2TMcLird/ln3qMhB3ZBjjcy1dIh73xQ5
OAGtVSpPd3jg3zs97xPUfKB7yvfNl9JnLYb4b0+aQ9wuTx6mx0UOfdOBAVKR
5oAePgAdlIqX
               "],
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4k7HhKcX1hQ5ZEx8W2Pvm+5gueVE2b71RQ5x
uzx5mOTTHbzNgSoOFznMyBNqPiCV7uDxsEpk3d4ih+MgiZh0h9znv1d+3FEE
UTcx3eHx0tlHFHZAzduJUN87HWjAk3SHqBTr+/5HixwuKd3+WSeVATH3UJED
SPpAWYbDZAmWMD6g+tbXgTvk5mZAzNle5PBNI6b/0NEMh0+XfJMElhQ57C0B
qlyXAbEP6H6u64sLbPsyHBa5bvv8dwvUPZkZDgZ3VdgatxY53PlZl7VHJgMi
DvQfWN0PqP+WF0HMOZLuoLChKGPiSqj5dekOsPDxAakDhg8A6B2OBw==
               
               "]]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4k7HhKcX1hQ5ZEx8W2Pvm+5gueVE2b71RQ5x
uzx5mOTTHbzNgSoOFznMyBNqPiCV7uDxsEpk3d4ih+MgiZh0h9znv1d+3FEE
UTcx3eHx0tlHFID8TJB5OxHqe6cDDXiS7hCVYn3f/2iRwyWl2z/rpDIg5h6C
ml+W4TBZgiWMD6i+9XXgDrm5GRB3bS9y+KYR03/oaIbDp0u+SQJLihz2lABV
rsuA2Ad0P9f1xQW2fRkOi1y3ff67pcjBB+SezAwHg7sqbI1bixzu/KzL2iOT
AXEn0H+LQep+QP23vAhizpF0B4UNRRkTV0LNr0t3gIUPWB0wfADplY4I
               "],
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYCYj7dTXPfFxc7CDcfOLVwZrLDcW/zTsesYoeL
Srd/1jUlO4DlI4sdXLpznv+emOzQ6Zjw9EJGsUPGxLc19huTHRa5bvv8t6TY
4RJI/SkovwCq/1Kyw33/3ul5FVD1H5MdLLecKNtXX+wQCjJYOMUBZF0CkA8S
nq+W4nAMJNBR7ACyRsk+xeHx0tlHFCYUO1wAmReWAnHP7GKHrSD1dikODCAw
pdjBCaReO8Xh0yXfJIGuYgfZqBTr+0Dzwe7tKXaYkSfUfIApxWE6iG4rdlj9
EajwTbKDwoaijInVxQ43z30Pfnw0GWJ/XbHDN42Y/kMbof5HCh8A/bGSfA==

               "]]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYCYj7dTXPfFxc7CDcfOLVwZrLDcW/zTsesYocL
Srd/1jUlO4DlI4sdnLtznv+emOzQ6Zjw9EJGsUPGxLc19huTHRa5bvv8t6TY
4SJI/SkovwCq/1Kyw33/3ul5FVD1H5MdLLecKNtXX+wQCjJYOMUBZF0CkL8V
KDxfLcXhGEigo9gBZI2SfYrD46WzjyhMgJoflgJxz2yoersUBwYQmAJVr53i
8OmSb5JAV7GDbFSK9X2g+WD39hQ7zMgTaj7AlOIwHUS3FTus/ghU+CbZQWFD
UcbE6mKHm+e+Bz8+mgyxv67Y4ZtGTP+hjVD/I4UPAPqZknk=
               "],
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{294.92999999999995`, 137.11299999999997`}, {292.977, 
               136.15200000000002`}, {291.4959999999999, 133.754}, {
               291.39799999999997`, 131.805}, {291.22999999999996`, 
               129.555}, {290.90999999999997`, 127.66}, {289.89799999999997`, 
               126.062}, {291.504, 126.508}, {292.27299999999997`, 129.07}, {
               292.504, 131.523}, {292.734, 134.059}, {294.10200000000003`, 
               135.16}, {294.92999999999995`, 137.11299999999997`}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{294.92999999999995`, 137.11299999999997`}, {292.977, 
               136.152}, {291.4959999999999, 133.75400000000002`}, {
               291.39799999999997`, 131.805}, {291.22999999999996`, 
               129.555}, {290.90999999999997`, 127.66}, {289.89799999999997`, 
               126.06199999999998`}, {291.504, 126.50799999999998`}, {
               292.27299999999997`, 129.07}, {292.504, 131.523}, {292.734, 
               134.059}, {294.10200000000003`, 135.16}, {294.92999999999995`, 
               137.11299999999997`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{290.863, 132.406}, {289.512, 129.914}, {287.625, 
               128.965}, {287.527, 127.113}, {287.363, 124.98400000000001`}, {
               287.203, 124.87899999999999`}, {286.625, 122.785}, {288.215, 
               123.20700000000001`}, {288.617, 123.348}, {289.047, 126.531}, {
               289.309, 128.76999999999998`}, {291.10200000000003`, 
               130.348}, {290.863, 132.406}}}]}, 
             {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
              0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{290.863, 132.406}, {289.512, 129.914}, {287.625, 
               128.965}, {287.527, 127.11299999999997`}, {287.363, 
               124.98400000000001`}, {287.203, 124.87899999999999`}, {286.625,
                122.78500000000003`}, {288.215, 123.20700000000002`}, {
               288.617, 123.34799999999998`}, {289.047, 126.531}, {289.309, 
               128.77}, {291.10200000000003`, 130.34799999999998`}, {290.863, 
               132.406}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{248.824, 
               109.34400000000001`}, {248.066, 107.91400000000002`}, {247.195,
                105.73400000000001`}, {245.61299999999997`, 106.133}, {245.59,
                107.23}, {247.32000000000002`, 107.988}, {248.824, 
               109.34400000000001`}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{246.47299999999998`,
                108.85499999999999`}, {243.40200000000002`, 107.598}, {
               240.754, 107.91000000000001`}, {240.42600000000002`, 105.98}, {
               243.30100000000002`, 105.66799999999999`}, {
               244.35500000000002`, 106.85199999999999`}, {
               246.47299999999998`, 108.85499999999999`}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{259.32, 119.008}, {257.254, 117.316}, {255.914, 
               115.383}, {255.289, 112.887}, {254.637, 110.559}, {
               253.71899999999997`, 108.703}, {252.375, 106.613}, {254.566, 
               108.10499999999999`}, {255.941, 110.141}, {256.633, 112.586}, {
               257.23799999999994`, 114.992}, {257.949, 116.793}, {259.32, 
               119.008}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{256.777, 119.016}, {254.562, 117.24600000000001`}, {
               252.47299999999998`, 115.242}, {251.848, 112.742}, {251.195, 
               110.418}, {250.80100000000002`, 108.637}, {249.309, 106.324}, {
               251.648, 107.816}, {252.578, 110.074}, {253.266, 112.52}, {
               253.871, 114.926}, {255.258, 116.727}, {256.777, 119.016}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4mqRde4P9fIdmg+cWujqF+Nw+2dd1h6DfAeu
64sLbLNiHFTZGqc6q+c7zMgTaj7QFONgteVE2T7pfAfn7pznvztjHHzMOx0T
WKHys2Ic4nZ58jC9z3PonQ4UWBHjsG++lP7dG3kOC123ff67JcYhnE9309z9
eQ7S+ndV2A7GOICoxo15DotA8nNiHLxB5gH5GRPf1ti3xkBoIP+bRkz/odgY
h1UfL/kmbchzEAU6u8oGod6Lh0m7XS4G4o5NeQ5A065U/Ix2AOo2jduW5yDX
+jpwx7doB3VDjjUyh6D2f4yG2HslzwHk3AOvoiH2vc1z8EsSiLB8Eu1wHGQB
Q75DLMhfp6Mh4cGfD/HfjmiIu2TzHZ5eULr98xhUv2q+QzGI8Rxqn1Y+1JwY
hzug8NXJh9hvGOOAHv4AioCw8w==
               "]], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4hl5Qs0H5PIcmg+cWujqF+OwyHXb578yeQ5c
1xcX2GbFOKz6eMk3SSXPYSFIvCXGYeuJsn3z9fIcRNa5P6zqgfKd8hwyJ76t
sZ8b43BB6fbPurA8h4dVQBULYxyKM4AS2XkQen6MQzVIY1Oew3Fv807HBTEO
t37WZe3pyHP4phHTf2hqjMO++VL6d4H8vSWTJVjqoO4B8uVaXwfuCIuBqOvM
c+idDnS4AUI92B9CMQ5hfLqb5rbnORjcVWFrfBvtwAACQHmQ8gOvoiHitXkO
IOfYP412KLQF+jQnz0EeZP69aAerLUAP+edB7L0TDXGvXZ7Dprnvlx87HO0A
cnaCIdR/G6MdXLpznv9WzIPYcwAqrwh1z6NoB2FQwCpCzfsTDXG3Qp6DtD7Q
IYYxDujhDwA/rLai
               "]], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{
                1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4,
                 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
                1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                262.832, 90.67999999999999}, {262.871, 89.73400000000001}, {
                262.97999999999996`, 88.977}, {263.543, 88.215}, {
                260.28099999999995`, 89.523}, {255.676, 88.824}, {
                252.52700000000002`, 87.35499999999999}, {251.125, 
                86.68799999999999}, {249.42600000000002`, 
                88.12499999999999}, {251.07, 89.48400000000001}, {253.414, 
                91.383}, {258.83599999999996`, 90.309}, {262.832, 
                90.67999999999999}}, {{216.82800000000003`, 90.73}, {216.875, 
                89.84}, {216.76999999999998`, 89.023}, {216.441, 
                88.24600000000001}, {219.98800000000003`, 
                89.71100000000001}, {223.79299999999998`, 88.492}, {227.375, 
                87.051}, {229.836, 86.031}, {230.035, 87.793}, {229.602, 
                88.402}, {228.85200000000003`, 89.48400000000001}, {227.406, 
                90.67199999999998}, {225.578, 90.699}, {224.359, 90.715}, {
                219.672, 90.758}, {216.82800000000003`, 
                90.73}}, CompressedData["
1:eJxdVGtIFFEUls0sSiTLomSxB2ZGhPlDzEr8Qq2sSKzmrrurJmbQzr7uloSZ
Wr4ICdGyKBIxs7RILKRErFRE7AGFWRZiZiYqlSWRFiZh93oGAgdmds+c13fO
991ZneLcf0Tn5uYWKW75u/BdFQ/PsOKKY3Feq86MB09PNFeYrHicVrrc3c+M
npe/DwyGWFFfPlbTMceMlgrfoD4fK3Z76jacbTZhXfD8Wn21iqPnv2VGDBkx
eLOsfZW/iqyIkKQmbyMCPHIuRT60wCL99njyX7RgIMOnbud6zbZZUKs3pW69
a0BSU4ynbolWL8SAgq9xjX4rVByUgZsMOCXSBi6oiJH93zK4yeuj5u9kOC4T
p1W8WtM7md3FUNI2EZggbJmWkcYQ1OfvkTOpYq3EZWZ4sie0cPuoquFhNO+E
SvMvY4SnV7OHFbJbVPhJYA0Kvf+gouHn3zfpJxXCM67ikIyrUhB1zjYyFWdF
XuvzyugdDF0S1xcrfgUmFLf1Kdgr2idn2cifrdA+rtmQKPOtCgxeG+vL+20o
uiwI4lp/Yc/g7pzl36zNN9eOBZLXXAZXuPint6MyWiDMZxQXb6d8zojPMw7C
b2HU/70DW+4LIZxmkGHJ3k7CW8TAZT0fJ839XSF+gp0Y7hSD1SkQ06mPopzE
X4FCfUqcIJ1p87U7MS2vGoXilnLifx6DePbHHv5vz9TP49iXsig+rFZBd/rn
gOASTnzmK8TzVU59bygQqJhXKSe9vVBoH4VavDvDLkm0sEnfDPaRqds/8jky
pV5jGK7LPaVz2v8dRvVzOZ2PNkb1i7X4ZwxSXsV6F/kXG6h+jIvOy2sD+mPF
xv1cpC9XPMUPc03fRshn0i1O+/ljhNj2UOcxTudnwIRGKbRUbR8rzagW67tn
4giT/ISaqf42rvFuJv21Omn+RBPpq9tBc3wyEq9jduK7x0jn19dO/HYb0SH5
GrdiVKy9oMyE2d+Hf6Gf21o=
                "]}]}, 
             {FaceForm[{RGBColor[0.741176, 0.41960800000000004`, 0.], Opacity[
              1.]}], FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1,
                 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
                1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}}}, {CompressedData["
1:eJxdUl1IVGEQXZbUKJOIHiTDVCoEsdUHkUV0j0WILSn9sH73Q9Iszd3b6nct
wmR7iIooaEUi+iMMonyRkAgpoU0k/CkoH5J+VGRZLSS1B6Mo0fpm50LRhcvc
YWbOnDnnZtY17693OhyOXP1SvN604Vz/QYWKuvXCPS0hjxZNVe5V6F1cftsa
lShZ8+6e2q0w6C28VPpeIqOnpbHDo3CisWM+9EbiBs3fasan0azxnzskIp2b
XJPDTdhy4cu+JxEDNF68EOT+5wbXU4MYIrx+AxRq3cfxPbu6faBAwiqmCZNx
P0rQmKfexMaHZdE2zS92//aLDGGipq882RmT2Fk7M5rlNVFJ/Ccknp28mrqq
xGS8MQmikZ5v8j0jEorws01E2zTiU8m8XgU4/jbwePhUpLMhgK2JZ6/t8hpY
S/x/+bneJfDh9Y8DsVk/9iQ7cy6GBfOd8/P9FQKlxCcpwPhugc0k6D95mASf
COAKxbtVcNDTbbL+532s14qtV7sP+hpfSo6ydfYhb5KYKdavpwpx/77ZfrgE
XFRfUjjjKTjUp/cthPSH00IaFcoFMsm/BIv5HBasT5IFP+kcFOyvzk/Pbs9f
HRKYp/lEi/dctvv1fFzPm4J5afwZuv+B3b+i2IdegZTcR3e+Lv/N43oMKaQT
UIPB94cVdFfX4KKBddR/TPG+lxJlRPSIwjbyQ/s91qqJVSt0E9Bnif//3z91
0Dt+
                "], CompressedData["
1:eJxTTMoPSmViYGDQBmIQ3fo6cIdcaIHD3pLJEiznohyEmg+cWhhd4NA7PU+o
+UKUw6GvGjH9CQUOIuvcH1adiXIAq0+Gqt8X5fDpkm+SQFeBQ629adyuh5EO
S2cfUdhwpMBh09z3y48FRzrslAPq+FXg4JckEGG5JMLhasVLNcN/BQ5rZKJS
rKdHODCAQSFEfXeEwwygtQeAfDDdFOGgf1eFrZGxEGJ+ZYQDUNd9fyAf5IzW
4giHHSDzgerB5udEONz3B7ocaP43oLMPxUY4dDomPL3wA2qfP9T8T1D3u0VA
3DepwCFj4tsa+6PhEPdpFTg8rAL6eGOYA9f1xQW2/3Ih6peFOVxUuv2zbl02
xJxZUPlHWRB3bg13kAU5kDvLoRhkINA+cDj+yITw4yMcuEHqf2U6xO7y5GHq
hvkvC2L+tAgInZfl4NKd8/y3ZaTDY1CAXslyeHYBaPG7SIh6w2yI+1ZGOYC8
dd88G2p/lIO6IccaGadsh+Pe5p2OB6IcDEDivtkQc49FOdz6WZe1JyIbEt6n
oxz2z5fSv5uS7XAbJA6M30JboI9yEOqBoWIaZ5YDMU8hCiIulutwDMRfEQkx
/20uxH/LIyH2n8pzAAXrjmVQ/rx8iHqJKAeFDUUZEx2h4bszChLu7gUO2z7/
vVJxMMphy4myffP9ChyApk51Pg1Nb0jpEwCygSyW
                "]}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4gJbruuLf2Q5qLE1TnXuznGoElnn/vBblsNF
pds/69blOBjcVWFr1M12yJj4tsZ+Y46DKkiderYDUDZrTwOUL5/tcMzbvNPR
JccBRCXMzHZwSnh6QWl1tkMRSOPibIc7IPU+2Q7vauxN41ZlQ8zlzXZ4C+LX
ZTuoG3KskbmW5TAjT6j5QFC2Qyif7qa5m7McfEDmyWY7cF9fXGDbBXXn6SwH
2agU6/v9WQ7750vp312S5RAGUr88y0G4+cCphb1ZEHt2ZTn0TgcaWAHl/8py
uHnue/DjziwHyy0nyvYJZzswgMCELIfjIIfLZEPMXZ3l8E0jpv/Q1iyH1teB
O+ReZkHcty3LoQ9knk22A0j7fCAfrL8hG+LOr9Bwa4KGFzDcwOHZlg0R74P6
E+iOVR8v+SZp5Dighz8AGsWr8g==
               "]], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{223.39100000000002`,
                220.84}, {223.824, 221.148}, {224.512, 219.805}, {
               224.02700000000002`, 219.469}, {223.621, 
               219.19899999999998`}, {222.83200000000002`, 220.465}, {
               223.39100000000002`, 220.84}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{224.55100000000002`, 223.566}, {224.336, 223.461}, {
               223.90200000000002`, 223.61299999999997`}, {224.031, 
               223.797}, {224.641, 224.668}, {225.941, 225.98000000000002`}, {
               226.883, 226.43800000000002`}, {227.172, 226.578}, {227.68, 
               226.066}, {227.504, 225.816}, {226.93800000000002`, 225.012}, {
               225.566, 224.062}, {224.55100000000002`, 223.566}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{234.625, 231.559}, {234.86700000000002`, 232.066}, {
               236.316, 232.637}, {236.68800000000002`, 232.977}, {237.031, 
               233.32800000000003`}, {237.191, 232.68}, {237.047, 232.375}, {
               236.805, 231.871}, {235.55100000000002`, 231.02}, {235.004, 
               230.996}, {234.707, 230.984}, {234.477, 231.254}, {234.625, 
               231.559}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{238.07, 231.39800000000002`}, {238.38700000000003`, 
               232.285}, {239.40200000000002`, 233.629}, {240.098, 234.07}, {
               240.45700000000002`, 234.297}, {241.102, 234.121}, {
               240.98000000000002`, 233.781}, {240.71099999999998`, 
               233.02700000000002`}, {239.47299999999998`, 
               231.71499999999997`}, {238.637, 231.098}, {238.383, 230.871}, {
               238., 231.195}, {238.07, 231.39800000000002`}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{235.121, 229.184}, {234.91, 229.078}, {235.023, 
               228.63299999999998`}, {235.227, 228.562}, {235.656, 228.418}, {
               236.441, 228.39100000000002`}, {236.797, 228.586}, {237.312, 
               228.906}, {237.078, 230.863}, {236.38700000000003`, 229.816}, {
               235.92200000000003`, 229.172}, {235.586, 229.379}, {235.121, 
               229.184}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}}}, {{{229.289, 224.68800000000002`}, {
               228.23399999999998`, 225.508}, {229.57, 226.66}, {230.672, 
               225.85500000000002`}, {232.82000000000002`, 224.238}, {
               227.47299999999998`, 218.035}, {224.562, 
               215.13299999999998`}, {224.02700000000002`, 214.566}, {223.562,
                215.996}, {224.242, 216.61299999999997`}, {
               226.33200000000002`, 218.383}, {228.285, 220.496}, {229.641, 
               222.68}, {229.90200000000002`, 223.102}, {230.15200000000002`, 
               224.008}, {229.289, 224.68800000000002`}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, CompressedData["
1:eJxNUl9I1EEQPq+4QqSgfBAzKbGSQlRQJEL87IiI6qHCAhERKYh2ZtSMHvII
vOgoMCSkf2QdFWdRcQ+hEVFymGD0EFIPJSVxiC+KhR0mQVG7N0v0g2V3fzP7
fTPfNxvb2g8eWxYIBHLs2mZX0K7pxM2xDZWCTz/PnniRIjxceLe/rVow+Xbp
0PQk4eTxy/ORFYLxvbUXG2x86PXpkXhIsPZc6s2dNCH3w72OOnvfFOq5Es4Q
Dq8qf3KrVnDE7X8IjxzePsFmF58jzWsXFDUd3fFlnHB+7sCz4kZBto5eQsvz
PXnBdaJ1XCAMO75ZVp4YaV03GI0OP0zYUrXycdEgY42rp4YUZ4j1fSnhR1lz
32iVYCReWDFVQLguNvOM/Itn67gvyrOVMB+pr2m5LcoX9Hgdgs9On18GfaOL
Zc1h0T6XDLrzk7vTxaJ92ni2n0XWPr8ZrHf4rxhOxvq0Ufwko6F1ZqIkbrDT
7f2MiRLrQMzg7q6nmd+9vt+oQWedPUVY6xjwfFFWHRJG311l9W/M6P9hVt6M
waVrtuGPDGdfa4736yurbrnenwFW3jwfj3r98gmVU6WhHmbVp9DPQ5fPryZ0
uXs3Y7sbDOvHy1P9BctjPr/J+/2eEXDfA6/vd4YrKzVIOierBRWOJ0GqU7ko
TtLr/998/gXD6ULx
               "]], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{245.566, 229.816}, {246.023, 230.21499999999997`}, {
               246.254, 230.88700000000003`}, {246.73, 231.29299999999998`}, {
               246.99200000000002`, 231.555}, {247.406, 231.242}, {247.34, 
               230.61299999999997`}, {247.281, 230.11299999999997`}, {
               246.61299999999997`, 229.68800000000002`}, {246.164, 
               229.312}, {245.80100000000002`, 229.039}, {245.375, 229.629}, {
               245.566, 229.816}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{250.742, 231.656}, {
               251.418, 231.73}, {251.586, 230.42600000000002`}, {250.848, 
               230.21499999999997`}, {250.40200000000002`, 230.066}, {250.008,
                231.578}, {250.742, 231.656}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIxIGYC4oyJb2vsFfMdGECgJMdhkeu2z38VoPyAHIet
J8r2zTfKd+g/9FUjJjjHoXd6nlBzSL5DgS3X9cUhOQ4+5p2OCaX5Dt80YvoP
heY4AEULbCflO1huAWoEqlc35FgjA+Q/Xjr7iALQfJfunOe/J+Y73Dz3Pfjx
1ByHYpAD6vMdVNkapzpvhqqvyndY/fGSb9IchPlVIuvcH7blOOjfVWFrLMx3
COXT3TQ3GerelHyHuF2ePEzFOQ5g/0RC7WvIgdgTC5VvznEQbj5waqFnPsTc
3BwHoGrTOLt8iLmJOQ6trwN3yNlC3VMMlTfLh/irDqrfMN9h/3wp/bstUPuA
4Qd2RwWCDwtPADINlWE=
               "]], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 
               3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxNU2tIlEEU3d22LVqTLfwR0dOsllIkUiJDOrVFaRqk0A8zWaXt4f2Y2exB
UQgS/hARi5KCCCsr6EFhmJSamURFRIVE2yYisvQuwiJjiahv9l6rD4aPmbn3
3HPPuTO7QheFxjgcDqe9cuzlstf2I58PLs9W2Jk7IdLSRaj9uOHmjAzF/wZC
2JxnKfSl9ser8wl3mqdmDhQojPhLG3vzCGUdeUkuUngVr67sWktI4F2U+1bC
cTX5UM99hQfrltSteEe4NNxXWPFSoe3h3u5mj8X3IwrTS7YsG/RamL9o/JVp
HxRi50/em/WJsNngRxTmeWqaAp3Cx86/YfKLCJkDaZ6a95K/mPj8q0Jj73d/
6RxCgV02mK2xMvj6WWqAmAc0x5UQ5xVrxqmVfUBzneeEE4Zfvua+3cJvvUaD
IZ5mMS4J/kKLcXZo7n+ixX1u1axLlPi8XKPb4O0TfiHNehcSNiZnXD+1TcNh
vizCLpN4TeNAytU1Q8mid6fm/ybx667s6wnRJz+KY1ENb6QlnNsh+1sah40e
Xwi3dx+d4r4g/H2W6Ktx2fiSZDHPYcEbFD2cYfajR/gP6b/zkYiLadgqPToT
Evw30p9f/G/XMFNW5iGue0zixwq/PRpnV7d/++WWfbn4s4Bkrkb1lflLl/h0
8dOnmefvSuYfVzDHQSexjqcVqszFOMJcM0dPFVbVW29/1hH31aZY51H9mhT7
YveX8LtKIccY6f03/4k59kl9v0K/4Zki8S7B3y/zOUnuz0n9mfLeHhPzXKpY
txfyfv57j38AmbmZ6A==
               "]], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJVIGYCYh/zTseEp/kO3NcXF9h25TjcPPc9+PHOfIfb
P+uy9izJcXi8dPYRhRf5EPGXOQ5g9X/zHYSbD5xaeDHHIWPi2xp74QKHVR8v
+SYtyHFgAAGNAodikIR2jsN9/97peWYFEP2KOQ5CIH32BQ5WW06U7ZPOcSjf
N19KH8g/7g00uCLHweNhlcg61wIHLpB7FuU4yEalWN/3LHAASScczHEAaZsf
U+CgytY41Xl7jsNkCZYwvsgChwmHvmrE9Oc4aLWL3TwXXuCgbsixRqYpx+GC
EtAnDgUOcbs8eZheZzvslGt9HehU4AAkd8g9zXZ4AHJfUIEDkBRqXgLlJ0HV
J2dD9OcUOHwDmn5INtthGTA4NhQUQNz1P8sBpO1AXAHE3yLZcPeB7ZfKhvgv
sMBhNSh8bLIh9tpC3bsfwQf7b2c2xFzjAki4xmZDwsmwwMGlO+f5b8dsB17d
TXPfqxc4WILEP2c55D7/vfKjSoHDDJA7bmU5XAS5VwgaPvezHEDRt0EMah83
1P1S0PDXz4aEnyk0vB9lOyhsKMqYCLS/COSA59kOHcDUcUGuAJIeDKDxwV3g
sBXkzyxoekBKPwAl7Amg
               "]], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIxIGZigAKpAoeMiW9r7B9mOfDpbpr7XrjAYeuJsn3z
H2U5XFS6/bOOq8CB6/riAttjWQ4z8oSaD2gUODglPL2gtDvLofV14A65wAKH
vulAiTVZDt7mnY4JtQUOlluABhzPcqgWWef+sKvAIXaXJw+TeLbDA//e6Xmz
oPaVZjssnX1EYcMSqH3nsh1AxhxYU+Cw6uMl36QP2Q5VIP3bChzCQA4Tz3GQ
jUqxvn+4wKEXpFAkx2GnHNAFuwocbp77HvzYN8dBYUNRxsTNBQ6OIPeV5zjk
PP+98uMyqPlZOQ47QOqB9hXYAn0UkgNxx1yofRI5EPc1FTh804jpPxSa7fAJ
KCxQVeDg0g00yTAbYl9WgUMhSP8HaPh4FUDcfS3LAT08AU9cpAo=
               "]], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}}}, {{{262.68, 224.742}, {262.40999999999997`, 
               225.324}, {261.777, 224.875}, {261.89099999999996`, 224.242}, {
               261.957, 223.668}, {262.42599999999993`, 
               223.35500000000002`}, {262.89099999999996`, 223.371}, {263.445,
                223.39100000000002`}, {264.617, 223.35200000000003`}, {
               264.617, 224.27299999999997`}, {264.621, 224.918}, {264.113, 
               225.45700000000002`}, {263.734, 224.742}, {263.375, 224.098}, {
               262.914, 224.168}, {262.68, 224.742}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{263.312, 227.176}, {263.117, 227.04299999999998`}, {
               263.29299999999995`, 226.324}, {263.52299999999997`, 
               226.33200000000002`}, {264.348, 226.359}, {265.51599999999996`,
                226.621}, {266.14500000000004`, 227.059}, {266.328, 
               227.184}, {266.25, 227.617}, {265.98799999999994`, 
               227.60899999999998`}, {265.195, 227.58200000000002`}, {
               263.92999999999995`, 227.605}, {263.312, 227.176}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{270.32, 225.36700000000002`}, {270.91799999999995`, 
               226.30100000000002`}, {272.566, 226.395}, {271.97299999999996`,
                225.062}, {271.555, 224.14499999999998`}, {267.449, 
               216.21899999999997`}, {266.89099999999996`, 
               215.21099999999998`}, {266.28099999999995`, 214.078}, {
               265.78099999999995`, 214.641}, {266.215, 215.523}, {
               266.79699999999997`, 216.656}, {270.133, 225.094}, {270.32, 
               225.36700000000002`}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIlIGYC4p1yra8Dmwoc1A051shsynLQv6vC1lhf4PC2
xt407liWg0xUivX9/AKHY97mnY5PshyEmw+cWlhY4MB1fXGB7bosh+l5Qs0H
SgocjoPkfbIcPl3yTRLYUeDglPD0glJ2lsN9/97peWcKHPaWTJZg6ctyyHn+
e+XHewUO1SLr3B8C9VeB6HMFDhMOfdWIkYfa/7zAgQEEBLIcFrlu+/z3S4FD
P0iePcvhgtLtn3V8hRD7dLIcgKaG8UkXOuyfL6V/F2i/drvYzXO2hQ6OIPuX
Zznw6W6a+z640KEX5FCNbAeQtoTSQog9jdkQ9zYVOqz6CGQsyYaYn1fokDER
GAJ7sx1A1vanQdUvzIbQnoUQ9zlAzVMthLizAmrf3wKIftcsB6stJ8r23S1w
eLx09hEFmSwHUHD6A/3HDQq/qiyHqxUv1QyfFUDsnQYNzycFDmpsjVOdV2dB
9N0ocLh57nvw45NZEHOPFzh8Azrr0FpoeO2Ght/sLIfyfcCAWFngsBrkn54s
iPtnQOX7oeHfVwAJjwlZDh2ggGqDug/IR08PAAHY+B0=
               "]], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{271.656, 
               219.258}, {271.68, 219.43}, {270.76599999999996`, 219.508}, {
               270.812, 218.621}, {270.84400000000005`, 217.969}, {271.625, 
               217.789}, {271.762, 217.883}, {272.99199999999996`, 218.781}, {
               271.5, 218.33200000000002`}, {271.656, 219.258}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{269.863, 215.664}, {269.621, 215.605}, {
               269.39799999999997`, 214.83200000000002`}, {269.969, 
               214.789}, {270.49199999999996`, 214.75}, {272.539, 
               214.97299999999998`}, {273.105, 214.93800000000002`}, {
               273.47299999999996`, 214.953}, {273.613, 
               215.65200000000002`}, {272.828, 215.61299999999997`}, {271.875,
                215.566}, {270.625, 215.805}, {269.863, 215.664}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {
                1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}}}, {{{220.297, 228.99200000000002`}, {220.621, 228.977}, {
                221.512, 227.824}, {221.453, 227.461}, {221.414, 
                227.29299999999998`}, {220.5, 227.48800000000003`}, {
                220.22299999999998`, 227.72299999999998`}, {220.016, 
                227.89800000000002`}, {220.098, 229.}, {220.297, 
                228.99200000000002`}}, CompressedData["
1:eJxNU1tIVFEUncSGEPGjhCIsSrL8CQsKiZCW9LCoPsrqIyYbpYF07+ldHzVI
JgZRqb3ohYjJQEgUlA7TMM6IFJaE6UQMZhIx2IMQiqiICLpnzqrpwuWwz95n
r7XXOmd+zf6tviyXy1Xq/Ga1nyAVvPlo3mVB75FLs7Lf1dn1NPezBaNDPypT
tYIdeYvvt80UfC/2tPQfFcTbZ5eMewVNn7aE5wYFJ/LvVrwdEuyKbMjNSrJu
QnBrbejr72Vq6yYFYz/r66LbFNf2TW/sy1GUjC9wNzQpjpvzCxVdXxKba1oV
a87q+1/lavveUGwsPVPurVW09n8r9uxWVBmcRkVOsvNAWbNi0dJpdwouqsW7
rZbHgOJgmVMRUKzofnIs9oJ9riuK3A1XVqcUaRmiijk796x8M8a+zxXNVx2C
rxUD5sBn4jr5tD5uv+U/yLpcxjHF3guTgVUfFefNfph4o+wfZ/4p54+o1bGP
84cUPQ7N9gjzXezTrdhu9O9Uq+tD9mljfYz7HeT7LKNHWp+EWj/P8dxLxUih
48Qp6pJkXT31GCZfUZR7J4YL7ylmONN2VJOP40+ByVcoWowuDzjHEvo5Qr+L
GE/1W1/zFQ768qoY8fLIJ0jcD7wfJ//2ycSbjI49mTite1T++ZDWoV5w2DSM
895UCV6Z+jD5VIvFCVAvn1gcH+fzi+W1TpEw+gyKvT8ete/gsVh91/MehMT6
O0VxyOBW8r30Eue/9/UH4cqIfA==
                "]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{197.84, 
               210.062}, {197.71499999999997`, 209.691}, {198.21099999999998`,
                208.68800000000002`}, {198.72299999999998`, 
               208.61299999999997`}, {199.22299999999998`, 
               208.57399999999998`}, {199.48000000000002`, 
               209.69899999999998`}, {199.316, 210.062}, {199.19899999999998`,
                210.33200000000002`}, {197.93, 210.32800000000003`}, {197.84, 
               210.062}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 
               3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxdU1tIVFEUnaaS6EFZfoSIlVgaRCokQ5m4zB6kVqQQUpNMNoJ7T6Q98KMk
GKwkpKzsScX0oB8NIUmT6CFSk0TEJESFDSZaQ4hCRElE1Dl37wq6cLicc9fZ
e621111QUV1SOdHlck0wy2OW26yhm5cez59FODKyuSv5CeHti/HSocmEp0We
Y/kRwt6qU6N1sSqM1uVll7cTXM5DKDaffVcI39K9TT0zCFNf36jJPU1o+dy3
oQKE1Y27Yj+ChLSsKbeSNhLm1Hc/u3aR8CiUmBH1EZK2+nMG7hJW3OmtfZij
uEUMh08xoSbXVFzGuL6m88vPMu0LxvHzu2fXnyGU31s/3T2ifW5r3WHCdns+
TjjZ8zXd20/C+yNhle9DJGUbCy6T8TKl//uhEhZ9O1l4FLH4QCz4Rpb6Oxgd
5nOondFq9XlZ+L1hHExoWzeYzNJvZkBwbhZ9aQFkRlPjglHCAYtbG5D+z9Xv
+ADC1udh5fuLxUdzv8nuY4x8y8PDsLK7Oxn7LN88hqUbOqf8C/TdwLhgcYkM
B0aqaxojw/LYo+efdE6H1d9ekvNXer+FsNzei6nfVwkP9jfPnTSmfBp0bgPK
s5kQsX6GtZ7BOzxbWfIR1fkHtf8gwaD5vl/rG/1jdk6Fqj9Mwjee/+buz/6E
xV/+t3f89Gv+tqgPpST+1Op8CjVfRxnvbN8lmi+j3+G1mLAwLni2oFrnmkqi
c5PyWar5MT46/0c2ic73msuVuu/SOc7THJp8//9//QaSPJEf
               "]], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}}}, {{{197.24599999999998`, 213.016}, {196.977, 
               212.71099999999998`}, {197.883, 212.10899999999998`}, {198.062,
                212.266}, {198.41, 212.566}, {199.766, 214.10899999999998`}, {
               199.504, 214.648}, {199.26999999999998`, 
               215.13299999999998`}, {197.41, 216.184}, {197.105, 215.664}, {
               196.54299999999998`, 214.762}, {198.859, 
               214.35500000000002`}, {198.5, 214.09}, {198.32000000000002`, 
               213.98800000000003`}, {197.684, 213.547}, {197.24599999999998`,
                213.016}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{200.586, 219.785}, {
               200.586, 219.785}, {201.168, 217.79299999999998`}, {201.641, 
               218.621}, {202.023, 219.19899999999998`}, {200.586, 219.785}, {
               200.586, 219.785}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIZIGYC4tbXgTvkDDMdLLecKNsnnO3wrsbeNE4r04EB
BASyHRwTnl5QEs90uP2zLmsPQ7ZDKJ/uprnKmQ4FtlzXF//Icug/9FUjxjzT
YZHrts9/32Q5ZEx8W2OfCzXvcZaDcPOBUwsTMx1cunOe/+bMdrikBDQpKtOh
d3qeULNCtsMMIHVgU6aDt3mnYwJQHqx/bqbDW5A73LIdwkD2Tc90UGVrnOoc
ng2xpybTIRwknp8NcWdBpoMTyJ3FUPXpmRBzSrMdJoDc553p8E0jpv9QarYD
2L+xUPnYbIi7MjMdQM6dH5btsH++lP7dCZkOViAB+2yHiyD3NkH9bwBVXwj1
L9D9YH1pUP+aZzuoG3KskQnKdHi8dPYRBZNsB5moFOv77pkQcaNsh60g9X6Z
EHtEsh1ugcz1gJrHk+2gf1eFrdEVGj4c2Q4g6oBZJoQWg7ofKb4A4TzGsw==

               "]], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{205.92200000000003`, 224.184}, {205.57, 224.012}, {
               204.94899999999998`, 223.066}, {204.92600000000002`, 
               222.63299999999998`}, {204.914, 222.39800000000002`}, {205.168,
                222.078}, {205.36700000000002`, 222.176}, {
               205.73399999999998`, 222.359}, {206.297, 223.254}, {206.316, 
               223.664}, {206.33200000000002`, 223.92200000000003`}, {206.137,
                224.29299999999998`}, {205.92200000000003`, 224.184}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{208.191, 224.434}, {207.52, 225.254}, {208.906, 
               226.47299999999998`}, {209.52700000000002`, 
               224.82800000000003`}, {209.906, 223.797}, {213.918, 218.516}, {
               214.738, 216.72299999999998`}, {215.32000000000002`, 
               215.512}, {214.71899999999997`, 215.008}, {214., 215.879}, {
               211.969, 218.47299999999998`}, {210.30100000000002`, 
               221.70299999999997`}, {208.191, 224.434}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}}}, {{{212.312, 224.32000000000002`}, {
               213.02700000000002`, 225.094}, {214.48800000000003`, 226.68}, {
               214.094, 227.562}, {213.79299999999998`, 228.324}, {212.906, 
               228.24599999999998`}, {212.754, 228.07}, {211.88700000000003`, 
               227.035}, {213.371, 227.29299999999998`}, {213.156, 226.941}, {
               212.71499999999997`, 226.10899999999998`}, {
               212.27299999999997`, 225.65200000000002`}, {212.047, 
               224.85500000000002`}, {211.99200000000002`, 224.668}, {212.184,
                224.18}, {212.312, 224.32000000000002`}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{274.53499999999997`, 221.727}, {274.02299999999997`, 
               222.14499999999998`}, {275.043, 224.164}, {275.72999999999996`,
                223.371}, {277.625, 221.18}, {278.508, 214.062}, {279.055, 
               208.73399999999998`}, {279.055, 208.73399999999998`}, {278.203,
                208.02700000000002`}, {278.195, 208.137}, {278.195, 
               210.977}, {277.055, 219.656}, {274.53499999999997`, 
               221.727}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJ5IGYC4m8aMf2HGHMdFrlu+/x3So4D1/XFBbbvchxc
unOe/z6Y46DK1jjVWT7XYUaeUPOBSzkOF5Ru/6xTy3XYeqJs3/xNOQ4FtkAd
HlC+XI6DuiHHGplZuQ4XQerWZTsc9zbvdLyR63Dz3Pfgx57ZDnG7PHmYXuc6
vKuxN43TynZgAIE7uQ5hfLqb5opnQ/XlQsw1garvz4WY65Xt4Jjw9IJSfq7D
vvlS+ndnZDuEg/TF5zrIRqVY35+d7RAK4jvnOrS+DtwhtzDboRBkDkOuw+Ol
s48oyGQ7FGVMfFtTDnWnE9T+kBwI7ZPt8BbkrrAcB/27KmyNW7MdgL4+tTA0
B6L/STaEBqoH++cn1H85OQ5WW4AB8D8bYm8uVP4h1Ly8HIdYkD+2Z0PCGage
HO6xUPuX5EDCNyrbAej7rD0XciDmRkDlTXIh7p4O1e8Bja8T2ZBwi86FqPuT
DbFHHOr/RKg9SPELAHwZ1xg=
               "]], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{275.688, 209.297}, {276.03099999999995`, 210.25}, {
               280.578, 217.883}, {281.176, 219.562}, {281.47999999999996`, 
               220.375}, {282.789, 218.176}, {281.512, 216.98800000000003`}, {
               280.395, 215.98000000000002`}, {277.09, 210.562}, {
               276.47299999999996`, 208.66}, {276.188, 207.805}, {275.328, 
               208.21099999999998`}, {275.688, 209.297}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4g7HhKcXthU6vK2xN40TynY45m3e6Xik0AEk
rFSe7TA9T6j5wJNCh2qRde4PmbIdHi+dfUThRKGD/l0VtsaTWQ5a7WI3z82G
yhdlOVxQuv2zrq/QIWMi0MSzmRDzPAodVn285Ju0JdMhKsX6vr9pocNxkPia
TAcGEBApdPABchOOZkLM5yp0KAIZcDnTYYdc6+tAtkKHffOl9O/eyHTYcqJs
33yeQof9IP6fTIh9EoUOEw591Yh5nemgsAGoU7PQodCW6/riC5kOuc9/r/zo
U+iwFaTvFFQ+vtBhkeu2z39fZEL80V7ooMrWONXZPAvinhWFDnG7PHmY5mc5
wMLnIsgeYPgAAIpRiv0=
               "]], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIxIGYCYnVDjjUyu3IdjnubdzqeyXSw3HKibN/mXIdF
rts+/z2S6bDq4yXfpAW5DlzXFxfYHst02AqUnj8v14EBBPZkOjgmPL2gND3X
AWzONIR8tcg694dNmQ5va+xN46blQug4KL8v16E4Y+LbGutMiL4yqH4rqP3l
uQ4gan5YpoNLd87z35VQ9dVQ98zIdQjn0900d30m1J5cB1W2xqnOmzMdCmyB
Li2B6t+W6aB/V4WtMTPX4ZtGTP+hk1D9FVD1lzMdjoH8PQWq/lkmRHxxrkMo
yPzHmQ4XlG7/rNsG1X830wHkDPu9uQ5WIA23ofbvy3W4ee578OOLUP8ghScA
Tmyjwg==
               "]], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}}}, CompressedData["
1:eJxdUksohFEUHo8skIUUeYW8IsZGEsYnC4kUitJ4JMr5uxflsfCYmkhZCHlN
iVlo2MjCa6EwSZEibCw0IRsbrChN5L/OXbl1Fvc793zn+865ye09dZ1BFosl
wIwUMwLNeB0pzW9Zl/jMtE+ffBOqCibL2pwSXbNmxkdoOagMD2yVsKhzTTh2
x1p9xRLNCt8gDEdtVTzlSoTerfWWLBLSQpwL5VbJuIP4XYaE1Zca4iTC3vng
kTtRwtUdOeatIxTumkCQrq8h9KnGfsF96wl5qu5V4NmzfJpkJzRG5GyvvAt+
P0Gs61Ew3qP13ArmbyK8KX8XAof9czHBNsKQyu/revP+59MjWJdN843r+nbt
d15gaskEOgg3KfdfjivBvAbx3C513kWYPvnItD8L9rFMaFC6/JpvVff7FqhW
cx4g9hWu5z9KiG/qKHqIljyXMe0/QSJB4TuEMKU7S7Iur+arlThS9xfCmVpg
r2S/P5rfJZGu9hJncH5TYkbpzDbY94HE3z+IMPD/P/wCd4HqJA==
               "]], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJVIGYCYuHmA6cW6uY56N9VYWtszHSQjUqxvs+f51Cc
MfFtTXWmwyLXbZ//iuQ5+Jh3OiaEZjqA1cvmORTacl1fHJDpwAACOnkOLt05
z397ZjoARQtsnfIcHBOeXlByz3TYeqJs33yvPIe4XZ48TMWZDheVbv+s88uD
mNuSCdEXCLVfMhNCV+Y5VIusc3/olOlw3Bto8YQ8iD0xmQ690/OEmk/kObyt
sTeNs8t0eLx09hGFB3kON899D34cC3XvB4R96oYca2S+5UHc3QiVf5HnAHRF
1p4FmQ6trwN3yD3Ng6hbBVV/DuqepZkOEw591Yg5nwfxRx/U/gt5DmpsjVOd
q6HhcTDPoR+kLjkT4q51eQ5FoPBLh9q3JM8BxLXPzHQI5dPdNHdzngPImAPT
Mh24QeG1Ks/BCRReixHqwf5ZCXXf3DwIvRIa3jOg7l2UCfEHMHzA4TQj00EV
5K750PjJyYS4qz3PoQoUnmmZDiBlCZl5kHiOh5oPDG9wOALjY/XHS75JOVD/
dmVC/OGcBwmH+ZmQdGEPTQ+tUP8jpR8ATgcJtg==
               "]], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIxIGYC4oyJb2vsRfMdZuQJNR84lekQt8uTh0k732H/
fCn9uxcyHY55m3c6qiD4QNWmcW5Q/ptMB8stJ8r2Bec7xIL0fYfKh+U76N9V
YWu8memwyHXb578h+Q7fNGL6D53NdLiodPtnXVC+w81z34Mf78x0qBZZ5/7Q
Kt+BAQROZDqE8ulummuc73ABpG5bpsM+kD0a+Q5WIHvmZzqA3aubD3FndqaD
MNDVCzWh9oVmOqiyNU51Vs93uATS75UJEQf6b8Khrxox3pkOslEp1veF8x0e
L519RCEkE+JvvnyIu/MyHfpB6sSh7unIdABbK5bvcOtnXdaeFVD/AflgczZD
+Wz5Dj7AYEo4CnUfUngCADiJmEQ=
               "]], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{244.664, 208.434}, {244.5, 207.691}, {244.512, 
               207.08200000000002`}, {244.512, 206.57}, {244.55100000000002`, 
               206.16}, {245.30100000000002`, 206.42600000000002`}, {245.297, 
               206.477}, {245.262, 207.129}, {245.41, 208.02700000000002`}, {
               245.21499999999997`, 208.281}, {245.11299999999997`, 
               208.414}, {244.70299999999997`, 208.57}, {244.664, 208.434}}}],
               FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
               0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 
               3, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
               0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJlIGYC4mPe5p2OX3IdnBKeXlD6neVQLbLO/eG5XAfZ
qBTr+9lZDnG7PHmYZkP5pxF8/bsqbI2ZUL52rsPbGnvTuHdZDjfPfQ9+HAhV
H5/lkDERKPM2B6J+K9R8pVyH2z/rsvaEZDkcB9lfkOMgA1J/HKr/YQ7EPc5Q
84Oh+juzHEDKE3ZC5Y2zHML5dDfNPZ8N4XdD7duYA7FfOsvBcsuJsn3MuQ4F
tlzXF7tkQewtyXUwAJkXm+WwFSg9/xOCD9aXnwfng+19mOew6uMl3ySgfgYQ
MMmHmw8OPyDfCmSPNNR+03yHx0tnH1GQyXIQaj5waqEpQj3Q9U8vcBXA3Qvi
KunnQ8LPCOreyflw/15QArqYDarfGcovy4eHF9g9R/Lg4QnW9zMPHt7750vp
352SB48PML07Dx5fYL53nsMtkP6MLIi/ffPg8Q02RzIPnh4ACz7tng==
               "]], 
              FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGI5IGYC4q0nyvbN18t1EFnn/rBqTawDjN984NRC175Y
h+Pe5p2OOrkOXNcXF9gmxTpYbgEqUM91kNa/q8KmGevQ+jpwh5wsJp8BBAKg
+mVyHfaWTJZgyYt1eFdjbxonlesQv8uTh6k51qHAFmiyRK7DfxCYHuuQMfFt
jb0o1LyNsQ6Pl84+oiAA1X8u1kE2KsX6PneuA1C3dvuzWAdVtsapzuy5EPp3
LMSdTFD/8MRBzPub4/BNI6b/kGwcxH1fcxxu/6zL2mMS56BuyLFG5lWOw7bP
f69UBMY5TDj0VSPmf44DN8icXVD1nLkOD6uAJi6MQ3VPX5zDMZD/RHIdeqfn
CTU3xDnsmy+lf1cC6v5CqP3A8DAAchtj4xxAyhMUofrd4hyEQAGtmuvgBfKP
HlS/Ri7EvaJxDk4JTy8oaec6VL5UM+T4EwsxRxcaH48Q8QWOl+MIPiw+ATDa
x/g=
               "]], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 
               3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxlk19IVFEQxjcLoaiXjAhLrTDwbV8KqQi/xSSieiihKJqTWEJBo5FStJRh
i2wRaiZa0B81NSMlyHQrJZOltD8QGQsVISJSPURIRElE1Mw9xy7lhcPwu3fu
OfN9M2dZYcm2opmBQGCGrJWykmRdy4t9/ZVgdC7ZtW/tUYN/eIfB+rMHP/4c
dpxjkCZh9DmjdH/t5+NBg7cvJvPHHzvOMDb2MaIL5UuKwcPG1OBIJ+OAvM6Z
Z1D5aeu99Nsuf4IQ0KebMbgp+0zoDWGzhIIexuruJ0f6hwgXiudHBmKM9y+X
v/sRIxzW/+4yFtzaMBZu9XmN5tf4PCzp5acIoQL5cyq/jCBVrDKyX3AkM7mi
iCC7P2uW8zTkbSfc/PJqS6HU4+kOufwuRpUWkkXoVz03prP1hzCkOoT39G6c
m5RPII3tjBXJFfW5ewnfs3bXxNucP6VOfyuj68pE+2CEkKKFNDPmvG45tO48
2X40MR6U1S2a1UA2XnV8nWwdF53eONlz6lw9o2T7U+V40uWfZuSqvtnG5kdc
f9IMesTGxrDrT7bjYsZYWBzcaWBUz0nGHa23z9g+RZ3eFoNz8W+ikHFCbOut
dfNRz/itT9SgQ/29zMjQQSg3f/V7fh/z52WKvX4M+OzFp4wPOg/VPi/Wht53
+yWmc6bq7DAYb7v0aKmw977JWD+E07WeBnd+wvlb7d8HHdvKyH/3Q+7LH2aC
gDg=
               "]], 
              FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {
                1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, {CompressedData["

1:eJxTTMoPSmViYGDQBGIQffPc9+DHuXkOVltOlO3rj3XQv6vC1piY5/CwSmSd
u2aswzeNmP5DkXkOBiBx3ViH/kNfNWKC8xxq7U3jdlnGOlxUuv2zzi8Pos43
1uFdDVDCK8/Bi4dJuz0Oqt49z+F14A651uJYB6HmA6cWuuY5ZE58W2PfG+sg
G5Vifd85z0GuFahiWaxD3C5PHiZnqP0HEXzRde4Pq+7EOhTYcl1fbJHn8PQC
0OJrsQ6rPl7yTTLIc/BLEoiwvAK1XwvBfwviyyH4vdPzhJpF8hxmAKkDt2Id
CkHm8eQ5rJEBOuR5rMP++VL6d1nyHNrFgCHzOdZhkeu2z38ZoHzmODi/OAPo
AXEEH+xexzgHoGkFtmxQ/6RB5QXyHP6DQHscxL/SeQ4gZ+1aGefweOnsIwoa
eQ6XQOG4Kw4SPqYIPljeAcEvAtkLDE8RUHhsiXMI49PdNNc7zyEEpHAFVH1A
nsMbUHjPjoOEHzC+gLqz9vTEOTCAQEieQ+VLNUOOGqj7QqDxkx0Hif/QPAcg
OdXZG8EHmyeN4EuDGB9jHVRB6sKh4Xkp1mErMBnNj0LEn495p2NCLNT8zbEO
lqB0lpznEA9y1+JYB/T0BwCaCyN9
                "], {{241.98800000000003`, 
                120.91400000000002`}, {241.92200000000003`, 121.32}, {
                241.71099999999998`, 121.523}, {241.344, 121.523}, {
                241.18800000000002`, 121.523}, {241.04299999999998`, 
                121.48}, {240.914, 121.395}, {240.781, 121.309}, {
                240.71499999999997`, 121.23400000000001`}, {
                240.71499999999997`, 121.16799999999999`}, {
                240.71499999999997`, 120.953}, {240.97299999999998`, 
                120.848}, {241.484, 120.848}, {241.648, 120.848}, {241.816, 
                120.871}, {241.98800000000003`, 120.91400000000002`}}}], 
              FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJVIGYC4nA+3U1z+fMdtn3+e6ViZayD/l0VtkbOfIfb
P+uy9ujEOmRMfFtj/zfPYW/JZAkWu1gHl+6c578/5jkscgXqiIl1KAIpeJ7n
UGNvGrerM9bhDkjfnTyH3ul5Qs07Yh2+acT0H7qY5zADyD3wK9Zhy4myffOP
QeUD4iDm74Wa/y/Wwce80zFha57DwyqRde4HYx1U2RqnOq+H6p8V69D6OnCH
3Mo8B6Dsw6oSqPxiqPpIqHvnQvmeUP7MPAcvHibtdqD7q0EaJ+U5bJr7fvkx
41gHdUOONTJdeQ4hj5fOPqIR61AM0tCd58AAAgtiHUDOPDAtz0EeZPG+WIet
IPfPy3NoPnBqoes1hP2eIPOfQcNnJdS+f1DzgO7nvr64wFYqzkE2KsX6/mYo
3yrO4bg30MM78hwuKQFDPArK35MHiYdWqPr9eQ5vgN5u3R3n4JTw9ILSaQQf
7P5LeRB/AtXvmy+lf/cG1HygeRMOfdWIuY+wDxy+T/Mc/JMEIixl4hz6QB58
kweJf8Y4hwJbruuLv+Q5XAS551UsRN8vqP5bUP8yQ9PHkVgH9PQDAPNPDX8=

               "]]}, 
             {FaceForm[{RGBColor[0.74902, 0., 0.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1,
                 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}}, {{0, 2, 0}, {0, 1, 0}, {
                0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3,
                 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
                1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}}, {{1, 4,
                 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
                1, 3, 3}, {1, 3, 3}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1,
                 0}}, {{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1,
                 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {1, 3, 
                3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1,
                 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {
                0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}}, {{1, 4, 3}, {1, 3,
                 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {
                1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                0}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {
                0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {
                0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}}, {{0, 2, 0}, {1, 3,
                 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {
                1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                0}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
                1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                0}}}, {CompressedData["
1:eJxTTMoPSmViYGBQAWIQnfv898qPRQUOLt05z38LRjq0vg7cIVde4ODFw6Td
/i/CgQEEqgocVNgapzq/jnBwf1glsq66wKF3ep5Q840IB2/zTseE2gKHvSWT
JViORTgc+qoR019X4AAypnV1hEPGxLc19vUFDtL6d1XYOqHmlUHVt0H5QPsX
um77/HdJhMPVipdqhnkFDpkgfXsjHB74A23KKnCQBznsXISDwoaijInpBQ6V
QGUcdyIc4nZ58jAlFzg8u6B0++e7CIctJ8r2zY8pcLAEMdgjHY6BHBgGda9C
JETcH8q3gPrXs8DBCiweCbHPqcChGOTw9EgHPt1Nc99bFjjMACo/0BQJsV+/
wAHo2isVC6Hy2gUOIuuAIbMm0kG4+cCphZoFDn5JAhGWWyIh7tEocAh5vHT2
kR2RDuX75kvpq0PN3x/p8OmSb5KAWoHDIpD/z0DlVaHh9TDSARiKrwNVoOHz
Bep+5QIHkDWufFEQ9yhD7dOJgrjHGereQ5GQ8AwocLgEDJ66WZEOO0HmRRU4
PAWFVxmUn1Tg8B8EwiMdQMJ1GQUOx0Hh5gB1Xx7UPZqRDujpBQAOoQIS
                
                "], {{256., 104.609}, {255.879, 103.121}, {
                253.49200000000002`, 103.184}, {253.672, 104.703}, {256., 
                104.609}}, CompressedData["
1:eJxTTMoPSmViYGBQBmIQ/bbG3jQupcDBP0kgwrImwsGW6/riAs4CB4O7KmyN
vBEO3uadjgkf8x2cu3Oe/86McIhKsb7v717gANK262SEg+WWE2X7nKHq70Y4
LHLd9vmvQ4EDkDfV+XWEw2QJljA++wKH+F2ePEyfIxwYQMCmwGGNDNCk/xEO
h75qxPRbFDiEPF46+whHpAPIuPkmBQ7FGRPf1vBHOoDdB+TvLQGa9C/C4TBI
vVGBg3zr68Ad7yIcyvfNl9LXL3AA2nql4mGEg1a72M1z2gUOfiD/XIlw0Ae5
S73AAeQt21MRDlcrXqoZKhU4bJr7fvmxw1D90gUOqiD37obKixQ4cIPU74LK
8xY4HAcFxIEIh2Mgmq3AAegb7fZjEQ4gZ8gxFjjMyBNqPnApwiGMT3fT3N/5
Drd/1mXteRLh4AIKN2D4gf0D9O8dkPibfEh4KEdCwuMNVN4/0kENHG75EPsa
Ih1unvse/BioHxyucyIdPl3yTRJgKID4a2kkxH2c0PDbEOkg3Hzg1EJRqPuW
RTqAjLVXLXB4ekHp9s+2SIdqkXXuD2Hhmw7lA+OrdzrQAw5Q9Z7Q8BKChj9S
+gAAf3fwHg==
                "], CompressedData["
1:eJxTTMoPSmViYGCQBGIQfeirRky/XIGDFw+TdrtdpMNxb/NOR6kCh+YDpxa6
ukU6dDgmPL0gVuAQu8uTh8k70uEYSF6kwGGR67bPf30iHay2nCjbJ1jg8OyC
0u2ffpEOtlzXFxfwI/hRKdb3/XkLHPySBCIsgeqXzT6isIGrwOFhlcg6d89I
h2og9ZCjwEGVrXGqs3OkgwxIA3uBwyWg9jqrSIec579XfmQrcKi1N43bZRjp
0Po6cIccUB5o+5UKzUgHkPXzOaDmKUY6KGwoypjIWeBQ+VLNkEMm0qF833wp
fe4Ch97peULNEpEOIOcnAN3zFOQ+sUgHd5BGoHv176qwNYpGOny65JskIAT1
vxjUfBGofZJQvhjC/Lc1QIdJFEDCQT7SQbtd7OY5yQKHjIlAGVWofdLQ8NOO
dMgF+UcG6l/jSAf08AcA2MWlpw==
                "], {{251.82000000000002`, 
                102.141}, {251.47299999999998`, 100.664}, {249.105, 
                100.883}, {249.465, 102.371}, {251.82000000000002`, 
                102.141}}, CompressedData["
1:eJxNU2tIFGEUXZaQkojQCiGzEsP+SPkjw0Q7VtLDXqY4N5PNVrMU624WJibC
IhISIZFREGIW0o8syuxJxaJhEVH2kLRVwiRDJUIqRULsuzMXbGCYGe537zn3
nDPLvbznoNvlcqWYW54Xj4ZVBxb5cFZeIggdf1bm1rl9eHrifMSsEIJdH2e0
ROYUJE1bqBnNeBg1zCg696Ny/ZSFwebLz5f1Mda1vSx7Zuqped+6ot8y3kUH
J6vcBM/jrXPdHfodSsieF9fa8IDRmb62NtXgXU27/2vq9kz/YZnbzBCYmlHL
4VXPzpyg1msZLrm6LNwYe7/DW6n8XlgIrw68ajrCTl/AcubvZqwI8V/YeNdy
9knQ+eGEunazcCYjy16EHJ5eRqLwiSX0TVYVPylhrO6PCfHHEUI/XfMllzI2
nSn5/jeeILBfTjLM1sHJBMKpBbc2D1QxjttEdf5pRozgpxNi42e3RJp6lAiZ
TRCYxjLGUvn2qB4+xn7ZN58cnCLGtFyHCEsEL58xUGGAigj3pN+j+IWEY8mG
YS47/hWq/vsYO73zKbGAMG7sbd/LMCgfyw+QoxMxhqTf4JcKb4txSXTKUX7Z
jCbhlaX8t2l/BsEsucaTwtgl8yvJ8TFJ89Gg5zcwgqJjm+JtUT6vyfHR4Nu8
+pW/2X/xKiP4MKH3zUTmYK32/yZH10b1e4Igx/x39PyY8jd5s30e0fMmjwuN
LRV9hDDJRzdDHmmdqneP+vlI+X5WPjcJEtO8Xs3HFeXfo/zrCdul3q39ft2n
i52cFJOTow8z/tgx61E9jR92TPoZEpuKAtXzK6O14ef1TuO/2DwwNFO38zWi
/M08O+9zfA6/cv1f//uf/wFpEcg1
                "], CompressedData["
1:eJxTTMoPSmViYGCQB2IQvfrjJd+knHwHLx4m7fZ94Q6LXLd9/uuS78B1fXGB
7aZwh7hdnjxM+vkOKmyNU51XQ+Vl8h1cunOe/94Y7lAtss79IV++gydI/7Fw
B1WQuv95Dnd+1mXtuRPuINx84NTCj3kQebYIiLnP8hw2zX2//JhzBET/JSh/
dYTDRaXbP+vO5UHMORzh0Ds9T6j5RJ7DQpC9VyIg9h/Ig4g/iHDwMe90TNib
57C3ZLIEy7MIB3VDjjUy2/IcDO4CXfw2AuL+1VD7v0U4rAL5d0eew5vAHXKt
0ZEOsSD543kOr0F870iIfqB7LoHcYRUJ8efNPAdpfaCBmpEOTglPLyg9znPw
SxKIsBSJhJj/Os8h5PHS2Ud+RDh4g9wD8++1CIcZQGce+JcHCd++CIfjIAUc
+Q6bQf6NjnAAGdsomO/wsAoYEJYRDu9q7E3jpPId1shEpVirQ+UV8yH+lYDy
NfMh5gpBw8soHyIuGuFw89z34MeR0PhRjHBAj18A0DPWew==
                "], {{
                246.125, 100.62899999999999`}, {245.33200000000002`, 99.23}, {
                243.08200000000002`, 99.75}, {243.883, 101.16}, {246.125, 
                100.62899999999999`}}, {{247.434, 94.293}, {241.824, 
                93.785}, {241.484, 95.367}, {246.19899999999998`, 95.793}, {
                246.07399999999998`, 96.051}, {245.906, 96.262}, {245.695, 
                96.43}, {245.586, 96.523}, {245.336, 96.67999999999999}, {
                244.95700000000002`, 96.895}, {245.375, 98.34400000000001}, {
                245.895, 98.05499999999999}, {246.27299999999997`, 97.738}, {
                246.512, 97.395}, {246.758, 97.04700000000001}, {
                246.95700000000002`, 96.52}, {247.10899999999998`, 95.812}, {
                247.434, 94.293}}, CompressedData["
1:eJxFVAlIlUEQFotXeUTlI8yreiVaURqaoqKOmpSGRmXsEmpeRZa7XlHiBVES
YgcRURQiFhGUCEmFSIdE2AGFVGgm9hLNihC7y8xsd2d878HjZ5jZmW++b2aW
5hVv3eXq4uKSq/76+zM48+T9LAn947V7bxcwGLp84cGSjRIOdz5pTt7NYLQ6
fl12hIRb3yZfVhQyeLgpsj4hWEKqh+uqo5JB0NrZLX4+EgIth84klZPfQ8I5
ueBwZyXD7z8B6XnzeNQRBok577pt34TDf7fJJ2Tgg8D6+xn47yiIsdsFrG8o
ej9RyiBBx/cKKN9zarS6mEHfs1/bhh4LWFz3aUu7qn/1y/O0vHYB0TceHbir
/Dosvl7Azo4UD1eF55r2Vwtoaxy70qVst95LJbFlAjJ0oxWEZx/VO0T18wUs
1/00MEB+BLjrd+cZlMSqDFzASLetf7yVgYYRkEb9KL/pAwRYWzcMVh5jyEuY
s/8ojTNIQKHGWcMwrw/lV3zcVO4mN4HvqqifwSK4s/+098xast8VYb5hip8r
UJ9BBlW6sE2Ai/69ZfgNF6jnCOmVSHi+E38Z5Ldw1Dub+FvGkY+dAnlL5Zhf
8WdwJHPMV0b9xHLQ8ueUUv5wDqWarxIBSZrfFZx0Ir0Wc9S3mOKtHPuRAnma
RfmVna3xTBDfKr+Zs88MyjSQgwJa/BTQ9zQfNdTPGwYhA0rJOuKnj/o/IcBX
O/pI3+sCUvQ89xC/ar6ak/ULin8toEvXe8Xg+Fkl9LCTX4PnC+X/yEDDsP8S
sFn385fBRZ3nN7335ph/nPAFEJ9/BOg0dYpvo7Palyn9CyL+pwTosp0rOWyf
u7qtcQbt3xqO9edInO8wjvNppf2N43BP75eV9jfKaRt9VbyZV2VP559+b+bZ
xrFfZYdqHv05zouyjR6+hM9Lov6eHLx04fnSoZexPSXuwzBz5DP7bKf99KP4
fuIzUKKevaTnarovL+geRErUv5thPyBRx6ekXwL130P7Fy8d+2HqxFD+MQZ6
zJoiCP8k7Xe4xHmwEF/KNvfAnfheJ6FGrUnHfNJLvQ/QjoUcTt7/EZyp8Jl7
sojjPEQSfl+a52iJ90Ppb/YqTiLuQOKbS7xv6VQvi2ylp+k7R+L8hXLkJ1c6
9tXMR75EXAqPuecFZFsIXz7p+3X6vjnv/391iJxl
                "], {{234.414, 
                100.12899999999999`}, {232.996, 99.12499999999999}, {231.93, 
                99.785}, {230.879, 99.}, {229.47299999999998`, 99.848}, {
                230.812, 100.80499999999999`}, {231.94899999999998`, 
                100.16799999999999`}, {233.04299999999998`, 
                100.96900000000001`}, {234.414, 100.12899999999999`}}, {{
                232.18800000000002`, 94.02}, {226.695, 94.918}, {227.297, 
                96.46900000000001}, {231.914, 95.71100000000001}, {
                231.94899999999998`, 95.98}, {231.918, 96.21900000000001}, {
                231.816, 96.426}, {231.766, 96.535}, {231.629, 96.742}, {
                231.40200000000002`, 97.035}, {232.629, 98.277}, {232.945, 
                97.883}, {233.10899999999998`, 97.49600000000001}, {
                233.13299999999998`, 97.117}, {233.156, 96.738}, {233.035, 
                96.199}, {232.766, 95.504}, {232.18800000000002`, 
                94.02}}, CompressedData["
1:eJxTTMoPSmViYGCQB2IQ7dKd8/x3YY7DGpmoFOv14Q4MIOCT47Dt898rFQfD
HapE1rk/NMtxeB24Q671dLjDjDyh5gNaOQ7NB04tdL0X7gDSdl89x+EhSOHP
cIdVHy/5JqlAzROPcHBKeHpBSTvHYdPc98uPOUdAzLfJcZBvBZpYF+Fw62dd
1p6IHIf4XZ48TI8jHFTZGqc6x+c41Nqbxu36GeFw89z34MeJOQ63Qep4Ih0K
bbmuL07IcdgMMk86EmJeAlS/cqTDIlegy2NyHLx4mLTb9SIh7gvPcdhbMlmC
xS7S4W0N0OC+HIf/INAe6VCUMfFtzeQch+Pe5p2OBZEO+ndVgC7IcQCHS2Qk
xD9Tchy+acT0H3KNhPhnMtQ8oPlg9/VC3SsIVd+S49A7HRhQHyIgdEGOQyzI
fasjHC4qAX2SBDW/MsJhwqGvGjHROQ5yoPAIi3CIA6mLhoanY4TD1hNl++ZH
5UD8aRABCf+4HIg7VSMc+kH606HqFSMcfIDeSAC659kFoEV8EQ7o8QsA9SzW
8A==
                "], {{224.75, 100.67999999999999`}, {222.824, 99.867}, {
                221.5, 101.15599999999999`}, {223.445, 101.977}, {224.75, 
                100.67999999999999`}}, CompressedData["
1:eJxNUwtIk1EUHiOiZIXUEKtl7wfUUpMQNdtXJLWeVMa9SRlISe38lD3psYyI
MMseEpgRMpYEEiL0spBaElJRITmCitAaChllKFJS4ere/54eg3E599xzzvc4
/6SinWu3Oh0OR7b66/PbzI3nHg4S3n4vDdz7LHAlr7F/sJewzOWcVdYqcK0v
urKoi5B168n+yB0Bh/69JuR3Xr3cUieQre+fEY745hU2XRK4v/dC8pAI4fHy
zPKF5wWqd4w63txAcDcsiR2qEBAjvTdqQlx/UmBXbsKr2gpC22SF4JRAavvU
ocf2cb9KYe4L+X21MH2XEsqS3rQO1AoUNvldzgzCZn3eFFC36zqHE85cVINf
CKjuJblfAqa+l+vfB7CqKFFmuaXJRwPYs62yJ5gpDV4V22eBxOLT1oefsQAm
nPi05m6pxGFNRPXbrp77arg+HoBf69UojT6JBD2++anEes13CmGcJhaTmJE+
rN6ziBDVvH5Iox8RUnT/pA3QR4rib+sYlyjR+uQTwtqXLp63gAyuNmn4pnO+
RcL2c9ofvxiPh/Wok8ZPN8+rkritnoUSyPA/KqFlmuji+cUSkdDY1PZkQlD7
4ed5qr89xysxvmBLzrsc9tfN+hXw/sQFdFvfQfavWxj+Vdy/g/PXCUqscJ6K
z2qcz8no3cH708HzPwqDr5uMbr/Y7x5Cmt6bEcy/j7Ba++th/fvJ+D2b8185
P19ik96bAUK9RxERErs1IBXb30GQ4wzL4H30L7b3M8z6zbWgXr88UC7xQOuV
Zv2tt/F5LcOvmP2fbhk8KyRG68QYy/Cdw/j++x5/A+LsplY=
                "]}]}},
            AspectRatio->Automatic,
            ImageSize->{{128}, {85}},
            PlotRange->{{0., 480.}, {0., 320.}}], ",", 
           GraphicsBox[
            {Thickness[0.0010416666666666667`], 
             {FaceForm[{RGBColor[0., 0.596078, 0.764706], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0., 
               0.}, {0., 480.}, {960., 480.}, {960., 0.}}}]}, 
             {FaceForm[{RGBColor[
              0.8784310000000001, 0., 0.20392200000000002`], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0., 
               320.}, {960., 320.}, {960., 160.}, {0., 160.}}}]}, 
             {FaceForm[{RGBColor[
              0., 0.6823529999999999, 0.39607800000000004`], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0., 
               160.}, {960., 160.}, {960., 0.}, {0., 0.}}}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{536.8009999999999, 240.}, {536.8009999999999, 
               200.23399999999998`}, {504.566, 168.}, {464.801, 168.}, {
               425.03499999999997`, 168.}, {392.801, 200.23399999999998`}, {
               392.801, 240.}, {392.801, 279.76599999999996`}, {
               425.03499999999997`, 312.}, {464.801, 312.}, {504.566, 312.}, {
               536.8009999999999, 279.76599999999996`}, {536.8009999999999, 
               240.}}}]}, 
             {FaceForm[{RGBColor[
              0.8784310000000001, 0., 0.20392200000000002`], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{540., 240.}, {540., 206.863}, {513.137, 180.}, {480., 
               180.}, {446.863, 180.}, {420., 206.863}, {420., 240.}, {420., 
               273.137}, {446.863, 300.}, {480., 300.}, {513.137, 300.}, {
               540., 273.137}, {540., 240.}}}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}}}, {{{573.105, 211.73399999999998`}, {552.4649999999999, 
               221.52700000000002`}, {544.828, 200.}, {537.16, 221.516}, {
               516.535, 211.695}, {526.328, 232.33200000000002`}, {504.801, 
               239.97299999999998`}, {526.3159999999999, 247.641}, {516.496, 
               268.26599999999996`}, {537.133, 258.47299999999996`}, {
               544.7730000000001, 280.}, {552.4409999999999, 258.484}, {
               573.0619999999999, 268.305}, {563.2730000000001, 247.668}, {
               584.8009999999999, 240.02700000000002`}, {563.2810000000001, 
               232.359}}}]}},
            AspectRatio->Automatic,
            ImageSize->{{128}, {85}},
            PlotRange->{{0., 960.}, {0., 480.}}], ",", 
           GraphicsBox[
            {Thickness[0.0025], 
             {FaceForm[{RGBColor[
              0., 0.41568600000000006`, 0.30588200000000004`], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0., 
               0.}, {0., 240.}, {400., 240.}, {400., 0.}}}]}, 
             {FaceForm[{RGBColor[0.956863, 0.16470600000000002`, 0.254902], 
              Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{260., 120.}, {260., 75.816}, {224.184, 40.}, {180., 
               40.}, {135.816, 40.}, {100., 75.816}, {100., 120.}, {100., 
               164.184}, {135.816, 200.}, {180., 200.}, {224.184, 200.}, {
               260., 164.184}, {260., 120.}}}]}},
            AspectRatio->Automatic,
            ImageSize->{{128}, {85}},
            PlotRange->{{0., 400.}, {0., 240.}}], ",", 
           GraphicsBox[
            {Thickness[0.00125], 
             {FaceForm[{RGBColor[
              0., 0.12941200000000003`, 0.6784309999999999], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0., 
               1.}, {0., 400.999847}, {799.999634, 400.999847}, {799.999634, 
               1.}}}]}, 
             {FaceForm[{RGBColor[0.109804, 0.541176, 0.25882400000000005`], 
              Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{0., 401.}, {800., 
               1.}, {799.543, 400.703}}}]}, 
             {FaceForm[{RGBColor[1., 0.776471, 0.223529], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4mqRde4PJ9Q6xO7y5GFSz3SA8YWbD5xaeDLN
YYdc6+tAkVoHBhAoSHE45m3e6WhXA+EfSYLwM6ohfIlEB1uu64sLrKscZuQJ
NR+QS3CYDqJ5KuH8T5d8kwTulcP5GRPf1thvLIPrB/Nvl8LNB/NZS+H2bzlR
tm9+RwncfTA+zP0w/qqPQItasuH6Xbpznv++mws3H8zvzIfbv8h12+e/swrg
7gvl0900V7wQ7n4YH+Y/GB/mf5h+WPjAzIeFH8x+WPjC3Ice/gBATahi
               
               "]]}, 
             {FaceForm[{RGBColor[0.109804, 0.541176, 0.25882400000000005`], 
              Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 
               3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
               1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 
               3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
               1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJyFVWtsFFUUXleigIKI1lhSNisSpdiKqGiEVE6NxhLU+qIxtUC72e2dzu5M
iTiPvTMpj1IJNg2oKEZEYgkxPNT1UVtIrYVUKGh00ZiKpWmhaSoxBYFo0xSD
c+e7LSb7w00m2TP33nO+7zvfuXNHpPr52LWBQOAa73G9JxiQv0dNelefXtt+
r0Z1fzzXEmowaV7P7OvWLUuQc+snT56eYFHFQHpW91mVSqOLeotjFv02UqO2
FsWpt7hhm56y6OjShzcVerG/3mXRLbXtxz8siCPPaRmfVEkbHN1z4U0bdXao
ZLXtnDHv6yTq3B+nw3/NKdtscnq8PjE4mqVlxEdEnddkfLNGmwrLB9JrOfIf
0+iejbed/GEdp7+9Y4ezddRvluuTdOxv4bTwy06z7bxGLSEPSTsnX4dOjRIC
Xxunu+dP3J+zV6PGJ7669E8nB949Gk3J/3zH+V5OAi5v0YD/Cgf+kA7+2Q7N
FH9W6uSpNlITdihL7Hd18MlxoPd7OviEZNymA0eejIPV0PcZme+SDtzLHNp7
4aenI2l5vswBzwM6DbmLF6zw4kfEvo904Io49I0Hs2eLDn3qHOyL6OhHhwO9
GnTUOXY1vuiVmZZ2aJvAc0Snc+LcGYdE2fJDmbGv84hDJVM9ob6TfP906BXl
jSH3qE5zRf0rMm7W6YDQ/6IDHhs08A+5JODvNDXqE/xnuCRk7vk1gfUcF32Z
kxjPt/zgkhuDw/Hx2Of/RRw6TnTh34o4nRD9eN2lFWL/yjj8UOYCd3acdm/v
CKcedHHunEpv3T6hZOpyF3p9oIJP2KUt4s8a6edVUt/vq0jQWlws+/XA/8e+
r+505Nwp434Yi30cAYfKBf6ZChVM7tq1qpvjfaki+8Lhh9kK/NLKMY99DPtS
HP1Zwug+4ZNvOfiPVkKvHzkJGWZtrqRf7LN3ze+Q+V6sBN5m6fffYzRd6LSP
o3/Xx6DPGk5PifwDUfBKchIwC96JYj5icl4Lo+BXI+ezKUJNos/q1djHM5ik
4Rf6d29PReDr2iTliLyDcr04iXm6HAHP9Unw+TSK/ulJ6JdfOR6P8fHnpyJJ
H4uE9QxxnU2rfaIM/KM2/KYw4C2yqVvcd68y5HvIBr9GhvnKs9GfJob5mmLT
PlGvlVG/OBC00YfjDHr1W9D1BKNwylPyZwv8DzH46ZS8Lz9jmI+DFvK9z6BX
xKL9Av9GBj0WyXwLlIzYr08W+lKtyLkysZ6rQKdJJvaVKeB/ykC/cuX+Thm/
LevtMqDnBumvRgP3XAnD/ccMeX8y+O5lA3i7GObtJQM8SmX+rQb03ZoZ+/Pe
YcBvXRJfn4E5PqNAz2ED/pxWhfdBE31ZX4X5uDx2Xs5blok5yFfR/1wT/q9W
kb/IhK+eVeX9YKI/mrwPVpv0mNhfr+JecE34Z2kc3wcmz6/NjP15uMkE3nAC
7yebdIPw09wE9BoywDst77s8+X1eKO/H/3yv/wVdD4SX
               "]]}, 
             {FaceForm[{RGBColor[1., 0.776471, 0.223529], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 
               3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
               1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, CompressedData["
1:eJxlVGtsFFUUrrUxvkB5GSoqj/BDwKYmapDK40PFitCoJQXUQkptl7Ld7kx3
trsNVmpn7s6gRolp2hqNJVYRIaQBbCuJBRvF1pBo5OGDYIMIBglQsNWA6BLv
2W9oE3eTuzNn7r3nfI9z79RSo7D8+oyMjOv0WK1Hph4t4bFOz2ACz5c9cvzp
3Ci+/Ove4k0/JfCFPK9GsWqTfhtQaFvUNZTsjiFDfvMVGidmLR99NI7mx14P
nR6nMFC34KHVY2vx3bRjf2+47ODmHz8w512Mw7vj6LeXkg7ztY6sXzL71YUl
RXEcLii9feV0hZ2RirfOZ8XxguDIU5jT8XVs32cx7J+iZ+DXf82vv1ThpfHt
+ScqYgh2RxsnFiqc3PLu/ikPp8epessU952qgc7+RssKBZne+XMN5gnQNxVG
5+x+78KLNXhb9GhSmCqAktG0+NOh5JHaToUi2eBEcX//9BsaDip0aribZ0bJ
98YEBP7mXgvFol++H9da+Er4ZCeIx41As65bMCmBlA9ZI3GK7+5qrruqON9d
TT1OKerZW828dyrE9X/uHAv3aRpbCx38ommG8yx0Cd42G0+eWD++fYuFucJ/
lY1/t/1xqKDDog/FNg6KbxELo0SHiE09CiwMHtIGDdis90SEeq5x2C+N1fTr
isM8SXPY31S9fpP65Pj67jXpS75if7Sa3FemuK7KpI4NPt+5JpokX6u//xaT
OH5V2K7hl1YYxPe7gshc3BcejkWO/j1h3C1AzyiskARGFfXcdy0OUbddComz
z+6556YQ97/j98uOIPukUsESY4z0OOX3oE0fYgH6m2Njx126sFHO/E31WPOb
PhnbAuxbux5LhffeAGZJglH1OC/npzkwvF67Eex+MEA8gVeQK/qUl1OHkw3s
k+wy5ily2C9HAuz/dgclUu+btZgvQp9x0CdC163FR4J/hs93TAXrNSrmmbCO
/s1IsN5zQfq8KIHH9ed/Xg6SZ0sC45yeA+/nVBLfBhePSsGhStb/xOW5afP1
vOjS764QLmztXTI712P8Q4j9+YBHvT+uwuJbM2d5+R6WC9FjVRizUt8EZR75
dPrz6z1cWqY7qSSMjQv1zHY/nx2mP20e5Dqp60uPU/dTs1/vGYO813nsy40G
8S/2588ZeErqZXvIE+IT/P687PLemGziQ1O/fe/y+xUDYvvxAy4E1rTTBvX8
3OV9cdigfx0u6/Wkx5PFmAaXuPpH4mt4Uutvc3leM01+n+SS558R/P8+/w+D
e6zi
               "]]}, 
             {FaceForm[{RGBColor[0.109804, 0.541176, 0.25882400000000005`], 
              Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{735.695, 245.79299999999998`}, {735.309, 244.707}, {
               733.3549999999999, 244.21899999999997`}, {731.602, 
               244.76899999999998`}, {729.8439999999999, 245.324}, {728.602, 
               246.812}, {728.992, 247.894}, {729.379, 248.98000000000002`}, {
               731.3319999999999, 249.469}, {733.09, 248.914}, {
               734.8439999999999, 248.363}, {736.086, 246.875}, {735.695, 
               245.79299999999998`}}}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{150.523, 248.25}, {
               140.324, 257.79699999999997`}, {130., 248.379}, {131.105, 
               262.308}, {117.309, 264.508}, {128.88700000000003`, 272.328}, {
               122.004, 284.48799999999994`}, {135.336, 280.312}, {
               140.55100000000002`, 293.277}, {145.598, 280.246}, {
               158.98800000000003`, 284.25}, {151.945, 272.18}, {
               163.42600000000002`, 264.21099999999996`}, {149.598, 
               262.191}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               186.71099999999998`, 132.57}, {175.71099999999998`, 139.91}, {
               164.996, 132.172}, {168.766, 144.63299999999998`}, {
               157.90200000000002`, 152.16}, {171.23, 152.523}, {175.227, 
               164.914}, {179.69899999999998`, 152.676}, {193.035, 152.805}, {
               182.469, 144.883}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{237.266, 180.226}, {
               227.066, 189.777}, {216.742, 180.359}, {217.848, 194.289}, {
               204.05100000000002`, 196.48800000000003`}, {215.629, 
               204.30800000000002`}, {208.74599999999998`, 216.469}, {222.078,
                212.289}, {227.29299999999998`, 225.254}, {232.34, 
               212.22299999999998`}, {245.727, 216.23}, {238.68800000000002`, 
               204.16}, {250.168, 196.191}, {236.34, 194.168}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{60.870999999999995`, 
               149.672}, {50.672000000000004`, 159.21899999999997`}, {40.348, 
               149.80100000000002`}, {41.452999999999996`, 163.73}, {
               27.656000000000002`, 165.93}, {39.234, 173.75}, {32.352, 
               185.91}, {45.684, 181.73399999999998`}, {50.898, 194.695}, {
               55.945, 181.668}, {69.332, 185.672}, {62.293000000000006`, 
               173.601}, {73.773, 165.63299999999998`}, {59.945, 
               163.61299999999997`}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{152.54299999999998`, 
               33.}, {142.34, 42.550999999999995`}, {132.02, 33.133}, {
               133.125, 47.062000000000005`}, {119.324, 49.26200000000001}, {
               130.906, 57.082}, {124.02, 69.242}, {137.35500000000002`, 
               65.062}, {142.57, 78.027}, {147.617, 64.99600000000001}, {
               161.004, 69.004}, {153.965, 56.933}, {165.441, 48.965}, {
               151.617, 46.940999999999995`}}}]}},
            AspectRatio->Automatic,
            ImageSize->{{128}, {85}},
            PlotRange->{{0., 800.}, {0., 401.}}], ",", 
           GraphicsBox[
            {Thickness[0.0020833333333333333`], 
             {FaceForm[{RGBColor[0., 0.686275, 0.7921569999999999], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               0., 0.}, {0., 240.}, {480., 240.}, {480., 0.}}}]}, 
             {FaceForm[{RGBColor[0.996078, 0.772549, 0.047058800000000005`], 
              Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 
               3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
               1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
               0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 
               3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
               1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
               0}}}, CompressedData["
1:eJxlVg1MlVUYvhKhY8hMjQiwAcMRukZazhrce9/vfB8jVNJqIRTdEd3vrxUI
knPK2hwRmiEaNnNUpMYKctaaojMiBmIg2SxLc8kcMn+WWYmTZobrnPO+9zsz
2O7Ys3Pu+z7neZ73nJtWXvm0eZfP55vCP1v5J4p/HtuklV1YkQufXfuxsDzX
hAj+9ebrL3d9FIZwzrnljSsB8YowFD++f2BNPPNwicAhw8MHr0/8tHZnHtRf
eerQA+0K787rvD6RYnr4wMCa7taQCZ0Cu3mQ8hzv1GBC446KmXV/GbBfrB+d
jH3iL1WD2NN7Vvl7bYh/6MsP/swPwol0zuBNB7JKm3pvXA5A6HBBXFSrg/+H
ArB+9r78kcMKC9rdo/9bT3fB2PzKpVslgPWKXFx/XsO+xS6ew2CQPZwRs6HE
hYaEM9//reuI0xSeVddzbNeI4+HRtpYjqdsdePXSrfZruxmuVzlwbJcoqHm4
78aDpU0LFW4/unTxphHwzhfBmQum7U3pUFjy7HPgU4Hv0WCcl+k97sCSuKj5
DUUKS/7RzMOS30kNWNmFE+nNk/EPou88hv7scGCRaFTN4Oua5sTofaT3E3Se
QQfeP5L6RfVGhv5H6vcxWLaYB+tnOt8Yg/e4rT3nHfiHx6amj+r94cCQ0KOR
gbC9Z1zVl3xvqv6rnW1Xa5Nd+J23qc9hMEfwm++iD/0a+rnQhYAIyrAGnMUz
o3NdrM+x9Pl+F/ue0pBPvAtTN7yrb07RsB6vL333AawT9WIUlvw6HQ9rQi/b
ge2J0UXxw4B+ZzjIbz2Db1qTsocfJX0SSZ8sBwqEPxc19GWGg/3Pashr3Mb5
yyT9Jmyv3tXa4KLQ7clY5mApw3qX6ftTGc7PKRv9jGVQ5efC7KX1lVT/gI3z
/CGDmcLPfhuShaBTdNjay437yka+FkNcacO9XJZ1GTrqERPpl0d+WpQ/A/VP
s0kvA/0sUVj6tk1huT+P9BowQMRaCyscma8IlvOQQP6VGuj/ky6IayK2Qcfz
vabw3Bi+cTXN6ywDzor7q9bF+62C6m1xaV6Jbxv5X6bj/i4X9XxLg28Fvy7K
VyNAtcjnHhfE8RPOBHCeWlzgaW9ONPy4/pKLeTmei3zyKY9Fubif51nIO7si
B/PS73j7xdeDLuHCAN6/0Q7W/Zz8z7Dwfh3U6Twm6nw3na/CxDnIMpD/MoVl
nUyFJZ+hMOp3mqG+HYTvUzhJNFig3bmeD5Q/hSX/6aaH5bxlm3g/vEPvjWHC
RXHx3VZY+hHF7sRjGjwszjWd9nfTPP8Wxvy+SPP3b5jWKe9zTNTpY7pPgvTe
+HT8PjNhjD+LM4p1rF9o4nvziU55NPF+cnTUb62J85hM+WpQ9SPv2zyx/xfi
02VifpYwaBLzdFLxl3qcM0HYXn9Fg26x/5CJeZ/GMIdvK30i2C8fRoV14V9B
EJ4VxOtMzOPOgMdf5mtLwMvHILcpqTKA+x+xJmHUI4DzUGXh/L9B/VZZyCdE
frxg4TzGaZjfNgv9Kie/hyz0/6Af+/daqFdNAOt9Z+F/COL9dl5h9Nv2sHzP
822aEz90iN8zG21vXqS/LTb2Xa5+7/wH58Ld4w==
               "]], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{266.469, 175.172}, {268.355, 174.824}, {
               269.29699999999997`, 175.859}, {269.578, 
               177.26999999999998`}, {269.949, 179.15200000000002`}, {
               269.14500000000004`, 188.63299999999998`}, {
               269.14500000000004`, 188.63299999999998`}, {
               269.14500000000004`, 188.63299999999998`}, {
               264.77299999999997`, 180.184}, {264.39799999999997`, 
               178.30100000000002`}, {264.121, 176.88700000000003`}, {
               264.58599999999996`, 175.547}, {266.469, 175.172}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{273.348, 173.086}, {275.133, 172.375}, {276.254, 
               173.207}, {276.805, 174.535}, {277.539, 176.309}, {
               278.60200000000003`, 185.762}, {278.60200000000003`, 
               185.762}, {278.60200000000003`, 185.762}, {272.66400000000004`,
                178.32800000000003`}, {271.92999999999995`, 176.555}, {
               271.379, 175.227}, {271.578, 173.82000000000002`}, {273.348, 
               173.086}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{279.691, 169.695}, {281.301, 168.65200000000002`}, {
               282.562, 169.25}, {283.363, 170.445}, {284.42999999999995`, 
               172.039}, {287.312, 181.105}, {287.312, 181.105}, {287.312, 
               181.105}, {280.043, 174.97299999999998`}, {278.977, 173.379}, {
               278.176, 172.18}, {278.094, 170.762}, {279.691, 169.695}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{285.25, 165.137}, {286.621, 163.797}, {
               287.97999999999996`, 164.137}, {288.9959999999999, 
               165.15200000000002`}, {290.355, 166.508}, {294.953, 174.84}, {
               294.953, 174.84}, {294.953, 174.84}, {286.621, 170.242}, {
               285.26599999999996`, 168.883}, {284.246, 
               167.86700000000002`}, {283.89099999999996`, 
               166.49200000000002`}, {285.25, 165.137}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{289.809, 159.578}, {290.895, 157.996}, {
               292.29299999999995`, 158.062}, {293.49199999999996`, 
               158.863}, {295.08599999999996`, 159.93}, {301.219, 
               167.19899999999998`}, {301.219, 167.19899999999998`}, {301.219,
                167.19899999999998`}, {292.15200000000004`, 164.316}, {
               290.559, 163.25}, {289.363, 162.453}, {288.742, 161.172}, {
               289.809, 159.578}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{293.199, 153.23399999999998`}, {293.957, 
               151.47299999999998`}, {295.34000000000003`, 151.266}, {296.668,
                151.816}, {298.441, 152.55100000000002`}, {305.875, 
               158.48800000000003`}, {305.875, 158.48800000000003`}, {305.875,
                158.48800000000003`}, {296.42199999999997`, 
               157.42600000000002`}, {294.648, 156.691}, {293.32, 156.141}, {
               292.465, 155.008}, {293.199, 153.23399999999998`}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{295.28499999999997`, 146.35500000000002`}, {295.684, 
               144.477}, {297., 144.008}, {298.414, 144.285}, {
               300.29699999999997`, 144.66}, {308.746, 149.031}, {308.746, 
               149.031}, {308.746, 149.031}, {299.26599999999996`, 149.836}, {
               297.383, 149.465}, {295.97299999999996`, 149.184}, {294.914, 
               148.238}, {295.28499999999997`, 146.35500000000002`}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{295.99199999999996`, 139.19899999999998`}, {
               296.01599999999996`, 137.281}, {297.215, 136.562}, {298.656, 
               136.562}, {300.574, 136.562}, {309.715, 139.19899999999998`}, {
               309.715, 139.19899999999998`}, {309.715, 
               139.19899999999998`}, {300.574, 141.84}, {298.656, 141.84}, {
               297.215, 141.84}, {295.99199999999996`, 141.117}, {
               295.99199999999996`, 139.19899999999998`}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{295.28499999999997`, 132.04299999999998`}, {
               294.93799999999993`, 130.156}, {295.97299999999996`, 
               129.21899999999997`}, {297.383, 128.93800000000002`}, {
               299.26599999999996`, 128.562}, {308.746, 
               129.36700000000002`}, {308.746, 129.36700000000002`}, {308.746,
                129.36700000000002`}, {300.29699999999997`, 133.738}, {
               298.414, 134.11299999999997`}, {297., 134.395}, {295.66, 
               133.92600000000002`}, {295.28499999999997`, 
               132.04299999999998`}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{293.199, 125.164}, {292.48799999999994`, 123.383}, {
               293.32, 122.258}, {294.648, 121.70700000000001`}, {
               296.42199999999997`, 120.973}, {305.875, 
               119.91400000000002`}, {305.875, 119.91400000000002`}, {305.875,
                119.91400000000002`}, {298.441, 125.848}, {296.668, 
               126.582}, {295.34000000000003`, 127.133}, {293.93399999999997`,
                126.938}, {293.199, 125.164}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{289.809, 118.824}, {288.76599999999996`, 117.215}, {
               289.363, 115.94900000000001`}, {290.559, 115.148}, {
               292.15200000000004`, 114.082}, {301.219, 111.199}, {301.219, 
               111.199}, {301.219, 111.199}, {295.08599999999996`, 118.473}, {
               293.49199999999996`, 119.539}, {292.29299999999995`, 
               120.336}, {290.875, 120.418}, {289.809, 118.824}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{285.25, 113.266}, {283.90999999999997`, 111.891}, {
               284.246, 110.535}, {285.26599999999996`, 109.516}, {286.621, 
               108.16}, {294.953, 103.562}, {294.953, 103.562}, {294.953, 
               103.562}, {290.355, 111.891}, {288.9959999999999, 
               113.24600000000001`}, {287.97999999999996`, 114.266}, {286.605,
                114.621}, {285.25, 113.266}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{279.691, 108.703}, {278.10900000000004`, 107.617}, {
               278.176, 106.21900000000001`}, {278.977, 105.023}, {280.043, 
               103.426}, {287.312, 97.293}, {287.312, 97.293}, {287.312, 
               97.293}, {284.42999999999995`, 106.359}, {283.363, 107.953}, {
               282.562, 109.15199999999999`}, {281.28499999999997`, 109.77}, {
               279.691, 108.703}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{273.348, 105.312}, {271.58599999999996`, 104.559}, {
               271.379, 103.17199999999998`}, {271.92999999999995`, 
               101.84400000000001`}, {272.66400000000004`, 100.07}, {
               278.60200000000003`, 92.637}, {278.60200000000003`, 92.637}, {
               278.60200000000003`, 92.637}, {277.539, 102.09}, {276.805, 
               103.863}, {276.254, 105.191}, {275.121, 106.04700000000001`}, {
               273.348, 105.312}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{238.93800000000002`, 108.703}, {237.32800000000003`, 
               109.75}, {236.062, 109.15199999999999`}, {235.262, 107.953}, {
               234.195, 106.359}, {231.312, 97.293}, {231.312, 97.293}, {
               231.312, 97.293}, {238.586, 103.426}, {239.648, 105.023}, {
               240.44899999999998`, 106.21900000000001`}, {240.531, 
               107.637}, {238.93800000000002`, 108.703}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{233.379, 113.266}, {232.004, 114.60499999999999`}, {
               230.648, 114.266}, {229.629, 113.24600000000001`}, {
               228.27299999999997`, 111.891}, {223.676, 103.562}, {223.676, 
               103.562}, {223.676, 103.562}, {232.004, 108.16}, {233.359, 
               109.516}, {234.379, 110.535}, {234.73399999999998`, 111.906}, {
               233.379, 113.266}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{228.816, 118.824}, {227.73, 120.406}, {
               226.33200000000002`, 120.336}, {225.137, 119.539}, {223.539, 
               118.473}, {217.406, 111.199}, {217.406, 111.199}, {217.406, 
               111.199}, {226.47299999999998`, 114.082}, {228.066, 115.148}, {
               229.266, 115.94900000000001`}, {229.883, 117.227}, {228.816, 
               118.824}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{225.42600000000002`, 125.164}, {224.672, 126.926}, {
               223.285, 127.133}, {221.95700000000002`, 126.582}, {220.184, 
               125.848}, {212.75, 119.91400000000002`}, {212.75, 
               119.91400000000002`}, {212.75, 119.91400000000002`}, {
               222.20299999999997`, 120.973}, {223.977, 
               121.70700000000001`}, {225.305, 122.258}, {226.16, 123.391}, {
               225.42600000000002`, 125.164}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{223.34, 132.04299999999998`}, {222.941, 
               133.92200000000003`}, {221.625, 134.395}, {220.21499999999997`,
                134.11299999999997`}, {218.33200000000002`, 133.738}, {
               209.883, 129.36700000000002`}, {209.883, 
               129.36700000000002`}, {209.883, 129.36700000000002`}, {219.359,
                128.562}, {221.242, 128.93800000000002`}, {222.656, 
               129.21899999999997`}, {223.71499999999997`, 130.164}, {223.34, 
               132.04299999999998`}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{222.63299999999998`, 139.19899999999998`}, {
               222.60899999999998`, 141.117}, {221.41, 141.84}, {
               219.97299999999998`, 141.84}, {218.055, 141.84}, {208.914, 
               139.19899999999998`}, {208.914, 139.19899999999998`}, {208.914,
                139.19899999999998`}, {218.055, 136.562}, {
               219.97299999999998`, 136.562}, {221.41, 136.562}, {
               222.63299999999998`, 137.281}, {222.63299999999998`, 
               139.19899999999998`}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{223.34, 146.35500000000002`}, {223.691, 148.242}, {
               222.656, 149.184}, {221.242, 149.465}, {219.359, 149.836}, {
               209.883, 149.031}, {209.883, 149.031}, {209.883, 149.031}, {
               218.33200000000002`, 144.66}, {220.21499999999997`, 144.285}, {
               221.625, 144.008}, {222.965, 144.47299999999998`}, {223.34, 
               146.35500000000002`}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{225.42600000000002`, 153.23399999999998`}, {226.141, 
               155.02}, {225.305, 156.141}, {223.977, 156.691}, {
               222.20299999999997`, 157.42600000000002`}, {212.75, 
               158.48800000000003`}, {212.75, 158.48800000000003`}, {212.75, 
               158.48800000000003`}, {220.184, 152.55100000000002`}, {
               221.95700000000002`, 151.816}, {223.285, 151.266}, {224.691, 
               151.465}, {225.42600000000002`, 153.23399999999998`}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{228.816, 159.578}, {229.863, 161.18800000000002`}, {
               229.266, 162.453}, {228.066, 163.25}, {226.47299999999998`, 
               164.316}, {217.406, 167.19899999999998`}, {217.406, 
               167.19899999999998`}, {217.406, 167.19899999999998`}, {223.539,
                159.93}, {225.137, 158.863}, {226.33200000000002`, 158.062}, {
               227.75, 157.98000000000002`}, {228.816, 159.578}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{233.379, 165.137}, {234.71899999999997`, 166.508}, {
               234.379, 167.86700000000002`}, {233.359, 168.883}, {232.004, 
               170.242}, {223.676, 174.84}, {223.676, 174.84}, {223.676, 
               174.84}, {228.27299999999997`, 166.508}, {229.629, 
               165.15200000000002`}, {230.648, 164.137}, {232.02, 163.777}, {
               233.379, 165.137}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{291.562, 139.16}, {291.562, 121.324}, {277.105, 
               106.867}, {259.27299999999997`, 106.867}, {241.43800000000002`,
                106.867}, {226.98000000000002`, 121.324}, {
               226.98000000000002`, 139.16}, {226.98000000000002`, 
               156.99200000000002`}, {241.43800000000002`, 
               171.44899999999998`}, {259.27299999999997`, 
               171.44899999999998`}, {277.105, 171.44899999999998`}, {291.562,
                156.99200000000002`}, {291.562, 139.16}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{259.312, 175.879}, {261.22999999999996`, 
               175.90200000000002`}, {261.953, 177.102}, {261.953, 
               178.54299999999998`}, {261.953, 180.461}, {259.312, 189.602}, {
               259.312, 189.602}, {259.312, 189.602}, {256.676, 180.461}, {
               256.676, 178.54299999999998`}, {256.676, 177.102}, {257.395, 
               175.879}, {259.312, 175.879}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{266.469, 103.227}, {264.59, 102.82799999999999`}, {
               264.121, 101.512}, {264.39799999999997`, 
               100.10199999999999`}, {264.77299999999997`, 
               98.21900000000001}, {269.14500000000004`, 89.77}, {
               269.14500000000004`, 89.77}, {269.14500000000004`, 89.77}, {
               269.949, 99.24600000000001}, {269.578, 101.12899999999999`}, {
               269.29699999999997`, 102.543}, {268.35200000000003`, 
               103.60199999999999`}, {266.469, 103.227}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{259.312, 102.52}, {257.395, 102.49600000000001`}, {
               256.676, 101.29700000000001`}, {256.676, 99.859}, {256.676, 
               97.94100000000002}, {259.312, 88.801}, {259.312, 88.801}, {
               259.312, 88.801}, {261.953, 97.94100000000002}, {261.953, 
               99.859}, {261.953, 101.29700000000001`}, {261.22999999999996`, 
               102.52}, {259.312, 102.52}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{252.156, 103.227}, {250.26999999999998`, 
               103.57799999999999`}, {249.33200000000002`, 102.543}, {
               249.05100000000002`, 101.12899999999999`}, {248.676, 
               99.24600000000001}, {249.48000000000002`, 89.77}, {
               249.48000000000002`, 89.77}, {249.48000000000002`, 89.77}, {
               253.85200000000003`, 98.21900000000001}, {254.227, 
               100.10199999999999`}, {254.508, 101.512}, {254.039, 
               102.85199999999999`}, {252.156, 103.227}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{245.277, 105.312}, {243.496, 106.027}, {242.371, 
               105.191}, {241.82000000000002`, 103.863}, {241.086, 102.09}, {
               240.02700000000002`, 92.637}, {240.02700000000002`, 92.637}, {
               240.02700000000002`, 92.637}, {245.961, 100.07}, {246.695, 
               101.84400000000001`}, {247.24599999999998`, 
               103.17199999999998`}, {247.05100000000002`, 
               104.57799999999999`}, {245.277, 105.312}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{238.93800000000002`, 169.695}, {240.52, 170.785}, {
               240.44899999999998`, 172.18}, {239.648, 173.379}, {238.586, 
               174.97299999999998`}, {231.312, 181.105}, {231.312, 181.105}, {
               231.312, 181.105}, {234.195, 172.039}, {235.262, 170.445}, {
               236.062, 169.25}, {237.34, 168.63299999999998`}, {
               238.93800000000002`, 169.695}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{245.277, 173.086}, {247.039, 173.844}, {
               247.24599999999998`, 175.227}, {246.695, 176.555}, {245.961, 
               178.32800000000003`}, {240.02700000000002`, 185.762}, {
               240.02700000000002`, 185.762}, {240.02700000000002`, 
               185.762}, {241.086, 176.309}, {241.82000000000002`, 174.535}, {
               242.371, 173.207}, {243.504, 172.35200000000003`}, {245.277, 
               173.086}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{252.156, 175.172}, {254.035, 175.57}, {254.508, 
               176.88700000000003`}, {254.227, 178.30100000000002`}, {
               253.85200000000003`, 180.184}, {249.48000000000002`, 
               188.63299999999998`}, {249.48000000000002`, 
               188.63299999999998`}, {249.48000000000002`, 
               188.63299999999998`}, {248.676, 179.15200000000002`}, {
               249.05100000000002`, 177.26999999999998`}, {
               249.33200000000002`, 175.859}, {250.27299999999997`, 
               174.80100000000002`}, {252.156, 175.172}}}], 
              FilledCurveBox[CompressedData["
1:eJxTTMoPSmJmYGBgBOLNQALEZmAC80fRKBpFo2gUwRAApg0EFg==
               
               "], CompressedData["
1:eJxdWQu0TdUaPkjJKyLlVZFHhuqEqy6SWZJBNLL3Wmu/914ka8211z77HHSS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               "]], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
               0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
               0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 
               3, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
               0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
               0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxdVGlIFlEU/dSw1bTsh6SmZi4hYUqrIV1LKSudNyUmaSZiENK892GSoiWJ
aURotpnRahJW2GKERYtaiGaQmllmamWSBqZg0oYZvTf3OQN9MMx3uMs5794z
zyuZbd5pZ7FYbPgTzx9b/mxLWfVB2W+F/tb5Xb//KtB35Wy9Z5EVPgs8rMC3
tqhkpxIriLTCDolLrbBn17GhfS0m1uON/+U3yn4nZX6tAg0blx8OOyjjFQoI
mJRh4pC7z/bWRJn54rXa1ewX2LPAPreJGfzW0Gkd5XHMiK9J4sq9mVHvnFf3
vGyIQprAtxTwC5pS6VZDwSJ+lxQoPE1n5xVTEDOxFCuQPefmut5UiufIlPyR
FM7Ve95Oi5M4VOL1Un8QhYUJR59+X6Egj5/E/gpsnbnoznkPCq5C+CwZ96bI
m6SgzgBTn67X3dSnz8PR1OcuFmZn6tPzfmlGv8fpJ1wmDWuGPv28/Zqhp1EI
/qjBVbEIGwX49Kyh7zW4NzrentkZjfG3mqFX31e77A8K8NMvTWzTDP7rI/xP
q2bsbyI+sZ+J+gl/6XxvNPCxzz211pkgX7eGfvMlhj4dLyPony8aCPq6DcQ4
70sezkkl8MOfH8yBghhbRAFBf/hQCD+ye2CsjKCeYIq8xwmIqkdAsT/PDxN+
UWR9DoFYsa94CokPImfYZhMYFvXcD7p+Hn8n6jNNvtqLcwN7uH++qvfn5ccT
9EcVhRghPIngPhoovouk3iZZXyL1NVPYIfjKCe63hWLeDYJ+fkVRdz3Bc7dR
fH8y8y9HVI+O/5H6B6TfbFQQW0+wY4inqpA/yIV6MdTnoqJ+YLhff1X6iIH4
DLKWqDi3HAbRyU5xK8NVnOsZiTepqLOK4d6ICm5CT4XsByrur5hBt9DvpqJf
0hn0ZnGGEWLw6Xt7TWC64MtiUC382ESMeh0/kf44wHCeF8x6Pr2AQ7EE74MY
ZvhHj6cw2C7mG0AMfn3e3gS/jwKGfnQl0Nn8c0vfNRPr83xo5i8WOl+Y/YrF
fLsYlAp/hhDwFXWDZlz30RiDSjEYD4L3hYMVsSOBjBq+AA+JJ0t/B5v38f/3
8z9bA3i2
               "]], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}}}, {{{244.824, 67.52}, {245.008, 67.45700000000001}, {
               245.195, 67.395}, {245.258, 67.21100000000001}, {
               245.32000000000002`, 67.023}, {245.258, 66.84}, {245.195, 
               66.65199999999999}, {245.008, 66.527}, {244.578, 66.527}, {
               244.453, 66.65199999999999}, {244.32800000000003`, 66.84}, {
               244.266, 67.023}, {244.32800000000003`, 67.21100000000001}, {
               244.453, 67.395}, {244.578, 67.45700000000001}, {244.824, 
               67.52}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{244.754, 
               67.273}, {244.875, 67.21100000000001}, {244.93800000000002`, 
               67.086}, {244.875, 66.96100000000001}, {244.754, 66.902}, {
               244.629, 66.96100000000001}, {244.566, 67.086}, {244.629, 
               67.21100000000001}, {244.754, 67.273}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{244.80100000000002`, 66.422}, {244.48800000000003`, 
               66.418}, {244.23, 66.67599999999999}, {244.23, 66.988}, {
               244.23, 67.301}, {244.48800000000003`, 67.55499999999999}, {
               244.80100000000002`, 67.55499999999999}, {245.11299999999997`, 
               67.55499999999999}, {245.36700000000002`, 67.301}, {
               245.36700000000002`, 66.988}, {245.36700000000002`, 
               66.67599999999999}, {245.11299999999997`, 66.418}, {
               244.80100000000002`, 66.422}}}], 
              FilledCurveBox[{CompressedData["
1:eJxTTMoPSmJiYGA4A8TMQMwA5DCOolFEQwQA/LgDRQ==
                
                "], CompressedData["
1:eJxTTMoPSmJiYGC4yMjAwAykGYAcxlE0ikbRKBpF9EAArgAEUA==
                
                "]}, {CompressedData["
1:eJxdVwlQVlUUJjSHUXIpMhMkXFLCMbGSKNJOYwbyv+23VVzGjCZ1lHfvjSnE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                "], CompressedData["
1:eJxVWXmcFNURXhFWEhZEUOKxbEARZD04FBFY8bEgiAfszHTPTM/OxYIRAs70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                "]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{244.754, 66.848}, {244.625, 66.848}, {244.52, 
               66.94900000000001}, {244.52, 67.07799999999999}, {244.52, 
               67.20700000000001}, {244.625, 67.309}, {244.754, 67.309}, {
               244.879, 67.309}, {244.984, 67.20700000000001}, {244.984, 
               67.07799999999999}, {244.984, 66.94900000000001}, {244.879, 
               66.848}, {244.754, 66.848}}}]}, 
             {RGBColor[0., 0.686275, 0.7921569999999999], Thickness[
              0.00019063687500000002`], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{244.754, 66.84799999999998}, {244.625, 
               66.84799999999998}, {244.52, 66.94899999999998}, {244.52, 
               67.07799999999997}, {244.52, 67.20700000000002}, {244.625, 
               67.309}, {244.754, 67.309}, {244.879, 67.309}, {244.984, 
               67.20700000000002}, {244.984, 67.07799999999997}, {244.984, 
               66.94899999999998}, {244.879, 66.84799999999998}, {244.754, 
               66.84799999999998}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[0.996078, 0.772549, 0.047058800000000005`], 
              Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 
               3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
               1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxllHlIFFEcxzevxEw7bDOvDsKORXbXmTezMzuz+9sOSkQsJf/QCLMEISux
EDGKCsRERESxP8xAIygqKRErKYkOiC7KBLtLZCsRSa2IEKF97/d8YrswzHx2
3vv+ru+b1UWHc4pDLRbLvMBVELhCAldzfFhezHMDLPR30gn/85P2rT0/j+ug
dz+u6Ftph7tHm+LDejTYsLvh/u8zDij9NnV5otwF0SG2GuuKdKDLp5tN2FF/
9tCSYU1wov3j2oh2Yy43AtRY377406SDGTV4oSzNB19frnn/95PC4/uA7OnN
iC6SIfDWjLrpw/W5DoxfEsxs3XInOALyp/wAd2i+LU7U7QPU/ZIOcZ3bhqq6
AdRaX6G/jK/fBWBjgnagr+NivIJpGiF1xly+4uL5OyHnVkr16GJVcAetsztd
8Hqa33YHDF9sfbjKYQea9XDxxiBe54y8mpQg8bsNJvuziha9kflcHPj/O4mv
l3jdMlSxgiTMa1SGY5TzJX4nWOd4OtwoL2kcO0dw3yUJ85QJ+Gl/TsiwpY5O
VMa4LsLzIFjHEQKVI6nOyFICyfn73Z+zCTyjA01WMK6N8L4pqP+dQMvmgGAr
gYPUJ10KVI/uDHRK5n1Xsa5rKs7nvIJ6bRr285VLMHuf4hZ8ndbxweB9cGGc
RA+vRxXM4vYrgpmfNino20kT+z9OuK9N7jMCLpqfw4N1vyaoO+CBJFp3rMLr
9/L58f4s9YJC9TtkXNfggV/TA5UjEYTPx8Q8CmTs1wGT5yfxeCb6tUKCbHp+
Hhg8vgR021SGgedqn4x9DDeEPtNbYOD8amXsf6Qb9awEJug8K3U8d0MEdUKD
mZ2Pwlk99IkimH0PTFUwy+ORyn3pFsx0LLPM4vh07he+Xtf4PHm8TA39mTTj
Xw33+/k5ytUFs/29hmCcowf91ynDMvoQBhCb1tX2Y74KT2mchYD9StVw3lb+
Pbino4/CvYKZDwYNwU3Up2Ma+rWe9yNTEoz+dghmPjudhpzlwjnk2USfZ5j5
wW0IZnUneGAvPZC37UH8D1c2WwE=
               "]], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 
               3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
               1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
               0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 
               3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
               1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
               0}}}, CompressedData["
1:eJxlVg1MlVUYvhKhY4RlZkytWbFMqhWupg7u5T3nO5d7L5ef77s2EmXMiArL
oIgxMOfGyIgcZGoLphZZRrqy32U1Yy5+lFjNrGWsqJH86MylOKNy/XznPOee
b467fffu2Tnnfd/zPM/7fvem8urYQ1f4fL4Z7rPVfRLcZ3kLWztmZ9PbC1dX
ZDU7FMd5KQm3N3fHqCLrl6LW+wm4bCWtWvHR0bpUbnCJxGXC4IMX/vmuviNI
f9xW+sIX78QM/rx2e1piv2Nwe9WcpsPcoY8lXhekI9FlLeycTa0vuwvnBNZr
pmOf/CxidOL1J/zJU2FKvfOD3b+HchB/PEhL3LQXTwWoed7Q11NNQSr7LJKS
MBig6w6ERjbM9fD8u4bTk54UBs+V67UWiS3rJy6VEOK9ybG+hiFvJ6c9Qbdi
wbGvgyOPZZElcYNlsLpXgzC4pvLFsxvfDdLjE5f2nd/Dsb4il758TQZkBvdc
dIlb6uF9/S4xI2TuF8fQxcMqzwVBb0l8DQMPR7UuxR5W9Sdyg9W5bxn9venR
Q7UfBqfhb27+8a9NGRw6dAbpXklIDafZinfNd5hD1yFBu3oXvVfzHKffnE9u
3Dyo4/dwxNkvcL9JTuratQJ5euLxBA3KhVbNc7ow8TPkb5ow+dXvNgt5sji1
yfpsi6SsjX0Met5jUSDZdcowo52yrkoL8V08ebyg/Op2C7x+z5Cv16KZjS9Z
WxYyxNtqQXcfwT+jHkZ9QYPVPR7MpR1picWpwwS9q0Oo72lOSTLuHSHwk6b5
WROiiNRnnFHD6VszZx0KIf9PDL5eHIbOizV/yWETT51Lmo6VX6Mc8Ur1+Zmc
7pa87A3rOBy8FES0j3T8jAj6+RXtz9NhWiAJnWFBtzkR5HmYA/M88JJugY/R
qM4X1Hrma/8J8F8f1XwJ6NmeZ7Dqn08jBqv9p3LBl+vTsWNugVUejvdXHKu8
XVq/UoG6ejnmRLNlfBzHqg+X6v69VkC3qzjmW5WOd4TpftU+rNRzYK2l9zPE
fZ6hvlSm/Uvap4zk9ecNBeCP7Yzkd5rwGx+rOF9lI8+vHH4szsb+lRapsVWV
RWekzmeE2Y+5pP1WECB5KvVsSM8ZTvVS//VF4GnAIleNrv6TNvrjSgF8i4M5
tkTQU/LcIx5Wur/v4Y05bsXrYuDvBCdpH/9+ja/3sJqrmezy9RBhfsc8rOoY
cwxW87/Tga+2EXxW59C45PVfDyueEvjleJJhnozq/d1al4wY7vEAp6bD7qRN
iul1TvK6OX0OfPsGx75GB3POZ9FxeX6DgzmxykL8Cgd96fpM8bXM0b7QeLaD
flyg5/9528SPv9+U73/Q9Txro848Tq7KB0Iltqlf7Sdb686wv82G32dx+k9+
JmzDTxz7FfEeVn0VyaH7Tu7d2funDT92BEz9yl9tAeOPgbruV+dXB6hLvkcy
i6Zh8BHAvZcXos+eIfQFFaKeMgbftBSiH1MY7vFYAfQqJ8zXY/nQ/6Af/TaV
D75qAyT/o/jcdcTNwRyp87CKPxA1WOk3kkebZaI+P+bYzxHTL3hfROiG1TKT
93/nfzxF5I4=
               "]], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 
               3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
               1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
               0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 
               3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
               1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, CompressedData["
1:eJxlVg1sU1UUHnNOssxNCS7LIIsKisKW9efdvv4wOO17Xdv99b3OYMYI0Ylh
AgLWptmAkCzLnETH0KFMCXFIcJEgoJCJOgnK3EBQcRoVVBS3MZdBBCdOXRa9
957b25g1eWm/3PvO/c53vnNu76ndEHn8lpSUlBn0aaNPKn0eWNH28c1gMRyc
u3yVp8WEBC7NTF3UciICK98PZaaOORGvrIKXtOfWjWwmEh+J1r1w7QeLxO/s
+a2r72wB/MkCvRWR+MNYe25anylxx/pZTSd9JoxMvnljoLUQ+svUbd7rBuSm
LcsqjBbhenQ6ZsfkVKvw7b6NxRkTQYgcz28eM90Y/4ofBvfv7r37iBtaci58
PtHkhzPxE6/lfeGGuw4FLm+ancR5RT/OT39Kl3g2W49pQIMdzx92Yrw3fLC2
h/4YckAK+3T6gMn0UzYBncow+YoPz7/TDkyWyQZN4u7xqa/rG3SJmUxbDvuR
V5WC664SOLfX3z2+h0jM1+2qxJzHN6rML4Epi3Drw0nM3xvXgdFNi6vwIKvj
aR3qR++3zrzqkJjzbyMSU9UfGb5O4J+ta3piR/3T8BoWUCfQuosWoFOc161A
diGtZMAPf1Cao+kE3mV8L+gY91kFrlIZm88m8lfgy3u//3vrAR1ep+lOHbMD
S3sqllzHeDoc5kIpuG++LuMvZHFzdXk+YcZ8UQOTEZtHYDvjZ2hYz2wH1lPR
4Mp5evAlAswV0TpN+JXA7wMVtXd0aNDODHaN4Hm9GsxhvnhUxXg7NFhgnXlw
7qsu9M9QEiM/v8Rcr8dK0Cc/q1jvDQHkt0+B9EbaOQUByGJ5riaoT00AGlh9
zhH87gng+ZcJ7lsQRF+FCOqXEZTxQqwR0qdj7tc0EW9FEH26jYCFhm3cH0R/
NxNYkkE7qCIk+lvUZ2EIXmYH1gh/jgaxz3bZ4dRN2tCzQrCT6fWZgthXCk7m
F8OOegyVof9yikQ9y4X/LKh/fZnQy4r17CiVmOf5Xkhivv/XEoxzmwWGWR3X
J3GivxKY90OXJvS3YL16fajD8zaRXxI/yQaPzYd+32jFvG73Yf4fiHj9XtGv
FvR1nRf5XbSJ/V6hpwP5ZXmFf53oz6gX6/mRG/3R7kX/Llss1n1Cz8XI5xef
6Ldi3F+lId+CJcCPGdPlfl63mhLEFR7h4wBsZsZ3K6j7ujAw9oO32nDuDhrY
H21WxPNMXPdb4WlGe3USc95vJ/GWpZTxE4n7wA7MPsUHIuIcIjH3i6pKzPln
unB+R5KYhW8cNiXm87/TRB/FnOjnuIn12K1KzOvRTv6PjxKcJ0Mm5p/nEPWO
YJ9/p0DTyU/3+tMjGG+OAizdpZ+YqEdYwXwbTTEX7DDA3t9kYv+M2jD+qsT9
aEO9VBP7tF/gbBPrWivm/w1Dxk/cb3z/iB35PGPIfqWX06FAtSH58/1gQJj1
9ymC+7cbYr4S+Jd9RgypTwLzeZfvkhjPd8ND7GL8y8A8Z3gkf9TfI/3B67vI
A119lIA1PA3z970e5OGsxP7Z4cS+g0rkf9Eh5k6l0FVF/66tQJ8POHG+ni8H
g+U36MF+myjHfrrPA+w/Sgpd5/223I3/L+JJzOOfKZMY52Yp+uErD1S7jp2O
XwrJfsH7IgT/ATGx0GU=
               "]], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 
               3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
               1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
               0}}}, CompressedData["
1:eJxllHlIVEEcx9ejkrIoNbvtILpEXHfddHff2/ed2ZWMiC6yA42sBCk7KAs7
ycBMJKS7KAKLLoqIEK1I/0iR6CJDEMuQMrssSKWixOjN+42zlAvD8Hkz+5vf
7/v7zkxes3lxTpjNZgsxR6Y5Qs1xfHR4xrCnGmzitz8J//PumJtz3ow14Kl4
uKNmYiI23M8/NvqdgZmZZQ++H7Jj44eea51HgcjQ+OLYMQ5aD9ew8PCpTVFt
bsXjEl9PHViu/ctHgKKORXfiBhjQBzdd3JLA4BNzFpPnM+z8NC0p4hyH+VUf
XMXovAsBOj+3P1txWQB2cypsB67Wz0spCQng/fMpr37VgOrL8kOUtasCKI5t
fvYzWu5fCrSLfc8CEMsxwwzFq+7NjQwt1f7l66mo/T4jsyw0gMV34oo6RqQo
vpBW2d1b4VA8Q+SXbqf8QtJgnrqkLWdWP96We+TrHsOP6UkRN8aPjaf1bC77
Yqf1Vi73O9H1Yv6a4ac5dlkFOUmnZZz6ttJJ+ydypJSw1e3fHFjuNhv5h5Fe
V52Un4NTXfuSKV4BpznVRX0AJ522uSj+KI4JK9d5Wxe4qG/VjPSId8Fqb72M
/9FFuv+Rfbo9G4HSvA89JTKfLSmoFvt/gPadn011/DZIz4ZUxdZ6nFfxra1m
YS0aqrp7GwvOACf9ZuBxPrhEIg6m+Pe+9ffz1wa5QPjpBkOeyKdLx0ghWyOj
PCp1XBF+6WRIFfnZfaTPW0b9bPTRXMdk/Qb5KFnqE23gi2nnot0c48V6mY90
SO/rjy7r5KTXBp3ya+PyPJ3yj/Jjgbg/tZo8n0Ok3zNXo/hnubw3mopvxRui
QWR1uJjT9wgvxeMcnVZfPRhUeMJf2sLofob1Z8tnE4LxyA9M8aNyU4CEIDcI
23wG+fWlV7HlG1uQ6V56yC86o/0eN8XrlfHmSa7u86+b/LLCT/ou8Si2/n9P
U9x26WzdpG8+iGMKt3PqazikPgyPRdyhgOhigRvU71j5bjX76D6Z71AfWz5v
0hQfE7p8dUO4vPhgX75OxeRvu2JL9wMJxJdB9yIjnuaThmIrryxdsVX/Xi+y
xYW8m9iPrffwSfB9/gsDg2Cj
               "]], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 
               3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
               1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
               0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 
               3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
               1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
               0}}}, CompressedData["
1:eJxllg1MVlUYx18JlRGxFBRCBGM2P5oxm2QF78tzz70M8WNmH3wU3nvfe8lp
KzAi14yxGBCUwyxt4SwJq4HN1FqJKyILJdRVhpWhEjHmx1KnwsgRmd1z/+e9
Zwy2d/DjnPuc5/yf//Pc926r5NGnb/P5fBOczxbnE+Z8HnxNMc89kkHLFjt/
rLMpxLuyDgzdDC+iovS+lfV5RDWXVh1MeqKI8h/6vGtDNPO4gLOuedw6dPOX
l7Zn0fP+yFMf/Gt7fHqk4pm2OsnOKSdSsm06wHldFn1dtjU+PMmm+neKp1Zd
07DeZ41jH/+ZpVDp2jevlA+YFL3gs/euZmfSPZMq31aTTZpX+MZ3wxcDxB87
NMkk/cucqLDjAfp7rrPwq+Fx7fSeH29UGWPXJxqkbXr2wmgBUTK/0E4d608p
dNm5Xs0OHbpoDHk16IijquAIw+NOLmid5JiqQ8eappj03IXR3dd3MawvMulY
Ew+oeNwx7CRyv+Td/I9+8u4X4j2JTxal3zA8Tu2dPanyiEEtnKco0Gm/QUuj
wu6tzZWMujKP3fxOKvRF14b2xqnmOP455cxIxXxGzn8fG7jDpDQuSCmjh52y
t181oPcSocdBg949PGt/aR2j/o2xe7M/FfE7GD0+8NGOw+8buN8gIy5H1qsG
/ePYosxZf4HXs8Sg41yPegY/6DL+Lf6TZ3jnn+F+ijVQl3RGjguaO4d0oYOC
ep7TKeDYcH2vgnxv6YjvMLdte5yBc35TkM99Bk12ZN6UqCBejAGdfIR4fsnu
c39IdvUKmLQtPjw3ulfsrzSR38sMuq83oU88o7M8/3KTcnh9ziv0TWNCau82
E+efFfnuM9F/c4S+LTKeo8rcwubx7Pp1mYjfJp6fzNA/P4l6Ror+HRHreYw+
vt69wrpmop93Mvqe++9Pk2ZwQSeo1M2f+0vku4bRCc4PBGna3uz+jbNVnNsY
FOdlQd/WoPCfBp2qg0Ivwcslu+fHSp7p2LvPEHp1aairIjnUXyF2+yFZ1K9Q
g/6f6ORU3x9Zq8J/pmS37YpE/8Zo6PtVOuZbsYiXqot+Ffn6dPw2VeK28nev
hp6vK2Tw+59cLfxLFMt1CdeJX396TwD5T9PJcfvWeM2P9WodfvlBzNs2Hb7K
zcD+YZ34ttjidMzJbw1v/2buhwzhtxUB1LPJxFzcx+CnVyw8d1SlXD4o42zE
naiBF9u49zwN86lA8pXyzDS9QnIDn6enbeh3iqHeo4LjJCfwAxYqY9ezSfhP
MuanZHe+vGhjPrxF0MO06Tw32n+S3XqEsbE8qMCvDWJ/u0KMn/eVDf8GGbVz
PVpC66KfnPeRG+dDhnquEe8fn4rnbZsGHVvema8ifr6N902zmOeKjfm0VvAC
G/04Q4UvkmT80PttPt//u8jnooV9Sxn07ra8/N39nRbxstZcEvPhsgW/RzD4
+y6pT4j97kUkq7x+OZk0Z2HEnsQUG37cHvDyd/21OeD546gzxhJKAthfao1j
6BFAHyyy0P/V4rw0kb8u6rHEQj9GKfg+4LNQL0vUuyeI+rf6MS8GgtCrTLyP
e8Q8oEzMtw7JqLdkvC+C6IMjflrOv8/MDHr9crt7UBBzZaX8vvM/dq7buw==

               "]], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 
               3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
               1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
               0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 
               3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
               1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, CompressedData["
1:eJxlVg1QVFUUXmklhkhSCQ0VirJslJZl39u37IIdUkaddBQrStP37r5Hf2ZJ
ZA4pw8QgiWNGDZpMjBExjdZYUpkxSaZZ2I+loWXgL7MRkTBqZg5DjL1zz937
xuHNvNn99t53zne+85379jZzxcLHrnO5XCPsu8a+Y+x7ypKary7PzoX7tfV5
7CkLovid/N2XhtxFoH8+JyHmXACqzhW0pD5UBJtnbFjes0aVuLnkydf7T2ZK
/PHW89vafpgGz+XGH2/6z5K4c6B8WWu1g/NY95H0WRb0DL53sX1jBnyxsna8
O9WC8e7CURklHlo/Yw7DCTFT1yUv0gDTlkUYLGxJtVMHYXJsxeYZaQwi79Z/
fWtzELY8O6ZyXyyD71btbUg5HIR/sbBfDInXJXf8dKXSuHZ9pEF1dAcgDb+8
pcPTrTax3/3QZ/9cVa/DxMVFoTOJKmzEBHU65R/tIxxnSNyGglY7eGzlvu8b
RzPK+4BC6wqDQ4220FtVifm6T5OY6/KrJuuL4h1I5IohsefUHbEV3xiAdN2r
NHDh1WxAae+d3rg+v8Scf40qMba9+4IKn35rCzGGDcPLMOBMFZB15EaRf7cC
wV32hvMG/DN0rLQ3VujRYsDd6J9qBbpWJ30466No/Qo8iI152yBf7fIBypH/
srP+PPZzhQE7eWMVyqM78a/i9bAh859APyUZUICJb1fJV5d06mein/rZrcMf
R9JPDJxWie9VXfhVhWzE4wyoRYP1q8TnHgMmoJBhjeKNNeAub9yOiW9mU7xc
B3Mepx3M9ZrOSNezGu2vYMSvSaG6ixmMyrAjP6HCSeRfxuBF7M8hFb5sSPGc
2sQof5fgu5MBjtvgHKHvdieerfKUJduGY+5Xt4jfymAmPr9epfk5zMjfVWJ+
B5iYbwXev9g+z7zA4A1M+KgCB9F/ZxkcbyrOjd/ig3ZbxvK/GGxCvX5UAGUt
94chgH5Z4KM4DWHyX7KH9P0sLPyXSbqsDQu9vITnOpjnT3LwJPSpwSAR9bo+
k/yd5+DofEUxn4c0Q+ifSfp/oJO+r2SR/5iDceyGinTye7GXdCrQqf49Ip5H
F/Mq+Lt04teZBfEoTPtSoacfDKz/6FLh3wDY7u9a7dapn/uDxP9mnXxTmEPr
a3WhZw75o1UX85ZL+y8LvtOmg716rHS/Ife/in7IEf2YFyIejQzWYOCgQn56
yaS5HZkFhWi8cRbNR42XsGbRer6XzqdFDu4vu1fVyx1ch+dppyX8Ivo9aFF/
l6sSc79omsScf0K28J+D6fx0MM/zgkU6rAzQJ7OoH/WaxLwfteq1+BOV/GrH
4/Wn+OE+zLfHgr9tW930mwJ7UY/tIt4EhfJXCz3mK9TPx8X+Oh89b1nki94s
iv9I9P2YRXrlWTTPBwXOsEDFwk0f/IzzkerEj77f+P4eH/H505TzyvVuNyV/
vr/NhPlI9IA4H/pMcb6q5O9bHH2imJ93qdkSU/4g+TbdIj+OCEn+pH9I+oP3
bWqI9peYwzB/Pi9E86CYND+vBSifKvh3+kmv2WJ/hUb/B1wmPMNf+AHqd0cY
FmB9kRCdF5Ew+XhyiOJ1iPNgcZDOtwMOpn47mN4XYfLD0RDMRWKTwnJebuDG
DMP/+LzHsw==
               "]], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 
               3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
               1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
               0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 
               3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
               1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, CompressedData["
1:eJxlVg9MVVUYR6KXcwRmjRkgC4LUIeP9O+8+3oP4UBy5JNEWCzNm9O6795op
qDlK1sYYoUtDh4qLOTLGmuTMlTKmZIaJGVBOy8o0QyIio7KS5ojWPed33r0r
3nb39nvnu9/3O7/v953zUivWr1DviIqKmmY+jeYTbT7zVjX23Hokj96+eaG4
IlelCP7m9strut8IUfnxJbHRN/zAJSHas+jVtSNbmIWPbNB3jV1xWvjd/b++
1du3gOpvLO9KOWjjNxd3/jGZrFr42MebT7aWqzQycfDmhR1ZlLwyFLzWoNLs
mNK4rA3ZdJSv907FsdGZDQllCs34sq0yr0ejFV0pZqkAnU8zGbyi01B7y0cP
HAmAd6tO58zXEj8L0Jb7DhcNHrdxDk849L/1NAO8h/3IV2rQc92bmmZ/76Mo
/nnSAM94RtlX0x21ZQbq3+MBTrXxvXWnPjkwqFtY8NqtU0PC15/+9bgX61U6
9R8whdnPLCzWPYqF3zfLx1xSrP1F8FzX9EPJHTYW+z2tE6cbs1mhcd7IAZ2q
Rx9yTf/ZZ2HBv5FZWNlWsHr4N0YLVw+fT2uaitfwhIUM7zXLep1efB/W6c/J
z6tHHZL/OZ3mc/9s9ULHgcj+vbSUJ/5Chw+Oemjfull1p67b6yLfLzq9w/1U
46Vmvj5u5xd8b9v1N/KwJIOW7zAjH2Q0h/PLNNDPeB/66TboBy7ct4y46kMZ
hvQro0LTxhP3G9TEDTbGwCfOoCTeyGcU5DPzC51fz6GXeD6HjQW/Tt3CBVwv
TYdPvlPQ73Qd/Nq89EFrYvZVr05xWeYEaAz6zNfpRd6ffgZdZuqoP8iwz3GN
+LhNLGHQb1Kz8o3V5LPyf6Zi4dcYme9HDfvcxjA/lzTUrWdUlWdO0CFNzrfs
zzGN9vKCT3lpFu/nGY34mM1o9tDOnlvzVp3QaDfXa8ALvF4jP/dLiQd6ODT4
LyFb9jMs/eeE/qma1MuFfpbZWMzPLhuL+MU6xXO97nJS76MmwZCNI/MVweK9
BEPq70T/HzOg73Y39veCjTMctXsWbTTg90oXXeHnV42B/Z+Q+V4z5Lw6wbdd
9v+yG/Hd8ryo99FZzs/E8K+fxFeb9NOHAcxTiwFdSnOx/qwh9cwFnyJDzlse
4jMl3wUPo84Z3Yrnr+cbEhcHcf7G6Nh3wIv+p4eh451uuR8V89HoAl6nSp1d
4L/UxoLfXBsLPn2R+8CDOh0h9Hcts7Dwi6JYWPCPzZH+s7Hgf7dqYTFv2Sp4
b5L3TaGKfrQoFhb9aGL/xe8xcnL/mPlE3UQf5vmnEP1uXmszv5Lz93cI+ZKk
3+dIPZbJ8yRfRfw+eT4tVDE/o27kL47cj27pRxXzfNYN/apVYlygCg/62WDn
j9xvIn7EAz7dqjWvjXyeLtr8hR7XVFrG5/s0o5M8vkuV5yuDz7fb+kSwOO9S
ciyM+gF6gheuU+HHaUGLP/QPWv4Q/c0MIt4TnoLF+wVBzENVGPOz0496lWHw
v+yDXk/L+FoF/m0P0/Piwvdjf31hKuH7G5L1e8KIywgiX38Yv68M4Hy7bmP0
W7OwuM+LNPjhYpA6+P+ZrZo1L6K/LRr9C1IyyJU=
               "]], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 
               3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
               1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
               0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 
               3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
               1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, CompressedData["
1:eJxlVQ1MlWUUviLdiEiwGXPgMEvNghv35/vud38EDkNmGArC/S73fj/XYDbK
LE0didzczKmxcuDQcDFnZM25ObR0zPk3kdJ+yB9qWkglQyIC+tGSGWl973ve
+35r3O2OPbzvPec5z3nOeWdVrSp7frLFYplkfBuMb5zxnac1nP3rmRx4ccdo
NM8mQwyfWtc0Pf52OUSOFyXFDXvgNjmQy2FXwVsrB+tEjg+veWHHaK+d44/3
/Lb/3JdZkLFleOkxa4DjRUlxmdt+NfHreWLk+KsyDI4f+KN7uw22pX53YaxT
hunxwSm2Ndl4nh+cgEmY1LAE6dnfz7Z6FSg7RjL5oP3W3W/Wd6jQ/2HLJ48e
9sHlx67d2XhThc9rTu9Nu+iDxKv7Vuc8pXFcOzTXkRA18YPk/G8NCO2MAQ/0
bZjWtrBSh5dOGkLccIOB+jYs12GGstz/Y7IIa42yo9U65p/qQjymcew9+lnN
6ddM3Htn44qTvSrWWS7g/WYVuloL22/tETmm5y6JY9qHKxKvL4YDpNAEjeNu
Uq9PA0I3vkYCC/mUarCe1Dni5pjybxA5lurznxv4XYTdrzy8+UyPOgGvIAEX
iLCkKiXkvcHytwtw/lnjZooGfxq0hqyM/0INniT+eVOAmUTIJbH6BThIEi/T
4H2j3LtHXdjPWvN8e7ORsFGDQ8RPUQEWGDYbbzXj/0s++zWef7Z1066CYQ2W
kh8+zvgl6djPZDf2M02Hny4ZwvwgIl+LzvwqwjmCf9agiRhsVEQ+lzX0VaWE
8UY0eMKRcHDGu170z1kTU36zTEz1ekNFXa9L8Ajxyz8K8tsnIO8MFabYjAmo
FqGIGNmqog+7RNh85ovWwisK5u8TUY/3FCDjNl4kYh1tZjzqz48mYurXeBZ/
q4I861l9lQr6ewub34cUNt+sPzMVeIckVJk/8xQgZSc2u0An9zIV2En0+kqA
ZQQ3hcFD/FLqwjwdIfRfajbrZ4j5z479GwsxvRyIq8Mc0/xXTUz7BSokE73u
t6NvoiaOzVcM03m4rjH97divMh31fduJ8feamNbdoqPfVzuwP2061n+Cxbuk
s3m1Y1xLBPn1OFE/W4Tp6UZ+WRHmXw+MkH+P69jPDraPftExT3A+ntfpTM/5
qGeBzuYtB+8nMr5Zubg/czV+f4D4YauKeLEf+ZxSoI4sKp+AfroXBMK+/z4n
q0fG+WhwIG6U8bzQAdfIfio28RwyX5NNTPksCjC/uNCXDwSwvytFjqlfJIlj
yj/Jy/xnYurnCyam8zZNRh3XeVCnXBn70SJxTPvRJP4fH2H752IA609zQ5Tk
qw/Aze7FVSnfMj3aAhgvXcD8xntE9SgRgLbRJeP93Ww/eWX09ZAT45fE3kcn
7vOojPN83on6fSCDSASqcmE/O2UeP/a+0fuDLuTzdJDPK9VbDXL+9P7aIJSQ
Qepk+2FukO1XEd+jLlOfGKZ1ZXg5xvw+OELe3RMy+nGSn/NH/f3cH7S/mX68
n14xAdPf5/txfpsrcH4aPZhvZwXy73GjXqvY/U0Svgf3KuBl+uB7sN/FISgl
9fX7cV94QjhPc/wYr5jtC8WH+63WxNhvE1O9CsL492s/0PX1aZjPC+3vcBj+
A+kU0+0=
               "]], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 
               3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
               1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
               0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 
               3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
               1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
               0}}}, CompressedData["
1:eJxllg1MlWUUx69ISETMioyBoTayxKhZc0lw33veD0Yoft/3frwfV2GU2goM
mYXd3MyUyGEUNnJWptnMrdHn0lkyFTHNMrUmmbBi5VfYF02ZUtTzPOfc95nj
bu/ufjzvPc95/v9zzsOEypp5j4z0+Xwj2NPMniT2TGtUF56ZUwxLXv4tHigw
IcF76lqyki/Ph6qiH2c3hQEu3+28tN+cD5HCTw4tz9A8jnKOGR7v/Pvf757e
WAK5a/rm7koJejw9PWlyw++Snw1Mje1+0oRPOS8pgYYxp44OdJjQ1Fp98+o/
DVxXQ8PYxz/jVci5rycvpdCCjIKP3vijNIBx9tkwiaVx6bwCx+84fWVlvw2x
3WXpSUcUSOt6e6k/3/G4/sLEKalxyTfw9asOGOsePzcYBehdkdlWWuHiuq0C
o94VVS5sLWE7GRosW8wEW+Ri3rqOPOB4zGVpf0py95WVj33ebcMT5wZ3/LWV
ft9qw5dbeEDV445LTMj7Je84OOPBxl7wzpfg4M/vbDqQ6nh8gp/3IQfe5XyT
ijrNcVD3kGSRf7LmscjvWxVeYzLv/cEexkLHfA1mVY6OFP5iw1QuSK0GX7Bt
1NEO6v0wnafUgdcPjP+g9gUNxnH/Z1H8Dg3eG2tVFS1w8Hz9GvpZ78BVJksd
Wxc+NztwhOvRpKEPW2T8//hnu+Ptn5ey6lW9z4GLc3flrimi/NJd4GWxqlNF
P7NdULjxPSrm63MxPmMuk3rewTo/qWI+xx0YxcKuG6tivIsO6uQDrJ/9kkV+
EyQLvZ6zYUNWciijB+BWXi//WJjfMxruk2ujPlkalHFfUmz8PqvC6r2sEk5a
uH+3inq8ZWH/3aXB2WPMiDYZT9Tnh8NZ1OsMir+Wfj+K9K6w0M806t8baT1M
/oyzsJ/fJD8DFvbZCB1cHneyhXEf1WAB55YonjNPRz32RWi/EvIzQvVnoH8D
EdKLeFHUY7F/l2ThF5Behwys27jkRH8lWPTDT+SfY6Bf81zgX2kNOsbfLFno
tIn69xYD/Wlzcb5VU7xjLvWrQXnF8HuhjvoVxFDPF1XM754Y1S+gL4Mu8OOP
OUXz6FcXWLW3ZBl+8s3Fevm6GPXUXcwjVEw+ucDlzawuQh0Vx3v/DK+HtVRv
MxXMZ48Ftdy39zWsp6EQzo3DOp3HxP64js7XbKJvkww4zedTueQ7eX+NlCzy
mR5E/bo00Pnfrye+TXI232CKeu16KVD9SRb1fFSy6LdME+fDK4A6KCa+NyRZ
+JGkXcv9NC+/CeL77SrE+X6NQazfCtKjLbFO/cTuI+HbNg36uB8P0P3j0zHf
QhP6T8xkmdF8n23ifbOd5nncxPm0WEf9tpnoa46OfrL7LBE/cb/l8/e/p3zu
DZGuGupth7z8xfvLQphXH82HiSGs91QN76OvpD4J9ovClyx8KAvAxyzrg5+Z
WI8bFS9/UV/rFa8+Di9v35xdo+D7OeFhjHoo2L+tYez/52m/DWHMJ0Z+1ISx
H9NVvA+GwuhXJfldHkH/d/pR92kR1KtOwXjlNC8ggPOtXjL6LRnv2SjwbXI7
/SDGV2fU6xfUMQq3W3xCyf93/gcwRuih
               "]], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 
               3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
               1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
               0}}}, CompressedData["
1:eJxllAlIVUEUhtVsIURK27Bso03aIwlLe/+d96Rs18gyUlrJO/MyowWzMqJM
SiorsyJbLKyMiIg2QkssLNowkfaIMpVsAZOMLKOZe6Z7IR/cd993Z945//nn
nNtv8cq4ZW18fHx85bVAXn7yyu3hHx/4KBI+6lMh8D9v6HJh0rsQF0rW7O/h
H+iFKJY/Prjo+VeBFXW/ihr2AbeOh4x8Uyxo3T8ScwKHXzp6m9scOn/phLfC
4fGX7627+cpE5qfY673bupAa1fHZqcsmJspbaqJB+U+YWP9x0OgO+QzqcdQ+
k/Kd9KBpyII9ZYWtuefINwPaGR6o8MfLTZwtnzpuh68Hd+XNqDCpvkQ36a80
kdXtxeMfwR5cUfvrTdRU9H/187GH8vXmNlvrKf9xPcft7zKxn84fKmxW6RYW
OZyu8jUJ0ucbjeCtpfcLEryteHXy3i8bXW7Ir/CkGXp9ESOuFbT+lmFguy0H
3PsFvlVOX9zpEMMq5V+OgJLdcS4jP3P1/j4MssrZ1QUC8yKkM38Mqn+n1jeG
obrwyJ2+qTpeGsPJ6KuNLfMEnQMYlIwtsTp+d0b9EC+g0qSWGOTHfAHreMt1
fCZQq/yS+az6wgQ82d66Xzu0ns6C4jSB8g8T5FOzi/ys4TZb6/kOn2uQQpdy
XGtsqUo7DOw+mBK0NZIjPOlGTMAYw+bmDF68ZonDaaqfzms9BkdXGS69yoBl
ewzHGdUvDQbpi9Dn+97ANHWeAzn5cscg3d04lJz0sQyjlD+hHJ9lO2du0P6M
4AiTZXyfrM9nFic/jjHyK07rq9Z+JGj9QW7Eq/lZ/i8/g5Jfuk7HP8KQUyYX
NjvxrXgZHHLKZu7KYuT/MR2P6fO8yNFetk32awNzVfxbrdmaj1AnHvWDYfP9
AhlouMNPZDkZ9YD85sXbHKb5dbiXmv9rnPolysBLtf+5jtdi0Lw+1Vyi+7eK
U78kuKn/rjhs/T/ZYevej9O+tbr+P6b2R5//bxNXVb9EAJVKV7OJAL+h8hUw
keapD7fZei8tc9iavzKOGPVgu9abJ2y2+umjw1a9g73Ep0F+TfHSfOS5bH6g
6k2Mstmqf9ME6m//1my9Dx867+e/8LeRNg==
               "]], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 
               3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
               1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxllHlIFFEcx63EImI7sTDXMjKVjt11Z2bdza1fWYRdlJGViYgpOe9ttklI
dBhiERadmv1RVhpBRkmFR4Sl2ElUyCZlipWIhoqVnXTSvPd7zkC7MOx85r35
Hd/f9014+tbEzGEBAQFDtGujdg3VruJJgUmmp3EQwH5NFP7nx2WLaz7vccHt
7UWTAk0e/K9xwq4JlUs63lPwvPtVMZATC/XnQiztdRTY9j/Fblhrmn2j9C7R
2ZycMfcNNdhV9Sj3TpsKB4JfPfte5AKve+TLC1UqdDdNa/vxWsH851WQU28l
jEqXQFv1uk+I/Wus8C0q5WjjRX9m20ZOtAELf+6BCnWs3hIbPFzmKFzQpGLc
tzFYv08F7Wlal9cG1Wx/rwozeUAL5gsjOvP17P+4l4j6bZjfTHVm6dIqDN7J
8n2j0Hnx9L2pVguML2h4XLbB48eRthFXQkPs0L97vpy60gOffCvSx7RIyN0U
11vtEBGUfzK+iEK0lvZrlgTbmH7HKDC5hvZJqGcxxT6TZWAqdZZRuJ6Tdbz/
jIzPD1IoZ/OQZKzDS2HRITZRCZ+vF/lCZLC0Tw/KX01hR88M2wiPjD5IovCE
DdSsoB7JFLSoOyeYFIy/kEJJvBbwtIz9RVPY37f6Zth+CesZK/x21YH5Z4l4
pU7Us4vozNfPGHx5QBMmg2CczFg4cip7XEEcEf04dN7C/OlTdOZ+WqhgPQsI
xv0og6bK7vkJBP1TK/Ryivk+l2E5m2cEgVDm49EK9h8s3rfKYGX6mAkoLH65
hOtzCHz507yjJ0jG+awiqMdGCfVKHKzPjvk2EPRrrh2S2PnZPJjfDqz8hlwC
qw5rd5skONb4NSplrxGfx8sjOL9CCfU/K+IFy6jLNQKT2SA7ZFjH4tf7Mz8f
aUY87q9Lis78e+B26Mzned8BbT/ySN0+g/H8Gsx1qxXzMzugle1vGZynjOf1
BUF/hgr/Nov3u2LQf9UG8/ezDOZ9hxP0X6Xo/68Ko7W2PgwXfvitol4znODT
PjN5P8X3oMGF52kK0ZnHzTSYn79Ggn49rGC9JVRn7qceg3m/kR7kFbGo11IP
zm+YS2fuh7lxOvO6Q+ahvwP9+R9CWIsK
               "]]}},
            AspectRatio->Automatic,
            ImageSize->{{128}, {85}},
            PlotRange->{{0., 480.}, {0., 240.}}], ",", 
           GraphicsBox[
            {Thickness[0.0010416666666666667`], 
             {FaceForm[{RGBColor[0., 0.478431, 0.23921600000000004`], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               0., 480.}, {960., 480.}, {960., 320.}, {0., 320.}}}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0., 
               320.}, {960., 320.}, {960., 160.}, {0., 160.}}}]}, 
             {FaceForm[{RGBColor[
              0.8078430000000001, 0.06666670000000002, 0.14902], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               0., 160.}, {960., 160.}, {960., 0.}, {0., 0.}}}]}, 
             {Thickness[0.0010416666666666667`], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0., 
               480.}, {240., 320.}, {240., 160.}, {0., 0.}}}]}},
            AspectRatio->Automatic,
            ImageSize->{{128}, {85}},
            PlotRange->{{0., 960.}, {0., 480.}}], ",", 
           GraphicsBox[
            {Thickness[0.0016666666666666668`], 
             {FaceForm[{RGBColor[
              0., 0.42352900000000004`, 0.20784300000000003`], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0., 
               0.}, {0., 400.}, {600., 400.}, {600., 0.}}}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 
                3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1,
                 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{
                1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4,
                 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
                1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 
                3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{
                1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
                1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {
                1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
                1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 
                3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{
                1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
                1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3,
                 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
                1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {
                1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}}, CompressedData["
1:eJxTTMoPSmJiYGBIB2JmIGZkYWZkHkqIgRHoaIaBdQMAS8ME2Q==
                "], {{
                1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
                1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{
                1, 4, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3,
                 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
                1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3,
                 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 
                3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {
                1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1,
                 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 
                3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 
                3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
                1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 
                3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}}}, {CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQZaBQ73/Xun50kUOyxy3fb5r0qBw5YTZfvmA/nC
zQdOLZQtcNBuF7t5TrTYoXzffCl94QIHIZA4f7FDUcbEtzXf8x14dTfNff+/
yGFGHlBmVj5E/nyRA9j8GfkOny75JgnMKHJofR24Q25qvsOy2UcUNlQUOYC0
23fmO3Q6Jjy9AOQDeaZxm/IdqkXWuT9Mgeq/kO9gy3V9cYF/EcQ9b/MdFDYA
bQ4sgugTKYCYkwhVr1bgwAdyT26RgxbI3doFEPGyIog+Q6j67iKIOywKHKpA
9q0rgriTp8DhHcgdVVD3sBVAxBcVOYC8f/dHPkT9sSKIOyWg5l+D2m9SAHHn
zyJIOAL5D0Dhy1UMUQ/kP14KtBgYvujhDwBPyaXl
                "], CompressedData["
1:eJxlVQ1MlmUUZeSquWJEX2gNSawcEwtdmSWVV4uwOURpc9mIGeVGJd/33PuU
ljU2p4lm5oiVzp80FQdlStaatUnUyhqlox/GrBVJs2ZkgJmFrex93nPQLdnY
y/2477nnnnvu/fKqUuUL0tPS0hZHv+EZ/3yvcuLL0qrMbC+XL2trf7VTpebn
v5sHEl5mTl41bf5nKp1PHhs7cbiXxa1brircr9JdtmZdst+k8r17Lkl/S2XC
d9deuLTTpGHksLkZdSpvf7qodcsuk3XJrGVtO5l/n8nOjR+NbmlT5F1jcv/D
Rd1lEf6+3Gd753yuMrrFquvfV8kKPB5T8HmD9WerFIY6zSqNAedulZj/iyrV
9cefmVqg8nRid8kRp1JyZEli90WsU6qyPvDIJP5E9purkhMIjFD0Wcj3LlA5
ED64hfh/OeCnVH4MhU87WRj0OaDQ44yT6L+TKuca4j4HHo8b6nU54Oww6NLi
JOp2X26D4fOtzF/OeLaTW0NikUnHmG8Ha/Md9Il0i+tkOvCvVHltIPrjZAp5
2Qrcj1PgUUD+O1LIn6Eyff7RjjH3piTj+r2b+2o4t1LGL7H+r0n0u8BkSuBR
lsTnKziX4hTmUM+++lPIb3Zyx/Cu7W6Sk3F12YcPrXWYe4WDD4ap5AU9nhjq
V2XltIjQCierwrNJwaPBwX+7FO9tcvJDwNmg8kXoc4PDHPqdbCt+5/d/mhi3
s87XrPsynzdTl5mcYx198rwDnzX0T1Q3ntdhxt0O9X6hjwbIO81Q74SDr0Ya
+PVQjwn09UHyG2/op4n8Kg06RvrEflhpsiTg1nKuPfTNauafYv4eh/3J8tA/
4nd70PtKL5cG3frow7EeOOkq7wbfTPHy4R/5FWtz6J8KD70zz8WxThfTz/O8
zAh7MOgQF3v038t+y5nfwbk86rGPrezf+bPziONa8jlEffd4+Oro0Lw89J6j
58UPhPvSxTv0FO9Am8c+LOI+v0n8pKLPVzx4VXGvN3vsR7Qvv4V+n/OYYzn3
2VivjP3fyXgq92c844d4FxLEe4HvJ6hnO/PTqc+pc3F8xwZVPgnv9/BOFnHO
Z4z1DPPIIP5thn5vYL838b7c6OGXWbyn0z3mUm2Y22Ue7+0lXj/xuwx++cqg
658GH71u0OM07/Vy+vkb4j3CvA8Y1/DZSPxq4q9m3oP0+0KDLlWGOZSw36XM
v5r3cJPJqLAwx1QKwt04aLgjjbwX+8nvrvPjeL+2cn+y6Z8k/59DvHnsO09x
Vycb9noc8a4zzKtl6PuAfK4w4Ocb7tJ23sd/+X32k8EPJ/XsHOO8XsU+jvDy
/+/X/wAwLEGX
                "], {{277.25, 304.707}, {276.43799999999993`, 
                304.637}, {275.53499999999997`, 303.688}, {274.801, 
                301.855}, {274.168, 300.465}, {273.39799999999997`, 293.18}, {
                273.52299999999997`, 293.18}, {273.02, 291.012}, {275.789, 
                290.094}, {277.051, 292.879}, {278.93799999999993`, 
                297.98799999999994`}, {278.949, 300.16400000000004`}, {
                279.074, 302.332}, {278.78099999999995`, 
                303.97999999999996`}, {278.062, 304.777}, {277.25, 
                304.707}}, CompressedData["
1:eJxNU2tIk1EYHlNMIv1hEVZqU8JuhA21ixE9SmGxItT0RxcZo8twbvt2zvnm
yCjKZNmPTAoqRIbGgkpUokQq1ggpkRCVQuwmIpISEcOkpKK+s/cE/Rjfzjnv
+1zeS7bDW37CbDKZYPzk19LDnC1lHFPh1n6LmeNNYDbXupujfllX6aSJI/6+
neNaemJV6gJDtjwXchw+vmPi4DTDC9vWpuLNHJeK7dPDvQzVj/ctMedzimtj
aJL3RRynJZ6f4aYnrSEKjsbPZX1Zxxj6sox/JzlSNz1o+2pV8QHFn86Id4Tj
peTp8EnZJlOuoPuN6hwQKJ00GLo1yrsoyM8hjfCvCHTs6Z37/c2LL2d2FVZf
F3g04I+ESrzYK/PaBa4+n1939IkbRQ+Nh7AgX69dWNoQHWy/JYh/Ww3dRwSc
LRKphnB/KLyuGopP0Ynf7qJ6rNIxPvS9Yqqylvwl6ygxPjk2D9Jk/CIV/96D
G7I+STruxUYPONK95CdRJ367l/LNOum976V+OXRUygJylR/RSd96N/VvhZ/0
RVy4Y9D0FPmx1prcmfHRhThsvp90VripnhY/miV+0E04Y0pP1EP8TMd+mTev
9JQr/Vs0ii/VidemIUMOymodOxeP3daCGuoioZV5MYHhnHcLZ19pkOUOzah+
5vkof0JgRL5f8FH8uOpvq4/8DgpkStwERnqN+qTI+WlW8/DrH77CmxWQdpoL
GDYEl48Pdav+1av8WsX3lpGPKoG8D2uSzhvzHs8zzvG8P2o+CwTcn37ejY0y
0m8RNM9hRv2yKD/nGO2FMa/xfTnCaM4zBflwMsJJU3x1jPwmKD2XFf4Ap74+
ZTRv/ZzinzE1z5z8zqh9aeTU1zlG9T+l9juR03z+t+9/AejMx9k=
                
                "], CompressedData["
1:eJxlVg9MV1UUJixiVIzA1NV0/lg6I5uQ/UOETsMCV44shWSJzdH88d7v3304
3ruP5mbk0loTEkoxQnRkDCnHJMWKSJwabmSSERhDRoRgfwQV54rVu+87Qpts
7O7ee9453/nOd8/5edYHX3o9PCwsrNL5V6v795SkH+LP39g0ZtCi3gcjNidJ
rFcM+vONpx/PS5B0ZM6WSysv8z5e0hll/6tBzumROXESa5dBn+w+PvdguCR7
+mcZ/S0GmS3V9y+aJimj3zmpNnAeIWnbM68NnvGyfYykY9cWvLo90aA/lP/p
kjKV/Q2B9T6JuGOCdsy6PTt6psR6ScB+FvsfEMgjViKuc5+bn9KXdQ/bjwr4
iZI0dnbF+pirgp5/0kFSbSGffIPmHjS8ZSmS+rLe+zAQYZDLz7gFP2s53y8t
mq0OqgyKfqSx6q86iy4o+0b+3mT7bgO85VkUV9LaXjNsAEeWhfwjC2mrWp+z
gL+T+U+3YFdrACdZtPbo8rvDg8xnOttnGJSnzp39w2/P6O5IMhBnjQVeI9ne
z/ldFuD5EMffKShRxZuwKDWqa18oRTAe5qcnROes4flJ2ayHuBA1q3xyJRWr
Oh4NgB9N0t5nv7gysdBPyYdOFbVskLQzEFvS+qYPeFZIcqJrX+3REfcxSaUK
yLu37l19REvwu04nj+LzmkUnVaFKdeQzYCHvah1877Jo3Enr2BbfLXu3PoUW
8Lb7EC/XIrXEH/YBP03Zu3mPm+D7uk4qneofTcpWji5p0M9ek7YrvIs1SlO8
VZh0l7OkRmnkH/q7bjRk0ryIzRXpQwXQZ6YJP09o0Ft/EQ3UOgV6UQc/s03w
c4HxxZjAI33QQVMR8q3X8R56i+iEcrSK8YwVUZPy78R34zjfu/UqK4BeHzKR
57ICrPkm4kcWIP4uk7xlDtJmL/C1mXRW6WXEC/89jMfD+cSwnh3/Lr57LcpR
/HzOeBIs+L+oQT9Lrcl8XV16LVK0pabp8LeJ72N06HCHRauVv04NeR7g+h/Q
UP/TFutFm9Svm/+jGuqfzP0sXgOfGyXqVaghz6qbetTA02FJSxRx59n/93IS
r8vnRd7/rEMfv0gSCuieAPD/xP1wRgj7fyR1d1x/eeDbIPTnscnpDrElq4Lw
n2GDz8EA8ObYsN/mh+7W2dDPYtbzGhv5jWjAudpGHnWc72kb9Wjg99Ru4z0u
8IE3Z/+NE7a33MfvwCYFp3XcN2nv4lnpB95pxTRfxd/tQx9LKYb/fn5vwWLY
z9Ohp9Ji8JOpw/9bxZPvy+UjxPbD3A+S2V+Nn+eMje+9AfDzNeO5Lch91UZf
aQtSgupz+2zWfwj2VTZwmiHk876NPBpC6ONbbdQtTODesoGTBOq20QZPuQJ4
Nth4N/UC+eps3yiQr8H8HhfA/Y6Nvnjz/gPGc1IA734buu8RmAev2OjDn/J8
SWT7Ae7/Hq7nhIE632kD51UD/fk3no/f8fw8JdEnGwyeIxLf+bn/97F+E3n+
TPA8Lxewn2lzn2X+FjKenBD0dgfvy0Lw4+jd5aWL+d8vcf+AAO+1EvPII3Bf
w+8reWrv+lkytXf5XSowNyrZfzPfV7D/LoF+Ui7RpwZ4vpdJ5oX5/5jtB3m+
10uc97C/Bok+0y2QdxPzeU6g7m38+6FTkE/18w7GO8Lz8QT7/1eg33/E7/8F
5reQ52cl87+c7YcM+Fkmod/fDXyXxvN1lPXwv99j/wFFn1ST
                
                "], CompressedData["
1:eJxTTMoPSmViYGAQBmIQDQZ/kh0uKN3+WfeuyEG4+cCphWeTHcr3zZfSf1/k
8K7G3jRuVrLDjDyh5gMPihzegvjrkh2qRda5PzxSBBFflOzg8bBKZN3WIoeM
iUAVnCkOO+VaXwc2FTmosTVOdZZOcXi8dPYRhbQihwmHvmrEaKc4gO0Ngspz
p0D0CRY53PlZl7VHJ8UhKsX6vj93kYPVlhNl+7xTHEDUfJYiB67riwtsy6Dm
WUDd05bi4A6yPx1qfn8KRF9jkUOBLVBHR4pD3C5PHqbbRQ6qIPv4oea/LXJY
5Lrt818OqHuA/t8KsocpxeG+f+/0PCAfPXwAlnOEaw==
                
                "], CompressedData["
1:eJxdUmtIlEEU/ZSQkJCw6EXJKmEPERWKwKiOhZRFhAX+kCxZE74HbvtNUPFd
EexB7I/KJWiLCKulHwtSIhK9WCJ6SIEsRciiZraJhGxRSesSQjN7pz8NDMMw
Z84599xb6j9+sD3fMIwKudU5ceBiJNBEMNT6JnAq3ruqqpGwvXAkGkwLXAsU
n322l9Ax/Sf244sALb23exIanxA4P9P4sGQD8RkTjPMRqsbXFnS3CXxS/Bs1
vlxAsr253UbYtyVU1xoN4ue7/f7Flwjrahb2rW4OwFP8Vwlj2S77aZ+DosqB
m9/DhNrBoZNxx0GibDTb1aP1GhyY4XTnjm5CXetUoixjs+5RgrtNFnDLxqMS
iawlvFKCm2zGL9d+DBsfTn8tr5n1mP+thSXKX8xDcjhzKHXdYnzYw07Ff8LC
muZjWyd2efi9/vDl5yst1pP3XC4DJtdzxmM/901UXFiWHE57eK30h0yuu4OY
P2ky/0ti/pSFiMp7jFCteCtt5PozR2h53LAoX9aX85clyF+bjwiH/eR1so/6
AO7UP/g1P6vrPRfkPOMEX78wwyGX9Z8QrqxY0FQUdZG6e+OFr59Qqt7HXdYb
JJ6DKRcqxuA/fMZFDv5R9y/lsv8Zneeciz2TUnGeEFIBFArOo0fzRQT7t/T9
veB/fuJ8PgvmayGodvTKefx/Pv8COAIxWg==
                "], CompressedData["
1:eJxTTMoPSmViYGCQAWIQ/emSb5LAmzIHBhB4UeQg1Hzg1MLnZQ7l++ZL6T8v
cpgswRLG97DM4b5/7/S8B0UO1SLr3B9eKXN4W2NvGnehyGF6HlDHtjIHPt1N
c9/nFjlcrXipZrimzMHgrgpbo2yRg/vDKpF126HqHxQ6LHLd9vkvSzlEn0+B
wzFv807HkHIHl+6c57935kLUu5c7CIPcsTPLYYdc6+vAnHIHILlDDsgH65tW
7gDSlpCYDXHPinKI+zlyHGaA5DeVO/iA5N/mOBwHKVwE1V+Z65AxEeiS+VD1
DHkQ8+eUO4BsfdiW55D7/PfKj0HlDoe+asT0pxU6gMPHpdxBYUNRxsSZhQ6P
l84+omBUDhH/VQhxR3c5xB/LCh08QO5vLIf4916hA1D26YUkqP2qRQ5WW06U
7RMth5jTUwRR/7cMYv7JIgeQ9PwvZRDzbxU56IPC8XMZxN0vixzQ4wsA2srK
og==
                "], CompressedData["
1:eJxNU39ojWEUvi1JaAl/rDvmGtlKmisSWp5pmoWWH1k0WrfpfVsMZzKNbiFl
dNu0NCVuiHIzrm22tc3aLzYLXdev7q7PbEtICKFLyvt+79Hnq6+v533Pec5z
nnO+2b49G3cmuVyuxerV3+qe75lFhRIfD69csuM1IfQlut6XK1FXNvVY1ytC
7qldb397JSqn38gbeU6o0fHzJVz6GSTkFL+JpGdIZFlzxx/pJtweONAZXCSR
PfHF5b2NBJt/jkRFZ9CddZMQTY8n/G6Js5o/RDj+YUNrWkJgeZNKrOf7X8LE
33Wwvg4+IBQmL2g4/1lguCBQV/aUcGl187c/7zg+RtBls0cF1i6tyimOE35k
FlX3WMLofcn4sYNXaf29AnkjqsM46+1lPTHut13AEyZ5+glhmT5vEdhWsmK4
4CHnN3L9fgfb/F1kdNwSUN0OXmxhf0ICVdq4JjK+X+B75dc+bVyNg2fqQrUC
h7T/DYShhL+044Qwec2EDO+E6zOOcr02wid9XimM/+0Onqb5uh1sxw8Qtrfl
T06qEHh28P08b5T1lzO/mvc6rX+3QL9uZIgwduVcn6dE4J7Gyj977luZ3yLD
6xFYqM8t1p/K8+rgfZnF9cNk+nJzfj33lyJQmzJuS3I5xwv2y0cI6MWMCKzR
88onxB793DR2RqI1TW3SZjJ1A7xv1xx8VckOq3qT9H6clLDX6P4/P6XhjxDu
7FeV/dLM12J/SyW+qt9iyijr+e9/+QtnxnWn
                "], CompressedData["
1:eJx9lG1IVEEUhi8S/giL2CIiQsxMtmDbXe2DCvGEFoZIn0SISEiBcO+M3jEs
yiJZQiNiMxGtCOmL6E9IlEmQiUVGP8RWIpbaNCQkosSiIiTozJlZZjLowmV4
7jl75j3vmdnlNXW7D2U4jlOCr1wnbl5+mvOWQU6PqG0bE7Dx3vPG/gcM5NL9
TsC++aG7VzoZFM19fb0+KYDymxh8aSpeV50Q8Fmu6xmwyZnb0z0CHh1uXzIn
n0H5hjNbDhwXcG1r77ffVQwc+VQKeJn75tfJCzpeIWBZ5cHNY0MMxnec6+QF
uv4NrWeFgMfdS8OpLAaY/WEk4cPKzOaOkpgLq1sWJ4fLfTg/+D1YVefCkX5M
LNRx5OqH27MykO/LPrgLTzAtXmCY9COTHuRXRz/mR634JmlA1DDpsTicysts
jprf17ahE1ac9CB38UBsAJl8iPgg28hFfVJ2PGL0k4/IDbIQcl/26U+7kMm3
ehe+JipqFiCTP8j0HXlIGok8D8c0FfaVX1ac9rUYq/Zl+yZ/YWzgxVXkgFyR
f6CsQV/3i1x61pucsZh0CpNP/QoTn800jwbtB3Jc9jubW1wYkT4G9f4nPHX+
glp/lwet0rg1Wv9Fw6Qfmb6n9SOn6yeHf+6ZsDgh97lkmPT+h9P5f/VnMfU3
pfOLtd5TXJ3XPPEP0/w8DmXvjy26E9Lx/RyeyTmu1fFSruoVCaU/xFW/23Q8
wtX52Gny0/eL7ustDp68j4063sqVn72a93Klf1Qo31ZxdX5TAvAWBmIOV/MY
1/nW/8MfLAnpTQ==
                "], CompressedData["
1:eJxTTMoPSmViYGDQAGIQfUHp9s86lTKHDseEpxfuFTmU75svpS9f5nDM27zT
EcifkSfUfECizOHx0tlHFK4VOVSJrHN/yFcGUXewyKH1deAOue+lDjvlgKxZ
RQ6xuzx5mJ6XOhz6qhHTH1bkUA1S/6IUol68yGEHSJ0MVP/mAodPl3yTBHTK
HFTZGqc6f89z8HgItMG3zAHkHCX9HIf7/r3T8wLKHLivLy6wfZXtAHJWgneZ
AxeI35btAHa/SZnD2xp707i4bAetdrGb5+6XOgg3Hzi1cG2Wg9WWE2X7Uksd
ijImvq25nAlxz4MSiPn5mQ6HQe68VOIQB3K3fybEPpZSiPnHMiDqXUoh5gP5
y4DBsGFDqcMEkAfvZzjYghTylzms+gj0SESmQ1SK9X3/dKj7p2dBwrWuzEH/
rgpb48MsiH9XlDkUgjQ2ZEPUryxzYACBP9kQdRuh+s/nOUyWYAnjm14Gsbeh
AOKeBKj6tkIHO5D9sWUQd8wvdLAE+Te+zEFxA9DHewsh9qVAw/toIcS87DIH
A5A9Zwsh8dtU5rDIddvnv0cKIe7pL3NQAOm/WQiJj4XQ8H0DNS8Oyu8ocnAH
yZtD+UeKIO4ygLrnchHEPG0o/36RA3p6AwBMEhxV
                "], CompressedData["
1:eJxlVQtsFFUUXZCUAoIoTQOKda0KbdS0BcFPU7gtEILSIFaCkM3abmfezEDp
vvf8QNKKIKAhKIWA36INlhrExhDSVjBa15ZYYwguJYRUfiFVS+XTIn6iSOK8
OTctSTfZ7N6Z++6ce865d+6NxZ+xh4dCodX+1/x2N9QeDvfbdPdyK//ccU2X
q2fPiHbadGJN75S8To5bbPq9szg2/jtNrXV35pzZy/nNmkLms8emzYWlvySr
NT2Qsv7tOfU2Pd70/cutczQF9ffbtOni4oMZt3H8M+cfUPTWu5V3bPjDpgkb
Ej/sLlP0V1akpm2sQP4tik79s3bFV2mCkpn+v42SXnC3X66usulghp9xRNIx
c/01rj9GUdfRv0u6G2wyj6+LKPrsqg98l02req5/evW0om8M/mqbcs/cn7L+
hgJ+y8ZvhiYDK3M+9ztFU6epP9qmT0wbYU1XDB8/WeAnU9PUvNTGyVGLzi3y
OzmraFvbn1mRfAv4KofGAZ8ZFpm2E49wv7dblGPwDON+QxaF92t3e4cErqZy
MmVqPuJ+15Yjf5Sijqce3Vz4dDmtNsIsVdBlejkFtKdr8PZrDNd7Fe0zfCRj
wPGsoq9f3DFxREuMzO1FxRL6+M87ZPBOk6QN3z2M7z4JnQos8DOT+Wy0aLIp
4Ciau6Wi5/q3Fp67TsEvFyzw78dB/UsW8JQNxgG/aySZdkp7LapK+3z++Yck
dC22gTddQo8PbPSXIqnI6HXRpgffSO86OkrCT2GBeqncDwmKfrng1uHtcTpt
+F0ooFtLJfyyTJAsGH2yfu8q4BaCnjAGqq0YEgf9hh3ys2WBqIB+2Q5wl1VS
s/HdNAe4tsSB+4qgdqNfkUS9dAd8Ps/6TnRo3MMHPuyrkqhfyvVekVRjhN/B
+XFJS0xitwO9SyTmbaQLf+Vyvxs5niXRZ5EHfz7H/DR58NPrXP8LD/V/lPBT
o4f5TGN/7fLg9+WsVynn1/H8uh6uNyrwlO9BvyOcP5fzuxTz5sH/rTyv73v0
8byWazcSPA8Ng/kLDQ+bOH+cho4lHvQu1Mgf5sF/SzXmo9XFfL/E+ybikrHx
7DjHj7mon6fR/1QXc/0b41/pQpd3FO4fd+HDxYr96YKPmdxfqofr/jwG/vyX
888zv+0u7h+T8N+bLo01ep/keY6yXv1D4+B8hwM+s9RAHPQ3Q2Ef9rF/mnmf
JR3Mx2Hm85CDehcUjTH872M/TdK8Tx3gzWY+lziYnyc15jTHAf9RTcrMyX9i
IMY+FwP5Ac+7Bb1n7o/n/ISA/3byvugXwBfhfTWB8WQrnF/gDOy3oH7uYBzs
07sc+PcS+92vF+yvazw/Sa6fxvtuD8/vMj5fy3gTg3HQfx/vw60C748s9tur
As+vZ79M5/Nt/L64h/tL8vtvpEAfJ5ifm96v/wMD2V+O
                
                "], CompressedData["
1:eJxlVg1MlWUUvrNmLRXLLK9JKMyAVg6wksKxDimZYSbaLubMGNzLvd/7/d5P
+zGbm5FL1wTEkjYypiYk/ZnDFvmTkANMggvOOQtGzLVshc4xs9bPet/3OYOt
2Nh3z/ee95zzPOd5z/emlrkrIxMCgUCd/FfP6vZrmWszBG39pfiLlLM+XTxQ
f2pOUODZ79M9E7e8vegmQfe9ceeFnm990v6jBmUNzp245YxPi9+0fvrzMwP7
23z6quGurMENBm2a/smS4fc53jaD7l4TXjhk+7Qsd3tB6TmDYjtHXn20Mk6P
tHS9eELGP/fyz+k5CQ/7nxG07sulkyeccen7PzaLY6WCAurvLZfecaZVnpwv
KJQ07/CeIhf1XDfgv8olGfWhdbUG3te5yLOR67mV43fHSG2/MsVDfSti9NIJ
uSDtCz3XV11si1Jfmsxc62L9UJTyVJ1TXapRceujlKzwNDnAtSsKnnKdMf94
/i3n9w/YjC9Gj5X+mEhbbyO/F0Odm+2xeqS3l7/bJk/tCxrg6YhNzylcJQbw
Bxz6LXNtdXvcgP9le8zOyLn5o2Rp67r98fX/2kdkOQ3+//2zVT9Hxm2dX9qa
10qDdtRJ4hM27Sv8fPRvz6APr/Y/VTZgIf+UGHiYbYH3B6J4f9wk2a1v9m6t
AN5GE/xkVgDnaovriABfl4W491dQZ5EswGO8eyKoP8mB3+/lVKD47DXQL9lf
8M/PGYLU9tJhGzpNFeD/Bgd9IQHe5zqUUHhDAu+TuX9Sbxpv0AHemKD1SkiT
eN1ifY7a0EORQJ2tBvLeWwG9uAbevxABP1/zOVvKeKeb8FsYQR0dJvjLjSBO
jgWcWRHw5FvQcUqE9W2hnsnMT6MFvQ+HwXeHhXPSxLbcD/2GgfcHE/xsD1O6
4s000f+qMPgqGrcnqfjfCeixM0wdqsDXo8wT8zsaA95rAv1tMdGPchN1pdrk
qx+jgppVnx9kPoMm6g85eC9t9MUBDzNNUmlOhlgP0sa5cDB/ZnIeaeu+zDKB
W9oal7T1OZS25lvamv/VDlWpwMkmcEhb60La0KcD3lNMUuNhUNpal3NM1PUs
15M6bmu/Dzhfpw0cFRa9ovr2OOOtseC/0YF+91o4l7UO+O7hPu/j+CMW+HnN
gR5KbPRzAc+fqVznGtbzAsY55NCAmp/LOG6ZSyWKl+dZ15d4voUdak2Ryszz
oI/ZDs5tlgeeLtmwMzzU02cj7ywP57Wb50LQA49dNvLf4aEvkgcdf5oH3G02
Hd+wK3jjPy76dNSG33kX8eXc0/o85CJui4159LGLeqR9WeFvdoHrMM/ZJsb3
Kc+t/fy9aOa59x7HP8D11buIu4PnXpULHZfb4HO3Cz2U2qi71UX/ySapuoNX
05mPVotUuIZs/p7ELOTf5OK8y3Os4y/neN0m9hVy/e2st20ueO3lc3mbR7cr
3neaY3zr/XJu6PhXXPT3V0FDT0vmazzwdUogbloc/u8KxDvKdkLg/B6Lg+cA
6/dgHPVnmyS7E0rq5PW/BOwZPuqo5vtAq488K3n9NN8HigW+p9LWcYt5Hp/m
+8EKrkfamuflPBflfULr/klB+jPazfeHJwTyyvuHPvdLBPTf42OuFHL+XvZf
zPGlrXlaJPC97mX/At6fYH/5PWhU+aSt+c7nevt86lf48jh/H/s/LKCDfsY/
n/PL+5PGMU+Qos07y/enjPH1fwEq9CVv
                "], CompressedData["
1:eJxTTMoPSmViYGAQBmIQXb5vvpS+d6mDbFSK9f2LRQ7HvM07HQ1KHZbNPqKw
4VKRw7sae9M4oVIHj4dVIusOFjkwgIBcqYMMSP38IoeMiW9r7MVLHQzuqrA1
9kLlI0odcp7/XvnRr8jhgX/v9LykUoelIPN0ihzA9pWWOjwGCfwodPh0yTdJ
IKTUgU9309z3RwsdhJoPnFqYDlW/r9BBGMSvLHU49FUjpn9bocPWE2X75k8q
dVjkuu3z3y+FEPvmQNXrFTkAXen+cFmpA8gbCbFFDoobijImtpY65ILcs6fI
4T7IPWFQ/10ocgCqenohqNRBAaQO6P/JEixhfP6lDtrtYjfPXYS6Fyl8AH3A
iKY=
                "], {{238.277, 297.52}, {239.04299999999998`, 
                297.59799999999996`}, {239.97299999999998`, 
                296.89099999999996`}, {240.42600000000002`, 295.895}, {240.91,
                 294.828}, {240.668, 293.812}, {239.875, 293.617}, {239.086, 
                293.42599999999993`}, {238.062, 294.129}, {237.578, 
                295.195}, {237.094, 296.258}, {237.336, 297.301}, {238.125, 
                297.49199999999996`}, {238.176, 297.508}, {238.227, 
                297.51599999999996`}, {238.277, 297.52}}, CompressedData["
1:eJxTTMoPSmViYGAQBmIQfd+/d3rekSoH/bsqbI2eRQ5a7WI3z62ucnhXY28a
51XksMh12+e/E6oc3B9WiawzL3IQaj5wauHsKofW14E75ISLHOy4ri8umArl
/y90eLx09hGFC1UO3uadjgm7Cx2EQepvVjnskAOqmFbocLXipZrhoyoHPt1N
c99XFzpsOVG2b/6ZKoec579XflQrdAC75x7UPPlChw7HhKcX3kH1ixU6yEal
WN9nrXbQBrkzEqqerxoiP6PQoXzffCl94WqHi0q3f9btKoSo+1nlcPirRky/
URHEvHNVDrwg+92LHBQ2FGVMPF3l0AkS9yiCiB+Huh8YHujhAwAjvJH8
                
                "], {{323.22999999999996`, 289.99199999999996`}, {323.371, 
                289.367}, {323.512, 288.734}, {323.605, 288.094}, {
                323.91799999999995`, 286.707}, {324.191, 285.332}, {
                324.47999999999996`, 283.969}, {323.26599999999996`, 
                285.641}, {322.262, 286.98799999999994`}, {321.828, 
                287.469}, {319.082, 290.72999999999996`}, {
                321.89099999999996`, 289.613}, {323.22999999999996`, 
                289.99199999999996`}}, CompressedData["
1:eJxTTMoPSmViYGAwAWIQXSWyzv3htlIH/bsqbI2JhQ7e5p2OCWtLHWSiUqzv
xxc6XK14qWa4pNRBqPnAqYXhhQ7VIPULSh2WzT6isMGr0GF6HlBmXqnDcZBG
p0KH3Oe/V34Eqj/0VSOm36TQIWPi2xr7uaUOO+RaXwcaQPXPKHWQBZmvXehg
ueVE2b72Uof7/r3T8/QKIXQHVN4VwQe7y7fQIW6XJw9Tc6mD4oaijImhhQ7u
D4E+qC912AkyP6oQYk9NqcMFpds/62IKHT5d8k0SqCp1AIrukIuF8ksQfLD7
c0odgKY/vRADdR+QD6ajoPyMUoelIP+GFDqU75svpZ8Oda8fVD6l1OEYyIEe
CD7YfMdCBz7dTXPfJ5c6zADZY1HosMh12+e/CaUQcVOo+iio+cDwYgCBEAQf
HH6hUPXGUP/6Q+PLvNABKGsa5wO1zxoaXh7Q8LdB8MHx5YTgT5ZgCePzLHTo
APnbrdQBFNz+wVD3uEDND4e63xEa/tGFEHW2pZB4hoWvBTR+46Dy0qWQdAPk
C4PSjSQ0vmyh/pGGutewEEID5cHxAIx/cDoTL3XQahe7ee5zgQM4fdpB3fO4
AEIXlzq8A/n7VIEDKPnMv1bqYMd1fXHB1QKHByD/XYKmB61COF8bZJ4hNLwu
lELSkTc0PM9DwzewEKLvFDR+46DqD0Ddm1zogJ5fAElDb5M=
                
                "], CompressedData["
1:eJxTTMoPSmViYGCQBGIQffPc9+DHc3MdZKJSrO/7Fzrsny+lf3dCrsOhrxox
/QGFDrIg8fpch6sVL9UM/Qodjnubdzrm5DrskGt9HehR6OCY8PSCEn+uA5C3
Q06/0MEJxH+d43Dfv3d63pMCh0Wu2z7/Vcl1WDb7iMKGHQUOamyNU52joeZN
KoDYtwFq3oICiPl7EPyijIlva8TzHLaeKNs3f1aBA9i9vnkQd30lzC+05bq+
OCDPQWED0CT+QodjIPOfQN17v8BhC8jcbbkOnSCP3CpwALpaqBnonskSLGF8
j6HuXwINn/cFDsUg98zOdRBqPnBqIXuhgzCIBoafJcgg+UKIezfnOujfVWFr
NC90MADRe3MdrEDyrgj5DpB9wPBED38AsCXAaA==
                "], CompressedData["
1:eJxTTMoPSmViYGBQBWIQ/Xjp7CMKkyocdsi1vg50KXQ45m3e6VhR4aC4oShj
omuhw/Q8oeYDMRUOnY4JTy+YFDpYbTlRti+0wkH/rgpbo2Chg3a72M1zQD7I
mA1/ChyApuyQi69wKN83X0r/Y4FDVIr1ff9YqPn3Chy2ArXPj4Lqv1wAof0r
HN7W2JvGnSlwyH3+e+VHkwqIOTcLHCZLsITxWVZAxO8UOFiC7FeGyv/G5Mfu
8uRh4q+AiLMXQuz/XO7wwL93et4vqHselkPc+67AwZbr+uKC61A+0PxPl3yT
BC6UQ/y1F6r+djnE/fOg7vlZ7gAKpoR0KB/oXwVQeHFC3dNf4bAMZB5HgQOI
O39ChcNxkAarAgc7kH1TKxzA4V5TAKFnQN2/tMAhYyIwJGZWOBz6qhHTv6XA
oVpknfvDORUOws0HTi08CjV/NTT8ThY4HAap21UBcc/ZAkj8XamAhPOuAocL
Srd/1l2BuudUAcRfF6HueQUN/9MVDjNA8SwBjd+d0PjUK4S4f0OFw9WKl2qG
NoUQdyyE+te50AE9/QAAyMoYyQ==
                "], CompressedData["
1:eJx9mHuMVcUdx1ckykNZhK1aRWVXKgTqk5eCawfEAraGWKM0Pimi3fs458w9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                "], CompressedData["
1:eJxTTMoPSmViYGAwAWIQHbfLk4fJuMih9XXgDrngAgf9uypsjZpFDrZc1xcX
BBY47JADyigUOQg3Hzi10LPAYZHrts9/ZYocls4+orDBpsChWmSd+0OpIodj
3uadjiYFDpMlWML4FIscrla8VDNUK3AACSdIFjnIRqVY31eE6hcpcrADmS9b
ABFnLnL4dMk3SUChwGHLibJ981mKIO4wR/BjQe60L4C483+hQ/m++VL67gUO
Wu1iN8/9LoSY413gcN+/d3rej0KIeX5Q/d8KIe6F8T8g+BkT39bYvyx0AJKm
cX5Q970ohJjjA+U/KYSEg1uBA8ga/8eFDgwg4ACVf1DooA1yhyWCvwxkvlEB
xB1A/juQ+VpQ998thPhPvQDir+tQ84Hh9RjksAsIvhXIwRcLHRQ3FGVMVC2A
hOuZQog5mtDwPwH1jw7Uf0cKIeboIfhg80wQfLD7rKD+OVwIMccFGl8HoeYD
4/uC0u2fdfsKHXKf/1750QeaPnYWOhz6qhHT7wd1z5ZCBxmwQQWQdDO9EBIv
/lD3T4Wapw81fzrUfiVo+E+Fhj8w/i1B6icXOszIEwKmuHwHcPrcXejADTTW
dlW+A0h04Xto+FfkQ8zNhaaXqflQd0HTm3QBnA92lzKU71MECQcbaPrxhup3
hqYftyKI+QFQ/9sUOUwHuSekwAE9vwAAcUN0QQ==
                "], {{401.562, 
                256.668}, {401.47999999999996`, 256.684}, {401.387, 256.68}, {
                401.289, 256.64500000000004`}, {401.289, 
                256.64500000000004`}, {386.039, 245.797}, {
                385.66400000000004`, 245.418}, {384.15200000000004`, 
                244.07399999999998`}, {384.90599999999995`, 239.348}, {
                385.66400000000004`, 239.895}, {386.758, 
                239.47299999999998`}, {402.105, 249.875}, {401.812, 
                251.094}, {402.484, 251.055}, {402.805, 256.445}, {401.562, 
                256.668}}, CompressedData["
1:eJxNkl9IVGEQxReJ0r2uyNZDhoqaUC9hPoRkiJPUQ2QspXlTQmQxkCgn9hP7
t22a9BAhi/RgIiEaBUmQRIWGilioRSy79tdELFR8CBOTCpGgmd0D64XLx497
vrlzzky2l0+cSXA4HPny6pk3k7u5Oc3QodvnFte/M0V5pyGHPvNMo793nw7u
NVTXtuQvnmG6+eN4f2aRobv17paREFNV7YFZj8fQ1paRt90DTK9UX2VoKvS3
bK4D+krobzDd2b6pIkV4V37i43Thi8NdO/KEew6/WP3XFNf3rkwe8zbF9YXP
JhqHrzPNelrb608ZiuRMrwUCTP2ZckN4qEGUwmNHC24dFC6Vo+Ya0y8pkyo8
96DzdZafybXn6b1l25BRQ1eZ0tWAcEnNQjhH2K0+hH/6i/dVX0EeNvK5zFTk
/Hz/gg2/wtFchL+uBc4OXkL/NvoXDmufFYaWtF4jU3afr67tJL43MLVrLuXI
x8ex3Euh9zLtV98Fhqa1fi30udBLfw/FVp/bkJ0ixoLodwvyesIxXaKJ3RuL
c1AHO458kwy1qmAC/QtHzzfwm4R9eIf+nIaeS/muEOo5oY8wVb88kpxgIa8I
5ivs06Deoz8L/j8wZWkeFv4vnKHzsLAPwmpr2UL9j5h/MvL5hPxdmO8X6F3Q
TzHJFiyEUw39kbUclf09v7j+aGUb6n9DPxv2/z+FclwC
                "], {{172.066, 
                252.312}, {164.168, 252.168}, {152.598, 241.953}, {
                152.29299999999998`, 236.285}, {160.629, 240.289}, {168.816, 
                244.14499999999998`}, {177.29299999999998`, 248.285}, {
                175.92600000000002`, 250.32800000000003`}, {
                177.21099999999998`, 252.168}, {172.066, 
                252.312}}, CompressedData["
1:eJxTTMoPSmViYGBQAmIQ7WPe6ZiwNcNh1cdLvkkS+Q7qhhxrZM5lODxeOvuI
ApB/3Buo4EWGg2xUivV9bqj8twyH1teBO+Re5jlsPVG2bz5TpgNIWcLJPIfp
eULNB4DyDCCwIs/BcgtQwfMMh6KMiW9rpuc5hPHpbpoL5Pcf+qoRA+TLgMwF
8qtE1rk/nIZQDzYHyAfrA/Lf1tibxgH5qmyNU52BfP27KkBWnkPsLk8epudQ
9wD5q0H+uAO1rz3PwTHh6QWl7VD53jyHPpDBc9D4NRkQf/TlORTacl1fnAP1
7+Q8iL8iMxz2lkyWYFmXBwmXgAyHOJC9p/Mg4ZMDte95nkMvyLwKqPl/8xwK
QOYB+eBwBvJByuwrMxy+acT0H/oLNb8Sav6/PIcZIH9XQcOPId9h/3wp/bs1
UP8z5UPsrYfGF0s+xL4OqH28+RB6JtQ+Uaj61VD3iedDzFkHNR8Yv2B3bETE
P3p6AAAFaeu5
                "], CompressedData["
1:eJxTTMoPSmViYGAQBmIQrX9Xha3xZYWD5ZYTZfs25zlMlmAJ47tc4cB1fXGB
7bo8B4+HVSLr9kLlm/McwOqPVzhYgfj2eQ7e5p2OCQcrHGSiUqzvi+c5MIDA
swqH4yCJnlyI+vcVDuqGHGtknHIdPl3yTRL4UeHgA9LHm+twQen2z7onUPUV
OQ475FpfB36rcOidnifUnJHjAKIOsFU6xO7y5GEKz3GQBdljWOkAVLVD7iBU
vUElxHy3XIj7TSsdLoHM7cp1eLx09hEFlUoHkHPnt+VB9P2sgLh7Y57D1YqX
aoZfKiDqtuQ5gKgN7yocFrlu+/x3C9S/SOEDAHzMhuo=
                
                "], CompressedData["
1:eJxTTMoPSmViYGAQBmIQzXV9cYFtXY6Dj3mnY8LeXIctJ8r2zQ/LcdgKonfl
OjglPL2gZAyVXwrlO0P5ubkOt3/WZe1xyIHQLrkO/Ye+asRszoHQwrkO3CDz
d0HVb81xmJEn1HzgFNT8vhyHbxox/YcW5jhcVAKaIJTjIBuVYn3/cI5D7C5P
Hib2HAdVtsapzo9zHFy6c57//pkN0c+X63AHZF9MjoMjyD3yuQ6904ESO3Ic
jnsDLdLIdagWWef+8FWOgyXIQ9+h9s7KddC/q8LWuDTHQd2QY40M0H/75kvp
352R47AfRO/JdSjOmPi2pjvHARwu+3Id0MMHADisi5I=
                
                "], CompressedData["
1:eJxdk11IVFEQxy8iIn1IlA8RGq709RJmJJFhjVFYZIgGFhGySIGeezDnVhYq
QlRQhKj0YD2EmC/Rh4RERIQbPlSEhAUhYpssabqu7rZKbEsEzZwzsuKFy+F3
55w5//n/ub7aC1Xn0xzH2U0vr/OtB4tqGhG2F2Y+zfmuIffMuf0TiGC+E18Z
7NlUcDFV725Yf/3tpRQ/PPJy8d8y5uMVl1Pse+7VdS3jkfzxZNsjhM+8DmnI
4/oiwqmsnQMPAtJ/j2f3D4ieeg86h37vOPtEw8KXE7Xrbnjw/vje26WnNURZ
Z5UH5YT+Irnf58G+Fx+aBjdo+Ho1vK1wAaEguCXjWtIFviYWRyjmuuvCREV7
d8MfqW914e7G9OqsBAKWrBrtc1yrb2l/TMHNSOWrzXHRH1X2/C+Eb8k29WZO
wVruH5P9EQU5LIi4mi8mpuk+9hIf8k+N5BOb/sQ1r4+tSSM2OojvsQ+zCuq6
KAni1aN9jSXEJo+Y+Els9BIfvqOn/4YV3CqlxlGZh9j4Scx2+YlNrsTtXJhR
8I4LxI/jZCzx0VBzdv88Wt3TyuZHbPwkbsnuLwvNITTz+lNZPyMIY58SJ39M
iT5ikwex8WkWIUCfg5MyXxhhnP0iNnPOiJ5J8TeIdg0pm98wQgfnnxC/ArI/
3bV59yI4/OySPMvl/H3Xzgvib4sGHqPngOh9pu28lcJjGlb+D/8B1W5zlw==

                "], CompressedData["
1:eJxTTMoPSmViYGCQBGIQXWDLdX2xR7JD7/Q8oWaDHAcgr8DWKdlh1cdLvklA
vv5dFbZG02QHH/NOxwTZHAewepVkB8stJ8r2sUPV9yU5PF46+4iCRLbD/vlS
+ncbkhwuKt3+Wbcp00E2KsX6/uUkiHr3TAcGMICaJ5rpALPfMeHpBaX/GRDz
6pId4nZ58jDxZzrc+VmXtedOsoMMyBzzTIg8W4qDKlvjVOfvUPPfQ82zzYK4
+0Kyw1agdfPzshz6D33ViNme7HAB5J6yLIg505Md+kD+9cmC6AtNhvjzaKaD
cPOBUwstkx1unvse/FgxC2K+MdT83CyIvGayw2qQPX+yHIoyJr6tMU+G+L8h
2yEW5G53aHi+yHaYALLfP9lhb8lkCRa5HIi/gPzbIH8Z5Dighz8Az4+pxg==

                "], CompressedData["
1:eJxTTMoPSmViYGDQAGIQ/bbG3jRuWbHDzXPfgx9/zXLodEx4emFBscMFpds/
675B+bOKHYC8rD1fshym5wk1H5hS7DADRL/LclDYUJQxcTKCn/P898qPccUO
QNG3NcuzHBhAwA9qfmmWA1DVqYXOxQ7qhhxrZNKg5rsUO/SCDI6Aqvcodmh9
HbhDzjbL4dMl3ySBgGKIuESWwzFv805HoPmhfLqb5ipnOYDdnwdVb5rlYLnl
RNm+5mKHuF2ePEzWWQ6Pl84+otBX7FAtss79oRxUfU+xQzHIfa8zHS6C/NlU
7DDh0FeNmNWZEH9MgLp/MoIPVt+Pxu/OdAA5J2FpMcSejEwHRVB47C2GuLMl
0wHknPkfih3U2BqnOgPNv+8P9KlAiQNIu/3FTIi/IkocVn0EevQD1PysEodF
rts+/wXyPR5WiazLLHHQv6vC1hgKDR+fEoh/I7Mg5qhCzQPKg9UxQvmBWRDz
bhVDzBfJcsgFxc+hYog8Z5ZDFShc9hU7cF1fXGCrBo3PnVD1DlDzNhc77J8v
pX+3IcuhfB+QcbwYEo7roPzD0Pi/B42fI8UOhbZAE+9kQdy5HRo+X6Dhj5Te
ANdEJCY=
                "], CompressedData["
1:eJxTTMoPSmViYGDQAGIQ3eGY8PQCX5VDccbEtzXVWQ5RKdb3/VmrHKpF1rk/
rILyf1c6HPc273SsyHLoBKl/U+lw89z34MelWQ6trwN3yN2tdFBla5zqnJ/l
ANQksu56pYP+XRW2xkSo+iuVEPOtsxz4dDfNfX8Vqp8xy0FhQ1HGxOeVDrd/
1mXtYclyEG4+cGrhT6j820yHT5d8kwRYqhz6D33ViLmcCXEXV5WDGsi+3ZkQ
839Aze/PhNgPNO/x0tlHFAoyIe64XQnRF5fp8MC/d3reKah6+0yHdzX2pnGH
Kh0YQEAlE+LfvZVQd2RAxK9VOqz+CHTImwwHIZA4c5XD1hNl++ZfynAo3zdf
Sj+3ykEWpDE6E86fkQdUCbRvhxwwhOqqHFaB9FdkOmwB6auogoTbSqj6cgQf
7CyYefszHaaDzAmrcuC6vrjAdlMmxH73Kkj4bM10uA/yjwOCD7ZXo8phP9DY
u3syIe43qYKY8yzTARSNCbZVkPBmyIKEC1A/OH4FsiDucYe61yAL4n6/Kodw
UMT5Z0HiwwOqPyULYr9eFTw9gM1XhIZPFVS/RBUkPmqyHNDTGwAQLip9
                
                "], CompressedData["
1:eJxllAtIVFEQhkVKJKKiN2WWUiZZWVGEWTmZ4tpLjLLLtvfutlu4mZn5OnvN
AguREIklQilEyh5GtmpaqZhE9CIiTAqJjIoyizJ7h0jUnDNndy+2oOvnec38
88+E2fdt3hUYEBCwA3/4d/SL2UHFOxhM538kW2HVqO6abOQtb86dum2yAuuo
nhaNHNN8v6AjyQolH1NbQpHrQsw7Y5Gd7v6iuEkMrn3/88Q1qMH4IzcfnJ7C
YN3owKjSDhVaQvGEicEm+zglZqlK5+fm+Tje1tsZ3pQFj8OfDx7KUGEGXvuy
JtPHPfi7vWiPj4/d+hlp6U6neBtV2LD86BrbHT9P4O+XOyGXB5a+HbaNWXCl
qn433FuPG7+YQWtLxsj20PtvzVCZhRF/2+tjsS8jH35FWvApMwh94piPuSyz
QqU+wWaKK54BT6ukTAG+3GCR+xMV0keV+ScodF5jkFCW2Te0Ru7XpP7ISa8L
J3qsDN514sWrFdjbN3Txq43BmURUeKVC+qD+Kfw+5KeuDxGL7QyaqgYu3I1V
ANXo7bT7149PHZE2xjFs/2EGM0UhFJhXOvnZo2MyH5cCrbxeJxl08bzaZHwP
5XqtQvV874K7XKdKuT9Qp/vbFfhcFLdMM/BVtE018iKu4w0FzvP7kIU+yOKe
iTrwsiWmKWDi+c/RgVe7/cc2ij9J7h+pwKyGHKe7WIe//LNcIb/V68CPJaXK
fBt10nu++T8WaV/SqS5bpT8jdKpjuAr8mtdBOvlnrEr5e1zAZQv+ZPmPeVtU
m1zk0xAVoriefxgcRBnawlR6v4zR/UtUyu8Eo7ydKvRzvWq9ftDIb27pB7dk
PC/0OKuRnli/Ffzheo3iL2AUT51G9TVwAP8YWPgn388innzpT2Shi2FdxG9g
4cM8//4K3j/Ior6XNdInT/ofWeSHLOrr0chvuXI+eGR+uXKeYD4HuP45Mv9G
Db51bbSPQ+b/LmyW+/fL/dc14DLakIUfkIX/s6X+rRr5LdvrZ3l/huyHHo3m
Wrrst4VW0gf7hYf5e62V4nV4+9dK/kMWcSRa6dvh7Xc5Pw0s/Obwz0tvP3pZ
9LfdP19fpZRXZNn981f0l90/n8V8MjAfbwOG+e2dD14WfjTMcxG/YX34/P8H
0Cyccg==
                "], CompressedData["
1:eJxNkm9IU2EUxseIiEiRkogyqYi4m4T4QSIjfEaIRtSoD9F7iRGjICNKCLrH
NCFsmURE+MFBiJRUSCVREWIy15SVBaajFEvR/tiaOgb9ZUTQeXcPbBcul4d7
3nN+53mfjf7TB445HQ5HGb/6m7f1UUeq3cI+f8Gh7UMmvsf2+guCFgp7qj+e
Y/2OElvKWLesnhz5M2iitziwsD+YrbdCnWtL8wi115ONlQ9M+Pp2r3A2ECqe
vDwbGjCR6Z8irCud3ry028Ss92r7KWc9dl05Gf9bK+fThPOV5b6+SQXu3luc
JNwvMo/uGFCI/DIOX1skNIdf3awKKTBVYc8CYSrddKK/X+pZezUP6zs3hjY8
nCc87kjdjT5TyNfzE9n/GuNCjm5bs+Rgfo7mLcp937LnM/zx7P/1jDXznODQ
T1j63yNojMCg6IDwv5B61l9HN31Ijyis0ouwntN6XPhZ/+Y1I9MKn2/zAo0E
dmllc42JBn0RFYSnP/69JY9p85dIfVJBt/eyztzXorLr3YTlE111O+fFD7f4
n1C2/27hi8s81pn7/CL8LsIY4zV9UqjRfruEZ1bmucT/KeFnHdP172W+QThz
nAMxodDqOTI3yjrIx8Mx4TFk/hsFHZNOQ/x7rRDds63Vw5pTVNISVXbeDOGJ
KNyqYid+WnZ+uhUu6/5RCxqzeljut82y9x1TmNH7XrRQzzFeViR5vmTZ87ok
nzn5/w8WOWkh
                "]}]}},
            AspectRatio->Automatic,
            ImageSize->{{128}, {85}},
            PlotRange->{{0., 600.}, {0., 400.}}], ",", 
           GraphicsBox[
            {Thickness[0.002352941176470588], 
             {FaceForm[{RGBColor[0.662745, 0., 0.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}, {0,
                 1, 0}}, {{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}, {0, 1, 
                0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 
                0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                0}, {0, 1, 0}}, {{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {
                0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}}, {{1, 4,
                 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 
                3}, {1, 3, 3}, {1, 3, 3}}}, {{{146.555, 24.364}, {
                148.90200000000002`, 24.364}, {150.805, 
                22.461999999999996`}, {150.805, 20.114000000000004`}, {
                150.805, 15.868}, {150.805, 13.524}, {148.90200000000002`, 
                11.622}, {146.555, 11.622}, {142.309, 11.622}, {142.309, 
                24.364}}, {{146.555, 7.372}, {151.24599999999998`, 7.372}, {
                155.05100000000002`, 11.177}, {155.05100000000002`, 15.868}, {
                155.05100000000002`, 20.114000000000004`}, {
                155.05100000000002`, 24.805}, {151.24599999999998`, 
                28.610000000000003`}, {146.555, 28.610000000000003`}, {
                138.059, 28.610000000000003`}, {138.059, 7.372}}, {{129.562, 
                28.610000000000003`}, {133.812, 28.610000000000003`}, {
                133.812, 7.372}, {129.562, 7.372}}, {{121.066, 
                28.610000000000003`}, {125.316, 28.610000000000003`}, {
                125.316, 7.372}, {121.066, 7.372}, {112.57, 20.708}, {112.57, 
                7.372}, {108.324, 7.372}, {108.324, 28.610000000000003`}, {
                112.57, 28.610000000000003`}, {121.066, 
                15.277999999999999`}}, {{57.348, 28.610000000000003`}, {70.09,
                 28.610000000000003`}, {70.09, 24.364}, {61.594, 24.364}, {
                61.594, 20.114000000000004`}, {70.09, 20.114000000000004`}, {
                70.09, 15.868}, {61.594, 15.868}, {61.594, 11.622}, {70.09, 
                11.622}, {70.09, 7.372}, {57.348, 7.372}}, {{40.355, 
                28.610000000000003`}, {44.602000000000004`, 
                28.610000000000003`}, {44.602000000000004`, 11.622}, {
                53.098000000000006`, 11.622}, {53.098000000000006`, 7.372}, {
                40.355, 7.372}}, {{84.96100000000001, 11.622}, {
                89.20700000000001, 11.622}, {92.727, 11.622}, {
                95.57799999999999, 14.473}, {95.57799999999999, 17.993}, {
                95.57799999999999, 21.509}, {92.67199999999998, 24.352}, {
                89.20700000000001, 24.364}, {84.96100000000001, 24.364}, {
                84.96100000000001, 20.114000000000004`}, {89.20700000000001, 
                20.114000000000004`}, {90.37899999999999, 
                20.114000000000004`}, {91.332, 19.165}, {91.332, 17.993}, {
                91.332, 16.820999999999998`}, {90.37899999999999, 15.868}, {
                89.20700000000001, 15.868}, {84.96100000000001, 15.868}}, {{
                89.20700000000001, 32.86}, {97.418, 32.86}, {104.074, 
                26.204}, {104.074, 17.993}, {104.074, 9.782}, {97.418, 
                3.126}, {89.20700000000001, 3.126}, {80.99600000000001, 
                3.126}, {74.34, 9.782}, {74.34, 17.993}, {74.34, 26.204}, {
                80.99600000000001, 32.86}, {89.20700000000001, 32.86}}, {{
                89.20700000000001, 28.610000000000003`}, {95.07, 
                28.610000000000003`}, {99.82799999999999, 23.856}, {
                99.82799999999999, 17.993}, {99.82799999999999, 
                12.129999999999999`}, {95.07, 7.372}, {89.20700000000001, 
                7.372}, {83.34400000000001, 7.372}, {78.586, 
                12.129999999999999`}, {78.586, 17.993}, {78.586, 23.856}, {
                83.34400000000001, 28.610000000000003`}, {89.20700000000001, 
                28.610000000000003`}}}]}, 
             {FaceForm[{RGBColor[
              0.15686300000000003`, 0.6823529999999999, 0.4], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0., 
               284.2}, {424.801, 284.2}, {424.801, 1.0009999999999764`}, {0., 
               1.0009999999999764`}}}]}, 
             {FaceForm[{RGBColor[
              0.7921569999999999, 0.21568600000000002`, 0.27058800000000005`],
               Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{50.977, 
               284.2}, {127.43800000000002`, 284.2}, {127.43800000000002`, 
               1.0009999999999764`}, {50.977000000000004`, 
               1.0009999999999764`}}}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4js/67L2xGQ5HFHYUJQxM9/hotLtn3Xvsh3M
Ox0Tnr7Jc2AAAY5ch56c579XxubC+SGPl84+0pMN5y+Q0r+rIpfpANR1QYk/
2+HflYqXaqrpDr3T84SaF2TA+d80YvoPdabD+VtPlO2b35XmkJ4GBF1Q+aOp
EPOMMhyKMya+rbFPc7h57nvw47/pDgW2XNcXH4Gqv5fucBvk/oB0B3vTuF2e
N9IdZgCtO7Av00EaqJ1tb7oDWPvZbIc3gTvkWudnQtzzItthxTFv807eHIfj
QMrxR7aDQITllhNluQ4gbynEZDucB1q3dH+eA3r4AADYT4vw
               "]], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               183.75, 249.708}, {179.758, 252.60999999999999`}, {181.281, 
               257.302}, {177.289, 254.399}, {173.297, 257.302}, {174.824, 
               252.60999999999999`}, {170.83200000000002`, 249.708}, {175.766,
                249.708}, {177.289, 245.012}, {178.816, 249.708}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               183.75, 231.583}, {179.758, 234.485}, {181.281, 239.177}, {
               177.289, 236.278}, {173.297, 239.177}, {174.824, 234.485}, {
               170.83200000000002`, 231.583}, {175.766, 231.583}, {177.289, 
               226.89100000000002`}, {178.816, 231.583}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               183.75, 213.45800000000003`}, {179.758, 216.36}, {181.281, 
               221.05200000000002`}, {177.289, 218.153}, {173.297, 
               221.05200000000002`}, {174.824, 216.36}, {170.83200000000002`, 
               213.45800000000003`}, {175.766, 213.45800000000003`}, {177.289,
                208.766}, {178.816, 213.45800000000003`}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               165.844, 222.74699999999999`}, {161.85200000000003`, 
               225.64499999999998`}, {163.379, 230.341}, {159.383, 
               227.43800000000002`}, {155.39100000000002`, 230.341}, {156.918,
                225.64499999999998`}, {152.92600000000002`, 
               222.74699999999999`}, {157.859, 222.74699999999999`}, {159.383,
                218.05200000000002`}, {160.91, 222.74699999999999`}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               188.738, 240.41899999999998`}, {192.73, 243.32100000000003`}, {
               191.20299999999997`, 248.012}, {195.195, 
               245.11399999999998`}, {199.18800000000002`, 248.012}, {197.664,
                243.32100000000003`}, {201.656, 240.41899999999998`}, {
               196.72299999999998`, 240.41899999999998`}, {195.195, 
               235.727}, {193.672, 240.41899999999998`}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
               0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIJIGYC4t7peULNH4IdpPXvqrDtzHXInPi2xn5voMPr
wB1yreF5Dhkg/tQAOB+krNHVz+H64gJbruMIfuVLNUOOhHyHha7bPv818Xaw
N43b5XkDwQeqvr64pgCuPuTx0tlHdiD4xiDAWgi3D6ibh8m2EO4eGB/m3qsV
QAt7Ch2cu3Oe/14ZAeeD1d+NgqsHm8caA+dbbjlRtq88Fm4fjA9zDwMYxMPd
C+PD/ANTD/MvjA8LD5h9sPCCuQfGh7kXFt4ATMyf3A==
               "]]}, 
             {FaceForm[{RGBColor[
              0.15686300000000003`, 0.6823529999999999, 0.4], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
               0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIJIGYCYk8eJu32ZREObwJ3yLXuz3WotTeN23UzyuHm
ue/Bj2PzIHzGGDh/ep5Q84GsWAfBCMstJ04h+CDppcn5DvG7gCZ+jnPYPPf9
8mO3EXy3bZ//XqkqgKvPef575cdtCD7HGpmoFOZCuH3fNGL6D1kWwt0D48Pc
mwvS31Ho0C4GdNnnYDg/5PHS2UcOBMLVg/kzAuD8ZxeUbv+M84PbB+PD3PMU
xPfzhrsXxof5B6Ye5l8YHxYeMPtg4QVzD4wPcy8svAEeRcV0
               "]]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
               0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIJIGYCYr8kgQhLkRCHBVL6d1V+5TpIAym2h4EOvdPz
hJpn5DnE7fLkYdodAOeD9DIE+DuosTVOdX6N4E9z7s553pzvAOIyOPg4xPYf
+qrxB8EvtOW6vjirAK4++PHS2UeWIfgBIAs+F8Dtm31EYUORTCHcPTA+zL3M
YXy6m7ILHZoPnFro2hYB52/7/PdKxc4ouPo1MlEp1vej4XygKwpsP8XA7YPx
Ye65pHT7Z11VHNy9MD7MPzD1MP/C+LDwgNkHCy+Ye2B8mHth4Q0AqVub2A==

               "]]}, 
             {FaceForm[{RGBColor[
              0.9803919999999999, 0.6823529999999999, 0.160784], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               111.43400000000001`, 244.97}, {115.586, 247.47}, {115.586, 
               252.23499999999999`}, {121.71100000000001`, 255.993}, {
               121.71100000000001`, 259.173}, {89.309, 259.173}, {89.309, 
               240.016}, {98.043, 240.016}, {106.84400000000001`, 244.97}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{62.828, 
               271.079}, {62.828, 266.309}, {56.703, 262.552}, {56.703, 
               259.376}, {89.10499999999999, 259.376}, {89.10499999999999, 
               278.52799999999996`}, {80.371, 278.52799999999996`}, {71.57, 
               273.579}, {66.98, 273.579}}}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{62.828, 
               247.47}, {66.98, 244.97}, {71.57, 244.97}, {80.371, 240.016}, {
               89.10499999999999, 240.016}, {89.10499999999999, 259.173}, {
               56.703, 259.173}, {56.703, 255.993}, {62.828, 
               252.23499999999999`}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{115.586, 
               266.309}, {115.586, 271.079}, {111.43400000000001`, 273.579}, {
               106.84400000000001`, 273.579}, {98.043, 278.52799999999996`}, {
               89.309, 278.52799999999996`}, {89.309, 259.376}, {
               121.71100000000001`, 259.376}, {121.71100000000001`, 
               262.552}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}}}, {{{103.895, 266.227}, {102.727, 267.462}, {106.273, 
               270.805}, {106.273, 273.079}, {108.34400000000001`, 271.794}, {
               109.85199999999999`, 273.2}, {111.348, 272.27799999999996`}, {
               109.836, 270.872}, {111.777, 269.66900000000004`}, {107.543, 
               269.66900000000004`}}}]}, 
             {FaceForm[{RGBColor[
              0.7921569999999999, 0.21568600000000002`, 0.27058800000000005`],
               Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {
                0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                109.87899999999999`, 272.95}, {108.523, 271.684}, {109.66, 
                270.98099999999994`}, {111.016, 272.247}}, {{106.477, 
                272.71599999999995`}, {106.477, 270.71999999999997`}, {
                103.016, 267.454}, {103.902, 266.512}, {107.46100000000001`, 
                269.872}, {111.066, 269.872}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}}}, {{{96.758, 266.845}, {95.59, 268.079}, {99.137, 
               271.42299999999994`}, {99.137, 273.69599999999997`}, {
               101.20700000000001`, 272.41499999999996`}, {102.715, 
               273.817}, {104.20700000000001`, 272.899}, {102.699, 271.489}, {
               104.637, 270.28599999999994`}, {100.402, 
               270.28599999999994`}}}]}, 
             {FaceForm[{RGBColor[
              0.7921569999999999, 0.21568600000000002`, 0.27058800000000005`],
               Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {
                0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{102.738, 
                273.567}, {101.383, 272.302}, {102.52, 271.59799999999996`}, {
                103.87499999999999`, 272.86400000000003`}}, {{99.34, 
                273.33299999999997`}, {99.34, 271.337}, {95.87499999999999, 
                268.07099999999997`}, {96.766, 267.13}, {100.324, 270.489}, {
                103.93, 270.489}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}}}, {{{104.418, 262.188}, {103.25, 263.42299999999994`}, {
               106.79700000000001`, 266.77}, {106.79700000000001`, 269.04}, {
               108.867, 267.759}, {110.37499999999999`, 269.165}, {111.871, 
               268.243}, {110.359, 266.83299999999997`}, {112.301, 265.63}, {
               108.066, 265.63}}}]}, 
             {FaceForm[{RGBColor[
              0.7921569999999999, 0.21568600000000002`, 0.27058800000000005`],
               Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {
                0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{110.402, 
                268.91099999999994`}, {109.04700000000001`, 
                267.64500000000004`}, {110.184, 266.942}, {111.539, 
                268.20799999999997`}}, {{107., 268.677}, {107., 266.68}, {
                103.539, 263.41499999999996`}, {104.426, 262.477}, {
                107.98400000000001`, 265.83299999999997`}, {111.59, 
                265.83299999999997`}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}}}, {{{103.895, 252.317}, {102.727, 251.08700000000002`}, {
               106.273, 247.73899999999998`}, {106.273, 245.47}, {
               108.34400000000001`, 246.751}, {109.85199999999999`, 
               245.345}, {111.348, 246.266}, {109.836, 247.677}, {111.777, 
               248.876}, {107.543, 248.876}}}]}, 
             {FaceForm[{RGBColor[
              0.7921569999999999, 0.21568600000000002`, 0.27058800000000005`],
               Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {
                0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                109.87899999999999`, 245.598}, {108.523, 246.86}, {109.66, 
                247.563}, {111.016, 246.298}}, {{106.477, 245.833}, {106.477, 
                247.82500000000002`}, {103.016, 251.095}, {103.902, 
                252.032}, {107.46100000000001`, 248.677}, {111.066, 
                248.677}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}}}, {{{96.758, 251.7}, {95.59, 250.47}, {99.137, 247.122}, {
               99.137, 244.85200000000003`}, {101.20700000000001`, 246.134}, {
               102.715, 244.727}, {104.20700000000001`, 
               245.64899999999997`}, {102.699, 247.055}, {104.637, 248.259}, {
               100.402, 248.259}}}]}, 
             {FaceForm[{RGBColor[
              0.7921569999999999, 0.21568600000000002`, 0.27058800000000005`],
               Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {
                0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{102.738, 
                244.98100000000002`}, {101.383, 246.24299999999997`}, {102.52,
                 246.946}, {103.87499999999999`, 245.68}}, {{99.34, 
                245.212}, {99.34, 247.208}, {95.87499999999999, 250.477}, {
                96.766, 251.415}, {100.324, 248.055}, {103.93, 248.055}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}}}, {{{104.418, 256.356}, {103.25, 255.122}, {
               106.79700000000001`, 251.778}, {106.79700000000001`, 
               249.505}, {108.867, 250.79}, {110.37499999999999`, 
               249.38400000000001`}, {111.871, 250.305}, {110.359, 251.712}, {
               112.301, 252.915}, {108.066, 252.915}}}]}, 
             {FaceForm[{RGBColor[
              0.7921569999999999, 0.21568600000000002`, 0.27058800000000005`],
               Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {
                0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{110.402, 
                249.637}, {109.04700000000001`, 250.899}, {110.184, 
                251.602}, {111.539, 250.33700000000002`}}, {{107., 
                249.86800000000002`}, {107., 251.864}, {103.539, 255.13}, {
                104.426, 256.071}, {107.98400000000001`, 252.712}, {111.59, 
                252.712}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}}}, {{{74.516, 252.317}, {75.684, 251.08700000000002`}, {
               72.137, 247.73899999999998`}, {72.137, 245.47}, {70.066, 
               246.751}, {68.559, 245.345}, {67.066, 246.266}, {68.574, 
               247.677}, {66.637, 248.876}, {70.871, 248.876}}}]}, 
             {FaceForm[{RGBColor[
              0.7921569999999999, 0.21568600000000002`, 0.27058800000000005`],
               Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {
                0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{68.535, 
                245.598}, {69.891, 246.86}, {68.754, 247.563}, {67.398, 
                246.298}}, {{71.93400000000001, 245.833}, {71.93400000000001, 
                247.82500000000002`}, {75.398, 251.095}, {74.508, 252.032}, {
                70.94900000000001, 248.677}, {67.34400000000001, 248.677}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}}}, {{{81.65599999999999, 251.7}, {82.824, 250.47}, {79.277, 
               247.122}, {79.277, 244.85200000000003`}, {77.20700000000001, 
               246.134}, {75.699, 244.727}, {74.203, 245.64899999999997`}, {
               75.715, 247.055}, {73.773, 248.259}, {78.008, 248.259}}}]}, 
             {FaceForm[{RGBColor[
              0.7921569999999999, 0.21568600000000002`, 0.27058800000000005`],
               Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {
                0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                75.67199999999998, 244.98100000000002`}, {77.027, 
                246.24299999999997`}, {75.895, 246.946}, {74.535, 245.68}}, {{
                79.074, 245.212}, {79.074, 247.208}, {82.539, 250.477}, {
                81.648, 251.415}, {78.09, 248.055}, {74.48400000000001, 
                248.055}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}}}, {{{73.992, 256.356}, {75.16, 255.122}, {71.613, 
               251.778}, {71.613, 249.505}, {69.543, 250.79}, {68.035, 
               249.38400000000001`}, {66.543, 250.305}, {68.051, 251.712}, {
               66.113, 252.915}, {70.348, 252.915}}}]}, 
             {FaceForm[{RGBColor[
              0.7921569999999999, 0.21568600000000002`, 0.27058800000000005`],
               Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {
                0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{68.012, 
                249.637}, {69.367, 250.899}, {68.23, 251.602}, {
                66.87499999999999, 250.33700000000002`}}, {{71.41000000000001,
                 249.86800000000002`}, {71.41000000000001, 251.864}, {
                74.87499999999999, 255.13}, {73.98400000000001, 256.071}, {
                70.426, 252.712}, {66.82, 252.712}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}}}, {{{74.516, 266.227}, {75.684, 267.462}, {72.137, 
               270.805}, {72.137, 273.079}, {70.066, 271.794}, {68.559, 
               273.2}, {67.066, 272.27799999999996`}, {68.574, 270.872}, {
               66.637, 269.66900000000004`}, {70.867, 
               269.66900000000004`}}}]}, 
             {FaceForm[{RGBColor[
              0.7921569999999999, 0.21568600000000002`, 0.27058800000000005`],
               Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {
                0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{68.535, 
                272.95}, {69.891, 271.684}, {68.754, 270.98099999999994`}, {
                67.398, 272.247}}, {{71.93400000000001, 
                272.71599999999995`}, {71.93400000000001, 
                270.71999999999997`}, {75.398, 267.454}, {74.508, 266.512}, {
                70.94900000000001, 269.872}, {67.34400000000001, 269.872}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}}}, {{{81.65599999999999, 266.845}, {82.824, 268.079}, {
               79.277, 271.42299999999994`}, {79.277, 273.69599999999997`}, {
               77.20700000000001, 272.41499999999996`}, {75.699, 273.817}, {
               74.203, 272.899}, {75.715, 271.489}, {73.773, 
               270.28599999999994`}, {78.008, 270.28599999999994`}}}]}, 
             {FaceForm[{RGBColor[
              0.7921569999999999, 0.21568600000000002`, 0.27058800000000005`],
               Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {
                0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                75.67199999999998, 273.567}, {77.027, 272.302}, {75.895, 
                271.59799999999996`}, {74.535, 272.86400000000003`}}, {{
                79.074, 273.33299999999997`}, {79.074, 271.337}, {82.539, 
                268.07099999999997`}, {81.648, 267.13}, {78.09, 270.489}, {
                74.48400000000001, 270.489}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}}}, {{{73.992, 262.188}, {75.16, 263.42299999999994`}, {
               71.613, 266.77}, {71.613, 269.04}, {69.543, 267.759}, {68.035, 
               269.165}, {66.543, 268.243}, {68.051, 266.83299999999997`}, {
               66.113, 265.63}, {70.348, 265.63}}}]}, 
             {FaceForm[{RGBColor[
              0.7921569999999999, 0.21568600000000002`, 0.27058800000000005`],
               Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {
                0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{68.012, 
                268.91099999999994`}, {69.367, 267.64500000000004`}, {68.23, 
                266.942}, {66.87499999999999, 268.20799999999997`}}, {{
                71.41000000000001, 268.677}, {71.41000000000001, 266.68}, {
                74.87499999999999, 263.41499999999996`}, {73.98400000000001, 
                262.477}, {70.426, 265.83299999999997`}, {66.82, 
                265.83299999999997`}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
               0, 1, 0}}}, {{{101.12899999999999`, 273.673}, {101.801, 
               275.309}, {98.922, 276.805}, {95.023, 276.805}, {93.027, 
               278.73099999999994`}, {85.387, 278.73099999999994`}, {83.387, 
               276.805}, {79.492, 276.805}, {76.613, 275.309}, {77.285, 
               273.673}, {79.85199999999999, 275.02}, {80.977, 275.02}, {
               84.91400000000002, 270.46999999999997`}, {89.20700000000001, 
               273.08299999999997`}, {93.5, 270.46999999999997`}, {97.438, 
               275.02}, {98.562, 275.02}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}}}, {{{101.12899999999999`, 244.872}, {101.801, 
               243.23499999999999`}, {98.922, 241.74299999999997`}, {95.023, 
               241.74299999999997`}, {93.027, 239.817}, {85.387, 239.817}, {
               83.387, 241.74299999999997`}, {79.492, 241.74299999999997`}, {
               76.613, 243.23499999999999`}, {77.285, 244.872}, {
               79.85199999999999, 243.524}, {80.977, 243.524}, {
               84.91400000000002, 248.07899999999998`}, {89.20700000000001, 
               245.46200000000002`}, {93.5, 248.07899999999998`}, {97.438, 
               243.524}, {98.562, 243.524}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}}}, {{{68.824, 262.78999999999996`}, {
               66.85199999999999, 262.78999999999996`}, {66.41000000000001, 
               263.32099999999997`}, {66.41000000000001, 
               264.71999999999997`}, {67.52, 265.45799999999997`}, {65.699, 
               266.137}, {65.65599999999999, 266.106}, {63.305, 
               264.47299999999996`}, {63.305, 264.03599999999994`}, {59.539, 
               259.274}, {63.305, 254.509}, {63.305, 254.071}, {65.699, 
               252.411}, {67.52, 253.091}, {66.41000000000001, 
               253.82500000000002`}, {66.41000000000001, 255.227}, {
               66.85199999999999, 255.755}, {68.824, 255.755}}}]}, 
             {FaceForm[{RGBColor[
              0.7921569999999999, 0.21568600000000002`, 0.27058800000000005`],
               Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}}}, {{{63.508, 254.177}, {63.508, 254.57899999999998`}, {
               59.797000000000004`, 259.274}, {63.508, 263.96599999999995`}, {
               63.508, 264.368}, {65.727, 265.91099999999994`}, {
               67.07799999999999, 265.407}, {66.20700000000001, 264.829}, {
               66.20700000000001, 263.247}, {66.758, 262.59099999999995`}, {
               68.621, 262.59099999999995`}, {68.621, 255.95800000000003`}, {
               66.758, 255.95800000000003`}, {66.20700000000001, 255.298}, {
               66.20700000000001, 253.71599999999998`}, {67.07799999999999, 
               253.141}, {65.727, 252.634}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
               0, 1, 0}, {0, 1, 0}}}, {{{109.586, 262.78999999999996`}, {
               111.562, 262.78999999999996`}, {112.004, 
               263.32099999999997`}, {112.004, 264.71999999999997`}, {110.891,
                265.45799999999997`}, {112.71100000000001`, 266.137}, {
               112.758, 266.106}, {115.109, 264.47299999999996`}, {115.109, 
               264.03599999999994`}, {118.87499999999999`, 259.274}, {115.109,
                254.509}, {115.109, 254.071}, {112.71100000000001`, 
               252.411}, {110.891, 253.091}, {112.004, 253.82500000000002`}, {
               112.004, 255.227}, {111.562, 255.755}, {109.586, 
               255.755}}}]}, 
             {FaceForm[{RGBColor[
              0.7921569999999999, 0.21568600000000002`, 0.27058800000000005`],
               Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}}}, {{{114.906, 254.177}, {114.906, 
               254.57899999999998`}, {118.617, 259.274}, {114.906, 
               263.96599999999995`}, {114.906, 264.368}, {112.684, 
               265.91099999999994`}, {111.332, 265.407}, {112.203, 264.829}, {
               112.203, 263.247}, {111.65599999999999`, 
               262.59099999999995`}, {109.789, 262.59099999999995`}, {109.789,
                255.95800000000003`}, {111.65599999999999`, 
               255.95800000000003`}, {112.203, 255.298}, {112.203, 
               253.71599999999998`}, {111.332, 253.141}, {112.684, 
               252.634}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 
                0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                89.10499999999999, 278.52799999999996`}, {89.10499999999999, 
                273.259}, {84.953, 270.73099999999994`}, {81.066, 
                275.22299999999996`}, {79.801, 275.22299999999996`}, {77.387, 
                273.954}, {76.867, 275.21599999999995`}, {79.539, 
                276.60200000000003`}, {83.46900000000001, 
                276.60200000000003`}, {85.46900000000001, 
                278.52799999999996`}}, {{89.309, 277.954}, {89.309, 
                273.259}, {93.46100000000001, 270.73099999999994`}, {
                97.34400000000001, 275.22299999999996`}, {98.613, 
                275.22299999999996`}, {101.027, 273.954}, {101.543, 
                275.21599999999995`}, {98.871, 276.60200000000003`}, {
                94.94500000000001, 276.60200000000003`}, {92.94500000000001, 
                278.52799999999996`}, {89.309, 278.52799999999996`}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 
                0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                89.10499999999999, 240.016}, {89.10499999999999, 245.29}, {
                84.953, 247.817}, {81.066, 243.32100000000003`}, {79.801, 
                243.32100000000003`}, {77.387, 244.591}, {76.867, 243.329}, {
                79.539, 241.946}, {83.46900000000001, 241.946}, {
                85.46900000000001, 240.016}}, {{89.309, 240.591}, {89.309, 
                245.29}, {93.46100000000001, 247.817}, {97.34400000000001, 
                243.32100000000003`}, {98.613, 243.32100000000003`}, {101.027,
                 244.591}, {101.543, 243.329}, {98.871, 241.946}, {
                94.94500000000001, 241.946}, {92.94500000000001, 240.016}, {
                89.309, 240.016}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
               0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
               0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
               0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
               0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxlk21IFFEUhtcRFqqlD41+lERF9kFICFJIRDfWJTSy2dWZFZs+WEzsw9mZ
kvBHKCK2RVSEhMUWtITkSj9CQiRCJMW+IEqsCOmXiIVELUKhUnbvHd5z0Rbm
xzN75573vOc9G2PxyMlsn8+XxZ8IfzT+lAW0HYnrYfZrm3Xjeb7DKsc7k0Nd
OnF5bGVVcYnOPjR+21IYcNjwwd1X9l/WWXdm5FCM8/tNYzNNOTqrEN99jbO0
OJA6zJpPP2to1xzi2Sb+YonDVhT03PuRKPe+L1L/r/n89nfFccX31+78srlW
3d+3vm0q3LCovqX0Xeuwc1otpf/Y09KAFnQY+gPn+1tuBYMR775axTNC36DD
Jt7xgv5K4oQQlmuyN6lQ73SuS6yLgttdNhXmNw0aLDm04fG5XS5b+umBs7db
8W0uayBisMm5dGZkq8vqbn6/uC9ksHrxIs9l63ib/izD66vI9XxvMzy/ddfT
nVQszxeaLNtcXtBzxmW9039GG08pPi8KzJt0fkw0sjpKLM/fiVI9qceIkp7i
Jy8v9B+Ikt4X4txPk/oRtvV9VFwq/L2k/ADDL+lvexX5+SivumZPtPo/xjx4
Oh4OLztC85J6M4pbB16nQqZF8y65enZybpVFeZgXv4RFeZHfv7IoT2DkTeo1
j1Ie8T/yCkaecT/yvqB+QOnDvkA/9gn9gdH/XeGnpljmtixO/oHhb5cYYNom
lueabZqP9KfGpvmBMV9Zv8Wm+XM3xjs7bMoH/+rERJ1N+fk7KhqyKV9g5E/6
O1tP+QQjvziPfIPlvvoMqof9gB7sD/Riv9AP9g+M/YQfYPiF/V7gL9//xYx5
/AN4GlC2
               "]]}, 
             {FaceForm[{RGBColor[
              0.9803919999999999, 0.6823529999999999, 0.160784], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{
                0, 2, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 
                1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                 1, 0}}}, {{{89.309, 242.985}, {90.20700000000001, 242.298}, {
                89.309, 241.61399999999998`}}, CompressedData["
1:eJxTTMoPSmViYGBQBmIQvch12+e/c0Idzn0PfrzUPM9hjUxUivV8BD9j4tsa
e9Mwh97peULNDHkOcq2vA3e4YfLfBO6Qa9XOc/gPAt9DHVYc8zbv9ETIg81L
R/DtTeN2ee6Ami8aAjEvJd9hb8lkCZayIAy+G9CZVzgKHKy2nCjbNz/QIeTx
0tlHjAocRNe5P6yKCYDzVdgapzpzBzh81YjpPyRd4NAudvPc92J/uDyYv9kP
zge7e7e/Q33WnpLJXAg+yFgRlgIHl+6c578FAyD++Zjv8A1kbmqAQwDIgZwF
DiIghSYBDkBVKz9yIPhA3/Ew8UL1LwxwyAXJaxQ4xIPEJwfC+ceBxjoGBDns
AfmTBcGX1r+rwhaY7wAKhgNcIXA+2N0KYQ7/rlS8VFubB+dPcwZaVJ3nUAwK
0OOhDgukgBri8hyaD5xa6LoMwbcEhZ97qEMPyMG1eZBwdgh1OKKwoSijM8/h
otLtn3VCoRD3ZEH5XYj0AADYPwDm
                "], {{64.17599999999999, 
                260.505}, {65.17599999999999, 259.376}, {63.176, 259.376}}, {{
                89.10499999999999, 276.93399999999997`}, {88.20700000000001, 
                276.247}, {89.10499999999999, 275.559}}, {{113.238, 
                259.173}, {114.238, 258.04400000000004`}, {115.238, 
                259.173}}, CompressedData["
1:eJxTTMoPSmViYGBQAmIQrcrWONX5d5hD7vPfKz/6FDpkTHxbY58a5jD7iMKG
ooxCh01z3y8/FozJj9vlycMUXOhwUen2z7pFYQ6nF7pu++yMkK8WWef+0ATB
r8vaUzKZB2p+awTEvG0FDn5JAhGWKlEY/Bvnvgc/ji9wmJEn1HzgVxTEfNMC
h70lkyVY7GLg/DUyUSnW/TFQ9xc49E4HangQ47AHpM4MyneIhfPv/AS6ZE+M
wwIp/bsqcQh+gS3X9cUpUPUdUP0FBQ63QfImMQ7MYXy6m+Kh9qfFOHzViOk/
hMQHy0cXOBzzNu90/BENkbcvcCgGeZgdwQfaUmDrFeUQ/Hjp7CMpCD5Y34EC
B6stJ8r29UfA+ds+/71SURkGca9QIZzvBmJoFTrEg+LhcpgDC8h+y0JI+H1B
8MHhFxTucBMUnpqFDi7dOc9/R4ZD/KdS6PAfBNrDIe4zLnRgAAGBcHh6AAB7
afdG
                "]}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 
                0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 
                0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 
                0}}}, {{{89.10499999999999, 241.61399999999998`}, {
                88.20700000000001, 242.298}, {89.10499999999999, 242.985}}, {{
                65.17599999999999, 259.173}, {64.17599999999999, 
                258.04400000000004`}, {63.176, 259.173}}, CompressedData["
1:eJxTTMoPSmViYGBQBmIQnTnxbY393zCHc9+DHy81z3NQZWuc6vwbwc8AyaeG
OfROzxNqZshz2DT3/fJjwZj8N4E75Fq18xwuKt3+WbcozGHFMW/zTk+EPNi8
dATf3jRul+cOqPmtERDzUvId/JIEIixVojD4bts+/73CUeAwAyh84FeUQ8jj
pbOPGBU47C2ZLMFiFwPnr5GJSrHuj3H4qhHTf0i6AGLOA4Q8mO8QC+ff+VmX
tWdPjEN91p6SyVwI/jr3h1UiLFD1HTEQ/3zMd7gNkjeJcQgASXBC7U+Lcch5
/nvlRw4EH+g7HibeAgeQNscf0Q65IHmNAodikIfZEXyu64sLbL2iHPaA9LEg
+NL6d1XYAvMdrLacKNvXHwHng4KhojLM4d+Vipdqa/Pg/GnO3TnPq/Mc4kH2
Xg5zWCAF1BCXBwm/Lwg+OPyCwh16QA6uzXNwAWr7HRnucERhQ1FGZ57DfxBo
D4e4JyvPgQEEBMLh6QEAP70BUg==
                "], {{114.238, 260.505}, {
                113.238, 259.376}, {115.238, 259.376}}, CompressedData["
1:eJxTTMoPSmViYGBQAmIQvUYmKsV6fqhD7vPfKz/6FDpkTHxbY28a5jD7iMKG
ooxCB7nW14E73DD5cbs8eZiCCx3+g8D3UIfTC123fXZGyFeLrHN/aILg12Xt
KZnMAzVfNARi3rYCh70lkyVYyoIw+DfOfQ9+HF/gYLXlRNm++YEQ800LHESB
xlbFBMD5KmyNU525A6DuL3BoF7t57nuxv8MekDlmUP5mPzj/TeAOudbd/g4L
pPTvqsQh+AW2XNcXpxQ4uHTnPP8tGABRX1Dg8E0jpv9QaoADcxif7iage0De
qjIJcPgKEkfig+WjCxyAphTYLoLK2xc4xIPCaXIgnH/c27zTMSDIIfjx0tlH
UhD8YyD6QIHD9Dyh5gNcIXB+CEidQhjEvUKFcL7bts9/r2gVOhSDAvR4qAML
yH7LQofmA6cWui5D8C1B4ece6nATFJ6ahQ69IAscQiH+Uyl0uKh0+2edUCjE
fcZQfhciPQAALpL1Zg==
                "], {{89.309, 275.559}, {
                90.20700000000001, 276.247}, {89.309, 
                276.93399999999997`}}}]}, 
             {FaceForm[{RGBColor[
              0.15686300000000003`, 0.6823529999999999, 0.4], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}}}, {{{89.10499999999999, 272.552}, {80.387, 267.2}, {
               74.04700000000001, 267.2}, {74.04700000000001, 261.895}, {
               70.824, 259.376}, {89.10499999999999, 259.376}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}}}, {{{89.309, 245.997}, {98.023, 251.345}, {104.367, 
               251.345}, {104.367, 256.653}, {107.59, 259.173}, {89.309, 
               259.173}}}]}, 
             {FaceForm[{RGBColor[
              0.7921569999999999, 0.21568600000000002`, 0.27058800000000005`],
               Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}}}, {{{107.59, 259.376}, {104.367, 261.895}, {104.367, 
               267.2}, {98.023, 267.2}, {89.309, 272.552}, {89.309, 
               259.376}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}}}, {{{70.824, 259.173}, {74.04700000000001, 256.653}, {
               74.04700000000001, 251.345}, {80.387, 251.345}, {
               89.10499999999999, 245.997}, {89.10499999999999, 
               259.173}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}}}, {{{84.273, 260.19599999999997`}, {85.44100000000002, 
               261.42699999999996`}, {81.895, 264.774}, {81.895, 
               267.04400000000004`}, {79.824, 265.762}, {78.316, 
               267.16900000000004`}, {76.82, 266.247}, {78.332, 264.837}, {
               76.391, 263.637}, {80.62499999999999, 263.637}}}]}, 
             {FaceForm[{RGBColor[
              0.7921569999999999, 0.21568600000000002`, 0.27058800000000005`],
               Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {
                0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{78.289, 
                266.91499999999996`}, {79.645, 265.653}, {78.512, 
                264.94599999999997`}, {77.15199999999999, 266.212}}, {{81.691,
                 266.68}, {81.691, 264.688}, {85.15599999999999, 261.419}, {
                84.266, 260.48099999999994`}, {80.70700000000001, 263.837}, {
                77.10199999999999, 263.837}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}}}, {{{94.137, 258.35200000000003`}, {92.973, 257.118}, {
               96.52, 253.77399999999997`}, {96.52, 251.501}, {98.59, 
               252.786}, {100.098, 251.38000000000002`}, {101.59, 
               252.30200000000002`}, {100.07799999999999`, 253.708}, {102.02, 
               254.911}, {97.785, 254.911}}}]}, 
             {FaceForm[{RGBColor[
              0.7921569999999999, 0.21568600000000002`, 0.27058800000000005`],
               Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {
                0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{100.121, 
                251.63}, {98.766, 252.895}, {99.902, 253.598}, {101.258, 
                252.333}}, {{96.723, 251.864}, {96.723, 253.86}, {93.258, 
                257.126}, {94.148, 258.067}, {97.70700000000001, 254.708}, {
                101.309, 254.708}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}}}, {{{84.273, 258.35200000000003`}, {85.44100000000002, 
               257.118}, {81.895, 253.77399999999997`}, {81.895, 251.501}, {
               79.824, 252.786}, {78.316, 251.38000000000002`}, {76.82, 
               252.30200000000002`}, {78.332, 253.708}, {76.391, 254.911}, {
               80.62499999999999, 254.911}}}]}, 
             {FaceForm[{RGBColor[
              0.15686300000000003`, 0.6823529999999999, 0.4], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {
                0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{78.289, 
                251.63}, {79.645, 252.895}, {78.512, 253.598}, {
                77.15199999999999, 252.333}}, {{81.691, 251.864}, {81.691, 
                253.86}, {85.15599999999999, 257.126}, {84.266, 258.067}, {
                80.70700000000001, 254.708}, {77.10199999999999, 254.708}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}}}, {{{94.137, 260.19599999999997`}, {92.973, 
               261.42699999999996`}, {96.52, 264.774}, {96.52, 
               267.04400000000004`}, {98.59, 265.762}, {100.098, 
               267.16900000000004`}, {101.59, 266.247}, {100.07799999999999`, 
               264.837}, {102.02, 263.637}, {97.785, 263.637}}}]}, 
             {FaceForm[{RGBColor[
              0.15686300000000003`, 0.6823529999999999, 0.4], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {
                0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{100.121, 
                266.91499999999996`}, {98.766, 265.653}, {99.902, 
                264.94599999999997`}, {101.258, 266.212}}, {{96.723, 
                266.68}, {96.723, 264.688}, {93.258, 261.419}, {94.148, 
                260.48099999999994`}, {97.70700000000001, 263.837}, {101.309, 
                263.837}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               98.57799999999999, 259.274}, {89.20700000000001, 253.024}, {
               79.832, 259.274}, {89.20700000000001, 265.52}}}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 
               0}}, {{0, 2, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}}}, {{{
               89.10499999999999, 265.212}, {80.348, 259.376}, {
               89.10499999999999, 259.376}}, {{89.309, 259.376}, {98.062, 
               259.376}, {89.309, 265.212}}, {{80.348, 259.173}, {
               89.10499999999999, 253.33700000000002`}, {89.10499999999999, 
               259.173}}, {{89.309, 253.33700000000002`}, {98.066, 259.173}, {
               89.309, 259.173}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}}}, {{{91.715, 263.137}, {91.715, 
               261.42299999999994`}, {94.95700000000001, 
               261.42299999999994`}, {94.95700000000001, 257.126}, {91.715, 
               257.126}, {91.715, 255.407}, {86.699, 255.407}, {86.699, 
               257.126}, {83.45700000000001, 257.126}, {83.45700000000001, 
               261.42299999999994`}, {86.699, 261.42299999999994`}, {86.699, 
               263.137}}}]}, 
             {Thickness[0.00006663529411764707], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}}}, {{{91.715, 263.13698200000005`}, {91.715, 
               261.42298200000005`}, {94.95700000000001, 
               261.42298200000005`}, {94.95700000000001, 257.125982}, {91.715,
                257.125982}, {91.715, 255.40698200000003`}, {86.699, 
               255.40698200000003`}, {86.699, 257.125982}, {83.45700000000001,
                257.125982}, {83.45700000000001, 261.42298200000005`}, {
               86.699, 261.42298200000005`}, {86.699, 263.13698200000005`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[
              0.7921569999999999, 0.21568600000000002`, 0.27058800000000005`],
               Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgAWI2IGYC4lp707hdO0MdYnd58jDlFzjA+K8Dd8i1Bhc4
cF1fXGD7KgSDv6dksgSLWYGDXCtQxi0Mgw8zb9Pc98uPBSPkj3ubdzpuCMfg
w8wPebx09pEHYRh8dPNgfJh7wOqMEHxjEBBF+AedDzb/cz7cveh8mHkw+2Dy
KO5D4sPMh/kHnY9uHowPAG5CqjE=
               "]]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
               0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIZIGYC4pDHS2cfMQhxuL64wJarOd0Bha+d7lBjbxq3
KzMCOx+o/vbPuqw9PlEYfKeEpxeUbqc7WG05UbZPPwY73zjD4aISUIdQHAb/
y98rFS/9suHq0fmfQfxl2XD70Plg9/zPRnUvOj88B9W/6Hyg+m8aMf2HfIMw
+DD7pucJNR/ICsDgw9xbnDHxbQ2/LwYf5l+Yeqx8YHjB7EPnw8IbAN9z2dI=

               "]]}, 
             {FaceForm[{RGBColor[
              0.7921569999999999, 0.21568600000000002`, 0.27058800000000005`],
               Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
               0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIZIGYC4js/67L2xEQ4rDjmbd7Zme6AwjdMd/imEdN/
yDYEOx+ofkaeUPOBqCAMfk/O898rH6Y7WG45UbavPAA73zLDYdvnv1cqNH0x
+Ks+XvJN8siGq0fn904HWrQgG24fVv6PbLh70fmFtlzXFwfkwP2LzoeptwLZ
Zx+FnQ+zTykGgw9zL9g+1jgMPsy/MPVY+cDwgtmHzoeFNwBep9jy
               "]]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
               0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIZIGYC4m8aMf2H9oY4rDjmbd55Mt0Bxj+isKEoozDd
4c7Puqw9d8Ix+DD1VltOlO3bH4mdr5jhMCNPqPnAomgMfk/O898rKzMg9rXG
YvB7pwMVcmTD1WPlJ2TD7UPnF9hyXV+8IxvuXnR+IYgvkAP3Lzofph5s360g
DD7MPkuQfd8DsPOB7t32+e+VCk0/DD7MvzD16HyU8ALah5UPDG8AAlTaAA==

               "]]}, 
             {FaceForm[{RGBColor[
              0.7921569999999999, 0.21568600000000002`, 0.27058800000000005`],
               Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
               0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIZIGZigIIL4Q7TnLtznp9Pd4Dxp4L45ekOF5Vu/6w7
FYLBh6kvzpj4tuZ5EAa/8qWaIYdGhoPIOveHVSyB2PkNGQ6/6rL2lDj7YfD3
lEyWYGHKhqvHyo/KhtuHzl8gpX9XZVM23L1Y+Vw5cP9i5QPVx+/y5GHaHInB
h9n3TSOm/9DUaOx8oHtDHi+dfaQiFoMP8y9MPVY+MLxg9qHzYeENAGuWuLI=

               "]]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[CompressedData["
1:eJxTTMoPSmJmYGBgBOJMIAaxGZjA/FFEOgIA9vgCgQ==
               
               "], CompressedData["
1:eJxtVFtIVFEUnSxEwyyloKSsRETpo/oQLYo5aUNYmY+xZpyHyJDNnblS9iA0
xBAZTFIiogdIYEoUEiYWEaE5lFj0ITkMSKkfIhYRIREmZq9ztrP2VfDC+Vh3
n/04a6+9t3vOFFesNJlMK+TxyxMlz67x1Oj6/BKR3XSgfKpKF77r32rNEnd+
D+V7unUxnDI6VxeyioeDR7KaanTxT302K9v3PH178aXE8A+p+x+LhTmz7EVe
m4EHtnWf0yy6uHM6sSHoKRaxjzY7Tm6NxJfYde3VTLpdF3tVvOkiUbV/9UhH
qi7G5ur8vbVFbN/QdWjiksTwp/yzhQv15RmY8s34xXp1v7lQHI6L2tE45BfV
X9J2x0jclrRzPDVKF6MqflyhqFH/w/6FepIK2H7wauXn+U0F7P/sx59wdcYx
0XvhxsZVvww80iErnveJ85okcG3+8rjRt/T+Ikz5r2ic72vR8+TAE43ruZUr
DZc1rpfq69L4PbDjvfAHHyWT91sHmg3ccls2IltjPhPs0uLRmO8PQ7PWyQyN
+0H8ujXuF+zoJ/zR77Oqf/sMTPcnvKyXv2FZeYLGevqZLjs87GW9UX0xGusR
dugV/vS/r0SsU/k/eRlTvoBXKPrNFcfFKfWFDEzxq72R+CdETvnU+5TXEXum
je3A8Cd+xmwcHxj52y2yo0ftXN9CfDvXT+99Y+f30XtzStlOfEoMf+K/v5T5
Awa/xGeWg/mn+BKjPypNsNPB/aM8W5xs71M6TnayP+Vvd7I+gKEfuh/vYn3R
XEgM/VH8Fhfrk96/xs126p/E8Kf7ATfrHxjzQfwkli2P5Xwtub8IYz6RD/OL
ejDfqBfz3xB8d88S72I73gt/8IH9Aoz9Az6xn8A39hf6gf2GfsGOfsIf/cb+
BMZ+hV6wf6En7GfoDfsbeoQdeoU/9Ez5Ww3sVvX91nkeeu5OPxh8bGCKH1vJ
80T96Nd53mAHhj/mFfGB06Lrb+bK/P8BIPUg9A==
               "]]}, 
             {FaceForm[{RGBColor[
              0.15686300000000003`, 0.6823529999999999, 0.4], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4m2f/16p0PR1WHHM27yzN9MBxi+w5bq++Eum
w6+6rD0lzn4Y/CMKG4oy3mZB+Mb+DjfPfQ9+fDDLoV0MyALyl4PM+5rlcPsn
UAFPgEPlSzVDjjNZDr3T84SaBQIg+s9mOayRiUqxrg+Aqy/OmPi2BsiHmWe5
5UTZvu8BcPtg/ODHS2cfmZIBVx/Tf+irxoEMuHl9IHt6MuD27y2ZLMGyLQPu
Ppg8zP0w/TD/wcyH8WHhAwDBUpeK
               "]]}, 
             {FaceForm[{RGBColor[
              0.9803919999999999, 0.6823529999999999, 0.160784], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{70.145, 
               195.454}, {68.07, 194.134}, {68.07, 217.93}, {70.145, 
               216.61399999999998`}, {70.148, 218.305}, {71.74600000000001, 
               216.872}, {73.34, 218.305}, {73.34400000000001, 
               216.61399999999998`}, {75.418, 217.93}, {75.418, 194.134}, {
               73.34400000000001, 195.454}, {73.34, 193.762}, {
               71.74600000000001, 195.192}, {70.148, 193.762}}}]}, 
             {FaceForm[{RGBColor[
              0.15686300000000003`, 0.6823529999999999, 0.4], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{77.57, 192.942}, {
               75.617, 191.466}, {75.617, 220.598}, {77.57, 219.122}, {77.574,
                221.059}, {79.289, 219.52800000000002`}, {81.004, 221.059}, {
               81.008, 219.122}, {82.96100000000001, 220.598}, {
               82.96100000000001, 191.466}, {81.008, 192.942}, {81.004, 
               191.005}, {79.289, 192.54}, {77.574, 191.005}}}]}, 
             {FaceForm[{RGBColor[
              0.9803919999999999, 0.6823529999999999, 0.160784], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{89.20700000000001,
                221.727}, {85.785, 223.92700000000002`}, {85.785, 221.032}, {
               83.164, 223.423}, {83.164, 188.64499999999998`}, {85.785, 
               191.032}, {85.785, 188.137}, {89.20700000000001, 
               190.33700000000002`}, {92.62899999999999, 188.137}, {
               92.62899999999999, 191.032}, {95.25, 188.64499999999998`}, {
               95.25, 223.423}, {92.62899999999999, 221.032}, {
               92.62899999999999, 223.92700000000002`}}}]}, 
             {FaceForm[{RGBColor[
              0.15686300000000003`, 0.6823529999999999, 0.4], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4m8aMf2HWOMcVhzzNu/szXSA8Qtsua4v/pLp
EPJ46ewjFbEY/CMKG4oy3mZB+AyxDjfPfQ9+fDDLoXd6nlAzkL8cZN7XLIh5
vTEOlS/VDDnOZDk4d+c8/90ZA9F/NstBla1xqrN0DFx93C5PHiYgH2beDKBx
BxZFw+2D8YNB9k7JgKsH2vJV40AG3Lw+kDt6MuD27y2ZLMGyLQPuPpg8zP0w
/TD/wcyH8WHhAwAmq49E
               "]]}, 
             {FaceForm[{RGBColor[
              0.9803919999999999, 0.6823529999999999, 0.160784], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{108.27, 
               195.454}, {110.34400000000001`, 194.134}, {110.34400000000001`,
                217.93}, {108.27, 216.61399999999998`}, {108.266, 218.305}, {
               106.66799999999999`, 216.872}, {105.074, 218.305}, {105.07, 
               216.61399999999998`}, {102.99600000000001`, 217.93}, {
               102.99600000000001`, 194.134}, {105.07, 195.454}, {105.074, 
               193.762}, {106.66799999999999`, 195.192}, {108.266, 
               193.762}}}]}, 
             {FaceForm[{RGBColor[
              0.15686300000000003`, 0.6823529999999999, 0.4], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{100.84400000000001`, 
               192.942}, {102.79700000000001`, 191.466}, {102.79700000000001`,
                220.598}, {100.84400000000001`, 219.122}, {100.84, 221.059}, {
               99.12499999999999, 219.52800000000002`}, {97.41000000000001, 
               221.059}, {97.406, 219.122}, {95.453, 220.598}, {95.453, 
               191.466}, {97.406, 192.942}, {97.41000000000001, 191.005}, {
               99.12499999999999, 192.54}, {100.84, 191.005}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}}}, {{{91.504, 216.466}, {90.691, 215.76999999999998`}, {
               90.691, 217.82100000000003`}, {92.523, 219.17299999999997`}, {
               89.20700000000001, 221.618}, {85.891, 219.17299999999997`}, {
               87.723, 217.82100000000003`}, {87.723, 215.76999999999998`}, {
               86.91000000000001, 216.466}, {86.91000000000001, 217.595}, {
               84.96900000000001, 216.001}, {87.051, 214.07899999999998`}, {
               86.238, 212.95800000000003`}, {92.17199999999998, 
               212.95800000000003`}, {91.363, 214.07899999999998`}, {
               93.44500000000001, 216.001}, {91.504, 217.595}}}]}, 
             {FaceForm[{RGBColor[
              0.7921569999999999, 0.21568600000000002`, 0.27058800000000005`],
               Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}}}, {{{86.70700000000001, 217.16899999999998`}, {
               86.70700000000001, 216.372}, {87.926, 215.333}, {87.926, 
               217.923}, {86.23, 219.17299999999997`}, {89.20700000000001, 
               221.36800000000002`}, {92.184, 219.17299999999997`}, {90.488, 
               217.923}, {90.488, 215.333}, {91.703, 216.372}, {91.703, 
               217.16899999999998`}, {93.137, 215.993}, {91.09400000000001, 
               214.106}, {91.777, 213.161}, {86.637, 213.161}, {87.32, 
               214.106}, {85.277, 215.993}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}}}, {{{89.20700000000001, 218.055}, {90.723, 
               219.17299999999997`}, {89.20700000000001, 220.29}, {89.148, 
               220.24699999999999`}, {87.691, 219.17299999999997`}}}]}, 
             {FaceForm[{RGBColor[
              0.15686300000000003`, 0.6823529999999999, 0.4], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{89.20700000000001, 220.04}, {89.309, 219.966}, {
               90.203, 219.305}, {90.383, 219.17299999999997`}, {90.203, 
               219.04399999999998`}, {89.309, 218.38000000000002`}, {
               89.20700000000001, 218.305}, {89.10499999999999, 
               218.38000000000002`}, {88.20700000000001, 
               219.04399999999998`}, {88.031, 219.17299999999997`}, {
               88.20700000000001, 219.305}, {89.10499999999999, 219.966}, {
               89.20700000000001, 220.04}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
               0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIRIGYC4m8aMf2HlkY6rDjmbd5ZmOlQnDHxbY1+DAZ/
mnN3zvPZmQ5+SQIRliyxGPwFUvp3VZ4h1KPze6fnCTULZDnA7IPxt33+e6Xi
YbjDvysVL9WWZjlIA7Wx7QyB82//rMva8yUIrh5EHcgKwODD7GNrnOrcreOP
wYe5F6YenQ/zL8w+GB/mHjB9NwPuXhgfAAZzj3w=
               "]]}, 
             {FaceForm[{RGBColor[
              0.7921569999999999, 0.21568600000000002`, 0.27058800000000005`],
               Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIRIGYCYsstJ8r2lQc4VL5UM+SoyHSA8dNAYFGmgycP
k3a7mz8G//z34MdL7yPUo/P3lEyWYOHKcuidnifU/CMIzr/zsy5rz54QB71N
c98vn5flYHBXha3xbjic79Kd8/z3wki4+hlA7QeUYjD4MPvWyESlWH/H5MPc
C1OPzof5F2YfjA9zDwfIoMcZcPfC+DD/wNQDADpbjso=
               "]]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}}}, {{{109.004, 204.68}, {109.004, 207.38700000000003`}, {
               101.766, 207.38700000000003`}, {101.766, 
               208.02800000000002`}, {95.309, 212.266}, {83.10499999999999, 
               212.266}, {76.648, 208.02800000000002`}, {76.648, 
               207.38700000000003`}, {69.41000000000001, 
               207.38700000000003`}, {69.41000000000001, 204.68}, {76.648, 
               204.68}, {76.648, 204.036}, {83.10499999999999, 199.798}, {
               95.309, 199.798}, {101.766, 204.036}, {101.766, 204.68}}}]}, 
             {FaceForm[{RGBColor[
              0.7921569999999999, 0.21568600000000002`, 0.27058800000000005`],
               Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}}}, {{{69.613, 207.184}, {76.848, 207.184}, {76.848, 
               207.91899999999998`}, {83.164, 212.067}, {95.25, 212.067}, {
               101.562, 207.91899999999998`}, {101.562, 207.184}, {108.801, 
               207.184}, {108.801, 204.88000000000002`}, {101.562, 
               204.88000000000002`}, {101.562, 204.14499999999998`}, {95.25, 
               200.001}, {83.164, 200.001}, {76.848, 204.14499999999998`}, {
               76.848, 204.88000000000002`}, {69.613, 
               204.88000000000002`}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {CompressedData["

1:eJxTTMoPSmViYGDQAWIQfftnXdaeKWEO0vp3VdhysxwyJ76tsfcNc1ggBRQI
ynL4phHTf4gVIW+15UTZvvpQOJ/r+uICWy6ovGWWgwGQauQNhei/lelgCVLf
HuKw+uMl3ySeLIeQx0tnH9kQ4jDNuTvnuXQWRN/DEIg9nFkO7WI3z31XDnX4
8vdKxUslhPq9JZMlWPyyHGrtTeN2MSLMu6gE9MGpEIg5BzPh8kDTf68szYTr
r3ypZshhkgk3X5WtcapzfCbc/lUg8yoQ6psPnFromoZwP8w8mP+mgty/PBPV
/56ZqOEjmokafkA+LHzB/tfPdEAJf6D8jDyh5gNS4XD+cW/zTscJCPMXuW77
/LcnHG4/WL1QBNx9NSD/vwyHux+o+krFznC4/zx5mLTby8Lh/oeph4UP2P8z
EOYxgMCFcHj4wuRh4Q/TD4sfmPmw+IPZD4tfmHpY/MPcDzMP5j9Y+kHxv2UW
avgA0x8AwN0vbA==
                "], {{89.20700000000001, 208.997}, {
                93.15599999999999, 206.032}, {89.20700000000001, 203.067}, {
                85.258, 206.032}}}]}, 
             {FaceForm[{RGBColor[
              0.9803919999999999, 0.6823529999999999, 0.160784], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                0}}}, {CompressedData["
1:eJxTTMoPSmViYGDQAWIQvWnu++XHPoc56IIYaVkOl5Ru/6yrCnOQ1r+rwmaZ
5bDIddvnvz3hDntKJkuwXMp0OOZt3umoEeGw+uMl3ySeLIcae9O4XS/DHaY5
d+c8V85yAKq+UrEz3OHmue/BjwWzHCpeqhlyAPV/AQq/VEKo3wsyzy3LIX6X
Jw9TM8I87uuLC2x3hUPsP5gJlwea/ntlaSZcf2z/oa8aNplw81XZGqc6x2fC
7Qcp8yxAqF8gBTQwDuF+mHkw/1WCzNmQiep/z0wHWPi8Cdwh1yqd6fCwSmSd
+0wEP3Pi2xp73zCIfguoPCNCHuh67fZloXC+1ZYTZfvkEeYbAKlG3lC4/S4g
hxWGwN0X8njp7CMbQuDuB+t7GAL3X/OBUwtd+ULh/oeph4VPcQbQgeII8xhA
4EEIPHxh8rDwh+mHxQ/MfFj8weyHxS9MPSz+Ye6HmQfzHyz9oPgfmL5g4QNL
f7Dwg/Fh4Qv2v1cWPPxh8gBYbjeA
                "], {{89.145, 209.208}, {84.918, 
                206.032}, {89.20700000000001, 202.813}, {93.49600000000001, 
                206.032}, {89.20700000000001, 209.251}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               77.95700000000001, 206.032}, {79.79700000000001, 204.813}, {
               81.633, 206.032}, {79.79700000000001, 207.255}}}]}, 
             {FaceForm[{RGBColor[
              0.15686300000000003`, 0.6823529999999999, 0.4], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               79.79700000000001, 207.009}, {81.266, 206.032}, {
               79.79700000000001, 205.055}, {78.324, 206.032}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               87.371, 206.032}, {89.20700000000001, 204.813}, {91.043, 
               206.032}, {89.20700000000001, 207.255}}}]}, 
             {FaceForm[{RGBColor[
              0.15686300000000003`, 0.6823529999999999, 0.4], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               89.20700000000001, 207.009}, {90.67999999999999, 206.032}, {
               89.20700000000001, 205.055}, {87.73400000000001, 
               206.032}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               100.45700000000001`, 206.032}, {98.617, 204.813}, {96.781, 
               206.032}, {98.617, 207.255}}}]}, 
             {FaceForm[{RGBColor[
              0.15686300000000003`, 0.6823529999999999, 0.4], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{98.617, 
               207.009}, {97.148, 206.032}, {98.617, 205.055}, {100.09, 
               206.032}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYCYin9uypsG/0d0tOAQC/LIcJyy4myc/4O1xcX
2HKpZzksP+Zt3vnR30GVrXGqs3KWw+2fdVl7eALg/N7peULNCgi+S3fO89+G
AXD9IY+Xzj7iEAA334uHSbs9LwBirmuWw3Eg5VgQ4MC5RiYqJT/LwQpo/b78
AIcjChuKMnox+TOA1h2wgvILsxykQe4H2rf64yXfpJwsh4tKQBdqBTgsAHms
COHezXPfLz/WTZh/eqHrts93/eH6+0D+u+APN3+yBEsY315/uP25z3+v/Bjk
D3cfOv/wV42YfiAf5j8DoHMbQ/3h/kcPfwC3UK7R
               "]]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4ts/67L28AQ4fPl7peJlXZaDyDr3h1UiAQ6V
L9UMOSqyHLx4mLTb9QIcenKe/16ZSJivytY41Tk4wEFa/64KW2mWA9f1xQW2
SQEO5p2OCU9rshx6p+cJNSdA7YvKctj2GcgIhNrnkOVQnDHxbY15gANIG5dx
lsPrwB1yrdpQ/TpZDotcgTpkAhy+acT0H9LMcoC5H8affURhQ9EPfzgfbO4d
f7j+X0DlJYf94eaD7ev3h9tvGrfLk6fIH+6+UwuBFub6w90PVtfjD/efAZBq
vOoP9z86vwKk/o2/A+camaiU7CwHYOCuc2cMcPgHNF6tFOF+WPgDADdUstg=

               "]]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{73.301, 214.52}, {
               71.74600000000001, 215.86}, {70.18799999999999, 214.52}, {
               71.258, 213.602}, {71.258, 211.47299999999998`}, {
               70.65199999999999, 212.07899999999998`}, {70.65199999999999, 
               213.278}, {69.266, 211.993}, {71.74600000000001, 209.516}, {
               74.223, 211.993}, {72.836, 213.278}, {72.836, 
               212.07899999999998`}, {72.23400000000001, 
               211.47299999999998`}, {72.23400000000001, 213.602}}}]}, 
             {FaceForm[{RGBColor[
              0.7921569999999999, 0.21568600000000002`, 0.27058800000000005`],
               Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{71.45700000000001, 
               213.696}, {70.49600000000001, 214.52}, {71.74600000000001, 
               215.591}, {72.992, 214.52}, {72.031, 213.696}, {72.031, 
               210.985}, {73.039, 211.993}, {73.039, 212.817}, {73.93, 
               211.989}, {71.74600000000001, 209.80200000000002`}, {69.559, 
               211.989}, {70.44900000000001, 212.817}, {70.44900000000001, 
               211.993}, {71.45700000000001, 210.985}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{80.848, 
               216.911}, {79.289, 218.24699999999999`}, {77.73400000000001, 
               216.911}, {78.801, 215.993}, {78.801, 213.864}, {78.199, 
               214.466}, {78.199, 215.66899999999998`}, {76.812, 
               214.38400000000001`}, {79.289, 211.903}, {81.77, 
               214.38400000000001`}, {80.383, 215.66899999999998`}, {80.383, 
               214.466}, {79.777, 213.864}, {79.777, 215.993}}}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{79.004, 216.083}, {
               78.043, 216.911}, {79.289, 217.98100000000002`}, {80.539, 
               216.911}, {79.57799999999999, 216.083}, {79.57799999999999, 
               213.376}, {80.586, 214.38400000000001`}, {80.586, 
               215.20399999999998`}, {81.477, 214.376}, {79.289, 
               212.18800000000002`}, {77.10199999999999, 214.376}, {
               77.99600000000001, 215.20399999999998`}, {77.99600000000001, 
               214.38400000000001`}, {79.004, 213.376}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{73.301, 
               197.54399999999998`}, {71.74600000000001, 196.208}, {
               70.18799999999999, 197.54399999999998`}, {71.258, 
               198.46200000000002`}, {71.258, 200.591}, {70.65199999999999, 
               199.989}, {70.65199999999999, 198.786}, {69.266, 200.071}, {
               71.74600000000001, 202.55200000000002`}, {74.223, 200.071}, {
               72.836, 198.786}, {72.836, 199.989}, {72.23400000000001, 
               200.591}, {72.23400000000001, 198.46200000000002`}}}]}, 
             {FaceForm[{RGBColor[
              0.7921569999999999, 0.21568600000000002`, 0.27058800000000005`],
               Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{71.45700000000001, 
               198.36800000000002`}, {70.49600000000001, 
               197.54399999999998`}, {71.74600000000001, 
               196.47299999999998`}, {72.992, 197.54399999999998`}, {72.031, 
               198.36800000000002`}, {72.031, 201.07899999999998`}, {73.039, 
               200.071}, {73.039, 199.251}, {73.93, 200.075}, {
               71.74600000000001, 202.262}, {69.559, 200.075}, {
               70.44900000000001, 199.251}, {70.44900000000001, 200.071}, {
               71.45700000000001, 201.07899999999998`}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{105.113, 
               214.52}, {106.66799999999999`, 215.86}, {108.227, 214.52}, {
               107.15599999999999`, 213.602}, {107.15599999999999`, 
               211.47299999999998`}, {107.762, 212.07899999999998`}, {107.762,
                213.278}, {109.148, 211.993}, {106.66799999999999`, 
               209.516}, {104.191, 211.993}, {105.57799999999999`, 213.278}, {
               105.57799999999999`, 212.07899999999998`}, {
               106.17999999999999`, 211.47299999999998`}, {
               106.17999999999999`, 213.602}}}]}, 
             {FaceForm[{RGBColor[
              0.7921569999999999, 0.21568600000000002`, 0.27058800000000005`],
               Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{106.95700000000001`, 
               213.696}, {107.918, 214.52}, {106.66799999999999`, 215.591}, {
               105.422, 214.52}, {106.383, 213.696}, {106.383, 210.985}, {
               105.37499999999999`, 211.993}, {105.37499999999999`, 
               212.817}, {104.48400000000001`, 211.989}, {106.66799999999999`,
                209.80200000000002`}, {108.85499999999999`, 211.989}, {
               107.965, 212.817}, {107.965, 211.993}, {106.95700000000001`, 
               210.985}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{105.113, 
               197.54399999999998`}, {106.66799999999999`, 196.208}, {108.227,
                197.54399999999998`}, {107.15599999999999`, 
               198.46200000000002`}, {107.15599999999999`, 200.591}, {107.762,
                199.989}, {107.762, 198.786}, {109.148, 200.071}, {
               106.66799999999999`, 202.55200000000002`}, {104.191, 
               200.071}, {105.57799999999999`, 198.786}, {105.57799999999999`,
                199.989}, {106.17999999999999`, 200.591}, {
               106.17999999999999`, 198.46200000000002`}}}]}, 
             {FaceForm[{RGBColor[
              0.7921569999999999, 0.21568600000000002`, 0.27058800000000005`],
               Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{106.95700000000001`, 
               198.36800000000002`}, {107.918, 197.54399999999998`}, {
               106.66799999999999`, 196.47299999999998`}, {105.422, 
               197.54399999999998`}, {106.383, 198.36800000000002`}, {106.383,
                201.07899999999998`}, {105.37499999999999`, 200.071}, {
               105.37499999999999`, 199.251}, {104.48400000000001`, 
               200.075}, {106.66799999999999`, 202.262}, {108.85499999999999`,
                200.075}, {107.965, 199.251}, {107.965, 200.071}, {
               106.95700000000001`, 201.07899999999998`}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{80.848, 
               195.157}, {79.289, 193.817}, {77.73400000000001, 195.157}, {
               78.801, 196.075}, {78.801, 198.20399999999998`}, {78.199, 
               197.598}, {78.199, 196.399}, {76.812, 197.684}, {79.289, 
               200.161}, {81.77, 197.684}, {80.383, 196.399}, {80.383, 
               197.598}, {79.777, 198.20399999999998`}, {79.777, 196.075}}}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{79.004, 
               195.98100000000002`}, {78.043, 195.157}, {79.289, 
               194.08700000000002`}, {80.539, 195.157}, {79.57799999999999, 
               195.98100000000002`}, {79.57799999999999, 198.692}, {80.586, 
               197.684}, {80.586, 196.86}, {81.477, 197.68800000000002`}, {
               79.289, 199.876}, {77.10199999999999, 197.68800000000002`}, {
               77.99600000000001, 196.86}, {77.99600000000001, 197.684}, {
               79.004, 198.692}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{97.566, 
               216.911}, {99.12499999999999, 218.24699999999999`}, {
               100.67999999999999`, 216.911}, {99.613, 215.993}, {99.613, 
               213.864}, {100.215, 214.466}, {100.215, 215.66899999999998`}, {
               101.60199999999999`, 214.38400000000001`}, {99.12499999999999, 
               211.903}, {96.645, 214.38400000000001`}, {98.031, 
               215.66899999999998`}, {98.031, 214.466}, {98.637, 213.864}, {
               98.637, 215.993}}}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{99.41000000000001, 
               216.083}, {100.371, 216.911}, {99.12499999999999, 
               217.98100000000002`}, {97.87499999999999, 216.911}, {98.836, 
               216.083}, {98.836, 213.376}, {97.82799999999999, 
               214.38400000000001`}, {97.82799999999999, 
               215.20399999999998`}, {96.938, 214.376}, {99.12499999999999, 
               212.18800000000002`}, {101.309, 214.376}, {100.418, 
               215.20399999999998`}, {100.418, 214.38400000000001`}, {
               99.41000000000001, 213.376}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{97.566, 
               195.157}, {99.12499999999999, 193.817}, {100.67999999999999`, 
               195.157}, {99.613, 196.075}, {99.613, 198.20399999999998`}, {
               100.215, 197.598}, {100.215, 196.399}, {101.60199999999999`, 
               197.684}, {99.12499999999999, 200.161}, {96.645, 197.684}, {
               98.031, 196.399}, {98.031, 197.598}, {98.637, 
               198.20399999999998`}, {98.637, 196.075}}}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{99.41000000000001, 
               195.98100000000002`}, {100.371, 195.157}, {99.12499999999999, 
               194.08700000000002`}, {97.87499999999999, 195.157}, {98.836, 
               195.98100000000002`}, {98.836, 198.692}, {97.82799999999999, 
               197.684}, {97.82799999999999, 196.86}, {96.938, 
               197.68800000000002`}, {99.12499999999999, 199.876}, {101.309, 
               197.68800000000002`}, {100.418, 196.86}, {100.418, 197.684}, {
               99.41000000000001, 198.692}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYCYin9uypsG/0dzn0Pfrw0ONMhwnLLibJz/g7X
FxfYckVnOiw/5m3e+dHfQRAkEZfpcPtnXdYengA4v3d6nlCzAoLv0p3z/Ldh
AFx/yOOls484BMDN9+Jh0m7PC3DoA+mzyXQ4DjTesQCqXyjTwQpo/b78AAeg
7uuLv2Rg8GcAtR2wCnAoBPEFMh2kQe4H2vdNI6b/kGimw0UloAu1AhwqX6oZ
cggg3Nt84NRC128ZBPmnF7pu+3zXH64f7M4L/nDzJ0uwhPHt9Yfbn/v898qP
Qf5w96HzD38Fagzyh/vPAOjcxlB/uP/Rwx8AxOmyuA==
               "]]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4ts/67L28AQ4OCU8vaDEnOkgss79YZVIgMOe
kskSLFyZDl48TNrtegEOvdPzhJoVCPNV2RqnOgcHOPy7UvFSjTfTgev64gLb
pAAHoKHr3FkzIeoSAhwcQfapZzps+/z3SkUg1D6nTIfijIlva8yh8v6ZDq8D
d8i1akP1h2Y6LHIF6pAJcLA3jdvlGZHpAHM/jD/7iMKGoh/+cH7lSzVDjjv+
cP2/gMpLDvvDzQfb1+8Ptx+kjafIH+6+UwuBFub6w90PNq/HH+4/g7sqbI1X
/eH+R+dXgNS/8XcQiLDcckIsE2IOY4CDeSfQBh6E+2HhDwCQuaLW
               "]]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYCYpfunOe/D8Y4pKcBgV6Wgypb41TnzTEO1xcX
2HKpZznU2pvG7VoYAxFXznL4phHTf6gXwQfrr0Twe6fnCTVnoOmPRJhf8VLN
kEMnxmH5MW/zTtcsBy6QQq0YB841MlEp+VkOIO0HgPwjChuKMnox+VZbTpTt
i4fyC7McHlaJrHPPjHFY/fGSb1JOlgMDCBTEOCyQ0r+rUoRw7+a575cf6ybM
fx24Q651NUI/2H2bEOZXgty/B2G/NFAZ20eE+9D5YPd9RPgP7P73CP+jhz8A
6EisBw==
               "]]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4m8aMf2HemMcvvy9UvGyLsthb8lkCZa2GIfK
l2qGHBVZDhUgOifGoSfn+e+ViYT5a2SiUqzdYxyk9e+qsJVmORzzNu90tIhx
AJIJT2uyHFy6gQotofZFZUHUeULtc8hyiN/lycOUHONwfXGBLZdxlsOzC0q3
f+ZB9etkORgAlTfWxjiA3a2Z5QBzP4zffODUQtd5CL7IOveHVWsQ+kMeL519
ZAfC/Bl5Qs0HLiHs3/YZ6LCHCPe9Dtwh1/oY4X6weVcQ/rPacqJs33qE/9H5
YPVLYhw4QQGTneXwsAooMjPG4R/QeLVShPth4Q8Ax0u5yQ==
               "]]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYCYpfunOe/D8Y4nPse/HhpcKaDKlvjVOfNMQ7X
FxfYckVnOtTam8btWhjjIBhhueVEXKbDN42Y/kO9CD5YfyWC3zs9T6g5A01/
JML8ipdqhhw6MQ59IHU2mQ5cIIVaUP1CmQ4g4QNAPlD39cVfMjD4VltOlO2L
j3EoBPEFMh0eVomsc8+MgbhLNNOBAQQKYhwqQfYIINzbfODUQtdvGQT5rwN3
yLWuRugHu28Twnyw+B6E/dL6d1XYPiLch84Hu+8jwn9g979H+B89/AH14a/u

               "]]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4m8aMf2HemMcnBKeXlBiznTYWzJZgqUtxmEP
iObKdKh4qWbIkRPj0Ds9T6hZgTB/jUxUirV7jMO/K0AZ3kyHY97mnY4WMQ4P
q0TWubNmOrh05zz/bRnj4AiyTz3TQVr/rgqbJ9Q+p0yH+F2ePEzJUHn/TIdn
F5Ru/8yD6g/NdDAAKm+sjXGwN43b5RmR6QBzP4zffODUQtd5CD5Q18OqNQj9
IY+Xzj6yA2H+DKCzD1xC2L/t898rFQ8R7nsduEOu9THC/WDzriD8Z7XlRNm+
9Qj/o/PB6pfEOAhEWG45IZYJMWdmjAMwVBKe8iDcDwt/ACC/qcc=
               "]]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}}}, {{{91.504, 195.598}, {90.691, 196.29399999999998`}, {
               90.691, 194.24299999999997`}, {92.523, 192.89100000000002`}, {
               89.20700000000001, 190.446}, {85.891, 192.89100000000002`}, {
               87.723, 194.24299999999997`}, {87.723, 196.29399999999998`}, {
               86.91000000000001, 195.598}, {86.91000000000001, 194.47}, {
               84.96900000000001, 196.063}, {87.051, 197.985}, {86.238, 
               199.10999999999999`}, {92.17199999999998, 
               199.10999999999999`}, {91.363, 197.985}, {93.44500000000001, 
               196.063}, {91.504, 194.47}}}]}, 
             {FaceForm[{RGBColor[
              0.7921569999999999, 0.21568600000000002`, 0.27058800000000005`],
               Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}}}, {{{86.70700000000001, 194.895}, {86.70700000000001, 
               195.692}, {87.926, 196.73499999999999`}, {87.926, 194.141}, {
               86.23, 192.89100000000002`}, {89.20700000000001, 190.7}, {
               92.184, 192.89100000000002`}, {90.488, 194.141}, {90.488, 
               196.73499999999999`}, {91.703, 195.692}, {91.703, 194.895}, {
               93.137, 196.075}, {91.09400000000001, 197.95800000000003`}, {
               91.777, 198.907}, {86.637, 198.907}, {87.32, 
               197.95800000000003`}, {85.277, 196.075}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}}}, {{{89.20700000000001, 194.009}, {90.723, 
               192.89100000000002`}, {89.20700000000001, 
               191.77399999999997`}, {89.148, 191.82100000000003`}, {87.691, 
               192.89100000000002`}}}]}, 
             {FaceForm[{RGBColor[
              0.15686300000000003`, 0.6823529999999999, 0.4], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{89.20700000000001, 192.02800000000002`}, {89.309, 
               192.098}, {90.203, 192.762}, {90.383, 192.89100000000002`}, {
               90.203, 193.024}, {89.309, 193.684}, {89.20700000000001, 
               193.759}, {89.10499999999999, 193.684}, {88.20700000000001, 
               193.024}, {88.031, 192.89100000000002`}, {88.20700000000001, 
               192.762}, {89.10499999999999, 192.098}, {89.20700000000001, 
               192.02800000000002`}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{63.465, 
               154.24299999999997`}, {63.465, 156.153}, {59.839999999999996`, 
               153.85200000000003`}, {58.382999999999996`, 
               154.97299999999998`}, {56.882999999999996`, 
               154.80200000000002`}, {56.160000000000004`, 153.782}, {
               57.452999999999996`, 152.79399999999998`}, {
               56.160000000000004`, 151.805}, {56.882999999999996`, 
               150.782}, {58.382999999999996`, 150.60999999999999`}, {
               59.839999999999996`, 151.731}, {63.465, 149.43}, {63.465, 
               151.345}, {61.184, 152.79399999999998`}}}]}, 
             {FaceForm[{RGBColor[
              0.15686300000000003`, 0.6823529999999999, 0.4], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{59.828, 153.602}, {
               63.26200000000001, 155.786}, {63.26200000000001, 
               154.35200000000003`}, {60.805, 152.79399999999998`}, {
               63.26200000000001, 151.231}, {63.26200000000001, 149.798}, {
               59.828, 151.98100000000002`}, {58.324, 150.82100000000003`}, {
               56.996, 150.97299999999998`}, {56.438, 151.762}, {
               57.785000000000004`, 152.79399999999998`}, {56.438, 
               153.82100000000003`}, {56.996, 154.60999999999999`}, {58.324, 
               154.762}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{63.465, 
               160.88700000000003`}, {63.465, 162.798}, {59.839999999999996`, 
               160.497}, {58.382999999999996`, 161.618}, {56.882999999999996`,
                161.446}, {56.160000000000004`, 160.42700000000002`}, {
               57.452999999999996`, 159.43800000000002`}, {
               56.160000000000004`, 158.45000000000002`}, {
               56.882999999999996`, 157.43}, {58.382999999999996`, 157.255}, {
               59.839999999999996`, 158.38000000000002`}, {63.465, 156.075}, {
               63.465, 157.989}, {61.184, 159.43800000000002`}}}]}, 
             {FaceForm[{RGBColor[
              0.15686300000000003`, 0.6823529999999999, 0.4], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{59.828, 160.251}, {
               63.26200000000001, 162.43}, {63.26200000000001, 160.997}, {
               60.805, 159.43800000000002`}, {63.26200000000001, 157.876}, {
               63.26200000000001, 156.442}, {59.828, 158.626}, {58.324, 
               157.466}, {56.996, 157.618}, {56.438, 158.407}, {
               57.785000000000004`, 159.43800000000002`}, {56.438, 160.47}, {
               56.996, 161.255}, {58.324, 161.411}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{63.465, 
               144.696}, {63.465, 142.786}, {59.839999999999996`, 
               145.08700000000002`}, {58.382999999999996`, 143.966}, {
               56.882999999999996`, 144.137}, {56.160000000000004`, 
               145.157}, {57.452999999999996`, 146.14499999999998`}, {
               56.160000000000004`, 147.137}, {56.882999999999996`, 
               148.157}, {58.382999999999996`, 148.329}, {59.839999999999996`,
                147.208}, {63.465, 149.509}, {63.465, 147.598}, {61.184, 
               146.14499999999998`}}}]}, 
             {FaceForm[{RGBColor[
              0.15686300000000003`, 0.6823529999999999, 0.4], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{59.828, 
               145.33700000000002`}, {63.26200000000001, 143.153}, {
               63.26200000000001, 144.58700000000002`}, {60.805, 
               146.14899999999997`}, {63.26200000000001, 147.708}, {
               63.26200000000001, 149.141}, {59.828, 146.95800000000003`}, {
               58.324, 148.118}, {56.996, 147.966}, {56.438, 147.177}, {
               57.785000000000004`, 146.14899999999997`}, {56.438, 145.118}, {
               56.996, 144.329}, {58.324, 144.177}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               114.94900000000001`, 154.24299999999997`}, {
               114.94900000000001`, 156.153}, {118.574, 
               153.85200000000003`}, {120.031, 154.97299999999998`}, {121.531,
                154.80200000000002`}, {122.254, 153.782}, {
               120.96100000000001`, 152.79399999999998`}, {122.254, 
               151.805}, {121.531, 150.782}, {120.031, 150.60999999999999`}, {
               118.574, 151.731}, {114.94900000000001`, 149.43}, {
               114.94900000000001`, 151.345}, {117.23, 
               152.79399999999998`}}}]}, 
             {FaceForm[{RGBColor[
              0.15686300000000003`, 0.6823529999999999, 0.4], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{118.586, 153.602}, {
               115.15199999999999`, 155.786}, {115.15199999999999`, 
               154.35200000000003`}, {117.609, 152.79399999999998`}, {
               115.15199999999999`, 151.231}, {115.15199999999999`, 
               149.798}, {118.586, 151.98100000000002`}, {120.09, 
               150.82100000000003`}, {121.418, 150.97299999999998`}, {121.977,
                151.762}, {120.62499999999999`, 152.79399999999998`}, {
               121.977, 153.82100000000003`}, {121.418, 
               154.60999999999999`}, {120.09, 154.762}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               114.94900000000001`, 160.88700000000003`}, {
               114.94900000000001`, 162.798}, {118.574, 160.497}, {120.031, 
               161.618}, {121.531, 161.446}, {122.254, 160.42700000000002`}, {
               120.96100000000001`, 159.43800000000002`}, {122.254, 
               158.45000000000002`}, {121.531, 157.43}, {120.031, 157.255}, {
               118.574, 158.38000000000002`}, {114.94900000000001`, 
               156.075}, {114.94900000000001`, 157.989}, {117.23, 
               159.43800000000002`}}}]}, 
             {FaceForm[{RGBColor[
              0.15686300000000003`, 0.6823529999999999, 0.4], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{118.586, 160.251}, {
               115.15199999999999`, 162.43}, {115.15199999999999`, 160.997}, {
               117.609, 159.43800000000002`}, {115.15199999999999`, 
               157.876}, {115.15199999999999`, 156.442}, {118.586, 158.626}, {
               120.09, 157.466}, {121.418, 157.618}, {121.977, 158.407}, {
               120.62499999999999`, 159.43800000000002`}, {121.977, 160.47}, {
               121.418, 161.255}, {120.09, 161.411}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               114.94900000000001`, 144.696}, {114.94900000000001`, 
               142.786}, {118.574, 145.08700000000002`}, {120.031, 143.966}, {
               121.531, 144.137}, {122.254, 145.157}, {120.96100000000001`, 
               146.14499999999998`}, {122.254, 147.137}, {121.531, 148.157}, {
               120.031, 148.329}, {118.574, 147.208}, {114.94900000000001`, 
               149.509}, {114.94900000000001`, 147.598}, {117.23, 
               146.14499999999998`}}}]}, 
             {FaceForm[{RGBColor[
              0.15686300000000003`, 0.6823529999999999, 0.4], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{118.586, 
               145.33700000000002`}, {115.15199999999999`, 143.153}, {
               115.15199999999999`, 144.58700000000002`}, {117.609, 
               146.14899999999997`}, {115.15199999999999`, 147.708}, {
               115.15199999999999`, 149.141}, {118.586, 
               146.95800000000003`}, {120.09, 148.118}, {121.418, 147.966}, {
               121.977, 147.177}, {120.62499999999999`, 
               146.14899999999997`}, {121.977, 145.118}, {121.418, 144.329}, {
               120.09, 144.177}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{107.016, 172.934}, {
               107.016, 170.17299999999997`}, {109.027, 
               170.17299999999997`}, {109.027, 168.95000000000002`}, {111., 
               168.95000000000002`}, {111., 171.17299999999997`}, {109.238, 
               171.17299999999997`}, {109.238, 172.934}}}]}, 
             {FaceForm[{RGBColor[
              0.15686300000000003`, 0.6823529999999999, 0.4], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{109.039, 172.731}, {109.039,
                170.97299999999998`}, {110.79700000000001`, 
               170.97299999999998`}, {110.79700000000001`, 169.153}, {109.227,
                169.153}, {109.227, 170.372}, {107.21900000000001`, 
               170.372}, {107.21900000000001`, 172.731}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{112.94100000000002`, 
               168.575}, {112.94100000000002`, 165.813}, {114.94900000000001`,
                165.813}, {114.94900000000001`, 164.591}, {116.926, 
               164.591}, {116.926, 166.817}, {115.164, 166.817}, {115.164, 
               168.575}}}]}, 
             {FaceForm[{RGBColor[
              0.15686300000000003`, 0.6823529999999999, 0.4], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{114.965, 168.376}, {114.965,
                166.61399999999998`}, {116.723, 166.61399999999998`}, {
               116.723, 164.79399999999998`}, {115.15199999999999`, 
               164.79399999999998`}, {115.15199999999999`, 166.016}, {113.145,
                166.016}, {113.145, 168.376}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{71.398, 172.934}, {
               71.398, 170.17299999999997`}, {69.387, 170.17299999999997`}, {
               69.387, 168.95000000000002`}, {67.41400000000002, 
               168.95000000000002`}, {67.41400000000002, 
               171.17299999999997`}, {69.17599999999999, 
               171.17299999999997`}, {69.17599999999999, 172.934}}}]}, 
             {FaceForm[{RGBColor[
              0.15686300000000003`, 0.6823529999999999, 0.4], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{69.37499999999999, 
               172.731}, {69.37499999999999, 170.97299999999998`}, {67.617, 
               170.97299999999998`}, {67.617, 169.153}, {69.18799999999999, 
               169.153}, {69.18799999999999, 170.372}, {71.195, 170.372}, {
               71.195, 172.731}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{107.016, 
               132.64899999999997`}, {107.016, 135.415}, {109.027, 135.415}, {
               109.027, 136.634}, {111., 136.634}, {111., 134.411}, {109.238, 
               134.411}, {109.238, 132.64899999999997`}}}]}, 
             {FaceForm[{RGBColor[
              0.15686300000000003`, 0.6823529999999999, 0.4], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{109.039, 
               132.85200000000003`}, {109.039, 134.61399999999998`}, {
               110.79700000000001`, 134.61399999999998`}, {
               110.79700000000001`, 136.43}, {109.227, 136.43}, {109.227, 
               135.212}, {107.21900000000001`, 135.212}, {107.21900000000001`,
                132.85200000000003`}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{71.398, 
               132.64899999999997`}, {71.398, 135.415}, {69.387, 135.415}, {
               69.387, 136.634}, {67.41400000000002, 136.634}, {
               67.41400000000002, 134.411}, {69.17599999999999, 134.411}, {
               69.17599999999999, 132.64899999999997`}}}]}, 
             {FaceForm[{RGBColor[
              0.15686300000000003`, 0.6823529999999999, 0.4], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{69.37899999999999, 
               132.85200000000003`}, {69.37899999999999, 
               134.61399999999998`}, {67.617, 134.61399999999998`}, {67.617, 
               136.43}, {69.18799999999999, 136.43}, {69.18799999999999, 
               135.212}, {71.195, 135.212}, {71.195, 132.85200000000003`}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{112.94100000000002`, 
               137.009}, {112.94100000000002`, 139.76999999999998`}, {
               114.94900000000001`, 139.76999999999998`}, {
               114.94900000000001`, 140.993}, {116.926, 140.993}, {116.926, 
               138.76999999999998`}, {115.164, 138.76999999999998`}, {115.164,
                137.009}}}]}, 
             {FaceForm[{RGBColor[
              0.15686300000000003`, 0.6823529999999999, 0.4], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{114.965, 137.212}, {114.965,
                138.97}, {116.723, 138.97}, {116.723, 140.79}, {
               115.15199999999999`, 140.79}, {115.15199999999999`, 139.571}, {
               113.145, 139.571}, {113.145, 137.212}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{65.473, 168.575}, {
               65.473, 165.813}, {63.465, 165.813}, {63.465, 164.591}, {
               61.488, 164.591}, {61.488, 166.817}, {63.25, 166.817}, {63.25, 
               168.575}}}]}, 
             {FaceForm[{RGBColor[
              0.15686300000000003`, 0.6823529999999999, 0.4], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{63.449, 168.376}, {63.449, 
               166.61399999999998`}, {61.691, 166.61399999999998`}, {61.691, 
               164.79399999999998`}, {63.26200000000001, 
               164.79399999999998`}, {63.26200000000001, 166.016}, {65.27, 
               166.016}, {65.27, 168.376}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{65.473, 137.009}, {
               65.473, 139.76999999999998`}, {63.465, 139.76999999999998`}, {
               63.465, 140.993}, {61.488, 140.993}, {61.488, 
               138.76999999999998`}, {63.25, 138.76999999999998`}, {63.25, 
               137.009}}}]}, 
             {FaceForm[{RGBColor[
              0.15686300000000003`, 0.6823529999999999, 0.4], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{63.452999999999996`, 
               137.212}, {63.452999999999996`, 138.97}, {61.691, 138.97}, {
               61.691, 140.79}, {63.26200000000001, 140.79}, {
               63.26200000000001, 139.571}, {65.27, 139.571}, {65.27, 
               137.212}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {1, 
               3, 3}, {0, 1, 0}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJRIGYC4odVIuvcNSMcKl+qGXIsSHWQ1r+rwqYI5S9J
dXh6Qen2z2PhDue/Bz9eeh6T78nDpN2eFu5wfXGBLddiTL5Ld87z3xvDHZoP
nFroWpfqcAmovW5XuMMCKaBFVakOe0smS7D4hTssP+Zt3uma6rBGJirF+j2C
D3NfD9CYlYmpDqpsjVOdkyPg8n5JAhGWLJFwvuWWE2X7pkfAzT8OFHZcEAG3
f9Pc98uPvY6Auw+drwIyvzsC7r+LIPdmRUDU7U91cAb5xzPCYRqIsR7hPlj4
AQCthJsa
               "]]}, 
             {FaceForm[{RGBColor[
              0.15686300000000003`, 0.6823529999999999, 0.4], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYCYrnW14E7joU7CERYbjlxLNVBHsQ/F+4gCOIf
SnV4WCWyzl0zwuH64gJbrumE+UDdcq3NEXD9YH53BNx8VbbGqc6TIxycEp5e
UDqc6tA7PU+o+QJUflmqg7T+XRW2mxEOX/5eqXi5KNXhuLd5pyNQXm/T3PfL
56U6ZEx8W2PfGuGwQAqosAqT75cENOlJhMM05+6c595Q8zMQfJh7dUHmZaU6
gIR/vwyHy+8tmSzBkofgZ4LMPxsONx+d7wLS3xgOdx/Y/MpwuPtr7U3jdjWG
w/23RiYqxXp/ONz/6OEPAFeYtek=
               "]]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {1, 
               3, 3}, {0, 1, 0}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJRIGYC4syJb2vsfcMcKl+qGXIsSHVY6Lrt818XKH9J
qkPsLk8eptehDue/Bz9eeh6Tf1Hp9s+6rlCH64sLbLkWY/KbD5xa6HotFELX
pTrIt74O3HEv1GGBlP5dlapUBy6QwqJQh+XHvM07XVMdVNkapzoLh8H5MPf1
5Dz/vTIx1WGNTFSKdTtCHkQ5aoTD+Zvnvl9+bHcY3Hy/JIEIyyNhcPsZQEAg
HO4+dH5xBtDC9WFw/4Hd2xfmsAlk7v5Uh70lkyVY8sIcpjl35zxfj3AfLPwA
brqWLQ==
               "]]}, 
             {FaceForm[{RGBColor[
              0.15686300000000003`, 0.6823529999999999, 0.4], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4thdnjxMr0MdBCIst5w4luoQD+J/DnUQBPEP
pTpkTnxbY+8b5nB9cYEt13TC/OIMoMDyMLh+qy0nyvatD4Obv0YmKsV6e5iD
U8LTC0qHUx1u/6zL2vMFKr8s1WGR67bPf/+EOXz5e6Xi5aJUB5F17g+rgPJ6
m+a+Xz4v1eFhFVBkZZjDAin9uypVmPze6XlCzRzhDtOcu3Oee0P194TB+TD3
6oLMy0p12FsyWYKFDyHvAqR+TwyF88HmfwxFtQ+JD9a/LBTuPoO7KmyNc0Ph
7v+mEdN/aGko3H+qbI1TnR+Hwv2PHv4Az+G4JA==
               "]]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {1, 
               3, 3}, {0, 1, 0}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJRIGYC4odVIuvcC0McKl+qGXIsSHXY9vnvlYpKKH9J
qsPrwB1yrZdDHM5/D3689Dwmv13s5rnvxqEO1xcX2HItxuT3Ts8Tan4R4tB8
4NRC17pUBwYQeBDisEBK/65KVaoD0PaHVT6hDsuPeZt3uqY6qLA1TnVeHQLn
w9zXk/P898rEVIc1MlEp1uYIebC504Lh/BlA6w4wIcznBjnkVzDcfvlWoA/W
BcPdh84Hm8+P8B/YvQYhDpvmvl9+bH+qQ8jjpbOPBIQ4THPuznm+HuE+WPgB
AHmtmBI=
               "]]}, 
             {FaceForm[{RGBColor[
              0.15686300000000003`, 0.6823529999999999, 0.4], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4k1z3y8/djnEQSDCcsuJY6kOYP7pEAdBEP9Q
qsPDKpF17oUhDtcXF9hyTSfMf3pB6fZPMYT+ZyA+H8L8NTJRKdbsIQ5OCUCV
h1MdnLtznv8+GQyRX5bqsO3z3ysVB4MdvgCpl4tSHbhABp8KdtADOWxeqoP+
XRW2RtEQhwVSQFYVJr/5wKmFrtuCHaaBDPZOdXABmW8YAufD3KsLMi8r1aF3
ep5Q8waEPFD2YZVOKJyfOfFtjf1ZhPnofLB+iVC4+8DmK4bC3R/yeOnsI0B5
mP9U2RqnOt9G+B89/AH5hbwF
               "]]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {1, 
               3, 3}, {0, 1, 0}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJRIGYC4odVIuvcNSMcdDfNfb98UoKDtP5dFTbFCAfB
CMstJ/oSHJ5eULr981i4w/XFBbZcyZh8Tx4m7fa0cAeQ9mP9mHyX7pznvzeG
O6z6eMk3aUuCwyWg9rpd4Q690/OEmnckOOwtmSzB4hfuAHbH2wSHNTJRKdbv
EXyY+8DuupjgoMrWONU5OQIu75ckEGHJEgnnA11dtm96BNz8497mnY4LIuD2
g931OgLuPnS+Csj87gi4/y6C3JsV4fDl75WKl0UJDs4g/3hCw6cJ4T5Y+AEA
1rqfLA==
               "]]}, 
             {FaceForm[{RGBColor[
              0.15686300000000003`, 0.6823529999999999, 0.4], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYCYrnW14E7joU7VL5UM+TISXCQB/HPhTtMc+7O
eZ6f4PCwSmSdu2aEw+a575cfm02YD9Qt19ocAdcP5ndHwM1XZWuc6jw5wuEN
SBwo3zs9T6j5AlR9d4KDtP5dFbabEQ6bQOb1Jzgc9zbvdLwA1T8lwSFj4tsa
+9YIiL4dmHy/JIEIyycRDkByy4lnUPMzEHyYe8HmnUhwAFn7+2U4XH5vyWQJ
ljwEPxNk/tlwuPnofBeQ/sZwuPvA5leGw91fa28at6sxHO6/NTJRKdb7w+H+
Rw9/AICQthA=
               "]]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {1, 
               3, 3}, {0, 1, 0}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJRIGYC4syJb2vsfcMcdDfNfb98UoLDQtdtn/+6hDkI
RlhuOdGX4BC7y5OH6XWow/XFBbZcyZj8i0q3f9Z1hTqAtB/rx+Q3Hzi10PVa
qMOqj5d8k7YkOMi3vg7ccS/UoXd6nlDzjgQHLpBBRaEOD6tE1rm/TXBQZWuc
6iwcBufD3Cetf1eF7WKCwxqZqBTrdoT8MW/zTkeNcDh/M8je3WFw8/2SBCIs
j4TB7WcAAYFwuPvQ+cUZQAvXh8H9B3ZvX5jDl79XKl4WJTjsLZkswZIHDZ8m
hPtg4QcAl/CaPw==
               "]]}, 
             {FaceForm[{RGBColor[
              0.15686300000000003`, 0.6823529999999999, 0.4], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4thdnjxMr0MdKl+qGXLkJDjEg/ifQx2mOXfn
PM9PcMic+LbG3jfMYfPc98uPzSbML84ACiwPg+u32nKibN/6MLj5a2SiUqy3
hzm8Cdwh1wqUv/2zLmvPF6j67gSHRa7bPv/9E+awCWRef4KDyDr3h1VfoPqn
JDg8rAKKrAxz6J2eJ9S8A5MPpjnCHQQiLLeceAbV3xMG58PcCzbvRILD3pLJ
Eix8CHkXoDN+TwyF88HmfwxFtQ+JD9a/LBTuPoO7KmyNc0Ph7v+mEdN/aGko
3H+qbI1TnR+Hwv2PHv4A+Nm4Sw==
               "]]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {1, 
               3, 3}, {0, 1, 0}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJRIGYC4odVIuvcC0McdDfNfb98UoLDts9/r1RUhjgI
RlhuOdGX4PA6cIdc6+UQh+uLC2y5kjH57WI3z303DnUAaT/Wj8nvnZ4n1Pwi
xGHVx0u+SVsSHBhA4EEIRHxHggPQ9odVPqEOYHe8TXBQYWuc6rw6BM6HuU9a
/64K28UEhzUyUSnW5gj55gOnFrpOC4bzZwCNPcCEMJ8b5NBfwXD75VuBPlgX
DHcfOh9sPj/Cf2D3GoQ4fAEGy8uiBIeQx0tnHwmAhk8Twn2w8AMAouOcJA==

               "]]}, 
             {FaceForm[{RGBColor[
              0.15686300000000003`, 0.6823529999999999, 0.4], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4k1z3y8/djnEofKlmiFHToIDmH86xGGac3fO
8/wEh4dVIuvcC0McNoPEZxPmP72gdPunGEL/MxCfD2H+GpmoFGv2EIc3gTvk
WoHyIGW/TwZD1HcnOGz7/PdKxcFgiDv6Exy4ri8usD0VDNE/JcFB/64KW6No
iEPv9Dyh5h2Y/OYDpxa6bgt2EIiw3HLiWYKDC8h8wxA4H+ZesHknEiD6NiDk
gbIPq3RC4fzMiW9r7M8izEfng2mJULj7wOYrhsLdH/J46ewjQHmY/1TZGqc6
30b4Hz38ASKMvCw=
               "]]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}}}, {{{69.18799999999999, 170.372}, {
               69.18799999999999, 166.016}, {63.26200000000001, 166.016}, {
               63.26200000000001, 139.571}, {69.18799999999999, 139.571}, {
               69.18799999999999, 135.212}, {109.227, 135.212}, {109.227, 
               139.571}, {115.15199999999999`, 139.571}, {115.15199999999999`,
                166.016}, {109.227, 166.016}, {109.227, 170.372}}}]}, 
             {FaceForm[{RGBColor[
              0.7921569999999999, 0.21568600000000002`, 0.27058800000000005`],
               Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}}}, {{{109.027, 170.17299999999997`}, {109.027, 
               165.813}, {114.94900000000001`, 165.813}, {114.94900000000001`,
                139.76999999999998`}, {109.027, 139.76999999999998`}, {
               109.027, 135.415}, {69.387, 135.415}, {69.387, 
               139.76999999999998`}, {63.465, 139.76999999999998`}, {63.465, 
               165.813}, {69.387, 165.813}, {69.387, 170.17299999999997`}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}}}, {{{106.46100000000001`, 168.497}, {
               71.94900000000001, 168.497}, {71.94900000000001, 163.251}, {
               65.137, 163.251}, {65.137, 142.333}, {71.94900000000001, 
               142.333}, {71.94900000000001, 137.08700000000002`}, {
               106.46100000000001`, 137.08700000000002`}, {
               106.46100000000001`, 142.333}, {113.277, 142.333}, {113.277, 
               163.251}, {106.46100000000001`, 163.251}}}]}, 
             {FaceForm[{RGBColor[
              0.7921569999999999, 0.21568600000000002`, 0.27058800000000005`],
               Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}}}, {{{106.262, 168.298}, {106.262, 163.048}, {
               113.074, 163.048}, {113.074, 142.536}, {106.262, 142.536}, {
               106.262, 137.29}, {72.15199999999999, 137.29}, {
               72.15199999999999, 142.536}, {65.34, 142.536}, {65.34, 
               163.048}, {72.15199999999999, 163.048}, {72.15199999999999, 
               168.298}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{65.137, 146.317}, {
               77.633, 137.08700000000002`}, {100.781, 137.08700000000002`}, {
               113.277, 146.317}, {113.277, 159.26999999999998`}, {100.781, 
               168.497}, {77.633, 168.497}, {65.137, 159.26999999999998`}}}]}, 
             {FaceForm[{RGBColor[
              0.15686300000000003`, 0.6823529999999999, 0.4], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}, {1,
                3, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{100.715, 168.298}, {100.766,
                168.259}, {112.992, 159.227}, {113.074, 159.165}, {113.074, 
               146.41899999999998`}, {112.992, 146.35600000000002`}, {100.766,
                137.329}, {100.715, 137.29}, {77.699, 137.29}, {77.648, 
               137.329}, {65.422, 146.35600000000002`}, {65.34, 
               146.41899999999998`}, {65.34, 159.165}, {65.422, 159.227}, {
               77.648, 168.259}, {77.699, 168.298}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{103.195, 165.684}, {75.117, 
               165.684}, {75.117, 163.454}, {71.531, 163.454}, {71.531, 
               142.13}, {75.117, 142.13}, {75.117, 139.899}, {
               103.29700000000001`, 139.899}, {103.29700000000001`, 142.13}, {
               106.883, 142.13}, {106.883, 163.454}, {103.29700000000001`, 
               163.454}, {103.29700000000001`, 165.684}}}]}, 
             {FaceForm[{RGBColor[
              0.7921569999999999, 0.21568600000000002`, 0.27058800000000005`],
               Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}}}, {{{103.09400000000001`, 
               165.48100000000002`}, {103.09400000000001`, 163.255}, {
               106.67999999999999`, 163.255}, {106.67999999999999`, 
               142.329}, {103.09400000000001`, 142.329}, {103.09400000000001`,
                140.102}, {75.32, 140.102}, {75.32, 142.329}, {
               71.73400000000001, 142.329}, {71.73400000000001, 163.255}, {
               75.32, 163.255}, {75.32, 165.48100000000002`}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{72.406, 
               145.02800000000002`}, {78.516, 139.899}, {99.898, 139.899}, {
               106.008, 145.02800000000002`}, {106.008, 160.555}, {99.898, 
               165.684}, {78.516, 165.684}, {72.406, 160.555}}}]}, 
             {FaceForm[{RGBColor[
              0.15686300000000003`, 0.6823529999999999, 0.4], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}, {1,
                3, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{99.824, 
               165.48100000000002`}, {99.883, 165.43800000000002`}, {
               105.73400000000001`, 160.52}, {105.80499999999999`, 
               160.46200000000002`}, {105.80499999999999`, 145.122}, {
               105.73400000000001`, 145.063}, {99.883, 140.14899999999997`}, {
               99.824, 140.102}, {78.59, 140.102}, {78.531, 
               140.14899999999997`}, {72.67999999999999, 145.063}, {72.609, 
               145.122}, {72.609, 160.46200000000002`}, {72.67999999999999, 
               160.52}, {78.531, 165.43800000000002`}, {78.59, 
               165.48100000000002`}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{73.473, 
               145.52800000000002`}, {78.902, 140.966}, {99.512, 140.966}, {
               104.938, 145.52800000000002`}, {104.938, 160.059}, {99.512, 
               164.618}, {78.902, 164.618}, {73.473, 160.059}}}]}, 
             {FaceForm[{RGBColor[
              0.7921569999999999, 0.21568600000000002`, 0.27058800000000005`],
               Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}, {1,
                3, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{99.438, 164.415}, {99.492, 
               164.36800000000002`}, {104.664, 160.024}, {104.738, 
               159.96200000000002`}, {104.738, 145.622}, {104.664, 145.559}, {
               99.492, 141.21599999999998`}, {99.438, 141.16899999999998`}, {
               78.977, 141.16899999999998`}, {78.922, 141.21599999999998`}, {
               73.74600000000001, 145.559}, {73.67599999999999, 145.622}, {
               73.67599999999999, 159.96200000000002`}, {73.74600000000001, 
               160.024}, {78.922, 164.36800000000002`}, {78.977, 164.415}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{81.363, 
               165.48100000000002`}, {97.051, 165.48100000000002`}, {97.051, 
               166.30200000000002`}, {95.398, 167.72299999999998`}, {
               93.85199999999999, 166.38700000000003`}, {92.30499999999999, 
               167.72299999999998`}, {90.754, 166.38700000000003`}, {
               89.20700000000001, 167.72299999999998`}, {87.66, 
               166.38700000000003`}, {86.109, 167.72299999999998`}, {84.562, 
               166.38700000000003`}, {83.016, 167.72299999999998`}, {81.363, 
               166.30200000000002`}}}]}, 
             {FaceForm[{RGBColor[
              0.7921569999999999, 0.21568600000000002`, 0.27058800000000005`],
               Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}}}, {{{96.848, 165.684}, {93.953, 165.684}, {93.953, 
               166.208}, {95.398, 167.454}, {96.848, 166.208}}}]}, 
             {FaceForm[{RGBColor[
              0.9803919999999999, 0.6823529999999999, 0.160784], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}}}, {{{93.75, 165.684}, {90.85499999999999, 165.684}, {
               90.85499999999999, 166.208}, {92.30499999999999, 167.454}, {
               93.75, 166.208}}}]}, 
             {FaceForm[{RGBColor[
              0.7921569999999999, 0.21568600000000002`, 0.27058800000000005`],
               Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}}}, {{{90.65199999999999, 165.684}, {87.758, 165.684}, {
               87.758, 166.208}, {89.20700000000001, 167.454}, {
               90.65199999999999, 166.208}}}]}, 
             {FaceForm[{RGBColor[
              0.9803919999999999, 0.6823529999999999, 0.160784], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}}}, {{{87.559, 165.684}, {84.664, 165.684}, {84.664, 
               166.208}, {86.109, 167.454}, {87.559, 166.208}}}]}, 
             {FaceForm[{RGBColor[
              0.7921569999999999, 0.21568600000000002`, 0.27058800000000005`],
               Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}}}, {{{84.46100000000001, 165.684}, {81.566, 165.684}, {
               81.566, 166.208}, {83.016, 167.454}, {84.46100000000001, 
               166.208}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{66.863, 149.696}, {68.195, 
               148.14899999999997`}, {66.863, 146.598}, {68.281, 
               144.95000000000002`}, {71.73400000000001, 
               144.95000000000002`}, {71.73400000000001, 160.634}, {68.281, 
               160.634}, {66.863, 158.985}, {68.195, 157.43800000000002`}, {
               66.863, 155.88700000000003`}, {68.195, 154.341}, {66.863, 
               152.79399999999998`}, {68.195, 151.24299999999997`}}}]}, 
             {FaceForm[{RGBColor[
              0.9803919999999999, 0.6823529999999999, 0.160784], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}}}, {{{68.37499999999999, 145.153}, {67.12899999999999, 
               146.598}, {68.37499999999999, 148.048}, {71.531, 148.048}, {
               71.531, 145.153}}}]}, 
             {FaceForm[{RGBColor[
              0.7921569999999999, 0.21568600000000002`, 0.27058800000000005`],
               Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}}}, {{{68.37499999999999, 148.24699999999999`}, {
               67.12899999999999, 149.696}, {68.37499999999999, 151.141}, {
               71.531, 151.141}, {71.531, 148.24699999999999`}}}]}, 
             {FaceForm[{RGBColor[
              0.9803919999999999, 0.6823529999999999, 0.160784], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}}}, {{{68.37499999999999, 151.345}, {67.12899999999999, 
               152.79399999999998`}, {68.37499999999999, 
               154.23899999999998`}, {71.531, 154.23899999999998`}, {71.531, 
               151.345}}}]}, 
             {FaceForm[{RGBColor[
              0.7921569999999999, 0.21568600000000002`, 0.27058800000000005`],
               Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}}}, {{{68.37499999999999, 154.442}, {67.12899999999999, 
               155.88700000000003`}, {68.37499999999999, 
               157.33700000000002`}, {71.531, 157.33700000000002`}, {71.531, 
               154.442}}}]}, 
             {FaceForm[{RGBColor[
              0.9803919999999999, 0.6823529999999999, 0.160784], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}}}, {{{68.37499999999999, 157.54}, {67.12899999999999, 
               158.985}, {68.37499999999999, 160.43}, {71.531, 160.43}, {
               71.531, 157.54}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{81.363, 140.102}, {97.051, 
               140.102}, {97.051, 139.282}, {95.398, 137.86}, {
               93.85199999999999, 139.196}, {92.30499999999999, 137.86}, {
               90.754, 139.196}, {89.20700000000001, 137.86}, {87.66, 
               139.196}, {86.109, 137.86}, {84.562, 139.196}, {83.016, 
               137.86}, {81.363, 139.282}}}]}, 
             {FaceForm[{RGBColor[
              0.7921569999999999, 0.21568600000000002`, 0.27058800000000005`],
               Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}}}, {{{96.848, 139.899}, {93.953, 139.899}, {93.953, 
               139.376}, {95.398, 138.13}, {96.848, 139.376}}}]}, 
             {FaceForm[{RGBColor[
              0.9803919999999999, 0.6823529999999999, 0.160784], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}}}, {{{93.75, 139.899}, {90.85499999999999, 139.899}, {
               90.85499999999999, 139.376}, {92.30499999999999, 138.13}, {
               93.75, 139.376}}}]}, 
             {FaceForm[{RGBColor[
              0.7921569999999999, 0.21568600000000002`, 0.27058800000000005`],
               Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}}}, {{{90.65199999999999, 139.899}, {87.758, 139.899}, {
               87.758, 139.376}, {89.20700000000001, 138.13}, {
               90.65199999999999, 139.376}}}]}, 
             {FaceForm[{RGBColor[
              0.9803919999999999, 0.6823529999999999, 0.160784], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}}}, {{{87.559, 139.899}, {84.664, 139.899}, {84.664, 
               139.376}, {86.109, 138.13}, {87.559, 139.376}}}]}, 
             {FaceForm[{RGBColor[
              0.7921569999999999, 0.21568600000000002`, 0.27058800000000005`],
               Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}}}, {{{84.46100000000001, 139.899}, {81.566, 139.899}, {
               81.566, 139.376}, {83.016, 138.13}, {84.46100000000001, 
               139.376}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{111.551, 149.696}, {
               110.21900000000001`, 148.14899999999997`}, {111.551, 
               146.598}, {110.133, 144.95000000000002`}, {106.67999999999999`,
                144.95000000000002`}, {106.67999999999999`, 160.634}, {
               110.133, 160.634}, {111.551, 158.985}, {110.21900000000001`, 
               157.43800000000002`}, {111.551, 155.88700000000003`}, {
               110.21900000000001`, 154.341}, {111.551, 
               152.79399999999998`}, {110.21900000000001`, 
               151.24299999999997`}}}]}, 
             {FaceForm[{RGBColor[
              0.9803919999999999, 0.6823529999999999, 0.160784], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}}}, {{{110.039, 145.153}, {111.285, 146.598}, {110.039, 
               148.048}, {106.883, 148.048}, {106.883, 145.153}}}]}, 
             {FaceForm[{RGBColor[
              0.7921569999999999, 0.21568600000000002`, 0.27058800000000005`],
               Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}}}, {{{110.039, 148.24699999999999`}, {111.285, 149.696}, {
               110.039, 151.141}, {106.883, 151.141}, {106.883, 
               148.24699999999999`}}}]}, 
             {FaceForm[{RGBColor[
              0.9803919999999999, 0.6823529999999999, 0.160784], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}}}, {{{110.039, 151.345}, {111.285, 152.79399999999998`}, {
               110.039, 154.23899999999998`}, {106.883, 
               154.23899999999998`}, {106.883, 151.345}}}]}, 
             {FaceForm[{RGBColor[
              0.7921569999999999, 0.21568600000000002`, 0.27058800000000005`],
               Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}}}, {{{110.039, 154.442}, {111.285, 155.88700000000003`}, {
               110.039, 157.33700000000002`}, {106.883, 
               157.33700000000002`}, {106.883, 154.442}}}]}, 
             {FaceForm[{RGBColor[
              0.9803919999999999, 0.6823529999999999, 0.160784], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}}}, {{{110.039, 157.54}, {111.285, 158.985}, {110.039, 
               160.43}, {106.883, 160.43}, {106.883, 157.54}}}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{82.031, 
               141.16899999999998`}, {83.191, 142.286}, {84.35199999999999, 
               141.16899999999998`}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{83.191, 
               144.622}, {82.05499999999999, 145.52800000000002`}, {80.922, 
               145.04}, {80.715, 143.74299999999997`}, {81.79700000000001, 
               142.79}, {80.02, 141.071}, {82.223, 141.071}, {83.191, 
               142.005}, {84.15599999999999, 141.071}, {86.363, 141.071}, {
               84.586, 142.79}, {85.664, 143.74299999999997`}, {
               85.46100000000001, 145.04}, {84.324, 
               145.52800000000002`}}}]}, 
             {FaceForm[{RGBColor[
              0.15686300000000003`, 0.6823529999999999, 0.4], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               81.10199999999999, 144.895}, {82.023, 145.29399999999998`}, {
               83.191, 144.364}, {83.254, 144.415}, {84.35499999999999, 
               145.29399999999998`}, {85.277, 144.895}, {85.44900000000001, 
               143.82100000000003`}, {84.285, 142.798}, {85.973, 
               141.16899999999998`}, {84.35199999999999, 
               141.16899999999998`}, {83.191, 142.286}, {82.031, 
               141.16899999999998`}, {80.406, 141.16899999999998`}, {
               82.09400000000001, 142.798}, {80.93400000000001, 
               143.82100000000003`}}}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{88.04700000000001, 
               141.16899999999998`}, {89.20700000000001, 142.286}, {90.367, 
               141.16899999999998`}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{89.20700000000001,
                144.622}, {88.074, 145.52800000000002`}, {86.938, 145.04}, {
               86.73400000000001, 143.74299999999997`}, {87.812, 142.79}, {
               86.035, 141.071}, {88.238, 141.071}, {89.20700000000001, 
               142.005}, {90.17599999999999, 141.071}, {92.37899999999999, 
               141.071}, {90.60199999999999, 142.79}, {91.684, 
               143.74299999999997`}, {91.477, 145.04}, {90.34, 
               145.52800000000002`}}}]}, 
             {FaceForm[{RGBColor[
              0.15686300000000003`, 0.6823529999999999, 0.4], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{87.121, 
               144.895}, {88.043, 145.29399999999998`}, {89.20700000000001, 
               144.364}, {89.27, 144.415}, {90.371, 145.29399999999998`}, {
               91.293, 144.895}, {91.465, 143.82100000000003`}, {
               90.30499999999999, 142.798}, {91.988, 141.16899999999998`}, {
               90.367, 141.16899999999998`}, {89.20700000000001, 142.286}, {
               88.04700000000001, 141.16899999999998`}, {86.426, 
               141.16899999999998`}, {88.109, 142.798}, {86.94900000000001, 
               143.82100000000003`}}}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{96.383, 
               141.16899999999998`}, {95.223, 142.286}, {94.062, 
               141.16899999999998`}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{95.223, 
               144.622}, {96.359, 145.52800000000002`}, {97.49600000000001, 
               145.04}, {97.699, 143.74299999999997`}, {96.617, 142.79}, {
               98.398, 141.071}, {96.191, 141.071}, {95.223, 142.005}, {
               94.258, 141.071}, {92.051, 141.071}, {93.82799999999999, 
               142.79}, {92.75, 143.74299999999997`}, {92.953, 145.04}, {
               94.09, 145.52800000000002`}}}]}, 
             {FaceForm[{RGBColor[
              0.15686300000000003`, 0.6823529999999999, 0.4], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{97.312, 
               144.895}, {96.391, 145.29399999999998`}, {95.223, 144.364}, {
               95.16, 144.415}, {94.059, 145.29399999999998`}, {93.137, 
               144.895}, {92.96900000000001, 143.82100000000003`}, {
               94.12899999999999, 142.798}, {92.44100000000002, 
               141.16899999999998`}, {94.062, 141.16899999999998`}, {95.223, 
               142.286}, {96.383, 141.16899999999998`}, {98.008, 
               141.16899999999998`}, {96.32, 142.798}, {97.48, 
               143.82100000000003`}}}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{82.031, 164.415}, {
               83.191, 163.298}, {84.35199999999999, 164.415}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{83.191, 
               160.96200000000002`}, {82.05499999999999, 160.055}, {80.922, 
               160.548}, {80.715, 161.841}, {81.79700000000001, 
               162.79399999999998`}, {79.98, 164.548}, {82.184, 164.548}, {
               83.191, 163.57899999999998`}, {84.195, 164.548}, {86.402, 
               164.548}, {84.586, 162.79399999999998`}, {85.664, 161.841}, {
               85.46100000000001, 160.548}, {84.324, 160.055}}}]}, 
             {FaceForm[{RGBColor[
              0.15686300000000003`, 0.6823529999999999, 0.4], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               81.10199999999999, 160.68800000000002`}, {82.023, 160.29}, {
               83.191, 161.22}, {83.254, 161.16899999999998`}, {
               84.35499999999999, 160.29}, {85.277, 160.68800000000002`}, {
               85.44900000000001, 161.762}, {84.285, 162.786}, {85.973, 
               164.415}, {84.35199999999999, 164.415}, {83.191, 163.298}, {
               82.031, 164.415}, {80.406, 164.415}, {82.09400000000001, 
               162.786}, {80.93400000000001, 161.762}}}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{88.04700000000001, 
               164.415}, {89.20700000000001, 163.298}, {90.367, 
               164.415}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{89.20700000000001,
                160.96200000000002`}, {88.074, 160.055}, {86.938, 160.548}, {
               86.73400000000001, 161.841}, {87.812, 162.79399999999998`}, {
               85.99600000000001, 164.548}, {88.203, 164.548}, {
               89.20700000000001, 163.57899999999998`}, {90.215, 164.548}, {
               92.418, 164.548}, {90.60199999999999, 162.79399999999998`}, {
               91.684, 161.841}, {91.477, 160.548}, {90.34, 160.055}}}]}, 
             {FaceForm[{RGBColor[
              0.15686300000000003`, 0.6823529999999999, 0.4], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{87.121, 
               160.68800000000002`}, {88.043, 160.29}, {89.20700000000001, 
               161.22}, {89.27, 161.16899999999998`}, {90.371, 160.29}, {
               91.293, 160.68800000000002`}, {91.465, 161.762}, {
               90.30499999999999, 162.786}, {91.988, 164.415}, {90.367, 
               164.415}, {89.20700000000001, 163.298}, {88.04700000000001, 
               164.415}, {86.426, 164.415}, {88.109, 162.786}, {
               86.94900000000001, 161.762}}}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{96.383, 164.415}, {
               95.223, 163.298}, {94.062, 164.415}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{95.223, 
               160.96200000000002`}, {96.359, 160.055}, {97.49600000000001, 
               160.548}, {97.699, 161.841}, {96.617, 162.79399999999998`}, {
               98.43400000000001, 164.548}, {96.23, 164.548}, {95.223, 
               163.57899999999998`}, {94.21900000000001, 164.548}, {92.016, 
               164.548}, {93.82799999999999, 162.79399999999998`}, {92.75, 
               161.841}, {92.953, 160.548}, {94.09, 160.055}}}]}, 
             {FaceForm[{RGBColor[
              0.15686300000000003`, 0.6823529999999999, 0.4], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{97.312, 
               160.68800000000002`}, {96.391, 160.29}, {95.223, 161.22}, {
               95.16, 161.16899999999998`}, {94.059, 160.29}, {93.137, 
               160.68800000000002`}, {92.96900000000001, 161.762}, {
               94.12899999999999, 162.786}, {92.44100000000002, 164.415}, {
               94.062, 164.415}, {95.223, 163.298}, {96.383, 164.415}, {
               98.008, 164.415}, {96.32, 162.786}, {97.48, 161.762}}}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{104.738, 
               158.567}, {104.738, 157.048}, {104.73400000000001`, 157.048}, {
               103.816, 157.805}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
               3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
               3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIpIGYC4oWu2z7/vRLpcPPc9+DHd5MdvmnE9B86G+nw
70rFS7WHyQ6WW06U7Zse6bDimLd5509MPli9a6TDqo+XfJO+JDtkTHxbY68a
6eDJw6Tdfg2Tv0YmKsU6PBKib2+yw7MLSrd/xkH5OxHyYPdsReiX1r+rwjYX
kw+zX5WtcapzPcJ9C6SACqow+TD/gd0zKdkB5n+w+FSovGkUxP5cBN8x4ekF
peXJDr3T84SaOaLg7oXJ94HEzyD454Hal/5PdvAC2aMX5SAYAXQJU4pDyOOl
s48IRDmkgcC3ZIcZQG0HPkHd9wrhHlh8AACwN8WQ
               "]]}, 
             {FaceForm[{RGBColor[
              0.15686300000000003`, 0.6823529999999999, 0.4], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIZIGYC4jUyUSnW+lEOC6T076pcSnbwSxKIsPwS6fBN
I6b/0M5kB5j8EYUNRRkLEXxpoHK2ymQHkXXuD6uuRDqkpwHBPEy+5ZYTZfum
RzoIRgBZTckOrwN3yLVOjnSw6HRMeNqQ7NB84NRC175Ih4dVQJ2NyQ6b5r5f
fiw40sEcJN+SDHGHL1S+NdlBha1xqrN3pMO578GPl7YnQ9xhGenQOz1PqHlG
skPGxLc19qaRDtOcu3Oez052UAWpt450+PL3SsVLoHvA5hQi/IfOh+nfCHLH
dYT5TglPLyjdRthf+VLNkOMNwn1g/75DuB/s33cI/4Gk0z4h/A+W/4QIH3B4
fECEH9hdVzH5sPDXBVn0K9kBAPEyyhI=
               "]]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{104.738, 
               153.555}, {104.738, 152.032}, {104.73400000000001`, 152.032}, {
               103.816, 152.79}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
               3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
               3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4oWu2z7/vRLpcERhQ1GGbbLDN42Y/kNnIx0K
bbmuL3ZIdrDccqJs3/RIB2n9uypskZh8sHrXSIdpzt05z4OTHTImvq2xV410
2FsyWYLFDJO/RiYqxTo80uFhlcg6d9lkh2cXlG7/jIPyJRHyYPeIIvSD3fMn
CYMPs18wAuiye0lw9/XkPP+98iYmH+a/PSD3fEpygPkfbP/XJIenIPeYRTmY
dzomPD2D4C+QAnk42aF3ep5QM0cU3L0w+T6QuA6CD7YnNdmh+cCpha5iUQ72
pnG7PCOg4fU10uHL3ysVL72SHdDDHwCGkrqO
               "]]}, 
             {FaceForm[{RGBColor[
              0.15686300000000003`, 0.6823529999999999, 0.4], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGI5IGYC4jUyUSnW+lEO3zRi+g8ZJjv4JQlEWH6JdHhY
JbLOXTLZASYvrX9XhY0Rwe+dnifUfCPJAajqYdWVSIeb574HP/6LybfccqJs
3/RIh+YDpxa6PkpyeB24Q651cqTDqo+XfJMeJEHE+yIdQh4vnX0EyN809/3y
Y8FQ+SdJEHf5RjoEg+SBfBW2xqnO3pEOjglPLyg9T4K4yzLSofKlmiHHjySH
jIlva+xNIx04QQ79neSgClJvHengxcOk3f4vCeKvQoT/CPFh+u1N43Z5miTD
zQeLmyfD7dcFOdwqGe6+NyB/eifD3Q8OD99kuP/A/vZLhvsfLB+YDA8fsHhQ
Mjz8wOERkAwPX3B4mGDyYfGzQArosKhkBwC57tdw
               "]]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{104.738, 
               147.016}, {104.738, 148.536}, {104.73400000000001`, 148.536}, {
               103.816, 147.778}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
               3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
               3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIpIGYC4oWu2z7/vRLpEPx46ewjIUkO3zRi+g+djXRY
cczbvDMwycFyy4myfdMjHf5dqXipZonJB6t3jXRoPnBqoatdkkPGxLc19qqR
DrH9h75qxGDy18hEpViHRzpI699VYStNcnh2Qen2z7hIB/NOx4SnFQj5EJB7
ahD6u3Oe/145FZMPs58DpHEzwn0FtlzXF+/A5MP8FwNyz4IkB5j/wfbPSXJ4
CnKPWZTDwyqRde5HEXyw+3uSHHqn5wk1c0TB3QuTB7snFcG/vhhoozHUf3pR
Due/A0NYPwnib8Eoh8qXaoYcNkkO8bs8eZg+Rzqs+njJN8kD4R5YfAAAHKjI
7g==
               "]]}, 
             {FaceForm[{RGBColor[
              0.15686300000000003`, 0.6823529999999999, 0.4], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIZIGYC4jUyUSnW+lEOvdPzhJoTkhz8kgQiLL9EOph3
OiY8rUhygMk/rBJZ5z4Rwe/Jef575c4kB6Dow6orkQ6rPl7yTZqCybfccqJs
3/RIh2nO3TnP1yc5vA7cIdc6OdLhm0ZM/6GNSQ7NB04tdO2LdFhxzNu8E8jf
NPf98mPBUPm1SRDaN9LhiMKGogwgX4Wtcaqzd6TD9cUFtlyrkxyk9e+qsFlG
OiyQAjJmJTlkTHxbY28a6QD0xZYT05IcVEHqrSMh5k5OgvijEOE/dD5MP9j8
aIT5574HP14ajrBfF2SgG8J99qZxuzxdEO4H+9cZ4T+wvAPC/2B5e0T4gM1x
RIQf2L+xmHxY+Fe+VDPksEhyAAAQD8ZG
               "]]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{73.67999999999999, 
               158.567}, {73.67999999999999, 157.048}, {74.598, 
               157.805}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
               3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
               3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIpIGYCYv27KmyNR4Mcbp77Hvz4brLD7Z91WXvOBDn8
u1LxUu1hssOMPKHmA0zBDiuOeZt3/sTkL3Td9vlvSLDDqo+XfJO+JDtkTHxb
Y18a7ODJw6Tdfg2T/zpwh1yrc7DDN42Y/kN7kx3egPjWUP5OhDzYPVsR+qVB
Dp2LyYfZr8rWONW5HuG+BVJABVWYfJj/wO6ZlOwA8z/Y/qlQ+RRoeOQi+I4J
Ty8oLU92cOnOef57YhDcvTD5vulAi84g+ODwYEhxUAG5KzvI4friAlsu5hQH
oGuvVHQGOehumvt++bdkh2KQh5YHObQcOLXQ9RXCPbD4AAA628bg
               "]]}, 
             {FaceForm[{RGBColor[
              0.15686300000000003`, 0.6823529999999999, 0.4], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIZIGYC4teBO+Ras4McFkjp31W5lOzQfODUQtdlQQ7f
NGL6D+1MdoDJH1HYUJSxEMGXBipnq0x22FsyWYLlWJBDehoQzMPkx+/y5GFi
DnYQjLDccqIp2eHpBaXbP9mCHSw6HROeNiQ7+CUJRFjyBDs8rBJZ594IlXcL
djAHybckO9z+WZe1xwcq35rssEYmKsXaP9jh3Pfgx0vbkx22ff57pSIx2KF3
ep5Q84xkh4yJb2vsU4Mdpjl35zyfDVUfH+zwBajsJdA9YHM0g+H+Q+fD9G+c
+375sesI850SQC5D2F/5Us2Q4w3CfWD/vkO4H+zfdwj/gaTTPiH8D5b/hAgf
cHh8QIQf2F1XMfmw8NfdBHTgr2QHAFQuzOI=
               "]]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{73.67999999999999, 
               153.555}, {73.67999999999999, 152.032}, {74.598, 152.79}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
               3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
               3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYCYv27KmyNR4McjihsKMqwTXa4/bMua8+ZIIdC
W67rix2SHWbkCTUfYAp2kAYpjMTkL3Td9vlvSLDDNOfunOfByQ4ZE9/W2JcG
O+wtmSzBYobJfx24Q67VOdjhYZXIOnfZZIc3IL41lC+JkAe7RxShH+yeP0kY
fJj9ghGWW07cS4K7ryfn+e+VNzH5MP/tAbnnU5IDzP9g+78mOQDJh1Up0PA4
i+B78jBpt7MlO7gAvfl7YhDcvTD52P5DXzV0klH1p0LDpyXIofKlmiFHBNQ/
S4McdDfNfb/cK9kBPfwBsn+wQQ==
               "]]}, 
             {FaceForm[{RGBColor[
              0.15686300000000003`, 0.6823529999999999, 0.4], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGI5IGYC4teBO+Ras4McvmnE9B8yTHZoPnBqoeuyIIeH
VSLr3CWTHWDy0vp3VdgYEfze6XlCzTeSHPaWTJZgORbkcPPc9+DHfzH58bs8
eZiYgyHmPkpyeHpB6fZPtmCHVR8v+SY9SHLwSxKIsOQJdgh5vHT2kQdQeTeo
/JMkh9s/67L2+AQ7BIPkgfw1MlEp1v7BDo4JQJXPkxy2ff57pSIx2KHypZoh
x48kh4yJb2vsU4MdOEEKf0PVxwc7ePEwabf/S4L4SzMY7j9CfJh+e9O4XZ4m
yXDzVdkapzqbJ8Pt19009/1yq2S4+96Awsk7Ge5+cHj4JsP9Bw4Pv2S4/8Hy
gcnw8AHLByXDww8cHgHJ8PAFh4cJJh8WPwukgBEWlewAAIKx2k0=
               "]]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{73.67999999999999, 
               147.016}, {73.67999999999999, 148.536}, {74.598, 
               147.778}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
               3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
               3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIpIGYCYv27KmyNR4Mcgh8vnX0kJMnh9s+6rD1nghxW
HPM27wxMcpiRJ9R8gCnY4d+Vipdqlpj8ha7bPv8NCXZoPnBqoatdkkPGxLc1
9qXBDrH9h75qxGDyXwfukGt1DnaQBllcmuTwBsS3DnYw73RMeFqBkA8BuacG
ob875/nvlVMx+TD7OdbIRKVsRrivwJbr+uIdmHyY/2JA7lmQ5ADzP9j+OUkO
IuvcH1alQPlHEPzz34Eh1J3k4AKyeGIQ3L0w+QVSQJPSEHzdTXPfLzdKcgBR
x7KDILR+kgPQtVcqOoMg4WGT5FAM8tDyIIfe6UCHeiDcA4sPAMpDxDI=
               
               "]]}, 
             {FaceForm[{RGBColor[
              0.15686300000000003`, 0.6823529999999999, 0.4], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIZIGYC4teBO+Ras4MceqfnCTUnJDk0Hzi10HVZkIN5
p2PC04okB5j8wyqRde4TEfyenOe/V+5McthbMlmC5ViQw6qPl3yTpmDy43d5
8jAxBztMc+7Oeb4+yeHpBaXbP9mCHb5pxPQf2pjk4JckEGHJE+yw4pi3eedG
qLwbVH5tksPtn3VZe3yCHY4obCjKAPLXyESlWPsHO1xfXGDLtTrJYdvnv1cq
EoMdFkjp31WZleSQMfFtjX1qsAPQ1C0npkHVxwc7bJr7fvmxyUkQf2gGw/2H
zofpB5sfjTD/3Pfgx0vDEfbrggx0Q7jP3jRul6cLwv1g/zoj/AeWd0D4Hyxv
jwgfsH8dEeEH9m8sJh8W/pUv1Qw5LJIcAHL8yRY=
               "]]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
               0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIRIGYCYk8eJu32aeEOXiB6VZIDjL9p7vvlxx4nOci1
vg7cYRaBwf/y90rFS79kuHp0vr1p3C7PjmSHGXlCzQeUMPnXFxfYch1PdrDc
cqJsX3koBh+mvl3s5rnvzJh8mH1gdyWHYPBh7oWpR+fD/AuzD51//nvw46XZ
SXD3ovNh6gHRGpUg
               "]]}, 
             {FaceForm[{RGBColor[
              0.9803919999999999, 0.6823529999999999, 0.160784], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}}}, {{{84.262, 154.266}, {84.262, 156.055}, {86.074, 
               156.055}, {86.074, 158.016}, {89.10499999999999, 158.016}, {
               89.10499999999999, 155.993}, {86.238, 154.364}, {86.238, 
               152.89100000000002`}, {81.762, 152.89100000000002`}, {81.762, 
               154.266}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               94.15199999999999, 151.32100000000003`}, {94.15199999999999, 
               149.52800000000002`}, {92.34, 149.52800000000002`}, {92.34, 
               147.567}, {89.309, 147.567}, {89.309, 149.591}, {
               92.17599999999999, 151.22}, {92.17599999999999, 152.692}, {
               96.65199999999999, 152.692}, {96.65199999999999, 
               151.32100000000003`}}}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               94.15199999999999, 156.055}, {94.15199999999999, 154.266}, {
               96.65199999999999, 154.266}, {96.65199999999999, 
               152.89100000000002`}, {92.17599999999999, 
               152.89100000000002`}, {92.17599999999999, 154.364}, {89.309, 
               155.993}, {89.309, 158.016}, {92.34, 158.016}, {92.34, 
               156.055}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               86.074, 149.52800000000002`}, {84.262, 149.52800000000002`}, {
               84.262, 151.32100000000003`}, {81.762, 151.32100000000003`}, {
               81.762, 152.692}, {86.238, 152.692}, {86.238, 151.22}, {
               89.10499999999999, 149.591}, {89.10499999999999, 147.567}, {
               86.074, 147.567}}}]}, 
             {FaceForm[{RGBColor[
              0.7921569999999999, 0.21568600000000002`, 0.27058800000000005`],
               Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               86.44100000000002, 152.692}, {86.44100000000002, 151.329}, {
               89.10499999999999, 149.813}, {89.10499999999999, 
               152.692}}}]}, 
             {FaceForm[{RGBColor[
              0.15686300000000003`, 0.6823529999999999, 0.4], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               89.10499999999999, 155.76999999999998`}, {86.44100000000002, 
               154.259}, {86.44100000000002, 152.895}, {89.10499999999999, 
               152.895}}}]}, 
             {FaceForm[{RGBColor[
              0.7921569999999999, 0.21568600000000002`, 0.27058800000000005`],
               Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{91.973, 
               152.895}, {91.973, 154.259}, {89.309, 155.76999999999998`}, {
               89.309, 152.895}}}]}, 
             {FaceForm[{RGBColor[
              0.15686300000000003`, 0.6823529999999999, 0.4], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{89.309, 
               149.813}, {91.973, 151.329}, {91.973, 152.692}, {89.309, 
               152.692}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
               0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
               0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
               0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}}}, CompressedData["
1:eJxlk1soRFEUhseMJCkltyRFiKR48CBhF5qkCXPmOIw5o8SDEh7klmia5EGS
JEoUkhSe5FYkJHmQpDRJroUkSUhM2WfrX2XOqf3wtfblX//6T1xNk7XOZDAY
/PjK5cvI12bLcJR/bimbfJnbLy5RGdhem31Z8lzFVt+8p+0ei47zMp0bRQt2
djhVuPKWVqxj7/zriSVaof2+fN0ZtmT2yPSeLws9bTY2MNoY6g6UiQ3adyWz
h29+4bv0V2+XmSZvYFViiQGukfxdiTj9IiHANSExTV7wjcS6NKEpMnFBf8P9
97qN7b4nOwattr/zbitxX4Tn6NMtsbOZ5pwgs8Sylg9at0Zl4vqh5648Sznr
eEzKCFyW2BiXs21UqF4UbEzti6gkXojhTkba6X6h/0ohtt3Oju81K6Rvmtvp
/akgFufPKqg/oT9OIT6JP//q3ignf0R9SCH/wpfM150Oh47h/weXsbOo6hjz
eypbi+01VesY88d+X0Z+8J4vI3//9HJGP8KXY5X6FX6GOMkPMPzSxth/p5Kf
YPgtDG1RaR5gzKtO87PHSfMEY95iXqFOygPqyAsYecL9yBsYeYQ+5BWMPKM/
5B2M/wH+/PtfuH+/A1q+Rg==
               "]]}, 
             {FaceForm[{RGBColor[
              0.7921569999999999, 0.21568600000000002`, 0.27058800000000005`],
               Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
               0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
               0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
               0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGI7IGYC4pDHS2cfWRDrMO/98mPe86Mc5FpfB+74Foed
rx7ugKIeid984NRC12ehDsUZE9/W+Mdg8B1M43Z5toQ4ePEwabf3hcP5D6tE
1rkvDHN48Xvlx0tfgyHycuEOh75qxPSvCnbIBGq3vxsB59faAzVKRjpcX1xg
y/U+2MFqy4myff3hcP43oLJDT8MdFDcUZUx0DXGQ1r+rwvYzEpUvGOlQ+VLN
kCMk2METZB9bOJwPts83zEHs5rnvwYeDHdpBjMmhcPltn/9eqegMRuUvDIKb
f/tnXdaeLSFw/vQ8oeYDXKFw94HDqyEYzgfbtzcY7j+wuTWhcD44fH6GwsOn
AiTPEwoPv9hdQB94B2DwYeH/C+icks++GHxY/KVY3/fvdffGzgfGP4p6JP4O
UMJ4EA23D53/B+hcX6dYuHthfJh/wOFwIRbuXzAtEwcPDxgfFl5gd12PhYcn
jA8Lb3C8NsbC4wOFD4yvw6DwLIqDxyeMjxLfzHHw9ACTh6UXFD4wPcHMh6U3
GB+WHmHug6VXGB+WnmH+g6V3GB+WH2DhA8svsPCD5Sd0Piz8YfkRxgcAsCzF
DA==
               "]]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
               0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIpIGYC4syJb2vsfcMcdsi1vg7UCHFw6c55/ntnuMPr
QKAIc6jDcW/zTscL0Rj8qBTr+/6pYQ7bPv+9UqEYi8H35GHSbl8W7lCcAbSg
PA6DD7ZPIQquHp3/sEpknXtiNNw+dH5A7/Q8ocMxcPfC+DD/NB84tdB1XqwD
SLj5QQhcnuv64gLbUwEYfJj5pnG7PHk++WHwYe7bUzJZgsXNB4MP8x9MPTof
Fj4w+9D5sPCFuRfGBwBbbLNz
               "]]}, 
             {FaceForm[{RGBColor[
              0.9803919999999999, 0.6823529999999999, 0.160784], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
               0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIpIGYCYlW2xqnOh6Md/qz8eMm3KMwBxt8h1/o6UCDU
wZOHSbt9WzicnznxbY29b5jDvPfLj3mbhzi0i9089/1xCFz+6QWl2z+vBWDw
Yea/CQTKcPtj8EHGBG8Od2AAgQQf7HzhKFT1SHwH07hdniHRcPvQ+c0HTi10
3RYDdy+Mj+Kf/li4f2HysPBA58PMv/2zLmuPSCwGH+a+i0ogkTjsfKD/UNQj
8WHhAwAvx8Mv
               "]]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
               0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIpIGYC4syJb2vsfcMcdNrFbp7rD3HY9vnvlYqF4Q4O
pnG7PGNCHYozgArKozH469wfVonsC3MIebx09pETMRj8ee+XH/P+H+4g3/o6
cIdcHHb+8UhU9Uj8+qw9JZM5ouH2ofP/rPx4yTcrBu5eGB/mH4EIyy0nzGId
pPXvqrD9DIHLx+/y5GFSDsTgw8z/VQdkLPbH4MPcl2J937/3uw92PtB/KOqR
+LDwgdmHzoeFL8y9MD4Agr3JpQ==
               "]]}, 
             {FaceForm[{RGBColor[
              0.15686300000000003`, 0.6823529999999999, 0.4], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
               0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIpIGYC4otKt3/WZUU7+PdOzxM6HeYA40vr31Vhywx1
2FsyWYJlXjicnznxbY29b5iDYITllhPzQhxE17k/rPoTApdnAAGDQAw+zHyg
aWF8e/0x+BUv1Qw5eCIcVhzzNu8U9MXgH/6qEdO/KxKuHp3/JnCHXOvvKLh9
6HzFDUUZE2Nj4O6F8WH+0WoXu3lOPRbuX5g8LDzQ+TDzK0Hu3BODwYe5r9be
NG6XYBwGH+Y/mHp0Pix8AIvmoTA=
               "]]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               70.738, 93.11}, {70.738, 87.759}, {79.09400000000001, 
               87.759}, {70.738, 93.30199999999999}}}]}, 
             {FaceForm[{RGBColor[
              0.7921569999999999, 0.21568600000000002`, 0.27058800000000005`],
               Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{70.94100000000002, 
               92.923}, {78.422, 87.962}, {70.94100000000002, 87.962}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4jUyUSnWy8MdpPXvqrAlhjvA+J8u+SYJCEQ4
vA7cIdeajeBnTnxbY+8b5hDQOz1P6HCEQ429adwuzzCHkMdLZx85EOHw7ILS
7Z96oXD1qmyNU50/h2DwYfZt+/z3SoUnJh/oivv+S8Pg6tH5zQdOLXT9Fgq3
D8aHuU/s5rnvwc6hcPfD5GH+Q+fDzAe7IzACgw9zHwAveoMP
               "]]}, 
             {FaceForm[{RGBColor[
              0.9803919999999999, 0.6823529999999999, 0.160784], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 
               1, 0}}}, {{{89.20700000000001, 98.809}, {93.29700000000001, 
               96.251}, {85.117, 96.251}}, {{93.29700000000001, 87.848}, {
               89.20700000000001, 85.29}, {85.117, 87.848}}}]}, 
             {FaceForm[{RGBColor[
              0.7921569999999999, 0.21568600000000002`, 0.27058800000000005`],
               Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               94.41000000000001, 90.583}, {94.41000000000001, 
               88.05199999999999}, {89.309, 88.05199999999999}, {89.309, 
               90.583}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               89.10499999999999, 90.583}, {89.10499999999999, 
               88.05199999999999}, {84.004, 88.05199999999999}, {84.004, 
               90.583}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{97.062, 
               93.31700000000001}, {97.062, 90.786}, {91.96100000000001, 
               90.786}, {91.96100000000001, 93.31700000000001}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{91.758, 
               93.31700000000001}, {91.758, 90.786}, {86.65599999999999, 
               90.786}, {86.65599999999999, 93.31700000000001}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{86.453, 
               93.31700000000001}, {86.453, 90.786}, {81.35199999999999, 
               90.786}, {81.35199999999999, 93.31700000000001}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               94.41000000000001, 96.048}, {94.41000000000001, 93.516}, {
               89.309, 93.516}, {89.309, 96.048}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               89.10499999999999, 96.048}, {89.10499999999999, 93.516}, {
               84.004, 93.516}, {84.004, 96.048}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
               0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4odVIuvcI0McwLRjpAOMv0Ou9XXgh0gHg7sq
bI2yCP4amagU6/9BDgG90/OEFkc5VL5UM+T4E+QgrQ9UuDAKQj8MhKsHcRuX
YvJh9skDhXfIYfKBttz3b42Aq0fne/IwabdfC4fbB+PD3AcypVU5HO5+mDzM
f+h8mPl7SyZLsKiFYvBh7gMAHJ14OA==
               "]]}, 
             {FaceForm[{RGBColor[
              0.7921569999999999, 0.21568600000000002`, 0.27058800000000005`],
               Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 
               0}}}, {{{75.988, 106.309}, {80.082, 103.755}, {71.898, 
               103.755}}, {{80.07799999999999, 95.35199999999999}, {75.988, 
               92.79400000000001}, {71.898, 95.35199999999999}}}]}, 
             {FaceForm[{RGBColor[
              0.9803919999999999, 0.6823529999999999, 0.160784], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               81.191, 98.083}, {81.191, 95.55199999999999}, {76.09, 
               95.55199999999999}, {76.09, 98.083}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{75.887, 
               98.083}, {75.887, 95.55199999999999}, {70.785, 
               95.55199999999999}, {70.785, 98.083}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{84.395, 
               100.81700000000001`}, {84.395, 98.286}, {79.293, 98.286}, {
               79.293, 100.81700000000001`}}}]}, 
             {FaceForm[{RGBColor[
              0.7921569999999999, 0.21568600000000002`, 0.27058800000000005`],
               Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{79.09, 
               100.81700000000001`}, {79.09, 98.286}, {73.988, 98.286}, {
               73.988, 100.81700000000001`}}}]}, 
             {FaceForm[{RGBColor[
              0.9803919999999999, 0.6823529999999999, 0.160784], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               73.785, 100.81700000000001`}, {73.785, 98.286}, {68.684, 
               98.286}, {68.684, 100.81700000000001`}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{81.191, 
               103.55199999999999`}, {81.191, 101.02}, {76.09, 101.02}, {
               76.09, 103.55199999999999`}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{75.887, 
               103.55199999999999`}, {75.887, 101.02}, {70.785, 101.02}, {
               70.785, 103.55199999999999`}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
               0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4odVIuvcHSMcIHSkA4y/Q671deCHSIdFrts+
/61B8FXZGqc6z450COidnie0OMrBi4dJu31epIO0/l0VtoVRDkDVVyp2RsHV
LwTp/4LJh9m3ee775ceqozH4USnW9/1bI+Dq0fmeIHuvhcPtg/Fh7nsdCLRR
ORzufpg8zH/ofJj5QN7DqpJwDD7MfQD7y4xs
               "]]}, 
             {FaceForm[{RGBColor[
              0.7921569999999999, 0.21568600000000002`, 0.27058800000000005`],
               Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 
               0}}}, {{{102.426, 106.309}, {98.332, 103.755}, {106.516, 
               103.755}}, {{98.336, 95.35199999999999}, {102.426, 
               92.79400000000001}, {106.516, 95.35199999999999}}}]}, 
             {FaceForm[{RGBColor[
              0.9803919999999999, 0.6823529999999999, 0.160784], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               97.223, 98.083}, {97.223, 95.55199999999999}, {102.324, 
               95.55199999999999}, {102.324, 98.083}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{102.527, 
               98.083}, {102.527, 95.55199999999999}, {107.62899999999999`, 
               95.55199999999999}, {107.62899999999999`, 98.083}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{94.02, 
               100.81700000000001`}, {94.02, 98.286}, {99.121, 98.286}, {
               99.121, 100.81700000000001`}}}]}, 
             {FaceForm[{RGBColor[
              0.7921569999999999, 0.21568600000000002`, 0.27058800000000005`],
               Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{99.324, 
               100.81700000000001`}, {99.324, 98.286}, {104.426, 98.286}, {
               104.426, 100.81700000000001`}}}]}, 
             {FaceForm[{RGBColor[
              0.9803919999999999, 0.6823529999999999, 0.160784], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               104.62899999999999`, 100.81700000000001`}, {
               104.62899999999999`, 98.286}, {109.73, 98.286}, {109.73, 
               100.81700000000001`}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{97.223, 
               103.55199999999999`}, {97.223, 101.02}, {102.324, 101.02}, {
               102.324, 103.55199999999999`}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{102.527, 
               103.55199999999999`}, {102.527, 101.02}, {107.62899999999999`, 
               101.02}, {107.62899999999999`, 103.55199999999999`}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
               0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4jUyUSnWy8MdFDcUZUxMjXKA8T15mLTbt0U6
vA7cIdeajeBnTnxbY+8bBhFnjnSosTeN2+UZ5vDi98qPl1gjHZ5dULr9Uy8U
rl6VrXGq8+cQDD7Mvm2f/16p8MTkP6wSWeeuGA1Xj84H2v468EI03D4YH+Y+
sZvnvgc3x8DdD5OH+Q+dDzNfWv+uCltgBAYf5j4Ayk2BGA==
               "]]}, 
             {FaceForm[{RGBColor[
              0.9803919999999999, 0.6823529999999999, 0.160784], Opacity[
              1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 
               0}}}, {{{89.20700000000001, 100.29400000000001`}, {
               93.29700000000001, 102.85199999999999`}, {85.117, 
               102.85199999999999`}}, {{93.29700000000001, 111.255}, {
               89.20700000000001, 113.813}, {85.117, 111.255}}}]}, 
             {FaceForm[{RGBColor[
              0.7921569999999999, 0.21568600000000002`, 0.27058800000000005`],
               Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               94.41000000000001, 108.52}, {94.41000000000001, 
               111.05199999999999`}, {89.309, 111.05199999999999`}, {89.309, 
               108.52}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               89.10499999999999, 108.52}, {89.10499999999999, 
               111.05199999999999`}, {84.004, 111.05199999999999`}, {84.004, 
               108.52}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{97.062, 
               105.79}, {97.062, 108.321}, {91.96100000000001, 108.321}, {
               91.96100000000001, 105.79}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{91.758, 
               105.79}, {91.758, 108.321}, {86.65599999999999, 108.321}, {
               86.65599999999999, 105.79}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{86.453, 
               105.79}, {86.453, 108.321}, {81.35199999999999, 108.321}, {
               81.35199999999999, 105.79}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               94.41000000000001, 103.05499999999999`}, {94.41000000000001, 
               105.587}, {89.309, 105.587}, {89.309, 103.05499999999999`}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               89.10499999999999, 103.05499999999999`}, {89.10499999999999, 
               105.587}, {84.004, 105.587}, {84.004, 103.05499999999999`}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               70.738, 105.99300000000001`}, {70.738, 111.345}, {
               79.09400000000001, 111.345}, {70.738, 105.80499999999999`}}}]}, 
             {FaceForm[{RGBColor[
              0.7921569999999999, 0.21568600000000002`, 0.27058800000000005`],
               Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}}}, {{{70.94100000000002, 
               106.17999999999999`}, {71.23, 106.37599999999999`}, {
               77.91000000000001, 110.80499999999999`}, {78.422, 111.141}, {
               70.94100000000002, 111.141}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               107.67599999999999`, 93.11}, {107.67599999999999`, 87.759}, {
               99.32, 87.759}, {107.67599999999999`, 93.30199999999999}}}]}, 
             {FaceForm[{RGBColor[
              0.7921569999999999, 0.21568600000000002`, 0.27058800000000005`],
               Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}}}, {{{107.473, 92.923}, {
               107.184, 92.73100000000001}, {100.504, 88.298}, {99.992, 
               87.962}, {107.473, 87.962}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               107.67599999999999`, 105.99300000000001`}, {
               107.67599999999999`, 111.345}, {99.32, 111.345}, {
               107.67599999999999`, 105.80499999999999`}}}]}, 
             {FaceForm[{RGBColor[
              0.7921569999999999, 0.21568600000000002`, 0.27058800000000005`],
               Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}}}, {{{107.473, 
               106.17999999999999`}, {107.184, 106.37599999999999`}, {100.504,
                110.80499999999999`}, {99.992, 111.141}, {107.473, 
               111.141}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               72.37899999999999, 100.255}, {72.37899999999999, 98.848}, {
               70.09, 98.848}, {70.09, 100.255}}}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               70.30499999999999, 100.04}, {72.16399999999999, 100.04}, {
               72.16399999999999, 99.063}, {70.30499999999999, 99.063}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               74.48400000000001, 102.989}, {74.48400000000001, 101.583}, {
               72.191, 101.583}, {72.191, 102.989}}}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{72.406, 
               102.774}, {74.265, 102.774}, {74.265, 101.797}, {72.406, 
               101.797}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               79.785, 102.989}, {79.785, 101.583}, {77.49600000000001, 
               101.583}, {77.49600000000001, 102.989}}}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               77.71100000000001, 102.774}, {79.57000000000001, 102.774}, {
               79.57000000000001, 101.797}, {77.71100000000001, 
               101.797}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               77.684, 100.255}, {77.684, 98.848}, {75.395, 98.848}, {75.395, 
               100.255}}}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{75.609, 
               100.04}, {77.46799999999999, 100.04}, {77.46799999999999, 
               99.063}, {75.609, 99.063}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               82.988, 100.255}, {82.988, 98.848}, {80.695, 98.848}, {80.695, 
               100.255}}}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               80.91400000000002, 100.04}, {82.77300000000001, 100.04}, {
               82.77300000000001, 99.063}, {80.91400000000002, 99.063}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               79.785, 97.52}, {79.785, 96.114}, {77.49600000000001, 
               96.114}, {77.49600000000001, 97.52}}}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               77.71100000000001, 97.30499999999999}, {79.57000000000001, 
               97.30499999999999}, {79.57000000000001, 96.332}, {
               77.71100000000001, 96.332}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               74.48400000000001, 97.52}, {74.48400000000001, 96.114}, {
               72.191, 96.114}, {72.191, 97.52}}}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{72.406, 
               97.30499999999999}, {74.265, 97.30499999999999}, {74.265, 
               96.332}, {72.406, 96.332}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               87.699, 110.489}, {87.699, 109.083}, {85.41000000000001, 
               109.083}, {85.41000000000001, 110.489}}}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               85.62499999999999, 110.274}, {87.48399999999998, 110.274}, {
               87.48399999999998, 109.301}, {85.62499999999999, 
               109.301}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               93.004, 110.489}, {93.004, 109.083}, {90.715, 109.083}, {
               90.715, 110.489}}}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{90.93, 
               110.274}, {92.789, 110.274}, {92.789, 109.301}, {90.93, 
               109.301}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               85.051, 107.759}, {85.051, 106.35199999999999`}, {82.758, 
               106.35199999999999`}, {82.758, 107.759}}}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{82.973, 
               107.54}, {84.832, 107.54}, {84.832, 106.56700000000001`}, {
               82.973, 106.56700000000001`}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               90.35199999999999, 107.759}, {90.35199999999999, 
               106.35199999999999`}, {88.062, 106.35199999999999`}, {88.062, 
               107.759}}}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{88.277, 
               107.54}, {90.136, 107.54}, {90.136, 106.56700000000001`}, {
               88.277, 106.56700000000001`}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               95.65599999999999, 107.759}, {95.65599999999999, 
               106.35199999999999`}, {93.363, 106.35199999999999`}, {93.363, 
               107.759}}}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{93.582, 
               107.54}, {95.44099999999999, 107.54}, {95.44099999999999, 
               106.56700000000001`}, {93.582, 106.56700000000001`}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               87.699, 105.024}, {87.699, 103.618}, {85.41000000000001, 
               103.618}, {85.41000000000001, 105.024}}}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               85.62499999999999, 104.809}, {87.48399999999998, 104.809}, {
               87.48399999999998, 103.832}, {85.62499999999999, 
               103.832}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               93.004, 105.024}, {93.004, 103.618}, {90.715, 103.618}, {
               90.715, 105.024}}}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{90.93, 
               104.809}, {92.789, 104.809}, {92.789, 103.832}, {90.93, 
               103.832}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               100.918, 102.989}, {100.918, 101.583}, {98.62899999999999, 
               101.583}, {98.62899999999999, 102.989}}}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               98.84400000000001, 102.774}, {100.703, 102.774}, {100.703, 
               101.797}, {98.84400000000001, 101.797}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               106.223, 102.989}, {106.223, 101.583}, {103.93, 101.583}, {
               103.93, 102.989}}}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{104.148, 
               102.774}, {106.00699999999999`, 102.774}, {106.00699999999999`,
                101.797}, {104.148, 101.797}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               97.71900000000001, 100.255}, {97.71900000000001, 98.848}, {
               95.426, 98.848}, {95.426, 100.255}}}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{95.641, 
               100.04}, {97.5, 100.04}, {97.5, 99.063}, {95.641, 
               99.063}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               103.02, 100.255}, {103.02, 98.848}, {100.73, 98.848}, {100.73, 
               100.255}}}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               100.94500000000001`, 100.04}, {102.804, 100.04}, {102.804, 
               99.063}, {100.94500000000001`, 99.063}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               108.324, 100.255}, {108.324, 98.848}, {106.035, 98.848}, {
               106.035, 100.255}}}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{106.25, 
               100.04}, {108.109, 100.04}, {108.109, 99.063}, {106.25, 
               99.063}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               100.918, 97.52}, {100.918, 96.114}, {98.62899999999999, 
               96.114}, {98.62899999999999, 97.52}}}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               98.84400000000001, 97.30499999999999}, {100.703, 
               97.30499999999999}, {100.703, 96.332}, {98.84400000000001, 
               96.332}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               106.223, 97.52}, {106.223, 96.114}, {103.93, 96.114}, {103.93, 
               97.52}}}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{104.148, 
               97.30499999999999}, {106.00699999999999`, 97.30499999999999}, {
               106.00699999999999`, 96.332}, {104.148, 96.332}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               87.699, 95.485}, {87.699, 94.079}, {85.41000000000001, 
               94.079}, {85.41000000000001, 95.485}}}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               85.62499999999999, 95.27}, {87.48399999999998, 95.27}, {
               87.48399999999998, 94.297}, {85.62499999999999, 94.297}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               93.004, 95.485}, {93.004, 94.079}, {90.715, 94.079}, {90.715, 
               95.485}}}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{90.93, 
               95.27}, {92.789, 95.27}, {92.789, 94.297}, {90.93, 94.297}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               85.051, 92.755}, {85.051, 91.348}, {82.758, 91.348}, {82.758, 
               92.755}}}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{82.973, 
               92.536}, {84.832, 92.536}, {84.832, 91.563}, {82.973, 
               91.563}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               90.35199999999999, 92.755}, {90.35199999999999, 91.348}, {
               88.062, 91.348}, {88.062, 92.755}}}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{88.277, 
               92.536}, {90.136, 92.536}, {90.136, 91.563}, {88.277, 
               91.563}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               95.65599999999999, 92.755}, {95.65599999999999, 91.348}, {
               93.363, 91.348}, {93.363, 92.755}}}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{93.582, 
               92.536}, {95.44099999999999, 92.536}, {95.44099999999999, 
               91.563}, {93.582, 91.563}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               87.699, 90.02}, {87.699, 88.614}, {85.41000000000001, 
               88.614}, {85.41000000000001, 90.02}}}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               85.62499999999999, 89.80499999999999}, {87.48399999999998, 
               89.80499999999999}, {87.48399999999998, 88.82799999999999}, {
               85.62499999999999, 88.82799999999999}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               93.004, 90.02}, {93.004, 88.614}, {90.715, 88.614}, {90.715, 
               90.02}}}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{90.93, 
               89.80499999999999}, {92.789, 89.80499999999999}, {92.789, 
               88.82799999999999}, {90.93, 88.82799999999999}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{118.15199999999999`, 
               40.345}, {98.301, 29.661}, {80.113, 29.661}, {
               60.26200000000001, 40.345}, {60.26200000000001, 57.946}, {
               80.113, 68.62599999999999}, {98.301, 68.62599999999999}, {
               118.15199999999999`, 57.946}}}]}, 
             {FaceForm[{RGBColor[
              0.15686300000000003`, 0.6823529999999999, 0.4], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{98.25, 29.864}, {
               117.94900000000001`, 40.466}, {117.94900000000001`, 57.825}, {
               98.25, 68.423}, {80.164, 68.423}, {60.465, 57.825}, {60.465, 
               40.466}, {80.164, 29.864}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{116.54700000000001`, 
               41.312999999999995`}, {97.898, 31.278}, {80.516, 31.278}, {
               61.867, 41.312999999999995`}, {61.867, 56.977}, {80.516, 
               67.012}, {97.898, 67.012}, {116.54700000000001`, 56.977}}}]}, 
             {FaceForm[{RGBColor[
              0.9803919999999999, 0.6823529999999999, 0.160784], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}}}, {{{116.34400000000001`, 41.434}, {116.34400000000001`, 
               49.044}, {89.309, 49.044}, {89.309, 31.480999999999998`}, {
               97.848, 31.480999999999998`}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}}}, {{{62.07, 49.247}, {89.10499999999999, 49.247}, {
               89.10499999999999, 66.809}, {80.566, 66.809}, {62.07, 
               56.855999999999995`}}}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}}}, {{{80.566, 31.480999999999998`}, {89.10499999999999, 
               31.480999999999998`}, {89.10499999999999, 49.044}, {62.07, 
               49.044}, {62.07, 41.434}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}}}, {{{116.34400000000001`, 56.855999999999995`}, {97.848, 
               66.809}, {89.309, 66.809}, {89.309, 49.247}, {
               116.34400000000001`, 49.247}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
               0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGI5IGYC4qcXlG7/LItwWCClf1eFzdUhfpcnD5NyuIPu
prnvl4c5w/n3VNgapzY7Orh05zz/zRjhAOQ5d9s4OBRnTHxbsz0Mg7/O/WGV
yDknh0wg1943zOH64gJbLncniHmPQ+HyMD5Mf+/0PKHmGSGo5pWHwu2H8WHu
UwUpVA6Bu/+bRkz/IdNgDP7Jsn3zpeR94OphfJh51vf9e6ef84Xz/12peKm2
0B/unsqXaoYcJQFw96Lzwf4L94P7V3FDUcbEu37w8IDJw/gw/bDwRDEPGN4w
+2F8mPtg8QVz/+2fdVl7UiIx+DD/AwAX3Mlr
               "]]}, 
             {FaceForm[{RGBColor[
              0.9803919999999999, 0.6823529999999999, 0.160784], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}}}, {{{97.801, 56.04}, {92.34400000000001, 59.501}, {
               92.34400000000001, 63.36}, {95.41400000000002, 65.61}, {91.07, 
               65.61}, {91.07, 60.309}, {89.309, 61.427}, {89.309, 49.247}, {
               101.371, 49.247}, {101.371, 56.04}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               80.609, 42.251}, {86.07, 38.786}, {86.07, 34.927}, {83., 
               32.67700000000001}, {87.34400000000001, 32.67700000000001}, {
               87.34400000000001, 37.977}, {89.10499999999999, 36.86}, {
               89.10499999999999, 49.044}, {77.039, 49.044}, {77.039, 
               42.251}}}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{91.07,
                32.67700000000001}, {95.41400000000002, 32.67700000000001}, {
               92.34400000000001, 34.927}, {92.34400000000001, 38.786}, {
               97.801, 42.251}, {101.371, 42.251}, {101.371, 49.044}, {89.309,
                49.044}, {89.309, 36.86}, {91.07, 37.977}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{86.07,
                59.501}, {80.609, 56.04}, {77.039, 56.04}, {77.039, 49.247}, {
               89.10499999999999, 49.247}, {89.10499999999999, 61.43}, {
               87.34400000000001, 60.309}, {87.34400000000001, 65.61}, {83., 
               65.61}, {86.07, 63.36}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}}}, {{{97.43400000000001, 54.755}, {100.098, 54.755}, {
               100.098, 43.532000000000004`}, {97.43400000000001, 
               43.532000000000004`}, {89.20700000000001, 
               38.312999999999995`}, {80.98, 43.532000000000004`}, {78.316, 
               43.532000000000004`}, {78.316, 54.755}, {80.98, 54.755}, {
               89.20700000000001, 59.973}, {89.262, 59.942}}}]}, 
             {FaceForm[{RGBColor[
              0.7921569999999999, 0.21568600000000002`, 0.27058800000000005`],
               Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}}}, {{{97.37499999999999, 54.552}, {89.20700000000001, 
               59.73500000000001}, {81.039, 54.552}, {78.52, 54.552}, {78.52, 
               43.73500000000001}, {81.039, 43.73500000000001}, {
               89.20700000000001, 38.552}, {97.37499999999999, 
               43.73500000000001}, {99.895, 43.73500000000001}, {99.895, 
               54.552}, {97.406, 54.552}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
               0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
               0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
               0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
               0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIPIGYC4uKMiW9rroc5zJoJBJreDij8k14O7WI3z30X
DsfO5/Ry+A8C5WHY+S+9HbivLy6wvRWOwT//Pfjx0tleDs0HTi10bYvA4C8/
5m3eudHDYUaeUPOBS+HY+YWeDnKtrwN3qEVg8MHm3fZ0eHpB6fbPbeFw/sMq
kXXuK8McDn/ViOmf5AGXB7vP0x2uH50f0Ds9T2izO9x+rPxiD7j70flg8zrd
UMMDie+UAHSJtSs8/LDypd3h4Y+VH+0Gjz+s/N+uEPdWhWPwIf5xc8gEKrf3
DXMwi9vlyaPk4WC15UTZPvlQuDyMDw5PoP54oDKmw5h8mP1AnnZ7GyYfrB7o
/ovA4K9TCsPgw/x/HBitjgdCMPiw8PNLEoiwFMHkw8LfEuTe4zj4wPjbNPf9
8mPFmHxY/KuyNU51fozgg9PPx1B4+oHJw9IXTD86H5Y+YfZj5QPTN8z96HxY
/oD5H50Py1+w8MPKB+ZPWPhj5QPzNyz+sPKB5QMs/tH5pqD0UuQFTz/g8GHy
hKcvmDyMD9MPAIz0HZY=
               "]]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
               0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
               0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
               0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIPIGYCYrnW14E70kIcpkiwhPGddXeYkSfUfGAXJp+X
SbtdLNLD4WGVyDp3RUx+QO/0PKHFbg6ZE9/W2J/F5LcBrZELdXXQv6vC1iga
hsFfcczbvJPR3QEk3Do5FIMPcqZcqZuD1ZYTZfvOY/JXgtQ/dIW4VwiTDzbv
INQ9vmEOhbZc1xc7eDhYgvS3h8PlYXyY/otKt3/WnQrD4MPsf3oBKMAWjsGH
uX+h67bPf1vCMPgw/0PCJxyDDws/cPhWRmDwYeEP9v/9cAw+LP42zX2//Jhx
BAY/jE9301x9aPhuDofzjwOd6TghzOHwV42Y/kkecHmw/756wvWj8z9d8k0S
iPCE24/OP/89+PHS0x5w96PzweHT6AX3Pzo/HOS+897w8EPn3wMmo6nKXvDw
R+eD/bfeCx5/6HywemdvePxj5Sd7wdNP9p6SyRJPPODpCyaPwgfqh6VPdD7M
flj6RufD3A/LH+h8mP9h+QudDws/WP5E58PCH5a/0fmw+IOVD+h8WPyDw/cZ
gu/cnfP8Nyci/cDkYekLph/GBwDIKwPE
               "]]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}}}, {{{107.613, 48.255}, {107.613, 
               46.294000000000004`}, {109.992, 46.294000000000004`}, {109.992,
                48.255}, {112.35499999999999`, 48.255}, {112.35499999999999`, 
               42.704}, {109.992, 42.704}, {109.992, 44.665000000000006`}, {
               107.613, 44.665000000000006`}, {107.613, 42.704}, {105.25, 
               42.704}, {105.25, 48.255}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}}}, {{{99.16, 40.88399999999999}, {99.16, 
               38.923}, {101.539, 38.923}, {101.539, 40.88399999999999}, {
               103.902, 40.88399999999999}, {103.902, 35.333}, {101.539, 
               35.333}, {101.539, 37.294000000000004`}, {99.16, 
               37.294000000000004`}, {99.16, 35.333}, {96.79700000000001, 
               35.333}, {96.79700000000001, 40.88399999999999}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}}}, {{{107.613, 50.036}, {107.613, 51.997}, {
               109.992, 51.997}, {109.992, 50.036}, {112.35499999999999`, 
               50.036}, {112.35499999999999`, 55.586999999999996`}, {109.992, 
               55.586999999999996`}, {109.992, 53.626000000000005`}, {107.613,
                53.626000000000005`}, {107.613, 55.586999999999996`}, {105.25,
                55.586999999999996`}, {105.25, 50.036}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}}}, {{{70.801, 48.255}, {70.801, 
               46.294000000000004`}, {68.422, 46.294000000000004`}, {68.422, 
               48.255}, {66.059, 48.255}, {66.059, 42.704}, {68.422, 
               42.704}, {68.422, 44.665000000000006`}, {70.801, 
               44.665000000000006`}, {70.801, 42.704}, {73.164, 42.704}, {
               73.164, 48.255}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}}}, {{{70.801, 50.036}, {70.801, 51.997}, {68.422,
                51.997}, {68.422, 50.036}, {66.059, 50.036}, {66.059, 
               55.586999999999996`}, {68.422, 55.586999999999996`}, {68.422, 
               53.626000000000005`}, {70.801, 53.626000000000005`}, {70.801, 
               55.586999999999996`}, {73.164, 55.586999999999996`}, {73.164, 
               50.036}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}}}, {{{99.16, 57.403}, {99.16, 59.364}, {101.539, 
               59.364}, {101.539, 57.403}, {103.902, 57.403}, {103.902, 
               62.958}, {101.539, 62.958}, {101.539, 60.997}, {99.16, 
               60.997}, {99.16, 62.958}, {96.79700000000001, 62.958}, {
               96.79700000000001, 57.403}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}}}, {{{79.254, 40.88399999999999}, {79.254, 
               38.923}, {76.87499999999999, 38.923}, {76.87499999999999, 
               40.88399999999999}, {74.512, 40.88399999999999}, {74.512, 
               35.333}, {76.87499999999999, 35.333}, {76.87499999999999, 
               37.294000000000004`}, {79.254, 37.294000000000004`}, {79.254, 
               35.333}, {81.617, 35.333}, {81.617, 40.88399999999999}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}}}, {{{79.254, 57.403}, {79.254, 59.364}, {
               76.87499999999999, 59.364}, {76.87499999999999, 57.403}, {
               74.512, 57.403}, {74.512, 62.958}, {76.87499999999999, 
               62.958}, {76.87499999999999, 60.997}, {79.254, 60.997}, {
               79.254, 62.958}, {81.617, 62.958}, {81.617, 57.403}}}]}, 
             {FaceForm[{RGBColor[
              0.7921569999999999, 0.21568600000000002`, 0.27058800000000005`],
               Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}}}, {{{105.453, 48.052}, {105.453, 42.907}, {
               107.41000000000001`, 42.907}, {107.41000000000001`, 44.864}, {
               110.195, 44.864}, {110.195, 42.907}, {112.15199999999999`, 
               42.907}, {112.15199999999999`, 48.052}, {110.195, 48.052}, {
               110.195, 46.091}, {107.41000000000001`, 46.091}, {
               107.41000000000001`, 48.052}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}}}, {{{97., 40.68}, {97., 35.536}, {
               98.95700000000001, 35.536}, {98.95700000000001, 37.497}, {
               101.742, 37.497}, {101.742, 35.536}, {103.699, 35.536}, {
               103.699, 40.68}, {101.742, 40.68}, {101.742, 
               38.720000000000006`}, {98.95700000000001, 
               38.720000000000006`}, {98.95700000000001, 40.68}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}}}, {{{105.453, 50.23500000000001}, {105.453, 
               55.38399999999999}, {107.41000000000001`, 55.38399999999999}, {
               107.41000000000001`, 53.423}, {110.195, 53.423}, {110.195, 
               55.38399999999999}, {112.15199999999999`, 55.38399999999999}, {
               112.15199999999999`, 50.23500000000001}, {110.195, 
               50.23500000000001}, {110.195, 52.196000000000005`}, {
               107.41000000000001`, 52.196000000000005`}, {
               107.41000000000001`, 50.23500000000001}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}}}, {{{72.96100000000001, 48.052}, {
               72.96100000000001, 42.907}, {71.004, 42.907}, {71.004, 
               44.864}, {68.21900000000001, 44.864}, {68.21900000000001, 
               42.907}, {66.262, 42.907}, {66.262, 48.052}, {
               68.21900000000001, 48.052}, {68.21900000000001, 46.091}, {
               71.004, 46.091}, {71.004, 48.052}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}}}, {{{72.96100000000001, 50.23500000000001}, {
               72.96100000000001, 55.38399999999999}, {71.004, 
               55.38399999999999}, {71.004, 53.423}, {68.21900000000001, 
               53.423}, {68.21900000000001, 55.38399999999999}, {66.262, 
               55.38399999999999}, {66.262, 50.23500000000001}, {
               68.21900000000001, 50.23500000000001}, {68.21900000000001, 
               52.196000000000005`}, {71.004, 52.196000000000005`}, {71.004, 
               50.23500000000001}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}}}, {{{97., 57.606}, {97., 62.755}, {
               98.95700000000001, 62.755}, {98.95700000000001, 
               60.794000000000004`}, {101.742, 60.794000000000004`}, {101.742,
                62.755}, {103.699, 62.755}, {103.699, 57.606}, {101.742, 
               57.606}, {101.742, 59.567}, {98.95700000000001, 59.567}, {
               98.95700000000001, 57.606}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}}}, {{{81.41400000000002, 40.68}, {
               81.41400000000002, 35.536}, {79.45700000000001, 35.536}, {
               79.45700000000001, 37.497}, {76.67199999999998, 37.497}, {
               76.67199999999998, 35.536}, {74.715, 35.536}, {74.715, 
               40.68}, {76.67199999999998, 40.68}, {76.67199999999998, 
               38.720000000000006`}, {79.45700000000001, 
               38.720000000000006`}, {79.45700000000001, 40.68}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}}}, {{{81.41400000000002, 57.606}, {
               81.41400000000002, 62.755}, {79.45700000000001, 62.755}, {
               79.45700000000001, 60.794000000000004`}, {76.67199999999998, 
               60.794000000000004`}, {76.67199999999998, 62.755}, {74.715, 
               62.755}, {74.715, 57.606}, {76.67199999999998, 57.606}, {
               76.67199999999998, 59.567}, {79.45700000000001, 59.567}, {
               79.45700000000001, 57.606}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{113.145, 
               57.079}, {105.312, 61.294000000000004`}, {105.312, 57.079}}}]}, 
             {Thickness[0.00006663529411764707], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{65.27, 
               41.208000000000006`}, {73.10199999999999, 36.993}, {
               73.10199999999999, 41.208000000000006`}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{65.27, 57.079}, {
               73.10199999999999, 61.294000000000004`}, {73.10199999999999, 
               57.079}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{113.145, 
               41.208000000000006`}, {105.312, 36.993}, {105.312, 
               41.208000000000006`}}}]}, 
             {FaceForm[{RGBColor[
              0.9803919999999999, 0.6823529999999999, 0.160784], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{105.516, 
               57.282000000000004`}, {105.516, 60.958}, {112.34400000000001`, 
               57.282000000000004`}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{72.898, 41.009}, {
               72.898, 37.333}, {66.07, 41.009}}}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{72.898, 
               57.282000000000004`}, {72.898, 60.958}, {66.07, 
               57.282000000000004`}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{105.516, 41.009}, {
               105.516, 37.333}, {112.34400000000001`, 41.009}}}]}, 
             {FaceForm[{RGBColor[
              0.9803919999999999, 0.6823529999999999, 0.160784], Opacity[
              1.]}], FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
                1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3,
                 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
                1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3,
                 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {
                1, 3, 3}}}, {{{57.18, 33.649}, {57.555, 32.044}, {58.832, 
                30.829}, {59.137, 29.161}, {59.75, 30.899}, {60.312, 
                32.356}, {59.891, 34.259}, {59.59, 35.62200000000001}, {
                58.445, 36.591}, {58.312, 37.989}, {57.066, 36.868}, {
                56.797000000000004`, 35.278000000000006`}, {57.18, 
                33.649}}, CompressedData["
1:eJxTTMoPSmViYGCQBGIQHWG55URZno/Dh+XHvM1fWjnsLZkswfLNx6HpwKmF
rmWWDqZxuzx5Nvk68DBpt4tFWkD4TX4OTglPLyjNNnfQiuk/9DXCz+G4t3mn
4wMLiP5lfg6ZE9/W2F+1dHgTuEOu9befA5B8HXjDysEMpD/J3+Fk2b75Uvw2
Du1iN899n+wP0e9g69A7PU+o2cHfYYGU/l2VZXYO2z//vVIh6e9gD7L4ja3D
Itdtn/8+8XOQZAnj0w2ydUixvu/fuxzK32TjwN441bnbx89B3ZBjjcwua4c+
kHkCfg7lQOv071o5HP6qEdPP5OewRiYqxXq+JcT9M3wh/rG2cgA5jynb1yF7
D9AjKtYQ9Ua+DkDX75BjtXGYIgG06K6Pw5WKl2qGHrYQ+SAfhxZQeIXZOfyq
y9pTstnbAWSMNru9gx3X9cUFd70dYoHWaMyxdQCqAnrA26EC5B5ZGwf08AcA
SLunQg==
                "], CompressedData["
1:eJxTTMoPSmViYGCQBGIQvbdksgRLmr9D84FTC12nmTloxvQf+urh73Cl4qWa
4QlTh97peULNBv4OjglPLyj9NnEAqzfzdwgESSibOLA3TnXuvuPnkL0HKPHE
xMHgrgpbY6qfQ8bEtzX2paYObwJ3yLX+9nX4BzJQ0MwhbpcnD1O2r4O6Icca
mV9mDoe/agBt9HFYIxOVYj3fHGKej4/D++XHvM1PWjicXui67XOsj4MxCAib
Q8zb7eOwzv1hlcg6UwdbruuLC3J9Ie5ZbOKw7fPfKxWafg4gYdsuY4h5PP4Q
/Z+NHEDOZDnm76DKBpQ4bejg0p3z/PdKfwceJu12sUhjh1wg7+MnfwegLa8D
Z5g4hDxeOvuIRIDDAil9oM/MHGYAg+OAUQDEvynmEPskAxxA3tI+buEAMrZ7
j7+DJEsYn+4lS4cIyy0nyvb5Q9yzysKBERjmDBP8HaJTrO/7rzV3QA9/ADmb
pE4=
                "], CompressedData["
1:eJxTTMoPSmViYGCQBGIQ3Xzg1ELXtgCHzIlva+xDDR22ff57pWJmgMMuTx4m
bXUDB6stJ8r2nQ9w+LPy4yXfJD2H2z/rsvZ8CXCYL6V/V8VNx0EaSLFNDHCI
sAQqtNOF8C0DHGzu+/dOf6fnADR92+e9/hD9TgYOKdZAied+Dg6mcbs8dQwh
+v75OjysElnnftDQofKlmiGHja9DBsg9X40cpkiwhPHN9XXgur64wFbLwIG9
capzd4+fA8h57WK6DnEgh772dwAZOz1PG+KP3AAHe5D5PloQfZcCHGL6D33V
uKPlsGnu++XHkgMdFoDcz6bpEA/SHxzosBXozflSOg7fNIAqTQMd2ED25Og7
rJGJSrFmD3QAWydpCFH/OMBB3ZBjjYyUEcT+3QEO84DGeosbQ8JnSYCDJNDZ
ukYmDn5JAhGWLQEQd3gZO4CC429JgEM50Db9WCMH9PAHACGno/o=
                
                "], CompressedData["
1:eJxTTMoPSmViYGCQBGIQfftnXdaeL4EOW0+U7ZsvpeXw9ILS7Z9iQQ7fgx8v
ne2i4SCyzv1hlUuQw0651teBO9QcREH8miCH3ul5Qs0Nqg7PQOrfBTrsAMlb
qDpkTnxbY18b6LBASv+uCpuGgypb41TnzwEOhhxrZKJUNByaD5xa6DovAKpe
A6LeFyqfou4wWYIljO+tP4S/RN3BAGhKYyxUfYWqw7bPf69UnAxwuO8PdMEk
ZYh73QIdVn285JskoOzAdX1xge2rQIc0MFCCujPIodAWKLNBGeIfk2AHa5AB
esoQ+QdBEH1cqg6ePEza7duCIO5vU3dw6c55/rsRqt9Ay+GbRkz/IVuYvC7E
/X8DHdJB1j3Th5hXAQsPA4j6tVD3TdBzAIf3mUCHCMstJ8rsdBzQwx8AQtmv
2g==
                "], {{79.67599999999999, 9.384}, {75.781, 
                8.722999999999999}, {72.051, 7.863999999999999}, {68.074, 
                7.824999999999999}, {72.523, 6.274}, {76.71900000000001, 
                5.993}, {81.133, 7.595}, {83.52, 8.462}, {85.348, 8.927}, {
                87.15199999999999, 8.798}, {89.785, 8.606}, {
                92.98400000000001, 7.566999999999999}, {96.527, 
                3.8329999999999997`}, {97.918, 4.946}, {92.84400000000001, 
                9.47}, {86.199, 10.493}, {79.67599999999999, 9.384}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{
                1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {
                1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4,
                 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
                1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3,
                 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 
                3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                3}}}, {{{121.254, 33.649}, {120.87899999999999`, 32.044}, {
                119.60199999999999`, 30.829}, {119.293, 29.161}, {118.684, 
                30.899}, {118.121, 32.356}, {118.543, 34.259}, {
                118.84400000000001`, 35.62200000000001}, {119.988, 36.591}, {
                120.121, 37.989}, {121.367, 36.868}, {121.637, 
                35.278000000000006`}, {121.254, 33.649}}, CompressedData["
1:eJxTTMoPSmViYGCQBGIQLbLO/WFVSpzDh+XHvM1fWjmEPF46+4hCnEPTgVML
XcssHWbkCTUfOBTrwMOk3S4WaQHhR8U6OCU8vaA029xhjUxUinV+rMNxb/NO
xwcWEP0esQ6ZE9/W2F+1dNhbMlmCRS7WYYdc6+vAG1YO00H6X8U4nCzbN1+K
38ah1t40btfFGIh+B1uHN4FAlb9jHBZI6d9VWWbn8OyC0u2ffLEOIGWeb2wd
HlYBXawZ6yDJEsanG2Tr8B8E3KH8TTYOQF1sjaWxDuqGHGtkdlk7vAaZNznW
oRxonf5dK4dLQOPqZsVC3D3fEmL+Oah/rK0cmkH+fhbrkL0H6HAVa4eLIPVM
cQ6tIINYbSD+0o1zuFLxUs3QwxYiXxTn0ALSF2bn4NKd8/z3wTiHXZ7AEGO3
d1jkuu3z3zVxDrH9h75qzLF1uPOzLmvPnDiHCpB7ZG0c0MMfAB6Psig=
                
                "], CompressedData["
1:eJxTTMoPSmViYGCQBGIQ3Ts9T6j5RYxD84FTC12nmTk8vaB0++e3GIcrFS/V
DE+YOrwO3CHXyhzr4JgAlPlt4hDyeOnsIwyxDoEgjcomDgZ3VdgadWMdsveU
TJZ4YuIgrQ8UyIx1yJj4tsa+1NRhL1CYZV6swz+QgYJmEHuexTqoG3Kskfll
5nAJaF2dVZzDGpmoFOv55g4g7Y2lcQ7vlx/zNj9p4QCUzdqTE+dgDALC5g7f
NGL6D9nGOaxzf1glss7UYaHrts9/n0Dds9jEQa4V6OK2WAeu64sLbLuMIeaJ
xkL0fzaCuH9HjIMqW+NU59OGEPXHYhx4mLTbxSKNHVy6c57/XhjjsAMkMcPE
IX6XJw9Tc4zDAimQSWZQ/8VA/JtiDlHfGOMAUqZ93AISHntjHCRZwvh0L1k6
iIIcuicG4p5VFg6b5gJ9djnGITrF+r7/WnMH9PAHAACeqxo=
                
                "], CompressedData["
1:eJxTTMoPSmViYGCQBGIQrX9Xha1RNMYhc+LbGvtQQweX7pznvxljHHZ58jBp
qxs4VLxUM+Q4E+3wZ+XHS75Jeg5PLyjd/rks2mG+FFCnm47D9Dyh5gNcMQ4R
lltOlNnpOlwEStclxTjY3Pfvnf5Oz+HOz7qsPXtiIPqdDBz+g4B6rIODadwu
Tx1DB9F17g+r5sQ6PKwSWed+0NDhm0ZM/6G/sQ4ZIPd8NYK462ysA9f1xQW2
WgYOYPeGxjqAnNcupuvQfODUQtdlMQ7WIPvytCF8vRgHe5D5PloQc09GOwBN
/apxRwtiv3m0wwKQ+9k0HUIeL519xCPaYeuJsn3zpXQc9pZMlmBJi3Zga5zq
3J2j7yACct+UaAewdZKGEPU7oh3UDTnWyEgZQfgPoh3mvV9+zFvcGBI+36Id
JFnC+HSNTBzWyESlWIvHQNzvZewg1/o6cIdajEM50Db9WCMH9PAHAKgmrgU=

                "], CompressedData["
1:eJxTTMoPSmViYGCQBGIQ/fSC0u2fy6Ictp4o2zdfSstBZJ37w6qWKIfvwY+X
znbRcFgjE5ViHR7lsFOu9XXgDjUIXz7KoXd6nlBzgypE/Zoohx0geQtVBy8e
Ju12uWiHBVL6d1XYNByOeZt3Oq6IdjDkAOpU0XAwAIo2/o2GqteAqPeLgcin
qDtkTHxbY78Uyl+i7tB84NRCV7sYiPoKVQeu64sLbC9FO9z3B7pgkrLD7Z91
WXtCoh1WfbzkmySg7LDt898rFRujHNLAQMkhbpcnD5N0lEOhLVDnBmUHsH/T
Ih2sQQboKTuosjVOdd4dCTGXSxVi/9NIiPvb1B1q7U3jdklC9RtoOewtmSzB
EhcFldeFuH9elEM6yLpn+hDzlGH+M4CofxcFcd8EPYdnIPvPRTlEWG45UWan
44Ae/gAy+KYv
                "], {{98.758, 9.384}, {102.65199999999999`, 
                8.722999999999999}, {106.383, 7.863999999999999}, {110.359, 
                7.824999999999999}, {105.91000000000001`, 6.274}, {101.715, 
                5.993}, {97.301, 7.595}, {94.91400000000002, 8.462}, {93.082, 
                8.927}, {91.281, 8.798}, {88.648, 8.606}, {85.44900000000001, 
                7.566999999999999}, {81.906, 3.8329999999999997`}, {80.512, 
                4.946}, {85.59, 9.47}, {92.23400000000001, 10.493}, {98.758, 
                9.384}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
               0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
               0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGItIGYC4r0lkyVY0nwcri8usOU6nO3AAAIKvg7nvgc/
Xjo92wEoG8ZX6+nw5e+Vipf7suB8jjUyUSni2Q6/6rL2lCz2hqvf9hmk0Atu
nmncLk+eIh+H5gOnFrrK5UDEj3s7gO11Q/Cl9e+qsPHmOCx0BZpQ4oXBf1gl
ss49MMfBlguoI9cXYh5TrsPrwB1yra/94PwU6/v+veL+Dpvmvl9+7HAOxD2W
fnC+S3fO89+a/g7nQe7thsofDHAw73RMeCqSC5dfIAV0wLxcuH5IOCHMh/Fh
9oNp9Vy4+2B8mPt7p+cJNd9A8EMeL519RCYP7n90Pti9j3Ph4fcGZB53Hjx8
BSIst5xIy4OHP9i9k/Lg8ZMGAkL5cD7Y3Ox8ePzC1MPiH2beKZAD3/rC7bMD
+Weuj8M/oK1qe3MdKl+qGXLU+ELiozPXYfYRhQ1FGv6Q+Hqb6wDy5oGsQHh4
wuTB/rPJgesHh8eCHLj5haCAy8mB2w9LLwCJMSw+
               "]]}, 
             {FaceForm[{RGBColor[
              0.9803919999999999, 0.6823529999999999, 0.160784], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
               0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
               0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGItIGYC4uuLC2y5vvs6nP8e/HhpfK6DS3fO89+a/g6O
CU8vKC3PdciY+LbG/mqAg3knUEQEIa+7ae775U05DjD9C6T076qcgvH94Px2
sZvnvl/2c5jmDNKY46AZ03/oa4UvnN83PU+oeYKXgx7IPD8E/3XgDrlW4RwI
vdobg7/8mLd5Z2iOgxbIvBk+Ds0HTi10lYPqF/CGuONwtsNFpds/6055O5wD
+W96tsNkCZYwvlpPiHo+BH8qyD3HsyDu++EDV//sAtAAOx+4eWD6uC/cPi8e
Ju32Mh+HQluu64tzchwqX6oZctT4OqwAuW9ljsPsIwobijT8Hb5pAA12zXF4
CjIvLBAenjB5sL4nuXD99qZxuzwbcuHm/7tS8VJtby7c/jegcODOg7tPIMJy
y4m0PLj7weE/KQ/uv5sgDyXmw/lg/dL58PCBqYeFH8w8WPjC7IOFP9h9V3Lh
fHB4iOXB4w+d7wRKT7dz4fEPdo9uLjx9wPiw9ANLjwD6gjUe
               "]]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               64.93, 232.74299999999997`}, {63.379, 231.298}, {
               63.12500000000001, 232.74299999999997`}, {63.379, 
               234.18800000000002`}}}]}, 
             {FaceForm[{RGBColor[
              0.9803919999999999, 0.6823529999999999, 0.160784], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               63.523, 233.76999999999998`}, {63.343999999999994`, 
               232.74299999999997`}, {63.523, 231.71599999999998`}, {
               64.62499999999999, 232.74299999999997`}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{54.473, 
               231.192}, {55.93, 232.64899999999997`}, {54.473, 
               234.11399999999998`}, {52.684, 234.11399999999998`}, {52.684, 
               236.165}, {50.977, 237.872}, {50.977, 227.43}, {52.684, 
               229.141}, {52.684, 231.192}}}]}, 
             {FaceForm[{RGBColor[
              0.9803919999999999, 0.6823529999999999, 0.160784], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{54.391, 
               233.911}, {55.645, 232.64899999999997`}, {54.391, 
               231.39100000000002`}, {52.483999999999995`, 
               231.39100000000002`}, {52.483999999999995`, 229.227}, {50.977, 
               227.72}, {50.977, 237.58700000000002`}, {52.483999999999995`, 
               236.07899999999998`}, {52.483999999999995`, 233.911}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
               0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
               0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGItIGYC4r0lkyVY0nwc1NgapzpLpzowgICCr0PlSzVD
jg8pDkDZML5aTwfHhKcXlMQR/PPfgx8vzU9x+FWXtadksTdc/bbPf69UvPSC
m2cat8uTp8jHwZOHSbu9LNXh+uICW67j3g7paUAwD8E/orChKCM11WGhK9CE
Ei8M/opj3uadK1MdbLmAOnJ9HXQ3zX2/PCrN4XXgDrnW135wfor1ff9ecX+I
e2TSIO6x9IPzXbpznv/WhMo/SYXIHwxw+Ad0tVouQh7kvLRvCP1g9+5DmA/j
w+wHWX+sPg3uPhgf5n6LTmAIGqTD+dL6d1XYStPh/kfng91nkw4PP7B5yenw
8AXHx/50ePiD3fMqHR4/ghGWW05kZcD5qqD4OJwBj1+Yelj8w8w7BXLgW1+4
fXYg/8z1gcSHaDrEXTW+Dj3AYFr5MM1hNkhCwx8i75ruMD1PqPlAViA8PGHy
YP9NTYXrB6ae2Ud+pMLNNweFz5FUuP2w9AIALMwnGw==
               "]]}, 
             {FaceForm[{RGBColor[
              0.9803919999999999, 0.6823529999999999, 0.160784], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
               0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
               0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGItIGYC4uuLC2y5vvs6VL5UM+TYkebg0p3z/LemvwPn
GpmolP9pDhkT39bYXw1w+Hel4qVaLkIerO92qgNMfxoIKKVB+X5wfrvYzXPf
L/s52JvG7fIMSXPQjOk/9LXCF87vm54n1DzBy+HzX6AFy1Lh/M1z3y8/lp3q
8Dpwh1zram8MPtDU4MdrUx20QObN8HHw5GHSbi+D6hfwdlBja5zqLJ3qcFHp
9s+6U94Q/31IcZgswRLGV+vpoLsJaGAagg8yRkMhBeK+Hz5w9c8uAA2w84Gb
B/bfcV+4fV5g2sfBvNMx4emRVIi+Gl+I+xjTHGYfUdhQpOHvsLcEaNO8VIen
IPPCAuHhCZNf/fGSb5JNOlx/L8gfN9Lg5oOUZYimw+0HOf9YcjrcfUDbLyjt
T4e7Px0U/q/S4f5rOXBqoeuuDDgfrL84Ax4+MPWw8IOZBwtfmH2w8Aer00Hw
9UAK8tLh8YfOB6szTofH/wIp/bsqbYj0AePD0g8sPQIAa2kuwg==
               "]]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               64.93, 179.501}, {63.379, 178.059}, {63.12500000000001, 
               179.501}, {63.379, 180.946}}}]}, 
             {FaceForm[{RGBColor[
              0.9803919999999999, 0.6823529999999999, 0.160784], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               63.523, 180.52800000000002`}, {63.343999999999994`, 179.501}, {
               63.523, 178.477}, {64.62499999999999, 179.501}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{54.473, 
               177.95000000000002`}, {55.93, 179.411}, {54.473, 180.876}, {
               52.684, 180.876}, {52.684, 182.923}, {50.977, 184.634}, {
               50.977, 174.192}, {52.684, 175.903}, {52.684, 
               177.95000000000002`}}}]}, 
             {FaceForm[{RGBColor[
              0.9803919999999999, 0.6823529999999999, 0.160784], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{54.391, 
               180.67299999999997`}, {55.645, 179.411}, {54.391, 178.153}, {
               52.483999999999995`, 178.153}, {52.483999999999995`, 
               175.985}, {50.977, 174.477}, {50.977, 184.348}, {
               52.483999999999995`, 182.841}, {52.483999999999995`, 
               180.67299999999997`}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
               0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
               0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}
               , {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGItIGYC4r0lkyVY0nwc5r1ffsz7eYwDAwgo+DrUZ+0p
mTwhxgEoG8ZX6+lwfXGBLdf9KDj/0yXfJIEJ0Q6/6oAKF3vD1W/7/PdKxUsv
uHmmcbs8eYp8HF78Xvnx0txYiDnHvR2iUqzv+79F8MVvnvseXB3rsNAVaEKJ
FwZ/01yggcxxDrZcQB25vg7r3B9WiaTFO7wO3CHX+toPzgcZ2yvu7xDyeOns
Iy/iIO6x9IPzXbpznv/WhMpXQOUPBjj4907PE+qOh8sLRlhuOeGXANcvAOKL
JcDNh/Fh9oPIwA3xcPfB+DD3/wOGilpnApx/RGFDUcbZBLj/0fmrPgIDeEoC
PPxi+w991diTAA9fsL3iifDwB7vXKRE1vg4j+Oe/Bz9eKp0Ej1+Yelj8w8w7
BXLgW1+4fXYg/8z1cfimEdN/KDfBofKlmiFHja8DKHoeWyY4zAY5XMPfoQcY
bCvnJjgAQ7H5QFYgPDxh8l2OCU8v3IqF6/8DTA6+i+Lg5h/+CrTAKg5uPyy9
AAAMfju0
               "]]}, 
             {FaceForm[{RGBColor[
              0.9803919999999999, 0.6823529999999999, 0.160784], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
               0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
               0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGItIGYC4uuLC2y5vvs6OJjG7fIUSHBw6c55/lvT32Hj
3PfLj4UnOGRMfFtjfzXAwb93ep5Qdzxc3pOHSbs9Lc4Bpl9xQ1HGxK8wvh+c
3y5289z3y34O0vp3Vdgi4x00Y/oPfa3whfP7gMY2T/By8AKZ9y8Wzt8h1/o6
sCPW4XUgkLXaG4NvD3IvT5yDFsi8GT4OL36v/HhpLlS/gLfDPKDzvZ/HOFxU
uv2z7pS3Q33WnpLJE2IcJkuwhPHVekLU10bD+WD3fIyCuO+HD1z9swtAA+x8
4OaB/XfcF24f2N1lPg6Hv2rE9FvFOVS+VDPkqIGG55Y4h9lHFDYUafg7nD0D
BG9iHZ6CzAsLhIcnTB5o6vXFUxLg+i06HROeGiTAzf8GNP5QbgLc/ligMzX2
JMDdBw4X8US4+wUjLLeccEqE+w8cX0JJcD5Y/5lEePjA1MPCD2YeLHxh9sHC
3xzkvhYE//PfKxUvjyXA4w+dvxmUnroT4PE/BeSOvfHw9AHjw9IPLD0CAG7u
Lxc=
               "]]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{64.93, 
               126.262}, {63.379, 124.81700000000001`}, {63.12500000000001, 
               126.262}, {63.379, 127.708}}}]}, 
             {FaceForm[{RGBColor[
              0.9803919999999999, 0.6823529999999999, 0.160784], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               63.523, 127.29}, {63.343999999999994`, 126.262}, {63.523, 
               125.235}, {64.62499999999999, 126.262}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{54.473, 
               124.712}, {55.93, 126.17299999999999`}, {54.473, 127.634}, {
               52.684, 127.634}, {52.684, 129.684}, {50.977, 131.395}, {
               50.977, 120.95}, {52.684, 122.661}, {52.684, 124.712}}}]}, 
             {FaceForm[{RGBColor[
              0.9803919999999999, 0.6823529999999999, 0.160784], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{54.391, 
               127.43}, {55.645, 126.17299999999999`}, {54.391, 124.915}, {
               52.483999999999995`, 124.915}, {52.483999999999995`, 
               122.74700000000001`}, {50.977, 121.239}, {50.977, 131.106}, {
               52.483999999999995`, 129.598}, {52.483999999999995`, 
               127.43}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
               0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
               0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGItIGYC4r0lkyVY0nwcwvh0N83V93dgAAEFX4fDXzVi
+pv8HICyYXy1ng4ny/bNl5L3hvP/Xal4qdbo4/CrLmtPyWJvuPptn/8CZbzg
5pnG7fLkKfJx8OJh0m73C3C4vrjAluu4t8M694dVIvMQ/MqXaoYcOgEOC12B
JpR4YfDBBm0JcLDlAurI9XXwBJknFuTwOnCHXOtrPzg/xfq+f6+4vwPQ9HXu
MwMh7rH0g/NdunOe/9aEymtC5Q8GOGye+375MesguDzYfX7BcP1g/j2E+TA+
zP6Qx0tnH0kIgrsPxoe5P6B3ep7Q4WA4X+zmue/B3iFw/6Pzwe67GQwPP7B5
GiHw8E0FueN+CDz8we4xC4XHj0CE5ZYTZmFwvlY70IbnYfD4hamHxT/MvFMg
B771hdtnB/LPXB+HClB89ARD4qXG14Gtcapzt0qww+wjChuKNPwh8m+CHYC+
bD6QFQgPT5g82H/dAXD9XY4JTy8EBcLNB8u/DoDbD0svADOPI54=
               "]]}, 
             {FaceForm[{RGBColor[
              0.9803919999999999, 0.6823529999999999, 0.160784], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
               0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
               0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGItIGYC4uuLC2y5vvs6PKwSWed+McjBpTvn+W9Nf4dP
l3yTBBKCHTImvq2xvxrgsHnu++XHrBHy84Bcb/FAB5j+de5AE5bB+H5wfrvY
zXPfL/s55Ak1HzjFGeSgGdN/6GuFL5zfNx3ImuAF0bc+AM4Pebx09hGLAIfX
gTvkWld7Y/CnSLCE8e0NcNACmTfDx8GLh0m73Q+qX8DbIYxPd9NcfX+Hi0q3
f9ad8nY4/FUjpr/Jz2EySF+tJ0R/rA+cH9AL1OjsDXHfDx+4+mcXgAbY+cDN
A7vzuC/cPjBd5uMA8mbw6wCHypdqhhw1vhBzUwMdZh9R2FCk4e8QlWJ9339u
gMNTkHlhgfDwhMmbxe3y5LkVDNf/Z+XHS75CwXDzK0DiPcFw+8HhoRECd18q
0Pje+yFw94PD3ywU7r8Xv4EGXg2D88H6PcLg4QNTDws/mHmw8IXZBwv/vyD3
7QqG88HutAuBxx86H6jqdeCJYHj8K24oypiYGwRPHzA+LP3A0iMAEvclyg==

               "]]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               64.93, 73.02}, {63.379, 71.579}, {63.12500000000001, 73.02}, {
               63.379, 74.46600000000001}}}]}, 
             {FaceForm[{RGBColor[
              0.9803919999999999, 0.6823529999999999, 0.160784], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               63.523, 74.048}, {63.343999999999994`, 73.02}, {63.523, 
               71.99700000000001}, {64.62499999999999, 73.02}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{54.473, 
               71.47}, {55.93, 72.93}, {54.473, 74.395}, {52.684, 74.395}, {
               52.684, 76.44200000000001}, {50.977, 78.15299999999999}, {
               50.977, 67.712}, {52.684, 69.423}, {52.684, 71.47}}}]}, 
             {FaceForm[{RGBColor[
              0.9803919999999999, 0.6823529999999999, 0.160784], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{54.391, 
               74.192}, {55.645, 72.93}, {54.391, 71.67299999999999}, {
               52.483999999999995`, 71.67299999999999}, {52.483999999999995`, 
               69.505}, {50.977, 67.99700000000001}, {50.977, 77.868}, {
               52.483999999999995`, 76.36}, {52.483999999999995`, 74.192}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
               0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
               0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGItIGYC4uKMiW9r0uMcri8usOU6nO1wUen2zzquOIdz
34MfL52e7VD5Us2Q4068w5e/Vype7suC8znWyESliGc7hDxeOvvICYR6/bsq
bI2q8XDztn0GakyMc2g+cGqhq1yOw9MLQAu2xTnsLZksweKG4EuDNPLmODCA
QEI8Bv9hlcg698Ach01z3y8/9jgWYh5TrgPQtVl7VBB8+dbXgTv4YiHqDuc4
fNOI6T9Ui+CD3cca63Ae5N7uHIg9N6MdzDsdE56K5MLlF0gBWfNy4frB7k1D
mA/jw+wHisq1qufC3Qfjw9zfOz1PqPkGgg8ON5k8uP/R+RBzcuHh9wZkHnce
PHwFIiy3nEjLg4c/2L2T8uDxkwYCQvlwPjg+svPh8QtTD4t/mHlgdy+OhdsH
dod3nMM/YPSr7c11EF3n/rDqTiwkPjpzIeHOFgsJx7e5DlZbTpTt00eEJ0we
7E6bHLh+cHgsyIGbX2jLdX1xTg7cflh6AQANNjHl
               "]]}, 
             {FaceForm[{RGBColor[
              0.9803919999999999, 0.6823529999999999, 0.160784], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
               0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
               0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGItIGYC4mcXlG7/nBfrcP578OOl8bkO+ndV2BpZYx0c
E55eUFqe65Ax8W2N/dFoB/NOoIgIQl5309z3y5tyHGD6F0gBZU5B+XII/nFv
oE6DWIdpzt05z3/nOOwtmSzBcg/B57q+uMA2KN5BD2SeH4L/OnCHXKtwjsPt
n3VZe47EYfCXHwMaHAo1zy/OofnAqYWucjkOLiBjBeMdQMZwHc6GuH9rnMM5
kP+mZztUvlQz5LgTD1HPh+BPBbnneBbEPDmE+rhdnjxM1XFw856C/LctFm7f
GpmoFOv4OIdCW6DLc3IcRNe5P6y6E+uwAuS+lTkQdWyxDt80YvoPueZA/OGM
CE+YPNgdT3Lh+u1NgTY35MLN/3el4qXa3ly4/W9A5nDnwd0nEGG55URaHtz9
4PCflAf3302QhxLz4Xywful8ePjA1MPCD8U8YPjC7IOFP9h9V3LhfLA/xPLg
8YfOdwKlp9u58PgHu0c3F54+YHxY+oGlRwBWgTbg
               "]]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               113.48400000000001`, 232.74299999999997`}, {115.035, 
               231.298}, {115.289, 232.74299999999997`}, {115.035, 
               234.18800000000002`}}}]}, 
             {FaceForm[{RGBColor[
              0.9803919999999999, 0.6823529999999999, 0.160784], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               114.891, 233.76999999999998`}, {115.07, 232.74299999999997`}, {
               114.891, 231.71599999999998`}, {113.789, 
               232.74299999999997`}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               123.94100000000002`, 231.192}, {122.48400000000001`, 
               232.64899999999997`}, {123.94100000000002`, 
               234.11399999999998`}, {125.73, 234.11399999999998`}, {125.73, 
               236.165}, {127.438, 237.872}, {127.438, 227.43}, {125.73, 
               229.141}, {125.73, 231.192}}}]}, 
             {FaceForm[{RGBColor[
              0.9803919999999999, 0.6823529999999999, 0.160784], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{124.023, 
               233.911}, {122.77, 232.64899999999997`}, {124.023, 
               231.39100000000002`}, {125.93, 231.39100000000002`}, {125.93, 
               229.227}, {127.438, 227.72}, {127.438, 237.58700000000002`}, {
               125.93, 236.07899999999998`}, {125.93, 233.911}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
               0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
               0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGItIGYC4uKMiW9r0uMc1NgapzpLpzpcVLr9s44rzqHy
pZohx4cUCH0n3sEx4ekFJXEE//z34MdL81McQh4vnX3kBEK9/l0VtkbVeLh5
2z7/vVKRGOfgycOk3V6W6gA05fbPbXEO6WlAMA/BP6KwoSgjNdWBAQQS4jH4
K455m3euTHXYNPf98mOPYx10QYyoNAega7P2qCD48q2vA3fwxULcI5Pm8E0j
pv9QLYIPdh8rlP8k1UEaJHAz2uHflYqXarkIeZDz0r4h9IPduw9hPowPsx/s
rvo0uPtgfJj7LTqBIWiQDueD7S1Nh/sfnQ92n006PPzA5iWnw8MXHB/70+Hh
D3bPq3R4/AhGWG45kZUB56uC4uNwBjx+Yeph8Q8zD+g7udbFsXD7wLQ3NH5E
0x1E17k/rLoT69CT8/z3yodpDs0HTi10ZYuFyLumO1htOVG2Tx8RnjB5sP+m
psL1B4Pc/SMVbr45KHyOpMLth6UXALDCLMI=
               "]]}, 
             {FaceForm[{RGBColor[
              0.9803919999999999, 0.6823529999999999, 0.160784], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
               0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
               0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGItIGYC4mcXlG7/nBfrUPlSzZBjR5qD/l0VtkbWWAfO
NTJRKf/THDImvq2xPxrt8O9KxUu1XIT89cUFtly3Ux1g+tNAQCkNwpdD8I97
m3c6GsQ62JvG7fIMSXPYWzJZguUegs8FMigo3uHzX6AFy1Lh/M1z3y8/lp3q
cPtnXdaeI3EY/Jvnvgc/XpsKMc8vzsGTh0m7vSzVwaU75/lvwXgHNbbGqc7S
qRD3b42D+O9DCoS+E++guwloYBqCH9N/6KuGQgrEPDmEeqAreZiq4+DmPQX5
b1ss3D5QMFnHxzkAfZnw9Eiqg+g694dVd2Ih7mNMc2g+cGqhK1ssxNx5qQ6v
A3fItTojwhMmv/rjJd8km3S4/t7peULNN9Lg5h9R2FCUIZoOtx/k/GPJ6XD3
AW2/oLQ/He7+dFD4v0qH+68FZM+uDDgfrL84Ax4+MPWw8EMxDxi+MPtg4d8H
cp8Ogq8HUpCXDo8/dD7Y38bp8PhfIAVMSW2I9AHjw9IPLD0CAMdZMIQ=
               
               "]]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               113.48400000000001`, 179.501}, {115.035, 178.059}, {115.289, 
               179.501}, {115.035, 180.946}}}]}, 
             {FaceForm[{RGBColor[
              0.9803919999999999, 0.6823529999999999, 0.160784], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               114.891, 180.52800000000002`}, {115.07, 179.501}, {114.891, 
               178.477}, {113.789, 179.501}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               123.94100000000002`, 177.95000000000002`}, {
               122.48400000000001`, 179.411}, {123.94100000000002`, 
               180.876}, {125.73, 180.876}, {125.73, 182.923}, {127.438, 
               184.634}, {127.438, 174.192}, {125.73, 175.903}, {125.73, 
               177.95000000000002`}}}]}, 
             {FaceForm[{RGBColor[
              0.9803919999999999, 0.6823529999999999, 0.160784], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{124.023, 
               180.67299999999997`}, {122.77, 179.411}, {124.023, 178.153}, {
               125.93, 178.153}, {125.93, 175.985}, {127.438, 174.477}, {
               127.438, 184.348}, {125.93, 182.841}, {125.93, 
               180.67299999999997`}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
               0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
               0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGItIGYC4uKMiW9r0uMc5r1ffsz7eYzDRaXbP+u44hzq
s/aUTJ4Q41D5Us2Q4068w/XFBbZc96Pg/E+XfJMEJkQ7hDxeOvvICYR6/bsq
bI2q8XDztn3+e6UiMc7hxe+VHy/NjXV4egFowbY4h6gU6/v+bxF88ZvnvgdX
xzowgEBCPAZ/01yggcxxEPpxrMM694dVImnxDkDXZu1RQfDlW18H7uCLhbjr
RZzDN42Y/kO1CD7YfaxQfkWcgzRI4Ga0g3/v9Dyh7ni4vGCE5ZYTfglw/QIg
vlgC3HwYH2b/DjmgxIZ4uPtgfJj7/12peKnWmQDnH1HYUJRxNgHuf3T+qo/A
AJ6SAA+/2P5DXzX2JMDDF+gKuVbxRHj4g93rlIgaX4cR/PPfgx8vlU6Cxy9M
PSz+YeaB6cWxcPvA/vGGhmNugoMoKKDvxDqAouexZYJD84FTC13ZYh16cp7/
Xjk3wcFqy4myffqI8ITJdzkmPL1wKxau/w8wOfguioObf/gr0AKrOLj9sPQC
AJB0QVs=
               "]]}, 
             {FaceForm[{RGBColor[
              0.9803919999999999, 0.6823529999999999, 0.160784], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
               0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
               0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGItIGYC4mcXlG7/nBfr4GAat8tTIMFB/64KWyNrrMPG
ue+XHwtPcMiY+LbG/mi0g3/v9Dyh7ni4vCcPk3Z7WpwDTL/ihqKMiV+hfDkE
/7i3eaejQayDNEhjZLzD3pLJEiz3EHyu64sLbIPiHbxA5v2LhfN3yLW+DuyI
dbj9sy5rz5E4DL49yL08cRDz/OIcXvxe+fHS3FgHl+6c578F4x3mAZ3v/TwG
4v6tcQ71WXtKJk+Icah8qWbIcSceor42Gs4Hu+djFMQ8OYR6kC1M1XFw856C
/LctFm7fGpmoFOv4OIfDXzVi+q3iHETXuT+sugMNzy1xDs0HTi10ZYt1OHsG
CN7EOrwOBPrEGRGeMPkCW6DPpyTA9Vt0OiY8NUiAm/8NaPyh3AS4/bH9h75q
7EmAuw9srngi3P2CEZZbTjglwv0Hji+hJDgfrP9MIjx8YOph4YdiHjB8YfbB
wt8c5L4WBP/z3ysVL48lwOMPnb8ZlJ66E+DxP0WCJYxvbzw8fcD4sPQDS48A
yt4w2Q==
               "]]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               113.48400000000001`, 126.262}, {115.035, 
               124.81700000000001`}, {115.289, 126.262}, {115.035, 
               127.708}}}]}, 
             {FaceForm[{RGBColor[
              0.9803919999999999, 0.6823529999999999, 0.160784], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               114.891, 127.29}, {115.07, 126.262}, {114.891, 125.235}, {
               113.789, 126.262}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               123.94100000000002`, 124.712}, {122.48400000000001`, 
               126.17299999999999`}, {123.94100000000002`, 127.634}, {125.73, 
               127.634}, {125.73, 129.684}, {127.438, 131.395}, {127.438, 
               120.95}, {125.73, 122.661}, {125.73, 124.712}}}]}, 
             {FaceForm[{RGBColor[
              0.9803919999999999, 0.6823529999999999, 0.160784], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{124.023, 
               127.43}, {122.77, 126.17299999999999`}, {124.023, 124.915}, {
               125.93, 124.915}, {125.93, 122.74700000000001`}, {127.438, 
               121.239}, {127.438, 131.106}, {125.93, 129.598}, {125.93, 
               127.43}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
               0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
               0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGItIGYC4uKMiW9r0uMcwvh0N83V93e4qHT7Zx1XnMPh
rxox/U1+DpUv1Qw57sQ7nCzbN19K3hvO/3el4qVao49DyOOls4+cQKjXv6vC
1qgaDzdv2+e/VyoS4xy8eJi02/0CHJ5eAFqwLc5hnfvDKpF5CD7YXJ0ABwYQ
SIjH4DuYxu3y3BLgsGnu++XHHsc6eILMEwtyALo2a48Kgi/f+jpwB1+sA9D0
de4zAx2+AZ11qBbBB7uPFcrXDHSQBgncjHbYDDLXOgguD3afXzBcP5h/D2E+
jA+zHxwOCUFw98H4MPcH9E7PEzocDOeL3Tz3Pdg7BO5/dD7YfTeD4eEHNk8j
BB6+qdb3/Xvvh8DDH+wes1B4/AhEWG45YRYG52u1A214HgaPX5h6WPzDzAP6
Tq51cSzcPrB/vOMcKkDm9AQ7iII03ol1YGuc6tytEuzQfODUQle2WIj8m2AH
qy0nyvbpI8ITJg/2X3cAXH+XY8LTC0GBcPPB8q8D4PbD0gsAt4UpRQ==
               
               "]]}, 
             {FaceForm[{RGBColor[
              0.9803919999999999, 0.6823529999999999, 0.160784], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
               0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
               0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGItIGYC4mcXlG7/nBfr8LBKZJ37xSAH/bsqbI2ssQ6f
LvkmCSQEO2RMfFtjfzTaYfPc98uPWSPk5wG53uKBDjD969yBJiyD8uUQ/OPe
5p2OBrEOeULNB05xBjnsLZkswXIPwee6vrjANijeAURxrQ+A80MeL519xCLA
4fbPuqw9R+Iw+FMkWML49gZAzPOLc/DiYdJu9wtwcOnOef5bMN4hjE9301x9
f4j7t8Y5HP6qEdPf5OdQ+VLNkONOPER/rA+cH9A7PU/I2RtinhxCfdwuTx6m
6ji4eU9B/tsWC7dvjUxUinV8nIPYzXPfg18HOIiCPH4n1mEyyPzUQAegLxe6
ssU6AFXd958b4PA6cIdcqzMiPGHyZiCLbgXD9f9Z+fGSr1Aw3PwKkDt7guH2
g8NDIwTuvlSg8b33Q+DuB4e/WSjcfy9+Aw28Ggbng/V7hMHDB6YeFn4o5vnF
we2Dhf9fkPt2BcP54PCwC4HHHzof6OvXgSeC4fGvuKEoY2JuEDx9wPiw9ANL
jwBu5yeM
               "]]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               113.48400000000001`, 73.02}, {115.035, 71.579}, {115.289, 
               73.02}, {115.035, 74.46600000000001}}}]}, 
             {FaceForm[{RGBColor[
              0.9803919999999999, 0.6823529999999999, 0.160784], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               114.891, 74.048}, {115.07, 73.02}, {114.891, 
               71.99700000000001}, {113.789, 73.02}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               123.94100000000002`, 71.47}, {122.48400000000001`, 72.93}, {
               123.94100000000002`, 74.395}, {125.73, 74.395}, {125.73, 
               76.44200000000001}, {127.438, 78.15299999999999}, {127.438, 
               67.712}, {125.73, 69.423}, {125.73, 71.47}}}]}, 
             {FaceForm[{RGBColor[
              0.9803919999999999, 0.6823529999999999, 0.160784], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{124.023, 
               74.192}, {122.77, 72.93}, {124.023, 71.67299999999999}, {
               125.93, 71.67299999999999}, {125.93, 69.505}, {127.438, 
               67.99700000000001}, {127.438, 77.868}, {125.93, 76.36}, {
               125.93, 74.192}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
               0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIxIGYC4uuLC2y5jns7fNWI6T8UXegA46uyNU51ti90
WOi67fPfEi8MPscamaiUxEIHWy6gjlxfh5vnvgc/3lno8Dpwh1zraz84P8X6
vn+vuL9DfdaeksmzCh2Auq9UWPrB+S7dOc9/a/o71IH4dVD5gwEOxiBwuNDh
otLtn3VZgXD+7CMKG4o0/B0CeqfnCYUXOlS+VDPkqPF1iNvlycPUWehgB3LP
XB+IfH6hwymQg9/6OtwAuce90GFvyWQJljQfh6sVQI1ShQ4MIKDgC7GfpdAB
KBvGV+vpsEBK/67KjAI4H2zvkQKHXyCFi73h6sHufekFN88U5JAiH7h9AIMo
ngA=
               "]]}, 
             {FaceForm[{RGBColor[
              0.9803919999999999, 0.6823529999999999, 0.160784], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
               0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIxIGYC4otKt3/WnfJ2qMvaUzKZpdBhsgRLGF+tp8ON
c9+DH+8vgPOTBCIst8wpcNCM6T/09YcPXP2zC0AD7Hwcrla8VDOUKnS4vrjA
luu4L0S/e6GDFw+TdnuZj0NA7/Q8ofxCh0qgMo4aX4c3gTvkWnsLHWYfUdhQ
pOHvINR84NTC6EKHpyDzwgIdjEHgcKFDxsS3NfZXA+B8l+6c5781/R3WuT+s
EqmC2vfd1+HF75UfL82F8f3g/Haxm+e+X/aDuH9bIcT9Fb5wfh/QWc0TvByA
vpFgSUDwwbRTocNrkDtXe2PwwXRyoYMWyLwZPnD/gtUJeMPDAwD7p6Dc
               
               "]]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{64.832, 
               284.2}, {63.379, 282.845}, {63.141, 284.2}}}]}, 
             {FaceForm[{RGBColor[
              0.9803919999999999, 0.6823529999999999, 0.160784], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
               63.358999999999995`, 284.2}, {63.523, 283.262}, {64.527, 
               284.2}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}}}, {{{55.93, 284.2}, {50.977, 
               284.2}, {50.977, 278.977}, {52.684, 280.688}, {52.684, 
               282.739}, {54.473, 282.739}, {55.93, 
               284.19599999999997`}}}]}, 
             {FaceForm[{RGBColor[
              0.9803919999999999, 0.6823529999999999, 0.160784], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}}}, {{{50.977, 279.262}, {50.977, 
               284.2}, {55.645, 284.2}, {55.645, 284.19599999999997`}, {
               54.391, 282.93799999999993`}, {52.483999999999995`, 
               282.93799999999993`}, {52.483999999999995`, 280.77}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
               0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIxIGYC4qcXlG7/3Bbn8FUjpv9QdKEDjK/K1jjV2b7Q
gQEEEuIx+BxrZKJSEgsdNs19v/zY41iHm+e+Bz/eWehw+2dd1h4VBF++9XXg
Dr5Yh/qsPSWTZxU6fAPZU4vg699VYWtkjXWoA/HrCh2kQQI3ox2MQeAw1D4D
BL/5wKmFrmyxDgG90/OEwgsdRNe5P6y6E+sQt8uTh6kT6h7vOIh8fqED0Ha5
1sWxDjdA7nEvdCjOmPi2Jj3O4WrFSzVDqUKHi0Dv1nHFQexnKXSoBApz3Il3
WCAFdMiMAjh/9hGFDUVHChxCHi+dfeQEQj3Y/arxcPO2ff57pSIxDm4fAAsQ
m/A=
               "]]}, 
             {FaceForm[{RGBColor[
              0.9803919999999999, 0.6823529999999999, 0.160784], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
               0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIxIGYC4oyJb2vst8Y51GXtKZnMUuhQ+VLNkONOvMON
c9+DH+8vgPOTBCIst8wpcNhbMlmCRQ6hPm6XJw9TdZzD1QqgQqlCh6cXlG7/
3BYL0e9e6LBGJirFOj7OIaB3ep5QfqGD6Dr3h1V3Yh3eBO6Qa+0tdGg+cGqh
K1usgxCIEV3o8Bok7hztYAwChwsdwO47iuDr31Vha2SNdQAZI1JV6PAMZN+8
WIcXv1d+vDQXypdD8I97m3c6GsRC3L+tEOL+ewg+1/XFBbZB8Q57QOIJCH4f
0LnNToUOt38CfXokDoMPdmcy1Dy/OLh/Xbpznv8WjIeHBwDCJaEs
               "]]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{113.582, 
               284.2}, {115.035, 282.845}, {115.273, 284.2}}}]}, 
             {FaceForm[{RGBColor[
              0.9803919999999999, 0.6823529999999999, 0.160784], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
               115.05499999999999`, 284.2}, {114.891, 283.262}, {113.887, 
               284.2}}}]}, 
             {FaceForm[{RGBColor[
              0.21960800000000003`, 0.21568600000000002`, 0.223529], Opacity[
              1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}}}, {{{122.48400000000001`, 284.2}, {127.438, 
               284.2}, {127.438, 278.977}, {125.73, 280.688}, {125.73, 
               282.739}, {123.94100000000002`, 282.739}, {122.48400000000001`,
                284.19599999999997`}}}]}, 
             {FaceForm[{RGBColor[
              0.9803919999999999, 0.6823529999999999, 0.160784], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}}}, {{{127.438, 279.262}, {127.438, 
               284.2}, {122.77, 284.2}, {122.77, 284.19599999999997`}, {
               124.023, 282.93799999999993`}, {125.93, 282.93799999999993`}, {
               125.93, 280.77}}}]}},
            AspectRatio->Automatic,
            ImageSize->{{128}, {85}},
            PlotRange->{{0., 425.}, {0., 285.}}], ",", 
           GraphicsBox[
            {Thickness[0.0025], 
             {FaceForm[{RGBColor[0., 0.6, 0.709804], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0., 
               200.}, {400., 200.}, {400., 136.}, {0., 136.}}}]}, 
             {FaceForm[{RGBColor[
              0.8078430000000001, 0.06666670000000002, 0.14902], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               0., 136.}, {400., 136.}, {400., 64.}, {0., 64.}}}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0., 
               132.}, {400., 132.}, {400., 68.}, {0., 68.}}}]}, 
             {FaceForm[{RGBColor[0.117647, 0.709804, 0.22745100000000001`], 
              Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0., 
               64.}, {400., 64.}, {400., 0.}, {0., 0.}}}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{80., 168.}, {80., 154.74599999999998`}, {69.254, 
               144.}, {56., 144.}, {42.746, 144.}, {32., 
               154.74599999999998`}, {32., 168.}, {32., 181.254}, {42.746, 
               192.}, {56., 192.}, {69.254, 192.}, {80., 181.254}, {80., 
               168.}}}]}, 
             {FaceForm[{RGBColor[0., 0.6, 0.709804], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{88., 168.}, {88., 154.74599999999998`}, {77.254, 
               144.}, {64., 144.}, {50.746, 144.}, {40., 
               154.74599999999998`}, {40., 168.}, {40., 181.254}, {50.746, 
               192.}, {64., 192.}, {77.254, 192.}, {88., 181.254}, {88., 
               168.}}}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{70.398, 153.602}, {
               68.918, 149.035}, {71.199, 148.29299999999998`}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{70.398, 153.602}, {
               71.883, 149.035}, {69.60199999999999, 148.29299999999998`}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{74.965, 150.285}, {
               70.164, 150.285}, {70.164, 147.883}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{74.965, 150.285}, {
               71.082, 147.461}, {69.67199999999998, 149.40200000000002`}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{73.223, 144.918}, {
               71.738, 149.48000000000002`}, {69.45700000000001, 148.738}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{73.223, 144.918}, {
               69.34, 147.738}, {70.75, 149.68}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{67.57799999999999, 
               144.918}, {71.46100000000001, 147.738}, {70.051, 149.68}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{67.57799999999999, 
               144.918}, {69.062, 149.48000000000002`}, {71.34400000000001, 
               148.738}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{65.836, 150.285}, {
               69.71900000000001, 147.461}, {71.12899999999999, 
               149.40200000000002`}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{65.836, 150.285}, {
               70.637, 150.285}, {70.637, 147.883}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{89.60199999999999, 
               153.602}, {88.117, 149.035}, {90.398, 148.29299999999998`}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{89.60199999999999, 
               153.602}, {91.082, 149.035}, {88.801, 148.29299999999998`}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{94.164, 150.285}, {
               89.363, 150.285}, {89.363, 147.883}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{94.164, 150.285}, {
               90.281, 147.461}, {88.871, 149.40200000000002`}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{92.422, 144.918}, {
               90.938, 149.48000000000002`}, {88.65599999999999, 148.738}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{92.422, 144.918}, {
               88.539, 147.738}, {89.94900000000001, 149.68}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{86.777, 144.918}, {
               90.66, 147.738}, {89.25, 149.68}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{86.777, 144.918}, {
               88.262, 149.48000000000002`}, {90.543, 148.738}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{85.035, 150.285}, {
               88.918, 147.461}, {90.32799999999999, 149.40200000000002`}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{85.035, 150.285}, {
               89.836, 150.285}, {89.836, 147.883}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{108.801, 153.602}, {
               107.316, 149.035}, {109.598, 148.29299999999998`}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{108.801, 153.602}, {
               110.285, 149.035}, {108., 148.29299999999998`}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{113.363, 150.285}, {
               108.566, 150.285}, {108.566, 147.883}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{113.363, 150.285}, {
               109.48, 147.461}, {108.07, 149.40200000000002`}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{111.621, 144.918}, {
               110.137, 149.48000000000002`}, {107.85499999999999`, 
               148.738}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{111.621, 144.918}, {
               107.738, 147.738}, {109.148, 149.68}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{105.98, 144.918}, {
               109.863, 147.738}, {108.453, 149.68}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{105.98, 144.918}, {
               107.46100000000001`, 149.48000000000002`}, {
               109.74600000000001`, 148.738}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{104.23400000000001`,
                150.285}, {108.117, 147.461}, {109.527, 
               149.40200000000002`}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{104.23400000000001`,
                150.285}, {109.035, 150.285}, {109.035, 147.883}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{128., 153.602}, {
               126.516, 149.035}, {128.80100000000002`, 
               148.29299999999998`}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{128., 153.602}, {
               129.484, 149.035}, {127.199, 148.29299999999998`}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{132.566, 150.285}, {
               127.766, 150.285}, {127.766, 147.883}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{132.566, 150.285}, {
               128.684, 147.461}, {127.27, 149.40200000000002`}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{130.82000000000002`,
                144.918}, {129.34, 149.48000000000002`}, {127.05499999999999`,
                148.738}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{130.82000000000002`,
                144.918}, {126.938, 147.738}, {128.348, 149.68}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{125.17999999999999`,
                144.918}, {129.062, 147.738}, {127.65199999999999`, 
               149.68}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{125.17999999999999`,
                144.918}, {126.66, 149.48000000000002`}, {128.945, 
               148.738}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{123.43400000000001`,
                150.285}, {127.316, 147.461}, {128.73, 
               149.40200000000002`}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{123.43400000000001`,
                150.285}, {128.23399999999998`, 150.285}, {
               128.23399999999998`, 147.883}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{147.19899999999998`,
                153.602}, {145.71499999999997`, 149.035}, {148., 
               148.29299999999998`}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{147.19899999999998`,
                153.602}, {148.684, 149.035}, {146.40200000000002`, 
               148.29299999999998`}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{151.766, 150.285}, {
               146.965, 150.285}, {146.965, 147.883}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{151.766, 150.285}, {
               147.883, 147.461}, {146.47299999999998`, 
               149.40200000000002`}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{150.02, 144.918}, {
               148.539, 149.48000000000002`}, {146.254, 148.738}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{150.02, 144.918}, {
               146.137, 147.738}, {147.547, 149.68}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{144.379, 144.918}, {
               148.262, 147.738}, {146.85200000000003`, 149.68}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{144.379, 144.918}, {
               145.863, 149.48000000000002`}, {148.14499999999998`, 
               148.738}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{142.637, 150.285}, {
               146.52, 147.461}, {147.93, 149.40200000000002`}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{142.637, 150.285}, {
               147.434, 150.285}, {147.434, 147.883}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{89.60199999999999, 
               172.80100000000002`}, {88.117, 168.23399999999998`}, {90.398, 
               167.49200000000002`}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{89.60199999999999, 
               172.80100000000002`}, {91.082, 168.23399999999998`}, {88.801, 
               167.49200000000002`}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{94.164, 169.484}, {
               89.363, 169.484}, {89.363, 167.08200000000002`}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{94.164, 169.484}, {
               90.281, 166.66}, {88.871, 168.605}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{92.422, 164.117}, {
               90.938, 168.684}, {88.65599999999999, 167.941}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{92.422, 164.117}, {
               88.539, 166.93800000000002`}, {89.94900000000001, 168.879}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{86.777, 164.117}, {
               90.66, 166.93800000000002`}, {89.25, 168.879}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{86.777, 164.117}, {
               88.262, 168.684}, {90.543, 167.941}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{85.035, 169.484}, {
               88.918, 166.66}, {90.32799999999999, 168.605}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{85.035, 169.484}, {
               89.836, 169.484}, {89.836, 167.08200000000002`}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{108.801, 
               172.80100000000002`}, {107.316, 168.23399999999998`}, {109.598,
                167.49200000000002`}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{108.801, 
               172.80100000000002`}, {110.285, 168.23399999999998`}, {108., 
               167.49200000000002`}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{113.363, 169.484}, {
               108.566, 169.484}, {108.566, 167.08200000000002`}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{113.363, 169.484}, {
               109.48, 166.66}, {108.07, 168.605}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{111.621, 164.117}, {
               110.137, 168.684}, {107.85499999999999`, 167.941}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{111.621, 164.117}, {
               107.738, 166.93800000000002`}, {109.148, 168.879}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{105.98, 164.117}, {
               109.863, 166.93800000000002`}, {108.453, 168.879}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{105.98, 164.117}, {
               107.46100000000001`, 168.684}, {109.74600000000001`, 
               167.941}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{104.23400000000001`,
                169.484}, {108.117, 166.66}, {109.527, 168.605}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{104.23400000000001`,
                169.484}, {109.035, 169.484}, {109.035, 
               167.08200000000002`}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{128., 
               172.80100000000002`}, {126.516, 168.23399999999998`}, {
               128.80100000000002`, 167.49200000000002`}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{128., 
               172.80100000000002`}, {129.484, 168.23399999999998`}, {127.199,
                167.49200000000002`}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{132.566, 169.484}, {
               127.766, 169.484}, {127.766, 167.08200000000002`}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{132.566, 169.484}, {
               128.684, 166.66}, {127.27, 168.605}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{130.82000000000002`,
                164.117}, {129.34, 168.684}, {127.05499999999999`, 
               167.941}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{130.82000000000002`,
                164.117}, {126.938, 166.93800000000002`}, {128.348, 
               168.879}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{125.17999999999999`,
                164.117}, {129.062, 166.93800000000002`}, {
               127.65199999999999`, 168.879}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{125.17999999999999`,
                164.117}, {126.66, 168.684}, {128.945, 167.941}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{123.43400000000001`,
                169.484}, {127.316, 166.66}, {128.73, 168.605}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{123.43400000000001`,
                169.484}, {128.23399999999998`, 169.484}, {
               128.23399999999998`, 167.08200000000002`}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{147.19899999999998`,
                172.80100000000002`}, {145.71499999999997`, 
               168.23399999999998`}, {148., 167.49200000000002`}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{147.19899999999998`,
                172.80100000000002`}, {148.684, 168.23399999999998`}, {
               146.40200000000002`, 167.49200000000002`}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{151.766, 169.484}, {
               146.965, 169.484}, {146.965, 167.08200000000002`}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{151.766, 169.484}, {
               147.883, 166.66}, {146.47299999999998`, 168.605}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{150.02, 164.117}, {
               148.539, 168.684}, {146.254, 167.941}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{150.02, 164.117}, {
               146.137, 166.93800000000002`}, {147.547, 168.879}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{144.379, 164.117}, {
               148.262, 166.93800000000002`}, {146.85200000000003`, 
               168.879}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{144.379, 164.117}, {
               145.863, 168.684}, {148.14499999999998`, 167.941}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{142.637, 169.484}, {
               146.52, 166.66}, {147.93, 168.605}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{142.637, 169.484}, {
               147.434, 169.484}, {147.434, 167.08200000000002`}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{108.801, 192.}, {
               107.316, 187.434}, {109.598, 186.691}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{108.801, 192.}, {
               110.285, 187.434}, {108., 186.691}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{113.363, 188.684}, {
               108.566, 188.684}, {108.566, 186.285}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{113.363, 188.684}, {
               109.48, 185.863}, {108.07, 187.805}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{111.621, 183.316}, {
               110.137, 187.883}, {107.85499999999999`, 187.141}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{111.621, 183.316}, {
               107.738, 186.137}, {109.148, 188.078}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{105.98, 183.316}, {
               109.863, 186.137}, {108.453, 188.078}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{105.98, 183.316}, {
               107.46100000000001`, 187.883}, {109.74600000000001`, 
               187.141}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{104.23400000000001`,
                188.684}, {108.117, 185.863}, {109.527, 187.805}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{104.23400000000001`,
                188.684}, {109.035, 188.684}, {109.035, 186.285}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{128., 192.}, {
               126.516, 187.434}, {128.80100000000002`, 186.691}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{128., 192.}, {
               129.484, 187.434}, {127.199, 186.691}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{132.566, 188.684}, {
               127.766, 188.684}, {127.766, 186.285}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{132.566, 188.684}, {
               128.684, 185.863}, {127.27, 187.805}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{130.82000000000002`,
                183.316}, {129.34, 187.883}, {127.05499999999999`, 
               187.141}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{130.82000000000002`,
                183.316}, {126.938, 186.137}, {128.348, 188.078}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{125.17999999999999`,
                183.316}, {129.062, 186.137}, {127.65199999999999`, 
               188.078}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{125.17999999999999`,
                183.316}, {126.66, 187.883}, {128.945, 187.141}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{123.43400000000001`,
                188.684}, {127.316, 185.863}, {128.73, 187.805}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{123.43400000000001`,
                188.684}, {128.23399999999998`, 188.684}, {
               128.23399999999998`, 186.285}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{147.19899999999998`,
                192.}, {145.71499999999997`, 187.434}, {148., 186.691}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{147.19899999999998`,
                192.}, {148.684, 187.434}, {146.40200000000002`, 186.691}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{151.766, 188.684}, {
               146.965, 188.684}, {146.965, 186.285}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{151.766, 188.684}, {
               147.883, 185.863}, {146.47299999999998`, 187.805}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{150.02, 183.316}, {
               148.539, 187.883}, {146.254, 187.141}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{150.02, 183.316}, {
               146.137, 186.137}, {147.547, 188.078}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{144.379, 183.316}, {
               148.262, 186.137}, {146.85200000000003`, 188.078}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{144.379, 183.316}, {
               145.863, 187.883}, {148.14499999999998`, 187.141}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{142.637, 188.684}, {
               146.52, 185.863}, {147.93, 187.805}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{142.637, 188.684}, {
               147.434, 188.684}, {147.434, 186.285}}}]}},
            AspectRatio->Automatic,
            ImageSize->{{128}, {85}},
            PlotRange->{{0., 400.}, {0., 200.}}], ",", 
           GraphicsBox[
            {Thickness[0.001893939393939394], 
             {FaceForm[{RGBColor[0., 0.47058800000000006`, 0.368627], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               0., 0.}, {0., 352.}, {528., 352.}, {528., 0.}}}]}, 
             {FaceForm[{RGBColor[
              0.9843139999999999, 0.8196080000000001, 0.08627450000000002], 
              Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {
               0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBWIuIGZigIKGAofHS2cfUbhV6LD1RNm++VYFDse8zTsd
WQod+g991YjZnAfnCzUfOLWQv8Dh0yXfJIEGqLop+Q4FtlzXF4fkO8DM2yHX
+jpQr8BBNirF+r5pIVz+bY29adwHhH6wumWFcPNBVMJRhP2LXLd9/iuQ5ZD7
/PfKj0lQd+ZkOaz+CDRgTr4DUPcOudxMB5funOe/X+ZB5JdkOfROzxNqfpLn
4Jjw9ILS/yyHapF17g935ULEU7Ih+h7mOYTx6W6aOzsH4s7beQ6qbI1TnRdn
O8Tu8uRhmp7vsApkD0eOwxZQuMQVQNzHmQ2hWQsc9O+qsDV+L4a7D2SMf3Ux
XF6rXezmud9FcP1g/+sVw82/WvFSzXBTEdx+K5BC32K4++77A13cUAx3P8i5
79cWw/0HCtYCzxK4/8HyJ4vh4VOUMfFtzeF0iP53OZDwcUh32D9fSv/ulWyH
CaD45U6DyP/KhqpLcwAZf0ANKp+d5lAIsogny6EYZF51OsTcxVkOcSB/xGdA
1J3PdLAEuV85w+H2z7qsPQzZDqEgBxlnQsJ5ejZE/f90Bx9Q+OzNhsSzXCnc
fReUgDoZSuHy4PBJK4HrB7v/XQncfLD6CyVw+4+DzHMqhbtvJyh9nSqFux+k
rL+jFO4/sPyvUrj/eUHhF18KDx8AMi5sNg==
               "]]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {0, 1, 0}, {1, 3, 
                3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {0,
                 1, 0}, {1, 3, 3}}, {{1, 4, 3}, {0, 1, 0}, {1, 3, 3}}, {{1, 4,
                 3}, {0, 1, 0}, {1, 3, 3}}, {{1, 4, 3}, {0, 1, 0}, {1, 3, 
                3}}, {{1, 4, 3}, {1, 3, 3}}}, {CompressedData["
1:eJxVVWtIFFEUFosSkwiLiLCyd9nD+hFSYp2KsKwoCxSiYhzc2XF3Z3RmZ5Me
SBGSPUlKKiKkRKEyidCealJSIZQmkmmGWUSSmElFVPSYe87M2RRk+Pbee+53
vvPdc6bKuVs8kREREbvtf/HFv/15EFSL+/f1aYA4kAvR7WV5KScCDtZhlMBH
fIxrnuyqL01TGc8ccaBk9UMF+vetWLLzrYMzPSDCrriWC3kpdsQ52fCu/Hxj
fLUOrdNe/SjweWBZtR1oig6zF0dVxv1RGD9an3R4ZbXKGOO151C8LB1WSe9b
pvX56NwLHTqefd/6rscPG+xjUqGzP8nhv1aHlWJ/aYDWZzr8YzXotFnUFmlQ
Z52aMPyPn84lavBc8Kv3McZ7fDmMz+qxBxseeGHswYami3c0yBi94MaFZAWW
Cr5lOpx88G3O9r9OvjEa3XdFIf5PfVDYl357co0Xjp+xA21WGaN+C8P4sdAh
RnX08MInsf7RS/FueEnHBBV23F0XE5nv7JdUuDLYulFe5IX60omJr4tURx+F
6hrph/vi9zcK5b1co3MvPVSnNp10W5RNv2/WKJ7lgaviu91PeSYpMEvokZzD
GPlEq4wxTq9Cev30UB26nTjHPKTngEJ1qZMp/4oc0rVOorzbAowvrbn55XeU
xhj1THF82yBRXnkanWuUYKfQZZhGOl+XSIfiANWzQqL7Jocxno/zMUbeaY5+
RhbF/apAl/BNrUz7K526XpRJJ0mhup+UwRB6jlHID0dl4q15Qbi/NiKL3p3f
0W+kRHqU+RmTDzXGia9njDhQnkv39Ergvl/0S7pMPBYYvI78400+T/4KMsb6
plmM84Vh1oWYX2rPnnFV30PMP+HQ+I5nzSHOL/66qRZfDnH+k7ZlJ3cXhlgf
9Gmnxfrh/sEg63tYGOKzydh2Y8boW2HcIvIvMLl+eD7V5Pqi3bNMrj/qs9dk
fyCfkjDG++ZbjFGPohD7r3uTfdOYXexPjHssxP6lr8X+xvcoh/E8oU96kHGc
uD/T5PezVuhZYvD7Qj9LJr8/ezW1pyDI7xPzvWfx+8V4zRa/b+Tz0eL3j/lF
h7g/YP4/LO4fuN5rcX9Bnu1hjHqeCzIWbW1gt8n9C+teZXB/Q79MN7n/oZ6q
yf3RxW7/dLHbX2NFHZJN7r+C7qZ+g/sz6tRlcP/G9TqD+7v24dflwdMG93/k
32zwfEC+nw2eHy5254uL3fmD+ZYbPJ8w3lyD51eRIHLC4PmG/JoMnn8uHjIf
bTxkfqYZQ+frf/P3HzZeSso=
                "], CompressedData["
1:eJxTTMoPSmViYGAQB2IQDQYNBQ6WW06U7WtOdOC+vrjAdlW+g8FdFbZG2wSH
CYe+asTcznXgAom/inO4ee578OO72XD+qo+XfJNE0uB8sHkOaQ419qZxuzLj
HL5pxPQfyk1zEFnn/rDqTayDcPOBUwvnpjnMyBNqPlAUCzHPNAfO3zdfSv8u
Rx6cX2ALNHlLvsOmue+XHzsMNR/o3oyJb2vsKxMcPB5WiaxTLYTLK2woypj4
uxCuf7IESxjf0yI4vxxkwcZSOL/1deAOuZOlcPeBzX9QCne/drvYzXNfS+H+
A5snWAzn75QDmiBUBOdXgwzSKoSHH3r4AgC2fJ4U
                "], {{186.059, 
                111.742}, {186.969, 110.74600000000001`}, {
                187.90200000000002`, 109.77}, {188.85200000000003`, 
                108.809}, {339.148, 108.809}, {340.09799999999996`, 109.77}, {
                341.03099999999995`, 110.74600000000001`}, {341.941, 
                111.742}}, {{195.336, 102.758}, {197.195, 
                101.16799999999999`}, {199.105, 99.637}, {201.07, 
                98.17599999999999}, {326.92999999999995`, 
                98.17599999999999}, {328.895, 99.637}, {330.805, 
                101.16799999999999`}, {332.66400000000004`, 102.758}}, {{
                207.758, 93.59}, {211.164, 91.44100000000002}, {214.695, 
                89.48}, {218.35200000000003`, 87.727}, {309.648, 87.727}, {
                313.305, 89.48}, {316.83599999999996`, 91.44100000000002}, {
                320.242, 93.59}}, {{225.055, 84.793}, {237.105, 80.}, {
                250.24599999999998`, 77.367}, {264., 77.367}, {277.754, 
                77.367}, {290.895, 80.}, {302.945, 84.793}}}]}},
            AspectRatio->Automatic,
            ImageSize->{{128}, {85}},
            PlotRange->{{0., 528.}, {0., 352.}}], ",", 
           GraphicsBox[
            {Thickness[0.0020833333333333333`], 
             {FaceForm[{RGBColor[0., 0.501961, 0.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0., 
               240.}, {480., 240.}, {480., 0.}, {0., 0.}}}]}, 
             {FaceForm[{RGBColor[1., 0.8784310000000001, 0.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{134.445, 170.}, {134.445, 141.16}, {111.062, 
               117.777}, {82.223, 117.777}, {53.379, 117.777}, {30., 
               141.16}, {30., 170.}, {30., 198.84}, {53.379, 
               222.22299999999998`}, {82.223, 222.22299999999998`}, {111.062, 
               222.22299999999998`}, {134.445, 198.84}, {134.445, 170.}}}]}, 
             {FaceForm[{RGBColor[0.501961, 0.12549000000000002`, 0.], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 
               3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIVIGYCYmn9uypsG4MdHi+dfUQhIMGh+cCpha7fwnDy
K1+qGXLIhDtcULr9s64sweGbRkz/obdhDsIghZ0JDsUZE9/W7A9z2D9fSv/u
nASH14E75Fq5wxwWuW77/HcBVL8NVP5JggMDCCwIc1j18ZJvUkGiw96SyRIs
68IcfMw7HRNcEx2AtmTteRMGoSckQczTDoe4506yQ429adwuz3AHyy0nyvY9
TsXgg/13MQwn/5g30KIXYQ7qhhxrZJxSHS6C/LUozMEKJJ+f4nAHZG9MmAPI
W/ZzkyH63MMcZuQJNR/oSnYAWsbD9DvUoRXksJdJkPBaF+pQBNLgngRRtyjU
AWRto2USJBxiQh0mHPqqEXM70WGNTFSKtXgoxPzaRIfjIPcIhDr0TgdqrEh0
iAeZvzjEASScoJgIMcc0BOLeUwkOmSB9sSEQe14lOISAAybE4S0oILYlQPzD
FAIxdw5U/d1gB1W2xqnOixMg4XESGv8TEhxE1rk/rNoSDPFPLVQeKX2g8wEC
hwLd
               "]]}, 
             {RGBColor[0.48235300000000003`, 0.192157, 0.], Thickness[
              0.002314814583333333], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIVIGYCYmn9uypsG4MdipbOY1UMSHBoPnBqoeu3MJz8
ypdqhhwy4Q4JSves6ssSHL5pxPQfehvmsKjpMPeizgSH4oyJb2v2hzn4zZct
uDsnweF14A65Vu4wBwPXnSb/FkD120DlnyQ4MIDAgjAHy49X+5IKEh32lkyW
YFkX5nDbrKcpwTXR4fbPuqw9b8Icsn42rt4zIQlinnY4xD13kh1q7E3jdnmG
O5zYfHr7vsepGHyw/y6G4eQf8zbvdHwR5rDNgPutjFOqw0UloI2LoPL5KQ53
QPbHhDn8mPBhr/3cZAfLLSfK9rmHOajliR450JXsALSMh+l3qIPI65Cfci+T
IOG1LtSBKWOKXq17ksOMPKHmA4tCHfbdUXdvtExyWOS67fPfmFAHuUM/MmNu
JzqskYlKsRYPhZhfm+hwHOQegVAHmemFwc0ViQ7xIPMXhzjcAoWHYqIDyPmN
piEQ955KcMgEBrd9bAjEPa8SHEIeL519RCHEoabGqSxuWwLEP0whDmHeVqcc
50DV3w122MLacs15cQIkPE5C439CgoPIOveHVVuCIf6phcojpQ90PgBfPP92

               "],
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 0.8784310000000001, 0.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{360., 57.145}, {
               363.305, 46.863}, {373.402, 50.688}, {367.42999999999995`, 
               41.69500000000001}, {376.715, 36.184}, {365.957, 35.25}, {
               367.43799999999993`, 24.555}, {360., 32.379}, {352.562, 
               24.555}, {354.043, 35.25}, {343.28499999999997`, 36.184}, {
               352.57, 41.69500000000001}, {346.59799999999996`, 50.688}, {
               356.695, 46.863}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{360., 
               217.14499999999998`}, {363.305, 206.863}, {373.402, 
               210.68800000000002`}, {367.42999999999995`, 201.695}, {376.715,
                196.184}, {365.957, 195.25}, {367.43799999999993`, 184.555}, {
               360., 192.379}, {352.562, 184.555}, {354.043, 195.25}, {
               343.28499999999997`, 196.184}, {352.57, 201.695}, {
               346.59799999999996`, 210.68800000000002`}, {356.695, 
               206.863}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{300., 
               152.14499999999998`}, {303.305, 141.863}, {313.402, 
               145.68800000000002`}, {307.42999999999995`, 136.695}, {316.715,
                131.184}, {305.957, 130.25}, {307.43799999999993`, 
               119.55499999999999`}, {300., 127.37899999999999`}, {292.562, 
               119.55499999999999`}, {294.043, 130.25}, {283.28499999999997`, 
               131.184}, {292.57, 136.695}, {286.59799999999996`, 
               145.68800000000002`}, {296.695, 141.863}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{413.332, 
               168.14499999999998`}, {416.641, 157.863}, {426.734, 
               161.68800000000002`}, {420.762, 152.695}, {430.047, 147.184}, {
               419.29299999999995`, 146.25}, {420.77299999999997`, 135.555}, {
               413.332, 143.379}, {405.895, 135.555}, {407.375, 146.25}, {
               396.621, 147.184}, {405.902, 152.695}, {399.92999999999995`, 
               161.68800000000002`}, {410.027, 157.863}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{384., 
               120.}, {386.613, 113.59400000000001`}, {393.512, 113.09}, {
               388.227, 108.62499999999999`}, {389.879, 
               101.91000000000001`}, {384., 105.55499999999999`}, {378.121, 
               101.91000000000001`}, {379.77299999999997`, 
               108.62499999999999`}, {374.48799999999994`, 113.09}, {381.387, 
               113.59400000000001`}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 
               3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
               1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJ/IGZigIE8BzDlkOpw52dd1p6eLDgfTB9Id1Bla5zq
XJwE50P0xcH52z7/vVIhGY6qvyHQAcV8IF/dkGONzLx8VPmuAoj5h4McHi+d
fURBotDhPwgcD3EQbj5waiFvocPrwB1yrZtDHIDk60CWQofijIlva6aHOChs
KMqY+LPAAcS1bw1xuFrxUs3wUoHDjDyh5gNOIQ6TJVjC+FYWODy7oHT7J1+I
wzFv807HugIHkDKON8EOIG5CcIGDtP5dFbaTwQ5VIuvcH6oVOICs2bEt2KEa
xP+UD+eD3TsDwY/b5cnDZJ8P1w8272Ue3PxQPt1Ncyfnwe0Hyzvmwd239UTZ
vvmfcuHul41Ksb6/OBfuf7D6yFyIPdKhDv2HvmrECOc61Nqbxu2qDIXoO5vj
0DsdaOCNUIcJIPnuHKj5YQ5WW4AW+OdA1O8Mg/hfJAfiXsNwh70lwBC6l+1w
GxRvW8Ih7lmXDZF3jICYV5/tsMgVGMNnIiDhE5bt4NKd8/x3YqQDSFmjaTYk
Pv5HQs2Hqp8T5fCuBmjxryxI+nCMdtg3X0r/7ossiPybaIh/rmdB9M2IceC6
vrjA9lwWhPaKhfNh6Q3G/6YR039oaxxcvyXIn+nxcPPB7uJMgNsPTl/xCXD3
geU3JsDdfxwkzpAI9x84vP0T4f4Hq5uZCA8fsH/vJ8LDTwiUTlWT4OFbBJJP
T4KHv1PC0wtKi5Pg8QM2514SPP7A7hdOhscvWL1zMjz+LwKTT11RMjx9gINj
TjI8/fiA1O1NhqcviPnJ8PQHTh8/kuHpcw/I3Vwp8PQL9o90Cjx9F9gCQ1ol
BZ7+YXxY/oDxYfkHph+Wv2Dmw/IfzH5Y/oS5D5Z/Ye6H5W+wOVuS4fkfHO/L
kuHlA8z/sPLjLSie56Wgli+w8gupfAMAErP+jA==
               "]]}, 
             {FaceForm[{RGBColor[0., 0.501961, 0.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {
                1, 3, 3}}}, {CompressedData["
1:eJxdVwlsFGUUhspVJA1qQQUUVAS8KCagBSR9oFJ67uwxu7M7uwWZ+eeoFEtB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                "], {{100., 176.39100000000002`}, {101.812, 176.695}, {
                100.039, 173.637}, {99.16799999999999, 173.68}, {99.242, 
                174.781}, {96.543, 174.676}, {98.21900000000001, 
                175.63299999999998`}, {98.762, 175.984}, {99.367, 176.25}, {
                100., 176.39100000000002`}}}]}},
            AspectRatio->Automatic,
            ImageSize->{{128}, {85}},
            PlotRange->{{0., 480.}, {0., 241.}}], ",", 
           GraphicsBox[
            {Thickness[0.0010416666666666667`], 
             {Thickness[0.0010416666666666667`], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0., 
               480.}, {960., 480.}, {960., 320.}, {0., 320.}}}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0., 
               320.}, {960., 320.}, {960., 160.}, {0., 160.}}}]}, 
             {FaceForm[{RGBColor[0., 0.478431, 0.23921600000000004`], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               0., 160.}, {960., 160.}, {960., 0.}, {0., 0.}}}]}, 
             {FaceForm[{RGBColor[
              0.8078430000000001, 0.06666670000000002, 0.14902], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{0., 480.}, {
               320., 240.}, {0., 0.}}}]}},
            AspectRatio->Automatic,
            ImageSize->{{128}, {85}},
            PlotRange->{{0., 960.}, {0., 480.}}], ",", 
           GraphicsBox[
            {Thickness[0.0010416666666666667`], 
             {Thickness[0.0010416666666666667`], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0., 
               480.}, {960., 480.}, {960., 320.}, {0., 320.}}}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0., 
               320.}, {960., 320.}, {960., 160.}, {0., 160.}}}]}, 
             {FaceForm[{RGBColor[0., 0.478431, 0.23921600000000004`], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               0., 160.}, {960., 160.}, {960., 0.}, {0., 0.}}}]}, 
             {FaceForm[{RGBColor[
              0.8078430000000001, 0.06666670000000002, 0.14902], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{0., 480.}, {
               320., 240.}, {0., 0.}}}]}},
            AspectRatio->Automatic,
            ImageSize->{{128}, {85}},
            PlotRange->{{0., 960.}, {0., 480.}}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           GraphicsBox[
            {Thickness[0.0010416666666666667`], 
             {FaceForm[{RGBColor[0.8509800000000001, 0., 0.0705882], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               0., 0.}, {0., 480.}, {960., 480.}, {960., 0.}}}]}, 
             {FaceForm[{RGBColor[0., 0.2, 0.627451], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0., 
               320.}, {960., 320.}, {960., 160.}, {0., 160.}}}]}, 
             {FaceForm[{RGBColor[0.9490200000000001, 0.6588240000000001, 0.], 
              Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0., 
               160.}, {960., 160.}, {960., 0.}, {0., 0.}}}]}},
            AspectRatio->Automatic,
            ImageSize->{{128}, {85}},
            PlotRange->{{0., 960.}, {0., 480.}}], ",", 
           GraphicsBox[{
             {Thickness[0.0008333333333333334], 
              {FaceForm[{RGBColor[0.870588, 0.160784, 0.06274510000000001], 
               Opacity[1.]}], 
               FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0., 
                0.}, {0., 800.}, {1200., 800.}, {1200., 0.}}}]}}, 
             {RGBColor[1., 0.870588, 0.], 
              PolygonBox[{{{156.4073211147477, 585.837018249545}, {129.465, 
                502.91799999999995`}, {200., 554.1649280840463}, {
                270.53499999999997`, 502.91799999999995`}, {243.5926788852523,
                 585.837018249545}, {243.59267888525227`, 585.837018249545}, {
                314.125, 637.082}, {226.94199026174442`, 637.082}, {
                226.9419902617444, 637.082}, {200., 720.}, {173.0580097382556,
                 637.082}, {85.87499999999999, 637.082}}, {{365.699, 
                699.4219999999999}, {394.02059683525385`, 
                705.9407992661736}, {408.97299999999996`, 681.02}, {
                411.5242212411751, 709.96961920159}, {439.84400000000005`, 
                716.488}, {413.10086862161455`, 727.8604005035999}, {
                415.65200000000004`, 756.809}, {396.57181807195605`, 
                734.8893074829407}, {369.828, 746.262}, {384.7797301874549, 
                721.3423223683757}}, {{440.402, 634.3439999999999}, {
                469.0343335503074, 629.361789846223}, {473.14500000000004`, 
                600.594}, {486.7292087861558, 626.2827677708841}, {
                486.7292087861558, 626.2827677708842}, {515.3589999999999, 
                621.3009999999999}, {495.1246145642034, 642.1591160197714}, {
                508.71099999999996`, 667.8519999999999}, {482.6172094551196, 
                655.0520653855589}, {462.383, 675.91}, {466.4935753121953, 
                647.1428479638266}}, {{465.6480604418864, 
                514.7602115466024}, {457.66400000000004`, 486.816}, {
                480.5486352299245, 504.73064709811763`}, {504.656, 488.504}, {
                494.6909275247808, 515.8015762641411}, {517.5740000000001, 
                533.715}, {488.53181121238066`, 532.6734000943798}, {478.566, 
                559.9730000000001}, {470.58218157485607`, 
                532.0296355119963}, {441.539, 530.988}}, {{366.582, 
                418.01599999999996`}, {394.60952440391605`, 
                425.7048046163738}, {394.60952440391605`, 
                425.70480461637374`}, {410.582, 401.42599999999993`}, {
                411.9307747145386, 430.4565517714337}, {411.9307747145386, 
                430.45655177143374`}, {439.957, 438.14500000000004`}, {
                412.7643509911082, 448.3981538726199}, {414.113, 
                477.42599999999993`}, {395.95886570694836`, 
                454.73476442005847`}, {368.76599999999996`, 
                464.98799999999994`}, {384.7381266235573, 
                440.70972583588684`}}}]}},
            AspectRatio->Automatic,
            ImageSize->{{128}, {85}},
            PlotRange->{{0., 1200.}, {0., 800.}}], ",", 
           GraphicsBox[
            {Thickness[0.001388888888888889], 
             {FaceForm[{RGBColor[0.870588, 0.160784, 0.06274510000000001], 
              Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0., 
               0.}, {0., 480.}, {720., 480.}, {720., 0.}}}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{359.97299999999996`, 240.07}, {275.762, 275.66}, {
               313.09, 385.33599999999996`}, {393.625, 379.82}, {
               377.33599999999996`, 371.449}, {374.97299999999996`, 
               355.824}, {384.277, 341.35200000000003`}, {394.695, 
               325.14500000000004`}, {383.316, 299.07}, {369.234, 292.734}, {
               346.08599999999996`, 282.316}, {341.449, 254.535}, {
               359.97299999999996`, 240.07}}}]}, 
             {FaceForm[{RGBColor[0.870588, 0.160784, 0.06274510000000001], 
              Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               355.41799999999995`, 319.26599999999996`}, {350.684, 
               311.828}, {348.965, 320.47999999999996`}, {340.42199999999997`,
                322.688}, {348.125, 327.}, {347.58599999999996`, 335.801}, {
               354.055, 329.809}, {362.258, 333.043}, {358.57, 
               325.03499999999997`}, {364.172, 318.22999999999996`}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1,
                3, 3}}}, {{{360.449, 240.99200000000002`}, {350.262, 
               246.21899999999997`}, {342.051, 257.117}, {338.47299999999996`,
                270.137}, {334.383, 285.074}, {336.734, 301.133}, {344.941, 
               314.168}, {343.172, 315.28099999999995`}, {334.66, 
               301.73799999999994`}, {332.219, 285.09}, {336.465, 
               269.58599999999996`}, {340.246, 255.809}, {348.637, 
               244.71099999999998`}, {359.4959999999999, 239.137}}}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{360.059, 240.047}, {367.883, 331.137}, {483.727, 
               329.52299999999997`}, {503.371, 251.227}, {490.371, 264.133}, {
               474.78099999999995`, 261.551}, {463.89099999999996`, 248.23}, {
               451.699, 233.312}, {423.387, 236.078}, {413.008, 247.516}, {
               395.945, 266.312}, {368.094, 262.133}, {360.059, 
               240.047}}}]}, 
             {FaceForm[{RGBColor[0.870588, 0.160784, 0.06274510000000001], 
              Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               433.969, 268.85200000000003`}, {425.43399999999997`, 
               271.059}, {433.133, 275.363}, {432.59, 284.172}, {439.07, 
               278.18}, {447.27299999999997`, 281.40999999999997`}, {443.574, 
               273.40599999999995`}, {449.188, 266.60200000000003`}, {
               440.42999999999995`, 267.637}, {435.691, 260.207}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1,
                3, 3}}}, {{{361.082, 239.879}, {362.90599999999995`, 
               251.184}, {370.72999999999996`, 262.35900000000004`}, {382.012,
                269.78499999999997`}, {394.949, 278.29299999999995`}, {
               410.949, 281.01599999999996`}, {425.883, 277.242}, {
               426.39799999999997`, 279.26599999999996`}, {410.887, 
               283.176}, {394.29699999999997`, 280.355}, {380.867, 271.527}, {
               368.93399999999997`, 263.672}, {360.969, 252.262}, {
               359.02299999999997`, 240.21499999999997`}}}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{360.062, 239.961}, {449.10900000000004`, 260.668}, {
               483.375, 149.996}, {414.97999999999996`, 107.117}, {
               423.23799999999994`, 123.46900000000001`}, {415.965, 
               137.496}, {399.92999999999995`, 143.738}, {381.977, 
               150.72299999999998`}, {375.855, 178.504}, {383.527, 191.91}, {
               396.129, 213.945}, {383.551, 239.14499999999998`}, {360.062, 
               239.961}}}]}, 
             {FaceForm[{RGBColor[0.870588, 0.160784, 0.06274510000000001], 
              Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               410.29699999999997`, 178.566}, {409.758, 
               187.36700000000002`}, {416.22999999999996`, 181.375}, {424.441,
                184.60899999999998`}, {420.746, 176.598}, {
               426.35200000000003`, 169.79299999999998`}, {
               417.59799999999996`, 170.84}, {412.85900000000004`, 
               163.39800000000002`}, {411.137, 172.047}, {402.605, 
               174.258}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1,
                3, 3}}}, {{{360.22299999999996`, 238.934}, {
               371.53499999999997`, 240.691}, {384.582, 
               236.70299999999997`}, {395.129, 228.26999999999998`}, {407.219,
                218.594}, {414.754, 204.21899999999997`}, {415.777, 
               188.848}, {417.863, 188.984}, {416.789, 204.945}, {408.977, 
               219.85200000000003`}, {396.43399999999997`, 
               229.89800000000002`}, {385.27299999999997`, 
               238.82000000000002`}, {371.96099999999996`, 242.871}, {359.902,
                240.996}}}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{359.984, 239.92600000000002`}, {407.191, 161.637}, {
               312.527, 94.848}, {250.60899999999998`, 146.648}, {268.715, 
               143.844}, {279.809, 155.098}, {280.789, 172.277}, {281.883, 
               191.512}, {306.414, 205.918}, {321.53499999999997`, 202.762}, {
               346.387, 197.586}, {366.465, 217.336}, {359.984, 
               239.92600000000002`}}}]}, 
             {FaceForm[{RGBColor[0.870588, 0.160784, 0.06274510000000001], 
              Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               317.117, 173.18}, {325.32, 176.41}, {321.621, 
               168.40200000000002`}, {327.234, 161.598}, {318.47299999999996`,
                162.637}, {313.734, 155.19899999999998`}, {
               312.02299999999997`, 163.848}, {303.484, 166.055}, {311.176, 
               170.36700000000002`}, {310.641, 179.164}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1,
                3, 3}}}, {{{359.055, 239.461}, {364.22299999999996`, 
               229.24599999999998`}, {364.46099999999996`, 215.602}, {359.699,
                202.965}, {354.22999999999996`, 188.477}, {
               342.89099999999996`, 176.86700000000002`}, {328.59, 
               171.14499999999998`}, {329.363, 169.20299999999997`}, {
               344.21099999999996`, 175.156}, {355.97299999999996`, 
               187.191}, {361.648, 202.23}, {366.688, 215.598}, {
               366.42599999999993`, 229.512}, {360.91799999999995`, 
               240.40200000000002`}}}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{359.92599999999993`, 239.99200000000002`}, {300.055, 
               170.90200000000002`}, {207.281, 240.297}, {237.414, 315.188}, {
               240.34, 297.105}, {254.47299999999998`, 290.03099999999995`}, {
               271.113, 294.40599999999995`}, {289.746, 299.309}, {311.027, 
               280.42999999999995`}, {312.699, 265.078}, {315.453, 239.844}, {
               340.445, 226.85200000000003`}, {359.92599999999993`, 
               239.99200000000002`}}}]}, 
             {FaceForm[{RGBColor[0.870588, 0.160784, 0.06274510000000001], 
              Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               283.199, 260.137}, {288.809, 253.336}, {280.047, 254.375}, {
               275.309, 246.934}, {273.59, 255.59}, {265.055, 
               257.79699999999997`}, {272.75, 262.09799999999996`}, {
               272.21099999999996`, 270.89799999999997`}, {278.688, 
               264.91799999999995`}, {286.887, 268.141}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1,
                3, 3}}}, {{{359.195, 240.73399999999998`}, {351.074, 
               232.66}, {338.176, 228.21899999999997`}, {324.684, 228.84}, {
               309.215, 229.562}, {294.672, 236.766}, {284.809, 248.598}, {
               283.203, 247.262}, {293.453, 234.98000000000002`}, {
               308.53499999999997`, 227.512}, {324.58599999999996`, 
               226.762}, {338.85900000000004`, 226.098}, {352.008, 230.648}, {
               360.66400000000004`, 239.254}}}]}},
            AspectRatio->Automatic,
            ImageSize->{{128}, {85}},
            PlotRange->{{0., 720.}, {0., 480.}}], ",", 
           GraphicsBox[
            {Thickness[0.001388888888888889], 
             {FaceForm[{RGBColor[0.996078, 0., 0.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0., 
               0.}, {0., 480.}, {720., 480.}, {720., 0.}}}]}, 
             {FaceForm[{RGBColor[0., 0., 0.5843139999999999], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0., 
               480.}, {360., 480.}, {360., 240.}, {0., 240.}}}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {
               0, 1, 0}, {0, 1, 0}}}, {{{204., 360.}, {180., 270.}, {156., 
               360.}, {180., 450.}}, {{180., 336.}, {270., 360.}, {180., 
               384.}, {90., 360.}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {
               0, 1, 0}, {0, 1, 0}}}, {{{200.785, 348.}, {135., 282.059}, {
               159.21499999999997`, 372.}, {225., 437.941}}, {{168., 
               339.215}, {257.941, 315.}, {192., 380.78499999999997`}, {
               102.059, 405.}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {
               0, 1, 0}, {0, 1, 0}}}, {{{192., 339.215}, {102.059, 315.}, {
               168., 380.78499999999997`}, {257.941, 405.}}, {{
               159.21499999999997`, 348.}, {225., 282.059}, {200.785, 372.}, {
               135., 437.941}}}]}, 
             {FaceForm[{RGBColor[0., 0., 0.5843139999999999], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{231., 360.}, {231., 331.832}, {208.168, 309.}, {180., 
               309.}, {151.83200000000002`, 309.}, {129., 331.832}, {129., 
               360.}, {129., 388.168}, {151.83200000000002`, 411.}, {180., 
               411.}, {208.168, 411.}, {231., 388.168}, {231., 360.}}}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{225., 360.}, {225., 335.148}, {204.85200000000003`, 
               315.}, {180., 315.}, {155.148, 315.}, {135., 335.148}, {135., 
               360.}, {135., 384.85200000000003`}, {155.148, 405.}, {180., 
               405.}, {204.85200000000003`, 405.}, {225., 
               384.85200000000003`}, {225., 360.}}}]}},
            AspectRatio->Automatic,
            ImageSize->{{128}, {85}},
            PlotRange->{{0., 720.}, {0., 480.}}], ",", 
           GraphicsBox[
            {Thickness[0.001388888888888889], 
             {FaceForm[{RGBColor[
              0.9372550000000001, 0.698039, 0.17647100000000002`], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               0., 0.}, {0., 480.}, {720., 480.}, {720., 0.}}}]}, 
             {FaceForm[{RGBColor[
              0.886275, 0.23921600000000004`, 0.15686300000000003`], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{0., 0.}, {
               720., 0.}, {720., 480.}}}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{385.395, 
               329.92999999999995`}, {381.402, 331.34400000000005`}, {378.828,
                329.28499999999997`}, {378.957, 324.133}, {379.082, 
               318.97999999999996`}, {381.789, 316.02}, {385.78099999999995`, 
               317.953}}}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{385.395, 329.93}, {
               381.402, 331.344}, {378.828, 329.285}, {378.957, 324.133}, {
               379.082, 318.98}, {381.789, 316.02}, {385.78099999999995`, 
               317.953}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{388.89799999999997`,
                339.574}, {385.578, 342.199}, {382.477, 341.074}, {380.941, 
               336.15200000000004`}, {379.40999999999997`, 331.234}, {381.02, 
               327.562}, {385.41799999999995`, 328.10900000000004`}}}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{388.89799999999997`,
                339.57399999999996`}, {385.578, 342.19899999999996`}, {
               382.477, 341.07399999999996`}, {380.941, 336.152}, {
               379.40999999999997`, 331.23400000000004`}, {381.02, 327.562}, {
               385.41799999999995`, 328.109}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{394.42999999999995`,
                348.914}, {391.566, 352.03499999999997`}, {388.328, 
               351.42199999999997`}, {386.02299999999997`, 346.812}, {
               383.72299999999996`, 342.203}, {384.72299999999996`, 338.32}, {
               389.156, 338.15200000000004`}}}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{394.42999999999995`,
                348.914}, {391.566, 352.03499999999997`}, {388.328, 
               351.422}, {386.02299999999997`, 346.812}, {383.72299999999996`,
                342.203}, {384.72299999999996`, 338.32}, {389.156, 338.152}}},
               
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{390.805, 303.527}, {
               385.90999999999997`, 301.727}, {385.395, 295.027}, {
               388.48799999999994`, 290.90599999999995`}, {391.578, 
               286.78499999999997`}, {397.242, 286.012}, {400.332, 
               290.90599999999995`}}}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{390.805, 
               303.52700000000004`}, {385.90999999999997`, 
               301.72700000000003`}, {385.395, 295.02700000000004`}, {
               388.48799999999994`, 290.906}, {391.578, 286.785}, {397.242, 
               286.01199999999994`}, {400.332, 290.906}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{385.137, 317.695}, {380.5, 319.23799999999994`}, {
               376.324, 313.012}, {375.605, 307.39099999999996`}, {374.707, 
               300.309}, {364.66, 297.99199999999996`}, {370.199, 287.301}, {
               371.355, 294.125}, {375.867, 297.85900000000004`}, {379.469, 
               298.117}, {383.078, 298.375}, {388.48799999999994`, 299.148}, {
               390.805, 303.527}}}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{385.137, 317.695}, {380.5, 319.238}, {376.324, 
               313.01199999999994`}, {375.605, 307.391}, {374.707, 
               300.30899999999997`}, {364.66, 297.99199999999996`}, {370.199, 
               287.30100000000004`}, {371.355, 294.125}, {375.867, 
               297.85900000000004`}, {379.469, 298.11699999999996`}, {383.078,
                298.375}, {388.48799999999994`, 299.14799999999997`}, {
               390.805, 303.52700000000004`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{399.82, 290.133}, {
               394.40999999999997`, 288.848}, {393.637, 281.633}, {397.5, 
               276.484}, {400.805, 272.074}, {411.148, 273.137}, {410.895, 
               277.512}}}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{399.82, 290.133}, {
               394.40999999999997`, 288.84799999999996`}, {393.637, 
               281.633}, {397.5, 276.48400000000004`}, {400.805, 
               272.07399999999996`}, {411.148, 273.137}, {410.895, 
               277.51199999999994`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}}}, {{{415.14500000000004`, 246.73399999999998`}, {
               415.39799999999997`, 251.371}, {407.93399999999997`, 
               253.172}, {404.328, 252.27299999999997`}, {400.719, 251.371}, {
               393.828, 252.40200000000002`}, {392.219, 
               256.26599999999996`}, {390.93399999999997`, 253.172}, {392.801,
                249.824}, {398.01599999999996`, 248.15200000000002`}, {
               401.965, 246.883}, {401.879, 244.031}, {400.719, 242.742}, {
               403.684, 242.227}, {412.441, 242.227}, {415.14500000000004`, 
               246.73399999999998`}}}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}}}, {{{415.14500000000004`, 246.734}, {
               415.39799999999997`, 251.371}, {407.93399999999997`, 
               253.17199999999997`}, {404.328, 252.273}, {400.719, 251.371}, {
               393.828, 252.402}, {392.219, 256.266}, {390.93399999999997`, 
               253.17199999999997`}, {392.801, 249.824}, {398.01599999999996`,
                248.152}, {401.965, 246.883}, {401.879, 244.031}, {400.719, 
               242.742}, {403.684, 242.22700000000003`}, {412.441, 
               242.22700000000003`}, {415.14500000000004`, 246.734}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{410.895, 276.355}, {405.613, 278.672}, {402.484, 
               275.141}, {400.465, 271.719}, {397.5, 266.695}, {388.355, 
               273.137}, {385.26599999999996`, 266.43799999999993`}, {389.453,
                268.242}, {393.715, 264.395}, {395.695, 263.09}, {401.363, 
               259.355}, {412.309, 260.51599999999996`}, {413.855, 
               269.27299999999997`}}}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{410.895, 276.355}, {405.613, 278.67199999999997`}, {
               402.484, 275.14099999999996`}, {400.465, 271.719}, {397.5, 
               266.695}, {388.355, 273.137}, {385.26599999999996`, 266.438}, {
               389.453, 268.24199999999996`}, {393.715, 264.395}, {395.695, 
               263.09000000000003`}, {401.363, 259.355}, {412.309, 
               260.51599999999996`}, {413.855, 269.273}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{413.984, 
               270.172}, {408.703, 266.18}, {406.64500000000004`, 261.414}, {
               406.77299999999997`, 258.195}, {406.902, 254.977}, {
               411.40999999999997`, 247.895}, {416.305, 247.508}, {419.137, 
               253.30100000000002`}, {420.555, 265.53499999999997`}, {413.984,
                270.172}}}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{413.984, 
               270.17199999999997`}, {408.703, 266.17999999999995`}, {
               406.64500000000004`, 261.414}, {406.77299999999997`, 
               258.195}, {406.902, 254.977}, {411.40999999999997`, 247.895}, {
               416.305, 247.50799999999998`}, {419.137, 
               253.30100000000002`}, {420.555, 265.53499999999997`}, {413.984,
                270.17199999999997`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{392.094, 245.316}, {
               392.094, 247.25}, {394.92599999999993`, 248.023}, {396.855, 
               247.379}, {398.789, 246.73399999999998`}, {401.75, 244.805}, {
               400.719, 242.742}}}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{392.094, 245.316}, {
               392.094, 247.25}, {394.92599999999993`, 248.023}, {396.855, 
               247.379}, {398.789, 246.734}, {401.75, 244.805}, {400.719, 
               242.742}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{362.98799999999994`,
                255.879}, {362.47299999999996`, 258.195}, {366.207, 
               262.188}, {371.22999999999996`, 260.}, {376.25, 257.809}, {
               376.895, 253.559}, {374.832, 251.88700000000003`}}}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{362.98799999999994`,
                255.879}, {362.47299999999996`, 258.195}, {366.207, 
               262.188}, {371.22999999999996`, 260.}, {376.25, 
               257.80899999999997`}, {376.895, 253.559}, {374.832, 
               251.88700000000003`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{375.219, 251.629}, {
               374.832, 252.918}, {378.449, 255.48800000000003`}, {384.621, 
               253.945}, {390.805, 252.40200000000002`}, {392.32, 
               248.42200000000003`}, {392.094, 245.316}}}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{375.219, 251.629}, {
               374.832, 252.91799999999998`}, {378.449, 255.488}, {384.621, 
               253.945}, {390.805, 252.402}, {392.32, 248.422}, {392.094, 
               245.316}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}}}, {{{362.34400000000005`, 255.879}, {365.562, 
               258.324}, {364.34400000000005`, 262.96099999999996`}, {361.441,
                264.379}, {356.16, 266.953}, {358.094, 273.648}, {354.742, 
               274.93799999999993`}, {351.395, 276.227}, {348.176, 278.543}, {
               348.047, 280.863}, {346.371, 277.64500000000004`}, {347.402, 
               274.68}, {349.72299999999996`, 272.621}, {352.039, 270.559}, {
               347.91799999999995`, 262.188}, {350.879, 260.}}}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}}}, {{{362.34400000000005`, 255.879}, {365.562, 
               258.324}, {364.34400000000005`, 262.961}, {361.441, 264.379}, {
               356.16, 266.953}, {358.094, 273.64799999999997`}, {354.742, 
               274.938}, {351.395, 276.22700000000003`}, {348.176, 278.543}, {
               348.047, 280.863}, {346.371, 277.645}, {347.402, 
               274.67999999999995`}, {349.72299999999996`, 272.621}, {352.039,
                270.55899999999997`}, {347.91799999999995`, 262.188}, {
               350.879, 260.}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{293.316, 257.68}, {
               290.60900000000004`, 261.92999999999995`}, {284.172, 261.16}, {
               281.469, 258.195}, {278.762, 255.23399999999998`}, {279.148, 
               250.85500000000002`}, {281.72299999999996`, 
               248.92600000000002`}}}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{293.316, 
               257.67999999999995`}, {290.60900000000004`, 261.93}, {284.172, 
               261.15999999999997`}, {281.469, 258.195}, {278.762, 255.234}, {
               279.148, 250.85500000000002`}, {281.72299999999996`, 
               248.92600000000002`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{308.77, 
               263.99199999999996`}, {307.73799999999994`, 269.656}, {300.914,
                270.301}, {297.18, 268.887}, {293.445, 267.469}, {290.867, 
               261.801}, {293.316, 257.68}}}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{308.77, 
               263.99199999999996`}, {307.73799999999994`, 269.656}, {300.914,
                270.30100000000004`}, {297.18, 268.88700000000006`}, {293.445,
                267.469}, {290.867, 261.80100000000004`}, {293.316, 
               257.67999999999995`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{319.07, 264.76599999999996`}, {321.52, 269.527}, {
               316.754, 276.613}, {311.34400000000005`, 
               277.64500000000004`}, {306.828, 278.5}, {301.49199999999996`, 
               278.47999999999996`}, {299.754, 282.92199999999997`}, {298.66, 
               279.059}, {301.559, 276.613}, {304.90599999999995`, 
               274.42199999999997`}, {308.254, 272.234}, {304.262, 266.566}, {
               309.672, 263.348}}}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{319.07, 264.766}, {321.52, 269.52700000000004`}, {
               316.754, 276.61299999999994`}, {311.34400000000005`, 
               277.645}, {306.828, 278.5}, {301.49199999999996`, 278.48}, {
               299.754, 282.922}, {298.66, 279.05899999999997`}, {301.559, 
               276.61299999999994`}, {304.90599999999995`, 274.422}, {308.254,
                272.23400000000004`}, {304.262, 266.56600000000003`}, {
               309.672, 263.34799999999996`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{318.555, 
               264.60200000000003`}, {317.42999999999995`, 268.012}, {319.715,
                272.555}, {324.34400000000005`, 272.23799999999994`}, {
               328.969, 271.91799999999995`}, {331.605, 268.555}, {329.566, 
               264.35200000000003`}}}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{318.555, 264.602}, {
               317.42999999999995`, 268.01199999999994`}, {319.715, 
               272.555}, {324.34400000000005`, 272.238}, {328.969, 271.918}, {
               331.605, 268.555}, {329.566, 264.352}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{328.85900000000004`,
                264.34400000000005`}, {328.22299999999996`, 267.879}, {
               331.121, 272.055}, {335.66, 271.09}, {340.195, 270.125}, {
               342.332, 266.42599999999993`}, {339.727, 262.551}}}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{328.85900000000004`,
                264.344}, {328.22299999999996`, 267.879}, {331.121, 
               272.055}, {335.66, 271.09000000000003`}, {340.195, 270.125}, {
               342.332, 266.42600000000004`}, {339.727, 262.55100000000004`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{339.08599999999996`,
                262.719}, {338.625, 266.28099999999995`}, {341.734, 
               270.309}, {346.215, 269.117}, {350.699, 267.92999999999995`}, {
               352.648, 264.125}, {349.85200000000003`, 260.387}}}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{339.08599999999996`,
                262.719}, {338.625, 266.28100000000006`}, {341.734, 
               270.30899999999997`}, {346.215, 269.11699999999996`}, {350.699,
                267.93}, {352.648, 264.125}, {349.85200000000003`, 
               260.38700000000006`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{261.375, 
               203.72299999999998`}, {252.75, 203.72299999999998`}, {250.641, 
               201.668}, {249.39800000000002`, 192.77299999999997`}, {
               247.85500000000002`, 181.69899999999998`}, {
               262.92199999999997`, 180.41}, {261.375, 
               203.72299999999998`}}}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{261.375, 203.723}, {
               252.75, 203.723}, {250.641, 201.668}, {249.39800000000002`, 
               192.77300000000002`}, {247.85500000000002`, 181.699}, {
               262.92199999999997`, 180.41000000000003`}, {261.375, 203.723}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{265.242, 
               215.312}, {251.977, 220.336}, {244.766, 199.344}, {231.629, 
               203.078}, {236.32800000000003`, 195.60899999999998`}, {
               247.72299999999998`, 203.062}, {251.977, 202.305}, {259.188, 
               201.016}, {274.77, 203.72299999999998`}, {265.242, 
               215.312}}}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{265.242, 
               215.312}, {251.977, 220.33599999999996`}, {244.766, 199.344}, {
               231.629, 203.07800000000003`}, {236.32800000000003`, 
               195.60900000000004`}, {247.72299999999998`, 
               203.06200000000007`}, {251.977, 202.305}, {259.188, 
               201.01600000000002`}, {274.77, 203.723}, {265.242, 215.312}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{256.613, 186.594}, {
               250.04299999999998`, 189.555}, {242.961, 179.512}, {244.25, 
               175.13299999999998`}, {245.883, 169.57}, {260.863, 174.102}, {
               256.613, 186.594}}}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{256.613, 
               186.59400000000005`}, {250.04299999999998`, 189.555}, {242.961,
                179.51200000000006`}, {244.25, 175.13299999999998`}, {245.883,
                169.57000000000005`}, {260.863, 174.10200000000003`}, {
               256.613, 186.59400000000005`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 
               3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
               1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, CompressedData["
1:eJxlVGlIVFEUniwqF2pS2y1arIwQkwhR0U5URGU12aAzzvbefbOmY2ISpmaI
rahZZAuUie2E9MNKSsxKBlFplUJFzGwTNQmVLIuod+cbJqiBx51z37nf+c73
nfsWst2JlvEKhWKc/GyXHx/5OZceWPgoPo382y5nxPWLtCxyclVIdRptiTq2
VmgWyY/vxzuptOFrmP6ISBFdoRMLljipvmJORNcNgR7yNcBJnWP5u+rKTFRy
Vga0p9K6orTen756SuA4gw7st+uAl2mnjy8WdY5d03nq2mgbU2qigzWUESdn
XLFSdfmX641BWpLZtVS+tiH/8N/484578w/F6pHvstP+NauNtdMMlGk/OZg3
004rOc8SA/jV2Ygf25CfQoN5cuIbqzeOudO0t/63xRu78cosVDPy61X2/WTE
B81kqN0U4DPgibMkmn5rY09OiIYU/KeRwL9YTSEp5tjuKJF6coJvbSxQUxXf
iDAh3qemuVzA5ToK5uerVPQg69SsCTVaUr+/et6lSqTRMH1pQ5ceeK5E6LDY
iLVQTW6/fATUzUiCX4dFrz5GzjNWgh+hGjrBfXsuoX5PCvLnS/BhWEu87AIV
o0/8fL72Pzx3v0cF6HFSS5Ub5H8fjOjLlASeVXr43ZyMfkYNtGRiwel1I8l4
/8STf0CD/SAB+X1azIVLgF8GHeo1iYidHr5nGHTr01HSlPDq8jaJWjndGCP8
GzBTdt/SyMkJevS9wIp5iDRhvlosdGRGx7NvhSa8V1roJT+/2UTR/LxkJj42
a04biYcVNRJwuw3Qp53BH6UJugUyb3233isY3Rxq3cqUAvr5LgHfz0SXuF6z
LMAPF+guxzda4WO/QMd5fpoNutwW0G+6HfsXBMzzJBvwLgrwM9cKnGER811s
pmSuS6mIOncl8DB77quvBH73GOqsYrSUr/4M9zyaoY8iRuu5L7MlrEMMeinM
uDd7GfTvNYP/DxF+rbeAzzsG3aba6NCAfEEfi7j/T20UxC/YJpFy+RgGOrz1
3fq8ddAeTrzI871pdJDs1s73HSLqq/7mu/1ptOOcgqHfeQ7Pd8vDb0sq8M4z
+vf79gfoVTIT
               "]]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 
               3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
               1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, CompressedData["
1:eJxlVGlIVGEUnSzalDKLsjJps4wQk4gyKU+kRWk1meiMs733vVnVMYmISrFC
s0JbJK2gjfZ+DP0wExNbGcSijSiyxbIFSs2ipJ2od98dRqiBx5v7vbuce869
3wSxOsPRV6fT9VGfFeoToj4HCiJKr87Px+BHJwrndcqYmjDQF1Wbj/TZOxZI
N2Q+n+/FnutfYs3bZMS3Te6/JcaLq0fHxLedlXCF3mFePPtRkttUbcPO/WpC
dx5Qkf/21yAz5+n2oJLOW02cb40b7+5NfPrjtAmhWl0X0kW4IXGEAYXzVI+T
TtQd/nimebgRKrqbxx662L+8136/siF6a5KZ/f1ubE6eZW0cZsEad1V38Sg3
ZhDOnRbG1+RCmRqWWpKD7mLV8bkzaM+ta1l3+Y8jaGv5qh2o6/n9YP3FbLbL
7JAal4SFdAXstQpGnFv8cmOUATr6GRTGX5mJqBx70ovZMt5sVD22ZMJHB/E2
tJO9IRNjicBpJo736XFp7d7IfvVGGF6fOujXZ+BrrHn39TYz9JTPn4Fa4mGS
lfkozYSmV4jEdQuzWK9yOciPlXAmKWgnPSYbWLe7CuN5mcP+0QrCiPfPRlDZ
8XrB8SXG//Jp/W6X0EB8VBlxLLW+5/cbK/dly8Jywukzs943srmfrxao7Ncs
7Mnm77cC/psMiKHz4RL7dxh5XvwS62Uxcb0WmW1vAO8+gUjircOErCFxtYcf
KXhAcOdaWb8uO9Z3TEkYmG7GU+p7vJPnIcHG83XTgcqRj+98K7Xx93AHxy+1
IZHiFTtobJJrVJ5V82i9gjn054WF+WkVrE+4jec3QgTra3xPF/B9ur9MhEvc
z/cAvsE2HCe+Ih3IpfxxEi5QfqsT+0jHTgm7yD/fhSnEy3mJ+y1w874cknie
B7igyXNEYj2LnKinPJ9lnu9KO/OyW+Y+Ligcbw/s6yCF8TUI5n+mYH1CBdJo
PxMF91EhkEK6jFawiN6fBPOls+MD7c06wXXe2hn/T5n1SnEwnleC9RjqQnmX
uqDXZN7/2y7e2yUyimgMIzzB+ho/7R7usyJw3zR78OTOt1WvH8tcX9/rr+nT
7OY4neB+x3kQq91bAXxpeZzvoMC/99tff9QyQQ==
               "],
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
               237.42200000000003`, 151.691}, {231.758, 156.07}, {
               223.90200000000002`, 150.789}, {218.49200000000002`, 
               152.85200000000003`}, {218.49200000000002`, 
               149.24599999999998`}, {220.297, 143.836}, {226.21899999999997`,
                141.777}, {228.023, 143.062}, {236.137, 150.148}, {
               237.42200000000003`, 151.691}}}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
               237.42200000000003`, 151.69099999999997`}, {231.758, 
               156.07000000000005`}, {223.90200000000002`, 
               150.78900000000004`}, {218.49200000000002`, 
               152.85199999999998`}, {218.49200000000002`, 
               149.24599999999998`}, {220.297, 143.83599999999996`}, {
               226.21899999999997`, 141.77700000000004`}, {228.023, 
               143.06200000000007`}, {236.137, 150.14799999999997`}, {
               237.42200000000003`, 151.69099999999997`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{246.309, 164.184}, {
               237.42200000000003`, 168.691}, {235.879, 
               157.48800000000003`}, {228.92200000000003`, 159.805}, {229.18, 
               156.586}, {231.758, 152.594}, {237.42200000000003`, 
               151.691}}}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{246.309, 
               164.18400000000003`}, {237.42200000000003`, 
               168.69099999999997`}, {235.879, 157.488}, {228.92200000000003`,
                159.805}, {229.18, 156.586}, {231.758, 152.59400000000005`}, {
               237.42200000000003`, 151.69099999999997`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{251.59, 174.359}, {
               238.453, 179.512}, {236.777, 166.89100000000002`}, {
               229.05100000000002`, 169.336}, {230.85500000000002`, 
               164.95700000000002`}, {241.93, 162.641}, {247.598, 
               164.184}}}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{251.59, 
               174.35899999999998`}, {238.453, 179.51200000000006`}, {236.777,
                166.89099999999996`}, {229.05100000000002`, 
               169.33599999999996`}, {230.85500000000002`, 164.957}, {241.93, 
               162.64099999999996`}, {247.598, 164.18400000000003`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{269.617, 229.605}, {
               266.141, 234.5}, {258.801, 230.508}, {257.641, 
               224.71099999999998`}, {256.484, 218.918}, {259.316, 210.805}, {
               264.21099999999996`, 212.605}}}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{269.617, 229.605}, {
               266.141, 234.5}, {258.801, 230.50799999999998`}, {257.641, 
               224.711}, {256.484, 218.918}, {259.316, 210.805}, {
               264.21099999999996`, 212.60500000000002`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{278.504, 245.062}, {
               272.453, 246.477}, {265.4959999999999, 245.83200000000002`}, {
               266.27, 239.91}, {263.953, 238.879}, {263.309, 231.281}, {
               269.617, 229.605}}}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{278.504, 
               245.06199999999998`}, {272.453, 246.477}, {265.4959999999999, 
               245.832}, {266.27, 239.91}, {263.953, 238.879}, {263.309, 
               231.28100000000003`}, {269.617, 229.605}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{282.4959999999999, 249.05100000000002`}, {276.574, 
               256.008}, {269.965, 255.844}, {266.27, 252.918}, {259.445, 
               247.508}, {252.812, 250.598}, {252.621, 245.18800000000002`}, {
               256.742, 248.344}, {260.348, 244.547}, {263.695, 
               245.70299999999997`}, {267.043, 246.863}, {269.49199999999996`,
                240.42600000000002`}, {278.762, 243.129}}}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{282.4959999999999, 249.05100000000002`}, {276.574, 
               256.008}, {269.965, 255.844}, {266.27, 252.91799999999998`}, {
               259.445, 247.50799999999998`}, {252.812, 
               250.59799999999998`}, {252.621, 245.188}, {256.742, 248.344}, {
               260.348, 244.547}, {263.695, 245.703}, {267.043, 246.863}, {
               269.49199999999996`, 240.42600000000002`}, {278.762, 243.129}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{268.203, 
               145.125}, {269.105, 143.44899999999998`}, {274.641, 142.676}, {
               277.348, 145.512}, {280.92999999999995`, 149.266}, {
               276.96099999999996`, 159.676}, {271.29299999999995`, 
               160.44899999999998`}, {265.625, 161.22299999999998`}, {265.113,
                148.73}, {268.203, 145.125}}}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{268.203, 
               145.125}, {269.105, 143.449}, {274.641, 142.676}, {277.348, 
               145.51200000000006`}, {280.92999999999995`, 
               149.26600000000002`}, {276.96099999999996`, 159.676}, {
               271.29299999999995`, 160.449}, {265.625, 161.223}, {265.113, 
               148.73000000000002`}, {268.203, 145.125}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{261.762, 
               144.86700000000002`}, {269.875, 141.906}, {273.355, 148.602}, {
               268.977, 152.85200000000003`}, {267.816, 151.434}, {263.566, 
               146.285}, {261.762, 144.86700000000002`}}}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{261.762, 
               144.86700000000002`}, {269.875, 141.906}, {273.355, 
               148.60200000000003`}, {268.977, 152.85199999999998`}, {267.816,
                151.43400000000003`}, {263.566, 146.28500000000003`}, {
               261.762, 144.86700000000002`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYCYtmoFOv7r3McvM07HRN2Jji8q7E3jduV47DI
ddvnvyoJDtUi69wf7sp2OA5SwAOVn5XlYHBXha2xNsbBpTvn+e/KTAeu64sL
bB9FONw89z34cWqGwzeNmP5DqVEOVltOlO2Tz3CI3eXJw/Q6HK7+TeAOuVbp
KIi6ziyHNTJAhyyPcGAAgYhsh5DHS2cfuRDlkDHxbY39xBwHoGuuVEjGOTgl
PL2gNDkXIr8g1mH1x0u+STx5DkDTtduvxUP9kefgCFJXn+gAMvb+9QKHKpA/
yhId7vv3Ts97U+CgD3L/x2QHoCkKG3IKHOJA7lNOcRBuPnBq4cZcuHr08AEA
nyiJLw==
               "]]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYCYtmoFOv7r3McfMw7HRN2Jji8q7E3jduV47DA
ddvnvyoJDtUi69wf7sp2OOYNVMADlZ+V5WBwV4WtsTbGwaU75/nvykwHnuuL
C2wfRTjcPPc9+HFqhsMPjZj+Q6lRDlZbTpTtk89wSNjlycP0Ohyu/k3gDrlW
6SiHbyB1nVkOa2SADlke4cAAAhHZDhGPl84+ciHKIWPi2xr7iTkOWz7/vVIh
GefglPD0gtLkXIj8gliH1R8v+Sbx5Dl48DBpt1+Ld/AG+yMPoq4+0QFk7P3r
BQ41IH+UJTrc9++dnvemAOL+j8kOQFMUNuQUQNynnOIg3Hzg1MKNuXD16OED
AKdgiUI=
               "],
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{434.59, 328.512}, {444.895, 325.16400000000004`}, {
               445.148, 311.77}, {456.9959999999999, 307.39099999999996`}, {
               468.848, 303.012}, {470.008, 292.453}, {479.66400000000004`, 
               295.027}, {470.648, 297.477}, {471.29299999999995`, 
               307.90599999999995`}, {461.895, 310.47999999999996`}, {450.867,
                313.504}, {446.695, 330.316}, {437.93799999999993`, 
               332.89099999999996`}}}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{434.59, 328.51199999999994`}, {444.895, 325.164}, {
               445.148, 311.77}, {456.9959999999999, 307.391}, {468.848, 
               303.01199999999994`}, {470.008, 292.453}, {479.66400000000004`,
                295.02700000000004`}, {470.648, 297.477}, {
               471.29299999999995`, 307.906}, {461.895, 310.48}, {450.867, 
               313.504}, {446.695, 330.31600000000003`}, {437.93799999999993`,
                332.891}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC0c0HTi2UrXOISrG+769Z4HBR6fbPOqs6hxl5
Qs0HzuU7vK2xN40zq3OQBSl4nOfgbd7pmHC+1mFvyWQJlmV5DrG7PHmY2Osc
GEAgASofWefg0p3z/PfCPIels48obGirc3gHMscq32EZiO9U5wC2lzfP4dMl
3ySBAij/b45D+b75Uvq3oeadyHFwf1glsm55nYO6IccamVm5DkBbw/ik6x1a
XwfukPubC1H3rQ7Cb82D8K3qHSYc+qoR453nYLXlRNm+0nqHm+e+Bz+emAsx
r7ge4k+5XAegpteBZ+odVn0EOuRJLkS9Yb3DY5DD3+Q5gLjz/eod9O+qsDUu
zXcAAC1GhAA=
               "]]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC0c0HTi2UrXOISrG+769Z4HBR6fbPOqs6hxl5
Qs0HzuU7vK2xN40zq3OQBSl4nOfgbd7pmHC+1mFPyWQJlmV5DrG7PHmY2Osc
GEAgASofWefg3J3z/PfCPIels48obGirc3gHMscq32EZiO9U5wC2lzfP4dMl
3ySBAij/b45D+b75Uvq3oeadyHFwf1glsm55nYO6IccamVm5DkBbw/ik6x1a
XwfukPubC1H3rQ7Cb82D8K3qHSYc+qoR453nYLXlRNm+0nqHm+e+Bz+emAsx
r7ge4k+5XAegpteBZ+odVn0EOuRJLkS9Yb3DY5DD3+Q5gLjz/eod9O6qsDUu
zXcAACtug/0=
               "],
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIxIGYC4p1yra8DP1U6rP54yTeJJ8MhKsX6vn9vpYNw
84FTC/dmOBz3Nu90TKp0UDfkWCNzL93h0FeNmH6DSocJIIY2VJ6p0qEoY+Lb
muIMB6Dm6XlHKhy+AZUdqs1wmJ4n1HxgTYWDEMg8U6j5zJUOxSD1+hkOi1y3
ff57o8JB/64KW+PKdIfc579XfmyodOgFaexIh8vfPPc9+HFhugOv7qa5779X
OFSLrHN/+CsVYm57hYMP0BkJvGkOQN/skPtf4TADZK9WKsQ8m0qHfpB7r6c5
aLeL3Tw3t9IBZL39xDS4fbd/1mXtaYDqP13pcAvE/wE1fzrUf86pDpMlWML4
Xlc6hPEBHeIO5fNWOQBNM43TS3Ow5bq+uEC8CuLepWkOAJL2qh0=
               "]]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIxIGYC4p1yra8DP1U6rPp4yTeJJ8MhKsX6vn9vpYNQ
84FTC/dmOBz3Nu90TKp0UDPkWCNzL93h0FeNmH6DSoc+EEMbKs9U6VCSMfFt
TXGGA1Dz9LwjFQ7fgMoO1WY4TM8DmrSmAmKeKdR8Zqh6/QyHRa7bPv+9UeFg
cFeFrXFlukPu898rPzYAzQdp7EiHy9869z34cWG6A6/uprnvv1c4VImsc3/4
KxVibnuFgw/QGQm8aQ5A3+yQ+1/hMA1kr1YqxDybSocJIPdeT3PQbhe7eW5u
pUMW0Hr7iWlw++78rMva0wDVfxrK/wE1fzrUvc6pDpMlWML4Xlc6hPEBHeIO
5fNWObyrsTeN00tzsOW6vrhAvAri3qVpDgCTRqol
               "],
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIlIGYC4rhdnjxMzoUOMlEp1vfbExxkQbRsoYNQ84FT
C48mOMzIA7I2FThsPVG2b/6jBAeFDUUZEzsLHFpfB+6Q25jgsEMOyEoocAjn
0900tz7BYTpIfV6Bgypb41Tn4gSHqxUv1QwXFDiA7clOcPB4WCWy7mIBxNyk
BAf9uypsjYKFELo13uFtjb1p3LICh01z3y8/VhzvkPv898qPJQUOIOtas+Md
7LiuLy5oLXAwAKnvjYWolytwEFnn/rAqJ9ZhC8idHgUOIOe7zotxKN83X0r/
YIED0HbtdrVYh/v+vdPz3hQ4SIMs5IyDuO9JgUNxxsS3Nf6xDgwgoFQIUb8s
xgEUHP6chQ7/QeB4tIMiyP+hhQ5PLyjd/rks2gGkzV6z0AHkLFujOAcrkAMW
FjqAvOkuGAcJn4JCh15QwPyIhfinpdDhDcg/1jEOtiCNtwsdnoHMWxfjwKsL
8nmhA8hZHD4xkHA6VOiwyHXb578x0RD3/4G6b1q0g7d5p2PC9UKIO1KjIeF8
utDBEuSO5VEOIGPr/hU6iILCxyYKYr5+ESS8fKIh7vtRCAkPyXgH9PQAANOF
8IM=
               "]]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIlIGYC4rhdnjxMzoUOMlEp1vfbExxkQbRsoYNQ84FT
C48mOMzIA7I2FThsO1G2b/6jBAeFDUUZEzsLHNpeB+6Q25jgsEOu9XVgQoFD
GJ/uprn1CQ7TQerzChzU2BqnOhcnOFyteKlmuKDAAWxPdoKDx8MqkXUXCyDm
JiU46N9VYWsULHQwANGt8Q5va+xN45YVOGyZ+375seJ4h9znv1d+LClweAO0
rjU73sGO6/rigtYCiPreWIh6uQIHkXXuD6tyYh22gNzpUeDQAnS+67wYh/J9
86X0DxY4+PAwaberxTrc9++dnvemwEECZDFnHMR9TwocSjImvq3xj3VgAAGl
Qoj6ZTEOoODw5yyEiJ+IdlAE+T+00OHFBaXbP5dFO4C02WsWOvAAnWVrFOdg
BXLAwkKHJ0BvugvGQcKnoNChBxQwP2Ih/mkphPjHOsbBFuSf21Dz1sU48AKD
8f3yQgeQszh8YiDhdKjQYYHrts9/Y6Ih7v9T6OABct+0aAdv807HhOuFDjkg
d6RGQ8L5dKGDBcgdy6McQMbW/SuEhI9NFMR8/SII3yca4r4fhZDwkIx3QE8P
ACEa65k=
               "],
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{556.676, 274.34400000000005`}, {566.535, 
               274.34400000000005`}, {574.523, 282.33599999999996`}, {574.523,
                292.195}, {574.523, 302.051}, {566.535, 310.043}, {556.676, 
               310.043}, {546.8159999999999, 310.043}, {538.828, 302.051}, {
               538.828, 292.195}, {538.828, 282.33599999999996`}, {
               546.8159999999999, 274.34400000000005`}, {556.676, 
               274.34400000000005`}}}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{556.676, 274.344}, {566.535, 274.344}, {574.523, 
               282.336}, {574.523, 292.195}, {574.523, 302.05100000000004`}, {
               566.535, 310.043}, {556.676, 310.043}, {546.8159999999999, 
               310.043}, {538.828, 302.05100000000004`}, {538.828, 292.195}, {
               538.828, 282.336}, {546.8159999999999, 274.344}, {556.676, 
               274.344}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 
               3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
               1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxdVGtIVEEUXm2RMBULDZMwrYiebAUVKtrZLNRKtASTKBHJksX23rm+3Ycz
V9IkJETIIkwkM+yHbKYmUZuViPgj1AyJFN3ETMosIySix8w9lxVcGIbZmXPm
e82NypFO564yGAw+fCTz4cvH+SfJAb5Ldsirm7cfviVBlEvJq0txgPb/Jhni
/MfuysMO6D9xqMacJMPiSEpO8G4nTKXWNlj9Zbh3uy/SVeX01keK+kcV8Lwp
3DRhlKB6/bvXS1so2ELaEz0jEkyLAiuFoc3vfznTZChx84N1FPtWybjfQSHJ
Ux7SXibDxrMXYicHKZgmtvoxkww3resqez/p9QEytMgcYSCDnogrn0/56f02
MDiSPcOPSPCGt800M+Ao0qcfSlA2t23f6kwGglacWwKD+JUxOMnpZTdKWN/M
sH+/BJanhfVhLxgIGKk7ZHj5c/u564sM+YTLcCPhWv5spAr1YcaMoFxdr/0q
cDUOZI3KyP+iCq1CpyldP4sKb0s5kAyC/ZNVmBR6thAoFffvVIGjmRlyEexv
VuHy7O+271SBV+L+YQbRnQPF7jMK4vdRcY5Q8Pw4gy6+3fRA72/U8RURELIm
zjHvOjiTd+pniDeLAHd9V7WbIc4ggjgGGPpxjOA9zxj6YCE4dzHg6vdElBC4
Ks536/q1Evgg7lMZ4g9XsF8aQz2+EfSnkGF+PDq+bAZi8lgJ+lXOgN8y2JxA
oPvHn9HSSwxzZtb1SWeYVxNBfZKW8Wt+xjKI1wwnsFbwXbPcP3BPR+PCVwpZ
or5gea3lrZJgLuap1x+tfo4in079/nGK+n3U9R6hqEeUAgv3+csZo5jPfAV1
cVNoELod1P1qo5irLwSOC/0bKfJ5TKBPEC1esR9K8T3eIYhrqAL9qSEQI3JR
VOH1V9P7qNPrh/Ze/zq8+mtzjwPzHKPgeq8D85mnIE+XHfNfq6BPPnbk06tg
Dv/ZEActwHzE23DfWAhBQs9oG9aHFiCPFrv3+7Ly+/MfbnUMuQ==
               "]]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 
               3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
               1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxdVGtIFFEUXksizMSemIRpRfRkK6iwSL+lIu1BVmASJRI9TGxn7mil7q7e
O1JmESFFD8JCMsN+hJmVRC32wMQfoZskYaEmZVJZGRERPebsGVZo4TLcvXPO
+V53EnZpW/aMdDgcYdZKtdYIa+28lxo54ocX+ys+eZMvaEioM7IrNvqQSf9P
07EyovOK3u5D8/pl5a4UHUOBjbui5xeje9PJc+4IHVcvPomvO1ocqo+n+lsl
8F+Odb4O11A2+eWzHzMkPBNvrO0NaOijArdE+/Sun8VpOg7TixWS+x7V+bxe
IqW3aOKNQh1Tt+9e0d0q4Xw9c5Ry6jjvHl/a9F4iQPWROqp1C+FYhca4Ix82
j7L7TVFwZb1tm96l4bnVNsOlYKHY2ndTQ+HArEWjMxSI1kq/Bgf9ChWIXlal
xvVVivE1a8i5n3865qECwdg0R8ej77N3nBpSKCI+sTrOrjqR2x9v4kxMeHrU
HluvxSYGvclLMjt05r/XRA3p1GPrl2PiRYEFJF1w/1QTPaRntUABzZ9r4jgR
qBPc32Uit/9X7Vdp4DHNb1dY3tByyL/NYPxhJj/jDH7/lQIdX75u9w+38R0U
IFnXDqjQPjojsaGlWTHeTAHL9XllfsU4owTKCUeLYj/WCJ7zQOEc+ZAj2I/b
Cpb6jXGHBY7R+3ds/WoE3tA8UzH+WIP7pSnW44tgf/IVsik/vTa+LMV5cQv2
q0hhQmlTa9UqgTvffncU7FOcM5etz1bFeXUK1idlGH/QzxUKSUHDBcYR3zHD
/ccuqK/8PCi5Pm94H8xbqcAGysUnGfInWD8gmU+DPf+VZP3e2XoHJOuRYODz
NevmdErOZ66BNtLFL1m3pbZftZJxfxRYR/pX2njuCjwhoof+O58k8ZQCe0nw
PWwrYX/KBefiYEnI36Deq4tDfgTv6x9fSP/gs9HHeV5u8H6hDx2Uz2wDB4hn
nZfzf9Jgn8K8zKfJQCLN++thfWQe5yPJw+fh+YgiPRM9XD8pj+9PtTf0ffn/
+/MPmF0Mzg==
               "],
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{337.22999999999996`, 138.945}, {346.758, 138.945}, {
               354.48799999999994`, 146.672}, {354.48799999999994`, 
               156.19899999999998`}, {354.48799999999994`, 165.73}, {346.758, 
               173.45700000000002`}, {337.22999999999996`, 
               173.45700000000002`}, {327.699, 173.45700000000002`}, {
               319.97299999999996`, 165.73}, {319.97299999999996`, 
               156.19899999999998`}, {319.97299999999996`, 146.672}, {327.699,
                138.945}, {337.22999999999996`, 138.945}}}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{337.22999999999996`, 138.945}, {346.758, 138.945}, {
               354.48799999999994`, 146.67200000000003`}, {
               354.48799999999994`, 156.199}, {354.48799999999994`, 
               165.73000000000002`}, {346.758, 173.457}, {337.22999999999996`,
                173.457}, {327.699, 173.457}, {319.97299999999996`, 
               165.73000000000002`}, {319.97299999999996`, 156.199}, {
               319.97299999999996`, 146.67200000000003`}, {327.699, 
               138.945}, {337.22999999999996`, 138.945}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 
               3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, CompressedData["
1:eJxFUw1IFEEUvqykX4kKKSkpMZHLyIIQrcMvKiQsLAOJLGv3bnYv0bKdOY0K
SU6RECupSCiRCosiQsxMKs0yUgKlhAopM7Myy35UJESFdu4NtjAsb2bf976f
2eX64VQ21eFwTLGXy15B9qoPL/qx86SF2tbcxspgN+auqqn4fd/CzxOJ6zJy
dVw8NN/fFMpxT57n61i6x7O+28WR8WDrnKASHccW3knqyeBoEOcWTfugUX8L
x+aSrL6xHg3eMhtphGNFcMGFTX6NcCIESiVwpAZ7en14g8D70fzMRzEaPqbY
J98FzddV/xNBfZkaknrsiSUCDvlc1vD6aH/Umt3qfEij/TBB/NJ15DVWhq2O
E0iQAle66T1doLP9765enxunNh748tIpcGuwY7ve6sbVLXXDE7Gq3uFBudQf
rb4v8pC+FEF67nrInyyBbXE20oQHx6UfOQKvIt6N5kcwqmsF4TgZ+fxH4LFN
qyuHIVn2zfSR3usM3VJ/jI/88TDiU+gjPQ/Vea2PdCQzVF16tqy6UdXpBs3b
4CMfBgwE8v0qyMcyAzK+lGblb52BpyPRe88YAgv8TS+uVBjolYBpAi2SWJZB
ffGKb6HC/8ZJ31oDzuLQzvZmTufjiu8Ax+y313JcToP8H+aYJesag3z4xBEv
+fYak3kE9DpMwo8ROCuJ7Tcn8wj4W2XSXF3xOW+Sn7cF3cM3JuloU/qemxiy
Y5xXrvJI9cIliSQKusd+L+X3mSMtxA42z4t90udiTrqzvZP3O5BTv5qfyhEl
809XfMPU94tN8nsGJ50JBrL7xm4OLuE4LQcNMKrHLcL5xWD/NWkh3RaOSGLV
jPo6LNJRyojvDYv2axjtH7QQ2xUZXNDGKE/X//ofZNLBEA==
               "]]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 
               3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, CompressedData["
1:eJxFUw1IFEEUvqykwiQqpMSkREQuIwtCsg6/iJKwsAwksqzdu929RE125jRK
pFCRMCvpR6FEKiwCETEzKRPLMAkUEyoqzMzKLDN/kBAV2udbbGFY3sy89/3t
rlNPJmnzHQ7HPGu5rOVnrcbQwl8HzppoaM9urvR3Y+mGuoo/j0wM58ZtSc1W
UZa5PL8lSKCezvNUrDns2dbrEkh9vCfAr1jF6ZU18X2pAk3yyqoFnxTufymw
uzh9YKpPgbf0d27chECE/7lrO/MVPKQ5YRIXaHC4Agu9MfSpxIfJvLSmKAWf
E0vKMn9KjBC+avc/k4yfpiC+z0IslnDQc1PBm1ODEZsOSeY/pvB+sGR+KSpy
miuDN8ZIxNKA9W5+L7TwOv8e7Pe5cX7H8W9dTonq0e59arsbt3c1jM9E2/V+
D8pJf6R9v9DD+hIl63ngYX/SJfbGWJNmPDhDfmRJdId9nMwL07iul7hO95wa
6xiRaLFo9WRpSKC+xT72+66GXtIf5WN/PBrzKfCxnif2eb2PdSRoqLrxYm1t
s12n6Iy33cc+DOmYzfe7RBr5WKqD4ktslYzXoOP5ROSRS7qExe7VrQod/TQw
WaKNiKXr7P9WCbKxp8Ce/0Owvs06nEVB7ztbBeuZtvkOCSx5dyfL5dTZ/3GB
AKrrdPbzi2C+/fpcHhdJr8Pg+VESl4nYMWMuj1l/qwy8JlzV5nPVYD+rJXKp
762BFaSjw9bXZmDMinFZuZ1HkhcuIhYnEUJG5Hs5v68CyYFWsDleHCWfiwT7
leGd+75n8Qdt/CSBcMo/xeYbbN9fbbDfiwTnHasjY2Dq/miI4DyHNK6nTXTR
nGEN1l+THNhrwiRitRr7021yHiUa871n8n6dxvpOmIjusRh0aJyn63/9D4+S
wSA=
               "],
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{293.059, 
               181.441}, {291.89799999999997`, 184.789}, {293.43399999999997`,
                187.805}, {294.215, 190.45700000000002`}, {
               296.21099999999996`, 197.21899999999997`}, {
               294.98799999999994`, 198.95700000000002`}, {
               288.93799999999993`, 198.055}, {288.42199999999997`, 
               194.836}, {291.512, 184.27299999999997`}, {293.059, 
               181.441}}}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{293.059, 
               181.44099999999997`}, {291.89799999999997`, 
               184.78900000000004`}, {293.43399999999997`, 187.805}, {294.215,
                190.457}, {296.21099999999996`, 197.21900000000005`}, {
               294.98799999999994`, 198.957}, {288.93799999999993`, 
               198.055}, {288.42199999999997`, 194.83599999999996`}, {291.512,
                184.27300000000002`}, {293.059, 181.44099999999997`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{288.613, 
               197.668}, {290.16, 196.121}, {295.633, 195.414}, {
               296.21099999999996`, 200.309}, {296.879, 
               205.92600000000002`}, {294.60200000000003`, 208.102}, {289.707,
                205.91}, {289.324, 204.621}, {288.871, 199.344}, {288.613, 
               197.668}}}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{288.613, 
               197.668}, {290.16, 196.12099999999998`}, {295.633, 
               195.41400000000004`}, {296.21099999999996`, 
               200.30900000000003`}, {296.879, 205.926}, {294.60200000000003`,
                208.10200000000003`}, {289.707, 205.91000000000003`}, {
               289.324, 204.62099999999998`}, {288.871, 199.344}, {288.613, 
               197.668}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
               289.77299999999997`, 206.102}, {291.832, 205.266}, {296.277, 
               203.594}, {298.72299999999996`, 208.35500000000002`}, {300.777,
                212.35500000000002`}, {298.078, 215.441}, {293.832, 
               215.184}, {292.801, 214.023}, {290.73799999999994`, 
               209.90200000000002`}, {289.77299999999997`, 206.102}}}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
               289.77299999999997`, 206.10200000000003`}, {291.832, 
               205.26600000000002`}, {296.277, 203.59400000000005`}, {
               298.72299999999996`, 208.35499999999996`}, {300.777, 
               212.35499999999996`}, {298.078, 215.44099999999997`}, {293.832,
                215.18400000000003`}, {292.801, 214.02300000000002`}, {
               290.73799999999994`, 209.90200000000004`}, {
               289.77299999999997`, 206.10200000000003`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{293.574, 
               215.57}, {294.08599999999996`, 214.023}, {299.367, 208.871}, {
               303.22999999999996`, 212.605}, {307.094, 216.344}, {307.094, 
               221.879}, {301.301, 223.941}, {299.754, 223.684}, {295.117, 
               218.27299999999997`}, {293.574, 215.57}}}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{293.574, 
               215.57000000000005`}, {294.08599999999996`, 
               214.02300000000002`}, {299.367, 208.87099999999998`}, {
               303.22999999999996`, 212.60500000000002`}, {307.094, 
               216.344}, {307.094, 221.87900000000002`}, {301.301, 
               223.94099999999997`}, {299.754, 223.68400000000003`}, {295.117,
                218.27300000000002`}, {293.574, 215.57000000000005`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{301.301, 
               223.941}, {302.457, 220.71899999999997`}, {306.062, 215.184}, {
               312.762, 217.758}, {319.457, 220.336}, {316.625, 
               228.70299999999997`}, {313.53499999999997`, 230.379}, {
               311.72999999999996`, 230.25}, {304.39099999999996`, 
               226.90200000000002`}, {301.301, 223.941}}}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{301.301, 
               223.94099999999997`}, {302.457, 220.71900000000005`}, {306.062,
                215.18400000000003`}, {312.762, 217.75799999999998`}, {
               319.457, 220.33599999999996`}, {316.625, 228.703}, {
               313.53499999999997`, 230.379}, {311.72999999999996`, 230.25}, {
               304.39099999999996`, 226.902}, {301.301, 223.94099999999997`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
               313.53499999999997`, 230.379}, {313.02, 227.547}, {
               313.53499999999997`, 219.82000000000002`}, {322.676, 
               219.94899999999998`}, {331.82, 220.078}, {329.246, 230.766}, {
               326.92599999999993`, 232.312}, {323.191, 232.312}, {316.883, 
               232.184}, {313.53499999999997`, 230.379}}}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
               313.53499999999997`, 230.379}, {313.02, 227.547}, {
               313.53499999999997`, 219.82}, {322.676, 219.949}, {331.82, 
               220.07800000000003`}, {329.246, 230.76600000000002`}, {
               326.92599999999993`, 232.31199999999998`}, {323.191, 
               232.31199999999998`}, {316.883, 232.184}, {313.53499999999997`,
                230.379}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{327.312, 
               231.92600000000002`}, {326.28499999999997`, 
               229.73399999999998`}, {323.96099999999996`, 215.324}, {341.867,
                219.305}, {344.184, 219.82000000000002`}, {350.234, 
               233.08200000000002`}, {327.312, 231.92600000000002`}}}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{327.312, 
               231.92600000000002`}, {326.28499999999997`, 229.734}, {
               323.96099999999996`, 215.324}, {341.867, 219.305}, {344.184, 
               219.82}, {350.234, 233.082}, {327.312, 231.92600000000002`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{337.10200000000003`,
                230.637}, {335.301, 228.83200000000002`}, {
               339.93399999999997`, 214.281}, {352.039, 216.727}, {
               364.14500000000004`, 219.176}, {353.97299999999996`, 
               232.953}, {337.10200000000003`, 230.637}}}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{337.10200000000003`,
                230.637}, {335.301, 228.832}, {339.93399999999997`, 
               214.281}, {352.039, 216.72700000000003`}, {364.14500000000004`,
                219.176}, {353.97299999999996`, 232.953}, {
               337.10200000000003`, 230.637}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{347.402, 
               228.44899999999998`}, {345.47299999999996`, 
               224.45700000000002`}, {348.371, 212.605}, {363.309, 212.605}, {
               376.848, 212.605}, {362.60200000000003`, 228.191}, {347.402, 
               228.44899999999998`}}}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{347.402, 
               228.44899999999998`}, {345.47299999999996`, 
               224.45700000000002`}, {348.371, 212.60500000000002`}, {363.309,
                212.60500000000002`}, {376.848, 212.60500000000002`}, {
               362.60200000000003`, 228.191}, {347.402, 228.44899999999998`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{359.121, 224.969}, {
               358.15200000000004`, 222.758}, {356.965, 210.195}, {374.578, 
               209.129}, {387.328, 208.35500000000002`}, {384.23799999999994`,
                226.38700000000003`}, {359.121, 224.969}}}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{359.121, 224.969}, {
               358.15200000000004`, 222.75799999999998`}, {356.965, 
               210.195}, {374.578, 209.12900000000002`}, {387.328, 
               208.35499999999996`}, {384.23799999999994`, 
               226.38700000000003`}, {359.121, 224.969}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{378.055, 219.691}, {
               375.867, 215.82800000000003`}, {373.547, 206.168}, {392.863, 
               205.395}, {405.23799999999994`, 204.89800000000002`}, {397.629,
                219.434}, {378.055, 219.691}}}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{378.055, 
               219.69099999999997`}, {375.867, 215.82799999999997`}, {373.547,
                206.168}, {392.863, 205.39499999999998`}, {
               405.23799999999994`, 204.89799999999997`}, {397.629, 
               219.43400000000003`}, {378.055, 219.69099999999997`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
               394.15200000000004`, 216.727}, {391.32, 212.863}, {
               393.40599999999995`, 205.285}, {400.59, 203.85200000000003`}, {
               409.605, 202.047}, {410.895, 210.547}, {404.715, 214.668}, {
               398.53099999999995`, 218.789}, {394.15200000000004`, 
               216.727}, {394.15200000000004`, 216.727}}}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
               394.15200000000004`, 216.72700000000003`}, {391.32, 212.863}, {
               393.40599999999995`, 205.28500000000003`}, {400.59, 
               203.85199999999998`}, {409.605, 202.04700000000003`}, {410.895,
                210.54700000000003`}, {404.715, 214.668}, {
               398.53099999999995`, 218.78900000000004`}, {
               394.15200000000004`, 216.72700000000003`}, {
               394.15200000000004`, 216.72700000000003`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{402.90999999999997`,
                214.92600000000002`}, {400.85200000000003`, 
               211.32000000000002`}, {402.125, 202.562}, {415.78499999999997`,
                202.562}, {418.621, 202.562}, {429.441, 213.637}, {
               402.90999999999997`, 214.92600000000002`}}}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{402.90999999999997`,
                214.926}, {400.85200000000003`, 211.32}, {402.125, 
               202.56200000000007`}, {415.78499999999997`, 
               202.56200000000007`}, {418.621, 202.56200000000007`}, {429.441,
                213.637}, {402.90999999999997`, 214.926}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{297.184, 46.98}, {308.246, 46.98}, {317.219, 
               55.949}, {317.219, 67.012}, {317.219, 78.07799999999999}, {
               308.246, 87.051}, {297.184, 87.051}, {286.117, 87.051}, {
               277.148, 78.07799999999999}, {277.148, 67.012}, {277.148, 
               55.949}, {286.117, 46.98}, {297.184, 46.98}}}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{297.184, 46.98000000000002}, {308.246, 
               46.98000000000002}, {317.219, 55.94900000000001}, {317.219, 
               67.01200000000006}, {317.219, 78.07800000000003}, {308.246, 
               87.05099999999999}, {297.184, 87.05099999999999}, {286.117, 
               87.05099999999999}, {277.148, 78.07800000000003}, {277.148, 
               67.01200000000006}, {277.148, 55.94900000000001}, {286.117, 
               46.98000000000002}, {297.184, 46.98000000000002}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 
               3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
               1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 
               3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
               1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 
               3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
               1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 
               3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, CompressedData["
1:eJxdVwtQVFUYRjGnFJ0syyegZNb4ptREI38lI80H8lriJexe7j4k3Lv3LrLs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               "]]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 
               3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
               1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 
               3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
               1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 
               3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
               1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 
               3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, CompressedData["
1:eJxdVwlsVFUULRSNYjGiKIiUTYIGRUBB22rlAiKLIKXb1G5MZ37/LNQ6f5nS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               "],
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{515.8549999999999, 121.215}, {528.031, 121.215}, {
               537.898, 131.08200000000002`}, {537.898, 143.254}, {537.898, 
               155.42600000000002`}, {528.031, 165.297}, {515.8549999999999, 
               165.297}, {503.684, 165.297}, {493.812, 155.42600000000002`}, {
               493.812, 143.254}, {493.812, 131.08200000000002`}, {503.684, 
               121.215}, {515.8549999999999, 121.215}}}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{515.8549999999999, 121.21500000000003`}, {528.031, 
               121.21500000000003`}, {537.898, 131.08200000000005`}, {537.898,
                143.25400000000002`}, {537.898, 155.426}, {528.031, 
               165.29700000000003`}, {515.8549999999999, 
               165.29700000000003`}, {503.684, 165.29700000000003`}, {493.812,
                155.426}, {493.812, 143.25400000000002`}, {493.812, 
               131.08200000000005`}, {503.684, 121.21500000000003`}, {
               515.8549999999999, 121.21500000000003`}}},
               CurveClosed->{1}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{431.758, 337.27}, {
               426.863, 315.633}, {430.984, 305.84799999999996`}, {438.195, 
               296.31600000000003`}, {453.10200000000003`, 276.621}, {464.984,
                231.66799999999998`}, {447.984, 202.305}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{457.512, 227.676}, {459.574, 
               228.44899999999998`}, {463.43799999999993`, 230.895}, {
               464.34000000000003`, 235.14499999999998`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{459.059, 
               237.07399999999998`}, {459.703, 240.81199999999998`}, {
               465.4959999999999, 242.41799999999998`}, {465.625, 246.414}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{459.188, 251.629}, {458.801, 
               255.492}, {464.984, 258.969}, {464.078, 262.832}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{455.84000000000003`, 
               265.53499999999997`}, {455.324, 267.72700000000003`}, {
               460.98799999999994`, 271.84799999999996`}, {459.445, 275.324}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{451.59, 279.05899999999997`}, {
               450.42999999999995`, 281.508}, {454.29299999999995`, 
               284.34000000000003`}, {452.621, 286.914}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{445.40599999999995`, 
               289.875}, {445.02, 291.55100000000004`}, {447.402, 295.223}, {
               446.117, 297.40999999999997`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{439.227, 302.625}, {
               439.73799999999994`, 303.27}, {441.805, 304.81600000000003`}, {
               440.965, 306.746}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{434.977, 311.961}, {435.812, 
               312.414}, {438.324, 313.188}, {438.004, 315.055}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{306.062, 69.14499999999998}, {
               300.914, 70.945}, {294.47299999999996`, 68.37099999999998}, {
               293.188, 63.988}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{297.051, 60.}, {
               297.695, 64.375}, {304.39099999999996`, 66.30900000000003}, {
               306.449, 64.25}, {302.199, 66.56600000000003}, {300.141, 
               58.327999999999975`}, {303.875, 58.06600000000003}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{338.51599999999996`, 
               161.86700000000002`}, {335.42599999999993`, 160.32}, {334.527, 
               154.65599999999995`}, {338.51599999999996`, 
               150.40200000000004`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
               343.15200000000004`, 160.57800000000003`}, {340.965, 
               158.77700000000004`}, {341.094, 153.36700000000002`}, {344.312,
                152.07800000000003`}, {341.60900000000004`, 
               154.01200000000006`}, {344.312, 157.35899999999998`}, {346.246,
                157.488}, {348.176, 157.61700000000002`}, {349.465, 
               155.29700000000003`}, {347.14500000000004`, 
               152.98000000000002`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{524.094, 147.832}, {
               516.883, 149.76200000000006`}, {511.08599999999996`, 
               141.39099999999996`}, {517.6519999999999, 
               133.92200000000003`}, {517.5269999999999, 
               141.13299999999998`}, {522.676, 145.89799999999997`}, {528.988,
                144.60900000000004`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{526.09, 
               139.62099999999998`}, {524.3159999999999, 
               139.62099999999998`}, {523.3199999999999, 
               138.23400000000004`}, {523.3199999999999, 
               136.88299999999998`}, {523.3199999999999, 
               135.46500000000003`}, {524.543, 134.113}, {526.539, 134.113}, {
               527.828, 134.113}, {528.8589999999999, 135.59400000000005`}, {
               528.8589999999999, 136.75400000000002`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{551.523, 
               297.73400000000004`}, {552.6840000000001, 293.355}, {558.738, 
               291.55100000000004`}, {563.5, 292.582}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{563.5, 295.414}, {
               559.766, 295.285}, {556.676, 298.762}, {556.934, 
               301.72700000000003`}, {556.934, 299.53499999999997`}, {
               561.9569999999999, 298.504}, {563.5, 299.922}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{307.867, 148.344}, {
               306.83599999999996`, 150.92200000000003`}, {310.957, 
               153.49599999999998`}, {311.08599999999996`, 
               155.94099999999997`}, {311.215, 158.39099999999996`}, {
               315.72299999999996`, 160.32}, {320.35900000000004`, 
               155.68400000000003`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{318.172, 
               183.11700000000002`}, {317.27, 182.73000000000002`}, {
               316.4959999999999, 182.21500000000003`}, {315.72299999999996`, 
               181.957}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{327.055, 
               169.07800000000003`}, {325.96099999999996`, 
               169.01200000000006`}, {323.707, 169.14099999999996`}, {322.484,
                169.98000000000002`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{322.547, 
               164.18400000000003`}, {321.648, 163.73400000000004`}, {319.648,
                162.961}, {318.49199999999996`, 162.70300000000003`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{278.375, 86.39799999999997}, {
               278.246, 84.07800000000003}, {280.566, 80.73400000000004}, {
               281.85200000000003`, 79.70300000000003}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{288.42199999999997`, 
               91.93799999999999}, {287.133, 90.00800000000004}, {
               286.35900000000004`, 86.65599999999995}, {287.133, 
               84.33999999999997}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{307.60900000000004`,
                84.21100000000001}, {305.29299999999995`, 
               85.75799999999998}, {306.83599999999996`, 89.75}, {306.578, 
               92.32400000000001}, {306.32, 94.89799999999997}, {
               309.28499999999997`, 99.02000000000004}, {315.078, 95.543}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{285.97299999999996`, 
               98.89099999999996}, {288.29299999999995`, 99.27700000000004}, {
               290.73799999999994`, 99.14799999999997}, {292.28499999999997`, 
               98.50800000000004}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{315.33599999999996`, 
               106.23400000000004`}, {314.305, 104.81599999999997`}, {314.051,
                103.27000000000004`}, {313.92199999999997`, 102.238}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{326.156, 106.488}, {
               324.35200000000003`, 106.488}, {322.805, 
               105.20300000000003`}, {322.03499999999997`, 
               103.91400000000004`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{301.172, 172.426}, {
               303.22999999999996`, 171.71900000000005`}, {308.574, 
               168.43400000000003`}, {308.77, 165.02000000000004`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{323.062, 189.168}, {316.754, 
               189.29700000000003`}, {314.305, 195.738}, {319.07, 195.738}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{334.395, 
               180.53900000000004`}, {331.949, 179.51200000000006`}, {
               333.10900000000004`, 175.26200000000006`}, {
               336.58599999999996`, 173.199}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{319.328, 
               140.10200000000003`}, {318.105, 141.64799999999997`}, {319.715,
                146.152}, {323.707, 144.805}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{328.72999999999996`, 
               93.09800000000001}, {328.984, 97.02300000000002}, {333.945, 
               99.344}, {335.941, 94.89799999999997}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{310.441, 
               81.89499999999998}, {310.121, 86.20700000000005}, {312.309, 
               87.625}, {314.242, 87.87900000000002}, {316.172, 88.137}, {
               318.941, 86.531}, {320.22999999999996`, 83.695}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{272.066, 78.67200000000003}, {
               272.324, 81.25}, {274.512, 83.95299999999997}, {276.832, 
               83.56600000000003}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{507.73799999999994`, 
               193.031}, {506.062, 191.80900000000003`}, {504.969, 
               186.33599999999996`}, {511.34400000000005`, 185.82}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{497.949, 
               184.01600000000002`}, {497.949, 183.375}, {498.78499999999997`,
                182.473}, {499.305, 182.086}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{528.3439999999999, 
               173.71500000000003`}, {526.668, 175.00400000000008`}, {
               522.3519999999999, 169.78500000000003`}, {526.2810000000001, 
               165.988}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{487.39099999999996`, 
               130.445}, {486.42199999999997`, 134.113}, {489.83599999999996`,
                135.08200000000005`}, {493.055, 134.30900000000003`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{479.148, 156.457}, {481.078, 
               157.74599999999998`}, {483.012, 159.16400000000004`}, {
               485.46099999999996`, 159.805}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{478.121, 142.293}, {478.121, 
               145.38299999999998`}, {479.66400000000004`, 147.957}, {481.078,
                148.73000000000002`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{489.449, 
               177.83599999999996`}, {489.191, 174.10200000000003`}, {
               490.73799999999994`, 170.49599999999998`}, {
               491.89799999999997`, 168.56200000000007`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{520.102, 
               177.57800000000003`}, {518.234, 177.}, {516.559, 
               176.28900000000004`}, {515.8519999999999, 
               174.74599999999998`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{518.039, 
               167.02000000000004`}, {518.9409999999999, 
               167.78900000000004`}, {519.9730000000001, 
               168.69099999999997`}, {520.4219999999999, 
               169.33599999999996`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{566.719, 279.445}, {566.719, 
               275.84000000000003`}, {562.215, 273.906}, {559.254, 
               276.22700000000003`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{576.512, 
               279.31600000000003`}, {578.504, 277.77}, {585.395, 279.25}, {
               583.7850000000001, 283.24199999999996`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{568.137, 258.582}, {566.719, 
               258.84000000000003`}, {564.2730000000001, 
               260.38700000000006`}, {563.242, 261.67199999999997`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{582.305, 269.273}, {579.988, 
               268.75800000000004`}, {578.4409999999999, 269.273}, {
               577.2810000000001, 269.785}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{545.73, 256.395}, {547.016, 
               256.395}, {550.105, 256.90999999999997`}, {552.234, 258.004}}},
               
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{541.8669999999998, 279.188}, {
               540.191, 279.379}, {538.9649999999999, 279.05899999999997`}, {
               538.004, 278.414}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{567.8159999999999, 272.879}, {
               567.3669999999998, 271.266}, {566.207, 268.75800000000004`}, {
               564.7890000000001, 267.65999999999997`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{537.488, 267.211}, {540.707, 
               268.629}, {544.6990000000001, 257.67999999999995`}, {
               552.4259999999999, 261.543}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{553.07, 272.879}, {552.039, 
               271.461}, {551.398, 269.273}, {551.266, 267.34000000000003`}}},
               
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{399.047, 289.621}, {400.078, 
               289.746}, {401.879, 290.133}, {402.26599999999996`, 291.422}}},
               
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{266.527, 169.723}, {
               270.39099999999996`, 167.531}, {273.09799999999996`, 
               163.79700000000003`}, {271.42199999999997`, 
               158.26200000000006`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{443.60200000000003`, 
               301.469}, {444.762, 300.695}, {449.14500000000004`, 300.695}, {
               451.59, 301.59799999999996`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{454.68, 298.891}, {454.551, 
               297.09000000000003`}, {455.066, 290.262}, {451.59, 
               288.84799999999996`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{452.875, 289.746}, {
               456.09799999999996`, 288.719}, {462.53499999999997`, 
               289.105}, {464.59799999999996`, 295.02700000000004`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{460.09, 290.004}, {461.762, 
               287.43}, {462.277, 282.406}, {457.258, 279.703}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{461.375, 285.754}, {
               465.10900000000004`, 284.469}, {473.73799999999994`, 
               284.34000000000003`}, {472.83599999999996`, 
               291.67999999999995`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{469.875, 285.754}, {472.453, 
               282.14799999999997`}, {483.78499999999997`, 277.898}, {481.984,
                285.371}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{459.445, 275.324}, {463.824, 
               274.293}, {470.008, 277.25800000000004`}, {467.42999999999995`,
                284.98400000000004`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{479.79299999999995`, 
               281.121}, {480.43799999999993`, 278.156}, {494.85900000000004`,
                275.06600000000003`}, {492.92999999999995`, 281.762}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{490.22299999999996`, 
               277.898}, {492.92999999999995`, 271.719}, {507.22299999999996`,
                272.23400000000004`}, {502.715, 280.477}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{500.39799999999997`, 
               274.03499999999997`}, {503.22999999999996`, 
               270.55899999999997`}, {515.8519999999999, 272.621}, {510.828, 
               280.99199999999996`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{510.699, 274.164}, {518.555, 
               268.24199999999996`}, {527.6990000000001, 
               276.74199999999996`}, {517.7810000000001, 282.922}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{522.2890000000001, 
               276.09799999999996`}, {529.246, 270.55899999999997`}, {537.746,
                280.605}, {531.691, 283.438}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{467.301, 278.414}, {
               469.48799999999994`, 277.77}, {474.125, 278.02700000000004`}, {
               475.156, 282.02}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{473.41799999999995`, 
               279.31600000000003`}, {473.16, 273.457}, {483.012, 271.203}, {
               485.52299999999997`, 277.96500000000003`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{482.23799999999994`, 
               274.293}, {484.043, 270.43}, {492.668, 268.88700000000006`}, {
               494.08599999999996`, 274.422}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{492.668, 
               271.84799999999996`}, {494.08599999999996`, 
               267.98400000000004`}, {501.555, 268.371}, {503.617, 272.363}}},
               
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{500.914, 269.785}, {
               503.22999999999996`, 264.766}, {512.762, 264.766}, {514.949, 
               272.105}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{513.277, 
               268.88700000000006`}, {517.012, 266.56600000000003`}, {524.996,
                267.469}, {524.3519999999999, 274.67999999999995`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{522.805, 
               269.52700000000004`}, {528.3439999999999, 265.023}, {
               536.1990000000001, 269.398}, {532.3359999999999, 277.}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{531.949, 263.605}, {534.914, 
               264.121}, {536.4569999999999, 270.043}, {533.3669999999998, 
               271.59000000000003`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{463.309, 
               262.57399999999996`}, {469.48799999999994`, 265.922}, {470.648,
                271.59000000000003`}, {466.39799999999997`, 277.129}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{468.59, 268.24199999999996`}, {
               472.453, 265.922}, {479.79299999999995`, 268.371}, {481.078, 
               274.03499999999997`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{473.871, 
               267.59799999999996`}, {476.055, 264.766}, {476.441, 261.285}, {
               473.60900000000004`, 258.06600000000003`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{475.672, 
               263.99199999999996`}, {482.4959999999999, 
               268.24199999999996`}, {490.9959999999999, 
               260.38700000000006`}, {484.688, 255.621}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{483.527, 264.379}, {485.074, 
               264.766}, {487.777, 267.59799999999996`}, {488.03099999999995`,
                270.81600000000003`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{486.617, 261.414}, {489.449, 
               264.379}, {508.77, 258.324}, {496.53099999999995`, 
               252.14499999999998`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{495.633, 
               269.52700000000004`}, {499.367, 268.11299999999994`}, {501.301,
                262.832}, {495.633, 261.031}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{500.527, 256.652}, {504.648, 
               260.902}, {517.5269999999999, 258.195}, {512.891, 
               252.78900000000002`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{509.801, 258.324}, {512.117, 
               266.17999999999995`}, {525.898, 261.285}, {521.391, 
               258.06600000000003`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{506.965, 
               266.17999999999995`}, {507.35200000000003`, 264.637}, {
               507.47999999999996`, 260.773}, {504.90599999999995`, 258.711}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{518.555, 
               267.72700000000003`}, {519.07, 266.438}, {518.9409999999999, 
               263.99199999999996`}, {517.7810000000001, 262.445}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{527.3119999999999, 
               267.59799999999996`}, {528.086, 266.17999999999995`}, {529.375,
                263.477}, {526.539, 261.285}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{417.078, 326.836}, {417.203, 
               319.496}, {419.78099999999995`, 314.602}, {429.695, 319.238}}},
               
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{420.168, 318.082}, {
               415.27299999999997`, 311.51199999999994`}, {420.809, 304.43}, {
               430.469, 311.51199999999994`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{405.10200000000003`, 
               314.85900000000004`}, {411.79699999999997`, 
               307.64799999999997`}, {423.77299999999997`, 312.93}, {416.047, 
               323.875}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{424.16, 308.67999999999995`}, {
               422.871, 301.59799999999996`}, {428.668, 
               300.17999999999995`}, {433.42999999999995`, 303.398}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{399.172, 313.703}, {400.395, 
               306.582}, {407.672, 300.953}, {414.758, 305.332}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{407.93399999999997`, 
               303.914}, {407.93399999999997`, 293.74199999999996`}, {421.969,
                292.582}, {425.191, 303.14099999999996`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{420.168, 296.703}, {424.672, 
               287.43}, {434.46099999999996`, 291.164}, {437.68, 296.832}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{410.25, 311.51199999999994`}, {
               412.055, 307.004}, {415.66, 301.98}, {424.03099999999995`, 
               305.719}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{384.49199999999996`, 
               313.703}, {385.65200000000004`, 309.969}, {392.35200000000003`,
                305.461}, {400.078, 310.609}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{389.258, 308.938}, {385.137, 
               302.88300000000004`}, {393.379, 297.219}, {403.29699999999997`,
                306.23}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{394.15200000000004`, 
               301.469}, {395.828, 292.969}, {399.172, 286.14099999999996`}, {
               411.28099999999995`, 297.09000000000003`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{405.227, 292.711}, {409.605, 
               287.30100000000004`}, {416.305, 283.953}, {422.613, 
               293.09799999999996`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{427.25, 291.164}, {
               426.863, 284.72700000000003`}, {428.148, 281.508}, {433.172, 
               281.762}, {437.133, 281.96500000000003`}, {440.89799999999997`,
                285.11299999999994`}, {443.09, 288.461}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{432.27299999999997`, 
               281.762}, {432.14500000000004`, 274.422}, {437.93799999999993`,
                268.629}, {448.758, 276.09799999999996`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{436.78099999999995`, 
               273.137}, {434.719, 267.59799999999996`}, {440.89799999999997`,
                258.582}, {453.008, 263.219}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{411.148, 
               287.81600000000003`}, {410.379, 280.73400000000004`}, {416.945,
                275.969}, {427.508, 285.11299999999994`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{416.305, 279.961}, {416.691, 
               274.164}, {423.258, 267.211}, {432.91799999999995`, 
               277.25800000000004`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{420.941, 272.621}, {420.168, 
               262.703}, {429.309, 259.871}, {437.03499999999997`, 267.469}}},
               
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{407.16, 279.961}, {409.219, 
               279.832}, {410.895, 281.633}, {411.92199999999997`, 282.922}}},
               
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{411.53499999999997`, 272.75}, {
               413.34000000000003`, 272.363}, {416.43399999999997`, 
               274.03499999999997`}, {417.465, 276.09799999999996`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{416.047, 261.031}, {418.105, 
               258.84000000000003`}, {425.059, 260.38700000000006`}, {
               425.96099999999996`, 263.34799999999996`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{423.77299999999997`, 
               261.15999999999997`}, {427.637, 252.14499999999998`}, {
               437.93799999999993`, 252.531}, {442.188, 262.703}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{440.258, 
               259.09799999999996`}, {442.188, 253.816}, {447.082, 250.469}, {
               455.066, 252.273}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{444.121, 253.688}, {439.613, 
               246.34799999999998`}, {445.53499999999997`, 237.719}, {455.578,
                246.219}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{446.566, 242.742}, {446.055, 
               238.105}, {450.305, 232.824}, {456.09799999999996`, 232.184}}},
               
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{427.508, 256.266}, {
               425.96099999999996`, 245.832}, {433.42999999999995`, 
               240.81199999999998`}, {442.832, 246.34799999999998`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{416.559, 251.242}, {419.008, 
               249.309}, {423.387, 249.05100000000002`}, {427.508, 
               250.59799999999998`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{432.53099999999995`, 
               244.547}, {430.21099999999996`, 235.78900000000002`}, {439.227,
                229.477}, {446.953, 239.26600000000002`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{420.03499999999997`, 
               249.824}, {420.168, 245.316}, {424.547, 240.42600000000002`}, {
               432.14500000000004`, 241.84}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{453.395, 232.824}, {
               448.23799999999994`, 229.34799999999998`}, {
               447.21099999999996`, 223.168}, {454.42199999999997`, 219.176}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{440.77, 234.629}, {
               441.03099999999995`, 229.34799999999998`}, {443.477, 
               226.38700000000003`}, {449.27, 225.871}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{433.172, 237.332}, {425.445, 
               230.25}, {433.043, 222.00800000000004`}, {442.188, 228.961}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{438.582, 226.773}, {436.008, 
               218.65999999999997`}, {445.668, 213.76600000000002`}, {450.816,
                222.00800000000004`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{422.613, 244.031}, {
               419.78099999999995`, 236.047}, {423.387, 
               230.76600000000002`}, {429.953, 231.28100000000003`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{412.441, 
               245.57399999999998`}, {412.828, 240.81199999999998`}, {416.945,
                239.137}, {421.582, 240.16799999999998`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{415.39799999999997`, 
               240.555}, {411.92199999999997`, 233.85500000000002`}, {417.203,
                230.25}, {424.16, 232.824}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{445.28099999999995`, 
               217.887}, {444.121, 213.637}, {444.762, 210.54700000000003`}, {
               451.074, 209.12900000000002`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{445.668, 
               211.83599999999996`}, {438.066, 208.35499999999996`}, {
               437.42199999999997`, 201.01600000000002`}, {443.348, 196.25}}},
               
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{439.547, 
               220.01200000000006`}, {435.555, 216.406}, {436.328, 
               210.15999999999997`}, {440.707, 207.71500000000003`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{405.742, 243.516}, {401.363, 
               239.19899999999998`}, {405.551, 227.28900000000002`}, {415.207,
                233.793}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{430.855, 
               228.44899999999998`}, {424.92999999999995`, 223.555}, {427.637,
                214.668}, {437.42199999999997`, 217.113}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{421.066, 232.184}, {417.977, 
               223.426}, {420.941, 220.33599999999996`}, {427.895, 
               220.20700000000005`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{399.305, 243.902}, {
               394.02299999999997`, 239.91}, {395.441, 234.242}, {397.758, 
               231.66799999999998`}, {400.078, 229.09}, {404.453, 230.25}, {
               405.871, 233.59799999999998`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{388.227, 247.379}, {382.305, 
               239.78100000000003`}, {388.227, 230.76600000000002`}, {
               396.60200000000003`, 233.469}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{419.90999999999997`,
                224.84}, {413.855, 222.652}, {409.23799999999994`, 
               217.15599999999995`}, {412.953, 212.34799999999996`}, {
               415.14500000000004`, 209.51600000000002`}, {424.672, 
               209.12900000000002`}, {427.375, 220.07800000000003`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{408.965, 
               231.92600000000002`}, {405.48799999999994`, 226.902}, {
               406.64500000000004`, 222.137}, {413.082, 219.69099999999997`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{408.578, 
               222.52300000000002`}, {404.84000000000003`, 220.461}, {402.395,
                218.01600000000002`}, {403.29699999999997`, 
               213.50800000000004`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{400.207, 230.379}, {398.789, 
               224.328}, {400.465, 220.59000000000003`}, {404.195, 
               218.78900000000004`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{400.078, 223.168}, {
               394.28099999999995`, 223.555}, {391.32, 221.10500000000002`}, {
               393.25, 215.44099999999997`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{393.76599999999996`, 221.75}, {
               388.10200000000003`, 223.812}, {387.195, 228.703}, {
               389.64500000000004`, 233.85500000000002`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{388.871, 226.258}, {382.691, 
               226.}, {379.98799999999994`, 222.91000000000003`}, {
               379.98799999999994`, 218.65999999999997`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{380.5, 250.34}, {
               375.99199999999996`, 248.41}, {374.578, 242.35500000000002`}, {
               376.25, 239.00799999999998`}, {377.92599999999993`, 235.66}, {
               383.207, 235.402}, {386.42599999999993`, 237.59}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{367.879, 255.105}, {363.758, 
               250.469}, {368.52299999999997`, 241.453}, {375.867, 
               243.64499999999998`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{357.32, 258.711}, {353.457, 
               253.30100000000002`}, {357.707, 244.28900000000002`}, {367.621,
                246.863}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{368.137, 221.75}, {367.105, 
               228.191}, {373.805, 232.441}, {382.047, 224.07}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{378.055, 
               237.07399999999998`}, {375.605, 234.88700000000003`}, {374.449,
                231.41}, {374.832, 228.57799999999997`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{346.758, 
               261.80100000000004`}, {342.508, 254.59}, {347.66400000000004`, 
               248.023}, {356.805, 250.59799999999998`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{370.58599999999996`, 
               243.902}, {364.53099999999995`, 237.84799999999998`}, {366.594,
                231.79700000000003`}, {371.10200000000003`, 228.32}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{366.719, 236.816}, {357.578, 
               236.691}, {357.062, 226.129}, {364.53099999999995`, 222.781}}},
               
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{359.76599999999996`, 
               247.379}, {356.03099999999995`, 244.805}, {354.871, 237.719}, {
               361.312, 234.88700000000003`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{359.508, 231.539}, {
               355.64500000000004`, 233.34}, {351.008, 231.152}, {351.395, 
               226.64499999999998`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{353.715, 231.41}, {350.234, 
               239.652}, {340.062, 238.234}, {340.965, 229.734}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{356.547, 241.582}, {
               354.35900000000004`, 241.195}, {349.97999999999996`, 239.91}, {
               348.305, 236.559}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{348.949, 
               250.85500000000002`}, {344.828, 246.219}, {348.047, 240.684}, {
               351.395, 239.523}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{336.715, 263.863}, {335.941, 
               258.324}, {338.133, 255.621}, {345.08599999999996`, 256.137}}},
               
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{339.16400000000004`, 
               256.78100000000006`}, {336.457, 250.082}, {340.062, 247.121}, {
               347.01599999999996`, 247.50799999999998`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{340.707, 248.539}, {
               336.58599999999996`, 243.64499999999998`}, {
               339.41799999999995`, 238.363}, {343.40999999999997`, 236.176}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{338.777, 
               242.35500000000002`}, {331.43799999999993`, 243.258}, {330.277,
                234.758}, {332.72299999999996`, 230.76600000000002`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{332.85200000000003`,
                264.508}, {328.34400000000005`, 262.57399999999996`}, {325.77,
                256.90999999999997`}, {328.215, 253.43}, {330.66400000000004`,
                249.953}, {335.555, 251.11299999999997`}, {338.258, 
               252.91799999999998`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{329.758, 
               251.88700000000003`}, {326.027, 246.219}, {329.371, 241.969}, {
               333.367, 240.29700000000003`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{315.33599999999996`,
                265.152}, {312.375, 262.05899999999997`}, {314.176, 255.75}, {
               321.39099999999996`, 255.621}, {327.195, 255.516}, {
               330.14500000000004`, 261.031}, {328.34400000000005`, 264.895}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{320.35900000000004`, 
               255.621}, {318.043, 250.469}, {319.457, 244.93}, {328.215, 
               245.832}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{331.949, 237.719}, {326.539, 
               240.16799999999998`}, {319.328, 237.719}, {322.42199999999997`,
                231.28100000000003`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{321.648, 246.863}, {319.457, 
               243.773}, {320.22999999999996`, 239.395}, {322.676, 236.691}}},
               
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{321.262, 238.621}, {317.656, 
               237.977}, {314.176, 236.047}, {316.367, 230.379}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{315.85200000000003`, 
               235.016}, {311.215, 236.434}, {305.29299999999995`, 233.082}, {
               308.89799999999997`, 228.32}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{308.125, 232.824}, {304.133, 
               233.469}, {299.367, 229.219}, {303.22999999999996`, 224.969}}},
               
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{301.688, 
               228.44899999999998`}, {298.078, 227.547}, {293.832, 223.426}, {
               297.566, 220.20700000000005`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{319.84400000000005`, 
               248.66799999999998`}, {314.691, 246.34799999999998`}, {314.176,
                240.555}, {316.625, 236.305}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{314.43399999999997`, 
               259.355}, {306.707, 256.395}, {306.83599999999996`, 246.09}, {
               315.33599999999996`, 242.871}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{311.72999999999996`, 
               245.188}, {307.094, 242.484}, {306.191, 237.332}, {
               309.28499999999997`, 233.984}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{303.617, 263.219}, {300.527, 
               262.188}, {300.78499999999997`, 252.66}, {309.027, 
               252.91799999999998`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{295.117, 260.}, {
               288.93799999999993`, 255.879}, {296.40599999999995`, 
               245.445}, {306.449, 252.91799999999998`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{300.914, 250.34}, {300.012, 
               246.09}, {301.172, 241.453}, {307.9959999999999, 240.938}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{301.301, 244.676}, {
               296.40599999999995`, 242.871}, {295.504, 232.824}, {
               304.39099999999996`, 232.055}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{285.715, 253.816}, {
               279.40599999999995`, 248.023}, {290.867, 243.}, {295.117, 
               251.371}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{276.96099999999996`, 244.16}, {
               273.867, 240.42600000000002`}, {284.688, 230.637}, {289.453, 
               246.992}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{290.60900000000004`, 247.25}, {
               290.867, 243.38700000000003`}, {293.188, 241.066}, {297.949, 
               240.81199999999998`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{297.824, 
               237.07399999999998`}, {290.22299999999996`, 
               235.91799999999998`}, {287.777, 226.38700000000003`}, {296.277,
                224.328}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{283.78499999999997`, 
               238.363}, {283.527, 234.758}, {287.262, 231.79700000000003`}, {
               291.512, 232.441}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{295.375, 224.582}, {
               288.42199999999997`, 223.03900000000004`}, {287.52, 
               214.02300000000002`}, {293.703, 214.53900000000004`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{290.47999999999996`, 
               206.168}, {284.688, 207.906}, {284.559, 214.79700000000003`}, {
               289.707, 217.37099999999998`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{285.715, 212.223}, {
               280.824, 209.25799999999998`}, {282.754, 202.176}, {285.332, 
               201.14499999999998`}, {287.90599999999995`, 200.113}, {289.965,
                201.40200000000004`}, {290.22299999999996`, 
               203.59400000000005`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{289.83599999999996`, 
               193.676}, {290.35200000000003`, 190.32799999999997`}, {
               277.92599999999993`, 191.61700000000002`}, {284.301, 
               202.04700000000003`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{284.234, 193.098}, {280.051, 
               186.52700000000004`}, {286.875, 181.18400000000003`}, {291.191,
                186.78500000000003`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{284.816, 185.176}, {283.141, 
               179.89499999999998`}, {289.51599999999996`, 176.098}, {293.637,
                180.21900000000005`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{270.90599999999995`, 
               234.629}, {268.59, 229.863}, {280.18, 228.06199999999998`}, {
               280.953, 237.84799999999998`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{267.688, 227.547}, {265.371, 
               218.27300000000002`}, {282.883, 220.20700000000005`}, {278.375,
                232.184}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{278.762, 226.}, {
               281.21099999999996`, 224.582}, {288.551, 
               224.45700000000002`}, {290.35200000000003`, 
               232.31199999999998`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{285.074, 225.742}, {285.59, 
               223.29700000000003`}, {287.777, 220.33599999999996`}, {
               289.83599999999996`, 219.43400000000003`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{276.703, 
               223.29700000000003`}, {275.92999999999995`, 
               218.27300000000002`}, {280.953, 214.152}, {286.746, 
               214.53900000000004`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{277.60200000000003`, 
               218.40200000000004`}, {274.77, 214.53900000000004`}, {273.867, 
               207.07000000000005`}, {282.754, 206.555}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{264.082, 217.113}, {
               262.66400000000004`, 213.12099999999998`}, {
               271.03499999999997`, 209.}, {275.92999999999995`, 
               215.57000000000005`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{261.504, 
               206.94099999999997`}, {260.79699999999997`, 
               203.91400000000004`}, {268.332, 199.85899999999998`}, {272.582,
                212.73400000000004`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{269.234, 206.168}, {
               271.03499999999997`, 202.949}, {277.09, 200.37099999999998`}, {
               280.824, 206.68400000000003`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{274.77, 202.82}, {273.227, 
               198.312}, {277.477, 194.06200000000007`}, {282.625, 
               195.35199999999998`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{265.113, 
               203.85199999999998`}, {264.082, 197.41000000000003`}, {271.551,
                193.676}, {276.188, 197.02300000000002`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{260.219, 
               201.01600000000002`}, {258.027, 192.77300000000002`}, {268.59, 
               189.68400000000003`}, {272.582, 195.86700000000002`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{269.875, 193.418}, {270.262, 
               188.781}, {277.477, 184.78900000000004`}, {283.141, 188.652}}},
               
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{257., 189.555}, {256.484, 
               187.49599999999998`}, {265.113, 185.43400000000003`}, {
               266.39799999999997`, 192.64499999999998`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{262.02, 187.75400000000002`}, {
               264.082, 182.473}, {271.03499999999997`, 
               181.18400000000003`}, {275.027, 187.625}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{272.71099999999996`, 
               185.04700000000003`}, {273.60900000000004`, 180.152}, {
               279.92199999999997`, 177.449}, {285.46099999999996`, 
               180.79700000000003`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{287.777, 
               178.86700000000002`}, {286.35900000000004`, 
               172.29700000000003`}, {293.188, 167.02000000000004`}, {
               297.43799999999993`, 170.625}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{276.832, 
               180.02300000000002`}, {274.77, 172.812}, {283.78499999999997`, 
               168.69099999999997`}, {288.809, 172.68400000000003`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{266.012, 
               183.62900000000002`}, {265.4959999999999, 
               176.93400000000003`}, {270.777, 172.94099999999997`}, {276.832,
                175.90200000000004`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{254.55100000000002`, 
               182.988}, {252.75, 178.60900000000004`}, {262.277, 
               175.00400000000008`}, {266.78499999999997`, 178.738}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{248.629, 
               171.01200000000006`}, {251.07399999999998`, 168.176}, {259.574,
                171.01200000000006`}, {260.348, 177.32}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{258.027, 
               172.68400000000003`}, {261.121, 169.07800000000003`}, {
               268.46099999999996`, 167.14799999999997`}, {
               271.42199999999997`, 174.875}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{268.848, 
               170.88299999999998`}, {268.719, 165.344}, {278.633, 
               161.35199999999998`}, {281.85200000000003`, 
               171.52700000000004`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{293.508, 
               169.52700000000004`}, {292.605, 166.824}, {294.72999999999996`,
                162.51200000000006`}, {299.176, 161.99599999999998`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{285.332, 
               171.20300000000003`}, {284.688, 168.113}, {289.195, 
               163.79700000000003`}, {293.957, 165.53500000000003`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{294.85900000000004`, 164.25}, {
               293.574, 160.89799999999997`}, {294.668, 
               156.07000000000005`}, {299.176, 156.137}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{295.312, 
               158.00400000000008`}, {291.96099999999996`, 
               155.17200000000003`}, {293.379, 150.14799999999997`}, {298.207,
                149.95299999999997`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{293.574, 153.238}, {288.809, 
               150.02000000000004`}, {290.47999999999996`, 142.938}, {
               296.79299999999995`, 143.32}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{279.148, 
               166.89099999999996`}, {279.148, 159.93400000000003`}, {287.777,
                158.906}, {289.453, 165.344}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{286.10200000000003`, 
               161.223}, {284.816, 157.10200000000003`}, {288.16400000000004`,
                153.10900000000004`}, {293.445, 154.27000000000004`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{287.133, 
               111.51200000000006`}, {288.29299999999995`, 
               109.83599999999996`}, {293.059, 112.67200000000003`}, {291.77, 
               115.50400000000008`}, {290.47999999999996`, 
               118.33599999999996`}, {285.43399999999997`, 
               116.79700000000003`}, {285.97299999999996`, 113.832}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{290.60900000000004`, 
               116.66400000000004`}, {291.254, 122.332}, {284.559, 
               123.23000000000002`}, {282.883, 118.33599999999996`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{285.332, 
               121.17200000000003`}, {287.004, 124.00400000000008`}, {
               281.34000000000003`, 127.86700000000002`}, {279.02, 
               123.74599999999998`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{281.082, 
               125.42200000000003`}, {282.625, 129.543}, {276.188, 131.344}, {
               275.672, 127.60900000000004`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{274.254, 
               133.02000000000004`}, {275.027, 135.08200000000005`}, {
               282.23799999999994`, 133.793}, {279.148, 129.543}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{284.688, 
               124.39099999999996`}, {287.52, 126.96500000000003`}, {282.754, 
               132.24599999999998`}, {279.79299999999995`, 130.312}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{303.746, 
               116.53500000000003`}, {301.49199999999996`, 
               116.27700000000004`}, {299.176, 114.79700000000003`}, {300.848,
                110.031}, {302.008, 106.72300000000001`}, {306.965, 
               106.555}, {307.672, 108.55099999999999`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{300.46099999999996`,
                114.15199999999999`}, {298.27299999999997`, 
               115.57000000000005`}, {293.508, 113.18799999999999`}, {295.695,
                108.55099999999999`}, {297.34400000000005`, 
               105.05900000000003`}, {301.49199999999996`, 106.488}, {302.137,
                108.293}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{288.16400000000004`, 
               107.52000000000004`}, {289.258, 105.59000000000003`}, {
               294.72999999999996`, 106.42200000000003`}, {295.695, 
               108.55099999999999`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{291.89799999999997`, 
               113.89499999999998`}, {293.059, 114.668}, {295.18, 
               113.70300000000003`}, {295.633, 112.738}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{291.512, 
               145.64099999999996`}, {287.777, 143.195}, {290.094, 135.723}, {
               295.89099999999996`, 137.65599999999995`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{290.35200000000003`, 
               139.586}, {287.39099999999996`, 137.27000000000004`}, {290.094,
                130.05900000000003`}, {295.633, 132.76200000000006`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{291.254, 
               132.76200000000006`}, {289.195, 130.699}, {291.191, 
               124.96900000000005`}, {296.53499999999997`, 
               126.06200000000007`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{290.47999999999996`, 
               129.926}, {289.324, 130.445}, {286.29699999999997`, 
               130.05900000000003`}, {285.008, 128.125}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{287.133, 
               156.00800000000004`}, {284.301, 153.301}, {285.65200000000004`,
                147.76200000000006`}, {290.93399999999997`, 147.312}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{286.10200000000003`, 
               150.33999999999997`}, {282.047, 148.344}, {282.047, 
               140.29700000000003`}, {290.16, 139.973}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{285.78099999999995`, 
               141.26200000000006`}, {283.527, 139.457}, {284.621, 
               132.50400000000008`}, {290.41799999999995`, 133.406}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{287.648, 
               133.66400000000004`}, {286.812, 132.82799999999997`}, {286.684,
                130.699}, {287.39099999999996`, 129.801}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{285.074, 136.305}, {283.012, 
               136.238}, {280.309, 134.75799999999998`}, {279.59799999999996`,
                132.63299999999998`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{275.863, 
               140.10200000000003`}, {276.637, 142.16400000000004`}, {283.012,
                142.03500000000003`}, {283.46099999999996`, 
               135.98000000000002`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{284.105, 143.195}, {283.203, 
               143.}, {281.469, 142.16400000000004`}, {281.01599999999996`, 
               140.42200000000003`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{281.34000000000003`, 
               162.05900000000003`}, {278.57, 159.54700000000003`}, {277.219, 
               151.62900000000002`}, {285.65200000000004`, 
               150.08200000000005`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{275.734, 
               145.70300000000003`}, {275.734, 147.832}, {281.469, 
               149.63299999999998`}, {283.46099999999996`, 
               146.47700000000003`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{272.066, 
               157.23000000000002`}, {272.902, 155.62099999999998`}, {276.895,
                153.43}, {279.34000000000003`, 155.23400000000004`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{251.33200000000002`,
                169.85199999999998`}, {251.20299999999997`, 
               166.11700000000002`}, {254.29299999999998`, 
               162.77000000000004`}, {258.543, 163.281}, {262.79299999999995`,
                163.79700000000003`}, {263.695, 167.531}, {
               262.40599999999995`, 169.98000000000002`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{259.188, 
               163.15599999999995`}, {256.355, 159.676}, {259.832, 
               154.78500000000003`}, {263.051, 156.199}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{262.40599999999995`, 
               165.60200000000003`}, {264.082, 166.24599999999998`}, {269.617,
                167.02000000000004`}, {271.29299999999995`, 
               164.44099999999997`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{244.508, 
               164.57000000000005`}, {243.21899999999997`, 
               162.64099999999996`}, {251.20299999999997`, 
               160.70700000000005`}, {253.906, 164.44099999999997`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{251.20299999999997`, 
               162.51200000000006`}, {250.945, 159.93400000000003`}, {
               252.23399999999998`, 155.555}, {258.801, 157.35899999999998`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{259.832, 
               153.36700000000002`}, {260.863, 155.555}, {255.969, 
               159.16400000000004`}, {252.23399999999998`, 
               155.17200000000003`}, {248.5, 151.18}, {252.75, 
               146.67200000000003`}, {255.066, 148.21500000000003`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{242.70299999999997`, 
               161.99599999999998`}, {240.77299999999997`, 
               158.64799999999997`}, {248.242, 152.531}, {252.49200000000002`,
                158.195}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{237.74599999999998`,
                156.199}, {235.039, 153.43}, {238.38700000000003`, 148.344}, {
               242.445, 149.89099999999996`}, {246.5, 151.43400000000003`}, {
               246.117, 155.68400000000003`}, {245.148, 156.77700000000004`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{232.531, 
               151.04700000000003`}, {230.34, 149.055}, {232.465, 
               144.35199999999998`}, {235.49200000000002`, 
               144.35199999999998`}, {238.516, 144.35199999999998`}, {
               240.38700000000003`, 146.73400000000004`}, {239.805, 
               149.76200000000006`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{244.82800000000003`, 
               151.43400000000003`}, {244.441, 148.473}, {248.82000000000002`,
                146.41400000000004`}, {251.65200000000002`, 149.18}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{251.781, 
               154.59000000000003`}, {252.168, 155.23400000000004`}, {251.848,
                156.32799999999997`}, {251.20299999999997`, 156.844}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{227.82800000000003`, 
               147.05900000000003`}, {225.316, 145.05900000000003`}, {230.727,
                139.52300000000002`}, {234.137, 144.60900000000004`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{247.21099999999998`, 
               148.14799999999997`}, {245.602, 146.60500000000002`}, {248.176,
                142.551}, {250.75, 143.77300000000002`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{238.38700000000003`, 
               145.31599999999997`}, {238.77299999999997`, 142.551}, {244.184,
                140.488}, {247.598, 144.738}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{241.35200000000003`, 
               142.551}, {240.516, 140.80900000000003`}, {242.18800000000002`,
                138.03900000000004`}, {244.25, 138.426}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{292.605, 
               126.64499999999998`}, {290.60900000000004`, 
               122.71500000000003`}, {296.984, 118.14499999999998`}, {301.621,
                122.91000000000003`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{297.242, 
               120.78500000000003`}, {296.277, 118.65999999999997`}, {
               297.43799999999993`, 115.695}, {299.176, 114.60200000000003`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{291.191, 
               116.33999999999997`}, {291.641, 118.27300000000002`}, {
               294.40999999999997`, 120.07800000000003`}, {
               296.92199999999997`, 119.17200000000003`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{287.84000000000003`, 121.43}, {
               288.227, 123.168}, {290.547, 124.906}, {292.28499999999997`, 
               124.45299999999997`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{439.484, 
               201.78900000000004`}, {430.34000000000003`, 
               201.65999999999997`}, {434.203, 186.98000000000002`}, {442.059,
                189.94099999999997`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{436.52299999999997`, 
               190.973}, {434.719, 188.00800000000004`}, {438.195, 
               183.30900000000003`}, {442.059, 186.07800000000003`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{441.03099999999995`, 
               185.49599999999998`}, {438.324, 180.99200000000002`}, {447.984,
                174.10200000000003`}, {451.848, 181.18400000000003`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{448.758, 
               178.48000000000002`}, {448.883, 174.23000000000002`}, {461.246,
                171.52700000000004`}, {459.445, 180.02300000000002`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{458.28499999999997`, 
               175.39099999999996`}, {461.246, 170.36700000000002`}, {472.324,
                169.85199999999998`}, {471.16400000000004`, 177.32}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{468.715, 172.168}, {
               471.03499999999997`, 168.82}, {481.85200000000003`, 
               166.76200000000006`}, {481.465, 173.71500000000003`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{424.805, 
               214.53900000000004`}, {426.348, 210.54700000000003`}, {431.625,
                209.12900000000002`}, {437.42199999999997`, 211.449}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{421.453, 
               211.70700000000005`}, {425.059, 209.387}, {419.78099999999995`,
                198.82799999999997`}, {414.242, 203.07800000000003`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{421.453, 205.137}, {425.445, 
               203.20700000000005`}, {430.34000000000003`, 
               204.62099999999998`}, {431.758, 210.28900000000004`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{429.309, 
               205.91000000000003`}, {429.695, 202.949}, {433.945, 
               200.62900000000002`}, {439.484, 201.78900000000004`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{419.395, 202.82}, {424.547, 
               198.44099999999997`}, {417.078, 189.426}, {413.727, 
               193.54700000000003`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{421.328, 199.473}, {
               423.77299999999997`, 197.668}, {430.082, 198.699}, {430.727, 
               203.46500000000003`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{427.895, 199.473}, {
               428.40999999999997`, 196.37900000000002`}, {430.855, 
               195.223}, {434.332, 195.09400000000005`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{419.90999999999997`, 
               195.223}, {422.484, 191.61700000000002`}, {428.92199999999997`,
                190.586}, {431.758, 195.35199999999998`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{428.92199999999997`, 
               192.64499999999998`}, {428.668, 189.168}, {432.53099999999995`,
                186.33599999999996`}, {436.52299999999997`, 
               187.10900000000004`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{414.887, 184.918}, {418.234, 
               183.24599999999998`}, {421.84000000000003`, 189.555}, {419.008,
                193.93400000000003`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{418.75, 178.223}, {422.742, 
               177.96500000000003`}, {423.258, 184.01600000000002`}, {
               419.52299999999997`, 187.36700000000002`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{427.895, 
               172.68400000000003`}, {431.242, 173.457}, {430.21099999999996`,
                180.79700000000003`}, {422.09799999999996`, 
               181.44099999999997`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{438.066, 
               167.27700000000004`}, {441.28499999999997`, 168.176}, {
               438.71099999999996`, 176.28900000000004`}, {429.828, 
               175.77300000000002`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{450.305, 
               164.44099999999997`}, {452.48799999999994`, 
               167.78900000000004`}, {445.28099999999995`, 173.457}, {439.355,
                170.49599999999998`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{456.35200000000003`, 
               159.805}, {460.348, 158.64799999999997`}, {463.051, 
               169.20700000000005`}, {450.42999999999995`, 167.531}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{463.691, 159.805}, {467.172, 
               160.70700000000005`}, {469.621, 167.02000000000004`}, {459.445,
                164.957}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{471.42199999999997`, 
               159.293}, {474.512, 157.74599999999998`}, {475.92999999999995`,
                166.76200000000006`}, {466.527, 164.312}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{419.52299999999997`, 
               187.36700000000002`}, {423.387, 185.176}, {429.441, 
               187.75400000000002`}, {428.92199999999997`, 
               192.64499999999998`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{427.375, 
               188.39499999999998`}, {428.668, 186.07800000000003`}, {428.148,
                181.57000000000005`}, {425.703, 180.41000000000003`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{427.762, 182.988}, {
               430.34000000000003`, 181.957}, {433.816, 
               182.85899999999998`}, {435.875, 186.98000000000002`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{432.27299999999997`, 
               182.988}, {433.043, 181.18400000000003`}, {433.305, 
               177.57800000000003`}, {431.625, 175.77300000000002`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{432.91799999999995`, 
               179.89499999999998`}, {435.75, 178.35199999999998`}, {
               439.09799999999996`, 180.41000000000003`}, {440.512, 183.375}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{438.71099999999996`, 
               180.79700000000003`}, {440.77, 179.51200000000006`}, {442.574, 
               173.457}, {439.09799999999996`, 171.01200000000006`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{441.03099999999995`, 
               173.844}, {443.477, 173.71500000000003`}, {447.082, 
               173.71500000000003`}, {449.39799999999997`, 176.805}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{447.727, 
               175.13299999999998`}, {449.91799999999995`, 174.488}, {
               452.48799999999994`, 170.88299999999998`}, {451.59, 
               167.65999999999997`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{451.715, 168.82}, {454.168, 
               169.07800000000003`}, {458.414, 170.75400000000002`}, {459.574,
                173.71500000000003`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{458.414, 171.781}, {460.477, 
               170.625}, {461.895, 168.176}, {461.633, 165.344}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{461.633, 167.406}, {464.078, 
               167.531}, {466.27, 168.82}, {466.914, 171.52700000000004`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{466.27, 169.723}, {468.074, 
               169.07800000000003`}, {470.262, 167.02000000000004`}, {470.395,
                164.57000000000005`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{470.133, 
               166.11700000000002`}, {471.93799999999993`, 166.375}, {
               473.22299999999996`, 167.531}, {474.383, 169.33599999999996`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{479.277, 
               169.59400000000005`}, {481.59799999999996`, 
               167.27700000000004`}, {478.508, 159.54700000000003`}, {
               473.73799999999994`, 160.96500000000003`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{429.828, 
               325.67999999999995`}, {425.059, 322.844}, {411.53499999999997`,
                323.746}, {418.234, 334.94899999999996`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{431.113, 
               333.27700000000004`}, {421.715, 329.543}, {410.121, 336.754}, {
               422.227, 344.609}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{419.008, 
               347.18399999999997`}, {411.148, 347.18399999999997`}, {405.871,
                334.562}, {416.43399999999997`, 330.188}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{388.48799999999994`,
                341.906}, {386.42599999999993`, 337.914}, {
               393.76599999999996`, 333.53499999999997`}, {398.789, 
               337.52700000000004`}, {402.68, 340.621}, {402.395, 348.988}, {
               400.078, 352.207}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{384.49199999999996`, 
               332.375}, {381.91799999999995`, 323.875}, {400.85200000000003`,
                323.35900000000004`}, {397.887, 336.88300000000004`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{383.465, 319.754}, {384.105, 
               313.31600000000003`}, {401.625, 315.375}, {395.953, 
               328.38300000000004`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{398.01599999999996`, 
               331.988}, {399.43399999999997`, 330.05899999999997`}, {
               403.29699999999997`, 326.707}, {409.863, 327.352}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{401.105, 341.133}, {401.688, 
               338.812}, {405.613, 337.01199999999994`}, {410.637, 338.75}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{225.383, 
               145.19099999999997`}, {220.93800000000002`, 
               142.03500000000003`}, {227.766, 137.07800000000003`}, {
               230.27299999999997`, 142.551}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{221.90200000000002`, 
               142.738}, {217.461, 139.586}, {224.289, 134.62900000000002`}, {
               226.797, 140.10200000000003`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{218.23399999999998`, 
               140.35899999999998`}, {213.789, 137.20300000000003`}, {220.617,
                132.24599999999998`}, {223.129, 137.71900000000005`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{214.371, 
               138.17200000000003`}, {210.121, 135.918}, {215.078, 
               130.37900000000002`}, {219.395, 135.27300000000002`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{210.184, 136.043}, {205.934, 
               133.793}, {210.895, 128.25400000000002`}, {215.207, 
               133.14799999999997`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{231.758, 142.676}, {231.691, 
               139.39499999999998`}, {237.93800000000002`, 
               138.03900000000004`}, {240.191, 142.938}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{235.684, 
               139.64799999999997`}, {233.754, 137.20300000000003`}, {
               237.29299999999998`, 134.176}, {239.227, 135.27300000000002`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{227.379, 
               140.10200000000003`}, {227.184, 137.332}, {232.594, 135.723}, {
               235.23399999999998`, 138.75}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{230.34, 137.20300000000003`}, {
               228.602, 134.949}, {232.016, 131.92200000000003`}, {
               234.20299999999997`, 132.82799999999997`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{223.77299999999997`, 
               137.59000000000003`}, {223.965, 135.39799999999997`}, {227.055,
                132.89099999999996`}, {230.40200000000002`, 
               134.30900000000003`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{225.76999999999998`, 
               134.62900000000002`}, {224.48000000000002`, 
               133.46900000000005`}, {225.125, 130.76200000000006`}, {
               226.92600000000002`, 129.926}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{219.07, 134.824}, {218.555, 
               132.82799999999997`}, {221.969, 129.28500000000003`}, {225.445,
                131.60200000000003`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{219.781, 
               132.50400000000008`}, {217.71899999999997`, 
               130.89499999999998`}, {217.977, 128.445}, {220.617, 128.125}}},
               
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{214.82000000000002`, 
               132.76200000000006`}, {214.562, 131.41000000000003`}, {216.305,
                129.21900000000005`}, {218.49200000000002`, 
               129.47700000000003`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{203.812, 
               132.89099999999996`}, {201.75, 131.79700000000003`}, {207.031, 
               126.195}, {210.312, 131.41000000000003`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{198.72299999999998`, 
               130.57400000000007`}, {196.148, 129.34799999999996`}, {202.523,
                123.168}, {205.35500000000002`, 129.47700000000003`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{215.40200000000002`, 
               130.832}, {213.406, 130.37900000000002`}, {212.117, 
               127.48000000000002`}, {213.789, 126.32400000000001`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{208.89800000000002`, 
               129.801}, {208.641, 128.64099999999996`}, {211.086, 
               126.71100000000001`}, {213.08200000000002`, 127.418}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{207.22299999999998`, 
               129.28500000000003`}, {205.29299999999998`, 
               128.05900000000003`}, {206.32000000000002`, 
               124.64799999999997`}, {208.57399999999998`, 
               125.16400000000004`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{200.33200000000002`, 
               127.031}, {198.531, 125.68}, {199.754, 122.97300000000001`}, {
               202.266, 123.61700000000002`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{203.617, 
               127.22300000000001`}, {203.684, 126.51600000000002`}, {
               205.29299999999998`, 125.42200000000003`}, {
               206.64499999999998`, 125.87099999999998`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{194.086, 
               128.38299999999998`}, {191.836, 127.418}, {191.961, 121.75}, {
               199.562, 124.83999999999997`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{189., 126.12900000000002`}, {
               185.844, 124.58200000000005`}, {186.875, 120.332}, {193.766, 
               124.39099999999996`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{194.344, 
               124.06600000000003`}, {193.508, 123.42200000000003`}, {192.605,
                120.59000000000003`}, {195.762, 121.68799999999999`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{188.55100000000002`, 
               122.71500000000003`}, {187.262, 121.55900000000003`}, {188.098,
                119.17200000000003`}, {190.934, 120.07800000000003`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{181.918, 122.332}, {179.602, 
               120.97700000000003`}, {184.68800000000002`, 
               119.17200000000003`}, {188.098, 122.781}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{183.465, 
               120.65599999999995`}, {182.434, 119.625}, {182.434, 
               116.60200000000003`}, {185.137, 117.695}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{176.895, 
               119.43400000000003`}, {175.35200000000003`, 
               118.27300000000002`}, {177.98800000000003`, 
               116.72700000000003`}, {182.82000000000002`, 
               118.85199999999998`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{178.82800000000003`, 
               117.75799999999998`}, {177.023, 116.27700000000004`}, {
               177.21899999999997`, 114.41000000000003`}, {
               179.85500000000002`, 114.988}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{173.48000000000002`, 
               116.92200000000003`}, {171.48800000000003`, 
               115.11700000000002`}, {174.383, 113.89499999999998`}, {177.859,
                115.375}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{173.547, 
               114.92200000000003`}, {170.13299999999998`, 
               113.37900000000002`}, {171.61299999999997`, 
               110.54700000000003`}, {173.738, 111.64099999999996`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{287.52, 
               105.07400000000007`}, {286.727, 103.37099999999998`}, {289.324,
                101.98400000000004`}, {291.77, 102.37099999999998`}, {294.121,
                102.738}, {296.367, 104.67599999999999`}, {
               294.60200000000003`, 107.39099999999996`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{294.72999999999996`, 
               104.043}, {297.051, 102.238}, {301.172, 104.30099999999999`}, {
               301.172, 107.00800000000004`}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{436.78099999999995`,
                376.93399999999997`}, {426.477, 382.08599999999996`}, {
               405.10200000000003`, 391.617}, {399.047, 383.887}, {404.582, 
               386.207}, {420.809, 383.758}, {434.203, 371.395}}}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{436.78099999999995`,
                376.93399999999997`}, {426.477, 382.086}, {
               405.10200000000003`, 391.617}, {399.047, 383.887}, {404.582, 
               386.207}, {420.809, 383.758}, {434.203, 371.395}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{443.027, 377.47999999999996`}, {431.113, 
               391.35900000000004`}, {424.09799999999996`, 388.25}, {
               415.53099999999995`, 393.03099999999995`}, {407.484, 
               397.52299999999997`}, {394.668, 398.441}, {392.184, 
               391.29699999999997`}, {403.941, 397.02299999999997`}, {414.734,
                388.219}, {421.363, 387.15200000000004`}, {430.469, 
               385.691}, {435.60900000000004`, 378.65200000000004`}, {
               438.27299999999997`, 375.414}}}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{443.027, 377.48}, {431.113, 391.359}, {
               424.09799999999996`, 388.25}, {415.53099999999995`, 393.031}, {
               407.484, 397.523}, {394.668, 398.44100000000003`}, {392.184, 
               391.297}, {403.941, 397.023}, {414.734, 388.219}, {421.363, 
               387.152}, {430.469, 385.69100000000003`}, {435.60900000000004`,
                378.652}, {438.27299999999997`, 375.414}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{487.90599999999995`, 379.254}, {481.72299999999996`, 
               393.41799999999995`}, {468.504, 389.719}, {462.66400000000004`,
                395.73799999999994`}, {454.168, 404.49199999999996`}, {432.66,
                412.605}, {423.77299999999997`, 406.555}, {443.348, 
               407.58599999999996`}, {451.684, 393.062}, {462.148, 388.008}, {
               469.621, 384.402}, {477.60200000000003`, 376.676}, {
               487.90599999999995`, 379.254}}}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{487.90599999999995`, 379.254}, {481.72299999999996`, 
               393.418}, {468.504, 389.719}, {462.66400000000004`, 395.738}, {
               454.168, 404.492}, {432.66, 412.605}, {423.77299999999997`, 
               406.555}, {443.348, 407.586}, {451.684, 393.062}, {462.148, 
               388.008}, {469.621, 384.402}, {477.60200000000003`, 376.676}, {
               487.90599999999995`, 379.254}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{464.727, 
               380.79699999999997`}, {454.168, 393.93399999999997`}, {
               437.93799999999993`, 405.52299999999997`}, {430.469, 
               401.14500000000004`}, {440.258, 400.629}, {443.348, 393.805}, {
               450.305, 389.42599999999993`}, {457.258, 385.047}, {454.168, 
               378.73799999999994`}, {464.727, 380.79699999999997`}}}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{464.727, 
               380.797}, {454.168, 393.93399999999997`}, {437.93799999999993`,
                405.523}, {430.469, 401.145}, {440.258, 400.629}, {443.348, 
               393.805}, {450.305, 389.426}, {457.258, 385.047}, {454.168, 
               378.738}, {464.727, 380.797}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{414.5, 357.617}, {
               403.42199999999997`, 361.73799999999994`}, {381.789, 
               363.79699999999997`}, {371.742, 351.176}, {388.48799999999994`,
                348.34400000000005`}, {413.727, 349.89099999999996`}, {414.5, 
               357.617}}}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{414.5, 357.617}, {
               403.42199999999997`, 361.738}, {381.789, 363.797}, {371.742, 
               351.176}, {388.48799999999994`, 348.344}, {413.727, 349.891}, {
               414.5, 357.617}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}}}, {{{412.441, 352.72299999999996`}, {401.363, 
               357.875}, {392.715, 350.68}, {382.305, 351.691}, {
               362.47299999999996`, 353.625}, {348.305, 352.465}, {346.504, 
               342.93399999999997`}, {357.83599999999996`, 
               353.10900000000004`}, {376.895, 344.73799999999994`}, {384.621,
                346.79699999999997`}, {392.35200000000003`, 
               348.85900000000004`}, {420.941, 347.055}, {429.953, 343.191}, {
               425.316, 348.85900000000004`}, {418.105, 
               350.40599999999995`}, {412.441, 352.72299999999996`}}}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}}}, {{{412.441, 352.723}, {401.363, 357.875}, {392.715, 
               350.67999999999995`}, {382.305, 351.69100000000003`}, {
               362.47299999999996`, 353.625}, {348.305, 
               352.46500000000003`}, {346.504, 342.93399999999997`}, {
               357.83599999999996`, 353.109}, {376.895, 344.738}, {384.621, 
               346.797}, {392.35200000000003`, 348.85900000000004`}, {420.941,
                347.055}, {429.953, 343.19100000000003`}, {425.316, 
               348.85900000000004`}, {418.105, 350.406}, {412.441, 352.723}}},
               
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}}}, {{{447.21099999999996`, 382.215}, {444.637, 
               390.715}, {444.762, 399.72999999999996`}, {457.512, 
               399.08599999999996`}, {454.29299999999995`, 403.078}, {442.445,
                405.137}, {440.512, 390.199}, {426.477, 400.5}, {411.148, 
               402.305}, {408.32, 393.41799999999995`}, {415.53099999999995`, 
               399.60200000000003`}, {426.734, 395.094}, {440.125, 379.895}, {
               441.28499999999997`, 380.539}, {444.375, 381.828}, {
               447.21099999999996`, 382.215}}}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}}}, {{{447.21099999999996`, 382.21500000000003`}, {
               444.637, 390.71500000000003`}, {444.762, 399.73}, {457.512, 
               399.086}, {454.29299999999995`, 403.078}, {442.445, 405.137}, {
               440.512, 390.199}, {426.477, 400.5}, {411.148, 402.305}, {
               408.32, 393.418}, {415.53099999999995`, 399.602}, {426.734, 
               395.094}, {440.125, 379.895}, {441.28499999999997`, 380.539}, {
               444.375, 381.82800000000003`}, {447.21099999999996`, 
               382.21500000000003`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIxIGYC4h1yra8D91U58Opumvtevdzh0FeNmH67Koed
IPGqcgdbruuLCyZWOhzzNu90ZKhweFtjbxp3oMpBNirF+r5pBVw9mF9d4ZD7
/PfKjw2VDotct33+G1PhINx84NTCqZUODCCQBzXPusLh0yXfJIFf5Q6djglP
LzhB6VNQ+/nKHbacKNs336HcoVpknfvDK2UOVyteqhmuKHMo3zdfSn91uYP7
wyqRdcFlEHddKHe4oHT7Z92WMgegq3fIrSyHmL8Eql653AGkLOFimUPGRKAP
Msvh/gU52399ucN9/97peXXlDuDwEKt0MLirwtZoWw7xV3YVRF13mcOy2UcU
NpyC+jcS6i6BGofHS4ESSWUO6OEJADBhoUo=
               "]]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIxIGYC4h1yra8D91U58Olumvtevdzh0FeNmH67Kgew
eFW5gy3X9cUFEysdjnmbdzoyVDi8rbE3jTtQ5SAblWJ937QCrh7Mr65wyH3+
e+XHhkqHRa7bPv+NqXAQbj5wauHUSgcGEMiDmmdd4fDpkm+SwK9yh07HhKcX
nKD0Kaj9fOUOW06U7ZvvUO5QLbLO/eGVMoerFS/VDFeUOZTvmy+lv7rcweNh
lci64DKIuy6UO1xUuv2zbkuZA9DVO+RWlkPMXwJVr1zu4ANUlnCxzCFjItAH
meVw/4Kc7b++3OG+f+/0vLpyiL/FKh3076qwNdqWQ/yVXQVR113msGz2EYUN
p6D+jYS6S6DG4fFSoERSmQN6eAIAMlGhTg==
               "],
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{422.227, 356.328}, {
               416.066, 368.90599999999995`}, {396.082, 
               357.48799999999994`}, {392.055, 369.672}, {386.555, 351.82}, {
               420.47299999999996`, 361.699}, {422.227, 356.328}}}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{422.227, 
               356.32800000000003`}, {416.066, 368.906}, {396.082, 357.488}, {
               392.055, 369.672}, {386.555, 351.82}, {420.47299999999996`, 
               361.699}, {422.227, 356.32800000000003`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{549.3359999999999, 342.676}, {553.5269999999999, 
               340.594}, {557.148, 343.867}, {550.738, 346.43799999999993`}, {
               554.934, 344.355}, {558.59, 347.551}, {552.1800000000001, 
               350.117}, {556.375, 348.039}, {560.031, 351.22999999999996`}, {
               553.621, 353.801}, {551.91, 352.078}, {549.4649999999999, 
               345.77}, {549.3359999999999, 342.676}}}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{549.3359999999999, 342.676}, {553.5269999999999, 
               340.594}, {557.148, 343.867}, {550.738, 346.438}, {554.934, 
               344.355}, {558.59, 347.55100000000004`}, {552.1800000000001, 
               350.11699999999996`}, {556.375, 348.039}, {560.031, 351.23}, {
               553.621, 353.801}, {551.91, 352.078}, {549.4649999999999, 
               345.77}, {549.3359999999999, 342.676}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4vJ986X0bRodjnmbdzq+K3PwAVIJbY0OQPLp
ha5yh8qXaoYcZo0Ob2vsTeMOlDvobpr7fvmERofW14E75BIrHBYX2HJdv9Xo
sOVE2b75TyocOkD65kHNs6l0AJv/tNHh8FeNmP5FlQ5LQOp/Nzro31Vhazxc
6fCwSmSdu26Tgx3X9cUFrFUORxU2FGUYNjmAtCe4V0Hk/ZscJkuwhPFtroTY
f6XR4b5/7/S8eZUO05y7c57faXSwBelfX+EQ23/oq8ajRoeMiUAXi1c4yIEc
uq7R4YLS7Z91KhUODCAwu9FBq13s5jnlcoj7pyH8H5Vifd+/pdFh6ewjChvK
yhzQwwcAOMWKPA==
               "]]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4vJ986X0bRodjnubdzq+K3PwAVIJbY0OQPLp
ha5yh8qXaoYcZo0O72rsTeMOlDvobpr7fvmERofW14E75BIrHBYX2HJdv9Xo
sOVE2b75TyocOkD65jU6HAOZZ1PpADb/aaPDoa8aMf2LKh2WgNT/bnTQv6vC
1ni40uFhlcg6d90mB6Do4gLWKoejChuKMgybIO5wr4LI+zc5TJFgCePbXAmx
/0qjw33/3ul58yodpjl35zy/0+hgB9K/vsIhth9o06NGh4yJb2vsxSsc5EAO
XdfocFHp9s86lQoHBhCY3eig3S5285xyOcT90xD+j0qxvu/f0uiwbPYRhQ1l
ZQ7o4QMAO9WKRA==
               "],
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{555.648, 362.512}, {560.797, 373.58599999999996`}, {
               566.711, 373.371}, {569.555, 377.707}, {574.9649999999999, 
               385.949}, {586.4219999999999, 376.289}, {596.082, 383.629}, {
               594.41, 373.199}, {581.4019999999999, 376.93399999999997`}, {
               575.738, 370.23799999999994`}, {570.07, 363.539}, {565.434, 
               360.449}, {555.648, 362.512}}}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{555.648, 362.512}, {560.797, 373.586}, {566.711, 
               373.371}, {569.555, 377.707}, {574.9649999999999, 385.949}, {
               586.4219999999999, 376.289}, {596.082, 383.629}, {594.41, 
               373.199}, {581.4019999999999, 376.93399999999997`}, {575.738, 
               370.238}, {570.07, 363.539}, {565.434, 360.449}, {555.648, 
               362.512}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{556.934, 358.90599999999995`}, {565.949, 366.117}, {
               572.594, 361.305}, {578.828, 365.08599999999996`}, {594.535, 
               374.617}, {600.8519999999999, 363.156}, {614.887, 367.66}, {
               611.148, 358.648}, {590.418, 366.375}, {581.4019999999999, 
               359.676}, {572.387, 352.97999999999996`}, {540.707, 346.543}, {
               556.934, 358.90599999999995`}}}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{556.934, 358.906}, {565.949, 366.117}, {572.594, 
               361.305}, {578.828, 365.086}, {594.535, 374.617}, {
               600.8519999999999, 363.156}, {614.887, 367.65999999999997`}, {
               611.148, 358.648}, {590.418, 366.375}, {581.4019999999999, 
               359.676}, {572.387, 352.98}, {540.707, 346.543}, {556.934, 
               358.906}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}}}, {{{530.664, 307.52}, {530.531, 311.641}, {526.668, 
               316.92199999999997`}, {521.262, 317.566}, {515.8519999999999, 
               318.207}, {513.531, 323.875}, {509.414, 324.133}, {
               505.29299999999995`, 324.39099999999996`}, {
               502.58599999999996`, 332.633}, {496.91799999999995`, 
               332.504}, {491.254, 332.375}, {488.93799999999993`, 
               325.03499999999997`}, {502.199, 318.34000000000003`}, {
               515.4649999999999, 311.641}, {530.148, 303.914}, {530.664, 
               307.52}}}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}}}, {{{530.664, 307.52}, {530.531, 
               311.64099999999996`}, {526.668, 316.922}, {521.262, 
               317.56600000000003`}, {515.8519999999999, 318.207}, {513.531, 
               323.875}, {509.414, 324.133}, {505.29299999999995`, 324.391}, {
               502.58599999999996`, 332.633}, {496.91799999999995`, 
               332.504}, {491.254, 332.375}, {488.93799999999993`, 
               325.03499999999997`}, {502.199, 318.34000000000003`}, {
               515.4649999999999, 311.64099999999996`}, {530.148, 303.914}, {
               530.664, 307.52}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{513.918, 304.043}, {
               508.254, 303.78499999999997`}, {507.47999999999996`, 
               295.543}, {502.074, 295.28499999999997`}, {509.539, 
               291.29299999999995`}, {514.949, 297.09}, {518.8119999999999, 
               302.23799999999994`}}}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{513.918, 304.043}, {
               508.254, 303.785}, {507.47999999999996`, 295.543}, {502.074, 
               295.285}, {509.539, 291.293}, {514.949, 297.09000000000003`}, {
               518.8119999999999, 302.238}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{518.555, 303.012}, {
               513.664, 298.89099999999996`}, {512.246, 290.262}, {519.328, 
               287.816}, {515.0780000000001, 293.676}, {526.8009999999999, 
               296.316}, {523.191, 301.727}}}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{518.555, 
               303.01199999999994`}, {513.664, 298.891}, {512.246, 290.262}, {
               519.328, 287.81600000000003`}, {515.0780000000001, 293.676}, {
               526.8009999999999, 296.31600000000003`}, {523.191, 
               301.72700000000003`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{523.449, 302.754}, {
               519.586, 295.28499999999997`}, {529.504, 294.383}, {
               526.9259999999999, 288.719}, {532.594, 290.004}, {533.496, 
               300.695}, {528.3439999999999, 303.527}}}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{523.449, 302.754}, {
               519.586, 295.285}, {529.504, 294.38300000000004`}, {
               526.9259999999999, 288.719}, {532.594, 290.004}, {533.496, 
               300.695}, {528.3439999999999, 303.52700000000004`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}}}, {{{485.58599999999996`, 318.72299999999996`}, {
               494.85900000000004`, 319.23799999999994`}, {
               503.34000000000003`, 314.22299999999996`}, {509.027, 
               306.10200000000003`}, {512.633, 300.953}, {524.738, 
               298.89099999999996`}, {528.8589999999999, 303.012}, {532.98, 
               307.133}, {530.664, 315.89099999999996`}, {520.3589999999999, 
               313.059}, {517.7810000000001, 317.43799999999993`}, {510.312, 
               315.89099999999996`}, {506.71099999999996`, 
               319.4959999999999}, {503.10200000000003`, 
               323.10200000000003`}, {489.191, 333.40599999999995`}, {
               485.58599999999996`, 318.72299999999996`}}}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}}}, {{{485.58599999999996`, 318.723}, {
               494.85900000000004`, 319.238}, {503.34000000000003`, 
               314.223}, {509.027, 306.102}, {512.633, 300.953}, {524.738, 
               298.891}, {528.8589999999999, 303.01199999999994`}, {532.98, 
               307.133}, {530.664, 315.891}, {520.3589999999999, 
               313.05899999999997`}, {517.7810000000001, 317.438}, {510.312, 
               315.891}, {506.71099999999996`, 319.496}, {503.10200000000003`,
                323.102}, {489.191, 333.406}, {485.58599999999996`, 318.723}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}}}, {{{520.3589999999999, 313.059}, {
               517.914, 312.543}, {517.141, 308.29299999999995`}, {
               518.6840000000001, 306.10200000000003`}}}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{520.3589999999999, 
               313.05899999999997`}, {517.914, 312.543}, {517.141, 308.293}, {
               518.6840000000001, 306.102}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}}}, {{{525.641, 
               310.47999999999996`}, {526.414, 309.195}, {525.898, 
               307.39099999999996`}, {525.512, 306.48799999999994`}}}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{525.641, 310.48}, {526.414, 
               309.195}, {525.898, 307.391}, {525.512, 306.488}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}}}, {{{500.27, 318.34000000000003`}, {
               505.03099999999995`, 318.082}, {505.93799999999993`, 
               314.60200000000003`}, {511.08599999999996`, 313.316}}}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{500.27, 318.34000000000003`}, {
               505.03099999999995`, 318.082}, {505.93799999999993`, 
               314.602}, {511.08599999999996`, 313.31600000000003`}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJ5IGZigAKheofc579XflxQ4rD1RNm++TwNDrG7PHmY
4kscsvaUTJYobXDImPi2xl61xEE2KsX6/tYGh9bXgTvkbhc7bAGp/9YA0T+h
2IFXd9Pc91GNDjvkgCpqih2Wzj6isGFTo4MVSOHaYgdbruuLC7iaIObdh8pv
bnI49FUjpp+nxOGyb5JAxOomh8cgCaNiCP9mk4O3eadjwvxihw7HhKcX5jU5
dIJokRIHwQjLLSc0ofKaJQ7TnLtznmtDzZtSAqE/NULkv0LNP9noYHBXha1x
a4nDts9/r1S8b3TQahe7eW5/CUSdQJODcPOBUwsNSxzK982X0j/aCPHX92KI
fZcbIf5PLnG4oHT7Z928Rgc+kPzhEoeYfqCN6Y1w+3WAwsu7oPrrSxys7/v3
Tl/XCHE/RwnEn/GN8PAEOeO7TqPDMZBD9hU7LCkAhtjjBgdQsPs/Lnbw4mHS
bl+LiA+w+8qh/PQSiL6eOggdVuqAHr8AWwfnhw==
               "]]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJ5IGZigAKheoec579XflxQ4rD1RNm++TwNDnG7PHmY
4kscsvaUTJYobXDImPi2xl61xEE2KsX6/tYGh9bXgTvkbhc7bAGp/9YA0T+h
2IFXd9Pc91GNDjvkgCpqih2Wzj6isGFTo4MVSOHaYgdbruuLC7iaIObdh8pv
bnI4/FUjpp+nxOGyb5JAxOomh8cgCaNiCP9mk4OPeadjwvxihw7HhKcX5jU5
dIFokRIHwQjLLSc0ofKaJQ7TnLtznmtDzZtS4nAIRH9qhMh/hZp/stFB/64K
W+PWEodtn/9eqXjf6KDdLnbz3P4SB2+QOoEmB6HmA6cWGpY4lO+bL6V/tNGB
D+Sv78UQ+y43QvyfXOJwQen2z7p5UPnDJQ4x/UAb0xvh9usAhZd3QeXrSxys
7/v3Tl/XCHE/RwnEn/GN8PAEOeO7TqPDcZBD9hU7LCkAhtjjBgdQsPs/Lnbw
4mHSbl+LiA+w+8qh/PQSh2MgfT11EP1hpQ7o8QsAYl/nkA==
               "],
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{538.648, 336.754}, {533.496, 334.43799999999993`}, {
               536.8439999999999, 329.027}, {528.8589999999999, 
               325.93799999999993`}, {520.875, 322.84400000000005`}, {
               515.3359999999999, 315.762}, {517.141, 309.71099999999996`}, {
               522.5509999999999, 321.559}, {532.0780000000001, 321.043}, {
               535.4259999999999, 325.68}, {538.777, 330.316}, {543.668, 
               337.141}, {538.648, 336.754}}}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{538.648, 336.754}, {533.496, 334.438}, {
               536.8439999999999, 329.02700000000004`}, {528.8589999999999, 
               325.938}, {520.875, 322.844}, {515.3359999999999, 315.762}, {
               517.141, 309.711}, {522.5509999999999, 321.55899999999997`}, {
               532.0780000000001, 321.043}, {535.4259999999999, 
               325.67999999999995`}, {538.777, 330.31600000000003`}, {543.668,
                337.14099999999996`}, {538.648, 336.754}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIxIGYC4gtKt3/WPWhwcH9YJbLuf4mDLdf1xQX3Ghwy
Jr6tsc8sgdCLGxw+XfJNElhQ4uBj3umYsKvBYensIwobzhQ72Nz3751+sMFh
Rp5Q84GuYgcGEDjf4ADknVooX+wQlWJ9339HgwNIWd6WIgeBCMstJ341QMRF
ix0qX6oZclyA6n9Q7DDNuTvn+dsGB4O7KmyNuiUQdX8aHLaeKNs3P6jEYXEB
0IV8jQ475FpfB/aUOGTtKZksIdboYLUFqGBviQOIms/WCHF3eomDzqa575ez
NzqA/XkMar5hI8TcuVA+fyPE3XYlEP/0NjrIghQcLIG4zxyqvroU4m8tqHq/
UgdPHibtduZGB2GQf/+WOKCHJwBBqZ8M
               "]]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIxIGYC4gtKt3/WPWhw8HhYJbLuf4mDLdf1xQX3Ghwy
Jr6tsc8sgdCLGxw+XfJNElhQ4uBj3umYsKvBYdnsIwobzhQ72Nz3751+sMFh
ep5Q84GuYgcGEDjf4ADknVooX+wQlWJ9339Hg8MDoLK8LUUOAhGWW078aoCI
ixY7VL5UM+S40OAwA6T/QbHDNOfunOdvGxz076qwNeqWQNT9aXDYcqJs3/yg
EofFBUAX8jU67JBrfR3YU+KQtadksoRYo4MVSMHeEog6tkaIu9NLHHQ2zX2/
nL3R4SLIn8eg5hs2QsydC+XzN0LcbVcC8U9vo4MMSMHBEoj7zKHqq0sdloL8
rQVV71fq4MnDpN3O3Ajx798SB/TwBABCqZ8M
               "],
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}}}, {{{513.7890000000001, 345.383}, {515.0780000000001, 
               343.449}, {516.3669999999998, 338.559}, {515.207, 
               335.85200000000003`}, {517.7810000000001, 
               337.39799999999997`}, {521.52, 341.39099999999996`}, {522.676, 
               344.094}, {527.9569999999999, 343.32}, {530.016, 336.754}, {
               524.996, 333.92199999999997`}, {528.086, 
               333.92199999999997`}, {533.3669999999998, 
               333.92199999999997`}, {536.328, 337.39799999999997`}, {
               532.7230000000001, 341.39099999999996`}, {521.52, 347.57}, {
               513.7890000000001, 345.383}}}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}}}, {{{513.7890000000001, 345.38300000000004`}, {
               515.0780000000001, 343.44899999999996`}, {516.3669999999998, 
               338.55899999999997`}, {515.207, 335.852}, {517.7810000000001, 
               337.398}, {521.52, 341.391}, {522.676, 344.094}, {
               527.9569999999999, 343.32}, {530.016, 336.754}, {524.996, 
               333.922}, {528.086, 333.922}, {533.3669999999998, 333.922}, {
               536.328, 337.398}, {532.7230000000001, 341.391}, {521.52, 
               347.57}, {513.7890000000001, 345.38300000000004`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 
               3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
               1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, CompressedData["
1:eJxdlAtIFVEQhm8aYaESZWVFZlFiRphgRfZwCsQyohKSkhKRSimy8Ozr7u69
dxeJXkiYhVSEpVkJJVoWFhVa9jIQsfIWYmYikvZAJaSH1R7/g1ALy2H3zMz5
/29md07WgdTdgS6Xa4xzpzp3gHNn3F0fHDDToISaZ8qD+wpNzq9rvBhi0Kz0
XSs6nit0qG9LbcSQTqsn+MsOvlaoOHdSfl2Tjvh2hVz8StWJh28aUuj9poLi
3JM6Lef72SrxpeSXjrw9KuUUfjYTOwwaaNmYNTFDo+a5bd+9GSat4vVLVLrF
4/M8qP9ZxL/0QMd4DfqmeKk06fbgsEujpxuWHV2T4sXaq0L3Yy+Vn2uIrFqp
kR5WmdyZ5kPefA1663x0dE1md3ODSsmdTsQLH/H0TL+Ktc1Hc6rycgq7xXO/
D3F9Ku29JxWFL7Do4bfoHSfGadC32ULdGqF/p0UGP3edSi8dm9vyLaFDhc9K
i2Lb542z41Q6wnU0ivzfCrgMWFQb4TiOEueF2NTFDUWr5P4YFRc0zQZXJ35k
P8GmSdzfbJUcKq+0bBv58SryvDZ4NSjwfcoG360KPeI+1tngpSikPiiZEbvS
ppjDU982HZexH2/Dzw+JnC4XFHdZ4FwvET+mtswi/jo3XKaU4ICFh1cJ/6Uy
RXKON33o3x0Zujf7aCefux5J9NkLXWESPeHAL3jpMtdzlqFulUfMDaPQRTfO
f93uoRC+DjHw7jVRz8/Ql0smvdYcUBr7d76mM/Rz0ADvPAZuzEB/sxm4hZk4
12KY21YDfq4y6Moy4b+a0RczcUnGBxOc7zKcU29i3uIkcJzswf5aCfEt4ryv
ov47A/6yJSoKH5sW6tdHeYzEpxjoS4WE7+qPgbw0sZ9uIv+6BH/7DKzVEvy7
DMzzRhn1T+uYs2AZuj658b5c8F+qQ5+P4bv2aDj/DEPcFZUW8/ktF8/O3I1w
OSLiSxTa3/Ozoj+IgZNHhY5WCf25pmH/jchPdCNvnwRup92j8zXynfjd4Bgo
ow9jdehMkwUnHf6ZDB4xOuLzZXBI0vF/OCbmr1X8R4Zl9LnGLXgp9P//8C8A
IlPh
               "]]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 
               3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
               1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, CompressedData["
1:eJxdVAlIFFEY3lSiQiXMym6Nig5CBCsyy98gNCsyoaWiRKRSKix8c+3M7O4M
EmoRYRZ2EFZmJVRYWVhUWNllIJ1uER0mImklKiHdzdvvIZQwDOP7j+96G5e7
PWtTqMvlGuQ8Wc4T4jzZ15aGh4wzaH7dA+XmDYVGFDU0HY8waMK6jQvePVRo
Z9eq+on9Oi0aFqja8UKhioKoooZmHfVvFHLxvyydePnKfoXer9xTUbBPnOep
xF+VP3U6yPs2q5Rf9tlMeWdQ79MVucOzNXo8+fU3X7aJ+ZUqXeb1hV70fxb1
z7zAMVQDvpE+OrHkSt8vl0b3l80rTc3w4d2pAvddH5060hhbm6yRHn0+rdXt
pyjeN1UD3gY/labmtD9uVCmt1al45KflTntOQCU+Jue1n+JqC/PL2sV3j5/S
eV2XSluuS+UxMyy6/XX6+r2DNeDLtDC3TuDfYJHB96ar9MyhuaZIfLtVWsh5
nrco/s2UwXaCSiUcR5Po/61Al16L6ic6jKeJfRE2tVU7hKar5Pk4LWHIaBu6
OvXB8yQb/Cap5KjyXMuz0Z+oos9nQ69GBbz329B3tUJ3OI90G3opCqk3K8fG
J9s0q3jUq+bdMs4Tbej4XSLH5T0VbRaN5zrfkoivqa+y4HuMTBnhIbOKF1qo
PyFTLNfxkh/+XZWBO9NPwdx1SJQU9NlHuziuaInuccGPCf8OM+LrCmq9IjeM
ImdfPNq91ot3P4PenSbmBRh8OWnSc80RSmP/5msMg599BvQuZNCNGfA3j0G3
aBN8LIa8txjw7wwDrlwT/C8w+mKmzMn+YELnawz+3jIxN0GimVzHEV6cL5ZQ
/1Ts6xbz3xrglydReUyYOzKgD+gRrM8wSOG+1Ejw7Y+B++QW5+tM9J+TwG+r
gTxfkMDfZcCHFTLmH9CRs3AZuD55aD//f7XQf64OfH6Ge+3VsP8QQ/9pFfmt
Ft9O7oK6lIj6SoW2dfyo6RnCcB+9Kj3hOFok+HNWw/lL0Z/iQd9WCff7gGcg
X8E9AQ/yGCrDhzAd990tI8/ROvgzGXrM1FFfJEOPJTp47RL5a9Hgzy8Z+arz
CL0U+v/38C8RUlPn
               "],
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{546.875, 367.90999999999997`}, {547.2230000000001, 
               367.188}, {547.4019999999999, 366.246}, {547.4019999999999, 
               365.08599999999996`}, {547.4019999999999, 
               359.41799999999995`}, {538.9019999999999, 359.16}, {538.391, 
               350.789}, {538.121, 346.414}, {537.617, 343.965}, {
               534.6519999999999, 344.47999999999996`}, {531.691, 
               344.9959999999999}, {529.117, 349.633}, {531.949, 355.039}}}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{546.875, 367.90999999999997`}, {547.2230000000001, 
               367.188}, {547.4019999999999, 366.246}, {547.4019999999999, 
               365.086}, {547.4019999999999, 359.418}, {538.9019999999999, 
               359.15999999999997`}, {538.391, 350.789}, {538.121, 346.414}, {
               537.617, 343.96500000000003`}, {534.6519999999999, 344.48}, {
               531.691, 344.996}, {529.117, 349.633}, {531.949, 355.039}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}}}, {{{437.93799999999993`, 
               372.29699999999997`}, {435.805, 373.79699999999997`}, {433.668,
                374.40599999999995`}, {431.758, 374.42199999999997`}}}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{437.93799999999993`, 
               372.297}, {435.805, 373.797}, {433.668, 374.406}, {431.758, 
               374.422}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{484.594, 
               382.684}, {491.414, 379.72999999999996`}, {494.73799999999994`,
                372.64500000000004`}, {504.648, 372.29699999999997`}, {
               514.1840000000001, 371.965}, {520.102, 358.133}, {536.07, 
               367.148}, {536.504, 367.39099999999996`}, {536.9259999999999, 
               367.617}, {537.3359999999999, 367.828}}}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{484.594, 
               382.68399999999997`}, {491.414, 379.73}, {494.73799999999994`, 
               372.645}, {504.648, 372.297}, {514.1840000000001, 
               371.96500000000003`}, {520.102, 358.133}, {536.07, 367.148}, {
               536.504, 367.391}, {536.9259999999999, 367.617}, {
               537.3359999999999, 367.82800000000003`}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}}}, {{{508., 380.301}, {506.578, 
               378.03499999999997`}, {506.254, 374.879}, {506.64500000000004`,
                372.105}}}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{508., 380.301}, {506.578, 
               378.03499999999997`}, {506.254, 374.879}, {506.64500000000004`,
                372.105}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{476.828, 351.176}, {464.727, 351.176}, {461.633, 
               344.9959999999999}, {461.633, 339.07}, {461.633, 333.148}, {
               467.301, 325.42199999999997`}, {477.348, 
               325.42199999999997`}, {487.39099999999996`, 
               325.42199999999997`}, {492.801, 331.60200000000003`}, {492.801,
                338.301}, {492.801, 344.9959999999999}, {486.617, 351.176}, {
               476.828, 351.176}}}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{476.828, 351.176}, {464.727, 351.176}, {461.633, 
               344.996}, {461.633, 339.07}, {461.633, 333.14799999999997`}, {
               467.301, 325.422}, {477.348, 325.422}, {487.39099999999996`, 
               325.422}, {492.801, 331.602}, {492.801, 338.30100000000004`}, {
               492.801, 344.996}, {486.617, 351.176}, {476.828, 351.176}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{479.02, 325.68}, {478.762, 329.027}, {
               472.71099999999996`, 328.512}, {472.965, 
               331.08599999999996`}, {473.22299999999996`, 
               333.66400000000004`}, {476.316, 334.691}, {476.316, 338.301}, {
               476.316, 341.90599999999995`}, {481.72299999999996`, 
               342.16400000000004`}, {483.527, 339.328}, {485.328, 
               336.4959999999999}, {490.73799999999994`, 330.957}, {
               491.89799999999997`, 333.79299999999995`}}}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{479.02, 325.67999999999995`}, {478.762, 
               329.02700000000004`}, {472.71099999999996`, 
               328.51199999999994`}, {472.965, 331.086}, {473.22299999999996`,
                333.664}, {476.316, 334.69100000000003`}, {476.316, 
               338.30100000000004`}, {476.316, 341.906}, {481.72299999999996`,
                342.164}, {483.527, 339.328}, {485.328, 336.496}, {
               490.73799999999994`, 330.957}, {491.89799999999997`, 333.793}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}}}, {{{483.527, 339.328}, {480.691, 
               336.4959999999999}, {479.40599999999995`, 330.699}, {483.141, 
               326.195}}}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{483.527, 339.328}, {480.691, 
               336.496}, {479.40599999999995`, 330.69899999999996`}, {483.141,
                326.195}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}}}, {{{487.39099999999996`, 
               334.949}, {486.48799999999994`, 333.02}, {486.234, 330.059}, {
               487.262, 328.254}}}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{487.39099999999996`, 
               334.94899999999996`}, {486.48799999999994`, 333.02}, {486.234, 
               330.05899999999997`}, {487.262, 328.254}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{535.488, 344.414}, {
               544.9569999999999, 343.645}, {546.5659999999999, 354.074}, {
               539.484, 354.719}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{523.8359999999999, 372.555}, {
               520.555, 376.742}, {513.02, 378.156}, {512.891, 369.27}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
               511.98799999999994`, 359.16}, {508.77, 367.148}, {500.527, 
               368.305}, {496.14500000000004`, 364.312}, {492.504, 
               360.99199999999996`}, {492.414, 352.33599999999996`}, {500.27, 
               350.53499999999997`}, {502.97299999999996`, 353.754}, {508.254,
                358.004}, {511.98799999999994`, 359.16}}}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
               511.98799999999994`, 359.15999999999997`}, {508.77, 367.148}, {
               500.527, 368.305}, {496.14500000000004`, 364.312}, {492.504, 
               360.992}, {492.414, 352.336}, {500.27, 350.53499999999997`}, {
               502.97299999999996`, 353.754}, {508.254, 358.004}, {
               511.98799999999994`, 359.15999999999997`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}}}, {{{508.445, 364.184}, {503.809, 
               368.305}, {496.984, 360.51599999999996`}, {503.168, 
               353.367}}}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{508.445, 
               364.18399999999997`}, {503.809, 368.305}, {496.984, 
               360.51599999999996`}, {503.168, 353.367}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{523.8359999999999, 
               372.555}, {521.004, 375.582}, {514.824, 373.199}, {516.559, 
               367.082}, {517.914, 369.914}, {520.809, 372.29699999999997`}, {
               523.8359999999999, 372.555}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{506.328, 
               356.059}, {508.28099999999995`, 357.47299999999996`}, {
               510.29299999999995`, 358.637}, {511.98799999999994`, 359.16}, {
               511.062, 361.453}, {509.727, 363.184}, {508.184, 
               364.39099999999996`}, {506.71099999999996`, 
               365.40599999999995`}, {502.477, 359.715}, {506.328, 
               356.059}}}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{498.72299999999996`,
                366.504}, {494.08599999999996`, 369.594}, {
               489.83599999999996`, 369.336}, {488.41799999999995`, 
               366.762}, {485.074, 366.891}, {482.305, 364.44100000000003`}, {
               482.172, 359.547}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{489.324, 357.488}, {
               483.78499999999997`, 361.28499999999997`}, {476.188, 
               359.871}, {476.703, 351.371}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{473.35200000000003`, 
               346.543}, {476.055, 348.73}, {479.91799999999995`, 
               350.27700000000004`}, {482.883, 346.414}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{514.691, 
               354.90999999999997`}, {513.664, 353.496}, {512.891, 351.305}, {
               514.5619999999999, 347.957}, {512.504, 350.664}, {
               507.35200000000003`, 350.664}, {501.812, 343.44899999999996`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{526.9259999999999, 355.297}, {
               520.23, 354.527}, {520.3589999999999, 350.14799999999997`}, {
               525.766, 348.21500000000003`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{479.277, 371.652}, {
               473.60900000000004`, 372.812}, {469.48799999999994`, 
               369.46500000000003`}, {477.348, 366.633}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{490.09799999999996`, 
               375.51599999999996`}, {482.10900000000004`, 377.449}, {
               478.89099999999996`, 375.391}, {482.4959999999999, 373.586}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{467.043, 
               343.44899999999996`}, {466.78499999999997`, 
               340.61699999999996`}, {468.328, 336.88300000000004`}, {472.965,
                341.133}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{468.59, 334.94899999999996`}, {
               468.59, 334.17999999999995`}, {468.46099999999996`, 
               333.27700000000004`}, {467.941, 332.633}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{450.043, 
               372.68399999999997`}, {445.148, 374.102}, {444.25, 378.609}, {
               449.91799999999995`, 378.223}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{448.371, 362.254}, {
               442.96099999999996`, 364.055}, {442.96099999999996`, 
               369.336}, {447.465, 368.82}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{458.414, 364.957}, {
               452.10200000000003`, 366.504}, {451.848, 370.883}, {456.613, 
               370.238}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{459.188, 378.352}, {
               455.84000000000003`, 378.609}, {450.688, 374.875}, {459.316, 
               372.68399999999997`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{468.59, 370.883}, {460.734, 
               372.039}, {460.863, 368.82}, {465.4959999999999, 366.762}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{474.512, 378.352}, {
               468.46099999999996`, 379.508}, {466.39799999999997`, 
               375.902}, {470.52, 374.359}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{455.453, 356.07}, {453.969, 
               357.293}, {452.75, 363.156}, {459.828, 361.414}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{470.133, 357.875}, {465.371, 
               359.15999999999997`}, {460.863, 354.527}, {465.23799999999994`,
                351.82}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{476.441, 
               363.40999999999997`}, {471.42199999999997`, 364.312}, {467.172,
                362.898}, {469.875, 361.094}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGZigAKXKocZeULNB7pKHYSbD5xaWFrlcEHp9s+6
aaUOx7zNOx33VUHoulIHxQ1FGRN1qx1ko1Ks73uWOgiB1BdXO+Q+/73yo0ap
g3a72M1zrjUO1SLr3B8+KoGYd7IGLg/mO9Y42HJdX1zwvcRh2ewjChtuVTsY
3FVhazyKMG86yD1rSh0OfdWI6eepdvh0yTdJYEophA6ocuDT3TT3fW4pxN0M
VQ6trwN3yO0sdXhXY28ad6gKrv8wSL9WNcT9bmUOvCB97DUOIG7CQYR7d8gB
TZhT6vB4KdBBU2ocFED+bIbyb9U4uD+sElnXXgrxl0oNRDypDKLftNoBHI7X
Sh0mS7CE8clWO5Tvmy+l317msBNkble1g9WWE2X7BMsg7pxaA1G/CMqXrYX7
HwCZTbJg
               "]]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGZigAKXKofpeULNB7pKHYSbD5xaWFrlcFHp9s+6
aaUOx7zNOx33VTkcB9F1pQ6KG4oyJupWO8hEpVjf9yx1EAKpL652yHn+e+VH
jVIH7Xaxm+dcaxyqRNa5P3xUAjHvZA1cHsx3rHGw47q+uOB7icOy2UcUNtyq
dtC/q8LWeBRh3gyQe9aUOhz6qhHTz1Pt8OmSb5LAlFIIHVDlwKe7ae773FKI
OoYqh9bXgTvkdpY6vKuxN407VAXXfxikX6sa4n63MgdekD72GgcfIDfhIMK9
O+SAJswpdXi8FOigKTUQfzZD+bdqHDweAn3UXupQDfKXSg1EPKkMot+02gEc
jtdKHSZLsITxyVY7lO+bL6XfXuawE2RuV7WD5ZYTZfsEyyDunFoDUb8Iypet
hfsfAJlVsmE=
               "],
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}}}, {{{523.57, 372.555}, {520.738, 
               372.027}, {518.2030000000001, 370.367}, {516.559, 367.082}}}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{523.57, 372.555}, {520.738, 
               372.027}, {518.2030000000001, 370.367}, {516.559, 367.082}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}}}, {{{436.26599999999996`, 
               358.395}, {434.672, 360.379}, {435.395, 362.355}, {433.684, 
               363.91799999999995`}}}]}, 
             {Thickness[0.0005555555555555556], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{436.26599999999996`, 
               358.395}, {434.672, 360.379}, {435.395, 362.355}, {433.684, 
               363.918}}},
               CurveClosed->{0}]}},
            AspectRatio->Automatic,
            ImageSize->{{128}, {85}},
            PlotRange->{{0., 720.}, {0., 480.}}], ",", 
           GraphicsBox[
            {Thickness[0.0008680555555555555], 
             {FaceForm[{RGBColor[
              0.968627, 0.8784310000000001, 0.09019610000000002], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               0., 0.}, {0., 576.}, {1152., 576.}, {1152., 0.}}}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{1152., 
               296.}, {1152., 160.}, {0., 400.}, {0., 536.}}}]}, 
             {Thickness[0.0008680555555555555], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{1152., 
               160.}, {1152., 40.}, {0., 280.}, {0., 400.}}}]}, 
             {FaceForm[{RGBColor[
              0.8117650000000001, 0.06666670000000002, 0.14902], Opacity[
              1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 
               3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
               1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 
               3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
               1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}}}, CompressedData["
1:eJxdVn9QVFUUJiMW0RwSJjPUUScUB0r4wzADPMokg0BOUWoSu++9fbtLZGpR
aex7yy77HtoPKjKTqRxGQdEgYjSVzIgRA2vS8WdYiMg4hZrlGEEy2tS977ux
k8y8Yb+9957znfN997ydpqx+0nVnWFjYHezZwJ5R7KleNT7YpgZo8dhRievH
2en1BdLPxy/5SZ8/x36gyk7X6jtyUtf6KbnngYjAUQetUB/tXZLgJ29sU1Zf
q0Rh/G+in34a9hUfvCRR0u4t1+qj/GQ/kD121BiZclJZxMgQLj748sb7IkK4
qOo3bX64n97ezIick0awFX+bhPwMN05imf9xEGP73db+MoqPCGzKLHDQ2taa
+2dvKqOhhGffOXSXg1qmmL8+saiM1t/747G/9tjpj5N5SvQxH8XNZgU846Dj
07uHfSt9xLLMsT8u0dTml4qqbD76itEKH5Lohf6bu66/pxM7nX/xFZk6eAHJ
OnjtkmklXz+v0dPjHty95ZRM7NTScSUafc1o9HwvE8veMiVeo0peT7WMeGEa
dfI4fhn8u7yIXyj6860X67ki3pde2nvk1daaeSJeg1hPktHvHSF8cftHh6dW
34Y/9NK8z1mAbpn4v5qdXvCNUZCfxbfqKVRoB9vefMWL77cr4DNNE3ortO2x
fQN/p2kUw9f7FMrqK41tytdoKY93M4QtPWzOEWz5aryTfud9Xiz6k+ZE/zI0
6uZ+UZ2UyIWaqIHnL07UP0ujNelRXbWqivXnRL5Olc6suzwjpVEDryQXdJyk
0wmua4YLdZTp8NeAirjVOvp2QSVuo97PdOhzXIWf94Sw5Z+2ELbit+jg/6cK
/7yvw2+FLuhbrBO/NtO7XKhbEflj3MhbpKM/tW46NMgOrtJpTFftmvQVHuj7
hU7LeH3XPMgX60O+Wx4q5ffA7kP9tiLoVulDnWfE+Zs+5An3IP80P/hVqdh/
2k/8mvTMdRJv65q6AL3LiXQruCdnA/QIb1S7Qtw+zQvLRf3CH/5yxBtU6DXW
/si0IPrqdtI9y9nJG0HE61VxH98ywCPKA157DehZ54GvjxiUy3121AO/XjFw
Hxi2+NpM4jTTj3mQJ87EfNnpQf+TTWq4zi52roey+dzKNBHnhhv1ZJvQud5N
H2S+ubI/y0R9M92It8gkPg4CZ1zIx85bffzUhfpSTfif6Wvxjxfx+lXMkwQT
/junEm9TW46J+mLFec2Eng4XsV2n1+0X+9Nc0L/LpIXcL+0q+jcg4i9Toc+Q
SS/yD1edqO+C2F8g8FkT/Yp3ot4TJk3m5weUEWzxvhrCVr97FPBn560+/qDQ
KQaXD5qYD//pH1eBfA1C/5QK8J8bwtZ8fkMewZZPl4r5nlwxMo8s/FDF/+dT
UghbfphcAT0WyFTHG3l3BZVwYQrE/j4TOm2XiV/Plk6TPuH6t8jo50aTCvl9
2y+jn8+bNDMlsnHSPhn12k3MhyaZDvOBv9Ckkxwz/pY/Jpi4r/kiHvOj1T/2
Pmvn+BuBVQnvx48NwcdB/FYkBA3onO2AfgUG8XaU5jqITZfKzQ8beH8tcUCH
yQZt5f2sc4BftAEfzZCgV6QBv+ZLZI0Fm4H5sVoiDutHG5gPpyWK5vVGifUJ
MvIxbPk3T8Z9HB3CFn9bCGdwvsNB+H+WTHx8Z10O4n18S6INfH9rEPNnvQR/
1AbhvzwJ/EuC4BMm1s+XE6fZkWgH38hyeooLKRXS7b83/gUIKM2n
               "]]}, 
             {FaceForm[{RGBColor[1., 0.8, 0.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIlIGYC4qMKG4oyBFscLijd/lnHluTQ6Zjw9IJ2i8Pq
j5d8k2ySHI6A5P1aHDImvq2xP5nkYHPfv3d6TItDgS3X9cUWyQ6yUSnW99Nb
HLzNgTonJjts//z3SkVmiwMDCGxIdugAmZfV4qDG1jjV2TvF4RPQWIGcFodL
IPtupUDUZUPNY0l14NPdNPd9SovDKpD9JqkOj5fOPqIQ1+LwTSOm/1BmqkO7
2M1z36NbHLaeKNs3Py/VgRek3gvB3way3wrBBznP37zF4TjIgRmpDotBFum1
OOwtmSzBYpbqoAPUvlwJav7bFAc7oDMKFFschJsPnFoYmAIxR6fF4V2NvWmc
VIqDNcj/xi0OMiCDvyc7HP4K1GjS4tB/CMgA8sHh4NwCcbdACsS94S0OF0H+
NUpxAHmzAOj+/fOl9O8apEDUA/m90/OEmllSIOEM5BeBGJOTHQQiLLecMGpx
AJoS/HhnksPDKpF17hxQvmuSwxKQf/40O2wBuVMtCeK+T80OliAB5iQHg7sq
bI0fmyH+/5EIic93zZBwv5HokLUHGBD/mh1A0aR0P9EBPT0AAPiN+JY=
               
               "]]}, 
             {FaceForm[{RGBColor[1., 0.831373, 0.16470600000000002`], Opacity[
              1.]}], FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIZIGYC4qWzjyhsONboILrO/WGVTbxDxsS3NfYPGh0Y
QKAh3kEgwnLLiXeNDpvnvl9+7He8A5D0Nv/Z6ND6OnCHXGmCgy3X9cUF/xod
CkGMDQkOfLqb5r5nbHK4qHT7Z927BIfKl2qGHDD+vwQHmagU6/tA9QUg9SqJ
DrIg/udGh60nyvbNV0p0ALvneaODS3fO898/Exwu+yYJRNxvdABZY3svweEK
iH8P6r4LCQ7yIIcA3dt/6KtGzPQEiHufNULsYU9w+HQJqOFWo0Pv9Dyh5hPx
DhX75kvpT2t08OJh0m7vi3fQv6vC1tjf6BDyGGhzRzzE3JpGh1p707hdE+Mh
5mQ1OswAaj+wKN5hC8idXo0O8bs8eZgOxzuAtCnYNzps+/z3SsXKeIcOx4Sn
F7yg4RUdD3GvX6ODH5CydIl3ABnnH97oIAIKb5V4B5CzDsQ1QsJdNN6hE6S/
oNHhuLd5p+OHOIj6zY0OD6uAOjjjHdDjCwB5h8qs
               "]], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJ5IGYC4qgU6/v+wU0OFS/VDDly4h1i+g991QhvcvgP
Au3xDpd9kwQiUpocQh4vnX1kR7zD1hNl++YXNDkc8zbvdLwR78AAAo1NDhkT
39bYMyY4bP/890pFZ5ODDMhg8QQHkLKECU0O++dL6d91SHB4WCWyzn1Jk0MR
SMP2BAeb+/690xc0OQg3Hzi1UDbRAeyeZqj88kQHW67riwuKmxxAlO2nRIcj
ChuKMnKaHI6DDP6Q6DA9T6j5QHyTQ+vrwB1ycxMdgLY9vRDS5OADsjc00eHT
JaAHQqH2B0Dlgf4pBBnsAJXPbYL4wyLRoV3s5rnvJU0OVluAHpVPhPi/Euo+
xkSHC0q3f9Z1NTnE7fLkYepOcLADOay1yUH/rgpbo2MCxDyg+4CqsvYA/Qs2
NxRqPpCvs2nu++V+TQ7VwGB4aJQA8Z9Hk4MXD5N2+7t4h/fLgSHrCg3vDfEO
wNiI6XdqcpAHeTAPwd8MNOZYNIK/DRTumvGQ8PVucnDpznn+2zDeAT1+AaDz
25I=
               "]], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4vfLj3mbqzY5PF46+4iCTYLD4a8aMf2aTQ4T
DgEZ2QkOny75JgloNzkwgMCBBAfr+/6907WaHO78rMvak5PokDnxbY09kL/q
I1Dhh0QHPt1Nc99rQM1LSHIAURvUmxxaXwfukEtNcpCNSrG+rwxVX5LkMM25
O+e5QJOD5ZYTZfuckxyAqosy+KD6VZIcsvaUTJbghcoLJzmU75svpc/f5HDz
3Pfgx28TIe4ThrrvQqJDuxhQRqLJAegq07hFiQ7yIIslmxzCQA4rT4TYJw41
/0iCw1agsfNFmxwuKt3+WXco3uEy0LgIoPrmA6cWupbFO6CHDwDaDYs8
               "]], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0,
                1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJRIGYC4mnO3TnPdzQ6HPc273RckeBQvm++lP7uRoeL
Srd/1l1KcIjtP/RVY1+jA0j4rkaig/5dFbbG/Y0Oj5fOPqKQkeiwpMCW6/qB
RgeQspjliQ6fLvkmCRyB8r8nOmw5UbZv/rFGBxegNb8lkyDmn210eFtjbxpX
lORgfd+/dzpQ/ptGTP+hziSHGJDGrVDzI5IcsvaUTJZY0egQt8uTh8k4yWEx
yL5VjQ6WIIM3Jzo8rBJZ57620aH1deAOOcdEB8EIoAxQvVPC0wtK2VD3L4L6
TyLB4YjChqKMBVD7mRIc2sVunvsOlGcAAY4EhwqQ+1ZB3aOZ4FD5Us2QY0Oj
wyLXbZ//uiRA/LOt0QGoK/hxbYIDevgBAAJ8n60=
               "]], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 
               3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
               1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 
               3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, CompressedData["
1:eJxdVQ9MlVUUf6IjYvJUaIRmSFhpmqJsCaXU79Ws/IOumI41dPfe77W9LA2V
JMn47p2pUWPkmFpzRQqGERUrYq0RGhC2aoWwxaohQ5blnBG2MtfKvvPOKbbe
9u3b+e495/zO75zfeTeZJx9+dGIoFJoQPKXBkxA8Nz4SXTpU7NCX/f2Vyk0K
m9rLajNiDskD9aUFRxVGG3tW5T3ucHR5269/dSuE6LfVIaJ+6M0u19iX/u1X
l7c7vLwldffJPo2lQ2urD5U7fByEmbTE4FJfoZm60+HO1s92dBQZrMqriqhd
Dhd33XPHxoMGVRToKYeNH62YnHDYcP6o5DcGvYQrwBfbH3gUSLzArun8bW5J
nkF3Vsu2WInDB0H4ur81nu6om5Fj5Px9jZ3nb12ctEH8ryjQ55oih+304YRi
PKsd1oUXvPdqreI4BQ5pu09+fqRK4RDVlSPxGhWCW6ONtzlU00Gr4vxzpb4u
hbMV173zwDyH34M0necVGkoLkgcWOGwNXvWLNG4n/9nCZ75mPNc4zFmc1Dwz
UWOY/C9aULi6bxRKKPGIZX6/U8jcc+GhD89Zxpum+fwny/2bp9kvOI/XG9Go
p/xnLeMp1MzfoMWJgKZBpUGwSgcs16Okny2W8azUCLoyf1+T5X7dr7n+44Jn
zbj9TAB7eMu4Hc+3R6Of2tVo0TQWJH5dY1pxwNQxid+kMXLscHdWg+V3q0YX
8bFf8LVL/grJ36GxgepdY7lvn2iQW8tCwXNGIz7PGRY5gzcnuumG5zFB7HWG
+xuS+M8Zjj9F6v/DMB/pgm+hx/3MtCB1tJd5INpHsyxSaT4OeNy/2YKvzQOl
Xztf+nfO47pyxT8UZf984WtGlPPfbXFLojtwX964HdcZxu24ntZHWQ/ZUn8k
iudJP+lSf3aU+x22CLpYNJISxSKqO8WyXq963I8pwsdpj/maZrGNBqbWY70k
/YvHA2UNX/DZHjL4mers9JnHStHnXp/1+obBEz/++ebYEp91s97DZrIzfJ7H
Vzw8SAOe4oNg1h/3eB4TfdZbcB7X0eVKxv2sx3thoo+XiOgbPK57us/4xwxO
U/5cn9+dBuWk/1qJHzOcv9nHKXKMCb4en/mNyf2vxS6R8zM+7iIcs2Q/XfJZ
//2a7XyZj70yfzuknxUaj1GdL1i+Xy778EWLHspfprGM7GrR53LNeq6xXHea
6K9G+E+TeX5b5iuseX6+kP5dqzlOr8SboHn+Tlnmb1BhFsXvtriX+t8v+6zL
Ml8dsl8+tVzvu+o/f+6HYn6+lHk+qHjOhmXeXlPcv19Evw2yX6/K/DZL/EmO
9d+ieF6SZf+3iX9Y9v9bClNpP6Q6nl8n8a53HL9Y9u1MByorc4VifueIHVF8
b5nEz1VYSfoplH0Lhf//3/0DDjwhTA==
               "]]}, 
             {FaceForm[{RGBColor[1., 0.8, 0.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 
               3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
               1, 3, 3}}}, CompressedData["
1:eJxdUwtIVEEU3SwspL8iESXmD8NEIiopwmMfTKzEjTKiZGZeoUn00SgrseQa
YlKb9DFYRFwNrajMNCzUxCwkQqwUy1jKJCJEQvuIZNDMztCDFoad8979nHPu
fUvEYef+qQ6HY4o8CfL4ydMT9n6ioIjQeuzygmnPGWbHNlR8u0lIV5c5HA71
ayc0dR1vqxQceW2VC+O6CdcPzaf2AY5rG0oPfukl7FDxgQKdofU5WQOEQGp/
UZVsY1++08aujp/RezKFrt9FeNc9vn2oRKA4WN5abOyrf9/GyyS92nuEoRvu
ztA6gZTVJYmskXB79PVWMWnqPSK8Urq2WXj4/U9v3gNCnDfCv7DJ4Fs2PqH0
1Np4i6pXRRjJT1iZ4bHwVNJ0VRDWs889YaWW7l9O2Ps4eaZfpqX7S7xT6U+3
oGjVuwkZ6n24hewWaayHcG44rTmkT2BM0pxbYd67BRqVL6Wk6xwwesjoTROo
PrIuoL+AUK78XmXji+rBIhsH9Mubv4Cy1XWGtA8/uPb7rI0HTwXdTSq0sU/v
eVNf5vvmdIXwS5bpWCx0vPQnJ6tsJD9J4JPCDYQn0jZvhMAbKWdXs+E7z8S3
Ek7Lv8Ex/g/7+n20sWeTnEQR1/n5hDXKiGGmeaSS5uVlOPk1avmMeMOnj+n9
WGHy3zKEKGNjCBvlmvyeMPGRBDn97JYgrv0OJ1xSxsRwvbcRZp4pZr+jzD5a
HLv3rf2QGk3IVXpdHDXK36UEBRPucN0/lnBUPq6e5Him/I00+ke55hNs4q9y
Pd8AwoDis9n0m05IVP3Hma4/y/jzkul5BRp9dQbHG/+LmZ6v0/hxgek8y+Ay
pvvmmno1DP9/338BdlTBuQ==
               "]]}, 
             {FaceForm[{RGBColor[
              0.8117650000000001, 0.06666670000000002, 0.14902], Opacity[
              1.]}], FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{647.48, 164.172}, {646.242, 166.059}, {646.984, 
               168.336}, {648.8399999999999, 168.336}, {649.938, 168.336}, {
               650.1519999999999, 168.066}, {650.2810000000001, 
               166.48800000000003`}, {650.395, 165.172}, {650.145, 164.375}, {
               649.414, 163.71499999999997`}, {648.4219999999999, 162.816}, {
               648.3589999999999, 162.83200000000002`}, {647.48, 164.172}}}]}, 
             {FaceForm[{RGBColor[1., 0.8, 0.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJpIGYC4iu+SQIRdS0O/Ye+asR8TnKQjUqxvj+1xcHb
vNMxITDZYUmBLdf1+S0Q8cPJDgwgsKDFASS8uCTFIWtPyWQJIF+4+cCphT9T
HDx5mLTbN7c4XFS6/bNOLtUBaMrTC2egfL9Uhxl5Qs0HnkD56xB8yy0nyvY9
RvDf1dibxkmlOSydfURhw70Wh6KMiW9rxNMcdDbNfb/8MtQ9t1Mh/NMtDoUg
92xIdeDTBQocaHG4ADJ/WirE/TNbHLYCjZ8PtL9d7Oa57/0tDn3TgRbZpDpc
BvkfyAfba5QK8U9vi4MPyP+9KRBzuqDuPQf1f0uLA8hbSu3JDkcVNhRlZLY4
LHLd9vkvS7LDY5CDI6H6tyZB9Ee0ODiB1K+Ghm8ygg+Wz0Dwj4DMK2lxCAN5
5HSSA3r8AABNAMog
               "]]}, 
             {FaceForm[{RGBColor[1., 0.831373, 0.16470600000000002`], Opacity[
              1.]}], FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIxIGYC4ul5Qs0HttQ76N9VYWssTHbIff575cdD9Q4+
5p2OCVOTHa5WvFQzvFHv8LbG3jTuXrIDn+6mue8f1zvIRqVY3xdOcXB/WCWy
7n29Q8ZEoArPFIfDXzVi+hkaHG6e+x78uDUFYg5rg8PWE2X75s9KcQBpXy7Q
4OCU8PSC0ukUhyu+SQIRXA0Ora8Dd8i9TIHY86Eewr+ZAqHv1jvc/lmXtedC
ioMd1/XFBVfrHS4qAUUOpTg8Xjr7iMKlegdvkD0LUyDuOA5Vb5LioLChKGPi
5nqHb0BnHTqaDFG/qN7BpTvn+e+JyQ7vQPY11UPETZIh6hvrHY6DDDRIdtgC
cncfgg+2ZyqCfwjk32X1DsLNB04t9E12QA9PAEFxqOI=
               "]]}, 
             {FaceForm[{RGBColor[1., 0.8, 0.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{623.727, 
               154.941}, {624.012, 155.79299999999998`}, {622.383, 
               156.40200000000002`}, {621.6840000000001, 
               155.70299999999997`}, {621.383, 155.406}, {621.305, 154.895}, {
               621.508, 154.566}, {621.9649999999999, 153.824}, {623.438, 
               154.07}, {623.727, 154.941}}}]}, 
             {FaceForm[{RGBColor[1., 0.831373, 0.16470600000000002`], Opacity[
              1.]}], FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 
               1, 0}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJFIGYC4ul5Qs0H2OodMia+rbEXTHEo3zdfSt+w3uG4
t3mno02Kg9WWE2X7Iusdbv+sy9qzAMGvFlnn/vAegl8EMoA91QFo2qmF5vUO
qz5e8k0ySXVYNvuIwgYJBD9ulycPEzeCD7bvY53DzXPfgx/Lpjoc+qoR03+n
zoEBDFIh9Jw6h4tKQBcsSnGIBekPr4PYsxXm3jqHCSCN+qkOj5cCLRSqcwjl
0900d3Kqg8fDKpF1H2sd1A051sicSnWYLMESxncVwY9Ksb7vvxHBlwEJrK+F
hMfcVIdOx4SnFy7VOuwHWnO3JdXBEuTfx7UOra8Dd8hVpjpot4vdPAc0vw8U
kDGpDnZc1xcX/K11AOo2jdNLdbAF8eXrHKpA4bUsBWKfcZ3DDFC496VA9PfW
QcKlPsXhEzBYBE7UQewrSXHYCrRu/qk6iPv0oPJn6hxU2RqnOrOnQOLhQp1D
P8j/z5Mh5l9F8MHm30TwweH5oc6BG+gs21/JDujxDwBgU+hd
               "]]}, 
             {FaceForm[{RGBColor[
              0.8117650000000001, 0.06666670000000002, 0.14902], Opacity[
              1.]}], FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
               495.555, 164.176}, {495.09, 165.383}, {495.746, 166.516}, {
               496.90999999999997`, 166.516}, {497.977, 166.516}, {
               498.22999999999996`, 165.727}, {497.65200000000004`, 
               164.21499999999997`}, {497.25, 163.176}, {495.949, 163.148}, {
               495.555, 164.176}}}]}, 
             {FaceForm[{RGBColor[1., 0.8, 0.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
               667.9449999999999, 166.383}, {668.23, 167.238}, {
               666.5980000000001, 167.848}, {665.9019999999999, 167.148}, {
               665.602, 166.85200000000003`}, {665.523, 166.34}, {
               665.7230000000001, 166.012}, {666.1840000000001, 165.266}, {
               667.656, 165.516}, {667.9449999999999, 166.383}}}]}, 
             {FaceForm[{RGBColor[
              0.8117650000000001, 0.06666670000000002, 0.14902], Opacity[
              1.]}], FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 
               3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
               1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}}}, CompressedData["
1:eJxdVH1MTWEcvtKaUaY7i1HkM1tr5Q8jiYc7U0hj8zHS0ilOt9x76x4k9x6d
e8+RRtJExtJizcfMWopUYkiGJWQ0a/lqrRn5nJls3p/f3WzO9u7de97fx/P8
nuecKen2NZnDTSbTMLEsYvmJtaA3uaTinIb59fd2tu6RkFJ66/usGg0fXIvm
pKoSYnqmB2hlGqJpL5ZwzHIgp9+l4e6KucWLyyXsX5zW12n25T+Q0CC2qvJC
zAzQjlr2ZOBtzck74fMKsW50VF3l+kxU2Mzemx0qTi+98vV3wjYsHPn8jKPS
DRM956ygsmnxbkTMHnExNN0GEX2/+pELHwnPmlxEFoV0d4S5GU+EE/GUP1nF
xoy43mS3wrhXqQivzZPLmhWE0sVeFZubEgP9BhUQnNqdKvd7oYBgDTpV7Gqt
mhD92JefpnL9agVymXizQsWXJ0npY2wKnuUPzJzd5eb4JCfjbXMjlvhPzON6
YSrjbncwT6jY3v/r/Gc4+H6Lipc/VWtLlx1BdK5SceGzaPDOxvH5ezFK0Io/
kY1imm9RIYz3qxsnRWXB2qIcGS9reDxVVFBl3CGiBRraCYhDxm4Bb0SlT6+1
MuNu0JBK/C0yBs8K5b758s0y4kj/EA9I9pRxMs8lx8M4UmQEbxDMmj24Ltr6
n5K5/5AHhyn+vQyS48ccL+ufnIXb4nVpn5f5FFoZxy6d59GWg02k0y0dT6h/
gR3LA/0ii77reCVg2C442D9BBjrpPiCPdf2ts/5mJwSqrvyvOvuv3sn9u3X2
UaYCglXa5Kv3xqfvZZ19N6TgqRjHhlod1yaJiZp3cHzdv/NVqn/t3/nv/AZ0
hBGQSoX972+wngkKssgfSwwkvC4Ye6nECUprzDbYNzV5SCR+Bb77hlzGsc/A
cdo/OdhHLoPnYbUzX8lALhl7aDvrFWPghgjrCcxmv93UsUTYYqrFp0esznod
3Mp1z3s5viWD5xvsxSFq/FDiea30MB+vxHimeeCgfooEgrmsUcMM+n7tEv7/
P/wBILPrVg==
               "]]}, 
             {FaceForm[{RGBColor[1., 0.8, 0.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
               3}}}, CompressedData["
1:eJxdk3tIVEEUxjcLW6REtBehm4nlRklJyEZm+5WhiG5mQYaUiNxZLxJmDyLN
FpyTSPlHRERBlMgmgURYRPbYNtGtrEDMDULKYrUHIj62sLAImtkZErow93Lu
3HPO9/3O3JUVh3azuRaLZY5YG8WKEutu73F/SwLBIi+fge5p+/5zSwk/xKP7
hYHa0dUZ1kTCyUW38kITBjYMpUY3JBHG652ZZbEMTUsG+37aCOK+ZySdYbhO
fJhC2NF88OvvfIakUiPrYyrh/YynylfIkB3z1luTRjhqnh+vL2Lo/P7nzYkM
woSsV8ow0nYlkJxFeNKyfP2QwbAw/c7VyVyt5zBDSNbfpfWcZYjoLyEUOM5s
K7/NINsVmQS/zLe6YWscK77v1vm1blT5jl1YVkxoDw+4Kk5X4p7sn6fr/arE
1I1nBY6thNcp72Y81SZ6JI8thEJZv1HHmwibZeNHpuKTqf0/MJVfu65XZ8Jb
IxwLPpeq46kr11T61xCkLNtiU/l1EFZFN1zMCVYqHi69/1Tr3UnYGytAlLgV
PxFLfM4kN4SraXshIYG6XraGmYqFn+3ln/tTgpqnU8+jlam8HELZw/wFUV6G
Sel3PindPXpeM1zlv2LKd5ireQQYLksfnzgGJJ92BlFlbVMfx3M5gHqGfvk+
wJGWYb2Z6NHz8XOlT8wn6KqI29fJ/+m9Lvl0cKVrcDaO8Dw1G0fO5zqGQHLH
EfPDbPxNjDEuxJXuMUP1H+aQad5eAwckjy8c8bJfm6F4jHJIjNnXDKyQoKe4
4ttsqPMWQ3gssM8T+///H38BLhp1tg==
               "]]}, 
             {FaceForm[{RGBColor[0.831373, 0., 0.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{606.387, 
               168.33200000000002`}, {605.305, 169.984}, {605.762, 171.195}, {
               607.4689999999999, 171.195}, {608.406, 171.195}, {
               608.9409999999999, 170.816}, {609.2890000000001, 
               169.90200000000002`}, {610.3359999999999, 
               167.14499999999998`}, {607.992, 165.879}, {606.387, 
               168.33200000000002`}}}]}, 
             {FaceForm[{RGBColor[1., 0.8, 0.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 
               3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
               1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 
               3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
               1, 3, 3}}}, CompressedData["
1:eJxdVQ1IllcUth9E1pBmK9yW2d9KaKLRRitzPmXRmko/o6byuZp1rxphTjN1
uXrvdSExnPthVph89DdxcylOo8CZq2i1KMK2RdMIaRElzdmoLcbY7nnPoRcm
vMjh3nvO8zznOeeblr91jRoTERExyn3F7hvtvoz5exZv+NXD7LlRrZPXKSTf
mBlpRjwMPN65uXuLwububZ/FjjL4ni4eUKjsCT+fFG2QSe9+UnjQl5U/fobB
u6lPXTucrFFB5ykGp9y/GzM1qu7OmhuVY3Blev/jnZM03nh69JxaFxd+cr86
bWIQ+/kH1JN4x7PHlg8eUyiie7lS72uFrvPbe8LlBks23L4y/bDU3y35mhRe
czBK9ht8OeIO9ilMzt2UcvNQEEfQX5vUc/G+4pia3i6p95HCM9kLOs+flPuV
CqH60w8TThn8Vp32ytu5gue0wYSa3h8O5ihQ+pXDBtcv//nmrSKp/5zFoWXH
//jHvY/fPbT6xDSLddGJHU0VEr9s8SjBZc5T+L35XMb8JRYfuzKhDOGz2qKU
CKVL/pBF3V4H9HWFM+5afbXFYuL/luBrscz/O4VO0qfNMq9ojbNT20sL2y1u
HW08OzVWcz+7LUqoXwkai26urNt7wYLShOZp7u89yz7I0qBn7UMWvk+KNAbf
c0JdkveVkq9X8OyS81ap/6lmXActzlGCI5r5NljEkH5d8r7WIo6InpF6u4L4
qpMje2sQTyH91otejUHs+60kiP26a4VPvuBZo1m/css+ytXYQ8Bd/aUfbrnz
9zuCv07452n2T4PwSxN/N1n23xy57/gtIOEnaNROck4Iy/k4jZc6moabGwXv
sMIXxK9c6rUoHCEhN1m8GGk+Tw8r7keOZZ86f5LMJassiNYU529KU7/coowI
tinG/6rFt07GsZdlXmcI3z7xe7xlv59QrEuc6NUq8xQr+n4j/o6R+KLcj7JI
8veCzOeIeXLu4/nFsJ+Pip/7DOvRHMS+n68GsT8PdxTclPxYeVHm567gaTHM
d1Cxvh/I+2uih2fYj9dlX1UZno+/ZH7K5P1E8UOpYf3jNc9TheH9tkgz/h2G
dcrWPD8u9udho5y7+2sJb5nGCuJfJvxqNOMpFj1qxL/rDc/bNo0U6udCg69o
n2RqNKS7xicZ3Kd9kh/ElCb15yBeSPlTCthvLxj2X0EB79FI4ZdYwPq5/e3r
d0n81u/x/glpkCy9DyROlniM6DVe8P/rYRzVvyf7yeXrJ306FfPt8XgfFirG
d0B+L0rFvyGP+Q6I/7I85vNI8f5f4TGfIYVEwpcp5x2K+a3y2D9V0r88j/3r
9u0w+eV9j/d/quJ+hoVvnPT/gsdzOlvh/79n/wGN1yE9
               "]]}, 
             {FaceForm[{RGBColor[
              0.8117650000000001, 0.06666670000000002, 0.14902], Opacity[
              1.]}], FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{544.4259999999999, 180.895}, {544.2230000000001, 
               181.42200000000003`}, {544.4730000000001, 
               182.02700000000002`}, {545.0659999999999, 182.461}, {545.891, 
               183.062}, {546.1519999999999, 183.059}, {546.7850000000001, 
               182.42600000000002`}, {547.195, 182.016}, {547.387, 181.312}, {
               547.215, 180.859}, {546.8009999999999, 179.781}, {
               544.8439999999999, 179.805}, {544.4259999999999, 
               180.895}}}]}, 
             {FaceForm[{RGBColor[1., 0.8, 0.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 
               3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {
               1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxdVAtIFUEUfRmIRJhURIhFRWaQphJlZeJJrQhTy0BF/GU2s0/r+emnJHbF
wkTMTEyhREJMCpOorBBTs8yICglN+oiI/SRK+lhIBc28mRhwYdg9O3f2nnPu
vbs0PTt230ybzTZDrDCxXMTqXXItz3pKyA2ZNdSYw1AwviLQ7S0honz/h9+X
GfyHl7sWj5G6NzHUOuaWdL8ndDV4+g9HcBU/TrCqPheGtnH4Xa+faP5ImFfS
/fjiXQ6bvEYNLl3w8tmvQYOPdooP9RNOftp1Z3GFwVe+Po9KD5i2P8mwKDEj
eETw/VIYujblFVPf6yXUSV7tDEmVPZMrbxDi3QWTbIYHUt8JraeKQewmVRYR
vF2La8InGLbPdllVWkg4KAXM4cjsOFS98DihLzKobLMvx7lwcfAUKR0ZHDJ9
TD3BSz4McVw6LzLUEcaaxMMPDl+p///5Cxy3vv8dyHeQ4p3KIV+nZRF8At1a
vFJ0vEPjs9q/XM33Hlf8s7T+QY4d8nwyIbldMO/jyJf+xBE23nx0pLOLYyAq
3SMhlvBTyOy5yrFpJKaidichRcaXc9RIPdEEeWzY0vWJ1PnjOCaaH0YGRRDO
SKNiuOK9XvMP57gv/fMmHJvfum3UYXCe9K/a4DZBp6FV6w/T/IItpZfrfC8s
pfew9svDrnwsJsjwhq0GO+sbbbBTf7xd5SnQepPtKl+Owd9EG3nsNVi4964/
lbBBJog32OlPqMFOfqvtqh+idP2fWMrvdbr/MyyVz5UgunD3mOjf/mWvp4pc
dL32cMXXkxAn+9GHq/700/tTDAFyrrYQ3kwVZXb8YUpPgp7HAB1vab8TDZbT
GuJu8Gk5mC1M8TxAqs/KmJof0nzTmOrfOs3Xj+G25N+m67uGYfr/4B9wp97J

               "]], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0,
                1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 
               3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
               1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 
               3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxdVX9ollUU/pwwhooMlTAx54bNzRrmLD5Jp4+JmDmzFFF0Wzbme+99v9S2
ZGm6Uu6VjxGyrEzZsGHLH6T5K1uy1lwr8lfKmqL9kmk6rKlME5X+CLvnPQcH
ffDyfYdz33Oe57nPOV9m6Yq5S/vGYrE+/lnqnxT/fPp6Qb8Lay0G29aT208H
eGxR2cROHz+eun7ztLjCd3dzimqqLI7NildPhUJRTdvdnA0WW5cPsq3PKlRP
XdLVftji13/eDpuHKjRQvZMW/S74X/kKBfSjU+o1KOyo+37kgW6LT6Y33vn3
ksKTh7b17Lpu8Ru9f0thVUv9sLHdEr+kMXNAyhPJPy36U70mzecfSL39mvHl
OjznYWTVaaz+K3tc2hiH0ePS9g6v1bhCDUc7DCJ+8zXjz3CMv1b4pTvmPV7i
G8LnSACiveSs8C0NmI+PiWbDhAA7ic8NiXWAvztml6anOGy4/vKREZsCDKe6
wxxIpqz7AXp2/TArnuOgN91cO6VYIUaffMf67lbYQn3GO9zzMNpOKHw07d3X
rvn4s9u+MDTC5pUfDH1a3v9G4meEzxnN3wUSd2uuP93xfaQY1me2Y/3TDAzV
KRG9Ug02U78Kh5+y/A3485F+lQ5vDdk347LPj704KnX9O5LPN3yfSYeNBHyh
QSHpVS39lhvWLyn8thrmZ4Vfl0HkP58/6q/9YixkvB9LPi9E8pFfztz/2qGD
+oUhDh+vbKk/5pBN97+nN474DEk8jKP+lQnG3+qwYGDeoW37E3iK8H/p2D/1
CUymg587rCF+7ydY170ST07AVz236gvhly71Gh3eoIMPQo6/cqxLV8h+8PUj
HOdDno+Dou++EGe9PRbWOdapSvgm5T7LQ5Bd5iwT/q+G7P/FgmeM9HtR+n1r
uP4EB6/SvCuPGvbxRMfznGm4bq7oW2YY3wDHdX407Oc7lvMHJO/nLfJrhmF/
XZX8JQ2frdC/W7znx6jI5yd1ztm45ZzMR4lh/Kcs41lm8AcZp80yn5kGt8j/
TZbx58r7zRbtdL/3NPvhhOyb3Rp5NO/tlnVap9mv52V/FPbGEd54b1xOxNoV
+71F+lcpnsed8v6HivvWWvbpdsW4aiyKm7zy13rj6HyOfhhH816mma+zKKHz
r2iQzXrWyT7N1LhM/NdY9m+TwghaDCss++mqYp+EluepQuNN2n9K9OzQ7L8S
4f+z5vmZJ/p4PaL9UCjx8xoZVL9Q+BZoFNO+myv7dJTGC+SnYunv922E3+OJ
9stIxfNQbrlPY8B+XSn3kx0wLv//QGWL4gH+///xHxEf4Jk=
               "]]}, 
             {FaceForm[{RGBColor[
              0.8117650000000001, 0.06666670000000002, 0.14902], Opacity[
              1.]}], FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
               640.777, 199.99200000000002`}, {639.508, 
               200.92200000000003`}, {640.09, 202.41}, {641.7230000000001, 
               202.41}, {643.211, 202.41}, {644.387, 201.184}, {
               643.9609999999999, 200.07399999999998`}, {643.586, 199.098}, {
               642.059, 199.059}, {640.777, 199.99200000000002`}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
               652.1990000000001, 203.47299999999998`}, {651.7930000000001, 
               204.754}, {652.746, 206.05100000000002`}, {654.094, 
               206.05100000000002`}, {655.094, 206.05100000000002`}, {655.375,
                204.848}, {654.754, 203.23}, {654.3009999999999, 202.055}, {
               652.602, 202.21499999999997`}, {652.1990000000001, 
               203.47299999999998`}}}]}, 
             {FaceForm[{RGBColor[1., 0.8, 0.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{516.082, 
               182.812}, {516.1800000000001, 183.316}, {515.918, 183.684}, {
               515.4609999999999, 183.684}, {514.496, 183.684}, {513.914, 
               182.83200000000002`}, {514.371, 182.094}, {514.8399999999999, 
               181.33200000000002`}, {515.879, 181.76999999999998`}, {516.082,
                182.812}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{556.75, 
               187.359}, {556.75, 188.105}, {556.4689999999999, 
               188.38700000000003`}, {555.848, 188.266}, {554.488, 188.004}, {
               554.3399999999999, 186.281}, {555.672, 186.281}, {556.418, 
               186.281}, {556.75, 186.617}, {556.75, 187.359}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 
               3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
               1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxdVGlIVUEYfWWJWZaVhJipbRaPwgyyjVef2mZloUGCaYkUzlzS1CJtm7ll
YhphWVEQJmkJhYlIi4k+xYXCH2pFqYmFWEhEheWCWNHM/QYHfHAZzn13vu98
55yZhYnHoo+42Gy2SeKJEc9k8WQ4i3yCtnLYcvlo/9hoErzL/BoYHMfh+9nN
aw6GEGgcWh6XX8nhdsqcrHo7gfupDvcODxPSxFLiS6DvwZ2mAC8THg28iUxc
TsCoOXHde6MJXa0j+/p6CWwSn6VGmFArXk8JpNAg68WYMCyWhngK7Yu6R1ms
xs0BFekkXuPc0IQv7YdMuHJLEEjVOF8WytF4/ZNXJ52NFPyzv0VVRZpQvPXZ
77/1FE6Jcdy2mLDU9fzN8CyKfENMmC5oOewUek97lW+fZYKk6bhAwCZ/U014
KsoVpRPk+4/jPJTAp72CyWcOvrGHN35KIuCxsrLwZxvH+VIInBHleis49ssg
QK4JJR9zrHuWwAK57wWHZcFuZb55BOu0KX2LlX42E/V3peP4YHXEjMnzNbb4
rKHoV6fyaw8FOb5fHUceYRRX4Z/Fw0FhblZ9y72bHNLli8VKD8bx/TQKG6SO
URykzSWdyt9V6vsOjaUd9a50HNeJGPV4UbDnzOtqDVf9dyp8QGFGcf7jat5K
tb+Ao1+Din+RyuNsA36JWHmWcZw/yMDvq1X/bQZU+YkdTo1fyzw1aDxT+tOs
6kVpbM15SOOgniWu59MMSO4fezhQw+HDKDNqMg2Q7SpKNbb0ztPYqpPNMT/p
BkjZUo8rvVcamBfCMZ8uBryQfKPV/C0UcRjHvJVTKJX97Bx1yKY4f4DC5xR2
53jeLlKQ8e39yND/AorzNDLMo3MCHta4W/L3NDDfTob97UrvKgYx8kOht3U+
Sxn2dxiYk1wGL3etzQ311tjiM0jHsZX/5xTk2EU3GOb9LkU9mhjmN1nx/8HQ
33Dl/xDDviEUZJuEEYZ1RN52yAM7qv5/T9CfPwzvo3YCMl57Z6u8viXo12qO
uRF5tupv5rBb1i0kmJMVHOvtJ7j6cbgqhfEn6IePOh+1SXBJ3jeBGlv3j11j
a/86lY/OJJh4v/4H4LaNtA==
               "]]}, 
             {FaceForm[{RGBColor[1., 0., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{502.648, 
               195.906}, {502.648, 196.754}, {503.125, 196.871}, {504.469, 
               196.35500000000002`}, {505.16, 196.09}, {505.195, 195.934}, {
               504.64500000000004`, 195.58200000000002`}, {503.566, 
               194.89800000000002`}, {502.648, 195.047}, {502.648, 
               195.906}}}]}, 
             {FaceForm[{RGBColor[
              0.8117650000000001, 0.06666670000000002, 0.14902], Opacity[
              1.]}], FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
               504.72999999999996`, 198.164}, {504.72999999999996`, 
               198.617}, {507.008, 199.809}, {507.875, 199.809}, {508.887, 
               199.809}, {508.328, 198.359}, {507.199, 198.055}, {505.562, 
               197.617}, {504.72999999999996`, 197.65200000000002`}, {
               504.72999999999996`, 198.164}}}]}, 
             {FaceForm[{RGBColor[1., 0.8, 0.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{539.324, 
               194.605}, {539.324, 195.73399999999998`}, {537.2930000000001, 
               195.578}, {537.0740000000001, 194.434}, {536.93, 193.695}, {
               537.164, 193.52}, {538.105, 193.65200000000002`}, {538.777, 
               193.75}, {539.324, 194.176}, {539.324, 194.605}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
               628.9609999999999, 202.547}, {629.168, 203.621}, {627.668, 
               204.348}, {626.875, 203.555}, {626.082, 202.762}, {626.805, 
               201.258}, {627.883, 201.465}, {628.379, 201.562}, {
               628.8669999999998, 202.047}, {628.9609999999999, 202.547}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 
               3, 3}}}, CompressedData["
1:eJxdUltIVFEUHZVEwspS/BhM7KVSyDQfERXmEpGKiqigDymLwYk4Z66lQfTw
7ptJhD+9oEaI0J4Q1DRUyiAymZSFhFYQojXkMEhEWVRkmESdM/vQQBcO96z9
XvusBb792/wZLpcrTR2vOunqbFzZWrknSHjY7vbEwgLLTuWPDN4hNO47N9E0
LPDt1WZfTohQ4s26XTAqECk8+XHrdUJt94bsdI9E34/SnWcuGv9NifKZw9cO
BI3/vkTixqXHRSp/oqliRW1UQnUbfzFAeDtFoue5RFFYdcp10PnsULSdJFY9
UJdFDudB4vXhD8Xe5Q7m19SteTdHokD/PQ5OB+vntWRLznM7UFNFCscF52c4
aFPu3m7BeQonebYKtrtTeH38aF6oLIWTfH2m/qcUfqoDcuQ/7IktzmyulJhV
du/ylxIHmnZ5l4RLf7+I54lL5Lb0DlyJEXbMVoHTku2PiOOyAujXdTuI+Sqc
nMNP3E/htbrwLsKxvNC6+GfJfoswMvhze8Jv+h0nbNL2JwK6THgvYbXew13B
/mLCqN53qYmftPFy4ZspOmHmSdhsH5PQ69qi8JLM5gtVBwPMU2Eth4q5Fu8r
jXBWP/xug6uJeTZYsN5P3/raSJhUsuizLdZTg5n/vMX1q4zeOiyu/8fmOTot
3kO/ze9aY7FuwjaiOj4SYD202cx3RoD1M2Til5p9e40e1ftfre76/ruOmI8j
WJ9HzL5sgf/1/xc+N1Nd
               "]], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIlIGYC4vfLj3mbt7Q4fNOI6T9Umu3QLnbz3Pe2Fofb
P+uy9jRkO4DlO1sc9O+qsDXORPDvgOTXIPiPl84+onAg20E2KsX6fm+LQ8bE
tzX2L7Mdtpwo2zd/covDcaAqR44ch8u+SQIRM1scVNkapzqr5zgwgMC8Focq
kXXuD90Q/K0gfX4IvrohxxqZvByHT5eABkxscVjkuu3z35wch+l5Qs0HgO4t
tOW6vtgnx+EhyKCaFocwPt1Nc7VzHI4obCjKKGlxqAaZr4XG90Lw43Z58jAF
5zgcBfErWxyKQB5IznEAimq317c4TDj0VSMmP8ehwzHh6YW+FofW14E75Hpz
HLL2lEyWmNDicEkJGGKrchyAofhVo7nFwaU75/nvgzkOOpvmvl9eBA2fB1D1
SdDwWQm1P6HFYQbIH35Q98e3OABlTeOEoPYD5cHhwAE1Pwfq3zfZEPeUQd17
ORtiTgU0vI5B47MMyl+U7TDNGeiwYqh7UrIdfIDRklAFtc8PGp9I6QEAyt/y
gg==
               "]], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 
               3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, CompressedData["
1:eJxdU2tIVEEYXa3UXhIWEVpmoiWYmFFJmewxkQiLrSSLEgnRsO7cW27Qg0QQ
Z5AIswepJCG9kCIkpIdEmJiERqTmUkiamIqYbivKmv4ImrkzONCF4XJm5jvf
d873zYa8s4cLFjgcjgC+wFcgX+uO56cMBDC8bL/QXNdg4PLYxqSQpQy7XvCN
TgP7lgXGl4cxsPFDTZF+jWficipbA8g89hY7t+eGEnRFf58rCWc4GprQeC+R
wFf/ITM5huF84U1vcSbB1bSTI11OhiurGvYO3iWw82cw5L7hTOME7/2ceCfD
km8Pz6WeMrFeJN7GJG+Vid0DrorqWIbMZM7Ua0q+hSqfy0KriB+nqLHCylqe
WvKeh2K/+Pst9BzIW3GsW2P7vF3j8tW9n/90UCT2xwSVFlmY+sIDeij4btZQ
gYVX0389l4Yo3tWFJ/YftGScl2JTUsiztTssDD2ubYsKVn7x+mzM6+2bKznz
lphYzsv0bWXIFvUGm2iLeu4ujGeIDSq9k95JwF31x3G/mgV/jfI3XPn9hEg+
B8MeLjs6wsSk8HeKolrozTalT8MUgian3JR9HdQ4Rfj3g8p8HKcKo/soVpa1
fLxfpLFb9CtLYzt/gonXQj/ns31bbMp6fRTXRQGfiDxfxCDCnacJNnO59dyP
LcLPBCL1z1Cpb9ZAVfo1Mjqp/B0xECmM+0Vl/78auCgujmls841qbOv+SeUc
TRs4wX8urs8hvjUEwmafR+F8NX+1VPbniCn5b2ssaFyVGtv9rVD60zS+IfyM
0PhBBp+MCaWXx9v97lPzXaPiO4j05ZGqv1G9jxYq99PIvN82X5Mh8bC6f8uQ
8zJB0S367DbkPPzW2Nbn09h+P7NU+l9h4P/3/g+ufdx1
               "]], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4mnO3TnPLVsdeqfnCTUb5DlU7JsvpW/W6nDc
27zTMSHPwYuHSbv9ZYuDbFSK9f3Z+Q66m+a+X/4QwQfL30XwQZT/nRaIeR35
DhkT39bYA+XVDTnWyITlO1zxTRKIuNfiADZeMt+h8qWaIceDFodqkXXuD/ny
HbZ9/nul4hXUPOZ8h0+XgBo+tjjsBzrr7p88iHmsrQ4Gd1XYGvfmOVwGmSfe
6uCY8PSCUnmegx3X9cUFmq0OhbZABtA/D6uABgP9p8bWONX5d67Doa8aMf1W
rQ6rPgINZsiD2GPd6iDUfODUQtY8iLw1VL10ngN6+AAAnyeB0w==
               "]]}, 
             {FaceForm[{RGBColor[
              0.8117650000000001, 0.06666670000000002, 0.14902], Opacity[
              1.]}], FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 
               3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGI1IGYC4k+XfJMEjNsdLird/lnHlOnQ6Zjw9IJzu4Nw
84FTCzkzHZbNPqKwIaTd4ZtGTP+hixkO7WI3z333a3fgvr64wLYrw+HwV6CE
b7uDjzlQZ22GwzTn7pzn7u0Oqz4CDU7JcLgAMteu3aFaZJ37Q68MBz7dTXPf
m7Q77J8vpX/XIMPBk4dJu1293aH1deAOOdEMh8qXaoYc4u0Ox72BBv5Jh/C/
tUHsO5XuYHPfv3f6iTYHyy0nyvYtTnfQARq3fHKbA0h5wsp0B6Arv2rMRvDt
uIAaU9scQMrnL4Pq92hzuARy1y6o+cptDo+XAj36Jt3hYRXQocxtDkIg/wPd
IxuVYn3/eatDxsS3NfamUP8/bXXQv6vC1rgUwd8H8s+ODAdgaBVlANWDzTuS
4bCkwJbr+stWSPiczYCY/6YV4p5rGQ7g8P/QCgnfu1D1X1odXIDB+PthBkTf
v1aI/19lOBwFmc/Z5nAM5MErUPuF2hzCQAF7HGq/epvDnZ91WXvWZEDCJ6jN
IRQkn5wBDx+wfYlQ8w+2OQBNCX4cC43Pu20OoGCzbcpwkANFzK82SPyszHDY
CnK3bDvEvuvQ+FVqd1jkuu3z3x9Q/yClJwDhcCPP
               "]], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 
               3, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {
               0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 
               3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
               1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
               0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 
               3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, CompressedData["
1:eJxdVg9MVlUU/zQKpSA0Y6wQBUwoKHJNnRZxnMs/aX/dypp/mGUjHsL37nsp
uaSR416ck09yiVszVhqIMiMjZWbYAoFyKRnZyAiRlJBEhIwpMbv3/Q7i+ra3
t/Pdc8/9nd/5nXNfzKrsF1ff5vP5Runnff2M1k9vWf2imf8oejLkl13+VpeK
s8Zv/Ebbr77+eNtz2l4W+PZqwoCibZFBL4VpW/+7pVjbm+aknW/6zaWfnlkV
vvSaollVjWtrzri0rqbkvuRBhXeLS293TZ02ZkhRw6KZm+acGrHDHj6w8/KP
LplX2RDvP+lS+/oJ++ffUFRv/OsYj7aro/O7X6hy6bLB6yugS++kTl+x2yWf
9ysg7fX9xwEXuLV/epH2WOfS9rmbMzt1/KbYM9dy57m0WIdNu67oIRXRciKY
8V5VtKZzsPxKnUPhSzWSi4w/1QHOFsazR1DHpx/WTW5U1HdKJ/6sIGNWHlT0
pYZfct3GOVs5n89s8GMx/kyblhs+5zF/CTbixyjk0eOniSaBCXz+535KMXUZ
z/tL/eBnnCJtVUcX+8FnuIJfnh/4wxTNN46Wn3b79Uoo432e/UM5/2Q/mbTS
7mT8v2eDnxDmb1Y2cGlbmD9UFh2bXCnSxyr65KmD/UOZa8BHCPM7I/NmPK/e
ZCHuWI6XYiHvYEXx08ZURM22UJ/bFRm6SmZY4ONfifWpFvD0STqq6WgNt+B3
QdJWTeOywQzo86SkLUYoTRnQywGJd2kG9PCBpB6jl73sf4s9zvD1ikQeFeyf
Kukeo6crGdBbIsfX53s83mJ76/ES+UdY4CtO0orDC+8afb8FfURLajkxsKRj
ooU6TZI02yRyw4L+pzDeMJtqdVoBbXt5bh+xTdnbte3xFcd4j/D6dEnJrVPu
yOu2SVelOWexhI7uFVRn6vWapJ9zdOFJkEaVqHIlJZr6rxbgt1BSjHYr2sDr
hbxf2wWmXoV8Xq5AvjsYTyHH3yfB2yFBT5v9XzOeNkGmTIF6ScatqF/AT9fL
69dgB/1wWoK3SAfvVklmzGQlODTJCL1dQq+POeD/D4n+SOF1bUeZwLpfvfz/
5PotdOgJE+gSn7/EIdNG1VpPjxp8yx2eXxL9nc77fQr4bQd10HotNXVc7wD/
3azv9xzKOOJui4zg+ZnvgLco1nMBx4vleaAc9F+8Ap/D+xN5vm5woIcktt/i
/Unc/2846KMkxveyg/o/qJDfXM7nAQXdPeJAL1E834Ic1FfPB4/f0wLnB/H8
OSxoh9HhEOtPzztvfgxwvTbz/Otjfbwp0O9/sb4WcLxO7q9YrneHRF+PYn21
SfRBuw0+Wvm8Rtaztj0c1TZ417Y3N6rsm/rwzqu04XdWoh57bcQ5x3os4345
PzwPbPDSyXreY9Mhw28X67Xchp4vSuS1z8a86JaYdxU2nTPC72H/L3i+93J+
X9mYJ/2sz+Mjtud/nOd9P+tZ2x4OrT/vPrtgY76Gcj2CBM6P5/syRuBNikLN
O1Ug35V8X68UwJOjgD9fAG8u6ykggOdd9t8pwHeeAp/7uV4b+X45KlCffF5v
FtBnwfB9JcBvQKHfYhzaZfTykUJd0lmvxzherYP50aCgpwbur3pFC8x99YND
3vdIDfdLnAt83ynMkbUu+l/fx978LHehi7OcT60LvXYp1LuZv096uX9/dXE/
9nE/6O8Xb378zefr75v/fw/9B6bsL9Y=
               "]], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 
               3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
               3}}}, CompressedData["
1:eJxdU21IVFEQ3SwUKhaxEOnDTCSiDyTIzKw8UiGxlNQPsbAQMTQh3b3vaktt
QSy9SSJD9oeVlJSGFCKLX6mYLCnrIiRWRkiESERU6GIpFhZ0b3N/9eDymHfP
zJxzZt7mkqqT55Y7HI5l6mSoE6NOQ2WCP9RDmPXlZJwdldjZcT/a2kcYcWXW
5qo42hp2ZQ4Qvr8+VhIfkeiK1Aw2DRJ6k69/OzEs8UZ9LhwiBJJWFDifS8aN
EGZ0vXaJ+MKsrkiYcOHz0pO5exLewaZ16f3EdUolHjcOpwQ7CHnTl9a2r5d4
9uPPhFf1V1He9JgFTaM4QPiogdKCUxP0E7p1/jYLKluU+0z9eYH9U/m3GryE
Nf7Q6MNJgRu5xZ/GawgaVj8kUHT7xcLWakKCvu8UOLo6ZjtZxHWbTb6HkP4h
LfZao8Dp0uypfDcxj7sCDv2cIhxc+a7ZXW3ibIJOqywQqNX9Uoi/7xU4oHGr
CMqt3uRNAlpm3k+b68cJ3NH+z9js21cPJrSfszY26MZRDyhxcmxRxRt1vOBh
v6I23nq/bNn128P95myENUGn0TNvo0/PJ1WwP4sGv0dgh57vks36XYJ1xxHO
9KvMMoGKARlISiSU16sJXhH8TjN+BEy93YTLej4tAhf1PHOM3qeCeR4y82oz
94eNX93GryPEuJeC9R03+FiL9RQR+7LPYr0VxD5WWYz3mf18ZPbjpuHTZfah
jrhOr4Xzmn+d2d+Q2R+F/zfXMonx1Pe/rj4w/YKS79sIWXpBhyT7GSTGqf1v
cSsmnYRXOlb/x///z1+Qv4VC
               "]], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxdUmtIlEEU3VbIUFlSJMooH6gsVqyCtWVEJwzFR8UGgYSpSIFEm8vMlGVP
seUiq8gaqCChuOWyFSGhsESIiIq/QouIiCiLkIhQg9Doj3eY+eUHF74zc++5
55472Y3NZy8lOByOLRxuDidHZvCXL95GaAr/vn38mUJvaejKUjuh7lVFipNx
ZYpzHwUJWaOiKRxTOJb0IRIgwq30F+WLj5Wp6yDM53z6d3dIoWViMMMTsrjf
5ncS+q6mtU92KnScaPgx/4BwZGzu+kS9wrQmvk/wfM7d2papMKMx6/n+ZGA6
a1YitYYzmwnc5WDdc4nLr9XDnfWEBc3fKlGo63yEVq2nTOLdqcbtNScJ/qX/
sdV0afhLCOPcbvCbgOvAy0fLXss3KRAJsMICwvsbP/OL4vZ+N0G3Hx0RWInO
VnldZOYKCxz9cqarL8nqDQnc5LJtiYRs7U9QYD+XRxMIVV6e9J5AhfYv0frV
I4wfyRYPC1TrPJfFTy3eZfGcwJ+3PJCbEN/Li1oXqO2e+usuIpy/yErypPG/
mMCntd3F0vh8iEyfUuvXYUKJ9tsnQTs+vlkrI7OHgDR85+x8MQk9fpT97Nc8
X6XRf5rg0J9bmb4XyPjkt9hP2KN/wgqLehHXCAW6UcTe37H75ve0+b1tADk1
HF8=
               "]], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJZIGYC4qMKG4oyXNsdGEBgVonDp0u+SQLu7Q7a7WI3
z80sceDT3TT3vUe7w9sae9O4GSUOD6tE1rl7tztUA6mHU0ocrgCVR/hB5SeU
OFS+VDPkCGp34AXpay9xkI1Ksb4f2u5Qvm++lH51icPjpbOPKHi1O+Q+/73y
YwBUvxPUPAmofS7tDjvkWl8H3iuG8z1AFt8thrsPZMyGPcUOtlzXFxc4tDsA
Ve+Qmw5Vb94OEa8udogGWu9v1u4wWYIljK+9GOI+43aHjIlAF08sdgApX67b
7iADcidMv3q7Qw7IffOKHQzuqrA1KrY7LHLd9vnvgmKHrD0lkyWkoe5bADVP
rt3hagWQ8aPYIab/0FcNoH59kD7PEocOx4SnF4zaIe4uK3GY5tyd89yi3cHb
vNMxobfE4Qgo/O2h/geG7/Q8oeYDzoj4AIe3C9R8IH9JAdBnQD44HIF89PgD
AJqJyQQ=
               "]], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{733.2810000000001, 
               283.699}, {733.3629999999999, 283.58599999999996`}, {
               733.2890000000001, 283.574}, {733.2810000000001, 283.641}, {
               733.2810000000001, 283.656}, {733.2810000000001, 283.68}, {
               733.2810000000001, 283.699}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
               3}}}, {{{707.8159999999999, 215.309}, {708.172, 
               215.23399999999998`}, {708.512, 215.141}, {708.8159999999999, 
               215.023}, {710.133, 214.52}, {712.0780000000001, 213.465}, {
               715.109, 212.684}, {707.777, 212.758}, {707.777, 212.758}, {
               707.8119999999999, 215.11299999999997`}, {707.8159999999999, 
               215.309}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0,
                1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGI1IGZigALudoe4XZ48TNzZDrZc1xcXiLc7qBtyrJER
ynbg0900971yuwM3UNj2VpbD0tlHFDbItzvMyBNqPjApy0EHKL1crt3h5rnv
wY9bsxy2ff57pUKq3WH/fCn9uzlZDvp3Vdgahdsd+g991YgJznLwNu90TOBp
h9CWWRD7mNodvmnE9B+SzXL4sPyYt/m3NofbP+uy9rBkQey52+ZQLbLO/eGl
TIdPl3yTBPa0ORwHGbAm0wFoytMLU9og9m/MdPABmTsLwQf6Sru9qM0BpExp
faZDDMghsW0Q/x7OdIhKsb7v79jmUAByyJdMiH2abRD/y2U52IHcJ9oGcZ9t
lkPlSzVDDpE2h70lkyVY1iH4YP8czHJ4DAogoPpCkHlnshymOnfnPBeDuudq
loN86+vAHRJQ99zPgrhPus0BZI3tsyyI/+TbHC4pAUPgFdQ8tTaIuz5lOUSD
3KvX5nAHFD53shyOKmwoyjBtg6i7kOVwGBjM/S5tDhkT39bYb81y2HqibN/8
FKg8MD5g4QOOz6wsBzmQe7a1OQBVm8alZTkATe+dfhpqX1eWw3tQfDxscxBu
PnBq4cYsh6w9QI//hpr3AKr/XxsknhmzHdDTEwBJJQ8N
               "]], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0,
                1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGI1IGYC4qw9JZMlFNsdjnubdzryZDnobJr7frl+u4Mq
W+NUZ+Esh+gU6/v+du0OEw591Yi5nelw2TdJIMKy3YEBBKZkOjxeOvuIgkW7
Q+wuTx6m9kyH98uPeZsbtzvsBRrLkpfp8OkSUIN2u0Pv9Dyh5pBMBxB1QKnd
4ZLS7Z91VpkOYPvF2x2qRda5P5TLdJgBkudod7h57nvwY1ao/jdtEPuuZDhs
PVG2b/6RNgcfoHMT1mY4AF3XO31am4NTwtMLSpszHGL6gQ6di+Bv+/z3SkVe
G8R/GzIcjipsKMoIbYO4+0gGxD6TNodvGiCdUP2SbRD/ymdC7GFsg7jPLtNB
rvV14I7/rQ6OIPPXI/gXQf45lOnQLgZ0OUMbxP1nof5jboOovw4NH1aoex5k
QtzH0eZQlDHxbc3zTIj/eNocwvh0N819nekwzbk757kI1P9fMh0ugOyRg5p/
N9OhA2SwWpsDSLv9xUyHw0Bn91u0QdRty3SIBfknDiqfC42vuVD/ZWc6XAHF
5z6o/elQ8661OchGASO+OxMSHh/aIOG0CepevnaIeQ+h/hdqh8gzZTmgpycA
OWwazA==
               "]], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0,
                1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGI1IGYCYtmoFOv7MysdLird/lnHlOnwtsbeNK6i0kG4
+cCphZyZDltOlO2bH1bp8E0jpv/QxQyHT5d8kwSSKh24ry8usO3KcKgWWef+
MKXSwce80zGhNsPhasVLNcOCSodVH4EKUzIc4nZ58jA1V0LUeWU4PF46+4jC
tEqH/fOl9O8aZDjkPv+98uOGSofW14E75EQzHPh0N819f7HS4bg30MA/6RC+
cBXEvlPpDh2OCU8v5FU5WIIctjjdYRnQuA03qhxAyhNWpjt4PKwSWXcSwQeb
a1oN8ccymP5qh0sg/+6Cmr+zGuKuN+kOtlxAi35WOwiB/A90zzGQQQY1DhkT
QSED9b9JjYP+XRW2xqUI/j6Qf3ZkOJSDGIY1EPOOZDjskAO6QKcGEj5nMyDm
q9dA3HMtw0EGFP7yNZDwvQtVL1bj4NKd8/z3wwyIvcw1EP+/gpr/thriritQ
+29VO4SBPHIcKr+x2uHOz7qsPWsyIOETVe0QCpJPzoCHD9i+RKj5tVUON899
D34cC41PlyoHkDNtmzIcDn8FKuSqgoTjygyH6XnAkDlSCbHvOjR+d1c6LHLd
9vnvjwwH9PQEADfzHaQ=
               "]], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 
               3, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {
               0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 
               3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
               1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
               0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 
               3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, CompressedData["
1:eJxNVg1MllUU/kDS/iTSZAz8Q52iZkg/OCjguPJvaVZstbU0c1nEh/C9P8q9
9003MkauGWotWs2x/sDPmEGhETotYOpyKZraiAiRqDmUMnPOrNG99zkJ3/bt
7tz3nnOe85zn3PdNXV3y5JoRoVAoRv+363+s/k+udwu2jRWUe+sPH0W6fDox
pfPaxjGCnnnhwe7l2l7co+7afaegt5LinorX9ub5q/raEwTWn3ycGy0oq/HI
+gOdPo3d9PW3H9wiqPRAdXJ6h0/xcz7f8ftNgg4/Om/z/JNDtl1P+PTJ+22T
6+PY/7hPOQZHjKBD5nybT+0GT0hQ08Ty/icafbJ4B0vp4it5D6z82KeQ/Qka
Y/JW+mTcVmn/gm36RKlPp8X56Rk6vo2z0Mf+bYJmVSR2HBvFeMcJWvvb9eil
No/OLt9SVTyL8ed51GsALmU8O13gLBH058llqxMec2mPNqu3C6x/O7Siecnt
sd1cz2cO+Jkpgb/IoUWGT0+CvzQH8fdL1DEQQZ4zEvkbIqS9miZ2sn9NhPsk
sV8VodGGx24J3soiwH9OIk84Ar9fJPA+HgHvfRL1p0fAx3kJ/D+XwO6XWLNK
gOuCJNdsVBQD10VJHy7Ye/nforWoU5+3/GYW3Yhn+01hqirWnbnA8XLC6Nsf
kmZk3Fw3PjuM/vwlyYSpzgyDj5EKz6eH4Zei6KBO25UQpndNvHsVbW25kvbs
9ULo83lFW0yi9kLo9z2FvDWF0MNpRQMm7y4+P8zuNnwtDZC3js+XBdDFpULo
LRogvs4/wTR0mG2fNwSoPzEMvpoDWml0kBIGry0BdRy7mt87IYy+fRNQtil4
MAz97w2AN94hjW5Rj7YtH+8M2XbVtuWrifHudygw+28HlN41bWRZv4M5fSkA
znEu+pUVwI9c6Dw2oNmm/2tc8NurKNXUsYGfn1Pw17blSds230YX9R5XwPMm
x48q6PxL9n9NAU+3C3yugt9lF/zqftl5HeVBp/kKvCV5WBcq9CXNI9PmyocU
9HqfR+NNonkKeXP4eabCvp5XW3+6Qv+WeJizaZw/36NWcz5Z0VyDb4XH95fC
3BWw/6AEfseD3rRea0yflAf8PazvVz3g+l5iLss9xDnEen6d4+2TmJMKD/PX
IMGn9rd9iEqc2+BBDzVsr2P/Wp7/Fz3gqmV8T3vgt06ivoe5nj0Sce7x0HeN
x/YlzuP+SvB7xgX+q3z/NLvQcZwCfn3f2bwJ3K83+P5LYX28zPqZoZBnsYt6
Mni+pnC/sxTqjmF9kMJ91eNgfwHnO8J6fkSB9yYH+9q2fWx0bujD5qt3gDdX
oR+7HPhlsx5reV7u//8+4HhzWc87eV7msF6jDnQ1WwH3pw7ui5kK912dA9xT
+fwXfL9P4vr2OeA1ifV5dMi254/yfZ/Eeta2vQe0/uy9+Cvn7+N+xLnIr/Vi
46e6PIcS936ei3pJAsdzLtY7JPCXu8A7gvVU6QJPiM/v4Pn8R4Cn3dyvawL3
1EEXea/w81MudDUg+H3lYv+swLylevSV0UuLAC49T3bO1nG8Vg86dfh9fZjn
yxWo8zt+vonfn1N94CsSmPP1PnS3TIC3qA/ecvl7pdWHXu8W6Pcp/j6ZJDC/
P/p4Pybz+15/v9i4iZy/i78vhn0P/QeJPxcd
               "]], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 
               3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
               3}}}, CompressedData["
1:eJxdk01IVFEUxyeLMSKmshKpSadJWgghLeyT6u8mCymphYsgkcHQRWlz3k3P
fX2ARZiVC3OhKSVlCUXIUEpT0CCMqAiJFRFDhMkQNUVZUVDUonc9d9XA5bx7
556P/++cuzbScPDIfJ/PN89bJd7K8taz8OvfZ64wvpzaVVI1oXC7ZyQUu8wY
K9/cWurtQzGqa29hfH++L7J0XKGrPufc8FlGPP/8pwMjCodqtk9XaEZH3oLK
wBOFNeYgyvhs4g0ovK1o66wnxrH3f+5861bwvCduXGIMjjcmemsUhoztZpTN
uCsGViuJ08bwdmUzkw7q2r1IKUbaFKYcsb9Y/IocNCV6VxVna4n/g3ChtPrd
VEBjucmTItGVo0VHkrDH5FmppY4HJH55GoEN96/N9hFajX9Qo/hNob+5h2Aw
VBdosVcJPvPbr7Fz0au+4yfs/qLGtNFZSaI7oeV8C8GjFM/PaLEFhB3Gb4kr
8bMJU4Z/oSt8P0aF5zoXQfMxG5XzsCtcf0aFW8jFS86s3/g3KvmCLkZNgQHC
UaMn18Uj058wCZ9l9v4mQr/p70JX9JeT8Pyqcfjx3sVZtYSiltzU5Ast3E+T
1PnQ8uiw8To1Tpr+3CLh3Gz13iWpg7XEvUeSp8nyGrK8GrXoeUqiL2Lv+x3R
s1vLnG1zbJ+1cGtw5L5fy3zetPORYaln0M5DmqWPcUfqTtv5Hbbz84GFc61C
ldGdZMkXU/J/P2OrAZ1UwvM6S5+8+Z+b+y7G3Lvx3sf/7+cf+nSByQ==
               "]], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGINIGYC4kNfNWL6/1Q4ZEx8W2O/usThasVLNcMfFQ5x
uzx5mID83Oe/V378UuGgsKEoY+LKEofW14E75D5WOFSLrHN/uKTEweCuClvj
2wqHC0q3f9YtKHEQbj5wauFLKH8GVP3zCofpeULNB3pKHIC2mMZ9q3Cw3HKi
bF98iUP5vvlS+v8rHPRB5shD+X8rHB4vnX1E4Vixw33/3ul5CpUQfWuKHbTb
xW6ec6x0uAgyv6rYYZHrts9/YyodqkDucSt2iEqxvu9fXglxt0gxxLzuSoet
QOvmPyqCmDsBat6BIoedckAXrqqE+HsHVP5EpQOI2rCsCOLvx5UQcyYWOXQ6
Jjy98KoS4t7uIgc+3U1z33+sdFAEqWstclgG0vej0sHbHKiyvgjijg+VkPCa
VAQJj5dQ/qIiSLg/hvJXQflnofwTRQ4yIA+tr3TYAXLnjyIHj4dAn86thPhT
tRjijumVDuB4NCmGhMukSgdbruuLC5yLHbRA4dVf6WAFCu/AYodPl3yTBIoq
If4oKIaYFwr138piiL+B4TkDFF8PiiHuT6p0YAABjRKIv1wrIf7OhfJVKx1k
QQ6aWOJgB7JXtBJi72KoPGslJL6B6Qk9vQEAyQEzcw==
               "]], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJZIGYC4vJ986X0SysdGEBgVomDbFSK9f3CSgftdrGb
52aWODxeOvuIQl6lw9sae9O4GSUOtlzXFxdkVjpUi6xzfzilxAGk3D8ZKj+h
xIFPd9Pc99GVDrwgur3E4Zi3eadjSKUD2J7qEgfLLSfK9mVXOuQ+/73yYwBU
fzXUPAmofWWVDjvkWl8H3iuG8z0eVomsu1sMdx9IeMOeYgegqh1y9ZUQejpU
/YRKiDurix1A1idMrnSYLMESxtdeDHHfzEqHjIlAF08shpizpNJBBmQuTP+G
SocckPvmFTssct32+e+eSgi9oBgSLieh7lsANe9wpcPVipdqhj+KIe7cWOmg
f1eFrdGzxOEdKFxmVTp8uuSbJFBWAlHXVwlxV28JJFwaof4Hhu8Fpds/6yoQ
8QH2RznUfCAfbC8wPMDunAXVjxR/AKgq1GU=
               "]], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{418.719, 283.699}, {
               418.637, 283.58599999999996`}, {418.71099999999996`, 
               283.574}, {418.719, 283.641}, {418.719, 283.656}, {418.719, 
               283.68}, {418.719, 283.699}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
               3}}}, {{{444.184, 215.309}, {443.828, 215.23399999999998`}, {
               443.48799999999994`, 215.141}, {443.184, 215.023}, {441.867, 
               214.52}, {439.92199999999997`, 213.465}, {436.89099999999996`, 
               212.684}, {444.22299999999996`, 212.758}, {444.22299999999996`,
                212.758}, {444.188, 215.11299999999997`}, {444.184, 
               215.309}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0,
                1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGI1IGZigIJXlQ5xuzx5mLizHVpfB+6Qu1jpoG7IsUZG
KNvh8dLZRxR2VDpwX19cYHsry2HLibJ98w9UOszIE2o+MCnLYRlQesOhSoeb
574HP27NcpgswRLGd7rSYf98Kf27OVkOi1y3ff57o9Kh/9BXjZjgLIeMiW9r
7J9XOnibdzomWGZB7Ptd6fBNI6b/kGyWg8KGooyJwlUOt3/WZe1hyXK4oARk
uVQ5VIusc394KdNBJirF+n57lcNxkAFrMh2AppnGXauC2L8xE2L+aQQ/9/nv
lR+lqh0cE55eUFqf6eDxsEpknWs1xL+HMyHuqK12KLDlur74SybEvjXVEP/L
Qd13tRriPtssB17dTXPfX6922FsC9Ok6BB9szsEsBytQAAHVF4LMO5PlcLXi
pZrhpWqIe65mOYCCof8c1D33syDuO1HtwAUK32dZDrIg/x2sdrgEcserLAdL
kHmbqyHh/SkLYs/iaoc7oPC5k+VQvg8Y0FOrIfF0IcuhChROZdWQcNia5TAd
pM8MKp+TBQ8fcHxmZTkcBrlnUhUkHNOyHDpBDsuogtjXleWgCIoP2yoH4eYD
pxZuzHLQbhe7eY6zCmLeA6h+pioH/bsqbI2M2Q7o6QkAI9Mfpg==
               "]], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0,
                1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGI1IGYCYu12sZvn9lY6HPc273TkyXJYNvuIwoYFlQ6q
bI1TnYWzHEDCCc2VDhMOfdWIuZ3pEJVifd+/t9KBAQSmZDpYbjlRtq+/0iF2
lycPU3umg8KGooyJMysd9pZMlmDJy3SQBWlYWenQOz1PqDkk0+Gi0u2fdbsq
HS6BaKtMB7D9FysdqkXWuT+Uy3S4ABJ/V+lw89z34MesmQ4yIP3qVRD7rmQ4
gIw5UFbl4ANy19oMByD59MKlKgcnIKW0OcPB42GVyLqjCD7QFWF8ytUQ/23I
cCjfN19KP7Ta4fFSoEePZEDsm1bt8E0jpv/QV6j+s9UQ/8pnOmRMfFtj/7ca
4j67TAeQcD9DjQPIWqX1CD7YX4cyHT5d8k0S+FcNcf9ZqP9+VkPUX890UASF
z1eoex5kQtz3vtqhCGTR80yI/55VO4Tx6W6a+zrT4WrFSzXDa9UQ/3/JdIgD
hfNhqPl3Mx3e1dibxm2qhrjzYqZDFcidfdUQf23LdHAH+ccZKp+b6WAFii9g
+ID9lw2Nz+YqiP3pUPOCqiDx1g3VL1/lMAPkrk1Q9z6uhJj3MNPhMMj/tyoh
8kxZDujpCQCbLRZr
               "]], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 
               3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxdU1tIVFEUHZUsQiRL+gi1mYFISosgkwp1pUWY2WsQLNSmsce9Z8LUj2lI
Ec6ZRKOPyZ6GiFSEESIS0YswsWka+ojRJAkTG0z6CLGQXkTQ2e1bQhcOh3Xu
PnuvtfY+Ds+JfUcSbDZbnF7r9YrXK3YqtXf7ewnaYkcNhOx99cZFidq8haM3
Wg20bnFPRXdJFOrN6TJRERz8kpktkX7g8OaJBsG7Q2JForxUNCHg7+9attYp
cX3bvdlf3y28RmK6sSCn6rVA1Dn2o6lQYtPdiK+/Q0BHjfgPSkze7AjZDYHk
7DudM945/Kk7XJLrm8MZzR/3PmiSqHpUnBTvEszvvEQa8Zgv0F6zODDwUGLl
ugU9aT4TO3PP6AiJ25+HSz17TNY3LPFE0xqPmpz3mUQD6V8lQNHRiMRG4ndM
gNLu1ve1G7V5iV7QcdesxJuX31yTZV6cJH1xCvVG23TjFS/rSVCct92LlHKd
aZ4ChY1r/KrUs6g8RbFf1db9dAWSleHwgq71bVCs74KAdrsimK9goy9TsP85
Cs9LtLC3JvuVpfBVhw1eNbEjKX51S7Ziv2vMf/n+4uVUCHOY0rirLRw2uY5f
IUw/UgVmyP+AwhD1Ld/qV1BhSWDgxbX9AvcJdypUEl/t1+Wis8c/3FLsT53A
n/l6rLhOm0Ax8Yso9r9HsD8jlp6IQJaW0z2hcI6Ejwnm+06B2uIctfCU4nl8
as1TSIHsL4iZaFmqK/cqnr/TJvvbrLBV0/o5ZLC+SgtLg3nZrXjD4HlNtvQd
Mthv3e86eg9uA/+/l983MH9T
               "]], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 
               3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
               1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, CompressedData["
1:eJxdVAtIVEEUtU1MzNI+RNiWupWZGmIQ9mH1mkR+sk0lUFtFrKB9T3eHkhQV
YyZMLULKxCJD+mFa2RZmImYhYRIk9jUVMRURCbO0EoOimXcHH7TweJydmTvn
nHvu889yJB1d6OLisoA/Fv4Y+FMelTnWE8vga1HktozfNugxDcwVxzBwET93
BZpn/rzP53hTmPs9o48Cy1J2NHXx/Y+7TrbXmhQoE+f3M9jNX6ZoBZZseXRt
KoLBsQuTRZGDCgwXrGzcG8ygkL+G41Ss68fgV6C1oqNchWr78tPPVzDw6L1J
zN0qTL9NyPL2ZnBZ/D+iwjsOUzwZVHT8DLTOyvOLGLyMDy+Pcs+G0dtXX/i5
6lg7/5fO4xBOp+4jRf5bVVDacitXd1IQtE1PFND0P6PQ8J0fLFNwfytF/rE6
1vgH6fiu2O+pgJBb10LhuDgwY4NvdZ3x4c061vQ16DivvdYn9BKFjW60KjpZ
AUHfWUqhf65YaWtRkH8hhRNiv68K6UJ4AUV/OP99XFYmx5p/r1VoEn3g+I3o
28VsWJt2ZNcQpZDRGutp8MpBH2so3NjDO2m0o3+NFBaLeq/sqP+BrDch150U
+rpnk0dtDpgSejjWeBkILBWC71D4bDlfbQ8i6EclhQ/5EwFhSQRKV/GTZyjy
sBG4RcwevWUUJkW+cgnm54qO4zwNwaX1OrYJ3zso+nRI1u+mMCTuiyCYx34K
JV8SW9atJ8hrhCLvEAK+YmGMQujgBjeaSrDf4xTzqsj1SQoxIpglst4Piavk
fTw/wULIfVnfwEDIsTwkIGKV6c7Qh3oyn1+tjzUE3yaGflh1rOnbrmMtX14E
rKK/mxkYxQVe0l8zw77sJHjvATkPmdI/KwM/J0+UQ+ohDP3Ik3yYnN9iAmYR
HCbX+X6troNhPuIJ5Auf0+S6v9RnYfjuc+B8WSTfVAdURZ/LHufzruVj0I7+
Jst5vm6XfWeY5085WOcUgwCR9zU5yO8sg4NC6OHsefyUl3HtVOexNl9GFeeJ
8x8Q9ZwK5iJH8kmU35cU+X2alvOVwCBd6Ou1wf/ft3+czzj7
               "]], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 
               3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
               1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxdlGtIVEEUxzeNCBF7ECJlZhEhLCFCtqxWeyJKzEp6ED1URHusljZ7R0vF
ghkrDSvZRA2k1B6KH4oILbGyJyWLREoPREIjRKS0LPpgD2jmnmMDLQzL796Z
8/if/9zFWUe27Q92OBzT1EpWK0itb32bs2Y7JZxZmzn86iSDVYOp5+qiJSzc
sy9x8AaD6/XPom+FSHjyIyataoiBIssbbPgaWx3y7rf4x2HLb1/6MiBgbtmj
QFOd4Svr73z/U2E4xaUyljHYpP/7BQyptPklDL62PE9xvRVwrKthfmwhg4v5
KlKvAGd5eP/LPAb6eEuPgGZdF2Ogsl9lDwU49E9S/FYBH3Xhlxl4/WOlnkYB
vUsGJk/0MUgODXKWK7b7jfHBnF3utu5G2l/ggwr9vFmAbtPf4oO27qNdDfcE
xL5fOkPMsqBO1xMQkNGpIu21MG8P1XvQgkStX4C4ycL43QL1HLOw3y4BeSO/
WiciOdbXJFDnNA7Fo8viZtZO9c/x3Fmqp9JwR9SpT1vPG1bUEeXn8FTPoUag
LtUc0qrUZBoN2/NtN2znf0EsKH8/5dtN7weJUzjqOyzgTZHaCMQjhmvXVR4e
GTVs6/yZ+t/Osf9x4kMcNup5TAiMU89xDj8FVEdM3xn2gINyzesi5bcp/lAy
72ZSqGHbL+HEfsN2vBzD46We+IwEDlG2UBL956L+4iTqmUn6uSX6zuLohw0S
7HtymuOctkjQ5aeqedzV9aVT/hrSg0uI1BuqOO4rkpCgjaT0tX1bTOePc/QP
p3xeDmv0HHIkPt/B0a8eij9pQe79guoIl8Q4FyzsJ1WCW8dfQH7LpvedPjyf
K/H+FPrw/nolpGv/LvKh3gck+ucxw3PplL+W7lOSRJ2KGT73kH7qPtr3YSXl
z6bvR7xh21crDNv1xkpo1/fKYvD/9+cvJcQFmA==
               "]], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 
               3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
               1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 
               3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
               1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 
               3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
               1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 
               3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
               1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, CompressedData["
1:eJxlVwtwVsUVDtZSxiJoKkgQIUErWmxAGQZFIQdioVZtpqIOtYAMJTMIqOi/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               "]], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}}}, {{{581.3359999999999, 389.578}, {577.234, 386.332}, {
               573.5509999999999, 389.105}, {573.5509999999999, 
               366.90999999999997`}, {581.3359999999999, 366.812}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJxIGYC4gtKt3/WvWl0KN83X0pfvsqhXezmue/nGx2u
VrxUM5SrclhSYMt1fWOjg7d5p2OCbJVDh2PC0wvTGh1m5Ak1HxCqcqgEKuNo
gcpzVzkwgEBxo0NUivV9//+VDoIRlltOpEDNf13p8Hjp7CMK6Y0QdXWVEPHs
Jof7/r3T8wIqIeIbmxwmS7CE8b2sdHhUJbLOfVGTA9id/yodjihsKMqY0OTQ
+jpwhxzQvmVA4zbUNMHdo7Np7vvlSU0O1UBtD2Wg7ndtgpgL9M+2z3+vVGg1
OYCMfQjke/IwabdrQdUzVDlsOVG2bz6Q3wny56NKVP6RSgdYeIHtP4rga4EC
7jGCD6ZZqhzQwxcAkzSlgA==
               "]], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}}}, {{{579.914, 451.809}, {577.98, 432.89799999999997`}, {
               597.4409999999999, 423.395}, {587.59, 436.562}, {601.043, 
               440.91799999999995`}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{577.746, 456.734}, {574.7890000000001, 456.734}, {
               572.605, 455.633}, {572.605, 454.32}, {572.605, 453.012}, {
               574.7890000000001, 451.89799999999997`}, {577.746, 
               451.89799999999997`}, {580.6990000000001, 
               451.89799999999997`}, {582.8669999999998, 453.012}, {
               582.8669999999998, 454.32}, {582.8669999999998, 455.633}, {
               580.6990000000001, 456.734}, {577.746, 456.734}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               579.9219999999999, 452.824}, {574.871, 452.78499999999997`}, {
               574.871, 413.277}, {580.02, 413.258}}}], 
              FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
               3}, {1, 3, 3}}}, {{{555.91, 412.60200000000003`}, {555.094, 
               402.10900000000004`}, {552.434, 394.789}, {548.73, 386.715}, {
               557.605, 394.949}, {563.7810000000001, 387.617}, {
               570.4730000000001, 395.078}, {577.2930000000001, 
               388.77299999999997`}, {583.8549999999999, 
               395.33599999999996`}, {590.672, 387.35900000000004`}, {596.59, 
               393.92199999999997`}, {606.629, 386.715}, {602.984, 
               394.79299999999995`}, {598.055, 401.637}, {598.676, 
               412.98799999999994`}, {588.953, 405.77}, {565.8519999999999, 
               404.469}, {555.91, 412.60200000000003`}}}]}, 
             {FaceForm[{RGBColor[1., 0.8, 0.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{621.996, 130.48800000000003`}, {622., 
               129.80100000000002`}, {621.3199999999999, 129.176}, {
               620.5740000000001, 129.176}, {619.824, 129.176}, {619.145, 
               129.80100000000002`}, {619.148, 130.48800000000003`}, {619.145,
                131.172}, {619.824, 131.797}, {620.5740000000001, 131.797}, {
               621.3199999999999, 131.797}, {622., 131.172}, {621.996, 
               130.48800000000003`}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{627.031, 132.164}, {627.035, 131.48000000000002`}, {
               626.3549999999999, 130.85500000000002`}, {625.609, 
               130.85500000000002`}, {624.8589999999999, 
               130.85500000000002`}, {624.1800000000001, 
               131.48000000000002`}, {624.1840000000001, 132.164}, {
               624.1800000000001, 132.85200000000003`}, {624.8589999999999, 
               133.477}, {625.609, 133.477}, {626.3549999999999, 133.477}, {
               627.035, 132.85200000000003`}, {627.031, 132.164}}}]}},
            AspectRatio->Automatic,
            ImageSize->{{128}, {85}},
            PlotRange->{{0., 1152.}, {0., 576.}}], ",", 
           GraphicsBox[
            {Thickness[0.001388888888888889], 
             {FaceForm[{RGBColor[
              0.8627450000000002, 0.141176, 0.12156900000000001`], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               0., 0.}, {0., 360.}, {720., 360.}, {720., 0.}}}]}, 
             {FaceForm[{RGBColor[1., 0.7803919999999999, 0.14902], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{0., 360.}, {
               0., 0.}, {360., 180.}}}]}, 
             {Thickness[0.001388888888888889], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{0., 360.}, {0., 
               0.}, {240., 180.}}}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{61.824, 236.348}, {
               71.20700000000001, 174.05100000000002`}, {100.87499999999999`, 
               178.52}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{61.824, 236.348}, {
               106.035, 191.465}, {84.66, 170.414}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{134.883, 224.207}, {
               78.535, 196.035}, {91.953, 169.19899999999998`}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{134.883, 224.207}, {
               105.859, 168.29299999999998`}, {79.23, 182.117}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{27.703, 170.617}, {
               89.85199999999999, 160.289}, {94.77, 189.883}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{27.703, 170.617}, {
               84.051, 198.79299999999998`}, {97.46900000000001, 
               171.95700000000002`}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{145.914, 
               150.97299999999998`}, {101.70700000000001`, 195.859}, {80.332, 
               174.805}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{145.914, 
               150.97299999999998`}, {83.766, 161.30100000000002`}, {88.684, 
               190.895}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{79.67199999999998, 
               117.85199999999999`}, {108.699, 173.766}, {82.074, 187.59}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{79.67199999999998, 
               117.85199999999999`}, {70.289, 180.148}, {99.95700000000001, 
               184.617}}}]}},
            AspectRatio->Automatic,
            ImageSize->{{128}, {85}},
            PlotRange->{{0., 720.}, {0., 360.}}], ",", 
           GraphicsBox[
            {Thickness[0.00125], 
             {FaceForm[{RGBColor[
              0.9098040000000001, 0.06666670000000002, 0.17647100000000002`], 
              Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0., 
               0.}, {0., 480.}, {800., 480.}, {800., 0.}}}]}, 
             {FaceForm[{RGBColor[1., 0.9372550000000001, 0.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
               407.26599999999996`, 325.914}, {400.543, 
               343.51599999999996`}, {414.945, 370.715}, {400.543, 
               383.51599999999996`}, {405.34400000000005`, 364.316}, {
               389.34400000000005`, 343.51599999999996`}, {393.824, 
               325.914}, {398.305, 308.316}, {413.984, 308.316}, {
               407.26599999999996`, 325.914}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{420.695, 
               323.801}, {416.812, 342.234}, {435.289, 366.848}, {423.07, 
               381.742}, {424.809, 362.027}, {405.75, 343.98799999999994`}, {
               407.42199999999997`, 325.902}, {409.094, 307.82}, {424.582, 
               305.367}, {420.695, 323.801}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{433.633, 
               319.60900000000004`}, {432.684, 338.42599999999993`}, {
               454.78099999999995`, 359.84400000000005`}, {445.043, 
               376.469}, {443.676, 356.72299999999996`}, {422.03099999999995`,
                341.887}, {420.85200000000003`, 323.76599999999996`}, {
               419.676, 305.641}, {434.58599999999996`, 
               300.79699999999997`}, {433.633, 319.60900000000004`}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{445.758, 
               313.449}, {447.758, 332.18}, {472.93799999999993`, 349.879}, {
               465.91799999999995`, 367.82}, {461.47999999999996`, 
               348.53499999999997`}, {437.78099999999995`, 
               337.26599999999996`}, {433.78099999999995`, 319.551}, {
               429.78099999999995`, 301.83599999999996`}, {443.754, 
               294.715}, {445.758, 313.449}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
               456.76599999999996`, 305.465}, {461.672, 
               323.65200000000004`}, {489.312, 337.195}, {485.184, 
               356.01599999999996`}, {477.78099999999995`, 337.66}, {452.613, 
               330.23799999999994`}, {445.89099999999996`, 313.363}, {439.172,
                296.49199999999996`}, {451.855, 287.277}, {
               456.76599999999996`, 305.465}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
               466.39099999999996`, 295.85900000000004`}, {474.082, 
               313.055}, {503.5, 322.105}, {502.367, 341.34000000000003`}, {
               492.184, 324.367}, {466.16400000000004`, 
               320.97299999999996`}, {456.887, 305.363}, {447.60900000000004`,
                289.75}, {458.695, 278.66}, {466.39099999999996`, 
               295.85900000000004`}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{474.395, 
               284.863}, {484.684, 300.64500000000004`}, {515.1519999999999, 
               304.984}, {517.043, 324.156}, {504.332, 308.98799999999994`}, {
               478.09799999999996`, 309.707}, {466.49199999999996`, 
               295.73799999999994`}, {454.887, 281.77}, {464.105, 269.082}, {
               474.395, 284.863}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{480.578, 
               272.754}, {493.207, 286.72999999999996`}, {523.98, 286.25}, {
               528.848, 304.89099999999996`}, {513.9219999999999, 
               291.89799999999997`}, {488.125, 296.71099999999996`}, {474.477,
                284.727}, {460.828, 272.746}, {467.945, 
               258.77299999999997`}, {480.578, 272.754}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
               484.79299999999995`, 259.824}, {499.453, 
               271.65200000000004`}, {529.7730000000001, 266.363}, {537.496, 
               284.01599999999996`}, {520.719, 273.51599999999996`}, {
               495.99199999999996`, 282.305}, {480.637, 272.605}, {
               465.28499999999997`, 262.90599999999995`}, {470.129, 
               247.99200000000002`}, {484.79299999999995`, 259.824}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
               486.92999999999995`, 246.395}, {503.262, 255.785}, {532.383, 
               245.816}, {542.7700000000001, 262.043}, {524.559, 254.297}, {
               501.512, 266.848}, {484.828, 259.668}, {468.14500000000004`, 
               252.49200000000002`}, {470.59799999999996`, 237.004}, {
               486.92999999999995`, 246.395}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{486.945, 
               232.797}, {504.543, 239.516}, {531.742, 225.117}, {544.543, 
               239.516}, {525.3439999999999, 234.71499999999997`}, {504.543, 
               250.71499999999997`}, {486.945, 246.23399999999998`}, {
               469.34400000000005`, 241.754}, {469.34400000000005`, 
               226.07399999999998`}, {486.945, 232.797}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{484.828, 
               219.363}, {503.262, 223.24599999999998`}, {527.875, 
               204.76999999999998`}, {542.7700000000001, 
               216.98800000000003`}, {523.055, 215.25}, {505.01599999999996`, 
               234.309}, {486.92999999999995`, 232.637}, {468.848, 230.965}, {
               466.395, 215.48000000000002`}, {484.828, 219.363}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{480.637, 
               206.42600000000002`}, {499.453, 207.379}, {520.871, 185.277}, {
               537.496, 195.016}, {517.754, 196.38700000000003`}, {502.914, 
               218.031}, {484.79299999999995`, 219.207}, {466.668, 
               220.38700000000003`}, {461.824, 205.47299999999998`}, {480.637,
                206.42600000000002`}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{474.477, 
               194.305}, {493.207, 192.30100000000002`}, {510.90599999999995`,
                167.121}, {528.848, 174.141}, {509.562, 
               178.58200000000002`}, {498.29299999999995`, 202.281}, {480.578,
                206.277}, {462.863, 210.277}, {455.742, 196.305}, {474.477, 
               194.305}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
               466.49199999999996`, 183.29299999999998`}, {484.684, 
               178.38700000000003`}, {498.22299999999996`, 150.75}, {517.043, 
               154.875}, {498.688, 162.277}, {491.26599999999996`, 187.445}, {
               474.395, 194.168}, {457.52, 200.88700000000003`}, {448.305, 
               188.20299999999997`}, {466.49199999999996`, 
               183.29299999999998`}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{456.887, 
               173.672}, {474.082, 165.977}, {483.133, 136.562}, {502.367, 
               137.691}, {485.39799999999997`, 147.875}, {482.004, 173.895}, {
               466.39099999999996`, 183.172}, {450.777, 
               192.44899999999998`}, {439.688, 181.363}, {456.887, 
               173.672}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
               445.89099999999996`, 165.668}, {461.672, 155.379}, {466.012, 
               124.91000000000001`}, {485.184, 123.016}, {470.01599999999996`,
                135.73}, {470.734, 161.961}, {456.76599999999996`, 173.566}, {
               442.79699999999997`, 185.172}, {430.10900000000004`, 
               175.95700000000002`}, {445.89099999999996`, 165.668}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
               433.78099999999995`, 159.48000000000002`}, {447.758, 
               146.85200000000003`}, {447.277, 116.07799999999999`}, {
               465.91799999999995`, 111.21100000000001`}, {
               452.92599999999993`, 126.141}, {457.73799999999994`, 
               151.93800000000002`}, {445.758, 165.58200000000002`}, {
               433.77299999999997`, 179.23}, {419.805, 172.11299999999997`}, {
               433.78099999999995`, 159.48000000000002`}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
               420.85200000000003`, 155.26999999999998`}, {432.684, 
               140.605}, {427.39099999999996`, 110.289}, {445.043, 102.562}, {
               434.543, 119.34}, {443.332, 144.066}, {433.633, 
               159.42200000000003`}, {423.93399999999997`, 
               174.77299999999997`}, {409.02299999999997`, 169.93}, {
               420.85200000000003`, 155.26999999999998`}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
               407.42199999999997`, 153.129}, {416.812, 136.797}, {
               406.84400000000005`, 107.67999999999999`}, {423.07, 97.289}, {
               415.324, 115.5}, {427.875, 138.547}, {420.695, 155.23}, {
               413.52, 171.914}, {398.03099999999995`, 169.461}, {
               407.42199999999997`, 153.129}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{393.824, 
               153.117}, {400.543, 135.516}, {386.14500000000004`, 108.316}, {
               400.543, 95.516}, {395.742, 114.715}, {411.742, 135.516}, {
               407.26599999999996`, 153.117}, {402.78499999999997`, 
               170.71499999999997`}, {387.105, 170.71499999999997`}, {393.824,
                153.117}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
               380.39099999999996`, 155.23}, {384.27299999999997`, 136.797}, {
               365.79699999999997`, 112.184}, {378.01599999999996`, 97.289}, {
               376.28099999999995`, 117.004}, {395.33599999999996`, 
               135.04299999999998`}, {393.66400000000004`, 153.129}, {
               391.99199999999996`, 171.21099999999998`}, {376.508, 
               173.664}, {380.39099999999996`, 155.23}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{367.453, 
               159.42200000000003`}, {368.40599999999995`, 140.605}, {346.305,
                119.18799999999999`}, {356.047, 102.562}, {357.414, 
               122.309}, {379.059, 137.14499999999998`}, {380.234, 
               155.26999999999998`}, {381.414, 173.39100000000002`}, {366.5, 
               178.23399999999998`}, {367.453, 159.42200000000003`}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{355.332, 
               165.58200000000002`}, {353.328, 146.85200000000003`}, {328.148,
                129.15200000000002`}, {335.168, 111.21100000000001`}, {
               339.60900000000004`, 130.496}, {363.309, 141.766}, {367.309, 
               159.48000000000002`}, {371.305, 177.19899999999998`}, {
               357.33599999999996`, 184.316}, {355.332, 
               165.58200000000002`}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{344.324, 
               173.566}, {339.414, 155.379}, {311.777, 141.836}, {315.902, 
               123.016}, {323.305, 141.371}, {348.477, 148.79299999999998`}, {
               355.195, 165.668}, {361.91799999999995`, 182.539}, {
               349.22999999999996`, 191.754}, {344.324, 173.566}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{334.699, 
               183.172}, {327.004, 165.977}, {297.59, 156.92600000000002`}, {
               298.719, 137.691}, {308.902, 154.664}, {334.92599999999993`, 
               158.059}, {344.203, 173.672}, {353.47999999999996`, 189.281}, {
               342.39099999999996`, 200.371}, {334.699, 183.172}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{326.695, 
               194.168}, {316.40599999999995`, 178.38700000000003`}, {
               285.93799999999993`, 174.047}, {284.047, 154.875}, {296.758, 
               170.04299999999998`}, {322.98799999999994`, 169.324}, {334.594,
                183.29299999999998`}, {346.199, 197.266}, {336.984, 
               209.94899999999998`}, {326.695, 194.168}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{320.512, 
               206.277}, {307.879, 192.30100000000002`}, {277.105, 192.781}, {
               272.23799999999994`, 174.141}, {287.168, 
               187.13299999999998`}, {312.965, 182.32000000000002`}, {326.613,
                194.305}, {340.258, 206.285}, {333.141, 220.258}, {320.512, 
               206.277}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
               316.29699999999997`, 219.207}, {301.633, 207.379}, {271.316, 
               212.668}, {263.594, 195.016}, {280.367, 205.516}, {305.094, 
               196.727}, {320.449, 206.42600000000002`}, {335.805, 216.125}, {
               330.957, 231.039}, {316.29699999999997`, 219.207}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{314.156, 
               232.637}, {297.824, 223.24599999999998`}, {268.707, 
               233.21499999999997`}, {258.316, 216.98800000000003`}, {
               276.53099999999995`, 224.73399999999998`}, {299.578, 
               212.184}, {316.258, 219.363}, {332.941, 226.539}, {
               330.48799999999994`, 242.02700000000002`}, {314.156, 
               232.637}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
               314.14500000000004`, 246.23399999999998`}, {296.543, 
               239.516}, {269.34400000000005`, 253.914}, {256.543, 239.516}, {
               275.742, 244.316}, {296.543, 228.316}, {314.14500000000004`, 
               232.797}, {331.742, 237.277}, {331.742, 252.95700000000002`}, {
               314.14500000000004`, 246.23399999999998`}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{316.258, 
               259.668}, {297.824, 255.785}, {273.21099999999996`, 274.262}, {
               258.316, 262.043}, {278.03099999999995`, 
               263.78099999999995`}, {296.074, 244.72299999999998`}, {314.156,
                246.395}, {332.242, 248.066}, {334.695, 263.555}, {316.258, 
               259.668}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{320.449, 
               272.605}, {301.633, 271.65200000000004`}, {280.215, 293.754}, {
               263.594, 284.01599999999996`}, {283.33599999999996`, 
               282.64500000000004`}, {298.172, 261.}, {316.29699999999997`, 
               259.824}, {334.41799999999995`, 258.64500000000004`}, {
               339.26599999999996`, 273.559}, {320.449, 272.605}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{326.613, 
               284.727}, {307.879, 286.72999999999996`}, {290.18, 
               311.90999999999997`}, {272.23799999999994`, 
               304.89099999999996`}, {291.527, 300.449}, {302.79299999999995`,
                276.75}, {320.512, 272.754}, {338.227, 268.754}, {
               345.34400000000005`, 282.727}, {326.613, 284.727}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{334.594, 
               295.73799999999994`}, {316.40599999999995`, 
               300.64500000000004`}, {302.863, 328.28099999999995`}, {284.047,
                324.156}, {302.39799999999997`, 316.754}, {309.824, 
               291.58599999999996`}, {326.695, 284.863}, {343.566, 
               278.14500000000004`}, {352.78499999999997`, 290.828}, {334.594,
                295.73799999999994`}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{344.203, 
               305.363}, {327.004, 313.055}, {317.953, 342.469}, {298.719, 
               341.34000000000003`}, {315.691, 331.156}, {319.08599999999996`,
                305.137}, {334.699, 295.85900000000004`}, {350.312, 
               286.582}, {361.39799999999997`, 297.668}, {344.203, 
               305.363}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{355.195, 
               313.363}, {339.414, 323.65200000000004`}, {335.078, 354.121}, {
               315.902, 356.01599999999996`}, {331.07, 343.301}, {
               330.35200000000003`, 317.07}, {344.324, 305.465}, {
               358.29299999999995`, 293.85900000000004`}, {370.977, 
               303.074}, {355.195, 313.363}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{367.309, 
               319.551}, {353.328, 332.18}, {353.812, 362.953}, {335.168, 
               367.82}, {348.16400000000004`, 352.895}, {343.35200000000003`, 
               327.09799999999996`}, {355.332, 313.449}, {367.312, 299.801}, {
               381.28499999999997`, 306.91799999999995`}, {367.309, 
               319.551}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{380.234, 
               323.76599999999996`}, {368.40599999999995`, 
               338.42599999999993`}, {373.695, 368.746}, {356.047, 376.469}, {
               366.543, 359.691}, {357.754, 334.965}, {367.453, 
               319.60900000000004`}, {377.15200000000004`, 304.258}, {392.066,
                309.10200000000003`}, {380.234, 323.76599999999996`}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
               393.66400000000004`, 325.902}, {384.27299999999997`, 
               342.234}, {394.242, 371.35200000000003`}, {378.01599999999996`,
                381.742}, {385.762, 363.53099999999995`}, {
               373.21099999999996`, 340.484}, {380.39099999999996`, 
               323.801}, {387.57, 307.117}, {403.055, 309.57}, {
               393.66400000000004`, 325.902}}}]}, 
             {FaceForm[{RGBColor[
              0.9098040000000001, 0.06666670000000002, 0.17647100000000002`], 
              Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{486.945, 239.516}, {486.945, 191.797}, {448.262, 
               153.117}, {400.543, 153.117}, {352.828, 153.117}, {
               314.14500000000004`, 191.797}, {314.14500000000004`, 
               239.516}, {314.14500000000004`, 287.234}, {352.828, 325.914}, {
               400.543, 325.914}, {448.262, 325.914}, {486.945, 287.234}, {
               486.945, 239.516}}}]}, 
             {RGBColor[1., 0.9372550000000001, 0.], Thickness[
              0.021882977499999998`], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{485.59799999999996`, 240.81199999999998`}, {
               485.59799999999996`, 193.89099999999996`}, {447.559, 
               155.85199999999998`}, {400.637, 155.85199999999998`}, {353.715,
                155.85199999999998`}, {315.676, 193.89099999999996`}, {
               315.676, 240.81199999999998`}, {315.676, 
               287.73400000000004`}, {353.715, 325.773}, {400.637, 325.773}, {
               447.559, 325.773}, {485.59799999999996`, 
               287.73400000000004`}, {485.59799999999996`, 
               240.81199999999998`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 0.9372550000000001, 0.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{464.621, 244.23399999999998`}, {464.621, 
               208.45700000000002`}, {435.93399999999997`, 179.453}, {400.543,
                179.453}, {365.156, 179.453}, {336.469, 
               208.45700000000002`}, {336.469, 244.23399999999998`}, {336.469,
                280.012}, {365.156, 309.01599999999996`}, {400.543, 
               309.01599999999996`}, {435.93399999999997`, 
               309.01599999999996`}, {464.621, 280.012}, {464.621, 
               244.23399999999998`}}}]}, 
             {FaceForm[{RGBColor[
              0.9098040000000001, 0.06666670000000002, 0.17647100000000002`], 
              Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1,
                3, 3}}}, {{{464.621, 279.707}, {414.574, 279.707}, {374.004, 
               238.68800000000002`}, {374.004, 188.094}, {374.004, 137.496}, {
               414.574, 96.477}, {464.621, 96.477}, {459.4959999999999, 
               92.93}, {407.508, 92.93}, {365.367, 135.535}, {365.367, 
               188.094}, {365.367, 240.648}, {407.508, 283.254}, {
               459.4959999999999, 283.254}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1,
                3, 3}}}, {{{456.078, 285.76599999999996`}, {402.719, 
               285.76599999999996`}, {359.465, 242.035}, {359.465, 188.094}, {
               359.465, 134.148}, {402.719, 90.418}, {456.078, 90.418}, {
               450.949, 86.453}, {395.42999999999995`, 86.453}, {
               350.41799999999995`, 131.961}, {350.41799999999995`, 
               188.094}, {350.41799999999995`, 244.227}, {395.42999999999995`,
                289.72999999999996`}, {450.949, 289.72999999999996`}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1,
                3, 3}}}, {{{447.53499999999997`, 292.49199999999996`}, {
               390.504, 292.49199999999996`}, {344.27, 245.75}, {344.27, 
               188.094}, {344.27, 130.434}, {390.504, 83.691}, {
               447.53499999999997`, 83.691}, {442.40599999999995`, 79.391}, {
               383.02299999999997`, 79.391}, {334.887, 128.059}, {334.887, 
               188.094}, {334.887, 248.129}, {383.02299999999997`, 
               296.79699999999997`}, {442.40599999999995`, 
               296.79699999999997`}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1,
                3, 3}}}, {{{336.469, 279.707}, {386.51599999999996`, 
               279.707}, {427.08599999999996`, 238.68800000000002`}, {
               427.08599999999996`, 188.094}, {427.08599999999996`, 
               137.496}, {386.51599999999996`, 96.477}, {336.469, 96.477}, {
               341.594, 92.93}, {393.578, 92.93}, {435.72299999999996`, 
               135.535}, {435.72299999999996`, 188.094}, {435.72299999999996`,
                240.648}, {393.578, 283.254}, {341.594, 283.254}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1,
                3, 3}}}, {{{345.012, 285.76599999999996`}, {398.367, 
               285.76599999999996`}, {441.621, 242.035}, {441.621, 188.094}, {
               441.621, 134.148}, {398.367, 90.418}, {345.012, 90.418}, {
               350.137, 86.453}, {405.66, 86.453}, {450.668, 131.961}, {
               450.668, 188.094}, {450.668, 244.227}, {405.66, 
               289.72999999999996`}, {350.137, 289.72999999999996`}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1,
                3, 3}}}, {{{353.555, 292.49199999999996`}, {
               410.58599999999996`, 292.49199999999996`}, {456.82, 245.75}, {
               456.82, 188.094}, {456.82, 130.434}, {410.58599999999996`, 
               83.691}, {353.555, 83.691}, {358.68, 79.391}, {418.062, 
               79.391}, {466.203, 128.059}, {466.203, 188.094}, {466.203, 
               248.129}, {418.062, 296.79699999999997`}, {358.68, 
               296.79699999999997`}}}]}},
            AspectRatio->Automatic,
            ImageSize->{{128}, {85}},
            PlotRange->{{0., 800.}, {0., 480.}}], ",", 
           GraphicsBox[
            {Thickness[0.0020833333333333333`], 
             {FaceForm[{RGBColor[
              0.8078430000000001, 0.06666670000000002, 0.14902], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               0., 0.}, {0., 320.}, {480., 320.}, {480., 0.}}}]}, 
             {FaceForm[{RGBColor[0., 0.15686300000000003`, 0.407843], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               0., 240.}, {480., 240.}, {480., 80.}, {0., 80.}}}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{304., 160.}, {304., 124.65199999999999`}, {275.348, 
               96.}, {240., 96.}, {204.65200000000002`, 96.}, {176., 
               124.65199999999999`}, {176., 160.}, {176., 195.348}, {
               204.65200000000002`, 224.}, {240., 224.}, {275.348, 224.}, {
               304., 195.348}, {304., 160.}}}]}},
            AspectRatio->Automatic,
            ImageSize->{{128}, {85}},
            PlotRange->{{0., 480.}, {0., 320.}}], ",", 
           GraphicsBox[
            {Thickness[0.0004464285714285714], 
             {FaceForm[{RGBColor[0.8, 0., 0.003921569999999999], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               0., 0.}, {0., 1120.}, {2240., 1120.}, {2240., 0.}}}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0., 
               80.}, {2240., 80.}, {2240., 0.}, {0., 0.}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0., 
               240.}, {2240., 240.}, {2240., 160.}, {0., 160.}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0., 
               400.}, {2240., 400.}, {2240., 320.}, {0., 320.}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0., 
               560.}, {2240., 560.}, {2240., 480.}, {0., 480.}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0., 
               720.}, {2240., 720.}, {2240., 640.}, {0., 640.}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0., 
               880.}, {2240., 880.}, {2240., 800.}, {0., 800.}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0., 
               1040.}, {2240., 1040.}, {2240., 960.}, {0., 960.}}}]}, 
             {FaceForm[{RGBColor[0.003921569999999999, 0., 0.4], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               0., 1120.}, {1120., 1120.}, {1120., 480.}, {0., 480.}}}]}, 
             {FaceForm[{RGBColor[1., 0.8, 0.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4k7HhKcXztQ4MICAwwSHx0tnH1GoK4HzwXRD
tgNYnXIvnA+mGTrh/PJ986X077Sg6m9odEAxH8hvfR24Q+5sPZx/Qen2zzqf
RocjChuKMj40QvRXNkH0bWxy+HTJN0ngVKPDUZB8aZNDBcgevkaHy0DhiJAm
B+v7/r3TvRrgfFuu64sLzCvh/Nznv1d+tCmGmOPfCud3gMz/1QHng81Z1gPX
/7BKZJ37wn64+TB+u9jNc9+lGuH8Q181YvofNULMr+l3yJj4tsZ+dpPDNOfu
nOfm/Q6CEZZbTqQ3OoC41cwTHHbKAUPgVT08fNHDHwDvCqa9
               "]], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
               0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIZIGYC4k+XfJMEHnY5XFC6/bNOotVh64myffO3tjvI
RqVY39/f5uDFw6TdvrTDwce80zEhttlBIMJyy4m2NoeKffOl9I3aHLZ//nul
4m6rAwMIHGhy4NXdNPe9WauDXOvrwB1A+WnO3TnPRZsdPEHmxDc7HP6qEdPP
0eLwsEpknfvBNgdBkHm3GxwuA50RIdPqcAgkb97ssGz2EYUNB9sh5jrUQ+yf
1w5R97bJ4fFSoALGTofj3kAJp3oHW67riwvSuhxs7vv3TrdodgAJJzh0Qdxz
r8FB/64KW+PzHog5XC0Q/Q7dDttA7pdqdtgC8veiPof3y495m1u2OgBVPb1w
thvi7kdQ/zn0O4DDq7MN4n6gfNaekskSqzog5izog7hjezvE/3bdEPOedDno
AJ2x/HEPRL6jwyEaGLz+dl0QcxV6IOGeCFV3qcNBBhT+/6C0XA8k3Ga2OwBD
pSijvQPi3v3tDgDqbsmS
               "]]}},
            AspectRatio->Automatic,
            ImageSize->{{128}, {85}},
            PlotRange->{{0., 2240.}, {0., 1120.}}], ",", 
           GraphicsBox[
            {Thickness[0.001736111111111111], 
             {FaceForm[{RGBColor[
              0.8235290000000001, 0.06274510000000001, 0.20392200000000002`], 
              Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0., 
               0.}, {0., 384.}, {576., 384.}, {576., 0.}}}]}, 
             {FaceForm[{RGBColor[0., 0.494118, 0.22745100000000001`], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               96., 288.}, {480., 288.}, {480., 96.}, {96., 96.}}}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{376., 192.}, {376., 156.65200000000002`}, {347.348, 
               128.}, {312., 128.}, {276.65200000000004`, 128.}, {248., 
               156.65200000000002`}, {248., 192.}, {248., 227.348}, {
               276.65200000000004`, 256.}, {312., 256.}, {347.348, 256.}, {
               376., 227.348}, {376., 192.}}}]}, 
             {FaceForm[{RGBColor[0., 0.494118, 0.22745100000000001`], Opacity[
              1.]}], FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{400., 192.}, {400., 156.65200000000002`}, {371.348, 
               128.}, {336., 128.}, {300.65200000000004`, 128.}, {272., 
               156.65200000000002`}, {272., 192.}, {272., 227.348}, {
               300.65200000000004`, 256.}, {336., 256.}, {371.348, 256.}, {
               400., 227.348}, {400., 192.}}}]}},
            AspectRatio->Automatic,
            ImageSize->{{128}, {85}},
            PlotRange->{{0., 576.}, {0., 384.}}], ",", 
           GraphicsBox[
            {Thickness[0.00026041666666666666`], 
             {FaceForm[{RGBColor[
              0.7686270000000001, 0.15294100000000005`, 0.184314], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               0., 0.}, {0., 1920.}, {3840., 1920.}, {3840., 0.}}}]}, 
             {FaceForm[{RGBColor[
              0.003921569999999999, 0.31764699999999996`, 0.5921569999999999],
               Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{1280., 
               1920.}, {2560., 1920.}, {2560., 0.}, {1280., 0.}}}]}, 
             {FaceForm[{RGBColor[
              0.976471, 0.8117650000000001, 0.007843139999999998], Opacity[
              1.]}], FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{816., 1264.}, {816., 1166.797}, {737.2030000000001, 
               1088.}, {640., 1088.}, {542.797, 1088.}, {464., 1166.797}, {
               464., 1264.}, {464., 1361.203}, {542.797, 1440.}, {640., 
               1440.}, {737.2030000000001, 1440.}, {816., 1361.203}, {816., 
               1264.}}}]}, 
             {FaceForm[{RGBColor[
              0.7686270000000001, 0.15294100000000005`, 0.184314], Opacity[
              1.]}], FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{832., 1344.}, {832., 1237.961}, {746.039, 1152.}, {
               640., 1152.}, {533.9609999999999, 1152.}, {448., 1237.961}, {
               448., 1344.}, {448., 1450.039}, {533.9609999999999, 1536.}, {
               640., 1536.}, {746.039, 1536.}, {832., 1450.039}, {832., 
               1344.}}}]}, 
             {FaceForm[{RGBColor[
              0.976471, 0.8117650000000001, 0.007843139999999998], Opacity[
              1.]}], FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{768., 1312.}, {768., 1241.309}, {710.691, 1184.}, {
               640., 1184.}, {569.309, 1184.}, {512., 1241.309}, {512., 
               1312.}, {512., 1382.6909999999998`}, {569.309, 1440.}, {640., 
               1440.}, {710.691, 1440.}, {768., 1382.6909999999998`}, {768., 
               1312.}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGZigIKGRgcw7TDDAcaXb30daPFmukO72M1z3480
QugZ0x1sua4vLrBuAsvviJ3uwKe7ae77jU0Ozt05z6uVoPIRzRBzGKZD6RY4
/9BXjZj+5Qj+p0u+SQJ+rXD9h0HyR1rh5le+VDPksG6D2w9xXxvcfTA+qvuh
/ANQ/oNWCH0Bjc8wE5VvAOU7QPUXQPkNUPkDaOph8g5QfgIaXwCND3NPAw5+
wwwHAN8kadg=
               "]], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{288., 
               1056.}, {448., 1056.}, {448., 288.}, {288., 288.}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{832., 
               1056.}, {992., 1056.}, {992., 288.}, {832., 288.}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{480., 
               928.}, {800., 928.}, {800., 864.}, {480., 864.}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{480., 
               480.}, {800., 480.}, {800., 416.}, {480., 416.}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 
               0}}}, {{{480., 1056.}, {800., 1056.}, {640., 960.}}, {{480., 
               384.}, {800., 384.}, {640., 288.}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{809.602, 672.}, {809.602, 578.3319999999999}, {
               733.668, 502.39799999999997`}, {640., 502.39799999999997`}, {
               546.3319999999999, 502.39799999999997`}, {470.39799999999997`, 
               578.3319999999999}, {470.39799999999997`, 672.}, {
               470.39799999999997`, 765.668}, {546.3319999999999, 841.602}, {
               640., 841.602}, {733.668, 841.602}, {809.602, 765.668}, {
               809.602, 672.}}}]}, 
             {RGBColor[0.7686270000000001, 0.15294100000000005`, 0.184314], 
              Thickness[0.005], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{809.602, 672.}, {809.602, 578.3320000000001}, {
               733.668, 502.39800000000014`}, {640., 502.39800000000014`}, {
               546.3319999999999, 502.39800000000014`}, {470.39799999999997`, 
               578.3320000000001}, {470.39799999999997`, 672.}, {
               470.39799999999997`, 765.6680000000001}, {546.3319999999999, 
               841.6020000000001}, {640., 841.6020000000001}, {733.668, 
               841.6020000000001}, {809.602, 765.6680000000001}, {809.602, 
               672.}}},
               CurveClosed->{1}]}, 
             {RGBColor[0.7686270000000001, 0.15294100000000005`, 0.184314], 
              Thickness[0.005], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGZigIEWhy7HhKcXfLocbO77907fiOA/Xjr7iEJS
q8MyILWBucsBxN1wv9Uha0/JZIm2ToeHVSLr3GPbHLx4mLTbOTodgLJFGcva
HMDGRnTA+cfAdDucLxBhueXElza4/gcg2qUNbv4KEH2sFW7/ExDt2Qp3H8Td
rQ4w98P4YPP9muF82agU6/tzmxzkQPS2FgcQ5a/QBKEtWxzkWl8H7ljUCKF3
N0PMj2x0+LD8mLc5N4IPoZvgfLDxKxrh+rd9/nul4nsD3Pxpzt05zysb4PZv
OVG2b/6Perj7PtTYm8al1cPdD+MDANeSp3k=
               "],
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[
              0.7686270000000001, 0.15294100000000005`, 0.184314], Opacity[
              1.]}], FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{672., 756.8009999999999}, {672., 739.125}, {657.672, 
               724.8009999999999}, {640., 724.8009999999999}, {622.328, 
               724.8009999999999}, {608., 739.125}, {608., 
               756.8009999999999}, {608., 774.4730000000001}, {622.328, 
               788.8009999999999}, {640., 788.8009999999999}, {657.672, 
               788.8009999999999}, {672., 774.4730000000001}, {672., 
               756.8009999999999}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{672., 587.1990000000001}, {672., 569.5269999999999}, {
               657.672, 555.1990000000001}, {640., 555.1990000000001}, {
               622.328, 555.1990000000001}, {608., 569.5269999999999}, {608., 
               587.1990000000001}, {608., 604.875}, {622.328, 
               619.1990000000001}, {640., 619.1990000000001}, {657.672, 
               619.1990000000001}, {672., 604.875}, {672., 
               587.1990000000001}}}]}},
            AspectRatio->Automatic,
            ImageSize->{{128}, {85}},
            PlotRange->{{0., 3840.}, {0., 1920.}}], ",", 
           GraphicsBox[
            {Thickness[0.0006944444444444445], 
             {FaceForm[{RGBColor[0.996078, 0.796078, 0.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0., 
               960.}, {1440., 960.}, {1440., 480.}, {0., 480.}}}]}, 
             {FaceForm[{RGBColor[
              0.9176470000000001, 0.15686300000000003`, 0.223529], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               0., 480.}, {1440., 480.}, {1440., 0.}, {0., 0.}}}]}, 
             {FaceForm[{RGBColor[0.20392200000000002`, 0.698039, 0.2], 
              Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0., 
               640.}, {1440., 640.}, {1440., 320.}, {0., 320.}}}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{812.992, 378.68}, {
               512.0659999999999, 160.04299999999998`}, {627.008, 
               513.8009999999999}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{684.48, 
               336.92199999999997`}, {383.555, 555.559}, {755.52, 555.559}}}],
               FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{605.055, 
               446.23799999999994`}, {720., 800.}, {834.9449999999999, 
               446.23799999999994`}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{684.48, 555.559}, {
               1056.4450000000002`, 555.559}, {755.52, 
               336.92199999999997`}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{812.992, 
               513.8009999999999}, {927.934, 160.04299999999998`}, {627.008, 
               378.68}}}]}},
            AspectRatio->Automatic,
            ImageSize->{{128}, {85}},
            PlotRange->{{0., 1440.}, {0., 960.}}], ",", 
           GraphicsBox[
            {Thickness[0.0020833333333333333`], 
             {FaceForm[{RGBColor[
              0.8588240000000001, 0.08627450000000002, 0.105882], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               0., 0.}, {0., 240.}, {480., 240.}, {480., 0.}}}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{120., 
               240.}, {480., 240.}, {480., 160.}, {120., 160.}}}]}, 
             {FaceForm[{RGBColor[0., 0.501961, 0.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{120., 
               80.}, {480., 80.}, {480., 0.}, {120., 0.}}}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {0,
                1, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{27.629, 
               198.945}, {40.523, 198.945}, {41.234, 198.945}, {41.809, 
               198.406}, {41.809, 197.738}, {41.809, 191.664}, {41.809, 
               190.996}, {41.234, 190.45700000000002`}, {40.523, 
               190.45700000000002`}, {27.629, 190.45700000000002`}, {26.914, 
               190.45700000000002`}, {26.34, 190.996}, {26.34, 191.664}, {
               26.34, 197.738}, {26.34, 198.406}, {26.914, 198.945}, {27.629, 
               198.945}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002951354166666667], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {0,
                1, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{27.629, 
               198.945}, {40.523, 198.945}, {41.234, 198.945}, {41.809, 
               198.406}, {41.809, 197.738}, {41.809, 191.664}, {41.809, 
               190.996}, {41.234, 190.457}, {40.523, 190.457}, {27.629, 
               190.457}, {26.914, 190.457}, {26.34, 190.996}, {26.34, 
               191.664}, {26.34, 197.738}, {26.34, 198.406}, {26.914, 
               198.945}, {27.629, 198.945}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {0,
                1, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{27.957, 
               198.594}, {40.191, 198.594}, {40.867, 198.594}, {
               41.413999999999994`, 198.098}, {41.413999999999994`, 
               197.48800000000003`}, {41.413999999999994`, 191.918}, {
               41.413999999999994`, 191.305}, {40.867, 190.812}, {40.191, 
               190.812}, {27.957, 190.812}, {27.281, 190.812}, {26.738, 
               191.305}, {26.738, 191.918}, {26.738, 197.48800000000003`}, {
               26.738, 198.098}, {27.281, 198.594}, {27.957, 198.594}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752291666666667], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {0,
                1, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{27.957, 
               198.594}, {40.191, 198.594}, {40.867, 198.594}, {
               41.413999999999994`, 198.098}, {41.413999999999994`, 
               197.488}, {41.413999999999994`, 191.918}, {41.413999999999994`,
                191.305}, {40.867, 190.812}, {40.191, 190.812}, {27.957, 
               190.812}, {27.281, 190.812}, {26.738, 191.305}, {26.738, 
               191.918}, {26.738, 197.488}, {26.738, 198.098}, {27.281, 
               198.594}, {27.957, 198.594}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
               0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIFIGYCYn7dTXPfH3dwiNvlycPUn+FwfXGBLZe6owMX
iNGXARHXdnQoypj4tqY5w2H2EYUNRRWODsLNB04trMxwWOi67fPfLY4ON899
D37cmuEQYbnlRNk/RwcGEKjJcADKXqnY6egA0m5fmOFwUen2z7pTjg5Anmlc
UoaDtP5dFTZFJwdVtsapzskI/oRDXzVi/DMcKl+qGXLccXQ47m3e6RiAME82
KsX6vjPUvexODt80YvoPmSLM5wZJaGU4uHTnPP/d6egAdNW++WYI/4Ddb5gB
8Ze+o0MxiJbPcICFB9g/slD1ux0g7tPPcBBd5/6wKsXBYdXHS75JFlD/mzhA
3KOd4fAJKCxww95hEVgc6j5xBwenhKcXlIDu/QJ0/stj9g6PlwJD0ifDoV0M
aJMxgg9xnz3EP6kZDqdAFuyFyqdkOBwGBku/EDS+ijMcpkiwhPGttYf4uw5q
nrKDgxXIw93Q8ItxgLinAeGfY6DwbMlwAADQteMG
               "]]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.00017376208333333334`], Opacity[1.], CapForm[
              "Butt"], JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
               0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIFIGYCYn7dTXPfH3dwiNvlycPUn+FwfXGBLZe6owMX
iNGXARHXdnQozpj4tqY5w2H2EYUNRRWODkLNB04trMxwWOi67fPfLY4ON899
D37cmuEQYbnlRNk/RwcGEKjJcADKXqnY6egA0m5fmOFwUen2z7pTjg7vauxN
45IyHKT176qwKTo5qLI1TnVORvD7D33ViPHPcKh8qWbIccfR4Zi3eadjAMI8
2agU6/vOUPeyOzl804jpP2SKMB/sfq0MB5funOe/Ox0dgK7aN98M4R+w+w0z
HIpADtOH+k8+wwEWHmD/yELV73aAuE8/w0F0nfvDqhQHh1UfL/kmWUD9b+Lg
IANyj3aGwyegsMANe4dFYHGo+8QdHJwSnl5QArr3C9D5L4/ZOzxeCgxJnwyH
djGgTcYIPsR99hD/pGY4nAJZsNfe4QlIPiXD4TAwWPqFoPFVnOEwRYIljG+t
PcTfdVDzlB0cQNGwrxsafjEOEPc0IPxzHBSeLRkOAMzd4wM=
               "],
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{34.602000000000004`, 194.79299999999998`}, {
               34.602000000000004`, 194.406}, {34.234, 194.094}, {
               33.785000000000004`, 194.094}, {33.336, 194.094}, {32.973, 
               194.406}, {32.973, 194.79299999999998`}, {32.973, 195.176}, {
               33.336, 195.48800000000003`}, {33.785000000000004`, 
               195.48800000000003`}, {34.234, 195.48800000000003`}, {
               34.602000000000004`, 195.176}, {34.602000000000004`, 
               194.79299999999998`}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.00018712128065294733`], Opacity[1.], CapForm[
              "Butt"], JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{34.602000000000004`, 194.79308092799997`}, {
               34.602000000000004`, 194.40591648}, {34.234, 194.093901888}, {
               33.785000000000004`, 194.093901888}, {33.336, 194.093901888}, {
               32.973, 194.40591648}, {32.973, 194.79308092799997`}, {32.973, 
               195.175489056}, {33.336, 195.488454912}, {33.785000000000004`, 
               195.488454912}, {34.234, 195.488454912}, {34.602000000000004`, 
               195.175489056}, {34.602000000000004`, 194.79308092799997`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{28.723, 198.23399999999998`}, {
               27.531000000000002`, 197.176}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{28.723, 198.23399999999998`}, {
               27.531000000000002`, 197.176}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{29.516000000000002`, 
               198.23399999999998`}, {28.324, 197.176}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{29.516000000000002`, 
               198.23399999999998`}, {28.324, 197.176}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{30.309, 198.23399999999998`}, {
               29.117000000000004`, 197.176}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{30.309, 198.23399999999998`}, {
               29.117000000000004`, 197.176}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{31.102, 198.23399999999998`}, {
               29.91, 197.176}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{31.102, 198.23399999999998`}, {
               29.91, 197.176}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{31.895, 198.23399999999998`}, {
               30.703, 197.176}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{31.895, 198.23399999999998`}, {
               30.703, 197.176}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{32.688, 198.23399999999998`}, {
               31.496, 197.176}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{32.688, 198.23399999999998`}, {
               31.496, 197.176}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{33.48, 198.23399999999998`}, {
               32.289, 197.176}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{33.48, 198.23399999999998`}, {
               32.289, 197.176}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{34.273, 198.23399999999998`}, {
               33.086, 197.176}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{34.273, 198.23399999999998`}, {
               33.086, 197.176}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{35.066, 198.23399999999998`}, {
               33.879, 197.176}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{35.066, 198.23399999999998`}, {
               33.879, 197.176}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{35.858999999999995`, 
               198.23399999999998`}, {34.672000000000004`, 197.176}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{35.858999999999995`, 
               198.23399999999998`}, {34.672000000000004`, 197.176}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{36.652, 198.23399999999998`}, {
               35.465, 197.176}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{36.652, 198.23399999999998`}, {
               35.465, 197.176}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{37.445, 198.23399999999998`}, {
               36.258, 197.176}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{37.445, 198.23399999999998`}, {
               36.258, 197.176}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{34.273, 198.23399999999998`}, {
               33.086, 197.176}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{34.273, 198.23399999999998`}, {
               33.086, 197.176}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{38.23800000000001, 
               198.23399999999998`}, {37.050999999999995`, 197.176}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{38.23800000000001, 
               198.23399999999998`}, {37.050999999999995`, 197.176}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{39.031, 198.23399999999998`}, {
               37.843999999999994`, 197.176}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{39.031, 198.23399999999998`}, {
               37.843999999999994`, 197.176}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{39.828, 198.23399999999998`}, {
               38.637, 197.176}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{39.828, 198.23399999999998`}, {
               38.637, 197.176}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{40.621, 198.23399999999998`}, {
               39.43, 197.176}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{40.621, 198.23399999999998`}, {
               39.43, 197.176}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{39.43, 198.23399999999998`}, {
               40.621, 197.176}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{39.43, 198.23399999999998`}, {
               40.621, 197.176}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{38.637, 198.23399999999998`}, {
               39.828, 197.176}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{38.637, 198.23399999999998`}, {
               39.828, 197.176}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{37.843999999999994`, 
               198.23399999999998`}, {39.031, 197.176}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{37.843999999999994`, 
               198.23399999999998`}, {39.031, 197.176}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{37.050999999999995`, 
               198.23399999999998`}, {38.23800000000001, 197.176}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{37.050999999999995`, 
               198.23399999999998`}, {38.23800000000001, 197.176}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{36.258, 198.23399999999998`}, {
               37.445, 197.176}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{36.258, 198.23399999999998`}, {
               37.445, 197.176}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{35.465, 198.23399999999998`}, {
               36.652, 197.176}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{35.465, 198.23399999999998`}, {
               36.652, 197.176}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{34.672000000000004`, 
               198.23399999999998`}, {35.858999999999995`, 197.176}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{34.672000000000004`, 
               198.23399999999998`}, {35.858999999999995`, 197.176}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{33.879, 198.23399999999998`}, {
               35.066, 197.176}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{33.879, 198.23399999999998`}, {
               35.066, 197.176}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{33.086, 198.23399999999998`}, {
               34.273, 197.176}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{33.086, 198.23399999999998`}, {
               34.273, 197.176}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{32.289, 198.23399999999998`}, {
               33.48, 197.176}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{32.289, 198.23399999999998`}, {
               33.48, 197.176}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{31.496, 198.23399999999998`}, {
               32.688, 197.176}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{31.496, 198.23399999999998`}, {
               32.688, 197.176}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{30.703, 198.23399999999998`}, {
               31.895, 197.176}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{30.703, 198.23399999999998`}, {
               31.895, 197.176}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{33.879, 198.23399999999998`}, {
               35.066, 197.176}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{33.879, 198.23399999999998`}, {
               35.066, 197.176}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{29.91, 198.23399999999998`}, {
               31.102, 197.176}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{29.91, 198.23399999999998`}, {
               31.102, 197.176}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{29.117000000000004`, 
               198.23399999999998`}, {30.309, 197.176}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{29.117000000000004`, 
               198.23399999999998`}, {30.309, 197.176}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{28.324, 198.23399999999998`}, {
               29.516000000000002`, 197.176}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{28.324, 198.23399999999998`}, {
               29.516000000000002`, 197.176}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{27.531000000000002`, 
               198.23399999999998`}, {28.723, 197.176}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{27.531000000000002`, 
               198.23399999999998`}, {28.723, 197.176}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{28.723, 192.227}, {
               27.531000000000002`, 191.164}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{28.723, 192.227}, {
               27.531000000000002`, 191.164}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{29.516000000000002`, 
               192.227}, {28.324, 191.164}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{29.516000000000002`, 
               192.227}, {28.324, 191.164}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{30.309, 192.227}, {
               29.117000000000004`, 191.164}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{30.309, 192.227}, {
               29.117000000000004`, 191.164}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{31.102, 192.227}, {29.91, 
               191.164}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{31.102, 192.227}, {29.91, 
               191.164}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{31.895, 192.227}, {30.703, 
               191.164}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{31.895, 192.227}, {30.703, 
               191.164}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{32.688, 192.227}, {31.496, 
               191.164}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{32.688, 192.227}, {31.496, 
               191.164}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{33.48, 192.227}, {32.289, 
               191.164}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{33.48, 192.227}, {32.289, 
               191.164}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{34.273, 192.227}, {33.086, 
               191.164}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{34.273, 192.227}, {33.086, 
               191.164}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{35.066, 192.227}, {33.879, 
               191.164}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{35.066, 192.227}, {33.879, 
               191.164}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{35.858999999999995`, 
               192.227}, {34.672000000000004`, 191.164}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{35.858999999999995`, 
               192.227}, {34.672000000000004`, 191.164}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{36.652, 192.227}, {35.465, 
               191.164}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{36.652, 192.227}, {35.465, 
               191.164}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{37.445, 192.227}, {36.258, 
               191.164}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{37.445, 192.227}, {36.258, 
               191.164}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{34.273, 192.227}, {33.086, 
               191.164}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{34.273, 192.227}, {33.086, 
               191.164}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{38.23800000000001, 192.227}, {
               37.050999999999995`, 191.164}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{38.23800000000001, 192.227}, {
               37.050999999999995`, 191.164}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{39.031, 192.227}, {
               37.843999999999994`, 191.164}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{39.031, 192.227}, {
               37.843999999999994`, 191.164}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{39.828, 192.227}, {38.637, 
               191.164}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{39.828, 192.227}, {38.637, 
               191.164}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{40.621, 192.227}, {39.43, 
               191.164}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{40.621, 192.227}, {39.43, 
               191.164}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{39.43, 192.227}, {40.621, 
               191.164}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{39.43, 192.227}, {40.621, 
               191.164}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{38.637, 192.227}, {39.828, 
               191.164}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{38.637, 192.227}, {39.828, 
               191.164}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{37.843999999999994`, 
               192.227}, {39.031, 191.164}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{37.843999999999994`, 
               192.227}, {39.031, 191.164}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{37.050999999999995`, 
               192.227}, {38.23800000000001, 191.164}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{37.050999999999995`, 
               192.227}, {38.23800000000001, 191.164}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{36.258, 192.227}, {37.445, 
               191.164}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{36.258, 192.227}, {37.445, 
               191.164}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{35.465, 192.227}, {36.652, 
               191.164}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{35.465, 192.227}, {36.652, 
               191.164}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{34.672000000000004`, 
               192.227}, {35.858999999999995`, 191.164}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{34.672000000000004`, 
               192.227}, {35.858999999999995`, 191.164}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{33.879, 192.227}, {35.066, 
               191.164}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{33.879, 192.227}, {35.066, 
               191.164}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{33.086, 192.227}, {34.273, 
               191.164}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{33.086, 192.227}, {34.273, 
               191.164}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{32.289, 192.227}, {33.48, 
               191.164}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{32.289, 192.227}, {33.48, 
               191.164}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{31.496, 192.227}, {32.688, 
               191.164}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{31.496, 192.227}, {32.688, 
               191.164}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{30.703, 192.227}, {31.895, 
               191.164}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{30.703, 192.227}, {31.895, 
               191.164}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{33.879, 192.227}, {35.066, 
               191.164}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{33.879, 192.227}, {35.066, 
               191.164}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{29.91, 192.227}, {31.102, 
               191.164}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{29.91, 192.227}, {31.102, 
               191.164}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{29.117000000000004`, 
               192.227}, {30.309, 191.164}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{29.117000000000004`, 
               192.227}, {30.309, 191.164}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{28.324, 192.227}, {
               29.516000000000002`, 191.164}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{28.324, 192.227}, {
               29.516000000000002`, 191.164}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{27.531000000000002`, 
               192.227}, {28.723, 191.164}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{27.531000000000002`, 
               192.227}, {28.723, 191.164}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {0,
                1, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{92.371, 
               198.945}, {79.477, 198.945}, {78.766, 198.945}, {78.191, 
               198.406}, {78.191, 197.738}, {78.191, 191.664}, {78.191, 
               190.996}, {78.766, 190.45700000000002`}, {79.477, 
               190.45700000000002`}, {92.371, 190.45700000000002`}, {93.086, 
               190.45700000000002`}, {93.66, 190.996}, {93.66, 191.664}, {
               93.66, 197.738}, {93.66, 198.406}, {93.086, 198.945}, {92.371, 
               198.945}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002951354166666667], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {0,
                1, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{92.371, 
               198.945}, {79.477, 198.945}, {78.766, 198.945}, {78.191, 
               198.406}, {78.191, 197.738}, {78.191, 191.664}, {78.191, 
               190.996}, {78.766, 190.457}, {79.477, 190.457}, {92.371, 
               190.457}, {93.086, 190.457}, {93.66, 190.996}, {93.66, 
               191.664}, {93.66, 197.738}, {93.66, 198.406}, {93.086, 
               198.945}, {92.371, 198.945}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {0,
                1, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{92.043, 
               198.594}, {79.809, 198.594}, {79.133, 198.594}, {78.586, 
               198.098}, {78.586, 197.48800000000003`}, {78.586, 191.918}, {
               78.586, 191.305}, {79.133, 190.812}, {79.809, 190.812}, {
               92.043, 190.812}, {92.71900000000001, 190.812}, {93.262, 
               191.305}, {93.262, 191.918}, {93.262, 197.48800000000003`}, {
               93.262, 198.098}, {92.71900000000001, 198.594}, {92.043, 
               198.594}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752291666666667], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {0,
                1, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{92.043, 
               198.594}, {79.809, 198.594}, {79.133, 198.594}, {78.586, 
               198.098}, {78.586, 197.488}, {78.586, 191.918}, {78.586, 
               191.305}, {79.133, 190.812}, {79.809, 190.812}, {92.043, 
               190.812}, {92.71900000000001, 190.812}, {93.262, 191.305}, {
               93.262, 191.918}, {93.262, 197.488}, {93.262, 198.098}, {
               92.71900000000001, 198.594}, {92.043, 198.594}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
               0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIFIGYC4sqXaoYcc0Id4nZ58jD1ZziIrHN/WJUT6sB1
fXGBbV+Gw0Wl2z/rskIdijImvq1pznDYNPf98mPOoQ7CzQdOLazMcNC/q8LW
qBrqcPPc9+DHrRkOIY+Xzj7CEOrAAAI1GQ6qbI1TnZVDHUDa7QszHGbkCTUf
kAp1APJM45IyHIpBEu9DIOqSEfwJh75qxPhnOLh05zz/LRjqcNzbvNMxAGGe
bFSK9X3nDAdRkHv/hDh804jpP2SKMJ8b5H6tDIi/rEMdtpwo2zffDOEfsPsN
MxyOgczNCIXYK5/hAAsPsH9koeoXhULs1c+A2HM21GHVx0u+SRZQ/z+Fukc7
w8EZ5F7OMIdFrts+/zWBhueXUAenhKcXlIDuBVnryhfmAAomBZ8Mh3iQ+4wR
fHA4mYZB7EnNcOidDvSQAFQ+JcNBrvV14I5v0PgqznAA+WaPSBjEnXUZDntL
JkuwvAt1sAJ5uBsafhdDIe5pQPgH7O+WDAcAOIfkoA==
               "]]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.00017376208333333334`], Opacity[1.], CapForm[
              "Butt"], JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
               0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIFIGYC4sqXaoYcc0Id4nZ58jD1ZziIrHN/WJUT6sB1
fXGBbV+Gw0Wl2z/rskIdijMmvq1pznDYNPf98mPOoQ5CzQdOLazMcNC/q8LW
qBrqcPPc9+DHrRkOIY+Xzj7CEOrAAAI1GQ6qbI1TnZVDHUDa7QszHGbkAXVK
hTq8q7E3jUvKgJj7PgSiLhnB7z/0VSPGP8PBpTvn+W/BUIdj3uadjgEI82Sj
UqzvO2c4iILc+yfE4ZtGTP8hU4T5YPdrZUD8ZR3qsOVE2b75Zgj/gN1vmAEx
NwPqP/kMB1h4gP0jC1W/KBRir34GxJ6zoQ6rPl7yTbKA+v9pqIMMyD3aGQ7O
IPdyhjksct32+a8JNDy/hDo4JTy9oAR0L8haV74wB1AwKfhkOMSD3GeM4IPD
yTQMYk9qhkPvdKCHBMIcnoDkUzIc5FpfB+74Bo2v4gwHkG/2iIRB3FmX4bC3
ZLIEy7tQB0uQh7uh4XcxFOKeBoR/joP83ZLhAAA0r+Sd
               "],
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{85.398, 194.79299999999998`}, {85.398, 194.406}, {
               85.766, 194.094}, {86.215, 194.094}, {86.664, 194.094}, {
               87.027, 194.406}, {87.027, 194.79299999999998`}, {87.027, 
               195.176}, {86.664, 195.48800000000003`}, {86.215, 
               195.48800000000003`}, {85.766, 195.48800000000003`}, {85.398, 
               195.176}, {85.398, 194.79299999999998`}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.00018712128065294733`], Opacity[1.], CapForm[
              "Butt"], JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{85.398, 194.79308092799997`}, {85.398, 
               194.40591648}, {85.766, 194.093901888}, {86.215, 
               194.093901888}, {86.664, 194.093901888}, {87.027, 
               194.40591648}, {87.027, 194.79308092799997`}, {87.027, 
               195.175489056}, {86.664, 195.488454912}, {86.215, 
               195.488454912}, {85.766, 195.488454912}, {85.398, 
               195.175489056}, {85.398, 194.79308092799997`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{91.277, 198.23399999999998`}, {
               92.46900000000001, 197.176}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{91.277, 198.23399999999998`}, {
               92.46900000000001, 197.176}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{90.48400000000001, 
               198.23399999999998`}, {91.67599999999999, 197.176}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{90.48400000000001, 
               198.23399999999998`}, {91.67599999999999, 197.176}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{89.691, 198.23399999999998`}, {
               90.883, 197.176}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{89.691, 198.23399999999998`}, {
               90.883, 197.176}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{88.898, 198.23399999999998`}, {
               90.09, 197.176}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{88.898, 198.23399999999998`}, {
               90.09, 197.176}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{88.10499999999999, 
               198.23399999999998`}, {89.29700000000001, 197.176}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{88.10499999999999, 
               198.23399999999998`}, {89.29700000000001, 197.176}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{87.312, 198.23399999999998`}, {
               88.504, 197.176}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{87.312, 198.23399999999998`}, {
               88.504, 197.176}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{86.52, 198.23399999999998`}, {
               87.71100000000001, 197.176}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{86.52, 198.23399999999998`}, {
               87.71100000000001, 197.176}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{85.727, 198.23399999999998`}, {
               86.91400000000002, 197.176}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{85.727, 198.23399999999998`}, {
               86.91400000000002, 197.176}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{84.93400000000001, 
               198.23399999999998`}, {86.121, 197.176}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{84.93400000000001, 
               198.23399999999998`}, {86.121, 197.176}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{84.141, 198.23399999999998`}, {
               85.32799999999999, 197.176}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{84.141, 198.23399999999998`}, {
               85.32799999999999, 197.176}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{83.348, 198.23399999999998`}, {
               84.535, 197.176}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{83.348, 198.23399999999998`}, {
               84.535, 197.176}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{82.55499999999999, 
               198.23399999999998`}, {83.742, 197.176}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{82.55499999999999, 
               198.23399999999998`}, {83.742, 197.176}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{85.727, 198.23399999999998`}, {
               86.91400000000002, 197.176}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{85.727, 198.23399999999998`}, {
               86.91400000000002, 197.176}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{81.762, 198.23399999999998`}, {
               82.94900000000001, 197.176}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{81.762, 198.23399999999998`}, {
               82.94900000000001, 197.176}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{80.96900000000001, 
               198.23399999999998`}, {82.15599999999999, 197.176}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{80.96900000000001, 
               198.23399999999998`}, {82.15599999999999, 197.176}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{80.17199999999998, 
               198.23399999999998`}, {81.363, 197.176}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{80.17199999999998, 
               198.23399999999998`}, {81.363, 197.176}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{79.37899999999999, 
               198.23399999999998`}, {80.57, 197.176}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{79.37899999999999, 
               198.23399999999998`}, {80.57, 197.176}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{80.57, 198.23399999999998`}, {
               79.37899999999999, 197.176}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{80.57, 198.23399999999998`}, {
               79.37899999999999, 197.176}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{81.363, 198.23399999999998`}, {
               80.17199999999998, 197.176}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{81.363, 198.23399999999998`}, {
               80.17199999999998, 197.176}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{82.15599999999999, 
               198.23399999999998`}, {80.96900000000001, 197.176}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{82.15599999999999, 
               198.23399999999998`}, {80.96900000000001, 197.176}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{82.94900000000001, 
               198.23399999999998`}, {81.762, 197.176}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{82.94900000000001, 
               198.23399999999998`}, {81.762, 197.176}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{83.742, 198.23399999999998`}, {
               82.55499999999999, 197.176}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{83.742, 198.23399999999998`}, {
               82.55499999999999, 197.176}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{84.535, 198.23399999999998`}, {
               83.348, 197.176}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{84.535, 198.23399999999998`}, {
               83.348, 197.176}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{85.32799999999999, 
               198.23399999999998`}, {84.141, 197.176}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{85.32799999999999, 
               198.23399999999998`}, {84.141, 197.176}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{86.121, 198.23399999999998`}, {
               84.93400000000001, 197.176}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{86.121, 198.23399999999998`}, {
               84.93400000000001, 197.176}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{86.91400000000002, 
               198.23399999999998`}, {85.727, 197.176}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{86.91400000000002, 
               198.23399999999998`}, {85.727, 197.176}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{87.71100000000001, 
               198.23399999999998`}, {86.52, 197.176}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{87.71100000000001, 
               198.23399999999998`}, {86.52, 197.176}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{88.504, 198.23399999999998`}, {
               87.312, 197.176}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{88.504, 198.23399999999998`}, {
               87.312, 197.176}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{89.29700000000001, 
               198.23399999999998`}, {88.10499999999999, 197.176}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{89.29700000000001, 
               198.23399999999998`}, {88.10499999999999, 197.176}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{86.121, 198.23399999999998`}, {
               84.93400000000001, 197.176}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{86.121, 198.23399999999998`}, {
               84.93400000000001, 197.176}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{90.09, 198.23399999999998`}, {
               88.898, 197.176}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{90.09, 198.23399999999998`}, {
               88.898, 197.176}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{90.883, 198.23399999999998`}, {
               89.691, 197.176}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{90.883, 198.23399999999998`}, {
               89.691, 197.176}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{91.67599999999999, 
               198.23399999999998`}, {90.48400000000001, 197.176}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{91.67599999999999, 
               198.23399999999998`}, {90.48400000000001, 197.176}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{92.46900000000001, 
               198.23399999999998`}, {91.277, 197.176}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{92.46900000000001, 
               198.23399999999998`}, {91.277, 197.176}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{91.277, 192.227}, {
               92.46900000000001, 191.164}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{91.277, 192.227}, {
               92.46900000000001, 191.164}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{90.48400000000001, 192.227}, {
               91.67599999999999, 191.164}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{90.48400000000001, 192.227}, {
               91.67599999999999, 191.164}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{89.691, 192.227}, {90.883, 
               191.164}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{89.691, 192.227}, {90.883, 
               191.164}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{88.898, 192.227}, {90.09, 
               191.164}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{88.898, 192.227}, {90.09, 
               191.164}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{88.10499999999999, 192.227}, {
               89.29700000000001, 191.164}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{88.10499999999999, 192.227}, {
               89.29700000000001, 191.164}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{87.312, 192.227}, {88.504, 
               191.164}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{87.312, 192.227}, {88.504, 
               191.164}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{86.52, 192.227}, {
               87.71100000000001, 191.164}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{86.52, 192.227}, {
               87.71100000000001, 191.164}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{85.727, 192.227}, {
               86.91400000000002, 191.164}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{85.727, 192.227}, {
               86.91400000000002, 191.164}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{84.93400000000001, 192.227}, {
               86.121, 191.164}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{84.93400000000001, 192.227}, {
               86.121, 191.164}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{84.141, 192.227}, {
               85.32799999999999, 191.164}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{84.141, 192.227}, {
               85.32799999999999, 191.164}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{83.348, 192.227}, {84.535, 
               191.164}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{83.348, 192.227}, {84.535, 
               191.164}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{82.55499999999999, 192.227}, {
               83.742, 191.164}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{82.55499999999999, 192.227}, {
               83.742, 191.164}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{85.727, 192.227}, {
               86.91400000000002, 191.164}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{85.727, 192.227}, {
               86.91400000000002, 191.164}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{81.762, 192.227}, {
               82.94900000000001, 191.164}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{81.762, 192.227}, {
               82.94900000000001, 191.164}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{80.96900000000001, 192.227}, {
               82.15599999999999, 191.164}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{80.96900000000001, 192.227}, {
               82.15599999999999, 191.164}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{80.17199999999998, 192.227}, {
               81.363, 191.164}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{80.17199999999998, 192.227}, {
               81.363, 191.164}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{79.37899999999999, 192.227}, {
               80.57, 191.164}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{79.37899999999999, 192.227}, {
               80.57, 191.164}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{80.57, 192.227}, {
               79.37899999999999, 191.164}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{80.57, 192.227}, {
               79.37899999999999, 191.164}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{81.363, 192.227}, {
               80.17199999999998, 191.164}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{81.363, 192.227}, {
               80.17199999999998, 191.164}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{82.15599999999999, 192.227}, {
               80.96900000000001, 191.164}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{82.15599999999999, 192.227}, {
               80.96900000000001, 191.164}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{82.94900000000001, 192.227}, {
               81.762, 191.164}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{82.94900000000001, 192.227}, {
               81.762, 191.164}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{83.742, 192.227}, {
               82.55499999999999, 191.164}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{83.742, 192.227}, {
               82.55499999999999, 191.164}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{84.535, 192.227}, {83.348, 
               191.164}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{84.535, 192.227}, {83.348, 
               191.164}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{85.32799999999999, 192.227}, {
               84.141, 191.164}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{85.32799999999999, 192.227}, {
               84.141, 191.164}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{86.121, 192.227}, {
               84.93400000000001, 191.164}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{86.121, 192.227}, {
               84.93400000000001, 191.164}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{86.91400000000002, 192.227}, {
               85.727, 191.164}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{86.91400000000002, 192.227}, {
               85.727, 191.164}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{87.71100000000001, 192.227}, {
               86.52, 191.164}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{87.71100000000001, 192.227}, {
               86.52, 191.164}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{88.504, 192.227}, {87.312, 
               191.164}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{88.504, 192.227}, {87.312, 
               191.164}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{89.29700000000001, 192.227}, {
               88.10499999999999, 191.164}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{89.29700000000001, 192.227}, {
               88.10499999999999, 191.164}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{86.121, 192.227}, {
               84.93400000000001, 191.164}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{86.121, 192.227}, {
               84.93400000000001, 191.164}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{90.09, 192.227}, {88.898, 
               191.164}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{90.09, 192.227}, {88.898, 
               191.164}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{90.883, 192.227}, {89.691, 
               191.164}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{90.883, 192.227}, {89.691, 
               191.164}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{91.67599999999999, 192.227}, {
               90.48400000000001, 191.164}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{91.67599999999999, 192.227}, {
               90.48400000000001, 191.164}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{92.46900000000001, 192.227}, {
               91.277, 191.164}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{92.46900000000001, 192.227}, {
               91.277, 191.164}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{50.605000000000004`, 181.15200000000002`}, {31.359, 
               162.33200000000002`}, {23.148, 159.953}, {27., 
               158.43800000000002`}, {30.855, 156.92200000000003`}, {43.246, 
               166.63299999999998`}, {56.145, 179.535}, {69.039, 
               192.43800000000002`}, {76.938, 203.918}, {73.086, 205.434}, {
               69.23, 206.953}, {71.07, 201.172}, {50.605000000000004`, 
               181.15200000000002`}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0004413333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{50.605000000000004`, 181.152}, {31.359, 162.332}, {
               23.148, 159.95299999999997`}, {27., 158.438}, {30.855, 
               156.92200000000003`}, {43.246, 166.63299999999998`}, {56.145, 
               179.535}, {69.039, 192.438}, {76.938, 203.918}, {73.086, 
               205.434}, {69.23, 206.953}, {71.07, 201.172}, {
               50.605000000000004`, 181.152}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}}}, {{{34.402, 
               167.477}, {41.145, 165.707}, {34.800999999999995`, 159.695}, {
               27.66, 157.21899999999997`}, {25.68, 158.281}, {23.695, 
               159.34}, {29.246, 161.816}, {34.402, 167.477}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}}}, {{{34.402, 
               167.477}, {41.145, 165.707}, {34.800999999999995`, 159.695}, {
               27.66, 157.219}, {25.68, 158.281}, {23.695, 159.34}, {29.246, 
               161.816}, {34.402, 167.477}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}}}, {{{34.402, 
               166.76999999999998`}, {39.956999999999994`, 
               165.35200000000003`}, {33.773, 159.57}, {27.66, 157.93}, {
               26.078, 158.63299999999998`}, {24.487999999999996`, 159.34}, {
               29.379, 161.32800000000003`}, {34.402, 
               166.76999999999998`}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}}}, {{{34.402, 
               166.76999999999998`}, {39.956999999999994`, 165.352}, {33.773, 
               159.57}, {27.66, 157.93}, {26.078, 158.63299999999998`}, {
               24.487999999999996`, 159.34}, {29.379, 161.32800000000003`}, {
               34.402, 166.76999999999998`}}},
               CurveClosed->{1}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJ5IGYC4qcXlG7/7PN2UGVrnOq8P81higRLGF+vt8Nx
b/NOxz1pDtcXF9hytXs79B/6qhGzPs3BNG6XJ0+TtwMXSGIVgu+UADRpcZrD
M5B5dd4O3zRi+g/NTXOofKlmyFHj7fB46ewjCjPSHH7VZe0pKYbaNznNYaHr
ts9/S7wdZuQJNR/og6qP8XbYN19K/25PmsObwB1yrd7eDiBrmNrTHHqnAxU6
eDvo31Vha2xNc3Dpznn+WxNqf3Oaw0WQ9VJQ+xrSHHKf/175kcnbofU10KBa
qPwrL4h9VWkOK44BPXrRy2HVx0u+SRVpDmDn7/KC6K+A+meel4MPMDgSKtMc
5hxR2FDU4eUAVJW1pybNQRPoza8VXg4gYxyB9gFdqd2e5gV3jxnI4UleDkUZ
E9/WAN1/GuThWC8HdUOONTJA/27//PdKRaSXw7sae9O4SVD/JXg57CmZLMEC
lDcA+TMV6t42hPlg9wLtaxe7ee57MsJ9MPPA8VOW5mAHYvh6OSwChXNBmgMA
EdfgEA==
               "],
               CurveClosed->{0}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJNIGYCYoO7KmyNS70chJoPnFqYmObwqy5rT8liLweX
7pznv4H8lce8zTsXejlcVLr9sy4pzeHZBSBjnpeDU8LTC0rJaQ6nFrpu+7zW
y8Fyy4myffFpDny6m+a+X+7lkDHxbY09UL8+yPxWL4dvGjH9h1LTHGy5ri8u
yPVyKAAxMqD2BXs5qBtyrJHJgvKNvRz6D33ViMlOc3gTuEOu9bYnnL/t898r
FTsR/MNAqn+RpwPIWNssqHynJ9z8T5d8kwQqPB0KQfyUNIcpEixhfLGeDu9q
7E3jgP6J2+XJw+Tt6VAtss79YVyaQ4r1ff9ec08HmSggKzrN4SnIv3qeDr3T
84SaI9IcFgG9+1fF08EK5N9gqHuFPR1kQer90xz4Qf5n94SEn2eaw+wjChuK
fnhA7HFPc1gOCs+PHhD3OKQ55D7/vfLjIw+HffOl9O8C+VrAYPp6wwNiv3Wa
A8hbXN89IP61hrqHzxMSH1ZpDqdB4S8L9Y9ZmoMmSL8FNHyMEe7xMe90TLCE
xt8/hPlgd770gMSXLdR/TzwcZgC9e8AuzWFPyWQJlmMIPjh8V3o4AG3P2uMA
Dd8ZHhB9NmkOIOPrqhDmg9VnekDiH2i/KDCYq1I8HFpfAyMWyI8AJRw/BB8A
wZYvwA==
               "],
               CurveClosed->{0}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJVIGYCYmn9uypsgZ4OlltOlO2TTnNoF7t57ruzp0MY
n+6muUC+Zkz/oa8cng4ZE9/W2EumOZjG7fLk+eQBVz/niMKGohseEHlZqPoT
Hg6rPl7yTVJIc9j2+e+Vip0eDkLNB04tVE1zWH7M27xzo4eDj3mnY4ImQr5a
ZJ37QzkE/12NvWmcVJrD9cUFtlzbPRzUDTnWyAilObwO3CHXutrDwaU75/lv
wTQIPRNqH0+aQ4r1ff/edg8HoC+CH3NC/VMM1c+W5rASZH+ih8OTpbOPKLCk
OawA8QM9HBa5Am1mSHM4tRDIsPVwAHmT6X+qw2yQ/zSg8n9SHQyAwdUo6uHg
lPD0gtLvVIdnF5Ru//zn7tAKctjPVIciUEC8d4fY9y3V4SJQuu6Wu0MVyH+f
Uh3YG6c6d99xd5iRBwyRd6kOfdOBjAvukPB5mepw+KtGTP8ldweQ8IFHqRD/
XHeHhM+9VEj4vHSH2HM71aEXpPADVP5aKsQ/jB4OaiD7L6U6FIPU8UP9cz7V
IRIUcXIeDsBQvb74RKoDAwgYQOPnaCokPjk8HGSjgDYfTnXIff575cdP7g7f
gM46dBDqnudQ+w8j3A9TDwDzNBH1
               "],
               CurveClosed->{0}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIpIGYC4l91WXtKDrs7qBtyrJHZlerQLnbz3PfN7g7V
IuvcHwL5kyVYwvhq3R3idnnyMO1PdVjkuu3z3xR3CH0g1WEKSJ4Xwb+odPtn
3Ss3h97peULNB6DmPXZz4Lq+uMB2X6oDiOI67uZQlDHxbc3uVAeQNVVb3BxU
2RqnOm9PdeDT3TT3/XI3h1UfL/kmbUl1iLDccqKsz80BaNiphRtTHaT176qw
Nbo5AE0Nfrw21QHoKu32NKj+5akOlS/VDDlioPYtSnUQBZkfAtU/N9WhGGSv
v5uDU8LTC0rTEfzHS2cfUZiQ6gAKG4YAKL8j1WH7579XKiLdHICu2De/DWH+
hENfNWLqUx3A4Zfs5gB2ViXUvXluDiBjGEpSHUxBAdfk5jADFBx5UPe0uDns
my+lfzcH6v42qH9zEP6VjUqxvp+d6gAAl/y3aw==
               "],
               CurveClosed->{0}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752354166666667], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 
               3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, CompressedData["
1:eJxVU2lIVUEUfmqYiFlIRYU/TErFFn1Zlpr1lTO3LMVKEgspE0+JmVsSFSJI
gYhoRYZChKhECyEhYRBPkQjbKEwMWwgJNQsSM8EWM5p5c56XfgzcM+dw5tvu
8pyifeTjcDi81IE63uoMtBYn+jdYCDrX/az5AGFR246PZ+vtOjPu3pNTdRZc
ZZeXzMkgtMiOyZnzFg49SA7wTicsi/qwwrfEwtuXP9KHUnm+0EK0uq5U9cm8
S2PlaXb9uyLfVRZjYSoi68JDVe8K8F5VFWth6PrVRyF7CCdGp29NhFp4o/ft
JdyfnOk/vdRCysbqbdn7Cc+bFYB5Fnp2q4tM3udjoatJIcki+FZeSar5IxGv
YHQdJnRq3FPSzOcSNIvAMYnGQsXwKPMZlgh3+t0Jzie8Cn3/q+KdRF2DGigg
bNBE+yQyAte0XysidGg8TyVqdb+YkKzx90iDr4Rw5kuY088lDT9Vu3m/llBb
811qPjdhMK12QELDayokKNZ3Sz9LrNTAj5O2xeH4Jo0eedz/KQ0/hf9TrwL4
V0LLuvUI4aYm5mUZvFm8fy7rkWnXHr/+66fYtUrBQOtOe7+bbxKharFydpLx
g/X9Kk0etrC/g6x3AuvZz3rEEearNeOPeT6W+XVLbM8e6Q2NYX3bmV80QT87
foP7UYTvfak5Cxolbk+oj9UEUVMwOl0t0ad9imS9y9mPCII7z8ckgg8qZuGE
uRpvit1351tI+OvBSM6v097vnguRKNW8ojiPQczHyXr4SAxrf9Z7/BEmP7Ee
fbiO9+RLGH6bCfU6fy8EtMwVSj8te3GnMP9PImFEN9qEyWc8v98ijP6bPHqI
WT31v+y4KGb1dOtdJRCm31/HeMrFLJ+Fmn+ZMPlbS/gHDmu4cA==
               "],
               CurveClosed->{0}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752354166666667], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 
               1, 0}}}, CompressedData["
1:eJxFUltIlEEU/t1i28JCwkRCukhaaiE+SFSYX81EdCMqkIJlEzkDRTeziK0k
sDCrZdWIqKiIsh6KiAqpEJHYpEJBTMLoIiVma7lrubZa2EIz/wz+A+fh48zM
dzlnftmBrWKSZVlJsvJluWTxwN7w+F0OS53FArPzexa4H3FkuasusjwBX9O6
ZFc7x+X9M089zxZYn+zKq+nmqB7c8mxOlsDKae8ayns46kPxRd65AjneulB8
gOPrnaut8zIE1DeBCEfz4Qvpk9MEXshrdTHDlyJQqAgkVrRVUx18SfG5BPzf
sws88n3JjCWPr48TgqrxhaMz8+PfE6M0oaflhlT+izDrwdreY60c7zvGtvVF
CUfV+2aO5Y2vj7QMmv5tjvIiKXyAsH2ZbNSafpggVT+s8HOsLu3vzAyb914H
23ls4BiVNkL9BDu/HJOHxLnKf7pz39ZrcfSpPCRf2801T0aiDF1K/w/z/yeG
g0pPhEArPm8OvmLa70/SPpsYVMxFMUJNmnTWwHBLfpP4TXg6knjrv2LwH8I1
pf8MQ63i/UeIdW0qS/EzbFx6dlVpktB6dzM9D7fAoV3no5U7mc7DY+ZbwrS/
6QI7VD4+pvOZYvZhD5uYjz2vCqb9JwjfbMFM78MYaZ7TDIqmOO7oW1jguZ8x
RFC7aNUz3BuWQmU+7SqfoNHb6+DjqXJwHwgRSVMdYBiqLC70dRPeKLpzxk8H
YZ/c5uGTpt/mYJvvJeE/RYpP9g==
               "],
               CurveClosed->{0}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 
               3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
               1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 
               3, 3}}}, CompressedData["
1:eJxdVHtoTmEc/nxmtJbksuQWso1iNrlkvvN9zznuNmS0ZmPW/NyHz8h1PsaW
2zbGhkJjYrls5pJcRnJLQojELBZCriMkrbzv+f22E3+cTr/z/t7n97zP87yn
W/rChBlNXS5XE/Wkq8etnvlv/xypyzRxM27QJrOS0FCHPDnoNyqcOrFln1P7
ThMGpF4YHarqyyUd+tao/hXvI2JaZEn/YULz7OKhW/JM9K3pEZx9gNC2YmTt
yjOCv58Qrb8/lv5SwrUfPads/WYic3bhp6wyQplurJN5xwiXluxoHxRhNfLZ
e71rZWaSxTjlhOV6foaFyJgWxzsdlfWNViOfYVsy1AksPOhe/Tug5p39Xv9o
+XkLfkN1KD5aC9d9C0frHo5N303Qx3NXW8y/kHBE86m1+Lx5hNsHhp/9fsnC
5yzfgNTNhIF6Q6mFp/d+TXyVS+hob7T4POsJHyec65KbInzWiX79nLqd1qet
02+vuwU/IHq9MRF75tbSy8sIelvIWxOdk2nIi8VOnb9rQev1swleDVwj/pD4
89xkvGRHf7tOJARrv6oEb6Kcr1zWE4RfjlPb9FaZrF8S8Vy/8Jsues+R/rmS
n3TJwyLpTxO/VxHe3FfGjDNZ/7WEpMEKyGvip4rFVaVnL/X60dOEhi9Rehfo
/a0Ev4AYt5n0Fwr+V2CR5ldE7PszsN47Cfqzv17q7ZI/t4kqnTOFp1QYn99c
+OQQ9ug8vQPrqfjpuLheApp2INCgFxr94vsAhGth10i/H6xLNqGofVBiy6lg
/I2i12Rnv52XOIjOws8SvpmCFw2+TxkEfU2+RILzP1P8bSf8UiUPnYHnvwNz
qyaJvlEyf5LopfDs9yjh7wH7C/F7CKDt8g0mbAjTSQf70J+wWC9MA+IVnbQY
4TMLqNbzohvug+BHy/nHOrXtv+Jj+xcj/49Q4T+QME8b89rH54sl7ByqBLvo
w261/YpX9NvkY/0s4Rvn43yNJBTr/j9e1ite8njKy/jjRM80p879oAwI9/L+
8bLu8uKhXh8j/O8aPG+EzDtmcL9P9Nlh/Ms/x8DrQypJvSUvqw3WM5z4v3HI
4Hx3kfk3DD5fmPhxx+D72ea//hDCCXuw4AeJnl4D29StmdJU9K/1sJ8uwknd
v9eDUkWj3iV6pnig7bjiJti/oygP3x+F9xdVCpwI
               "],
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{72.562, 198.137}, {
               81.10499999999999, 212.879}, {86.773, 225.42600000000002`}, {
               85.21100000000001, 226.141}, {83.65599999999999, 226.859}, {
               75.465, 215.477}, {66.926, 200.73399999999998`}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.00034917708333333334`], Opacity[1.], CapForm[
              "Butt"], JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{72.562, 198.137}, {
               81.10499999999999, 212.879}, {86.773, 225.426}, {
               85.21100000000001, 226.141}, {83.65599999999999, 226.859}, {
               75.465, 215.477}, {66.926, 200.73399999999998`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{72., 198.395}, {
               80.23400000000001, 212.617}, {85.91000000000001, 224.625}, {
               84.66799999999999, 225.19899999999998`}, {83.426, 
               225.77299999999997`}, {75.727, 214.695}, {67.488, 200.477}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.00030675208333333343`], Opacity[1.], CapForm[
              "Butt"], JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{72., 
               198.39499999999998`}, {80.23400000000001, 212.617}, {
               85.91000000000001, 224.625}, {84.66799999999999, 225.199}, {
               83.426, 225.773}, {75.727, 214.695}, {67.488, 200.477}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{70.586, 
               205.816}, {69.57799999999999, 204.15200000000002`}, {68.52, 
               202.254}, {67.488, 200.477}, {72., 198.395}, {73.027, 
               200.176}, {74.15199999999999, 202.047}, {75.09400000000001, 
               203.738}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0003481479166666667], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{70.586, 
               205.816}, {69.57799999999999, 204.152}, {68.52, 202.254}, {
               67.488, 200.477}, {72., 198.39499999999998`}, {73.027, 
               200.176}, {74.15199999999999, 202.047}, {75.09400000000001, 
               203.738}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{70.965, 
               205.242}, {69.965, 203.578}, {69.266, 202.309}, {
               68.23400000000001, 200.52700000000002`}, {71.617, 
               198.97299999999998`}, {72.648, 200.75}, {73.406, 
               201.99200000000002`}, {74.348, 203.684}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0003481479166666667], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{70.965, 
               205.242}, {69.965, 203.578}, {69.266, 202.309}, {
               68.23400000000001, 200.527}, {71.617, 198.973}, {72.648, 
               200.75}, {73.406, 201.992}, {74.348, 203.684}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{73.418, 
               203.316}, {71.164, 204.35500000000002`}, {69.16, 
               200.89800000000002`}, {71.41400000000002, 199.859}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002769611943733424], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               73.417948599, 203.315917393}, {71.16350044599997, 
               204.35527949000002`}, {69.15984768300001, 200.898620309}, {
               71.414295836, 199.859258212}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{73.422, 203.316}, {69.164, 
               200.89800000000002`}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0003481479166666667], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{73.422, 203.316}, {69.164, 
               200.898}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{71.41400000000002, 199.859}, {
               71.164, 204.35500000000002`}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0003481479166666667], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{71.41400000000002, 199.859}, {
               71.164, 204.355}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{83.613, 220.91}, {
               81.35499999999999, 221.94899999999998`}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0003481479166666667], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{83.613, 220.91}, {
               81.35499999999999, 221.949}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[
              0.8588240000000001, 0.08627450000000002, 0.105882], Opacity[
              1.]}], FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{82.836, 222.934}, {82.91400000000002, 222.625}, {
               83.262, 222.44899999999998`}, {83.613, 222.539}, {83.965, 
               222.625}, {84.18799999999999, 222.94899999999998`}, {
               84.10499999999999, 223.258}, {84.027, 223.562}, {
               83.67999999999999, 223.742}, {83.32799999999999, 
               223.65200000000002`}, {82.977, 223.566}, {82.754, 223.242}, {
               82.836, 222.934}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0004373646025411586], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{82.83573959999997, 222.933795676}, {82.91418599999999,
                222.62476281}, {83.26183340000001, 222.448992254}, {
               83.61338199999999, 222.53949645}, {83.96505909999999, 
               222.62536242599998`}, {84.18728319999998, 
               222.94948530200003`}, {84.1058368, 223.25776177800003`}, {
               84.0275189, 223.56215642400002`}, {83.67974299999999, 
               223.7425652}, {83.32819439999999, 223.65206100400002`}, {
               82.97651729999998, 223.566195028}, {82.7542932, 
               223.24207215200002`}, {82.83573959999997, 222.933795676}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{69.395, 181.15200000000002`}, {88.641, 
               162.33200000000002`}, {96.85199999999999, 159.953}, {93., 
               158.43800000000002`}, {89.145, 156.92200000000003`}, {76.754, 
               166.63299999999998`}, {63.855, 179.535}, {50.961, 
               192.43800000000002`}, {43.062000000000005`, 203.918}, {
               46.913999999999994`, 205.434}, {50.77, 206.953}, {48.93, 
               201.172}, {69.395, 181.15200000000002`}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0004413333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{69.395, 181.152}, {88.641, 162.332}, {
               96.85199999999999, 159.95299999999997`}, {93., 158.438}, {
               89.145, 156.92200000000003`}, {76.754, 166.63299999999998`}, {
               63.855, 179.535}, {50.961, 192.438}, {43.062000000000005`, 
               203.918}, {46.913999999999994`, 205.434}, {50.77, 206.953}, {
               48.93, 201.172}, {69.395, 181.152}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}}}, {{{85.598, 
               167.477}, {78.85499999999999, 165.707}, {85.199, 159.695}, {
               92.34, 157.21899999999997`}, {94.32, 158.281}, {
               96.30499999999999, 159.34}, {90.754, 161.816}, {85.598, 
               167.477}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}}}, {{{85.598, 
               167.477}, {78.85499999999999, 165.707}, {85.199, 159.695}, {
               92.34, 157.219}, {94.32, 158.281}, {96.30499999999999, 
               159.34}, {90.754, 161.816}, {85.598, 167.477}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}}}, {{{85.598, 
               166.76999999999998`}, {80.043, 165.35200000000003`}, {86.227, 
               159.57}, {92.34, 157.93}, {93.922, 158.63299999999998`}, {
               95.512, 159.34}, {90.621, 161.32800000000003`}, {85.598, 
               166.76999999999998`}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}}}, {{{85.598, 
               166.76999999999998`}, {80.043, 165.352}, {86.227, 159.57}, {
               92.34, 157.93}, {93.922, 158.63299999999998`}, {95.512, 
               159.34}, {90.621, 161.32800000000003`}, {85.598, 
               166.76999999999998`}}},
               CurveClosed->{1}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJ5IGYC4t7peULNFgEOqmyNU533pzls+/z3SoVlgMNx
b/NOxz1pDqLr3B9W2QQ49B/6qhGzPs3h2QWl2z/tAhy4ri8usF2F4DslPL2g
tDjNAWyeQ4DDN42Y/kNz0xxcunOe/3YMcHi8dPYRhRlpDs0HTi10dYPaNznN
Qf+uCluja4DDDKC2A31Q9YEBDvvmS+nf7Ulz4AbZExXgELfLk4epPc3BasuJ
sn3xARB9rWkOsSDxbKj9zWkQc4qg9jWkOXjxMGm31wU4tL4O3CFXm+YAct6B
Lqh9VWkOa2SiUqynBzis+njJN6kCqn8RVH8F1D8bAhx8gMGRUJnmsHnu++XH
dgc43P5Zl7WnJs0BZGzr4QCHY6DwAtoHFj+DcA84fM4FOBRlTHxbA3S/NMjh
FwMc1A051sgA/QsOh8sBDu9q7E3jJkH9dz7AYU/JZAkWoHwmUJv9Wah72xDm
g90LtG8vSN05hPtg5oHjpyzN4WGVyDr3mwEOi1yBMVuQ5gAAXi7g/Q==
               "],
               CurveClosed->{0}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJNIGYC4syJb2vs1wY4CDUfOLUwMc0BRLmuC3Bw6c55
/hvIXyMTlWK9PsDhotLtn3VJaQ690/OEmjcEODglPL2glJzmIK1/V4VtZYCD
5ZYTZfvi0xwqXqoZcqwJcMgAmQvUDzZ/b4DDN42Y/kOpaQ4Pq0TWuZ8McCiw
5bq+OANq37UAB3WgLpksKP9ZgEP/oa8aMdlpDkBVBbZCgXC+KlvjVGdlBF++
9XXgDr1AiLosqLx1INz8drGb5747BzoUgvgpaQ7bPv+9UhEY6PCuxt40Duif
SyB/RQU6VAOd9TAuzcEvSSDCMiXQAeTt+9FQ/2YEQuiINAcDoHcbcwMdrED+
DYa6tyzQQRak3j/NoRLk/5pASPh5pjlsmvt++bHmQIe4XZ48TO7Q8GyHusch
zcGLh0m7vS/QYd98Kf27QD7QN3Ktk6H2W6c5gJxV1QL1rzXUPRWBkPiwgoZ/
IdQ/ZlD9yVD1xgj3+Jh3OiZYQvU3IMyPBbmrOxASX7ZQ//UGOswAKjtgl+aw
yBUYYnMQfBVQ+K4OdADanrXHARq+mwMh6mzSIOoOIcwHqz8dCIl/oP1g+myg
Ayja5ID8kMdLZx+5geADAA+pGxs=
               "],
               CurveClosed->{0}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJVIGYC4uKMiW9rwgMdLLecKNsnneawt2SyBEtcoEMY
n+6muUD+m8Adcq3VgQ4gZfaSaQ5PLyjd/tmGUL9p7vvlxyZD5WWh6mcHOqz6
eMk3SSHNQZWtcarz4kAHoeYDpxaqpjmskYlKsV4e6OBj3umYoImQrxZZ5/5Q
DsF/V2NvGieV5gASrloS6KBuyLFGRijNgev64gLbVYEOLt05z38LpjnE7/Lk
YdoMtY8nzcE/SSDCck+gw81z34Mfc0L9cwyqnw1q//lAhydLZx9RYIHyrwc6
LHLd9vkvQ5qDtP5dFbaHgQ5xIHP/p0L89xoq/ycV4s+vgQ5OCcCQ+J3q0Ds9
T6iZIcih9TXQ4z9THY55Az3GEQSx71uqwwyg9AGhIIcqkEc+pTrUAr21SzAI
Iv4uFRKO4kGQ8HmZ6iAHMkgsyAFk7IFHqQ5+IP+IBEHC516qgwoofLiDHIpA
DrkN1c8Olb+WCvHP/0AHNZD9l6Du+QH1z/lUh5DHQI9/CHQosAWG5IlUh/8g
8BwaP0dTHTaD/Ps70EEWaMz9w6kOQF3a7WxBDt80YvoPHYS6hwdq/2GE+2Hq
AZ/jAt4=
               "],
               CurveClosed->{0}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIpIGYC4uYDpxa6ygU5qBtyrJHZleqwt2SyBItakEO1
yDr3h0D+ts9/r1Q4BjnE7fLkYdqf6mBwV4Wt0TfIYZErUOYAVL4SwZ+eJ9R8
oCvIoRfMgJrXF+TAdX1xge2+VAdRoLFVc4IcijImvq3ZnerwTSOm/9DSIAdV
tsapzttTHSpeqgFdEuSw6uMl36QtqQ4hj5fOPrIjyEEI5NCNqQ7FIH37gxxu
nvse/HhtqsPtn3VZe85A9S9PdXDpznn++yLUvkVQ869C9c9NdTjmbd7peCPI
wSnh6QWl6Qg+yBqFCakO/0HgOpTfkQox93KQw5YTZfvmtyHMn3Doq0ZMfaoD
OPzOBTnog8KlEureE0EODCBQkurw7ILS7Z/7ghxmgIIjD+qevUEO++ZL6d/N
SXW4A3L/Hqh/cxD+lY1Ksb6fneoAABBoy4o=
               "],
               CurveClosed->{0}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752354166666667], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 
               3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, CompressedData["
1:eJxVk1tIVVEQho8XzMpCRCXyPGiUillHsyyPmb+ZlKVd9pRomNnBKTFRuyAm
dkB8EAmLiKgIEYkoQnwwuyAqFaXSQ4QEGSYhWtFDRQiFdLG19prYdGDBmT2z
Z83/zb/jfLUWB7lcrgB1oE6gOpE926ca+yxEtDx63lXC+J5YeuHJPSfeP33z
+tOHFgZOX1oWXMRImVwZ0jxooaw/PyyQGKcqL35uGrHw5sUPmi6U+lHL1Kl4
eNfGtpxxJ9Zt8z5Y5h4VT8z5qwZmLOjXYvcydoYFrm79YmFc99vHWBXSfDl3
1kKBalN+gBHjUY3mLNO3WPr9sTDUudwzWco4m72hrD+A4O0brR86zOjKuz/7
O5hMfQVDRa8aFhKu1iiFR0XPEkJCami3u4rN8wjC+SvqTzXj/csVE3PRhKKl
a3o7amWeGEK7ztcx3ur53WTmO8HYdq764884MvpUrPFkR5HRqep3+8KLMyIJ
erzOGkZvx9dbw4vJ9D3OmNe/BWR4VEo+iIw+Nb99r4tM3yOMbvfBisx5y8yr
9O/R/X8Jj2In/rev//IFTlyXtej1jR1Of1tvLmNQ7z1E5gejSfNV/Gw/bGGM
aK7hwjuTodfTHCU8MhhnPsWnhrqlPp217VyuWMLWckU2TfjGi74URoOuT5a8
h9EarZyVRrjzbazQl8xGRyZhTL3mTxLeObKPRIbt5wKCxvIuQfxQ4uTtvRwi
KLV1WUni32NOf1tHLeGkfq7uz9d+rBc9qcLDT5jR+1kv+2kR/6QLnzaJveKv
dtG3Wfx3jaBl+xW/qUY1cReZ7ydL+N8Wf3rle+gR/puEx12Hp+2XBw5Pm/cA
IV7fv070P3b02Pqfif/WMv4C+lG0GA==
               "],
               CurveClosed->{0}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752354166666667], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 
               1, 0}}}, CompressedData["
1:eJxFUl1IlEEUXbfYNC0sQqIWM8kSrJaIEDfNU9sPaZE5Q/RgIcsdiIgyih5K
BBEVkTKpKIolKkLo78EiRExCw6IHSR+KDB8Wk402tTK1MLG530x+A/Nw5sy9
99xz7+rwqVI1z+PxJOgb0Ner75H2vSnehwIePusVzhxrHqlsEcjyVV8L5Sj0
Z376U3VT4MbJpTUv1ypodLzjqkBt/GBbepZC9PyyJ3uaBS53TWSXrVLg59pG
gc/3b73K8CtUFm452t4g0HH2yvL5aQrpHFhn66UqDL/TBTQODK7xVSe5+DrX
8yqEGk/EpnX8ocUbWiPThOCzN+c6mwT4W9UkzenpvL0iMPidMJld1tQVEfjY
OyWGRgg7Of6OMHFxyz8WqChY+OHeF4Ic0kLbLB8jtEbGWnq6BXaUayUxG9/n
YsePAWHyDBMc/+LWD42d/sfd/07eWQEuk6HrreRGk6TJ89XmXyJxmvV8IxwI
px7O80vT7xgZ3zMlNFtR8JPwgn3cKHF31/PxmV9k5rTZ4t+Ep6x/q8QlNvAv
oT5NOxGS2JfbsL08QRm9xdLMw6fwulgTJdL4kWjnK6Xpb5Ey/mje6WOBQh/r
LpJz83HmtVua/mcIF5mANPswRUZXvgSvVeGEq2/dpsRH/lHCLJ9ciQc/+veH
//uTZ/VGXXxBr1l0gJDMPgQlRnmx3lt/grafXkJRijenfpvl37rYqddD+AcX
9FjD
               "],
               CurveClosed->{0}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 
               3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
               1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 
               3, 3}}}, CompressedData["
1:eJxdVAtMjlEY/qXFiLnPXCKTy7Bqc1lZeisKUaPvnDUjlte9UTEZ+UlaVKLc
2loqhiGtyczcNRObGWXulyXE3NaINXM55ztPfZtv+/bt/c57nvd5n+c9xzdx
zdwlHV0uVwf1JqrXQ70zvD3GZEcKuhk9aWdYFVNb3OXRkeSQSieW3cedKalm
entv2LNWFV8pHeD/QuVPzU1q+hWG/GNMm0MnJFwIEuT/YrhXRjnTj1Hzd9f4
Ab+MaXnB5/TQvsg/zOST9XHOeS9BqXrhOFPFoHk8uRPqnWI6PO3ct9+frHY+
Z0q+Hr9Zb1GAxj/NFKHr37ZoZGDnikEnmar1+kWrnc+CC6qDUxbdV7Tdqp6f
V8b+iCMWJYeoDMXnr34OWnSyuW52YhGbvELL8C8An92W6TePaaBeKLfoS7pq
NIfpndaj0qInd3/GNWYxrdV9XLVMP5lseNSBzzbo986JbX1anHwb7w/w3Uwr
tF7dBAWfvbX+ShpTn8qoho3eggYrWq/WOvGug6t7ZS5natio/vSEPwx/VGzj
zXP0t2MJv3yBF4f+RmN9LviFOLGtT7gw+sUzBWleUeC3GHpHI38l00w9PzGY
hxQ2ebHwexMb3vHC6L+VyWo8WnxjkTB1lZ5qOnyyVgnS20pzUC8N+PnQZzPy
C7CeLShF89vHVKTgrxVi3g5AnwzEhUxD9Py5BV1at7e/p8KLTewRH5QOPtsx
b7nQU/Fz6WePIG2T2w29Toh2v2y9rwszZ1swX7XC/M9gUtP8YMN94O9gWqj1
qnf2d9W8ngpK0P83gd9L8E0FXhPOUxLThg8jAjt/Emb+l8LfFvBLQL/Ngp63
uldesqDve9S3oFcT5mc6+DfAX4Lfr4XBDWK6rHV6KChf549nqtU87gmapT6L
AsHnjqBnul5A23kAfgD6f+LE9vc9/AvEPLaC/0ScFy9p+guG3j2l8XUKm3tg
sDT6hWMexkkzX1HID5NGr1k4/3HS4MdAz2VObN9H67E/Fn5vlVSn12ey6SsP
9SKh937kh7LxrVi287fP8yFJb5TsQ8ei3zJp9vnhfj0gzXz7wO989NcP95+q
Z5/P3v/ld4GfZcD3hB9VkvbUtIya3xH+1krjpwv5j6XBdUGfD5I0rWseuE++
S3N+FN4/DLG/mg==
               "],
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{47.438, 198.137}, {
               38.895, 212.879}, {33.227000000000004`, 225.42600000000002`}, {
               34.789, 226.141}, {36.343999999999994`, 226.859}, {
               44.535000000000004`, 215.477}, {53.074, 
               200.73399999999998`}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.00034917708333333334`], Opacity[1.], CapForm[
              "Butt"], JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{47.438, 198.137}, {
               38.895, 212.879}, {33.227000000000004`, 225.426}, {34.789, 
               226.141}, {36.343999999999994`, 226.859}, {44.535000000000004`,
                215.477}, {53.074, 200.73399999999998`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{48., 198.395}, {
               39.766000000000005`, 212.617}, {34.09, 224.625}, {35.332, 
               225.19899999999998`}, {36.574, 225.77299999999997`}, {44.273, 
               214.695}, {52.512, 200.477}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.00030675208333333343`], Opacity[1.], CapForm[
              "Butt"], JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{48., 
               198.39499999999998`}, {39.766000000000005`, 212.617}, {34.09, 
               224.625}, {35.332, 225.199}, {36.574, 225.773}, {44.273, 
               214.695}, {52.512, 200.477}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
               49.413999999999994`, 205.816}, {50.422000000000004`, 
               204.15200000000002`}, {51.48, 202.254}, {52.512, 200.477}, {
               48., 198.395}, {46.973, 200.176}, {45.848, 202.047}, {44.906, 
               203.738}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0003481479166666667], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
               49.413999999999994`, 205.816}, {50.422000000000004`, 
               204.152}, {51.48, 202.254}, {52.512, 200.477}, {48., 
               198.39499999999998`}, {46.973, 200.176}, {45.848, 202.047}, {
               44.906, 203.738}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
               49.035000000000004`, 205.242}, {50.035000000000004`, 
               203.578}, {50.734, 202.309}, {51.766000000000005`, 
               200.52700000000002`}, {48.382999999999996`, 
               198.97299999999998`}, {47.352, 200.75}, {46.594, 
               201.99200000000002`}, {45.652, 203.684}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0003481479166666667], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
               49.035000000000004`, 205.242}, {50.035000000000004`, 
               203.578}, {50.734, 202.309}, {51.766000000000005`, 200.527}, {
               48.382999999999996`, 198.973}, {47.352, 200.75}, {46.594, 
               201.992}, {45.652, 203.684}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{46.582, 
               203.316}, {48.836, 204.35500000000002`}, {50.839999999999996`, 
               200.89800000000002`}, {48.586, 199.859}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002769611943733424], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               46.58167737800001, 203.316123686}, {48.83612553100003, 
               204.355485783}, {50.839778294, 200.898826602}, {
               48.58533014099999, 199.85946450500003`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{46.578, 203.316}, {50.836, 
               200.89800000000002`}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0003481479166666667], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{46.578, 203.316}, {50.836, 
               200.898}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{48.586, 199.859}, {48.836, 
               204.35500000000002`}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0003481479166666667], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{48.586, 199.859}, {48.836, 
               204.355}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{36.38699999999999, 220.91}, {
               38.645, 221.94899999999998`}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0003481479166666667], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{36.38699999999999, 220.91}, {
               38.645, 221.949}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[
              0.8588240000000001, 0.08627450000000002, 0.105882], Opacity[
              1.]}], FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{37.164, 222.934}, {37.086, 222.625}, {
               36.73800000000001, 222.44899999999998`}, {36.38699999999999, 
               222.539}, {36.035000000000004`, 222.625}, {35.812, 
               222.94899999999998`}, {35.895, 223.258}, {35.973, 223.562}, {
               36.32, 223.742}, {36.672000000000004`, 223.65200000000002`}, {
               37.023, 223.566}, {37.246, 223.242}, {37.164, 222.934}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0004373646025411586], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{37.16445770000001, 222.933479778}, {37.08623700000002,
                222.62532413000002`}, {36.7385896, 222.449553574}, {
               36.3868153, 222.539180552}, {36.03513820000002, 
               222.625046528}, {35.8129141, 222.949169404}, {
               35.894360500000005`, 223.25744588}, {35.9729041, 
               223.562717744}, {36.320454300000016`, 223.74224930200003`}, {
               36.672228600000004`, 223.652622324}, {37.02390570000001, 
               223.566756348}, {37.24612980000001, 223.242633472}, {
               37.16445770000001, 222.933479778}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0,
                1, 0}}}, {{{54.105000000000004`, 206.016}, {
               54.105000000000004`, 193.641}, {54.176, 188.977}, {
               53.266000000000005`, 188.336}, {52.398, 187.65200000000002`}, {
               28.324, 188.336}, {28.324, 184.80100000000002`}, {28.324, 
               181.266}, {48.156, 177.727}, {54.105000000000004`, 177.727}, {
               62.035000000000004`, 177.727}, {66.004, 181.266}, {66.004, 
               188.336}, {66.004, 206.016}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0003178145833333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0,
                1, 0}}}, {{{54.105000000000004`, 206.01600000000002`}, {
               54.105000000000004`, 193.64100000000002`}, {54.176, 188.977}, {
               53.266000000000005`, 188.336}, {52.398, 187.652}, {28.324, 
               188.336}, {28.324, 184.801}, {28.324, 181.266}, {48.156, 
               177.727}, {54.105000000000004`, 177.727}, {62.035000000000004`,
                177.727}, {66.004, 181.266}, {66.004, 188.336}, {66.004, 
               206.01600000000002`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
               3}}}, {{{54.105000000000004`, 202.48000000000002`}, {
               54.105000000000004`, 200.71099999999998`}, {58.07, 200.125}, {
               62.035000000000004`, 200.125}, {66.004, 200.71099999999998`}, {
               66.004, 202.48000000000002`}, {62.035000000000004`, 
               201.89100000000002`}, {58.07, 201.89100000000002`}, {
               54.105000000000004`, 202.48000000000002`}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
               3}}}, {{{54.105000000000004`, 202.48}, {54.105000000000004`, 
               200.711}, {58.07, 200.125}, {62.035000000000004`, 200.125}, {
               66.004, 200.711}, {66.004, 202.48}, {62.035000000000004`, 
               201.891}, {58.07, 201.891}, {54.105000000000004`, 202.48}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
               3}}}, {{{54.105000000000004`, 206.016}, {54.105000000000004`, 
               204.25}, {58.07, 203.66}, {62.035000000000004`, 203.66}, {
               66.004, 204.25}, {66.004, 206.016}, {62.035000000000004`, 
               205.42600000000002`}, {58.07, 205.42600000000002`}, {
               54.105000000000004`, 206.016}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
               3}}}, {{{54.105000000000004`, 206.01600000000002`}, {
               54.105000000000004`, 204.25}, {58.07, 203.66}, {
               62.035000000000004`, 203.66}, {66.004, 204.25}, {66.004, 
               206.01600000000002`}, {62.035000000000004`, 205.426}, {58.07, 
               205.426}, {54.105000000000004`, 206.01600000000002`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
               3}}}, {{{54.105000000000004`, 204.25}, {54.105000000000004`, 
               202.48000000000002`}, {58.07, 201.89100000000002`}, {
               62.035000000000004`, 201.89100000000002`}, {66.004, 
               202.48000000000002`}, {66.004, 204.25}, {62.035000000000004`, 
               203.66}, {58.07, 203.66}, {54.105000000000004`, 204.25}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
               3}}}, {{{54.105000000000004`, 204.25}, {54.105000000000004`, 
               202.48}, {58.07, 201.891}, {62.035000000000004`, 201.891}, {
               66.004, 202.48}, {66.004, 204.25}, {62.035000000000004`, 
               203.66}, {58.07, 203.66}, {54.105000000000004`, 204.25}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
               3}}}, {{{54.105000000000004`, 200.71099999999998`}, {
               54.105000000000004`, 198.945}, {58.07, 198.35500000000002`}, {
               62.035000000000004`, 198.35500000000002`}, {66.004, 198.945}, {
               66.004, 200.71099999999998`}, {62.035000000000004`, 200.125}, {
               58.07, 200.125}, {54.105000000000004`, 
               200.71099999999998`}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
               3}}}, {{{54.105000000000004`, 200.711}, {54.105000000000004`, 
               198.945}, {58.07, 198.355}, {62.035000000000004`, 198.355}, {
               66.004, 198.945}, {66.004, 200.711}, {62.035000000000004`, 
               200.125}, {58.07, 200.125}, {54.105000000000004`, 200.711}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{55.188, 203.242}, {55.188, 203.031}, {54.945, 
               202.863}, {54.645, 202.863}, {54.348, 202.863}, {
               54.105000000000004`, 203.031}, {54.105000000000004`, 
               203.242}, {54.105000000000004`, 203.453}, {54.348, 203.625}, {
               54.645, 203.625}, {54.945, 203.625}, {55.188, 203.453}, {
               55.188, 203.242}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.00027523230299006575`], Opacity[1.], CapForm[
              "Butt"], JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{55.188, 203.24234895299998`}, {55.188, 
               203.03123184700002`}, {54.945, 202.863372589}, {54.645, 
               202.863372589}, {54.348, 202.863372589}, {54.105000000000004`, 
               203.03123184700002`}, {54.105000000000004`, 
               203.24234895299998`}, {54.105000000000004`, 
               203.45323096200002`}, {54.348, 203.625086869}, {54.645, 
               203.625086869}, {54.945, 203.625086869}, {55.188, 
               203.45323096200002`}, {55.188, 203.24234895299998`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{57.348, 203.055}, {57.348, 202.844}, {
               57.105000000000004`, 202.672}, {56.809, 202.672}, {56.508, 
               202.672}, {56.266000000000005`, 202.844}, {56.266000000000005`,
                203.055}, {56.266000000000005`, 203.262}, {56.508, 203.434}, {
               56.809, 203.434}, {57.105000000000004`, 203.434}, {57.348, 
               203.262}, {57.348, 203.055}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.00027523230299006575`], Opacity[1.], CapForm[
              "Butt"], JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{57.348, 203.054741547}, {57.348, 202.843859538}, {
               57.105000000000004`, 202.672003631}, {56.809, 202.672003631}, {
               56.508, 202.672003631}, {56.266000000000005`, 202.843859538}, {
               56.266000000000005`, 203.054741547}, {56.266000000000005`, 
               203.261862004}, {56.508, 203.43371791100003`}, {56.809, 
               203.43371791100003`}, {57.105000000000004`, 
               203.43371791100003`}, {57.348, 203.261862004}, {57.348, 
               203.054741547}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{59.512, 202.863}, {59.512, 202.65200000000002`}, {
               59.27, 202.48000000000002`}, {58.973, 202.48000000000002`}, {
               58.672000000000004`, 202.48000000000002`}, {58.43, 
               202.65200000000002`}, {58.43, 202.863}, {58.43, 
               203.07399999999998`}, {58.672000000000004`, 203.242}, {58.973, 
               203.242}, {59.27, 203.242}, {59.512, 203.07399999999998`}, {
               59.512, 202.863}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752377784678158], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{59.512, 202.863295456}, {59.512, 202.652414344}, {
               59.27, 202.48032407200003`}, {58.973, 202.48032407200003`}, {
               58.672000000000004`, 202.48032407200003`}, {58.43, 
               202.652414344}, {58.43, 202.863295456}, {58.43, 
               203.07417656799998`}, {58.672000000000004`, 203.242035112}, {
               58.973, 203.242035112}, {59.27, 203.242035112}, {59.512, 
               203.07417656799998`}, {59.512, 202.863295456}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{61.676, 202.863}, {61.676, 202.65200000000002`}, {
               61.434, 202.48000000000002`}, {61.137, 202.48000000000002`}, {
               60.836, 202.48000000000002`}, {60.594, 202.65200000000002`}, {
               60.594, 202.863}, {60.594, 203.07399999999998`}, {60.836, 
               203.242}, {61.137, 203.242}, {61.434, 203.242}, {61.676, 
               203.07399999999998`}, {61.676, 202.863}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752377784678158], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{61.676, 202.863295456}, {61.676, 202.652414344}, {
               61.434, 202.48032407200003`}, {61.137, 202.48032407200003`}, {
               60.836, 202.48032407200003`}, {60.594, 202.652414344}, {60.594,
                202.863295456}, {60.594, 203.07417656799998`}, {60.836, 
               203.242035112}, {61.137, 203.242035112}, {61.434, 
               203.242035112}, {61.676, 203.07417656799998`}, {61.676, 
               202.863295456}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{63.839999999999996`, 203.055}, {63.839999999999996`, 
               202.844}, {63.598000000000006`, 202.672}, {63.297000000000004`,
                202.672}, {63., 202.672}, {62.758, 202.844}, {62.758, 
               203.055}, {62.758, 203.262}, {63., 203.434}, {
               63.297000000000004`, 203.434}, {63.598000000000006`, 
               203.434}, {63.839999999999996`, 203.262}, {63.839999999999996`,
                203.055}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.00027523230299006575`], Opacity[1.], CapForm[
              "Butt"], JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{63.839999999999996`, 203.054741547}, {
               63.839999999999996`, 202.843859538}, {63.598000000000006`, 
               202.672003631}, {63.297000000000004`, 202.672003631}, {63., 
               202.672003631}, {62.758, 202.843859538}, {62.758, 
               203.054741547}, {62.758, 203.261862004}, {63., 
               203.43371791100003`}, {63.297000000000004`, 
               203.43371791100003`}, {63.598000000000006`, 
               203.43371791100003`}, {63.839999999999996`, 203.261862004}, {
               63.839999999999996`, 203.054741547}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{66.004, 203.242}, {66.004, 203.031}, {65.762, 
               202.863}, {65.46100000000001, 202.863}, {65.164, 202.863}, {
               64.922, 203.031}, {64.922, 203.242}, {64.922, 203.453}, {
               65.164, 203.625}, {65.46100000000001, 203.625}, {65.762, 
               203.625}, {66.004, 203.453}, {66.004, 203.242}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.00027523230299006575`], Opacity[1.], CapForm[
              "Butt"], JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{66.004, 203.24234895299998`}, {66.004, 
               203.03123184700002`}, {65.762, 202.863372589}, {
               65.46100000000001, 202.863372589}, {65.164, 202.863372589}, {
               64.922, 203.03123184700002`}, {64.922, 203.24234895299998`}, {
               64.922, 203.45323096200002`}, {65.164, 203.625086869}, {
               65.46100000000001, 203.625086869}, {65.762, 203.625086869}, {
               66.004, 203.45323096200002`}, {66.004, 203.24234895299998`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{54.105000000000004`, 
               197.176}, {66.004, 187.629}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{54.105000000000004`, 
               197.176}, {66.004, 187.62900000000002`}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{55.293000000000006`, 
               197.176}, {66.004, 188.691}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{55.293000000000006`, 
               197.176}, {66.004, 188.691}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{56.879, 196.824}, {66.004, 
               189.754}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{56.879, 196.824}, {66.004, 
               189.754}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{58.07, 196.824}, {66.004, 
               190.812}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{58.07, 196.824}, {66.004, 
               190.812}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{59.26200000000001, 196.824}, {
               66.004, 191.871}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{59.26200000000001, 196.824}, {
               66.004, 191.87099999999998`}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{60.449, 196.824}, {66.004, 
               192.934}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{60.449, 196.824}, {66.004, 
               192.934}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{61.641, 196.824}, {66.004, 
               193.996}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{61.641, 196.824}, {66.004, 
               193.996}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{62.828, 196.824}, {66.004, 
               194.69899999999998`}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{62.828, 196.824}, {66.004, 
               194.699}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{64.02, 196.824}, {66.004, 
               195.406}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{64.02, 196.824}, {66.004, 
               195.406}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{65.20700000000001, 196.824}, {
               66.004, 196.117}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{65.20700000000001, 196.824}, {
               66.004, 196.11700000000002`}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{54.105000000000004`, 
               196.117}, {66.004, 186.566}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{54.105000000000004`, 
               196.11700000000002`}, {66.004, 186.566}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{66.004, 197.176}, {
               52.913999999999994`, 186.566}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{66.004, 197.176}, {
               52.913999999999994`, 186.566}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{64.812, 197.176}, {53.312, 
               187.984}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{64.812, 197.176}, {53.312, 
               187.984}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{63.227000000000004`, 
               196.824}, {54.105000000000004`, 189.754}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{63.227000000000004`, 
               196.824}, {54.105000000000004`, 189.754}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{62.035000000000004`, 
               196.824}, {54.105000000000004`, 190.812}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{62.035000000000004`, 
               196.824}, {54.105000000000004`, 190.812}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{60.848, 196.824}, {
               54.105000000000004`, 191.871}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{60.848, 196.824}, {
               54.105000000000004`, 191.87099999999998`}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{59.656, 196.824}, {
               54.105000000000004`, 192.934}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{59.656, 196.824}, {
               54.105000000000004`, 192.934}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{58.469, 196.824}, {
               54.105000000000004`, 193.996}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{58.469, 196.824}, {
               54.105000000000004`, 193.996}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{57.277, 196.824}, {
               54.105000000000004`, 194.69899999999998`}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{57.277, 196.824}, {
               54.105000000000004`, 194.699}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{56.09, 196.824}, {
               54.105000000000004`, 195.406}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{56.09, 196.824}, {
               54.105000000000004`, 195.406}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{54.895, 196.824}, {
               54.105000000000004`, 196.117}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{54.895, 196.824}, {
               54.105000000000004`, 196.11700000000002`}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{66.004, 196.117}, {
               52.913999999999994`, 185.508}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{66.004, 196.11700000000002`}, {
               52.913999999999994`, 185.50799999999998`}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{66.004, 195.055}, {
               52.913999999999994`, 184.44899999999998`}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{66.004, 195.055}, {
               52.913999999999994`, 184.449}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{66.004, 193.996}, {
               52.913999999999994`, 183.383}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{66.004, 193.996}, {
               52.913999999999994`, 183.383}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{66.004, 192.934}, {
               52.913999999999994`, 182.324}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{66.004, 192.934}, {
               52.913999999999994`, 182.324}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{66.004, 191.871}, {
               52.913999999999994`, 181.266}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{66.004, 191.87099999999998`}, {
               52.913999999999994`, 181.266}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{66.004, 190.812}, {
               52.913999999999994`, 180.20299999999997`}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{66.004, 190.812}, {
               52.913999999999994`, 180.203}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{66.004, 189.754}, {
               52.913999999999994`, 179.14499999999998`}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{66.004, 189.754}, {
               52.913999999999994`, 179.145}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{66.004, 188.68800000000002`}, {
               52.913999999999994`, 178.078}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{66.004, 188.688}, {
               52.913999999999994`, 178.078}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{66.004, 187.629}, {53.707, 
               177.727}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{66.004, 187.62900000000002`}, {
               53.707, 177.727}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{66.004, 186.566}, {54.895, 
               177.727}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{66.004, 186.566}, {54.895, 
               177.727}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{65.60499999999999, 
               185.15200000000002`}, {56.879, 178.078}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{65.60499999999999, 185.152}, {
               56.879, 178.078}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{65.20700000000001, 183.738}, {
               58.07, 178.078}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{65.20700000000001, 183.738}, {
               58.07, 178.078}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{64.41400000000002, 
               181.97299999999998`}, {60.848, 179.14499999999998`}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{64.41400000000002, 181.973}, {
               60.848, 179.145}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{54.105000000000004`, 
               195.055}, {65.60499999999999, 185.859}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{54.105000000000004`, 
               195.055}, {65.60499999999999, 185.859}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{54.105000000000004`, 
               193.996}, {65.60499999999999, 184.80100000000002`}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{54.105000000000004`, 
               193.996}, {65.60499999999999, 184.801}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{54.105000000000004`, 
               192.934}, {65.20700000000001, 184.094}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{54.105000000000004`, 
               192.934}, {65.20700000000001, 184.094}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{54.105000000000004`, 
               191.871}, {65.20700000000001, 183.031}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{54.105000000000004`, 
               191.87099999999998`}, {65.20700000000001, 183.031}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{54.105000000000004`, 
               190.812}, {64.812, 182.324}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{54.105000000000004`, 
               190.812}, {64.812, 182.324}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{53.707, 190.105}, {
               64.41400000000002, 181.617}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{53.707, 190.105}, {
               64.41400000000002, 181.61700000000002`}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{53.707, 189.04299999999998`}, {
               63.62500000000001, 181.266}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{53.707, 189.043}, {
               63.62500000000001, 181.266}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{53.312, 188.336}, {
               63.227000000000004`, 180.555}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{53.312, 188.336}, {
               63.227000000000004`, 180.555}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{52.913999999999994`, 
               187.629}, {62.434, 180.20299999999997`}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{52.913999999999994`, 
               187.62900000000002`}, {62.434, 180.203}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{52.913999999999994`, 
               186.566}, {62.035000000000004`, 179.496}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{52.913999999999994`, 
               186.566}, {62.035000000000004`, 179.496}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{52.913999999999994`, 
               185.508}, {60.848, 179.14499999999998`}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{52.913999999999994`, 
               185.50799999999998`}, {60.848, 179.145}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
               3}}}, {{{54.105000000000004`, 198.945}, {54.105000000000004`, 
               197.176}, {58.07, 196.59}, {62.035000000000004`, 196.59}, {
               66.004, 197.176}, {66.004, 198.945}, {62.035000000000004`, 
               198.35500000000002`}, {58.07, 198.35500000000002`}, {
               54.105000000000004`, 198.945}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
               3}}}, {{{54.105000000000004`, 198.945}, {54.105000000000004`, 
               197.176}, {58.07, 196.59}, {62.035000000000004`, 196.59}, {
               66.004, 197.176}, {66.004, 198.945}, {62.035000000000004`, 
               198.355}, {58.07, 198.355}, {54.105000000000004`, 198.945}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{52.913999999999994`, 
               184.44899999999998`}, {60.050999999999995`, 178.789}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{52.913999999999994`, 
               184.449}, {60.050999999999995`, 178.789}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{52.913999999999994`, 
               183.383}, {59.26200000000001, 178.43800000000002`}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{52.913999999999994`, 
               183.383}, {59.26200000000001, 178.438}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{52.913999999999994`, 
               182.324}, {58.469, 178.078}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{52.913999999999994`, 
               182.324}, {58.469, 178.078}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{52.913999999999994`, 
               181.266}, {56.879, 178.078}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{52.913999999999994`, 
               181.266}, {56.879, 178.078}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{52.913999999999994`, 
               180.20299999999997`}, {56.09, 177.727}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{52.913999999999994`, 
               180.203}, {56.09, 177.727}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{52.913999999999994`, 
               179.14499999999998`}, {54.895, 177.727}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{52.913999999999994`, 
               179.145}, {54.895, 177.727}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{55.188, 197.941}, {55.188, 197.73}, {54.945, 
               197.559}, {54.645, 197.559}, {54.348, 197.559}, {
               54.105000000000004`, 197.73}, {54.105000000000004`, 197.941}, {
               54.105000000000004`, 198.148}, {54.348, 198.32000000000002`}, {
               54.645, 198.32000000000002`}, {54.945, 198.32000000000002`}, {
               55.188, 198.148}, {55.188, 197.941}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.00027523230299006575`], Opacity[1.], CapForm[
              "Butt"], JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{55.188, 197.941381797}, {55.188, 197.730499788}, {
               54.945, 197.55864388100002`}, {54.645, 197.55864388100002`}, {
               54.348, 197.55864388100002`}, {54.105000000000004`, 
               197.730499788}, {54.105000000000004`, 197.941381797}, {
               54.105000000000004`, 198.148502254}, {54.348, 198.320358161}, {
               54.645, 198.320358161}, {54.945, 198.320358161}, {55.188, 
               198.148502254}, {55.188, 197.941381797}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{57.348, 197.75}, {57.348, 197.539}, {
               57.105000000000004`, 197.36700000000002`}, {56.809, 
               197.36700000000002`}, {56.508, 197.36700000000002`}, {
               56.266000000000005`, 197.539}, {56.266000000000005`, 197.75}, {
               56.266000000000005`, 197.961}, {56.508, 198.129}, {56.809, 
               198.129}, {57.105000000000004`, 198.129}, {57.348, 197.961}, {
               57.348, 197.75}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.00027523230299006575`], Opacity[1.], CapForm[
              "Butt"], JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{57.348, 197.750012839}, {57.348, 
               197.53913083000003`}, {57.105000000000004`, 197.367274923}, {
               56.809, 197.367274923}, {56.508, 197.367274923}, {
               56.266000000000005`, 197.53913083000003`}, {
               56.266000000000005`, 197.750012839}, {56.266000000000005`, 
               197.960894848}, {56.508, 198.12898920300003`}, {56.809, 
               198.12898920300003`}, {57.105000000000004`, 
               198.12898920300003`}, {57.348, 197.960894848}, {57.348, 
               197.750012839}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{59.512, 197.559}, {59.512, 197.348}, {59.27, 
               197.176}, {58.973, 197.176}, {58.672000000000004`, 197.176}, {
               58.43, 197.348}, {58.43, 197.559}, {58.43, 
               197.76999999999998`}, {58.672000000000004`, 197.941}, {58.973, 
               197.941}, {59.27, 197.941}, {59.512, 197.76999999999998`}, {
               59.512, 197.559}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752377784678158], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{59.512, 197.55858931199998`}, {59.512, 197.3477082}, {
               59.27, 197.17561792800004`}, {58.973, 197.17561792800004`}, {
               58.672000000000004`, 197.17561792800004`}, {58.43, 
               197.3477082}, {58.43, 197.55858931199998`}, {58.43, 
               197.76947042400002`}, {58.672000000000004`, 
               197.94132560000003`}, {58.973, 197.94132560000003`}, {59.27, 
               197.94132560000003`}, {59.512, 197.76947042400002`}, {59.512, 
               197.55858931199998`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{61.676, 197.559}, {61.676, 197.348}, {61.434, 
               197.176}, {61.137, 197.176}, {60.836, 197.176}, {60.594, 
               197.348}, {60.594, 197.559}, {60.594, 197.76999999999998`}, {
               60.836, 197.941}, {61.137, 197.941}, {61.434, 197.941}, {
               61.676, 197.76999999999998`}, {61.676, 197.559}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752377784678158], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{61.676, 197.55858931199998`}, {61.676, 197.3477082}, {
               61.434, 197.17561792800004`}, {61.137, 197.17561792800004`}, {
               60.836, 197.17561792800004`}, {60.594, 197.3477082}, {60.594, 
               197.55858931199998`}, {60.594, 197.76947042400002`}, {60.836, 
               197.94132560000003`}, {61.137, 197.94132560000003`}, {61.434, 
               197.94132560000003`}, {61.676, 197.76947042400002`}, {61.676, 
               197.55858931199998`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{63.839999999999996`, 197.75}, {63.839999999999996`, 
               197.539}, {63.598000000000006`, 197.36700000000002`}, {
               63.297000000000004`, 197.36700000000002`}, {63., 
               197.36700000000002`}, {62.758, 197.539}, {62.758, 197.75}, {
               62.758, 197.961}, {63., 198.129}, {63.297000000000004`, 
               198.129}, {63.598000000000006`, 198.129}, {63.839999999999996`,
                197.961}, {63.839999999999996`, 197.75}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.00027523230299006575`], Opacity[1.], CapForm[
              "Butt"], JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{63.839999999999996`, 197.750012839}, {
               63.839999999999996`, 197.53913083000003`}, {
               63.598000000000006`, 197.367274923}, {63.297000000000004`, 
               197.367274923}, {63., 197.367274923}, {62.758, 
               197.53913083000003`}, {62.758, 197.750012839}, {62.758, 
               197.960894848}, {63., 198.12898920300003`}, {
               63.297000000000004`, 198.12898920300003`}, {
               63.598000000000006`, 198.12898920300003`}, {
               63.839999999999996`, 197.960894848}, {63.839999999999996`, 
               197.750012839}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{66.004, 197.941}, {66.004, 197.73}, {65.762, 
               197.559}, {65.46100000000001, 197.559}, {65.164, 197.559}, {
               64.922, 197.73}, {64.922, 197.941}, {64.922, 198.148}, {65.164,
                198.32000000000002`}, {65.46100000000001, 
               198.32000000000002`}, {65.762, 198.32000000000002`}, {66.004, 
               198.148}, {66.004, 197.941}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.00027523230299006575`], Opacity[1.], CapForm[
              "Butt"], JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{66.004, 197.941381797}, {66.004, 197.730499788}, {
               65.762, 197.55864388100002`}, {65.46100000000001, 
               197.55864388100002`}, {65.164, 197.55864388100002`}, {64.922, 
               197.730499788}, {64.922, 197.941381797}, {64.922, 
               198.148502254}, {65.164, 198.320358161}, {65.46100000000001, 
               198.320358161}, {65.762, 198.320358161}, {66.004, 
               198.148502254}, {66.004, 197.941381797}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{37.050999999999995`, 
               180.555}, {51.328, 187.984}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{37.050999999999995`, 
               180.555}, {51.328, 187.984}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{36.258, 180.91}, {
               49.73800000000001, 187.984}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{36.258, 180.91}, {
               49.73800000000001, 187.984}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{35.858999999999995`, 
               181.617}, {48.156, 187.984}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{35.858999999999995`, 
               181.61700000000002`}, {48.156, 187.984}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{35.465, 182.324}, {
               46.172000000000004`, 187.984}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{35.465, 182.324}, {
               46.172000000000004`, 187.984}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{34.672000000000004`, 
               183.031}, {44.586, 187.984}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{34.672000000000004`, 
               183.031}, {44.586, 187.984}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{35.066, 184.094}, {41.809, 
               187.629}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{35.066, 184.094}, {41.809, 
               187.62900000000002`}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{34.672000000000004`, 
               184.80100000000002`}, {39.828, 187.629}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{34.672000000000004`, 
               184.801}, {39.828, 187.62900000000002`}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{34.672000000000004`, 
               185.859}, {38.23800000000001, 187.629}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{34.672000000000004`, 
               185.859}, {38.23800000000001, 187.62900000000002`}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{38.23800000000001, 
               180.20299999999997`}, {51.723000000000006`, 187.277}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{38.23800000000001, 180.203}, {
               51.723000000000006`, 187.277}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{39.43, 179.848}, {52.121, 
               186.566}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{39.43, 179.848}, {52.121, 
               186.566}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{40.621, 179.496}, {52.516, 
               185.859}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{40.621, 179.496}, {52.516, 
               185.859}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{41.809, 179.14499999999998`}, {
               51.723000000000006`, 184.44899999999998`}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{41.809, 179.145}, {
               51.723000000000006`, 184.449}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{43.395, 179.14499999999998`}, {
               52.121, 183.738}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{43.395, 179.145}, {52.121, 
               183.738}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{44.586, 178.789}, {52.121, 
               182.68}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{44.586, 178.789}, {52.121, 
               182.68}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{45.777, 178.43800000000002`}, {
               51.723000000000006`, 181.617}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{45.777, 178.438}, {
               51.723000000000006`, 181.61700000000002`}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{47.358999999999995`, 
               178.43800000000002`}, {52.121, 180.91}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{47.358999999999995`, 
               178.438}, {52.121, 180.91}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{48.949, 178.078}, {52.121, 
               179.848}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{48.949, 178.078}, {52.121, 
               179.848}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{50.535000000000004`, 
               178.078}, {52.516, 179.14499999999998`}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{50.535000000000004`, 
               178.078}, {52.516, 179.145}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
               3}}}, {{{53.312, 188.336}, {51.328, 188.336}, {
               50.668000000000006`, 184.80100000000002`}, {
               50.668000000000006`, 181.266}, {51.328, 177.727}, {53.312, 
               177.727}, {52.648, 181.266}, {52.648, 184.80100000000002`}, {
               53.312, 188.336}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
               3}}}, {{{53.312, 188.336}, {51.328, 188.336}, {
               50.668000000000006`, 184.801}, {50.668000000000006`, 
               181.266}, {51.328, 177.727}, {53.312, 177.727}, {52.648, 
               181.266}, {52.648, 184.801}, {53.312, 188.336}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{29.91, 183.383}, {
               34.672000000000004`, 186.92200000000003`}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{29.91, 183.383}, {
               34.672000000000004`, 186.922}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}}}, {{{29.91, 185.859}, {
               34.672000000000004`, 181.617}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{29.91, 185.859}, {
               34.672000000000004`, 181.61700000000002`}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
               3}}}, {{{37.050999999999995`, 187.629}, {34.672000000000004`, 
               187.277}, {34.141, 185.035}, {34.141, 183.15200000000002`}, {
               34.672000000000004`, 180.91}, {37.050999999999995`, 
               180.20299999999997`}, {36.52, 182.445}, {36.52, 
               185.38700000000003`}, {37.050999999999995`, 187.629}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.00019591270833333333`], Opacity[1.], CapForm[
              "Butt"], JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
               3}}}, {{{37.050999999999995`, 187.62900000000002`}, {
               34.672000000000004`, 187.277}, {34.141, 185.035}, {34.141, 
               183.152}, {34.672000000000004`, 180.91}, {37.050999999999995`, 
               180.203}, {36.52, 182.445}, {36.52, 185.387}, {
               37.050999999999995`, 187.62900000000002`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {0,
                1, 0}}}, {{{65.988, 205.309}, {65.988, 207.094}, {
               64.20700000000001, 207.078}, {63.016, 208.137}, {63.016, 
               209.21499999999997`}, {57.074, 209.19899999999998`}, {57.074, 
               208.137}, {55.88699999999999, 207.078}, {54.105000000000004`, 
               207.078}, {54.105000000000004`, 205.309}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0003369062500000001], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {0,
                1, 0}}}, {{{65.988, 205.309}, {65.988, 207.094}, {
               64.20700000000001, 207.078}, {63.016, 208.137}, {63.016, 
               209.215}, {57.074, 209.199}, {57.074, 208.137}, {
               55.88699999999999, 207.078}, {54.105000000000004`, 207.078}, {
               54.105000000000004`, 205.309}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{57.5, 
               211.32000000000002`}, {62.594, 211.32000000000002`}, {62.594, 
               209.199}, {57.5, 209.199}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002847395833333333], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{57.5, 
               211.32}, {62.594, 211.32}, {62.594, 209.19899999999998`}, {
               57.5, 209.19899999999998`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{57.926, 
               213.441}, {62.168, 213.441}, {62.168, 211.32}, {57.926, 
               211.32}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002847395833333333], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{57.926, 
               213.441}, {62.168, 213.441}, {62.168, 211.32}, {57.926, 
               211.32}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{57.926, 
               215.562}, {62.168, 215.562}, {62.168, 213.441}, {57.926, 
               213.441}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002847395833333333], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{57.926, 
               215.562}, {62.168, 215.562}, {62.168, 213.441}, {57.926, 
               213.441}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{58.348, 
               218.395}, {61.742999999999995`, 218.395}, {61.742999999999995`,
                215.56300000000002`}, {58.348, 215.56300000000002`}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002847395833333333], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{58.348, 
               218.395}, {61.742999999999995`, 218.395}, {61.742999999999995`,
                215.56300000000002`}, {58.348, 215.56300000000002`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{58.203, 
               220.86700000000002`}, {61.891000000000005`, 
               220.86700000000002`}, {61.891000000000005`, 218.394}, {58.203, 
               218.394}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002967500000000001], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{58.203, 
               220.867}, {61.891000000000005`, 220.867}, {61.891000000000005`,
                218.394}, {58.203, 218.394}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{65.16799999999999, 223.168}, {65.16799999999999, 
               221.312}, {62.969, 219.809}, {60.25, 219.809}, {
               57.535000000000004`, 219.809}, {55.332, 221.312}, {55.332, 
               223.168}, {55.332, 225.023}, {57.535000000000004`, 
               226.52700000000002`}, {60.25, 226.52700000000002`}, {62.969, 
               226.52700000000002`}, {65.16799999999999, 225.023}, {
               65.16799999999999, 223.168}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002797843009704614], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{65.16799999999999, 223.167931868}, {65.16799999999999,
                221.31284951800004`}, {62.969, 219.808938571}, {60.25, 
               219.808938571}, {57.535000000000004`, 219.808938571}, {55.332, 
               221.31284951800004`}, {55.332, 223.167931868}, {55.332, 
               225.023014218}, {57.535000000000004`, 226.52692516500005`}, {
               60.25, 226.52692516500005`}, {62.969, 226.52692516500005`}, {
               65.16799999999999, 225.023014218}, {65.16799999999999, 
               223.167931868}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4rhdnjxM0f4OYPp1tgOM72Pe6ZhwNtth9hGF
DUU//B2stpwo2zcbk7+nZLIES5u/w6qPl3yTOrIdTi903fb5rJ/DzXPfgx9X
Zjv0Ts8TalZA8A9/1YjpL/KF8126c57/nukD4TdmO/Drbpr73t0Hbj463+Cu
ClvjUx+4+2B8mPth/AJbruuLOXLg+qtF1rk/1MPkO4Ps3+nj8LbG3jTOKQfu
vv3zpfTvBuTA3Q/jw/wH48P8D9MPCx+Y+eh8WPjC3Ice/gCXa7OX
               "]]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002797833333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4rhdnjxM0f4OYPp1tgOM72Pe6ZhwNtth9hGF
DUU//B0st5wo2zcbk7+nZLIES5u/w6qPl3yTOrIdTi903fb5rJ/DzXPfgx9X
Zjv0Ts8TalZA8A9/1YjpL/KF8126c57/nukD4TdmO/Drbpr73t0Hbj463+Cu
ClvjUx+4+2B8mPth/EJbruuLOXLg+qtF1rk/1MPkO4Ps3+nj8K7G3jTOKQfu
vn3zpfTvBuTA3Q/jw/wH48P8D9MPCx+Y+eh8WPjC3Ice/gCTM7OU
               "],
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYCYtO4XZ48n/wcQBTT62wHGN/HvNMx4Wy2Q3HG
xLc1/f4OvdPzhJonYPLtuK4vLpD1d1jkuu3z35psh9MLgYyzfg43z30PflyZ
DVGngOAf/qoR01/kC+fnPv+98iOTr8OWE2X75pdlO0jp31Vh2+gDNx+dH2EJ
VOnnC3cfjA9zP4xfYAt0GEcOXD830Jm2Vph8sP1Kvg7CzQdOLfTNgbtv/3yg
yoAcuPthfJj/YHyY/2H6YeEDMx+dDwtfmPvQwx8ALlew6g==
               "]]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002797833333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYCYtO4XZ48n/wcQBTT62wHGN/HvNMx4Wy2Q3HG
xLc1/f4OvdPzhJonYPLtuK4vLpD1d1jkuu3z35psh9MLgYyzfg43z30PflyZ
DVGngOAf/qoR01/kC+fnPv+98iOTr8OWE2X75pdlO0jp31Vh2+gDNx+dH2EJ
VOnnC3cfjA9zP4xfaAt0GEcOXD/ImbZWmHyw/Uq+DkLNB04t9M2Bu2/ffKDK
gBy4+2F8mP9gfJj/Yfph4QMzH50PC1+Y+9DDHwArf7Dj
               "],
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{56.562000000000005`, 222.98800000000003`}, {
               56.562000000000005`, 222.40200000000002`}, {56.012, 221.93}, {
               55.332, 221.93}, {54.656, 221.93}, {54.105000000000004`, 
               222.40200000000002`}, {54.105000000000004`, 
               222.98800000000003`}, {54.105000000000004`, 
               223.57399999999998`}, {54.656, 224.05100000000002`}, {55.332, 
               224.05100000000002`}, {56.012, 224.05100000000002`}, {
               56.562000000000005`, 223.57399999999998`}, {
               56.562000000000005`, 222.98800000000003`}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002797843009704614], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{56.562000000000005`, 222.988463436}, {
               56.562000000000005`, 222.402602545}, {56.012, 221.929772253}, {
               55.332, 221.929772253}, {54.656, 221.929772253}, {
               54.105000000000004`, 222.402602545}, {54.105000000000004`, 
               222.988463436}, {54.105000000000004`, 223.57432432700003`}, {
               54.656, 224.05060593500002`}, {55.332, 224.05060593500002`}, {
               56.012, 224.05060593500002`}, {56.562000000000005`, 
               223.57432432700003`}, {56.562000000000005`, 222.988463436}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{66.398, 222.98800000000003`}, {66.398, 
               222.40200000000002`}, {65.848, 221.93}, {65.16799999999999, 
               221.93}, {64.488, 221.93}, {63.940999999999995`, 
               222.40200000000002`}, {63.940999999999995`, 
               222.98800000000003`}, {63.940999999999995`, 
               223.57399999999998`}, {64.488, 224.05100000000002`}, {
               65.16799999999999, 224.05100000000002`}, {65.848, 
               224.05100000000002`}, {66.398, 223.57399999999998`}, {66.398, 
               222.98800000000003`}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002797843009704614], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{66.398, 222.988463436}, {66.398, 222.402602545}, {
               65.848, 221.929772253}, {65.16799999999999, 221.929772253}, {
               64.488, 221.929772253}, {63.940999999999995`, 222.402602545}, {
               63.940999999999995`, 222.988463436}, {63.940999999999995`, 
               223.57432432700003`}, {64.488, 224.05060593500002`}, {
               65.16799999999999, 224.05060593500002`}, {65.848, 
               224.05060593500002`}, {66.398, 223.57432432700003`}, {66.398, 
               222.988463436}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{61.48, 222.98800000000003`}, {61.48, 
               222.40200000000002`}, {60.93, 221.93}, {60.25, 221.93}, {
               59.574, 221.93}, {59.023, 222.40200000000002`}, {59.023, 
               222.98800000000003`}, {59.023, 223.57399999999998`}, {59.574, 
               224.05100000000002`}, {60.25, 224.05100000000002`}, {60.93, 
               224.05100000000002`}, {61.48, 223.57399999999998`}, {61.48, 
               222.98800000000003`}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002797843009704614], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{61.48, 222.988463436}, {61.48, 222.402602545}, {60.93,
                221.929772253}, {60.25, 221.929772253}, {59.574, 
               221.929772253}, {59.023, 222.402602545}, {59.023, 
               222.988463436}, {59.023, 223.57432432700003`}, {59.574, 
               224.05060593500002`}, {60.25, 224.05060593500002`}, {60.93, 
               224.05060593500002`}, {61.48, 223.57432432700003`}, {61.48, 
               222.988463436}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{61.48, 226.52700000000002`}, {61.48, 225.941}, {60.93,
                225.465}, {60.25, 225.465}, {59.574, 225.465}, {59.023, 
               225.941}, {59.023, 226.52700000000002`}, {59.023, 
               227.11299999999997`}, {59.574, 227.586}, {60.25, 227.586}, {
               60.93, 227.586}, {61.48, 227.11299999999997`}, {61.48, 
               226.52700000000002`}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002797843009704614], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{61.48, 226.52692516500005`}, {61.48, 225.941064274}, {
               60.93, 225.464782666}, {60.25, 225.464782666}, {59.574, 
               225.464782666}, {59.023, 225.941064274}, {59.023, 
               226.52692516500005`}, {59.023, 227.11364888500003`}, {59.574, 
               227.58561634800003`}, {60.25, 227.58561634800003`}, {60.93, 
               227.58561634800003`}, {61.48, 227.11364888500003`}, {61.48, 
               226.52692516500005`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{57.926, 206.371}, {57.926, 205.785}, {57.355, 
               205.309}, {56.652, 205.309}, {55.949, 205.309}, {55.379, 
               205.785}, {55.379, 206.371}, {55.379, 206.95700000000002`}, {
               55.949, 207.43}, {56.652, 207.43}, {57.355, 207.43}, {57.926, 
               206.95700000000002`}, {57.926, 206.371}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002847359638519521], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{57.926, 206.37114037400002`}, {57.926, 
               205.78548654000002`}, {57.355, 205.308965924}, {56.652, 
               205.308965924}, {55.949, 205.308965924}, {55.379, 
               205.78548654000002`}, {55.379, 206.37114037400002`}, {55.379, 
               206.95679420800002`}, {55.949, 207.429982512}, {56.652, 
               207.429982512}, {57.355, 207.429982512}, {57.926, 
               206.95679420800002`}, {57.926, 206.37114037400002`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{64.715, 206.371}, {64.715, 205.785}, {64.145, 
               205.309}, {63.440999999999995`, 205.309}, {62.73800000000001, 
               205.309}, {62.168000000000006`, 205.785}, {62.168000000000006`,
                206.371}, {62.168000000000006`, 206.95700000000002`}, {
               62.73800000000001, 207.43}, {63.440999999999995`, 207.43}, {
               64.145, 207.43}, {64.715, 206.95700000000002`}, {64.715, 
               206.371}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002847359638519521], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{64.715, 206.37114037400002`}, {64.715, 
               205.78548654000002`}, {64.145, 205.308965924}, {
               63.440999999999995`, 205.308965924}, {62.73800000000001, 
               205.308965924}, {62.168000000000006`, 205.78548654000002`}, {
               62.168000000000006`, 206.37114037400002`}, {
               62.168000000000006`, 206.95679420800002`}, {62.73800000000001, 
               207.429982512}, {63.440999999999995`, 207.429982512}, {64.145, 
               207.429982512}, {64.715, 206.95679420800002`}, {64.715, 
               206.37114037400002`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{57.074, 
               209.19899999999998`}, {63.016, 209.19899999999998`}, {60.047, 
               206.016}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.00028473541666666665`], Opacity[1.], CapForm[
              "Butt"], JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{57.074, 209.199}, {
               63.016, 209.199}, {60.047, 206.01600000000002`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{61.746, 206.72299999999998`}, {61.746, 205.941}, {
               60.983999999999995`, 205.309}, {60.047, 205.309}, {59.109, 
               205.309}, {58.348, 205.941}, {58.348, 206.72299999999998`}, {
               58.348, 207.504}, {59.109, 208.137}, {60.047, 208.137}, {
               60.983999999999995`, 208.137}, {61.746, 207.504}, {61.746, 
               206.72299999999998`}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0003796485856436213], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{61.746, 206.72269929}, {61.746, 
               205.94127212600003`}, {60.983999999999995`, 205.308965924}, {
               60.047, 205.308965924}, {59.109, 205.308965924}, {58.348, 
               205.94127212600003`}, {58.348, 206.72269929}, {58.348, 
               207.50412645400004`}, {59.109, 208.136432656}, {60.047, 
               208.136432656}, {60.983999999999995`, 208.136432656}, {61.746, 
               207.50412645400004`}, {61.746, 206.72269929}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {0,
                1, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{54.004, 
               196.11299999999997`}, {62.137, 196.11299999999997`}, {62.41, 
               196.11299999999997`}, {62.629000000000005`, 195.945}, {
               62.629000000000005`, 195.738}, {62.629000000000005`, 
               194.36700000000002`}, {62.629000000000005`, 194.156}, {62.41, 
               193.99200000000002`}, {62.137, 193.99200000000002`}, {54.004, 
               193.99200000000002`}, {53.730000000000004`, 
               193.99200000000002`}, {53.508, 194.156}, {53.508, 
               194.36700000000002`}, {53.508, 195.738}, {53.508, 195.945}, {
               53.730000000000004`, 196.11299999999997`}, {54.004, 
               196.11299999999997`}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {0,
                1, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{54.004, 
               196.113}, {62.137, 196.113}, {62.41, 196.113}, {
               62.629000000000005`, 195.945}, {62.629000000000005`, 
               195.738}, {62.629000000000005`, 194.367}, {62.629000000000005`,
                194.156}, {62.41, 193.992}, {62.137, 193.992}, {54.004, 
               193.992}, {53.730000000000004`, 193.992}, {53.508, 194.156}, {
               53.508, 194.367}, {53.508, 195.738}, {53.508, 195.945}, {
               53.730000000000004`, 196.113}, {54.004, 196.113}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {0,
                1, 0}, {1, 3, 3}}, {{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
               3}, {0, 1, 0}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgAmJ+KO3SnfP8d2SAw+Ols48o7Mlw2DT3/fJjwgi+Fw+T
dvs2f4dvGjH9hxYi+Itct33+24DgCzcfOLXQF8G/87Mua48Owry3NfamcUIZ
DjD7YPze6XlCzQsQfGn9uypsNwPg+mF8mPkwPsx+GB/mPph5MPej+w/GB2lr
XJrhYLXlRNk+fQQfbA5vgMOqj5d8kyYg+OqGHGtkytDkI9Dk7RDmtb4O3CGn
ibAPxvdLEoiwbEHwQd5yXYbQD+PDzEeRL0OTn4AwD+Z+dP8BAFDw06U=
               
               "]]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {0,
                1, 0}, {1, 3, 3}}, {{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
               3}, {0, 1, 0}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgAmJ+KO3SnfP8d2SAw+Ols48o7Mlw2DT3/fJjwgi+Fw+T
dvs2f4dvGjH9hxYi+Itct33+24DgCzUfOLXQF8G//bMua48Owrx3NfamcUIZ
DjD7YPze6XlCzQsQfGn9uypsNwPg+mF8mPkwPsx+GB/mPph5MPej+w/GB2lr
XJrhYLXlRNk+fQQfbA5vgMOqj5d8kyYg+OqGHGtkytDkI9Dk7RDmtb4O3CGn
ibAPxvdLEoiwbEHwQd5yXYbQD+PDzEeRL0OTn4AwD+Z+dP8BAE+I06Q=
               "],
               CurveClosed->{1, 1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {0,
                1, 0}, {1, 3, 3}}, {{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
               3}, {0, 1, 0}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgAmJ+KM3eONW5u8fb4fbPuqw9GzIcPl3yTRKwQPDbxW6e
+/7Zy8Fqy4myfbMRfP27KmyNjQj+Itdtn//6IPjVIuvcHxohzPumEdN/SDbD
AWYfjC8NMughgi8K1Fal4gPXD+PDzIfxYfbD+DD3wcyDuR/dfzB+/6GvGjHH
MxyKMya+rfnvBedHWAIN6oP6Zw2Cf9zbvNOxB8FXN+RYI+OE4IOkExQR5sXu
8uRhYkfYB+NrAb35VcIHznfpznn+u9MHrh/Gh5kP48Psh/Fh7oOZB3M/uv8A
zm7Z+Q==
               "]]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {0,
                1, 0}, {1, 3, 3}}, {{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
               3}, {0, 1, 0}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgAmJ+KM3eONW5u8fb4fbPuqw9GzIcPl3yTRKwQPDbxW6e
+/7Zy8Fyy4myfbMRfP27KmyNjQj+Itdtn//6IPjVIuvcHxohzPumEdN/SDbD
AWYfjC8NMughgi8K1Fal4gPXD+PDzIfxYfbD+DD3wcyDuR/dfzB+/6GvGjHH
MxyKMya+rfnvBedHgAzqg/pnDYJ/3Nu807EHwVc35Fgj44Tg+wClExQR5sXt
8uRhYkfYB+NrAb35VcIHznfpznn+u9MHrh/Gh5kP48Psh/Fh7oOZB3M/uv8A
zfbZ/A==
               "],
               CurveClosed->{1, 1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {0,
                1, 0}, {1, 3, 3}}, {{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
               3}, {0, 1, 0}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgAmJ+KO3Fw6Td/s3Tgfv64gLbWRkOZnG7PHkWIfh2XEBG
rKdD6+vAHXKtCH61yDr3h1kI/tYTZfvmxyH4qz5e8k1yQZinytY41Vk/wwFm
H4wPkmby9oLzIyy3nCjr84Lrh/Fh5sP4MPthfJj7YObB3I/uPxj/9s+6rD0b
Mhy2ff57pSITwZ99RGFD0Q8Ph7c19qZx0xB8oeYDpxaWIvgga/cFI/hge40R
5hXYAgNCAmEfjH/4q0ZMf5MXnN8udvPc989ecP0wPsx8GB9mP4wPcx/MPJj7
0f0HAM/n1e4=
               "]]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {0,
                1, 0}, {1, 3, 3}}, {{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
               3}, {0, 1, 0}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgAmJ+KO3Fw6Td/s3Tgev64gLbWRkOZnG7PHkWIfh2IEas
p0Pr68Adcq0IfrXIOveHWQj+lhNl++bHIfirPl7yTXJBmKfK1jjVWT/DAWYf
jA+SZvL2gvMjLIEm9XnB9cP4MPNhfJj9MD7MfTDzYO5H9x+Mf/tnXdaeDRkO
2z7/vVKRieDPPqKwoeiHh8O7GnvTuGkIvlDzgVMLSxF8K5CDghF8sL3GCPMK
bIE2SiDsg/EPf9WI6W/ygvPbxW6e+/7ZC64fxoeZD+PD7IfxYe6DmQdzP7r/
AMlX1ew=
               "],
               CurveClosed->{1, 1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {0,
                1, 0}, {1, 3, 3}}, {{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
               3}, {0, 1, 0}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgAmJ+KL3Iddvnv1PcHfTvqrA17sxwmCzBEsb31w3Oz33+
e+XHJjeHm+e+Bz9eiOAX2HJdX9yC4Lt05zz/7YngF4LkdRDmtb4O3CEnmuEA
sw/GB8vresD51xcDTV7uAdcP48PMh/Fh9sP4MPfBzIO5H91/MH61yDr3h5cy
HD5d8k0SmOEG57M3TnXuPuPqkDHxbY39VgQf7J4JCD7YPls09ZII86y2nCjb
9zsdbh+Mbxq3y5Nnkgecbwc0tiDWE64fxoeZD+PD7EdRD3QfzDyY+9H9BwDC
Ud9Y
               "]]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {0,
                1, 0}, {1, 3, 3}}, {{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
               3}, {0, 1, 0}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgAmJ+KL3Iddvnv1PcHfTvqrA17sxwmCzBEsb31w3Oz33+
e+XHJjeHm+e+Bz9eiOAX2nJdX9yC4Lt05zz/7YngF4DkdRDmtb4O3CEnmuEA
sw/GB8vresD51xcDdS73gOuH8WHmw/gw+2F8mPtg5sHcj+4/GL9aZJ37w0sZ
Dp8u+SYJzHCD89kbpzp3n3F1yJj4tsZ+K4IPtm8Cgg+2zxZNvSTCPMstJ8r2
/U6H2wfjm8bt8uSZ5AHn2wGNLYj1hOuH8WHmw/gw+1HUA90HMw/mfnT/AQDA
6d9V
               "],
               CurveClosed->{1, 1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {0,
                1, 0}, {1, 3, 3}}, {{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
               3}, {0, 1, 0}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgAmJ+KC26zv1hlU2QA9f1xQW26zIceqfnCTV/CITzVdka
pzpvDnS4oHT7Z900BD9j4tsa+0oEf+uJsn3z7dDkFRHmfdOI6T/EmeEAsw/G
P+Zt3unYgeDr31VhazwaBNcP48PMR5GvRPBh7oOZB3M/uv9g/P5DXzVijmdA
7N0bCOdbbgFaFB7o4NKd8/z3SgTfB2hsQiuCfxFknxGCv7dksgQLH8I8iL/T
4fbB+HG7PHmYdiP4IY+Xzj6iEAzXD+PDzIfxYfbD+DD3wcyDuR/dfwDn09cI

               "]]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {0,
                1, 0}, {1, 3, 3}}, {{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
               3}, {0, 1, 0}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgAmJ+KC26zv1hlU2QA9f1xQW26zIceqfnCTV/CITzVdka
pzpvDnS4qHT7Z900BD9j4tsa+0oEf8uJsn3z7dDkFRHmfdOI6T/EmeEAsw/G
P+Zt3unYgeDr31VhazwaBNcP48PMR5GvRPBh7oOZB3M/uv9g/P5DXzVijmdA
7N0bCOdbgiwKD3Rw6c55/nslgu8DNDahFcEH22eE4O8pmSzBwocwrw/s73S4
fTB+3C5PHqbdCH7I46WzjygEw/XD+DDzYXyY/TA+zH0w82DuR/cfAOhL1wk=

               "],
               CurveClosed->{1, 1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {0,
                1, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
               66.45700000000001, 196.11299999999997`}, {70.699, 
               196.11299999999997`}, {70.84400000000001, 
               196.11299999999997`}, {70.96100000000001, 195.945}, {
               70.96100000000001, 195.738}, {70.96100000000001, 
               194.36700000000002`}, {70.96100000000001, 194.156}, {
               70.84400000000001, 193.99200000000002`}, {70.699, 
               193.99200000000002`}, {66.45700000000001, 
               193.99200000000002`}, {66.316, 193.99200000000002`}, {66.199, 
               194.156}, {66.199, 194.36700000000002`}, {66.199, 195.738}, {
               66.199, 195.945}, {66.316, 196.11299999999997`}, {
               66.45700000000001, 196.11299999999997`}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {0,
                1, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
               66.45700000000001, 196.113}, {70.699, 196.113}, {
               70.84400000000001, 196.113}, {70.96100000000001, 195.945}, {
               70.96100000000001, 195.738}, {70.96100000000001, 194.367}, {
               70.96100000000001, 194.156}, {70.84400000000001, 193.992}, {
               70.699, 193.992}, {66.45700000000001, 193.992}, {66.316, 
               193.992}, {66.199, 194.156}, {66.199, 194.367}, {66.199, 
               195.738}, {66.199, 195.945}, {66.316, 196.113}, {
               66.45700000000001, 196.113}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {0,
                1, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
               61.992000000000004`, 196.465}, {64.465, 196.465}, {64.551, 
               196.465}, {64.617, 196.242}, {64.617, 195.965}, {64.617, 
               194.137}, {64.617, 193.859}, {64.551, 193.637}, {64.465, 
               193.637}, {61.992000000000004`, 193.637}, {61.906, 193.637}, {
               61.839999999999996`, 193.859}, {61.839999999999996`, 
               194.137}, {61.839999999999996`, 195.965}, {61.839999999999996`,
                196.242}, {61.906, 196.465}, {61.992000000000004`, 
               196.465}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {0,
                1, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
               61.992000000000004`, 196.465}, {64.465, 196.465}, {64.551, 
               196.465}, {64.617, 196.242}, {64.617, 195.965}, {64.617, 
               194.137}, {64.617, 193.859}, {64.551, 193.637}, {64.465, 
               193.637}, {61.992000000000004`, 193.637}, {61.906, 193.637}, {
               61.839999999999996`, 193.859}, {61.839999999999996`, 
               194.137}, {61.839999999999996`, 195.965}, {61.839999999999996`,
                196.242}, {61.906, 196.465}, {61.992000000000004`, 196.465}}},
               
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {0,
                1, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{48.902, 
               196.465}, {51.379, 196.465}, {51.461, 196.465}, {51.527, 
               196.242}, {51.527, 195.965}, {51.527, 194.137}, {51.527, 
               193.859}, {51.461, 193.637}, {51.379, 193.637}, {48.902, 
               193.637}, {48.82, 193.637}, {48.754, 193.859}, {48.754, 
               194.137}, {48.754, 195.965}, {48.754, 196.242}, {48.82, 
               196.465}, {48.902, 196.465}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {0,
                1, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{48.902, 
               196.465}, {51.379, 196.465}, {51.461, 196.465}, {51.527, 
               196.242}, {51.527, 195.965}, {51.527, 194.137}, {51.527, 
               193.859}, {51.461, 193.637}, {51.379, 193.637}, {48.902, 
               193.637}, {48.82, 193.637}, {48.754, 193.859}, {48.754, 
               194.137}, {48.754, 195.965}, {48.754, 196.242}, {48.82, 
               196.465}, {48.902, 196.465}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {0,
                1, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{40.324, 
               196.82000000000002`}, {45.273, 196.82000000000002`}, {
               45.440999999999995`, 196.82000000000002`}, {45.578, 
               196.54299999999998`}, {45.578, 196.195}, {45.578, 193.91}, {
               45.578, 193.562}, {45.440999999999995`, 193.285}, {45.273, 
               193.285}, {40.324, 193.285}, {40.160000000000004`, 193.285}, {
               40.023, 193.562}, {40.023, 193.91}, {40.023, 196.195}, {40.023,
                196.54299999999998`}, {40.160000000000004`, 
               196.82000000000002`}, {40.324, 196.82000000000002`}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {0,
                1, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{40.324, 
               196.82}, {45.273, 196.82}, {45.440999999999995`, 196.82}, {
               45.578, 196.543}, {45.578, 196.195}, {45.578, 193.91}, {45.578,
                193.562}, {45.440999999999995`, 193.285}, {45.273, 193.285}, {
               40.324, 193.285}, {40.160000000000004`, 193.285}, {40.023, 
               193.562}, {40.023, 193.91}, {40.023, 196.195}, {40.023, 
               196.543}, {40.160000000000004`, 196.82}, {40.324, 196.82}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {0,
                1, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{74.809, 
               196.465}, {79.402, 196.465}, {79.559, 196.465}, {79.684, 
               196.184}, {79.684, 195.84}, {79.684, 193.555}, {79.684, 
               193.207}, {79.559, 192.93}, {79.402, 192.93}, {74.809, 
               192.93}, {74.65199999999999, 192.93}, {74.527, 193.207}, {
               74.527, 193.555}, {74.527, 195.84}, {74.527, 196.184}, {
               74.65199999999999, 196.465}, {74.809, 196.465}}}]}, 
             {RGBColor[0.8588240000000001, 0.08627450000000002, 0.105882], 
              Thickness[0.0002752333333333334], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {0,
                1, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{74.809, 
               196.465}, {79.402, 196.465}, {79.559, 196.465}, {79.684, 
               196.184}, {79.684, 195.84}, {79.684, 193.555}, {79.684, 
               193.207}, {79.559, 192.93}, {79.402, 192.93}, {74.809, 
               192.93}, {74.65199999999999, 192.93}, {74.527, 193.207}, {
               74.527, 193.555}, {74.527, 195.84}, {74.527, 196.184}, {
               74.65199999999999, 196.465}, {74.809, 196.465}}},
               CurveClosed->{1}]}},
            AspectRatio->Automatic,
            ImageSize->{{128}, {85}},
            PlotRange->{{0., 480.}, {0., 240.}}], ",", 
           GraphicsBox[
            {Thickness[0.0010416666666666667`], 
             {FaceForm[{RGBColor[1., 0.717647, 0.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0., 
               0.}, {0., 480.}, {960., 480.}, {960., 0.}}}]}, 
             {FaceForm[{RGBColor[1., 0.356863, 0.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{172., 
               440.}, {304., 440.}, {304., 40.}, {172., 40.}}}]}, 
             {FaceForm[{RGBColor[0., 0.3372549999999999, 0.254902], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               40., 440.}, {172., 440.}, {172., 40.}, {40., 40.}}}]}, 
             {FaceForm[{RGBColor[
              0.5529410000000001, 0.12549000000000002`, 0.160784], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               344., 440.}, {924., 440.}, {924., 40.}, {344., 40.}}}]}, 
             {FaceForm[{RGBColor[1., 0.717647, 0.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIpIGYC4g7HhKcX1Lodtn3+e6XiZJQDOj86xfq+f1C3
w0JXoAhLhIOPeadjQlO3g1+SQITlkzAHm/v+vdNPdjv0Ts8TarYIddhyomzf
/OgehzUyUSnW4aEQ+Zk9EPUpwQ6yQOH7j3scLEEKxQMdlhTYcl2f3ONQ+VLN
kEPGx+GC0u2fdVN6HBaB7JviDdE/o8eBAQQSPDD4YPVpPQ57SyZLsIR5OBxV
2FCUEdjjsPKYt3mnooeDfOvrwB2GPQ6Hv2rE9F9yd7jsC3SIao+D/l0VtkZT
N4j/XnU75D7/vfJjkZvDNOfunOeh3Q5TgKbx8bpD+NHdDrOPgAz2h+gL7nZo
PnBqoatbsMOnS0ADfbodLoLcsSgEEn5W3Q4g6x0zwiDuNISG15FwiPs1uh28
eJi0299FYIQ3Oh8AZG64MA==
               "]]}, 
             {Thickness[0.0017714645833333332`], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIpIGYC4g7HhKcX1Lodtnz+e6XiZJQDOj86xfq+f1C3
wxLXbZ//skQ4+Jh3OiY0dTsEJAlEWD4Jc7C57987/WS3Q8/0PKFmi1CHLSfK
9s2P7nFYIxOVYh0eCpGf2QNRnxLsIAsUvv+4x8ECpFA80GFJgS3X9ck9Dg0v
1Qw5ZHwcLijd/lk3pcdhBci+Kd4Q/TN6HBhAIMEDgw9Wn9bjcKBksgRLmIfD
UYUNRRmBPQ4bjnmbdyp6OMi3vg7cYQiU/6oR03/J3eGyL9Ahqj0OBndV2BpN
3SD+e9XtkPH898qPRW4O05y7c56HdjvMAJrGx+sO4UcD+UdABvs76IP0BXc7
tBw4tdDVLdjh0yWggT7dDldA7lgUAgk/q26HE0DrHTPCIO40hIbXkXCI+zW6
HXx4mLTb30VghDc6HwB57rhI
               "],
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 0.717647, 0.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIpIGYC4nc19qZxnyochJsPnFroW+6Azvc273RMmF3h
MD1PqPnAv3KHjIlva+ytKxxynv9e+dGtwgEo+/TCmnIH2agU6/sbKxxmgNR1
lDlcrXipZrgKKs9TBlGvVulwDGRgRanDp0u+SQK7Kh12yLW+DpQoc7igdPtn
XU2VQ+wuTx4m8TKIvb1VDh0g/XxlDgwg8AWTHwdSX1wGcdfXKofyffOl9OeW
OWi1i90897vK4dBXjZj+O2UOHg+rRNaxVjuAnOn/tQxCW1ZD7Mkuh/jXsBri
7ikVDm9B4SAH5XdUOOSC3C9U5bDIddvnvzMqHO77907P06t0kAEZtLwCYs71
Ckj4napw4NPdNPd9agXEnfeg4cVXAXH/O6j5RzDDG50PALzvvic=
               "]]}, 
             {Thickness[0.0017714645833333332`], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIpIGYC4nc19qZxnyochJoPnFroW+6Azvc273RMmF3h
MCMPKPKv3CFj4tsae+sKh5znv1d+dKtwAMo+vbCm3EE2KsX6/kaouo4yh6sV
L9UMV0Hlecog6tUqHY6BDKwodfh0yTdJYFelww651teBEmUOF5Vu/6yrqXKI
3eXJwyRe5uADsre3yqEDpJ+vzIEBBL5g8uNA6ovLIO76WuVQvm++lP7cMgft
drGb535XORz6qhHTf6fMweNhlcg61moHkDP9v5ZBaMtqiP+yyyH+NayGuHtK
BSQc5KD8jgqHXJD7haocFrlu+/x3RoXDff/e6Xl6lQ4yIIOWV0Dcex2q71SF
A5/uprnvUysg7rwHDS++Coj730HVHcEMb3Q+AL5/vik=
               "],
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 0.717647, 0.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIpIGYC4g7HhKcX1LodhJsPnFroW+6Azo9Osb7vH9Tt
MD1PqPnAv3IHH/NOx4Smboec579XfnSrcLC57987/WS3g2wUUOHGCoctJ8r2
zY/ucbha8VLNcBVUfmYPRL1aJUTd4x6HT5d8kwR2VTosKbDluj65x+GC0u2f
dTVVEHpKj4M3yJ7eKoj+GT0ODCDwBZMPVp/W45Ax8W2N/dcqh6MKG4oyAnsc
tNrFbp77XeUg3/o6cIdhj4PHwyqRdazVDpeB1kao9jiAnOFvWQ3x3yuofw2r
HaY5d+c8D+12AJpmGicH5Ud3O+SC3C9U5aB/V4WtMbjbAeSMPL1KiD98uiHu
vV4BCT+rbgc+3U1z36dWQNxpCA0vPmh4aEDNP4IZ3uh8ADOCwEA=
               "]]}, 
             {Thickness[0.0017714645833333332`], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIpIGYC4g7HhKcX1LodhJoPnFroW+6Azo9Osb7vH9Tt
MCMPKPKv3MHHvNMxoanbIef575Uf3SocbO77904/2e0gGwVUuLHCYcuJsn3z
o3scrla8VDNcBZWf2QNRr1YJUfe4x+HTJd8kgV2VDksKbLmuT+5xuKh0+2dd
TZXDBRA9pQdiT28VRP+MHgcGEPiCyQerT+txyJj4tsb+a5XDUYUNRRmBPQ7a
7WI3z/2ucpBvfR24w7DHweNhlcg61mqHy0BrI1R7HEDO8LeshvjvFdS/htUO
05y7c56Hdju8q7E3jZOD8qO7HXJB7heqctC/q8LWGNztAHJGnl4lxB8+3RD3
Xq+AhJ9VtwOf7qa571MrIO40hIYXHzQ8NKDmH8EMb3Q+ADUSwEI=
               "],
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 0.717647, 0.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIpIGYC4nc19qZxnyoctn3+e6XiZJQDOt/bvNMxYXaF
w0JXoAhLhEPGxLc19tYVDn5JAhGWT8IcgLJPL6wpd+idnifUbBHqMANIHego
c1gjE5ViHR4Kkecpg6hPCXY4BjKwotTBcsuJsn3igQ475FpfB0qUOVS+VDPk
kPFxiN3lycMkXuawCGTfFG+HDpB+vjIHBhBI8MDgx4HUF5c57C2ZLMES5uFQ
vm++lP7cMoeVIIsUPRwOfdWI6b9T5nAYRF9ydwC66r7/1zIH/bsqbI2mbhD/
ZZc75D7/vfJjkZvD1QqgQ6ZUOEwBmsbH6w7hd1Q4zD6isKEowx/irhkVDs0H
Ti10dQt2AHnz/vIKh4tKt3/WLQqBhN+pCog/M8Ig7rwHDa8j4RD3v6tw8OJh
0m5/F4ER3uh8AO3bthc=
               "]]}, 
             {Thickness[0.0017714645833333332`], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIpIGYC4nc19qZxnyoctnz+e6XiZJQDOt/bvNMxYXaF
wxLXbZ//skQ4ZEx8W2NvXeEQkCQQYfkkzAEo+/TCmnKHnul5Qs0WoQ4zgNSB
jjKHNTJRKdbhoRB5njKI+pRgh2MgAytKHSy2nCjbJx7osEOu9XWgRJlDw0s1
Qw4ZH4fYXZ48TOJlDitA9k3xdugA6ecrc2AAgQQPDH4cSH1xmcOBkskSLGEe
DuX75kvpzy1z2ACySNHD4dBXjZj+O0B5EH3J3QHoqvv+X8scDO6qsDWaukH8
l13ukPH898qPRW4OVyuADplS4TADaBofrzuE3wHkH1HYUJTh77AI5K4ZFQ4t
B04tdHULdgB58/7yCocrSrd/1i0KgYTfqQqHEyCDM8Ig7rwHDa8j4RD3v6tw
8OFh0m5/F4ER3uh8AANqti8=
               "],
               CurveClosed->{1}]}, 
             {Thickness[0.004633204166666667], FilledCurveBox[{CompressedData["
1:eJxTTMoPSmJiYGDQZ2RgYAbSDEAOIwMjMzOQhDCIRPjVw2WJN5ZIlQSVUa6A
bPVoKqnud2JMINsNBGONoMn4FVArXkhyJIWxQKqbKYxHAMnLCKY=
                "], {{1, 
                4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 
                0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1,
                 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0,
                 1, 0}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1,
                 3, 3}}, {{1, 4, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {0, 1, 
                0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 
                0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0,
                 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 
                0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {
                1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3,
                 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
                0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 
                3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{
                0, 2, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1,
                 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 
                0}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1,
                 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {0, 1, 0}, {
                0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {0,
                 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{
                1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 
                0}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1,
                 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 
                3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {
                1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3,
                 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 
                3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 
                3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 
                3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0,
                 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}}}, {CompressedData["
1:eJxdW3mcT+UaH0v2O8mSJblZwkXkhgm58wppoYT8fsxqFmMs8zu/ddDiLL/l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                "], CompressedData["
1:eJxdVn9MlVUYvlErhsQynQNaJmSNQoP+YGry4yUqRswRtgxDrkYQrtn1O59O
r2XZPae7m2tpyIxWmXlTzDBWJkiuQQNDsVYUmBVzIv1gXQrQrOUs1znnfeRr
sbFvz33PeX887/O+35dWvXpxbZzP56vX/+Z57utF1deVKdrz+pFZ7x9x6DJe
cPDYuo5Bh1bW/7axYK6iH8yBVEE+8zdF0djGghz/3YLPT0hKmntgx/ijgsy1
naOSnhy5uO9staCuPzKWbdU4PFrePrNEUNvv/wwENbb30gU98fHahuTvJd0e
mfHdF52I1+9hnZW78ksP32Qc9UryHy5JjOt3aOHpspcaeyQN6Ucg5lDWqdlX
h7qRzxWI1ybpRPCXW+/MFtRq8tsnOU65oOGnprcUb5P0SI3xJLjO5yRNU58c
3/WQoPUdO1OzVku6yxSWJmi3k5dwslySuXZmzKHNhSt+6rvHw02Gx0IP2/o0
Plo6b3NhAvIpknS98Z8paINOK/4+SdeafMuAtb/GgD6xSpCuMjOSLzmPNYLy
E06+7SwAnxsEnTGBciQ1JF+1JGm9h20fAv+zV8JfouS+XHLolaIXV41c6WGT
5gqfhy3/F0N8P0XQjYaov0KUZ/MQNKDbWPFniDJNf5ZCD+dwXvNpeR0PMd/N
gnJNv34NcZ96BfvX56P3amYOChrf21M67+8Q8/0M/CWhXynoX5qkvvTBC88u
wf056G8Q93OgvzcE39O4xxT2jofNtfoPBdc/H/W2C+o39eRJ5kHbXzV9KIT/
FsG6KoYewuhXqWQ+dP3GvPcBSU+b/scLCpq+PS5ZV/Nx3oX+F8PfJsk6Wgt7
GPHDuL8F/qKC53QLzkehx7ckz+XzuN8sOW8X5w8jvxLMZzf4yEA/PpdUZebp
GszjCUntM7XCtH4tL99gPs467P9b2M87/Psg+jED+jiF/PPQnyHEq0E+w5J1
rOvbbvgfhr4jmLcfUd/LgqZW6E10s2L+86GnhYrjTxdc1/2K411w+HyF4vkY
cVgPldhnow73p0qRUYF/wqE5Bi9X3I9kMYltX4o8bPl9AfwuUzzPr0FvxYrz
6MS8ZcEeA993KPrK8BNDPbcorvMzQZWmnlRF3YbnKOyJiPcfbPVz3MO23hHM
82nsj4ddtvd72O7LPg/bfI+C7wKX8+uQPH+zXK6vDfqJg7/90GsM+ngXeo5h
n70pJ+s1bWn3SzKyCgRd3mN+3N/mYauXJpd/fwzzvculCZNfAPltctnfOthr
XdZPBPst3+U+NcB+G+rdj3m4JBi3Il68y/3plKzTStTbhX28Bvn1YB4iLuuw
18NWzwMetvtjCvQ2FflOU5N82fm5QbGfLkHZZu+lob9j2C8Zip/pLj+zFecx
2+V9lKvYz3nMR6FifofQj6WK+WgTdMj0Qyjeb43Qyw7obTnmr0mxHrTdvj+b
kf8h7NsDivVwDP5bMT+d2L8fKebvA9hbMC8PCvrUBN6jqNgQXQD7bnxf5KIf
2xXP/yLkG1a832qwD+uQ/1bBvNUh/yLoqw75puB9WKv4ffuzw3GqMY/92E9V
iPee931jeY56+PL3z7/RviXx
                "], CompressedData["
1:eJxNVGtIFVEQvghJSJaZRNjLykyysJISNXO0h5SaFP2w0BRLEjG7OItdNQrP
wVRCzIJUTMxXIkRImNrLxExFKKSMKLKLRNjLTEVIQuqMMz9aWA6ze84332N2
16WeO5rmYrPZDpib1tyvftsXZiuYehWX6uGHEBtcEpkSrsBG10Wpdyr41FTd
63MN4eAil4CiXQo2Fy1/9/IRwtKEkLaBYAVvHAboC8JEc19McJiCGDr3RGqD
17mm8PuRRoT08vELETEKiiNTPg8Z/MVb79VMJCo431XrHXhK9ucrfh6EUEL7
ShUkPTSdk5F5ViogOq05CM9m/BPLbinI97obPWr4rTVtOk29THcP1tUgJJb1
zPjXKQggvg+QzzUoCHd722DvQHht4BL6Ffi0ZqeX5yLM+zGmGDdK9Jq6nwRF
Cf8fwi8NYdWJ02HOnwpC2wZyunJFz7joqUVw0PpNQf3+9um5TtHjFL9tFjTa
DZNRBZVZnrrbzYJD1G9SgTvhOIXfrPAZFPwFGpzxpRVZdxA6pueGHe6a9d9E
CKMX3pr1FiD0krCVmvNRCEQ33kdDBfUzeWQ8tq6v2KChh/ANvz3ky0YNZ8f+
tEx+QNg24utaYOr5dQbhvpFZa+r5eVhvwS/KK0pz3qMIN/ZeyRxL1KyzUfgn
az5XjxBIOGc0+/8UYTTPEM8UPUNS2zX7PCvn7cLf2+JzduG/z+I8szXjxlus
x6FZZ4TFPAs09BFBXwsayO88zX6+R0ii+cjQEEL5VUteJzXjZiG0k7+HNUQT
MZPnMPEJ1TzPHxG2mDiag6TfCDIvP83zUIXsq8ljNW04jkCPaz01z8Mx2e8q
fl6W+f6reH8Twm4yZk6+x3qZ59+K/UmW/KZkvryQ5+iF4hzjEJ5T/i0y/4WC
X6XgNulLkfqqYn9ipV+xvN+B7HexzOMmZJ6mntflgZz7JfkfLBG8//4n/wAn
LwFL
                "], {{648.8359999999999, 326.855}, {646.438, 
                329.01599999999996`}, {644.7850000000001, 331.074}, {645.164, 
                331.43399999999997`}, {645.543, 331.79299999999995`}, {
                645.9689999999999, 331.895}, {646.113, 331.66}, {646.254, 
                331.42999999999995`}, {648.215, 329.367}, {650.4649999999999, 
                327.082}, {655.6519999999999, 321.82}, {654.586, 321.672}, {
                648.8359999999999, 326.855}}, CompressedData["
1:eJxdVGtIVEEY3RYTMZNNIkVcsyWyB6VFYGLSMRWTCKkfISolS8JSZEvcqS2k
mLmEKISIhVGE1VaSREhtJhEWPVT6IZI9aM2sNOxBmaaklNTMnW9bcGG5fHNn
znfO+c7cJe4DOyrsNpstX/7Vs+3nzHPfS44r5x6ntH43YFO/JxzOkj1Zg06G
H82dWzM6OU583d6enM2QHf3K7+3nkKs1OV4GR3FmoPsLx+GOpsS00ww1OeUf
e8c4utT7swwbB4tONsYIfa6BYYHa7xRoSIjYGVvH0FgZZz7YLHBV9Q/h7RKY
v/rm+dEihiFF7LjQz5WEd0HgjDrnYCiMsa+qvivwTi5XRjNUL3rd86tX4FK+
VBbB0LfN7SgeEtg/8vvamD1cW/rmhmuLdxTT+oNC60llCHQf6mjqIf6FDA8n
l5fV3RK4rdalPsu/gICCK/LT+T7Sc5ChVK2PE1+QP/Gm1rOO8PaZ8NR/q9qU
QXinTGx5f3ThjUyGxcr4KlPz8JDeUlP728I0bgXhtTKorp5aE72u/uljXvL7
uqn7ric9LYSXzvBBtilwm3jh+7xsrYvwc02MP5PGJNG8XYSXQv5GUr2G4bJX
7hgQUHTKc5nW8YbmK+sjEjZqWCBtYGkkTyX8TwKS9dOL8eTHKPkp52f5PhGu
rXlPzXr/R+CR8s0eri0fpoz/tZWHoKF5+YnPpIFYlSuf0PpCeuKF9lNQHucR
Xi3Tc5zg2p8q0jvCtd8GnQ9yKJqVZaQvdJ/yyP8ujnSlP9T/L9f5vmNg7z2j
IUH2t9ZnDO2HvB9WvzjyM4nyn0LzcFBeNzComBTYyJ8S6jeH8rqbIUsRk/gq
FvXyPln9UgXak2Ww8si/FdR/2tD3L1Fo/m8NnY9owrtvQG1rHqb7321g9vfj
H3Wl+0g=
                "], CompressedData["
1:eJxTTMoPSmViYGAQBmIQbct1fXFBSLPDTrnW14GbSh2iUqzv+3s0Q+iTpQ6d
jglPLwQ2O+Q8/73y47lSh/J986X0O5odckH8C6UOYP2nmx3076qwNV4udXhY
JbLO/UuzgyzIgJelDts+/71SodLiMD1PqPmAWplD1p6SyRLeLRD14WUOh79q
xPSHtkDU+5Y5THPuznlu0AKxX7oMop+/xSFj4tsa+7dQ991udrDacqJsH9B9
7WI3z31fAXXfvlIHm/v+vdMnNDt4gByyE+r+kmaHB0DhPKD/3i8/5m2e3Qxx
z7pSB91Nc98vT2x2APp+h9zqUocjChuKMsKh8mug/kMKHwAzJJYO
                
                "], CompressedData["
1:eJxdVGtIFFEU3raIkpAeIpFWJoE9FNMyk7Q9lmJlKho5s45uu+O+lDJ7kFEm
Rtw7SYlJ5QMpMzMpRCKWEPOFlmlBiAYSi4hZ9qMiI7IkpO7dc3GhgdmZs/fc
73znO9+dDeqJDJtep9MlsZs/8zvO3FhdRUDHr20yFHXVrwl3EaguWHm555UM
seNp5dUD3vWRFHW5PEkgfGzj4ks2CZrqngc91lPYd/XYpz95ErDolDOQQhpL
i4mVwTVwtqs+hMJfflXLsJ58Tm+LoHDaWfm1eFSGK/Hmj0ORFJ7+mHt7blCG
Kg60ncKX9LZ15JmId4n8Ihl8w57c/hZHwWe0sTAuUoaJ836tSQkUTO0Hlund
EvJLpzA1FOyebZUw30nhoiHK1N4gwaHosngzEfUqJeyrXOA3S5Bl3T2eViPw
t8iwQo5xDTRR6GQyLeqXIZnv76Mwsym7ojdMRhw/DdyzJfkd1zIhlJVrNmi4
f68McfwlQIMALthDBest1UDzf/fmV24OTHIBV2lwL5EhZZuAdbFVS9XgJS+0
3wy9P1khhwZcpuBuM3jmVawhnz2W+TgkYklLoOqN1/JG6izIr0iDI1yIRgvk
VDDETFHvrgXyWNuGnRqw3yjTHQvqHaohrxYLPgNFvRkLlHEiOtFfgYr96TXs
67eKfQUJPa7n4jxiNLjAxjThY0V+vqK/UisoXO8ZCt3MdmM9VvTPawqrmPsa
jDb0YSvFfkZsuF4g5jNlR37hFB59H05RnQ70o5sAY3F4kjhwfyNBvFoH3C/k
jAnmT9uRL4s9eP52OMj17yRQzjcm2HDeCylwexgmchEvg6KPUlT0i0yhhv/v
q+K5UIQ/5o7CdHN/crSJIl5pNuIkCf7DCnCbljD/e/TaoWA/m0V+kILzmiLo
3wUK1n1AIJXL+iELda8leP4Gs+A9Pw+UYJ3ELHjB9TpOoIHP+6YR8+1iPcqI
+psIJPD98TLqYxT4Lgn9rIjzfkvCeTu9sQfvpDfu434lZP48/v99+Qe+3O82

                "], CompressedData["
1:eJxdVGtIlEEU3SKyLKWHRQ8TszJ7qohEmXmzRDPDHuqPqNhvx91ZNEsyCuyb
AemlQpmFJGlIWdFDxR5GVFZU9ISwB2RYbGbij7DSUjExmpk77RctLLuHuXPP
PefeudMd29c7h9psts3iK383ZsZ4Ut8ymB05oibwhB0iPswcXtDO4NDxbeP2
3rPDsUnDMvy7GHSacdFbflt48bUnu+7MMLz48epFRcs3GZDUmh9QN8ggdHhB
2YpsA+NiONytmhL+wTQwzwGOfEcNuN8TtqkkjUO45G01INb3bXXuZA5L5L04
B9jkJ4CDTG8vckDb2YqHwUk6vkifmxb2X3Dl5LfXHFJkfI8DlL5WDvu/rLsR
lEAwroPDKEETm0VAiHx2qk3zVRBoCmnp5806voEg7y0OGTJxHwEZVrWPw3h5
r5PASxmfz7GOMwSC63e4S7drvWkE3KVC8WYOuVKYwHMPTnz3IopDvL29KaSa
wDKpt4chz+RMzPOTwbsXfRva/JyQ0zFwoSuCw6WuV2sclU7kXcMhTyb2OPGe
wNOk0DYnlMu2hen657jQzyEc0mX9eS70Q/R3luyPD8V6+hj6MZd6+6f8i6ag
xiCQw2H5Zz6FPQF1ia1LOfo0kcID2b8sjvn6XNhP0Q91r9eF9ZVwuCjrD6Bw
I0hU9oSjvhwKDdLPYg6nE67/GPxI0a9w7fdjiv766n42Uqx/gHnPu0XaMb0M
egXt/U6Nuxnm9XWjLy8Z8ke4UV8tQ5/i3ejvVgY7JDFxoy6Bt9xcNXroP1jV
O9LCag7PU9S7luEclVHs/1TN94Zi/HcTSmSgjxt9eWTivHmoF6u+77Ow0r2Q
YlyXCY+kkcMo5Ev/l+n36q/15mv9EyjGmRo3uvB8JYMjkj/OBYlS/9/6PjsR
x2hc6MT3nK3fs82Jc0QZNO4UJ0GZ6H8UwzmsJXBO2FDvy/BdpRPkE3qVP5UE
8z03QY5h7G8CnlSxWcpN3AviPan5KTbR7xKC81pgwle5J5IJ9qdQn88j+L6v
6nyfHCCmor2pycQ5u+zA+F+mdx+ofoxlXqzqXmVhxZfIcO4iHbD7jni4flp/
s4F99Zg4T2JfKX2hDN7386zbYp8p/hQGLRLnGt75UP3ZaOFX8jfZwiqfv4F+
ntT+p9nxHdRYWPFdt7Dy86nev3l2+H9//wHKOZ9v
                "], CompressedData["
1:eJxNVWtsFFUYbRpDGi0E26YhgstDRSwh5WVMRfCIBVQkaAlo5BHS3YGZO1Mo
FUoVvDMbIg8JtBUNAsHyEBOThodKKWhaUgoFf/CQWm1lgaaxlSglUG1jGhLv
d7/LLJtsJmfn3u873znn3h1ZuLLASk1JSSlUX3o6lbfXv1wT4OO/3q6NHI9C
45YACwaN+3ZvVxSvp6eO3TQ0jkd/PVg89edYiDsO7WkckW6FWO16fknEQuOI
oyV2WhxXRv3+nyyx8MGt0RPS7gZYfEqtbLLw5HuxKTfqAxyYUdNzv2wZ3nxh
yytLPwlQPFV1+Go511sf8Lp5Nugxd02AZwbEP3/1iM31Cwy/2Q7zuOkz/wsC
3cSjTaK+6oncRKMHr6v/m7vbJY6fL62r+tLDNBrEksjccPqn/Vs8qO5/XJ4o
MYwarfVwY+62nSsikvsprPv3f8Tzl3qgtncUfnZCWvWwEo/r5ki0Xuyb1/Gc
x7wXmvoJl+fcJ/EY7c8x+zskz7vaQ21EMe+UzH+Nh4Z/xywq75awyYc8D7NJ
nx7J/bM9FNE8f5r6rS7zbZHcp9rFZdK9UaJXlWmIuzhJ9U9JqF/Fj2+5yPte
Ea6XrBtcrK1TQp2VqKDGuS7z+05i+84VGRvSXRDN4l2S/bwnmK8t2e8GgV/K
lMEzJc/9lGB+XhJrXcuTWOt9zfBrF9zvqkT+VuXUSJfnvSSxLuvwrPbpLsju
yiuGf8zl/b8ZvYpcEM3TvRJNtLHC5X3/SExXy0b1i1Af7c8xEepDMlRtFKE+
GaTnfBHqo/OTL0J9zlH9ySLUR/N8XIT6lJN+fQ7XVfqUkIFNJp9KnzbiP8a8
95JY8/40iXX9hOR8XXc4D80P9BGY1f5h1uFLhu8MEeqTm3h6QNwRoT56/SrB
ufj7Qd6NH30SKfTJEthM6ztNPtscvEb1EyYPPzgYuym79WLC5LHSwY4hjywY
1CXxIg2y0kEOve8z52WSE9bTPtTZGEjzNEl8QT7ttvG1kuOo0ns0rd9q8zxn
JK7R/J7N+ncYP1+y+Znhsx69y9n3TJ/rdSexnrN2WYj1+hqLczrEZ37vW5zX
8T6fp5kW83zDx3wSPtNiv+f47N9DWOuVn8T0SJRZ7MM6n/U9abF++5NY169O
4iV0D/b4Jt8WIppwwOfhWAyLKEj5Ad4hPsNjuDqncPC7bsD5OhjlvJUG7M+e
KE703G8uiwfMd0cUZykQ2wKjbxTanoqA+W429/lnAZ+DjVG+3w4FfG/uNvf/
Q/8H/wPhWdiy
                "], {{484.76599999999996`, 196.805}, {
                484.76599999999996`, 199.41}, {479.387, 202.195}, {472.953, 
                202.918}, {467.758, 203.5}, {467.672, 203.465}, {467.672, 
                200.871}, {467.672, 198.72299999999998`}, {
                468.48799999999994`, 197.879}, {472.074, 196.316}, {
                477.83599999999996`, 193.809}, {484.76599999999996`, 
                194.07399999999998`}, {484.76599999999996`, 196.805}}, {{
                490.66400000000004`, 197.04299999999998`}, {493.289, 
                199.42200000000003`}, {494.53099999999995`, 202.254}, {
                492.953, 202.254}, {491.137, 202.254}, {486.32, 197.93}, {
                486.32, 196.30100000000002`}, {486.32, 193.758}, {487.215, 
                193.91}, {490.66400000000004`, 197.04299999999998`}}, {{
                485.07, 204.75}, {485.29299999999995`, 206.22299999999998`}, {
                484.383, 207.20299999999997`}, {481.65200000000004`, 
                208.43800000000002`}, {475.77, 211.094}, {468.734, 212.324}, {
                467.039, 210.99200000000002`}, {463.91799999999995`, 
                208.539}, {465.9959999999999, 205.24599999999998`}, {471.039, 
                204.65200000000002`}, {473.07, 204.414}, {475.824, 203.797}, {
                477.16, 203.277}, {481.03499999999997`, 
                201.77299999999997`}, {484.72299999999996`, 
                202.45700000000002`}, {485.07, 204.75}}, {{485.07, 
                212.63299999999998`}, {485.387, 214.73}, {484.043, 
                215.48000000000002`}, {473.08599999999996`, 219.34}, {
                464.90599999999995`, 222.21899999999997`}, {
                461.28499999999997`, 220.859}, {463.89799999999997`, 
                215.895}, {464.809, 214.164}, {466.34000000000003`, 
                213.375}, {469.76599999999996`, 212.859}, {472.316, 
                212.477}, {475.801, 211.73}, {477.508, 211.19899999999998`}, {
                482.074, 209.781}, {484.715, 210.281}, {485.07, 
                212.63299999999998`}}, {{490.562, 220.02}, {492.215, 
                221.695}, {493.566, 223.672}, {493.566, 224.414}, {493.566, 
                226.816}, {487.039, 222.562}, {486.207, 219.617}, {485.207, 
                216.08200000000002`}, {486.824, 216.23}, {490.562, 
                220.02}}, {{485.074, 220.516}, {485.43399999999997`, 
                222.906}, {481.457, 225.062}, {473.637, 
                226.72299999999998`}, {467.902, 227.941}, {465.371, 227.25}, {
                465.801, 224.586}, {466.03499999999997`, 223.129}, {467.945, 
                222.066}, {473.367, 220.375}, {482.039, 217.668}, {484.648, 
                217.69899999999998`}, {485.074, 220.516}}, CompressedData["
1:eJxTTMoPSmViYGCQB2IQrX9Xha3xdJ1DgS3X9cVfchy02sVunsuud+g/9FUj
pjnXweNhlci6ynoHNbbGqc6v8xwuKt3+WfeozuGbRkz/Ic98B8stJ8r2La5z
WOS67fPfgnwHd5D66joH2agU6/vRUH5ynQOQdH/Ilu+QMfFtjX0gVP/RPAfF
DUUZE2PrHCaA7PPPc5ieJ9R8oAzBB6uvR/CvVrxUM2yrc/A273RMsETwtwKd
MV8OwRduPnBq4cJcB5C3CibWQtyXkeswWYIljE+31mEGyJ5zuQ5WIPdz1kL8
9SnX4YF/7/S8XzVw+8D+E6+F88HhoYvgV4P8ZVPrcPPc9+DHa6HyhrUOQNOy
9nzIc3hXY28ap1QLCQ/vfIcLIHu+1DgUgzyWnQ8R31gDCX+PfAchkLulaxxc
unOe//6ZB4kP+RqHffOl9O/OyHUA+vrphR01DnG7PHmYmHMdjoECwqzW4fHS
2UcUOnIcQMb5e9Y5FILMa8hxQI9fAIGY6Mg=
                "], CompressedData["
1:eJxTTMoPSmViYGBQAmIQbbnlRNm+9DqH1teBO+Q48xwmS7CE8RXWOczIE2o+
IJXnsMh12+e/OXUO3zRi+g+Z5jnYcV1fXBBb5wCibP3yHLzNOx0TrOscwOY0
5zmU75svpW9b51CUMfFtzeU8h8NfgRqToObp5TuAlM2vq3NQZWuc6lyc73C1
4qWaYRPU/Jv5DlrtYjfPddc5yEalWN//WOhwQen2z7o5dQ65z3+v/JhT6jAd
ZM49qHu5Kxw+XfJNEjCrd+DT3TT3/eoKB6Brnl6IgPJfV0Do4HqIPW8qHB4v
nX1E4VcdxJ/rKxze1tibxrXVOeyQA5qYUOFwDOQhvToHK5BDf5ZD9D2odYjd
5cnDlF4Osd+n1kEb5M7AMgeFDUCfStZCwulOCZwPdt/BQjj/Esgfv6D+l6mF
2NOSD7HfrBYSHvr5Dh0g9/vVOlwEqb+XB3FvQK0DkJe150CeQw4oHOyg5mXl
QcLLuBYSvkZ5EPfp1TqAgt/+b66D+8MqkXVAeXB4fs6F2B9S6wBUdWrh1lyI
/S51DuqGHGtkjuU6oKcHAMJ3/wg=
                "], CompressedData["
1:eJxTTMoPSmViYGCQA2IQfVRhQ1HG1UaHY97mnY5hRQ7TnLtznl9vdODT3TT3
fWyRwxXfJIGIS40O0/OEmg+0FDl8ugQUONnocOirRkz/miIIvavRYeuJsn3z
XxU5zACp29LoUC2yzv3hlyKHrD0lkyUWIPi2XNcXF8Qj+J48TNrt3xscls4+
orBBr9gB5IyEngaHqxUv1Qz7ih0uKN3+WefXABE/WuzwGKTQsgHijkvFDvKt
rwN3GDY4MIDAkWIHgQjLLSfkGiDqFhQ7ZE58W2Nv1+AQtwtok3exQ7vYzXPf
8xog/pUrdqjYN19Kf1YDxB/fihwqgdZyCDc6aIMUHi1yiO0Hyngh+GBzsxB8
magU6/tAfu7z3ys/HipyWAbyR0Sjww45oMP6ihxA0v7ejQ7AUDm1ML3IYdvn
v1cq8hsdrLYAAyy1COKvZmj4phQ5LC4AhtC8Roi/44og9JpGB15QfIRD3Xeh
0aHDMeHpBTeofiQ+enwCAHk04P4=
                "]}]}, 
             {Thickness[0.004633204166666667], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], JoinedCurveBox[{CompressedData["
1:eJxTTMoPSmJiYGDQZ2RgYAbSDEAOIwMjMzOQhDCIRPjVw2WJN5ZIlQSVUa6A
bPVoKqnud2JMINsNBGONoMn4FVArXkhyJIWxQKqbKYxHAMnLCKY=
                "], {{1, 
                4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 
                0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1,
                 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0,
                 1, 0}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1,
                 3, 3}}, {{1, 4, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {0, 1, 
                0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 
                0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0,
                 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 
                0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {
                1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3,
                 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
                0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 
                3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{
                0, 2, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1,
                 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 
                0}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1,
                 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {0, 1, 0}, {
                0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {0,
                 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{
                1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 
                0}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1,
                 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 
                3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {
                1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3,
                 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 
                3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 
                3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 
                3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0,
                 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}}}, {CompressedData["
1:eJxdW3mcTlUfH0v2d5IlS/LawovIGybkdWRJRQl5HmY1Zox1nvusgxbPvffZ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                "], CompressedData["
1:eJxdVn9MlVUYvlErhoxlOgdU5iVrFBr0B0uTHy9REZojbBmGohGEawy/8+nw
2i+753R3s1aGZrTKzJtihjEzQXINGhiKtbIuacWcQD9YlwI0aznLdc55H/la
bOzb+51z3vO8z/O87/38lasWVcf5fL4G/W+eZ75eWHlliaKmNw7N2HvIoYvx
7fuP1Hf0O7Sy4bcn82cr+mGn3pAqyGf+JinSb7Mr7hC8f1xS0ux9W8ceFmSO
bRuRVDt8fvfpSkFdf6Qv3ajj0Ehp+/RiQW2//9MX0LE9lybosY/XbE7+XlJG
eNp3X3TivqgXa1Tuyi+9+DqTqFdSxcHixLioQ/NOlbzY2CPJPOpiDmWenHl5
sBt4LsF9bZL6Ar/ceGuWoFaDb7fke0oFDT0+taVok6SHqkwmwXU+I+kq9cnR
7Q8IWtuxLTVzlaS5pjC/oB1ObsKJUklP6GODow5tKFjx07E7vdjyWODFtj4d
9yy4bUNBAvAUSppi8mcIWqdhxd8NvCWIdb7X6jSCWkG6yoxwnqR6g2O1oLyE
E+84c8HnOkGDBn+2pFeSL1uctNaLrQ51/1svR75EybpccOjVwhdqhy/1YgNz
hc+LLf/ng3w+RdC1hqi/gsAhqE/LWPZnkG42+iyBH85gv+bT8joWZL6bBeUY
oX4Nsk69gvPr/ZG7NDP7BY3t0kz9HWT/PYV8SdArBfr5JX2V1n/u6cU4Pwv6
BnA+G/57U/C5bPD/rhf79bGGDwXXPwf1tguKmnpyJd1reNDrVget33GTv0Ww
TkWS8YWg1wLJfOj6zfKu+6B/vKCA0e1Ryb6ag/0u/L8I+dZLet74aA3WQ7g/
hPMvSTIyDkYEmTR7dWx9F4Ef35bcl8/ifLOkRoPbxf6DwFeM/uwGH+nQ43P0
0xXox28ktU/XDtP+tbwcR3+cdjj/t1g/6/D7fugxDf44Cfy50GdA0mFzXxXw
DAGPrm+L4X8I/g6j334EHy8LmlymO+96xfznwU/zFN8/VVCuyTNf8X3nHN5f
prg/hh32Qznm2YjD+ixTNGrm17hDs0y8XLEeyWIitroUerHl9znwu1Qxf6/D
b0WK6+lEv2ViPQa+b1HMTwz13KC43s8ElZt6UhXzHMF6Iu77T2z9c9SLbb3D
6OdTmB8Purwe9WI7L495scV7GHznu4yvQ3L/zXC5vjb4Jw759sCvMfjjPfg5
hnn2lpyo18jSXiFpwMzjgMt5KnB+kxdbPppcfv8I+nu7S+MGXx3wrXc5Xz3W
q132TxjzLc/lujZj/SbUuwf9cEFw3Ir74l3Wp1PSNcZI5ai3C/N4NfD1oB/C
LvdZrxdbP/d5sZ0fk+C3ycA7RU3wZXW9WnGeLkFZZu75oe8o5ku64nvTXI6z
FD9nujyPchR1mzxn0R8FivkdgB5LFPPRJuiA0UMoMjAbGuGXrfDbcvRfE/yt
1+3vZzPwH8C83afYD0eQvxX904n5+5Fi/j7Aegvy3S/oU3PxTkX3GKLzsb4D
3xc50GML+mUh8IYUz8sqzMMa4N8omLca4C+Ev2qANwW/h9U4/7PD9VUifxTz
aRni973vG8t3xIsvfv/8C0mFJgw=
                "], CompressedData["
1:eJxNVGtIVEEUXoQkpIeJRNjLykyysJKSNPPT3plJ0Q+LTRdLEhFbPBfxEYUz
mFqIWZCKiflKhAiJUntZmGUIhZQhRbYtFfYyUxGSkJrZOT+6cBnO3plzvtfs
stSTB9O8bDbbTvXqNe9r8PqZ2QLjLxNSfYMJ+yJKYx3RAjb9nOZ6o8DH5pqe
wIuEPbO8Qos3CYQWz3/z4h5hXtLmW88iBAZyVaMvhNGWp/ERUcKce8C16te5
pOj7gSZCesXIqZh4gXOxjs/9qv+ctTdrR+0COV11AWHHeH+BML+HE0r1vjKB
5LtqcgoZnFUC1xScthzC48kQe/lVgXz/G7vcCt9SNaZT1X7yUV99LcFe3j0Z
Ui+wWuO9Q9A02hoFtvoMNjo7CK9Uu6RegcC27PSKPIJHj2GBbt03jvmqWqEq
jY1j/D8YXxph0ZHjUa6fAkqFnK485jPCfOoIuXr9JtCwo31iupP5uFhvm4Um
Z7TPoFugMksh9rGwV88b4/4uxjfFePq4/wyJD4lllVnXCR0T0wO5syUKNP8r
hCiX+hAgDd9CQo8mtlDitfZHEDTcxECJKj1P+ZFx37q0YIU0/RU+jy4rJTKH
/7SOvSOsGwryLlR1mF4nCbcVzTpVe/Kw3MIv7VecNH67CZe3nc8ctkvjbxPj
T5HQ8tQ1kOlzQpo5DwlubVwm8+nn2imNzlN83sn4AyxE63NOxr/dMn5mM75E
y/DJlYZnjGVwFkr0av+CLDRqvfOZ71vCUZ2PDIlIDbCG/UqWJl9ZhHat736J
3RqY8nNA44mUJs/vCWuUHS3hPG+IjI/B0uShmswc5YcnJ4fJ6OAnTR4O8X5v
iU8a51nO91+BxXp/M2GL9nOa72MD5/m3MPqksH/jnC9/Mro853wnEJ5o/1v5
vhZx/2q+Pw6uLwijzz6eV8LfN5DRu4TzuIqMniWcR1+CPuY4w/3ncr///k/+
ASkHAVA=
                "], {{648.8359999999999, 326.855}, {646.438, 
                329.01599999999996`}, {644.7850000000001, 
                331.07399999999996`}, {645.164, 331.43399999999997`}, {
                645.543, 331.793}, {645.9689999999999, 331.895}, {646.113, 
                331.65999999999997`}, {646.254, 331.43}, {648.215, 329.367}, {
                650.4649999999999, 327.082}, {655.6519999999999, 321.82}, {
                654.586, 321.67199999999997`}, {648.8359999999999, 
                326.855}}, CompressedData["
1:eJxdVG1Ik1EUXsNETGRJNBG1JdH6oKwITMx6TMWkQupHiEoNSRgVNuLespDi
vS8hDkJEwyiij1WSREiNkoiKKBv9EMs+aGZWGvZBmaaklNS97z1r4GDcnfvx
nPM85zmbX7lvW5XdZrMVyq9ab/6cel7z0sDl0w9d7d8ZbOrzyEBa2a6c/jSO
H62dm7I6DRz7urUjPZcjN/5VwNdrQO7W5/k4HKXZwdAXAwfvnk3JPMFRn+f5
2D1C56c41vaXHG9JEFin3jVxzFb30wSak2O2JzZwtFQnmfc3CJ0/grdDIHHZ
9TPDJRwDl+TBUaHXJYR3TuCkeufgKE6wL627LaC2q+M56ua+7vrVLXChUDKL
4ejZUukoHRDYO/T7yog9Glv8ZkZjv6o7jmv+YYEDio+bIxiSv7qo/mKOB+OL
KhpuCL0v+Vn6BQUUXEmA3vcQn/0c5Wp/lOoF6eM0NZ9VhLfHhLfxW+36LMJr
NrHx/eE517I55inha02dz0t8y02tbxvXuFWE186hsnr9Jp5m9E4e8ZHeV03N
bzXxaSO8FRwfZJqiShMvaj4vXJlB+PkmRp9JYVKp3xmE5yJ9YyleznHRJ2/0
CWyW5Xjyuebxhvor40MSNm5QILNvQazhJvxPArLqJ+edpMcw6Sn7Z/loLBpb
/Z6Ydv5HaN3s0djSYYL9jy0/hBmUTJ4A1TPOtK9qhOYX4eMUWk9Bfpwl9Orn
uo9jhtanlvgOGRhUejN6HzbwTuWrIH6ReSog/R8bmn8k/19Dr7cYdt9hTclO
8vsU03rI+bDyJZGeqeR/F/XDQX5dw6FsUmQjfcoo3wzy606OHCWExFe2aJTz
ZOVzC3SkS2MVkH6LKf8k0/OXQv59y7Q/4gnvHoO61jpI8x1imP7/8Q9/zftP

                "], CompressedData["
1:eJxTTMoPSmViYGAQBmIQbct1fXFBSLPDDrnW14GbSh2iUqzv+3s0Q+iTpQ6d
jglPLwQ2O+Q8/73y47lSh/J986X0O6D8C6UOYP2nmx3076qwNV4udXhYJbLO
/UuzgwzIgJelDts+/71SodLiMCNPqPmAWplD1p6SyRLeLRD14WUOh79qxPSH
tjjIgtT7ljlMc+7OeW7QArFfugyin7/FIWPi2xr7t1D33W52sNxyomwf0H3t
YjfPfV8Bdc++Ugeb+/690yc0O3iAHLIT6v6SZgeQcB7Qf++XH/M2z26GuGdd
qYPuprnvlyc2OwB9v0NudanDEYUNRRnhUPk1UP8hhQ8AMHyWCw==
                
                "], CompressedData["
1:eJxdVAlIVFEUnUzCQqRFJGookyArRbNVyjyaYpuZBv4/M2ozozNOUrYgGSFh
xHsvyaiozIhSM5NAJGIIsU3asIIIC6JMxLQF2ozIkgh61zso9OHz/+Xf5Zxz
z/tz3DtzPEEWiyVD3/QsuVl2cnqNgIWueBPlt+tmxPkFakunHup4bGJVb9bR
M51j359nuieb/QLxPXMnHPQYaDp3P/JqkASObP/wZ5sBHe3xWSU26rTEVSb8
nXtv182TXF9rYrb4lN22SKLMd+JLxUsTh1Oc754lSPh//H2x75GJmjW60WKJ
z9lts8SNQLwikF9uIiz22vlvSRKhLxt3JSWY6Nsf3pqRJuFsXxca1G0wvmyJ
j8+iuodbDc73SVQmLy1obzCwcXlVilNItNG8EwbjOhro32zAXrSyN6tWIoT6
LzAxxUz0dzZJdGiZgh+a2ED19yR+R+cduxtr4jr1CVd4M3yg5GZ1LmL0uOZk
xfhSTSRN0i8zFabHacGuOHjeRIXqiFdPfxXmo58EnKZQn6475RVAs1ioNik8
pEFrnbj7Uw8qVkjVMkXdcWJkXxUK9Ahe7RqNoxeFtFjdY7GViJxzMb5yhVwS
otGF/GO6Y67CRZpX78I2TTt5mcLXCi3QBRfrHaMwQLhaXIzPGpg35EIV7cui
QLSSSt3ML0gxr99uKOIVGdDjeCHvI1GB1tQ3qYjxhSl0Er/KIjhI7yGtr7Zd
T0cR++eJBLmvwebBGfJhq2Q+zz38vVTy/Pdexhcn0fK9K9PtK2Y/dgu8fvpr
S78o5vpGwf3OFuPSLkIsOH/Qy3h1PNIvwov1pP8tgWoqTPPwvsdLlJBOfYXc
L0eyjzLd7BdT8nkJc4PWfNAR8MffrRhs1psskDhOhZV5IJslZwT82+UA2fSA
9v+IXksczGd+ID/Swft6L9i/4xw897LAZpJ1wM66nxV8/h7Z8ZaElgLbaU66
HQ9Irx2C/XXKxvlewTiW2lj/AoE0qk8xWR+b4PPrN9jPDoEY4nXa4H37xuKR
frvH4nvkVyFGz+P//5d/+0nqVw==
                "], CompressedData["
1:eJxdVH9MlVUYvjmWxYT1A10qMqPGCDVwzjUl4MlyoMHUQv5wwu53D/eeO0xg
6Wqj75zNhSauImtOlzpnVrOGTk2YU2CMGqFtDq1N+8FuhMw/GBoUMHO6znve
4/1ad7v7vmfn/d73eZ73fc/TkYbXojNCoVC1+dNzU21hYt01hZylj7RlfhpG
weCzD+8YUfhwf/0T7/aE8clTKVXp4wq3/JLlNfcDvPJs/1vdz3hJ3PfqCy0v
bfZQNtSUcfKegsmy7+UtHlZQXKFGz5F5+YO+hzHKs0sjl+p97KF3Mndza6Xm
ukMeilKvHWucqzl/SQQh+mVolJv04ZYIhr84+N3CMhff4s79AKcvOXP49o8u
fjICq29Io3l0w7ms1QL5FHdTg8oU1QkYkZeODrt6BwUGsn+9o6+7+HYBkhW+
oFFFiacFKOxIs+bvxgSuUHyTZh6fCyw89WZ8b4NGN+mtFIjvNYqrNRpJmMF5
7835+fIyjVXhkYHsYwLFRGRSMd+5tZznb4VfLk+/PpwWxdabd78aL9D4evxq
ReRQFE9S3QqN7ZQ4EWV+BmeS0OEoDlDbcjV2Ef/nYuznQ47/thj7YfqbQ/2Z
KZnPtGI/8mSyf5bPcgk7Bpka79PLYol3Mk6WDr2ocZV0z5H4lvpXpznfdIz7
afpheUzFmF+r458hcS5r5+iGfs36tkq0k597ND5b3fHXvd8l+5Xv+H4v2d9U
188uyfzvquT5hEn72JTClCnbO+bwhOI+pcaxgD64otBG9QvirO+EYn6r4uzv
G4r9FHHuv8Hh82tmzfgPtnwfDfANmsPjkvWuVzwP+yT3f75ivT9Jjv/Tx0cU
ODPOfvb5PG8JmcS2780Btt89Lzlu3Of9SpFoIv+L3b6mO71NTv9syXG+w10x
Pn9Fcf2SGEpJ/wN+N6KMC50/u6O8z1sU+ilPKIqdNEdSoXO7OcmqZf+XOb0n
BL40NpxKVbx/GwXXM3qtP4cE5/vB5/m6L5BY98H++gNOv9knOz97fPa7VfC8
7vD5vlkruD+7fdTQ+SLB+/2Nj1mU748IzFSMDAz4PB+nIxz/j5+8D2w/HldJ
bPdnTYBtvVKFOpq7pRG8TYub5u6z6x7rTPjooHky95XVl2Pm4Y6u6zT3ma1f
rvAb4UYvOR+2P5sCbJ9rA2znM91jPw+7flSGeQ/aAmzrdQTY+nnR3b/bwvj/
/f0vArCfhA==
                "], CompressedData["
1:eJxNVX9sTWcYbmSRZulkaxuRza4fE7qKYJuI0Xm2VW1+xBCyjIj03sM53zmo
ooruO+cGpTO0bLMRis6SJY2xTVe2VFO1sj8wjLUUTbd2C2rWaSONxPd+77dz
3eTekzfn/fG8z/N83x2Uu2yW1SspKSlXfenplN0tmlgVYMPtmdWRY1Ho+EqA
uX1GfLu3PYp3U3oN3/RCHClXK/KyLsbC+I9De+oHplhh3FE0ccyCiIX6gUfy
7eQ4Lg6+9lDmW1jz99DRyfcDLDyhMhssvPhBbPzNkwEOTqrqfFS4CNPGlry5
8KMAeVlPX634cjH3KwrQn/Jm26DHjFUBhvaOf/r2Nzb3n2XwTXXQSjhu+Sgm
/GcF42iSqCl/fmRzvQevvefr+9skjp0pqCnf5+ENNSbPkkhbX/vLgRIPavqf
F16RjGu1h5sztu5aGpE8T8V6fs+HoLKsAg809p6Kh41Oruyf73HfTInGc92z
W1/2uM88iVTq3+zynvsl12ea+lbJ+670UB3ZeHtmm8RGwr/KQ92DjPnbOyTr
MM7DVOKn09T39bCE9vnL9G90Ge8VyXMqXVwg3uslulSburiL49T/hMT1h1L8
9J6Lcd8rwCcl2og3uFhNRJ2WKKXBI13G953Ex7uWpq5PcUEw876QrOe/gvHa
Ev8Qz3UCvxUqgXMk6/WSYHxeItbP7YlY833d4GsRPO+SRM4WpdQgl/c9L1GU
fnhyy1suSO6yXyWaCH/M5frfJeu9xAXBrO2SOEOFpS7WUd1/ElBpg3tEyE8T
6XNUhPxUkW7FIuRH8zlHhPxo/2SLkJ+fqf9rIuRH+/Y5EfKj+et2QOXlip+V
thKwwfgzx/CfYd57ibiB+u5IxLp/s/If+euGw364/D8/ApNb1qYfPm/wThIh
P6Oah/SOOyLkR+cvF+yLOya/xOjRLZFEn3SBzZTfZvzV5OAd6q/mb6PBPzoY
vqlv4zkVC/JjmYOd/Z6a26dd4nVaZJmDTHrfbc7Lq07YT+tXY+MZ2qdB4jPS
abeNrxQdRxTfQyh/i837nDL6ejbz32r4nmAzP6k+89G1mM9Jmo/PqV9HItZ7
Vi8KY51fZeEu+bSfz/hWWOzXUT7vm2OxX6b4fJ+kWaz3dJ/1eyLWfGUn4lry
R6HFvK7z+XncYv4OJGLdvzIRL6B7sNM3/rYQ0YADPg9HY1C/DzKyzf02IIZL
03Offd8N2F8VUfZbQcD67Inih85HlwvjAePdGcVpMsTWwPAbhZanNGC8m819
/knA57k4yvfboYDvzd3m/n/i/+AxP5jYyg==
                "], {{
                484.76599999999996`, 196.805}, {484.76599999999996`, 
                199.41000000000003`}, {479.387, 202.195}, {472.953, 
                202.918}, {467.758, 203.5}, {467.672, 203.46500000000003`}, {
                467.672, 200.87099999999998`}, {467.672, 198.723}, {
                468.48799999999994`, 197.87900000000002`}, {472.074, 
                196.31599999999997`}, {477.83599999999996`, 
                193.80900000000003`}, {484.76599999999996`, 
                194.07400000000007`}, {484.76599999999996`, 196.805}}, {{
                490.66400000000004`, 197.043}, {493.289, 
                199.42200000000003`}, {494.53099999999995`, 
                202.25400000000002`}, {492.953, 202.25400000000002`}, {
                491.137, 202.25400000000002`}, {486.32, 197.93}, {486.32, 
                196.301}, {486.32, 193.75799999999998`}, {487.215, 
                193.91000000000003`}, {490.66400000000004`, 197.043}}, {{
                485.07, 204.75}, {485.29299999999995`, 206.223}, {484.383, 
                207.20300000000003`}, {481.65200000000004`, 208.438}, {475.77,
                 211.09400000000005`}, {468.734, 212.324}, {467.039, 
                210.99200000000002`}, {463.91799999999995`, 
                208.53900000000004`}, {465.9959999999999, 
                205.24599999999998`}, {471.039, 204.652}, {473.07, 
                204.41400000000004`}, {475.824, 203.79700000000003`}, {477.16,
                 203.27700000000004`}, {481.03499999999997`, 
                201.77300000000002`}, {484.72299999999996`, 202.457}, {485.07,
                 204.75}}, {{485.07, 212.63299999999998`}, {485.387, 
                214.73000000000002`}, {484.043, 215.48000000000002`}, {
                473.08599999999996`, 219.33999999999997`}, {
                464.90599999999995`, 222.21900000000005`}, {
                461.28499999999997`, 220.85899999999998`}, {
                463.89799999999997`, 215.89499999999998`}, {464.809, 
                214.16400000000004`}, {466.34000000000003`, 213.375}, {
                469.76599999999996`, 212.85899999999998`}, {472.316, 
                212.47700000000003`}, {475.801, 211.73000000000002`}, {
                477.508, 211.199}, {482.074, 209.781}, {484.715, 210.281}, {
                485.07, 212.63299999999998`}}, {{490.562, 
                220.02000000000004`}, {492.215, 221.695}, {493.566, 
                223.67200000000003`}, {493.566, 224.414}, {493.566, 
                226.816}, {487.039, 222.56200000000007`}, {486.207, 
                219.61700000000002`}, {485.207, 216.08200000000005`}, {
                486.824, 216.23000000000002`}, {490.562, 
                220.02000000000004`}}, {{485.074, 220.51600000000002`}, {
                485.43399999999997`, 222.906}, {481.457, 
                225.06199999999998`}, {473.637, 226.723}, {467.902, 
                227.941}, {465.371, 227.25}, {465.801, 224.586}, {
                466.03499999999997`, 223.12900000000002`}, {467.945, 
                222.06600000000003`}, {473.367, 220.375}, {482.039, 
                217.668}, {484.648, 217.699}, {485.074, 
                220.51600000000002`}}, CompressedData["
1:eJxTTMoPSmViYGCQB2IQrX9Xha3xdJ1DgS3X9cVfchy02sVunsuud+g/9FUj
pjnXweNhlci6ynoHVbbGqc6v8xwuKt3+WfeozuGbRkz/Ic98B8stJ8r2La5z
WOS67fPfgnwHd5D66joH2agU6/vRUH5ynUO1yDr3h2z5DhkT39bYB9Y5fAXp
P5rnoLihKGNibB3EPv88h+l5Qs0HyhB8sPp6BP9qxUs1w7Y6Bx/zTscESwR/
K9AZ8+UQfOHmA6cWLsx1AHmrYGKtw2KQ+zJyHSZLsITx6dY6zADZcy7XwQrk
fs5ahwsgf33KdXjg3zs971cN3D6w/8Rr4XxweOgi+GB/2dQ63Dz3PfjxWqi8
Ya0D0LSsPR/yHN7V2JvGKdVCwsM7H2LPlxqHYpDHsvMh4htrHApBDvXIdxAC
uVu6xsG5O+f57595kPiQr3HYP19K/+6MXAegr59e2FHjELfLk4eJOdfhmDcw
IMxqHZ4snX1EoSPHAWScvyc0PhtyHNDjFwB7QOjD
                "], CompressedData["
1:eJxTTMoPSmViYGBQAmIQbbnlRNm+9DqHtteBO+Q48xwmS7CE8RXWOczIE2o+
IJXnsMh12+e/OXUOXzVi+g+Z5jnYcV1fXBBb5wCibP3yHLzNOx0TrOscwOY0
5zmU75svpW9b51CUMfFtzeU8h8MgjUlQ8/TyHUDK5tfVOaiwNU51Ls53uFrx
Us2wqc7hG8j8m/kOWu1iN8911znIRKVY3/9Y6HBB6fbPujl1DjnPf6/8mFPq
MB1kzr06h1aQe7krHD5d8k0SMKt34NPdNPf96goHoGueXoiA8l9XQOjgeog9
byocHi+dfUThV53DFJA/11c4vK2xN41rq3PYIQc0MaHC4RjIQ3pQ//wsh+h7
UOsQt8uThym9HGK/T62DNsidgWUOChuAPpWshYTTnRI4H+y+g4Vw/kWQP35B
/S9TC7GnJR9iv1mtgyooPPTzHTpA7veDqr+XB3FvQK0DkJe150AeJBzsoPJZ
eZDwMq6FhK9RHsR9erUOoOC3/5vr4P6wSmQdUF4WFJ6fcyH2h9Q6AFWdWrg1
F2K/S52DuiHHGpljuQ7o6QEAve//BQ==
                "], CompressedData["
1:eJxTTMoPSmViYGCQA2IQfVRhQ1HG1UaH497mnY5hRQ7TnLtznl9vdODT3TT3
fWyRwxXfJIGIS40OM/KEmg+0FDl8ugQUONnocPirRkz/miKHQyB6V6PDlhNl
++a/KoKo29LoUC2yzv3hlyKHrD0lkyUWIPi2XNcXF8Qj+J48TNrt3xscls0+
orBBr9gB5IyEngaHaxUv1Qz7ih0uKN3+WefX4OADEj9a7PB4KVChZQPEHZeK
HeRbXwfuMGxwYACBI8UOAhGWW07INUDULSh2yJz4tsbersEhbhfQJu9ih3ax
m+e+5zVA/CtX7FCxb76U/qwGiD++FTlUAq3lEG500AYpPFrkENsPlPFC8MHm
ZiH4MlEp1veB/Jznv1d+PFQE8UdEo8MOOaDD+oocQNL+3o0OwFA5tTC9yGHb
579XKvIbHaxAAZZaBPFvMzR8U4ocFhcAQ2heo8NFkL/jiiD+XwONj3Co+y40
OnQ5Jjy94AbVj8RHj08AglzhCw==
                "]},
               
               CurveClosed->{1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 
                1, 1}]}, 
             {FaceForm[{RGBColor[1., 0.717647, 0.], Opacity[1.]}], 
              FilledCurveBox[{CompressedData["
1:eJxTTMoPSmJiYGDQZ2RgYAbSDEAOIwMjMzOQhDCIRPjVw2WJN5ZIlQSVUa6A
bPVoKqnud2JMINsNBGONoMn4FVArXkhyJIWxQKqbKYxHAMnLCKY=
                "], {{1, 
                4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 
                0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1,
                 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0,
                 1, 0}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1,
                 3, 3}}, {{1, 4, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {0, 1, 
                0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 
                0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0,
                 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 
                0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {
                1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3,
                 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
                0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 
                3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{
                0, 2, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1,
                 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 
                0}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1,
                 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {0, 1, 0}, {
                0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {0,
                 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{
                1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 
                0}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1,
                 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 
                3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {
                1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3,
                 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 
                3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 
                3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 
                3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0,
                 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}}}, {CompressedData["
1:eJxdW3mcT+UaH0v2O8mSJblZwkXkhgm58wppoYT8fsxqFmMs8zu/ddDiLL/l
TJuRGyprXIwtsgsjpBpElhApW0TWKSW67jnv9ztzPrf+8XnmnPO+z/J9vs/z
Pu+vZhmeQdkV4+Li4ivFxdn/LlB61jhSXRNNI5de3HC/W8zIq2Nse1gT/lFT
Lr8y3S0e+XjW1UWdNPFMrYrtYtbzHb+2SZ7cSxNfNz9+67XRLsjjNFFvRb9T
E8e6RG13tzVfvK6JA/bzxm4xenNgasN5XG+OW9xnP1/tPH8uoaBX+h5NWLs3
jYxxiVzrtcQ/NNGyivZub0vebq/fQBevJnZJ3dSI67XXRez+Y1/9NtUt/mYr
2EGHftPc+PcJXawr/fPQ+G5u8cT3L7w1vY8u+rwx9vztCm4xPKvH9y8k6yJt
k/XmDpe4umjXcwleHfsud4km9gvTdGFsK5nXN+oSlnfmK9N1sctW1HSJ9fa6
y3Ux5Mx/PthZ6Bbx9v7FuthiqVU5b5gwe6Wf279dF5aVoa2fDxM7H1rpG7VV
F8/aes0eLjp+Z1n2iS5s721unyQODsio7d5A/e5Lxn7rdbHacvuuD5IRj7W6
mNfXsujfKdhvbZm9Kfj+DJ/XS8V+d3R8NzxVfGbLjQzx1nTrDxtSRYGtXwsD
759NxXpdDPjjsTTIOXw/nF4uy/U+duRU+/3idOw3xBBWNAaf+Tqd/jfE2/b3
J9Lh/+90YW/bvOoI+GGvju8PjhA2LBJrGuKmFebtAzLFg7b/PYbw2Q/WZ4u1
lhvnLDPEh7a+tUeJCT+16lRtuSFs9z9UmIv4WbLEV4/Ror2N14/4fmC0sFb9
tc1aQ3S34/HCaGH/M2d32fq58N98A3p0yxFJNj5G0j5PNuweYAjraZfUdVki
f+ucxh2zDRFn/7cnC3j0GcDNkSwxrbcVyC2UXdlioaXmyr+FxZLrBwZkXMjG
dxfCsNOfA/mxCPLg0xzgc1tE1LUBWJQjbDNXdo2KOrb8bg72y40KO12bWvrK
9TdHkU/fZiMvLkSBr4eyYW/dGOz/IAv5PCIGfY7S31VN8bmtwOMZwG+8Cf/W
yyAvmIhD23TITU3gOJgs7DBva2zC/4nJ2H9zDPn6XhLwNjYmnrfc3K1WEvK5
e0ycmmgzxjDY80gM+O/lhj4P8/0sF+LdJQZ8pLjEv+z8SImJR+39H3GLG5YZ
tV/m88/cwIPpPJd4ey+G+Ga7xCE73ltj4CtrfRmvEzFhu2VXOzf0L40Je5ue
293Qt6ZZ/lyu86hJfV2I3wgTOJnogj/yTPHjfisgs93IP68pltmAOOIGL403
sY6lr3w/asJfI6jvPPpzkUuMt/H2owk+cbkQh8sm9LtIfrpGfZrRH5dMMd72
2zLy9ylTnLDx0GSY+Lsdv40m/HpnOPPHRL7/kITny6jfOcZzKfExMBV+3Uh7
7qYifpY+T9r5XTcd9rQrQL7sSgeOEguA5+UjYP+9jiz1vWGWyzIPDpnAe/0M
8O2nJvijOAN6f0B/NMhCfD40RWvL2ibvZwNXJ8rsHYU8vJ/7FY0W/e31Hyyg
v8bAn5Zsh+u1b8YCr5Ys+SEhT/Sw+euBAmGXyfmBPOC+agH26+qB/26b4Ltl
HvDHaVNssBOlgwL+2W8ir1IV+OMjU6TY/LJeQbyPmcj7PxXYl1SAPDjoBZ+K
AmFVl6Hxj/kRzwWm2Givv8mP+ATojzN+fJ9rwo/n/fBffRP160c/60VMNLNg
OeWcn/Uuhngd9cOfY2Ji3PnbRde/8ANfiTHw3kY/+OaXKPy1zI98/DQKuyxZ
5oMSxXdL/SLFtj+D8kd+9AdPRsXLdgLu9yP+zaOinx24Uu7XJAp9Kwdgz/1R
4GpIAPisF4W/sgOo//FR0c52RDAAPatzvwkBrP/fCPRVA6gPJRHguzWf74jA
f3f9WLc4gv1/9uO9zRH46zLlVRFhp/WUqgH4vygCexoGoOcc7icCwM/7XD8t
ALy9FQE+VgTQP82KQO+fAuDX3dSvfhDxvxoB7hKCqLffRsTTtr9eDIr5NjBX
RERbW5FYEDyUFQGOM4Ko189Q3+pB4P/JCOJ9LYD87R6B/49T34QI8u84/dOF
3x+n/1rxeWmA/VkE9ei+IPz3fRh4nRTE+zfC0LdZCHzbk/VucAjxHRlB/MaF
kA8FrH/DQtC/MAJ8tQwh32ZGxA+WmnkHgsj3Yn7fM4R4bIgg32aH4Ic1EeoV
Al7X0p+nQojX7r/IFx1Z9qvto/BDIffvFUVdHUj93FEx1s6XKnzuIr7fCcK/
PaPCdmveE0H0Q22YP78HEM/eUcS7UhD7j46i/6jL+BVGEd/eQby3IFruX5mP
G6Lw15Yg8nlTFPFKoP6Lo/D3BOo3nf3DRsrvcf8dIeBwdRTxWh6i37hfQUi8
a8fvJu1PDwHP1WJY/4EQ8Nwwhv7rRBD+bsR6vDeIeNSOATdvBuHnmjH4I4t4
uUt7Owbxd2s/+V4D2n+B9l1nvp2PQu9LxHOpI8v3q8XKZckLndkPWP6VuOoT
gz2dg8Bjf+rbN4h8cMVgvycIf6aQHwuDwEUuv/8qCP4LxZAfc5gPJvdPCQL/
S+mvZnx+JCYO2wX7TgDfV2H/dShA/5moB1+TDyuwXvxG/rhGf9YOimt2PA/E
8Pft5IvjMax7KCjkee+HGPjtZBB6PWSiz3wliO9GmYjTH9TH6g8kriZRPsr6
7AqU19cyWa6X48gSv+8WwO9nAtjfWwC+ySEekgsQxzXE+yN8v5jxr1MAP7xK
/93DepgWxHsVC5B/TwVRb6oUAN+tiacaBfBnHL+vVoD8tOyTf//NLJdlfL//
i7zKRHy7Mt7prN/F3N+qp1KeHCrHj8RXYj78epL9+6R88PmMKPJjcT7WrViW
j/mI6ycRrDcnH/rlRcDrej54rU5EXLH5u20+9DkVRr7sJr+aYeDJ4ku5XyyM
uFh4lvX/uzC+m8j4/BpGHBMD4NNz/L4W+X9vGPpu86Of2RdGPUtivb7I9e+j
fDPM+uIDLitGkE+Hfdj/HkeW61VjfbVkyUc1I+CViz6sWysC/qzsRz7Gs/71
9YNPm7CeeP34rnMEvKj7ca5/NoL+9R3Wb3cE+fs6+6FPWD97cP0WUeh9wYd4
7iOfn6b+EfJVez/jy/wf6Af/PG3i+fP0R8gE3ltT3m3Cnh98iK+FN2lnax/6
u7km8vB9L+yJmLA3hf3gGBP69/Gi3tVlvtbzAj9fM7+vsb/8NIb6eFmBfm1j
sMd6Lv20mP1SqYLzxkTWpysK+oW+rF9H2Z/W4vNtCnB5IQKcbFWwv4jAf7sU
2PEq8bCf/fDUMPy1jOvNCcOeGQrs+CiMdVUFem0IA/ch9s+fh4HbbAX5vSsM
/2by+5Vh1IvBCvwzPwzeelbB32PE95P0j9eRpb7POLKMS58w+vs7HuCnVxjz
jlUe9NeWLOM03AN/9qH+3fncWk+ev2t6gJd+zKfKHuRbjzDyvYEHefjPMM5T
LTw4Lz0QFq3seVgPvl81LJba5/f+Hvi91EA+pXhQJ44YON+rHvSHJQbOO+95
4Lc1hii2zPpupwdx/NhAPu/woF4sMWDP6zzfzDfEUPtDlwf4SzNw/nk7D/n3
kiNLPw9xZMlHL3K/NXz+IvU7mwf9BxrQuy7PT09xnjPZAzz1MHD++432P2og
3zsq4OeWnLfkEI/NDPDpBOLtQQNxnEr8P2DA7n8z3vU5L7LwJvW4z4BeAQX2
1jIQ14EK8rO6gfnnPxWcZ6oYyLd6CvxxR+f51wN7S3Xkm+VPud8pHd839QDf
3+iI98uMRwmfnyRe1unAdXPi9yNHlvYsd2SJ98Xcr46CecdCztvuEh9zdeB3
OWWvjvjsyUP8Rzqy5IMMR5bnk1Qd+KvlKZdlvIc7sozHItqfpAs7DMnnae9Q
R5b7v+jIsn4/r4uHbbwfdGQZ102OLO2Z5AF/tHL0Q//pyNJ/dRxZ5m91HXhe
nweeqqRjfjQrD3j6RRM17fnK8DzE+4KG/MjMg11XNMx7V+TB79c1zNv2E+9X
Nc4XGL+LnJdneNDHnNOg/3za/70Gfc4T/yf5/LYH9eaEBv6vriB/92rg4ypl
eNAQz3P8/jVNyPHaQg/6rXHUx+IryZ8xDfwbpyCPCjXky73k29kaeY78v1DD
dwrxtEJDvzVbQZ5s0oDbL/j9Nuq3h99/qQEHBxT45wsN+bibz7dq8NMKBXy1
TsN8433m20ra85oCXlpJf3gdGecHBfOAJdS/L/VboCE/25MPZnH/ugr8M0PD
/Ot34vN9xusG8TVTA95/9qBPXUH7KrN+7dSAg4ZKebxlnHoqwIsly++aUL8y
PNRQEAcLL3K+tIZ8+6uG+VMm+fiuBpzsy0MeNNLRz8R54J/OxG8nJz9kPp52
ZIm7Lkq5LP3jov0uHX4aRD618lXGuwP5JFnHeasF7c3UEc/fyc+55INlrH8B
8k9z8kGU+k3wIF6FOnBbxPo1i+tXIr4+1NEPtCS+l+qIfyr5eSPvV/IdWeJh
gCOX1Qdp5xkdOIvQv5eo/wwP+POqDv6fy/je1KHnDdYbi89lXFvRP1VZL8LU
tzHrzWfsT1oZ8Mt6BfzSlvcVHytYrz3ry2L69x8G7J1LPLRmPXyPeO3EepXM
9RNZjxqS/wfw/qSI+Z1EfSz+OW3vl8r7mQrEU6YhXDZA97EejzLg32/ygNuI
Ibw2HgXr1QzWO539TBHt2eNhfMrquQf98wrqa+WH9KfVX8j+uhLt2WkALyfY
T5zgfcpc5l+HMPb7lwf+7hzGekNpX0IY/UEa9evGfm8t8d49DPzVYPyt/kry
SYaCPnIQ13NTvzSeX6x+UerxstM/Sv6dHMY6w9jfruH5J5P8OZX9XCH303i/
U6RgXpLH81YJ4zua+x9l/EaGwQvniYeXuN4v5JPeYdj9uwJ+r8Pv47ywZxPx
kOHIMh+mOLL0p3WekPrsMmDfG17MUw8bmEcqXsTvJvHZ2Qt7WobBn/Fe6NHf
kaW+uY4s13WF4ZdEL/jeel/md5KX8y7OBy39JB56Ud7iRf/Uk/6u5MP33Xh+
iPchf+qHEYdelO8a8F8az2tned/3lg/2HWX/t8hXjr+y86fkz40G8nQ291tN
f6g+8OMyA+f3HB/wscSR5XqLHFn6bSbvEyf4wDtTmF9v+3BeiRqoHwt8wN/L
xP86ngcnGLzn9SHOIQPnt7W0bxzvY2dwvyzyTZDrDTaA/87Urx/XH87zteD+
ebSvo4E8eseHfra5gXxZQv/VJx62+1Cf4x3/yXjXNf7/PN/QkaVebQzotdkH
XCSQHyx/y/owyAA+LP/JvEkhX0z24fyTxfOJFT+Jt5HUfw/lTPLRRR/wm8bz
QX0/7E3n+aCBH/uOoj53fOAXy5+Sdy5RftXAfKXEh/x8k/hZTXkh+d9kPDYw
/0qo/5fUpxbvQ0p4PrBk+fcDXO8c9T9B/l9J/duRLx71gR8t/pD6nvUiXuPJ
V8e8sCfA/KngQ50fQf5Lpr+T+b6FD8w/yC9zHVnqt9WR5Tz5J+J9EM/nlr/k
PKUr12vtx/kgnvyUxflKBfLnZN4X3WI9u+4H/90kPzUKsP8hPp/iPO4i828I
51OniI/cAPjhB36fEgBeTxMfdTnvPcv9TtH/p5hP83m/dZz7vU79vqb/h/P+
zIqXPP/rfvj7M64/nfatZn5v8SMP5xqcX/kxf32b+18m/jTm7z0B/N0w0C/W
CCB+UeL93gDvqw34/xb9u4LyMd7/7eX3i/3I20Pkc8s+aedR4nMD79dOGugX
DzjPpX2C8+R9fP9Nzs9LmD+rA8BfSRn+A9DnNO0zeB9USv+lc374J79P4Py0
MvF7hfO4eNb3d6hf3TD6FcMPvulJPD7O+zgX60FNzvvGEb8XyGce5svPzD+F
+LzKfA0Qj5l+1J8Q509XeP85kfXqFufTQebP40Ho8xL3fyOI/foyP9YGwXdp
lC9z/q9x/a6cvxbSPm8I/pleNk/l/cxMzrMq5EPPSfRPSQhyDvN7Vgh2JlOe
yvWEI2Me4sjy/cb050zqU5X9yw5+f539Yinnx1+Szx7Khz0LWL+6Up7G9xPz
y+ub1LOHI8s8a+PIcr3G+eirCyjf4H2TyvzeF8L6njL+p/ycgfPmN7xv68z5
VMV81I/G3K9lPuJk9eey7+mQDz48zP7+6Xzg8ICO+vGUI+P+JVQuy3r+Rgjr
b2L/HwqhHk3m+eXTEPI3j/OaP0LAw2Cd94H5yNd6Ouy8FQLOzmrQ9wrjc5nn
/R28b/uFz2eHsO8Nnmcnc/0zPA9m0x9f8vzZnM+LNPQ/9/D7kCPLOpfmyPL8
8iTP93d4/9VV4/ye+P8H5wVnifeaGvB1hPchN1TyC/F/TC2/75Pnj60q+GFn
kPMsFfYUBxGnJSp/XxUE/xWp4PctvK9YrvL3AbyvWs33nwqhH56mwm9GCO/n
OrKsrx0cWdpXT0V+Nw4h/9uqwPMU3id3VGFviP7oosK//al/gop86sz7te4q
8U1/DVExzz3C+hVQEc9p/L3AVBX4cweg1yqVv2dh/bP8I/OtCn/fsEmFX2+S
r0roz2/98PMx7l/C+5lfVPhpOe9DrqlY90c/+OFnFThvyfv+UtrbgfWzsob7
9YoB1LMaGs/DvC9pxPhb9Qi/1+I85kvu100DzlexXj2hwd8rHVnas8uR5fsH
WY+Fhny8Qb7vWzYv4e8Nnue8qCvvp1I11ME/2F+M1JCfln6Sf3QN/cTbftj9
gQa+Gcx6v5fvn2I/fYn6ZfD+6jjx34fnjcMa6v7jlHfS/m6+8t+7Sv7qx34y
wvwcxH4xi/nt5n5Dac8QH/DfjfOi/lw/gfk5hP360xq+U3kflcR51Aof8Ojm
83Xcr7MjSzxWd2R5np9HPJ7kehNU+P+/PvDDIBXxfpDxf0Yt769l/HtS3s3z
wuMq1l/CftLKJ8k346h/G+ZjX9bvB1X467YX/NRPhZ7W+U/6PZX5Xo3ngVdU
xLuOD3EoUIGPxrR3ugr8Nmc85quc3/jw3QIVerfg+wuZ/814/prL/SrTn9Np
z1mej2PkryKeb+cxP9d44YeVXH8jz8u7VODvCy/48ADXO8Tz8HkVdeSCF/r+
RP4474V9t1TgdZUX+RjPebTHC/80ZX74vOivmjN/NnihVyviP479UScN/cqv
XvDE08TXNN43pmjg8+5exMGvoX9t5EW8xnOeOtCL/J2g4byUwecR4n8S/TNF
K59HSP8tZf1a6wW/bWX9W+rlnIT6W/bIfDhMfkjgep8w//7g/NjLejWX85QT
5LdvOJ+MkF/Pj0P/M1bFvF4Zg352qMrf++XCXzNVUWgn6KWRkNto6B/68Pe7
Y8hnE7PYX5A//pMJnH3FefXNTPhvlYZ52sBszF8+pv/O5iC/92viJfvFwaPA
f4f4PGsU+Pwgfz//91Gwfw/5eFMO+HEt/dd7JPqVYuKjQTb0ul12n5GB9zvp
yMfiNMS9LX8vPy8F+fEd1+vB339a/HbX/u/zJP6eWsPvx9ckIV4WPuR9zSdJ
8Hc7jb+fTcL+Lfj/F6xLwj61NKzbIgnzupsq5pfv8veoVj0r+/1tmSz9ccH1
/899/D2slS/y97OaS/z1/2f4HzqSVXw=
                "], CompressedData["
1:eJxdVn9MlVUYvlErhsQynQNaJmSNQoP+YGry4yUqRswRtgxDrkYQrtn1O59O
r2XZPae7m2tpyIxWmXlTzDBWJkiuQQNDsVYUmBVzIv1gXQrQrOUs1znnfeRr
sbFvz33PeX887/O+35dWvXpxbZzP56vX/+Z57utF1deVKdrz+pFZ7x9x6DJe
cPDYuo5Bh1bW/7axYK6iH8yBVEE+8zdF0djGghz/3YLPT0hKmntgx/ijgsy1
naOSnhy5uO9staCuPzKWbdU4PFrePrNEUNvv/wwENbb30gU98fHahuTvJd0e
mfHdF52I1+9hnZW78ksP32Qc9UryHy5JjOt3aOHpspcaeyQN6Ucg5lDWqdlX
h7qRzxWI1ybpRPCXW+/MFtRq8tsnOU65oOGnprcUb5P0SI3xJLjO5yRNU58c
3/WQoPUdO1OzVku6yxSWJmi3k5dwslySuXZmzKHNhSt+6rvHw02Gx0IP2/o0
Plo6b3NhAvIpknS98Z8paINOK/4+SdeafMuAtb/GgD6xSpCuMjOSLzmPNYLy
E06+7SwAnxsEnTGBciQ1JF+1JGm9h20fAv+zV8JfouS+XHLolaIXV41c6WGT
5gqfhy3/F0N8P0XQjYaov0KUZ/MQNKDbWPFniDJNf5ZCD+dwXvNpeR0PMd/N
gnJNv34NcZ96BfvX56P3amYOChrf21M67+8Q8/0M/CWhXynoX5qkvvTBC88u
wf056G8Q93OgvzcE39O4xxT2jofNtfoPBdc/H/W2C+o39eRJ5kHbXzV9KIT/
FsG6KoYewuhXqWQ+dP3GvPcBSU+b/scLCpq+PS5ZV/Nx3oX+F8PfJsk6Wgt7
GPHDuL8F/qKC53QLzkehx7ckz+XzuN8sOW8X5w8jvxLMZzf4yEA/PpdUZebp
GszjCUntM7XCtH4tL99gPs467P9b2M87/Psg+jED+jiF/PPQnyHEq0E+w5J1
rOvbbvgfhr4jmLcfUd/LgqZW6E10s2L+86GnhYrjTxdc1/2K411w+HyF4vkY
cVgPldhnow73p0qRUYF/wqE5Bi9X3I9kMYltX4o8bPl9AfwuUzzPr0FvxYrz
6MS8ZcEeA993KPrK8BNDPbcorvMzQZWmnlRF3YbnKOyJiPcfbPVz3MO23hHM
82nsj4ddtvd72O7LPg/bfI+C7wKX8+uQPH+zXK6vDfqJg7/90GsM+ngXeo5h
n70pJ+s1bWn3SzKyCgRd3mN+3N/mYauXJpd/fwzzvculCZNfAPltctnfOthr
XdZPBPst3+U+NcB+G+rdj3m4JBi3Il68y/3plKzTStTbhX28Bvn1YB4iLuuw
18NWzwMetvtjCvQ2FflOU5N82fm5QbGfLkHZZu+lob9j2C8Zip/pLj+zFecx
2+V9lKvYz3nMR6FifofQj6WK+WgTdMj0Qyjeb43Qyw7obTnmr0mxHrTdvj+b
kf8h7NsDivVwDP5bMT+d2L8fKebvA9hbMC8PCvrUBN6jqNgQXQD7bnxf5KIf
2xXP/yLkG1a832qwD+uQ/1bBvNUh/yLoqw75puB9WKv4ffuzw3GqMY/92E9V
iPee931jeY56+PL3z7/RviXx
                "], CompressedData["
1:eJxNVGtIFVEQvghJSJaZRNjLykyysJISNXO0h5SaFP2w0BRLEjG7OItdNQrP
wVRCzIJUTMxXIkRImNrLxExFKKSMKLKLRNjLTEVIQuqMMz9aWA6ze84332N2
16WeO5rmYrPZDpib1tyvftsXZiuYehWX6uGHEBtcEpkSrsBG10Wpdyr41FTd
63MN4eAil4CiXQo2Fy1/9/IRwtKEkLaBYAVvHAboC8JEc19McJiCGDr3RGqD
17mm8PuRRoT08vELETEKiiNTPg8Z/MVb79VMJCo431XrHXhK9ucrfh6EUEL7
ShUkPTSdk5F5ViogOq05CM9m/BPLbinI97obPWr4rTVtOk29THcP1tUgJJb1
zPjXKQggvg+QzzUoCHd722DvQHht4BL6Ffi0ZqeX5yLM+zGmGDdK9Jq6nwRF
Cf8fwi8NYdWJ02HOnwpC2wZyunJFz7joqUVw0PpNQf3+9um5TtHjFL9tFjTa
DZNRBZVZnrrbzYJD1G9SgTvhOIXfrPAZFPwFGpzxpRVZdxA6pueGHe6a9d9E
CKMX3pr1FiD0krCVmvNRCEQ33kdDBfUzeWQ8tq6v2KChh/ANvz3ky0YNZ8f+
tEx+QNg24utaYOr5dQbhvpFZa+r5eVhvwS/KK0pz3qMIN/ZeyRxL1KyzUfgn
az5XjxBIOGc0+/8UYTTPEM8UPUNS2zX7PCvn7cLf2+JzduG/z+I8szXjxlus
x6FZZ4TFPAs09BFBXwsayO88zX6+R0ii+cjQEEL5VUteJzXjZiG0k7+HNUQT
MZPnMPEJ1TzPHxG2mDiag6TfCDIvP83zUIXsq8ljNW04jkCPaz01z8Mx2e8q
fl6W+f6reH8Twm4yZk6+x3qZ59+K/UmW/KZkvryQ5+iF4hzjEJ5T/i0y/4WC
X6XgNulLkfqqYn9ipV+xvN+B7HexzOMmZJ6mntflgZz7JfkfLBG8//4n/wAn
LwFL
                "], {{648.8359999999999, 326.855}, {646.438, 
                329.01599999999996`}, {644.7850000000001, 331.074}, {645.164, 
                331.43399999999997`}, {645.543, 331.79299999999995`}, {
                645.9689999999999, 331.895}, {646.113, 331.66}, {646.254, 
                331.42999999999995`}, {648.215, 329.367}, {650.4649999999999, 
                327.082}, {655.6519999999999, 321.82}, {654.586, 321.672}, {
                648.8359999999999, 326.855}}, CompressedData["
1:eJxdVGtIVEEY3RYTMZNNIkVcsyWyB6VFYGLSMRWTCKkfISolS8JSZEvcqS2k
mLmEKISIhVGE1VaSREhtJhEWPVT6IZI9aM2sNOxBmaaklNTMnW9bcGG5fHNn
znfO+c7cJe4DOyrsNpstX/7Vs+3nzHPfS44r5x6ntH43YFO/JxzOkj1Zg06G
H82dWzM6OU583d6enM2QHf3K7+3nkKs1OV4GR3FmoPsLx+GOpsS00ww1OeUf
e8c4utT7swwbB4tONsYIfa6BYYHa7xRoSIjYGVvH0FgZZz7YLHBV9Q/h7RKY
v/rm+dEihiFF7LjQz5WEd0HgjDrnYCiMsa+qvivwTi5XRjNUL3rd86tX4FK+
VBbB0LfN7SgeEtg/8vvamD1cW/rmhmuLdxTT+oNC60llCHQf6mjqIf6FDA8n
l5fV3RK4rdalPsu/gICCK/LT+T7Sc5ChVK2PE1+QP/Gm1rOO8PaZ8NR/q9qU
QXinTGx5f3ThjUyGxcr4KlPz8JDeUlP728I0bgXhtTKorp5aE72u/uljXvL7
uqn7ric9LYSXzvBBtilwm3jh+7xsrYvwc02MP5PGJNG8XYSXQv5GUr2G4bJX
7hgQUHTKc5nW8YbmK+sjEjZqWCBtYGkkTyX8TwKS9dOL8eTHKPkp52f5PhGu
rXlPzXr/R+CR8s0eri0fpoz/tZWHoKF5+YnPpIFYlSuf0PpCeuKF9lNQHucR
Xi3Tc5zg2p8q0jvCtd8GnQ9yKJqVZaQvdJ/yyP8ujnSlP9T/L9f5vmNg7z2j
IUH2t9ZnDO2HvB9WvzjyM4nyn0LzcFBeNzComBTYyJ8S6jeH8rqbIUsRk/gq
FvXyPln9UgXak2Ww8si/FdR/2tD3L1Fo/m8NnY9owrtvQG1rHqb7321g9vfj
H3Wl+0g=
                "], CompressedData["
1:eJxTTMoPSmViYGAQBmIQbct1fXFBSLPDTrnW14GbSh2iUqzv+3s0Q+iTpQ6d
jglPLwQ2O+Q8/73y47lSh/J986X0O5odckH8C6UOYP2nmx3076qwNV4udXhY
JbLO/UuzgyzIgJelDts+/71SodLiMD1PqPmAWplD1p6SyRLeLRD14WUOh79q
xPSHtkDU+5Y5THPuznlu0AKxX7oMop+/xSFj4tsa+7dQ991udrDacqJsH9B9
7WI3z31fAXXfvlIHm/v+vdMnNDt4gByyE+r+kmaHB0DhPKD/3i8/5m2e3Qxx
z7pSB91Nc98vT2x2APp+h9zqUocjChuKMsKh8mug/kMKHwAzJJYO
                
                "], CompressedData["
1:eJxdVGtIFFEU3raIkpAeIpFWJoE9FNMyk7Q9lmJlKho5s45uu+O+lDJ7kFEm
Rtw7SYlJ5QMpMzMpRCKWEPOFlmlBiAYSi4hZ9qMiI7IkpO7dc3GhgdmZs/fc
73znO9+dDeqJDJtep9MlsZs/8zvO3FhdRUDHr20yFHXVrwl3EaguWHm555UM
seNp5dUD3vWRFHW5PEkgfGzj4ks2CZrqngc91lPYd/XYpz95ErDolDOQQhpL
i4mVwTVwtqs+hMJfflXLsJ58Tm+LoHDaWfm1eFSGK/Hmj0ORFJ7+mHt7blCG
Kg60ncKX9LZ15JmId4n8Ihl8w57c/hZHwWe0sTAuUoaJ836tSQkUTO0Hlund
EvJLpzA1FOyebZUw30nhoiHK1N4gwaHosngzEfUqJeyrXOA3S5Bl3T2eViPw
t8iwQo5xDTRR6GQyLeqXIZnv76Mwsym7ojdMRhw/DdyzJfkd1zIhlJVrNmi4
f68McfwlQIMALthDBest1UDzf/fmV24OTHIBV2lwL5EhZZuAdbFVS9XgJS+0
3wy9P1khhwZcpuBuM3jmVawhnz2W+TgkYklLoOqN1/JG6izIr0iDI1yIRgvk
VDDETFHvrgXyWNuGnRqw3yjTHQvqHaohrxYLPgNFvRkLlHEiOtFfgYr96TXs
67eKfQUJPa7n4jxiNLjAxjThY0V+vqK/UisoXO8ZCt3MdmM9VvTPawqrmPsa
jDb0YSvFfkZsuF4g5jNlR37hFB59H05RnQ70o5sAY3F4kjhwfyNBvFoH3C/k
jAnmT9uRL4s9eP52OMj17yRQzjcm2HDeCylwexgmchEvg6KPUlT0i0yhhv/v
q+K5UIQ/5o7CdHN/crSJIl5pNuIkCf7DCnCbljD/e/TaoWA/m0V+kILzmiLo
3wUK1n1AIJXL+iELda8leP4Gs+A9Pw+UYJ3ELHjB9TpOoIHP+6YR8+1iPcqI
+psIJPD98TLqYxT4Lgn9rIjzfkvCeTu9sQfvpDfu434lZP48/v99+Qe+3O82

                "], CompressedData["
1:eJxdVGtIlEEU3SKyLKWHRQ8TszJ7qohEmXmzRDPDHuqPqNhvx91ZNEsyCuyb
AemlQpmFJGlIWdFDxR5GVFZU9ISwB2RYbGbij7DSUjExmpk77RctLLuHuXPP
PefeudMd29c7h9psts3iK383ZsZ4Ut8ymB05oibwhB0iPswcXtDO4NDxbeP2
3rPDsUnDMvy7GHSacdFbflt48bUnu+7MMLz48epFRcs3GZDUmh9QN8ggdHhB
2YpsA+NiONytmhL+wTQwzwGOfEcNuN8TtqkkjUO45G01INb3bXXuZA5L5L04
B9jkJ4CDTG8vckDb2YqHwUk6vkifmxb2X3Dl5LfXHFJkfI8DlL5WDvu/rLsR
lEAwroPDKEETm0VAiHx2qk3zVRBoCmnp5806voEg7y0OGTJxHwEZVrWPw3h5
r5PASxmfz7GOMwSC63e4S7drvWkE3KVC8WYOuVKYwHMPTnz3IopDvL29KaSa
wDKpt4chz+RMzPOTwbsXfRva/JyQ0zFwoSuCw6WuV2sclU7kXcMhTyb2OPGe
wNOk0DYnlMu2hen657jQzyEc0mX9eS70Q/R3luyPD8V6+hj6MZd6+6f8i6ag
xiCQw2H5Zz6FPQF1ia1LOfo0kcID2b8sjvn6XNhP0Q91r9eF9ZVwuCjrD6Bw
I0hU9oSjvhwKDdLPYg6nE67/GPxI0a9w7fdjiv766n42Uqx/gHnPu0XaMb0M
egXt/U6Nuxnm9XWjLy8Z8ke4UV8tQ5/i3ejvVgY7JDFxoy6Bt9xcNXroP1jV
O9LCag7PU9S7luEclVHs/1TN94Zi/HcTSmSgjxt9eWTivHmoF6u+77Ow0r2Q
YlyXCY+kkcMo5Ev/l+n36q/15mv9EyjGmRo3uvB8JYMjkj/OBYlS/9/6PjsR
x2hc6MT3nK3fs82Jc0QZNO4UJ0GZ6H8UwzmsJXBO2FDvy/BdpRPkE3qVP5UE
8z03QY5h7G8CnlSxWcpN3AviPan5KTbR7xKC81pgwle5J5IJ9qdQn88j+L6v
6nyfHCCmor2pycQ5u+zA+F+mdx+ofoxlXqzqXmVhxZfIcO4iHbD7jni4flp/
s4F99Zg4T2JfKX2hDN7386zbYp8p/hQGLRLnGt75UP3ZaOFX8jfZwiqfv4F+
ntT+p9nxHdRYWPFdt7Dy86nev3l2+H9//wHKOZ9v
                "], CompressedData["
1:eJxNVWtsFFUYbRpDGi0E26YhgstDRSwh5WVMRfCIBVQkaAlo5BHS3YGZO1Mo
FUoVvDMbIg8JtBUNAsHyEBOThodKKWhaUgoFf/CQWm1lgaaxlSglUG1jGhLv
d7/LLJtsJmfn3u873znn3h1ZuLLASk1JSSlUX3o6lbfXv1wT4OO/3q6NHI9C
45YACwaN+3ZvVxSvp6eO3TQ0jkd/PVg89edYiDsO7WkckW6FWO16fknEQuOI
oyV2WhxXRv3+nyyx8MGt0RPS7gZYfEqtbLLw5HuxKTfqAxyYUdNzv2wZ3nxh
yytLPwlQPFV1+Go511sf8Lp5Nugxd02AZwbEP3/1iM31Cwy/2Q7zuOkz/wsC
3cSjTaK+6oncRKMHr6v/m7vbJY6fL62r+tLDNBrEksjccPqn/Vs8qO5/XJ4o
MYwarfVwY+62nSsikvsprPv3f8Tzl3qgtncUfnZCWvWwEo/r5ki0Xuyb1/Gc
x7wXmvoJl+fcJ/EY7c8x+zskz7vaQ21EMe+UzH+Nh4Z/xywq75awyYc8D7NJ
nx7J/bM9FNE8f5r6rS7zbZHcp9rFZdK9UaJXlWmIuzhJ9U9JqF/Fj2+5yPte
Ea6XrBtcrK1TQp2VqKDGuS7z+05i+84VGRvSXRDN4l2S/bwnmK8t2e8GgV/K
lMEzJc/9lGB+XhJrXcuTWOt9zfBrF9zvqkT+VuXUSJfnvSSxLuvwrPbpLsju
yiuGf8zl/b8ZvYpcEM3TvRJNtLHC5X3/SExXy0b1i1Af7c8xEepDMlRtFKE+
GaTnfBHqo/OTL0J9zlH9ySLUR/N8XIT6lJN+fQ7XVfqUkIFNJp9KnzbiP8a8
95JY8/40iXX9hOR8XXc4D80P9BGY1f5h1uFLhu8MEeqTm3h6QNwRoT56/SrB
ufj7Qd6NH30SKfTJEthM6ztNPtscvEb1EyYPPzgYuym79WLC5LHSwY4hjywY
1CXxIg2y0kEOve8z52WSE9bTPtTZGEjzNEl8QT7ttvG1kuOo0ns0rd9q8zxn
JK7R/J7N+ncYP1+y+Znhsx69y9n3TJ/rdSexnrN2WYj1+hqLczrEZ37vW5zX
8T6fp5kW83zDx3wSPtNiv+f47N9DWOuVn8T0SJRZ7MM6n/U9abF++5NY169O
4iV0D/b4Jt8WIppwwOfhWAyLKEj5Ad4hPsNjuDqncPC7bsD5OhjlvJUG7M+e
KE703G8uiwfMd0cUZykQ2wKjbxTanoqA+W429/lnAZ+DjVG+3w4FfG/uNvf/
Q/8H/wPhWdiy
                "], {{484.76599999999996`, 196.805}, {
                484.76599999999996`, 199.41}, {479.387, 202.195}, {472.953, 
                202.918}, {467.758, 203.5}, {467.672, 203.465}, {467.672, 
                200.871}, {467.672, 198.72299999999998`}, {
                468.48799999999994`, 197.879}, {472.074, 196.316}, {
                477.83599999999996`, 193.809}, {484.76599999999996`, 
                194.07399999999998`}, {484.76599999999996`, 196.805}}, {{
                490.66400000000004`, 197.04299999999998`}, {493.289, 
                199.42200000000003`}, {494.53099999999995`, 202.254}, {
                492.953, 202.254}, {491.137, 202.254}, {486.32, 197.93}, {
                486.32, 196.30100000000002`}, {486.32, 193.758}, {487.215, 
                193.91}, {490.66400000000004`, 197.04299999999998`}}, {{
                485.07, 204.75}, {485.29299999999995`, 206.22299999999998`}, {
                484.383, 207.20299999999997`}, {481.65200000000004`, 
                208.43800000000002`}, {475.77, 211.094}, {468.734, 212.324}, {
                467.039, 210.99200000000002`}, {463.91799999999995`, 
                208.539}, {465.9959999999999, 205.24599999999998`}, {471.039, 
                204.65200000000002`}, {473.07, 204.414}, {475.824, 203.797}, {
                477.16, 203.277}, {481.03499999999997`, 
                201.77299999999997`}, {484.72299999999996`, 
                202.45700000000002`}, {485.07, 204.75}}, {{485.07, 
                212.63299999999998`}, {485.387, 214.73}, {484.043, 
                215.48000000000002`}, {473.08599999999996`, 219.34}, {
                464.90599999999995`, 222.21899999999997`}, {
                461.28499999999997`, 220.859}, {463.89799999999997`, 
                215.895}, {464.809, 214.164}, {466.34000000000003`, 
                213.375}, {469.76599999999996`, 212.859}, {472.316, 
                212.477}, {475.801, 211.73}, {477.508, 211.19899999999998`}, {
                482.074, 209.781}, {484.715, 210.281}, {485.07, 
                212.63299999999998`}}, {{490.562, 220.02}, {492.215, 
                221.695}, {493.566, 223.672}, {493.566, 224.414}, {493.566, 
                226.816}, {487.039, 222.562}, {486.207, 219.617}, {485.207, 
                216.08200000000002`}, {486.824, 216.23}, {490.562, 
                220.02}}, {{485.074, 220.516}, {485.43399999999997`, 
                222.906}, {481.457, 225.062}, {473.637, 
                226.72299999999998`}, {467.902, 227.941}, {465.371, 227.25}, {
                465.801, 224.586}, {466.03499999999997`, 223.129}, {467.945, 
                222.066}, {473.367, 220.375}, {482.039, 217.668}, {484.648, 
                217.69899999999998`}, {485.074, 220.516}}, CompressedData["
1:eJxTTMoPSmViYGCQB2IQrX9Xha3xdJ1DgS3X9cVfchy02sVunsuud+g/9FUj
pjnXweNhlci6ynoHNbbGqc6v8xwuKt3+WfeozuGbRkz/Ic98B8stJ8r2La5z
WOS67fPfgnwHd5D66joH2agU6/vRUH5ynQOQdH/Ilu+QMfFtjX0gVP/RPAfF
DUUZE2PrHCaA7PPPc5ieJ9R8oAzBB6uvR/CvVrxUM2yrc/A273RMsETwtwKd
MV8OwRduPnBq4cJcB5C3CibWQtyXkeswWYIljE+31mEGyJ5zuQ5WIPdz1kL8
9SnX4YF/7/S8XzVw+8D+E6+F88HhoYvgV4P8ZVPrcPPc9+DHa6HyhrUOQNOy
9nzIc3hXY28ap1QLCQ/vfIcLIHu+1DgUgzyWnQ8R31gDCX+PfAchkLulaxxc
unOe//6ZB4kP+RqHffOl9O/OyHUA+vrphR01DnG7PHmYmHMdjoECwqzW4fHS
2UcUOnIcQMb5e9Y5FILMa8hxQI9fAIGY6Mg=
                "], CompressedData["
1:eJxTTMoPSmViYGBQAmIQbbnlRNm+9DqH1teBO+Q48xwmS7CE8RXWOczIE2o+
IJXnsMh12+e/OXUO3zRi+g+Z5jnYcV1fXBBb5wCibP3yHLzNOx0TrOscwOY0
5zmU75svpW9b51CUMfFtzeU8h8NfgRqToObp5TuAlM2vq3NQZWuc6lyc73C1
4qWaYRPU/Jv5DlrtYjfPddc5yEalWN//WOhwQen2z7o5dQ65z3+v/JhT6jAd
ZM49qHu5Kxw+XfJNEjCrd+DT3TT3/eoKB6Brnl6IgPJfV0Do4HqIPW8qHB4v
nX1E4VcdxJ/rKxze1tibxrXVOeyQA5qYUOFwDOQhvToHK5BDf5ZD9D2odYjd
5cnDlF4Osd+n1kEb5M7AMgeFDUCfStZCwulOCZwPdt/BQjj/Esgfv6D+l6mF
2NOSD7HfrBYSHvr5Dh0g9/vVOlwEqb+XB3FvQK0DkJe150CeQw4oHOyg5mXl
QcLLuBYSvkZ5EPfp1TqAgt/+b66D+8MqkXVAeXB4fs6F2B9S6wBUdWrh1lyI
/S51DuqGHGtkjuU6oKcHAMJ3/wg=
                "], CompressedData["
1:eJxTTMoPSmViYGCQA2IQfVRhQ1HG1UaHY97mnY5hRQ7TnLtznl9vdODT3TT3
fWyRwxXfJIGIS40O0/OEmg+0FDl8ugQUONnocOirRkz/miIIvavRYeuJsn3z
XxU5zACp29LoUC2yzv3hlyKHrD0lkyUWIPi2XNcXF8Qj+J48TNrt3xscls4+
orBBr9gB5IyEngaHqxUv1Qz7ih0uKN3+WefXABE/WuzwGKTQsgHijkvFDvKt
rwN3GDY4MIDAkWIHgQjLLSfkGiDqFhQ7ZE58W2Nv1+AQtwtok3exQ7vYzXPf
8xog/pUrdqjYN19Kf1YDxB/fihwqgdZyCDc6aIMUHi1yiO0Hyngh+GBzsxB8
magU6/tAfu7z3ys/HipyWAbyR0Sjww45oMP6ihxA0v7ejQ7AUDm1ML3IYdvn
v1cq8hsdrLYAAyy1COKvZmj4phQ5LC4AhtC8Roi/44og9JpGB15QfIRD3Xeh
0aHDMeHpBTeofiQ+enwCAHk04P4=
                "]}]}},
            AspectRatio->Automatic,
            ImageSize->{{128}, {85}},
            PlotRange->{{0., 960.}, {0., 480.}}], ",", 
           GraphicsBox[{
             {Thickness[0.0010416666666666667`], 
              {FaceForm[{RGBColor[0.890196, 0.0392157, 0.09019610000000002], 
               Opacity[1.]}], 
               FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0., 
                0.}, {0., 640.}, {960., 640.}, {960., 0.}}}]}, 
              {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
               FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}}}, {{{500., 320.}, {500., 231.63299999999998`}, {428.367, 
                160.}, {340., 160.}, {251.63299999999998`, 160.}, {180., 
                231.63299999999998`}, {180., 320.}, {180., 408.367}, {
                251.63299999999998`, 480.}, {340., 480.}, {428.367, 480.}, {
                500., 408.367}, {500., 320.}}}]}, 
              {FaceForm[{RGBColor[0.890196, 0.0392157, 0.09019610000000002], 
               Opacity[1.]}], 
               FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}}}, {{{508., 320.}, {508., 249.309}, {450.691, 192.}, {380.,
                 192.}, {309.309, 192.}, {252., 249.309}, {252., 320.}, {252.,
                 390.691}, {309.309, 448.}, {380., 448.}, {450.691, 448.}, {
                508., 390.691}, {508., 320.}}}]}}, 
             {RGBColor[1., 1., 1.], 
              PolygonBox[{{521.9449999999999, 302.03905243264535`}, {
               521.9449999999999, 243.914}, {556.1093226919377, 
               290.9381676425142}, {611.387, 272.977}, {577.2235256317572, 
               320.}, {611.387, 367.02299999999997`}, {556.1093226919377, 
               349.06183235748574`}, {521.9449999999999, 
               396.08599999999996`}, {521.9449999999999, 
               337.96094756735465`}, {466.668, 320.}}]}},
            AspectRatio->Automatic,
            ImageSize->{{128}, {85}},
            PlotRange->{{0., 960.}, {0., 640.}}], ",", 
           GraphicsBox[
            {Thickness[0.0010416666666666667`], 
             {FaceForm[{RGBColor[
              0.854902, 0.14509800000000003`, 0.11372500000000002`], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               0., 0.}, {0., 720.}, {960., 720.}, {960., 0.}}}]}, 
             {FaceForm[{RGBColor[1., 1., 0.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{480., 504.}, {435.5,
                367.047}, {526.805, 337.383}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{480., 504.}, {524.5,
                367.047}, {433.195, 337.383}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{616.953, 404.5}, {
               472.953, 404.5}, {472.953, 308.5}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{616.953, 404.5}, {
               500.453, 319.855}, {444.027, 397.52299999999997`}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{564.641, 243.5}, {
               520.145, 380.453}, {428.84000000000003`, 350.789}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{564.641, 243.5}, {
               448.14500000000004`, 328.14500000000004`}, {504.57, 
               405.809}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{343.047, 404.5}, {
               487.047, 404.5}, {487.047, 308.5}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{343.047, 404.5}, {
               459.547, 319.855}, {515.9730000000001, 397.52299999999997`}}}],
               FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
               395.35900000000004`, 243.5}, {439.855, 380.453}, {531.16, 
               350.789}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{395.35900000000004`,
                243.5}, {511.855, 328.14500000000004`}, {455.42999999999995`, 
               405.809}}}]}},
            AspectRatio->Automatic,
            ImageSize->{{128}, {85}},
            PlotRange->{{0., 960.}, {0., 720.}}], ",", 
           GraphicsBox[
            {Thickness[0.00078125], 
             {FaceForm[{RGBColor[0.007843139999999998, 0.309804, 0.635294], 
              Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0., 
               0.}, {0., 640.}, {1280., 640.}, {1280., 0.}}}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0., 
               533.3319999999999}, {1280., 533.3319999999999}, {1280., 
               106.66799999999984`}, {0., 106.66799999999984`}}}]}, 
             {FaceForm[{RGBColor[
              0.9294119999999999, 0.109804, 0.15294100000000005`], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               0., 515.555}, {1280., 515.555}, {1280., 124.44599999999991`}, {
               0., 124.44599999999991`}}}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{568.891, 320.}, {568.891, 241.453}, {505.215, 
               177.777}, {426.668, 177.777}, {348.121, 177.777}, {284.445, 
               241.453}, {284.445, 320.}, {284.445, 398.547}, {348.121, 
               462.22299999999996`}, {426.668, 462.22299999999996`}, {505.215,
                462.22299999999996`}, {568.891, 398.547}, {568.891, 320.}}}]}, 
             {FaceForm[{RGBColor[
              0.9294119999999999, 0.109804, 0.15294100000000005`], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{426.668, 
               457.777}, {384.09, 326.742}, {449.60900000000004`, 305.457}}}],
               FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{426.668, 
               457.777}, {469.242, 326.742}, {403.727, 305.457}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{557.6990000000001, 
               362.574}, {419.92199999999997`, 362.574}, {419.92199999999997`,
                293.688}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{557.6990000000001, 
               362.574}, {446.23799999999994`, 281.594}, {405.746, 
               337.324}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{295.633, 362.574}, {
               407.09799999999996`, 281.594}, {447.59, 337.324}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{295.633, 362.574}, {
               433.40999999999997`, 362.574}, {433.40999999999997`, 
               293.688}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{507.65200000000004`,
                208.535}, {465.074, 339.57}, {399.559, 
               318.28099999999995`}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{507.65200000000004`,
                208.535}, {396.188, 289.52}, {436.676, 345.25}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{345.684, 208.535}, {
               457.148, 289.52}, {416.656, 345.25}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{345.684, 208.535}, {
               388.258, 339.57}, {453.777, 318.28099999999995`}}}]}},
            AspectRatio->Automatic,
            ImageSize->{{128}, {85}},
            PlotRange->{{0., 1280.}, {0., 640.}}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           GraphicsBox[
            {Thickness[0.0011111111111111111`], 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0., 
               0.}, {900., 0.}, {900., 600.}, {0., 600.}}}]}, 
             {FaceForm[{RGBColor[0.91, 0.067, 0.17600000000000002`], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}}}, {{{389.99969999999996`, 600.0003}, {
               389.99969999999996`, 
               360.00030000000004`}, {-0.0003000000000383807, 
               360.00030000000004`}, {-0.0003000000000383807, 
               240.00030000000004`}, {389.99969999999996`, 
               240.00030000000004`}, {389.99969999999996`, 
               0.0003000000000383807}, {510.00069999999994`, 
               0.0003000000000383807}, {510.00069999999994`, 
               240.00030000000004`}, {899.9997, 240.00030000000004`}, {
               899.9997, 360.00030000000004`}, {510.00069999999994`, 
               360.00030000000004`}, {510.00069999999994`, 600.0003}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{172.9215, 539.9021999999999}, {180.2365, 
               501.41219999999987`}, {180.2365, 461.88819999999987`}, {
               172.9215, 423.39819999999986`}, {186.4875, 
               425.09019999999987`}, {200.2125, 425.09019999999987`}, {
               213.7785, 423.39819999999986`}, {206.4635, 
               461.88819999999987`}, {206.4635, 501.41219999999987`}, {
               213.7785, 539.9021999999999}, {200.2125, 538.2091999999999}, {
               186.4875, 538.2091999999999}, {172.9215, 539.9021999999999}}}],
               FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{251.6022, 502.07849999999996`}, {213.1122, 
               494.76349999999996`}, {173.5882, 494.76349999999996`}, {
               135.09820000000002`, 502.07849999999996`}, {
               136.79020000000003`, 488.5125}, {136.79020000000003`, 
               474.78749999999997`}, {135.09820000000002`, 461.2215}, {
               173.5882, 468.53649999999993`}, {213.1122, 
               468.53649999999993`}, {251.6022, 461.2215}, {249.9092, 
               474.78749999999997`}, {249.9092, 488.5125}, {251.6022, 
               502.07849999999996`}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{686.2215, 176.6022}, {693.5365, 138.1122}, {693.5365, 
               98.5882}, {686.2215, 60.098200000000006`}, {699.7875, 
               61.79020000000001}, {713.5125, 61.79020000000001}, {727.0785, 
               60.098200000000006`}, {719.7635, 98.5882}, {719.7635, 
               138.1122}, {727.0785, 176.6022}, {713.5125, 174.9092}, {
               699.7875, 174.9092}, {686.2215, 176.6022}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{764.9021999999999, 138.77849999999998`}, {
               726.4121999999999, 131.46349999999998`}, {686.8881999999999, 
               131.46349999999998`}, {648.3981999999999, 
               138.77849999999998`}, {650.0901999999999, 
               125.21249999999998`}, {650.0901999999999, 
               111.48749999999998`}, {648.3981999999999, 97.92149999999998}, {
               686.8881999999999, 105.23649999999998`}, {726.4121999999999, 
               105.23649999999998`}, {764.9021999999999, 97.92149999999998}, {
               763.2091999999999, 111.48749999999998`}, {763.2091999999999, 
               125.21249999999998`}, {764.9021999999999, 
               138.77849999999998`}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{686.2215, 539.9021999999999}, {693.5365, 
               501.41219999999987`}, {693.5365, 461.88819999999987`}, {
               686.2215, 423.39819999999986`}, {699.7875, 
               425.09019999999987`}, {713.5125, 425.09019999999987`}, {
               727.0785, 423.39819999999986`}, {719.7635, 
               461.88819999999987`}, {719.7635, 501.41219999999987`}, {
               727.0785, 539.9021999999999}, {713.5125, 538.2091999999999}, {
               699.7875, 538.2091999999999}, {686.2215, 539.9021999999999}}}],
               FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{764.9021999999999, 502.07849999999996`}, {
               726.4121999999999, 494.76349999999996`}, {686.8881999999999, 
               494.76349999999996`}, {648.3981999999999, 
               502.07849999999996`}, {650.0901999999999, 488.5125}, {
               650.0901999999999, 474.78749999999997`}, {648.3981999999999, 
               461.2215}, {686.8881999999999, 468.53649999999993`}, {
               726.4121999999999, 468.53649999999993`}, {764.9021999999999, 
               461.2215}, {763.2091999999999, 474.78749999999997`}, {
               763.2091999999999, 488.5125}, {764.9021999999999, 
               502.07849999999996`}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{172.9215, 176.6022}, {180.2365, 138.1122}, {180.2365, 
               98.5882}, {172.9215, 60.098200000000006`}, {186.4875, 
               61.79020000000001}, {200.2125, 61.79020000000001}, {213.7785, 
               60.098200000000006`}, {206.4635, 98.5882}, {206.4635, 
               138.1122}, {213.7785, 176.6022}, {200.2125, 174.9092}, {
               186.4875, 174.9092}, {172.9215, 176.6022}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{251.6022, 138.77849999999998`}, {213.1122, 
               131.46349999999998`}, {173.5882, 131.46349999999998`}, {
               135.09820000000002`, 138.77849999999998`}, {
               136.79020000000003`, 125.21249999999998`}, {
               136.79020000000003`, 111.48749999999998`}, {
               135.09820000000002`, 97.92149999999998}, {173.5882, 
               105.23649999999998`}, {213.1122, 105.23649999999998`}, {
               251.6022, 97.92149999999998}, {249.9092, 
               111.48749999999998`}, {249.9092, 125.21249999999998`}, {
               251.6022, 138.77849999999998`}}}]}},
            AspectRatio->Automatic,
            ImageSize->{{128}, {85}},
            PlotRange->{{0., 900.}, {0., 600.}}], ",", 
           GraphicsBox[
            {Thickness[0.001388888888888889], 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0., 
               480.}, {720., 480.}, {720., 240.}, {0., 240.}}}]}, 
             {FaceForm[{RGBColor[0.8352940000000001, 0.168627, 0.117647], 
              Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0., 
               240.}, {720., 240.}, {720., 0.}, {0., 0.}}}]}, 
             {FaceForm[{RGBColor[0., 0.223529, 0.65098], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0., 
               320.}, {720., 320.}, {720., 160.}, {0., 160.}}}]}},
            AspectRatio->Automatic,
            ImageSize->{{128}, {85}},
            PlotRange->{{0., 720.}, {0., 480.}}], ",", 
           GraphicsBox[
            {Thickness[0.001893939393939394], 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0., 
               0.}, {0., 384.}, {528., 384.}, {528., 0.}}}]}, 
             {FaceForm[{RGBColor[
              0., 0.21960800000000003`, 0.7215689999999999], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0., 
               348.}, {528., 348.}, {528., 288.}, {0., 288.}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0., 
               96.}, {528., 96.}, {528., 36.}, {0., 36.}}}]}, 
             {RGBColor[0., 0.21960800000000003`, 0.7215689999999999], 
              Thickness[0.024999999999999998`], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{264., 261.938}, {
               203.43, 157.031}, {324.57, 157.031}}},
               CurveClosed->{1}]}, 
             {RGBColor[0., 0.21960800000000003`, 0.7215689999999999], 
              Thickness[0.024999999999999998`], Opacity[1.], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{264.00000000000006`,
                122.06200000000018`}, {324.56999999999994`, 
               226.96900000000002`}, {203.43000000000004`, 
               226.96900000000002`}}},
               CurveClosed->{1}]}},
            ImageSize->{{128}, {85}},
            PlotRange->{{0, 528}, {36, 348}}], ",", 
           GraphicsBox[
            {Thickness[0.0008333333333333334], 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0., 
               0.}, {0., 720.}, {1200., 720.}, {1200., 0.}}}]}, 
             {FaceForm[{RGBColor[
              0.8078430000000001, 0.06666670000000002, 0.14902], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{1200., 720.}, {296., 720.}, {
               480., 648.}, {296., 576.}, {480., 504.}, {296., 432.}, {480., 
               360.}, {296., 288.}, {480., 216.}, {296., 144.}, {480., 72.}, {
               296., 0.}, {1200., 0.}}}]}},
            AspectRatio->Automatic,
            ImageSize->{{128}, {85}},
            PlotRange->{{0., 1200.}, {0., 720.}}], ",", 
           GraphicsBox[
            {Thickness[0.0015625], 
             {FaceForm[{RGBColor[
              0.8784310000000001, 0., 0.14509800000000003`], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0., 
               308.202}, {640., 308.202}, {640., 103.40099999999998`}, {0., 
               103.40099999999998`}}}]}, 
             {FaceForm[{RGBColor[0.011764699999999998`, 0.180392, 0.631373], 
              Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0., 
               410.6}, {640., 410.6}, {640., 308.202}, {0., 308.202}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0., 
               103.40100000000001`}, {640., 103.40100000000001`}, {640., 
               0.9990000000000094}, {0., 0.9990000000000094}}}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{317.59, 285.811}, {
               317.59, 285.811}, {317.441, 290.022}, {319.895, 290.069}, {
               322.348, 290.022}, {322.199, 285.811}, {322.199, 
               285.811}}}]}, 
             {Thickness[0.0012000000000000001`], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{317.59, 
               285.811006}, {317.59, 285.811006}, {317.441, 
               290.02200600000003`}, {319.895, 290.069006}, {322.348, 
               290.02200600000003`}, {322.199, 285.811006}, {322.199, 
               285.811006}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {0,
                1, 0}, {0, 1, 0}}}, {{{418.93399999999997`, 175.721}, {
               418.93399999999997`, 196.73299999999998`}, {419.617, 
               199.39700000000002`}, {421.879, 201.756}, {423.582, 202.225}, {
               423.582, 221.93200000000002`}, {421.012, 
               221.93200000000002`}, {419.75, 218.58}, {419.75, 218.58}, {
               415.375, 199.319}, {415.375, 175.88100000000003`}}}]}, 
             {Thickness[0.0012000000000000001`], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {0,
                1, 0}, {0, 1, 0}}}, {{{418.93399999999997`, 
               175.72100600000002`}, {418.93399999999997`, 196.733006}, {
               419.617, 199.39700600000003`}, {421.879, 201.756006}, {423.582,
                202.225006}, {423.582, 221.932006}, {421.012, 221.932006}, {
               419.75, 218.580006}, {419.75, 218.580006}, {415.375, 
               199.319006}, {415.375, 175.88100600000004`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{374.449, 
               217.545}, {380.75800000000004`, 217.545}, {380.75800000000004`,
                204.178}, {374.449, 204.178}}}]}, 
             {Thickness[0.001292146875], CapForm["Round"], JoinForm["Round"], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{374.449, 
               217.545006}, {380.75800000000004`, 217.545006}, {
               380.75800000000004`, 204.178006}, {374.449, 204.178006}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{262.316, 
               217.545}, {378.847, 217.545}, {378.847, 172.70499999999998`}, {
               262.316, 172.70499999999998`}}}]}, 
             {Thickness[0.0012000000000000001`], CapForm["Butt"], JoinForm[
              "Round"], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{262.316, 
               217.545006}, {378.847, 217.545006}, {378.847, 172.705006}, {
               262.316, 172.705006}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}}}, {{{221.262, 175.79899999999998`}, {
               221.262, 196.73299999999998`}, {220.578, 
               199.39700000000002`}, {218.316, 201.756}, {216.61299999999997`,
                202.225}, {216.61299999999997`, 220.651}, {220.445, 218.58}, {
               224.82000000000002`, 199.319}, {224.82000000000002`, 
               175.79899999999998`}}}]}, 
             {Thickness[0.0012000000000000001`], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}}}, {{{221.262, 175.799006}, {221.262, 
               196.733006}, {220.578, 199.39700600000003`}, {218.316, 
               201.756006}, {216.61299999999997`, 202.225006}, {
               216.61299999999997`, 220.65100600000002`}, {220.445, 
               218.580006}, {224.82000000000002`, 199.319006}, {
               224.82000000000002`, 175.799006}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {0,
                1, 0}, {0, 1, 0}}}, {{{221.262, 175.721}, {221.262, 
               196.73299999999998`}, {220.578, 199.39700000000002`}, {218.316,
                201.756}, {216.61299999999997`, 202.225}, {
               216.61299999999997`, 221.93200000000002`}, {
               219.18800000000002`, 221.93200000000002`}, {220.445, 218.58}, {
               220.445, 218.58}, {224.82000000000002`, 199.319}, {
               224.82000000000002`, 175.88100000000003`}}}]}, 
             {Thickness[0.0012000000000000001`], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {0,
                1, 0}, {0, 1, 0}}}, {{{221.262, 175.72100600000002`}, {
               221.262, 196.733006}, {220.578, 199.39700600000003`}, {218.316,
                201.756006}, {216.61299999999997`, 202.225006}, {
               216.61299999999997`, 221.932006}, {219.18800000000002`, 
               221.932006}, {220.445, 218.580006}, {220.445, 218.580006}, {
               224.82000000000002`, 199.319006}, {224.82000000000002`, 
               175.88100600000004`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{216.73, 
               170.354}, {218.535, 171.272}, {220.59, 173.409}, {221.262, 
               175.79899999999998`}, {418.97299999999996`, 
               175.79899999999998`}, {419.64500000000004`, 173.409}, {421.699,
                171.272}, {423.504, 170.354}}}]}, 
             {Thickness[0.0012000000000000001`], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{216.73, 
               170.35400600000003`}, {218.535, 171.27200599999998`}, {220.59, 
               173.409006}, {221.262, 175.799006}, {418.97299999999996`, 
               175.799006}, {419.64500000000004`, 173.409006}, {421.699, 
               171.27200599999998`}, {423.504, 170.35400600000003`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{372.828, 
               192.791}, {376.5, 192.791}, {376.5, 175.9}, {372.828, 
               175.9}}}]}, 
             {Thickness[0.0012000000000000001`], CapForm["Round"], JoinForm[
              "Round"], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{372.828, 
               192.791006}, {376.5, 192.791006}, {376.5, 
               175.90000600000002`}, {372.828, 175.90000600000002`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{262.316, 
               201.135}, {378.847, 201.135}, {378.847, 195.92399999999998`}, {
               262.316, 195.92399999999998`}}}]}, 
             {Thickness[0.0012000000000000001`], CapForm["Butt"], JoinForm[
              "Round"], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{262.316, 
               201.135006}, {378.847, 201.135006}, {378.847, 195.924006}, {
               262.316, 195.924006}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{262.316, 
               208.202}, {378.847, 208.202}, {378.847, 203.60399999999998`}, {
               262.316, 203.60399999999998`}}}]}, 
             {Thickness[0.0012000000000000001`], CapForm["Butt"], JoinForm[
              "Round"], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{262.316, 
               208.20200599999998`}, {378.847, 208.20200599999998`}, {378.847,
                203.60400599999997`}, {262.316, 203.60400599999997`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{262.316, 
               215.256}, {378.847, 215.256}, {378.847, 210.799}, {262.316, 
               210.799}}}]}, 
             {Thickness[0.0011818156249999998`], CapForm["Butt"], JoinForm[
              "Round"], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{262.316, 
               215.256006}, {378.847, 215.256006}, {378.847, 
               210.79900600000002`}, {262.316, 210.79900600000002`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{374.449, 
               217.545}, {380.75800000000004`, 217.545}, {380.75800000000004`,
                204.178}, {374.449, 204.178}}}]}, 
             {Thickness[0.001292146875], CapForm["Round"], JoinForm["Round"], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{374.449, 
               217.545006}, {380.75800000000004`, 217.545006}, {
               380.75800000000004`, 204.178006}, {374.449, 204.178006}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {1, 3, 3}}}, {{{421.484, 170.354}, {419.715,
                171.155}, {417.137, 173.342}, {417.137, 175.545}, {417.137, 
               201.70499999999998`}, {418.348, 203.866}, {373.78099999999995`,
                203.866}, {375.52, 201.70499999999998`}, {375.52, 175.545}, {
               375.52, 173.342}, {373.75, 171.155}, {371.97999999999996`, 
               170.354}}}]}, 
             {Thickness[0.0012000000000000001`], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {1, 3, 3}}}, {{{421.484, 
               170.35400600000003`}, {419.715, 171.15500600000001`}, {417.137,
                173.342006}, {417.137, 175.545006}, {417.137, 201.705006}, {
               418.348, 203.86600600000003`}, {373.78099999999995`, 
               203.86600600000003`}, {375.52, 201.705006}, {375.52, 
               175.545006}, {375.52, 173.342006}, {373.75, 
               171.15500600000001`}, {371.97999999999996`, 
               170.35400600000003`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               292.98799999999994`, 192.791}, {296.65999999999997`, 
               192.791}, {296.65999999999997`, 175.9}, {292.98799999999994`, 
               175.9}}}]}, 
             {Thickness[0.0012000000000000001`], CapForm["Round"], JoinForm[
              "Round"], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               292.98799999999994`, 192.791006}, {296.65999999999997`, 
               192.791006}, {296.65999999999997`, 175.90000600000002`}, {
               292.98799999999994`, 175.90000600000002`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{343.156, 
               192.791}, {346.82800000000003`, 192.791}, {346.82800000000003`,
                175.9}, {343.156, 175.9}}}]}, 
             {Thickness[0.0012000000000000001`], CapForm["Round"], JoinForm[
              "Round"], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{343.156, 
               192.791006}, {346.82800000000003`, 192.791006}, {
               346.82800000000003`, 175.90000600000002`}, {343.156, 
               175.90000600000002`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {1, 3, 3}}}, {{{349.301, 170.354}, {
               347.22299999999996`, 171.155}, {344.203, 173.342}, {344.203, 
               175.545}, {344.203, 200.42800000000003`}, {346.90599999999995`,
                203.866}, {292.863, 203.866}, {295.453, 
               200.42800000000003`}, {295.453, 175.545}, {295.453, 173.342}, {
               293.379, 171.155}, {291.301, 170.354}}}]}, 
             {Thickness[0.0012000000000000001`], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {1, 3, 3}}}, {{{349.301, 
               170.35400600000003`}, {347.22299999999996`, 
               171.15500600000001`}, {344.203, 173.342006}, {344.203, 
               175.545006}, {344.203, 200.428006}, {346.90599999999995`, 
               203.86600600000003`}, {292.863, 203.86600600000003`}, {295.453,
                200.428006}, {295.453, 175.545006}, {295.453, 173.342006}, {
               293.379, 171.15500600000001`}, {291.301, 170.35400600000003`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               302.47299999999996`, 192.791}, {306.145, 192.791}, {306.145, 
               175.9}, {302.47299999999996`, 175.9}}}]}, 
             {Thickness[0.0012000000000000001`], CapForm["Round"], JoinForm[
              "Round"], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               302.47299999999996`, 192.791006}, {306.145, 192.791006}, {
               306.145, 175.90000600000002`}, {302.47299999999996`, 
               175.90000600000002`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               333.51599999999996`, 192.791}, {337.188, 192.791}, {337.188, 
               175.9}, {333.51599999999996`, 175.9}}}]}, 
             {Thickness[0.0012000000000000001`], CapForm["Round"], JoinForm[
              "Round"], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               333.51599999999996`, 192.791006}, {337.188, 192.791006}, {
               337.188, 175.90000600000002`}, {333.51599999999996`, 
               175.90000600000002`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {1,
                3, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}}}, {{{
               291.895, 232.178}, {291.895, 203.86200000000002`}, {347.215, 
               203.86200000000002`}, {347.215, 209.959}, {347.29299999999995`,
                232.178}, {345.03099999999995`, 231.291}, {344.633, 
               229.24099999999999`}, {344.633, 229.24099999999999`}, {344.633,
                217.178}, {294.715, 217.178}, {294.715, 
               229.24099999999999`}, {294.715, 229.24099999999999`}, {294.156,
                231.291}, {291.895, 232.178}}}]}, 
             {Thickness[0.0012000000000000001`], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {1,
                3, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}}}, {{{
               291.895, 232.17800599999998`}, {291.895, 203.862006}, {347.215,
                203.862006}, {347.215, 209.95900600000002`}, {
               347.29299999999995`, 232.17800599999998`}, {
               345.03099999999995`, 231.291006}, {344.633, 229.241006}, {
               344.633, 229.241006}, {344.633, 217.17800599999998`}, {294.715,
                217.17800599999998`}, {294.715, 229.241006}, {294.715, 
               229.241006}, {294.156, 231.291006}, {291.895, 
               232.17800599999998`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}, {1,
                3, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{339.707, 170.354}, {
               337.89799999999997`, 171.155}, {333.96099999999996`, 
               173.342}, {333.96099999999996`, 175.545}, {333.96099999999996`,
                203.389}, {334.348, 204.944}, {336.457, 
               205.86200000000002`}, {337.812, 206.83}, {301.129, 206.83}, {
               302.875, 205.905}, {304.82, 205.13899999999998`}, {305.52, 
               203.389}, {305.52, 175.545}, {305.52, 173.342}, {302.402, 
               171.155}, {300.59799999999996`, 170.354}}}]}, 
             {Thickness[0.0012000000000000001`], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}, {1,
                3, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{339.707, 
               170.35400600000003`}, {337.89799999999997`, 
               171.15500600000001`}, {333.96099999999996`, 173.342006}, {
               333.96099999999996`, 175.545006}, {333.96099999999996`, 
               203.38900600000002`}, {334.348, 204.944006}, {336.457, 
               205.862006}, {337.812, 206.83000600000003`}, {301.129, 
               206.83000600000003`}, {302.875, 205.90500600000001`}, {304.82, 
               205.139006}, {305.52, 203.38900600000002`}, {305.52, 
               175.545006}, {305.52, 173.342006}, {302.402, 
               171.15500600000001`}, {300.59799999999996`, 
               170.35400600000003`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{344.629, 206.53}, {344.629, 
               226.58800000000002`}, {339.60200000000003`, 
               226.58800000000002`}, {339.60200000000003`, 228.541}, {299.828,
                228.541}, {299.828, 226.58800000000002`}, {294.801, 
               226.58800000000002`}, {294.801, 206.53}}}]}, 
             {Thickness[0.0012000000000000001`], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{344.629, 
               206.53000600000001`}, {344.629, 226.588006}, {
               339.60200000000003`, 226.588006}, {339.60200000000003`, 
               228.541006}, {299.828, 228.541006}, {299.828, 226.588006}, {
               294.801, 226.588006}, {294.801, 206.53000600000001`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{263.234, 
               192.791}, {266.90999999999997`, 192.791}, {266.90999999999997`,
                175.9}, {263.234, 175.9}}}]}, 
             {Thickness[0.0012000000000000001`], CapForm["Round"], JoinForm[
              "Round"], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{263.234, 
               192.791006}, {266.90999999999997`, 192.791006}, {
               266.90999999999997`, 175.90000600000002`}, {263.234, 
               175.90000600000002`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {1, 3, 3}}}, {{{218.539, 170.354}, {220.312,
                171.155}, {222.89100000000002`, 173.342}, {
               222.89100000000002`, 175.545}, {222.89100000000002`, 
               201.70499999999998`}, {221.676, 203.866}, {266.246, 203.866}, {
               264.504, 201.70499999999998`}, {264.504, 175.545}, {264.504, 
               173.342}, {266.277, 171.155}, {268.047, 170.354}}}]}, 
             {Thickness[0.0012000000000000001`], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {1, 3, 3}}}, {{{218.539, 
               170.35400600000003`}, {220.312, 171.15500600000001`}, {
               222.89100000000002`, 173.342006}, {222.89100000000002`, 
               175.545006}, {222.89100000000002`, 201.705006}, {221.676, 
               203.86600600000003`}, {266.246, 203.86600600000003`}, {264.504,
                201.705006}, {264.504, 175.545006}, {264.504, 173.342006}, {
               266.277, 171.15500600000001`}, {268.047, 170.35400600000003`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{223.312, 
               221.27599999999998`}, {227.429, 221.27599999999998`}, {227.429,
                206.01799999999997`}, {223.312, 206.01799999999997`}}}]}, 
             {Thickness[0.0012000000000000001`], CapForm["Round"], JoinForm[
              "Round"], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{223.312, 
               221.276006}, {227.429, 221.276006}, {227.429, 
               206.01800599999999`}, {223.312, 206.01800599999999`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{223.289, 
               224.538}, {227.402, 224.538}, {227.402, 221.323}, {223.289, 
               221.323}}}]}, 
             {Thickness[0.0012000000000000001`], CapForm["Round"], JoinForm[
              "Round"], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{223.289, 
               224.538006}, {227.402, 224.538006}, {227.402, 221.323006}, {
               223.289, 221.323006}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {1, 3, 3}}}, {{{259.051, 170.354}, {
               257.28099999999995`, 171.155}, {254.69899999999998`, 
               173.342}, {254.69899999999998`, 175.545}, {254.69899999999998`,
                200.424}, {258.40599999999995`, 203.866}, {
               228.10899999999998`, 203.866}, {231.812, 200.424}, {231.812, 
               175.545}, {231.812, 173.342}, {229.23399999999998`, 171.155}, {
               227.465, 170.354}}}]}, 
             {Thickness[0.0012000000000000001`], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {1, 3, 3}}}, {{{259.051, 
               170.35400600000003`}, {257.28099999999995`, 
               171.15500600000001`}, {254.69899999999998`, 173.342006}, {
               254.69899999999998`, 175.545006}, {254.69899999999998`, 
               200.42400600000002`}, {258.40599999999995`, 
               203.86600600000003`}, {228.10899999999998`, 
               203.86600600000003`}, {231.812, 200.42400600000002`}, {231.812,
                175.545006}, {231.812, 173.342006}, {229.23399999999998`, 
               171.15500600000001`}, {227.465, 170.35400600000003`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {1, 3, 3}}}, {{{254.809, 170.354}, {253.035,
                171.155}, {250.45700000000002`, 173.342}, {
               250.45700000000002`, 175.545}, {250.45700000000002`, 
               198.038}, {252.883, 201.47899999999998`}, {233.63299999999998`,
                201.47899999999998`}, {236.059, 198.038}, {236.059, 
               175.545}, {236.059, 173.342}, {233.48000000000002`, 171.155}, {
               231.707, 170.354}}}]}, 
             {Thickness[0.0012000000000000001`], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {1, 3, 3}}}, {{{254.809, 
               170.35400600000003`}, {253.035, 171.15500600000001`}, {
               250.45700000000002`, 173.342006}, {250.45700000000002`, 
               175.545006}, {250.45700000000002`, 198.038006}, {252.883, 
               201.479006}, {233.63299999999998`, 201.479006}, {236.059, 
               198.038006}, {236.059, 175.545006}, {236.059, 173.342006}, {
               233.48000000000002`, 171.15500600000001`}, {231.707, 
               170.35400600000003`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {1, 3, 3}}}, {{{412.42199999999997`, 
               170.354}, {410.65200000000004`, 171.155}, {408.074, 173.342}, {
               408.074, 175.545}, {408.074, 200.424}, {411.777, 203.866}, {
               381.47999999999996`, 203.866}, {385.188, 200.424}, {385.188, 
               175.545}, {385.188, 173.342}, {382.605, 171.155}, {
               380.83599999999996`, 170.354}}}]}, 
             {Thickness[0.0012000000000000001`], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {1, 3, 3}}}, {{{412.42199999999997`, 
               170.35400600000003`}, {410.65200000000004`, 
               171.15500600000001`}, {408.074, 173.342006}, {408.074, 
               175.545006}, {408.074, 200.42400600000002`}, {411.777, 
               203.86600600000003`}, {381.47999999999996`, 
               203.86600600000003`}, {385.188, 200.42400600000002`}, {385.188,
                175.545006}, {385.188, 173.342006}, {382.605, 
               171.15500600000001`}, {380.83599999999996`, 
               170.35400600000003`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {1, 3, 3}}}, {{{408.18, 170.354}, {
               406.40599999999995`, 171.155}, {403.828, 173.342}, {403.828, 
               175.545}, {403.828, 198.038}, {406.254, 201.47899999999998`}, {
               387.004, 201.47899999999998`}, {389.42999999999995`, 
               198.038}, {389.42999999999995`, 175.545}, {389.42999999999995`,
                173.342}, {386.85200000000003`, 171.155}, {385.078, 
               170.354}}}]}, 
             {Thickness[0.0012000000000000001`], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {1, 3, 3}}}, {{{408.18, 
               170.35400600000003`}, {406.40599999999995`, 
               171.15500600000001`}, {403.828, 173.342006}, {403.828, 
               175.545006}, {403.828, 198.038006}, {406.254, 201.479006}, {
               387.004, 201.479006}, {389.42999999999995`, 198.038006}, {
               389.42999999999995`, 175.545006}, {389.42999999999995`, 
               173.342006}, {386.85200000000003`, 171.15500600000001`}, {
               385.078, 170.35400600000003`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{238.66, 
               201.47899999999998`}, {247.855, 201.47899999999998`}, {247.855,
                170.35399999999998`}, {238.66, 170.35399999999998`}}}]}, 
             {Thickness[0.0012000000000000001`], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{238.66, 
               201.479006}, {247.855, 201.479006}, {247.855, 170.354006}, {
               238.66, 170.354006}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {1, 3, 3}}}, {{{331.78099999999995`, 
               170.354}, {330.012, 171.155}, {327.42999999999995`, 173.342}, {
               327.42999999999995`, 175.545}, {327.42999999999995`, 
               199.319}, {328.887, 201.47899999999998`}, {310.77, 
               201.47899999999998`}, {312.227, 199.319}, {312.227, 175.545}, {
               312.227, 173.342}, {309.64500000000004`, 171.155}, {307.875, 
               170.354}}}]}, 
             {Thickness[0.0012000000000000001`], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {1, 3, 3}}}, {{{331.78099999999995`, 
               170.35400600000003`}, {330.012, 171.15500600000001`}, {
               327.42999999999995`, 173.342006}, {327.42999999999995`, 
               175.545006}, {327.42999999999995`, 199.319006}, {328.887, 
               201.479006}, {310.77, 201.479006}, {312.227, 199.319006}, {
               312.227, 175.545006}, {312.227, 173.342006}, {
               309.64500000000004`, 171.15500600000001`}, {307.875, 
               170.35400600000003`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               315.23799999999994`, 201.467}, {324.41799999999995`, 
               201.467}, {324.41799999999995`, 170.36200000000002`}, {
               315.23799999999994`, 170.36200000000002`}}}]}, 
             {Thickness[0.0012262218749999998`], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               315.23799999999994`, 201.46700600000003`}, {
               324.41799999999995`, 201.46700600000003`}, {
               324.41799999999995`, 170.36200600000004`}, {
               315.23799999999994`, 170.36200600000004`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               392.03099999999995`, 201.47899999999998`}, {
               401.22599999999994`, 201.47899999999998`}, {
               401.22599999999994`, 170.35399999999998`}, {
               392.03099999999995`, 170.35399999999998`}}}]}, 
             {Thickness[0.0012000000000000001`], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               392.03099999999995`, 201.479006}, {401.22599999999994`, 
               201.479006}, {401.22599999999994`, 170.354006}, {
               392.03099999999995`, 170.354006}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{310.617, 
               213.29899999999998`}, {329.043, 213.29899999999998`}, {329.043,
                206.51}, {310.617, 206.51}}}]}, 
             {Thickness[0.0012000000000000001`], CapForm["Butt"], JoinForm[
              "Round"], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{310.617, 
               213.299006}, {329.043, 213.299006}, {329.043, 206.510006}, {
               310.617, 206.510006}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}, {0,
                1, 0}}}, {{{329.242, 208.315}, {329.26599999999996`, 
               210.36200000000002`}, {335.219, 210.455}, {338.28499999999997`,
                212.202}, {301.469, 212.202}, {304.53499999999997`, 
               210.455}, {310.355, 210.311}, {310.355, 208.315}, {
               311.60200000000003`, 204.33800000000002`}, {
               326.84000000000003`, 203.72899999999998`}}}]}, 
             {Thickness[0.0012000000000000001`], CapForm["Butt"], JoinForm[
              "Round"], 
              JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}, {0,
                1, 0}}}, {{{329.242, 208.315006}, {329.26599999999996`, 
               210.362006}, {335.219, 210.45500600000003`}, {
               338.28499999999997`, 212.20200599999998`}, {301.469, 
               212.20200599999998`}, {304.53499999999997`, 
               210.45500600000003`}, {310.355, 210.31100600000002`}, {310.355,
                208.315006}, {311.60200000000003`, 204.338006}, {
               326.84000000000003`, 203.729006}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}, {1,
                3, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{336.43799999999993`, 
               229.959}, {336.43799999999993`, 234.975}, {336.648, 236.909}, {
               338.191, 236.909}, {338.191, 220.955}, {334.40999999999997`, 
               219.584}, {331.715, 214.76}, {331.715, 214.76}, {307.945, 
               214.76}, {307.945, 214.76}, {305.246, 219.584}, {301.469, 
               220.955}, {301.469, 236.909}, {303.367, 236.909}, {303.379, 
               234.889}, {303.379, 229.959}}}]}, 
             {Thickness[0.0012000000000000001`], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}, {1,
                3, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{336.43799999999993`, 
               229.95900600000002`}, {336.43799999999993`, 234.975006}, {
               336.648, 236.909006}, {338.191, 236.909006}, {338.191, 
               220.95500600000003`}, {334.40999999999997`, 
               219.58400600000002`}, {331.715, 214.760006}, {331.715, 
               214.760006}, {307.945, 214.760006}, {307.945, 214.760006}, {
               305.246, 219.58400600000002`}, {301.469, 
               220.95500600000003`}, {301.469, 236.909006}, {303.367, 
               236.909006}, {303.379, 234.88900600000002`}, {303.379, 
               229.95900600000002`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
               308.29699999999997`, 226.98700000000002`}, {
               311.35900000000004`, 223.311}, {311.074, 217.077}, {311.039, 
               213.401}, {328.801, 213.401}, {328.76599999999996`, 217.077}, {
               328.47999999999996`, 223.311}, {331.543, 
               226.98700000000002`}}}]}, 
             {Thickness[0.0012000000000000001`], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
               308.29699999999997`, 226.98700600000004`}, {
               311.35900000000004`, 223.31100600000002`}, {311.074, 
               217.077006}, {311.039, 213.40100600000002`}, {328.801, 
               213.40100600000002`}, {328.76599999999996`, 217.077006}, {
               328.47999999999996`, 223.31100600000002`}, {331.543, 
               226.98700600000004`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               226.14499999999998`, 192.791}, {229.81699999999998`, 
               192.791}, {229.81699999999998`, 175.9}, {226.14499999999998`, 
               175.9}}}]}, 
             {Thickness[0.0012000000000000001`], CapForm["Round"], JoinForm[
              "Round"], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               226.14499999999998`, 192.791006}, {229.81699999999998`, 
               192.791006}, {229.81699999999998`, 175.90000600000002`}, {
               226.14499999999998`, 175.90000600000002`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{412.719, 
               221.27599999999998`}, {416.832, 221.27599999999998`}, {416.832,
                206.01799999999997`}, {412.719, 206.01799999999997`}}}]}, 
             {Thickness[0.0012000000000000001`], CapForm["Round"], JoinForm[
              "Round"], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{412.719, 
               221.276006}, {416.832, 221.276006}, {416.832, 
               206.01800599999999`}, {412.719, 206.01800599999999`}}},
               CurveClosed->{1}]}, 
             {Thickness[0.0012000000000000001`], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{216.73, 
               170.35400600000003`}, {218.535, 171.27200599999998`}, {220.59, 
               173.409006}, {221.262, 175.799006}, {418.97299999999996`, 
               175.799006}, {419.64500000000004`, 173.409006}, {421.699, 
               171.27200599999998`}, {423.504, 170.35400600000003`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{257.633, 
               192.791}, {261.305, 192.791}, {261.305, 175.9}, {257.633, 
               175.9}}}]}, 
             {Thickness[0.0012000000000000001`], CapForm["Round"], JoinForm[
              "Round"], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{257.633, 
               192.791006}, {261.305, 192.791006}, {261.305, 
               175.90000600000002`}, {257.633, 175.90000600000002`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
               3}}}, {{{220.434, 226.475}, {220.434, 203.866}, {223.004, 
               203.866}, {223.004, 226.53}, {222.078, 226.99800000000002`}, {
               221.207, 227.07299999999998`}, {220.434, 226.475}}}]}, 
             {Thickness[0.0012000000000000001`], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
               3}}}, {{{220.434, 226.475006}, {220.434, 
               203.86600600000003`}, {223.004, 203.86600600000003`}, {223.004,
                226.53000600000001`}, {222.078, 226.998006}, {221.207, 
               227.073006}, {220.434, 226.475006}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}}}, {{{220.516, 211.846}, {
               223.70299999999997`, 210.21699999999998`}, {226.859, 208.33}, {
               227.656, 203.866}, {220.516, 203.866}}}]}, 
             {Thickness[0.0012000000000000001`], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}}}, {{{220.516, 
               211.84600600000002`}, {223.70299999999997`, 210.217006}, {
               226.859, 208.33000600000003`}, {227.656, 
               203.86600600000003`}, {220.516, 203.86600600000003`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               259.39099999999996`, 217.545}, {265.7, 217.545}, {265.7, 
               204.178}, {259.39099999999996`, 204.178}}}]}, 
             {Thickness[0.001292146875], CapForm["Round"], JoinForm["Round"], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               259.39099999999996`, 217.545006}, {265.7, 217.545006}, {265.7, 
               204.178006}, {259.39099999999996`, 204.178006}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
               3}}}, {{{264.719, 218.62}, {264.719, 203.866}, {266.801, 
               203.866}, {266.801, 218.655}, {266.15200000000004`, 218.959}, {
               265.262, 219.006}, {264.719, 218.62}}}]}, 
             {Thickness[0.0012000000000000001`], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
               3}}}, {{{264.719, 218.620006}, {264.719, 
               203.86600600000003`}, {266.801, 203.86600600000003`}, {266.801,
                218.65500600000001`}, {266.15200000000004`, 
               218.95900600000002`}, {265.262, 219.006006}, {264.719, 
               218.620006}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 
               3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {
               1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 
               3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
               0}}}, CompressedData["
1:eJxlVWtIFFEU3t20l2WmoRK2aoVFFhIUsUl1/BEmZQ8LiwoRKYtyZ69z75Rp
SiEhEWFSUBARS5nUD1nEFokISwnzx6KlVIpJpPQyou2xWATdx8wZ1gbmx8e9
c875vvOdM5llvqLD0xwOh5O/5fx18feqlljfOYfCnevdGYFHFWDh8PPCsgTm
hQ2zX94icRTO55WO94W8kBHQjzaN6rD/UO7ojkEvPN267nzeGx0m6449ZCna
f/jJz+UHG1/pKn61Bkn1nb3+cR3iV7Xd+NqiqfgRHZJfhyK7l2iQ/7Z6QWsK
hce9/s3BXBs3fTm9aa1u4w9/7n577tdgo/g+lkKrOAhpkCYK4/XFFPMMeT5Y
JPALXdVR7lN1D+tgXE6NKR7ywbtmXtiEDpzd4mEngfs9Jx7dDOuw8yJX4qZ5
/lsH73ueUPOp/PMo4poFPHOajRMFv2Wmfmds3CXyt03BYZ/SYT6F4Pe/A1Wz
CBwVRGdQWCnkySJKd54//dznXR1bCAh5S6dR6BaNOE5UnlQKCfs87T11RNWR
QeFBwRxXdiGBDjf/0G3e95h4jY1l/FIzfz4BIXMJPxc26G0git8KCqc+Zq2e
eY3AXFFvOgUh1+Q9ovzgoaq+vv+x1Cvf5HObwGAVD7SNwjMu80I/Uf0/YNbb
TEDIHdAowNqSBwX3zPsVFJzZDcmvnxLlzz0UigSREaL020xBlFk9QSBnZOn0
szzfwUbecVel0msvhRZhzCQTH6GwScT/QWAFDxuqobC9jCv4i4BIE6o1659Z
qfQkJt5Zqfp3gSGWfq5lik+ciU8xxSdCQMhUd4WBSwQOEzjJr+U0M6xHhHHf
Z1iv5B9kyEf6uYUhX9mfSwz1kPwvMtRLxvMz1FPeDzDUW/JpZ9gPMQbxXQz7
NRVLfw0xGBNEggTWt/MB6WfoBznvPQz9IvW8ztBP1nmU/97YWPpjmKFf5ZyO
MfSznIdJhn6X/XEa0fPwk+G8yD3zieE8Sb4DDOctCrfZ2JpXj+A3yqLne8LG
/aKfLgOx1H+WgftC9jvBwH0i902mgftG1rfcwH0k/Zxm4L6S/ogw3GcyP9fD
2ncWtvahha19Kb+PNXCfVog6kw3ctw7xLDVwH0t/uA3c11Ox9MMiA/e99Nc3
hv8D6c+vDP8XFrb+J/8ApYz8HQ==
               "]]}, 
             {Thickness[0.0012000000000000001`], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 
               3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {
               1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 
               3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
               0}}}, CompressedData["
1:eJxlVWtIFFEUVrPSnrZKRW2mFWb2kCCz7XkMYnsYVpQ9MelhRu7sde6dMrei
shKJMC0qiLKlzDIqWUokSKRCRdBWS3osKdI7DVMysaKae2fmLNrA/PiYmXvO
953vfBO+zb5mZz8fHx9f9U5Rbz/1Pi+ZsiqGUNjauHF6SXkaGPjWkLdSELPB
gkEvrpLBFBY7ujrcdTYIK5FT85plCL7sbk1otEHliticuCYZXGV/q9ko6T/8
qCtyS+5LWTs/U4LgrIoa53sZKlOsxe1FknZ+twxPTTv8106UwNqSGXJnFIVM
/9g1pfO8ePlkU3yM7MXOmEV/GpwSLOTf96ew68je7JA6CcybdsxrVvt7mHvV
4oqzwziOn8ngiC5PzU2xA4cJHhlm1N4OSnxth7eFF5+Etckw/+jYKR5fAver
95YXdMoQWDXNYSrQn/+UISI8r7RDsmv1h1PEjpA71hazF5s4v8kUirl+h71Y
1Hf1wZ12GDbddal9BIX800s9GYEEUvO+Hlg0kMKghE9dRREEcuKS37vV+r/C
Z28oW0qAy5vcj8KVhz8zUvcQ6GxYuS1oNIWv37MeVB8iYPv462ZHGIXzHxID
pq4kUBZ6vHV1qKoXf9+i41leLM5PpnCG17cSUKvHJKnP4+/WVtZkE41fFIV1
J9JjAy4QGMr7HU/hkc3W0lNMND9YqNaf+38s9LLqfK4RaMz4HDEznkJhcOD1
MU6izX+z3m8hAS53iUTB3HCjYlmx/n4ahaaqevOrSqL5cy2FGet2n2x9QzT9
llD4tjz/Y2Ybgeg3kwYcUevNmTb0d6RfuqbXegrHtp9bkBOs4136+d8JRGWP
fFXnoBD1d1OS5QeBqRwf1PsPSNf0JDpela7N7yRDLPx8kGl8But4P4NznE83
AfcET8+hs0zrv5PAvvKCMdGFDPtRp1EWep9hv4J/KUM+ws9FDPmK+ZxmqIfg
f4qhXuI8J0M9xfslDPUWfO4xnMeZ0f6Jwx4znFdfLPz1mmnzLiUw9566IPUM
/SD2vZqhX4SeFxn6yXjey39NXiz84WHoV5EX7xj6WexDD0O/i/n4Kr33oYvh
vlzn+n1huE+C73OG+9YLu7zY2FcL59fMeu93mxfX83n6KYiF/oEK5oWYd5CC
eSLyJlzBvBH9RSqYR8LPZgXzSvijm2GeifqqHkbeGdjIQwMbeSm+769gnqZx
fiMVzFsffk1SMI+FP0IVzOu+WPhhnIJ5L/zVwfB/IPzZzvB/YWDjf/IPab3x
Fw==
               "],
               CurveClosed->{1}]}, 
             {Thickness[0.001], CapForm["Butt"], JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{311.277, 271.655006}, {328.816,
                271.655006}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}}}, {{{
               318.28099999999995`, 269.10400000000004`}, {315.848, 
               270.358}, {315.848, 273.94}, {316.84400000000005`, 273.639}, {
               317.96099999999996`, 273.518}, {318.066, 
               271.93199999999996`}, {318.414, 274.194}, {319.039, 274.084}, {
               320.02, 274.967}, {321., 274.084}, {321.625, 274.194}, {
               321.97299999999996`, 271.93199999999996`}, {322.082, 
               273.518}, {323.199, 273.639}, {324.191, 273.94}, {324.191, 
               270.358}, {321.758, 269.10400000000004`}}}]}, 
             {Thickness[0.0012000000000000001`], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}}}, {{{
               318.28099999999995`, 269.104006}, {315.848, 
               270.35800600000005`}, {315.848, 273.94000600000004`}, {
               316.84400000000005`, 273.639006}, {317.96099999999996`, 
               273.518006}, {318.066, 271.932006}, {318.414, 274.194006}, {
               319.039, 274.08400600000004`}, {320.02, 274.967006}, {321., 
               274.08400600000004`}, {321.625, 274.194006}, {
               321.97299999999996`, 271.932006}, {322.082, 273.518006}, {
               323.199, 273.639006}, {324.191, 273.94000600000004`}, {324.191,
                270.35800600000005`}, {321.758, 269.104006}}},
               CurveClosed->{1}]}, 
             {Thickness[0.001], CapForm["Butt"], JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{309.195, 266.178006}, {330.621,
                266.178006}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}}}, {{{318.117, 
               263.22499999999997`}, {314.078, 266.002}, {314.078, 269.303}, {
               315.4959999999999, 268.97499999999997`}, {317.08599999999996`, 
               268.84200000000004`}, {317.242, 267.10400000000004`}, {317.734,
                269.584}, {318.625, 270.87}, {320.02, 271.834}, {
               321.41799999999995`, 270.87}, {322.309, 269.584}, {322.801, 
               267.10400000000004`}, {322.957, 268.84200000000004`}, {324.547,
                268.97499999999997`}, {325.965, 269.303}, {325.965, 
               266.002}, {321.92199999999997`, 263.22499999999997`}}}]}, 
             {Thickness[0.0012000000000000001`], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}}}, {{{318.117, 
               263.225006}, {314.078, 266.002006}, {314.078, 269.303006}, {
               315.4959999999999, 268.975006}, {317.08599999999996`, 
               268.84200599999997`}, {317.242, 267.104006}, {317.734, 
               269.58400600000004`}, {318.625, 270.870006}, {320.02, 
               271.83400600000004`}, {321.41799999999995`, 270.870006}, {
               322.309, 269.58400600000004`}, {322.801, 267.104006}, {322.957,
                268.84200599999997`}, {324.547, 268.975006}, {325.965, 
               269.303006}, {325.965, 266.002006}, {321.92199999999997`, 
               263.225006}}},
               CurveClosed->{1}]}, 
             {Thickness[0.001], CapForm["Butt"], JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{307.121, 259.534006}, {332.625,
                259.534006}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}}}, {{{317.832, 
               254.069}, {313.188, 258.14700000000005`}, {313.188, 
               262.99799999999993`}, {314.816, 262.514}, {316.64500000000004`,
                262.319}, {316.824, 259.764}, {317.39099999999996`, 
               263.409}, {318.414, 265.29499999999996`}, {320.02, 
               266.71299999999997`}, {321.629, 265.29499999999996`}, {322.648,
                263.409}, {323.219, 259.764}, {323.395, 262.319}, {325.227, 
               262.514}, {326.855, 262.99799999999993`}, {326.855, 
               258.14700000000005`}, {322.207, 254.069}}}]}, 
             {Thickness[0.0012000000000000001`], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}}}, {{{317.832, 
               254.069006}, {313.188, 258.14700600000003`}, {313.188, 
               262.99800600000003`}, {314.816, 262.514006}, {
               316.64500000000004`, 262.319006}, {316.824, 259.764006}, {
               317.39099999999996`, 263.409006}, {318.414, 265.295006}, {
               320.02, 266.71300599999995`}, {321.629, 265.295006}, {322.648, 
               263.409006}, {323.219, 259.764006}, {323.395, 262.319006}, {
               325.227, 262.514006}, {326.855, 262.99800600000003`}, {326.855,
                258.14700600000003`}, {322.207, 254.069006}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               326.39799999999997`, 248.647}, {322.199, 242.834}, {317.441, 
               242.834}, {313.23799999999994`, 248.647}}}]}, 
             {Thickness[0.0012000000000000001`], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               326.39799999999997`, 248.647006}, {322.199, 
               242.83400600000002`}, {317.441, 242.83400600000002`}, {
               313.23799999999994`, 248.647006}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{310.82, 
               238.893}, {312.92199999999997`, 237.74499999999998`}, {313.699,
                235.455}, {313.92199999999997`, 231.159}, {325.75, 231.159}, {
               325.97299999999996`, 235.455}, {326.75, 237.74499999999998`}, {
               328.85200000000003`, 238.893}}}]}, 
             {Thickness[0.0012000000000000001`], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{310.82, 
               238.893006}, {312.92199999999997`, 237.745006}, {313.699, 
               235.45500600000003`}, {313.92199999999997`, 231.159006}, {
               325.75, 231.159006}, {325.97299999999996`, 
               235.45500600000003`}, {326.75, 237.745006}, {
               328.85200000000003`, 238.893006}}},
               CurveClosed->{1}]}, 
             {Thickness[0.001], CapForm["Butt"], JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{304.945, 251.412006}, {335.191,
                251.412006}}},
               CurveClosed->{0}]}, 
             {Thickness[0.001], CapForm["Butt"], JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{304.25, 242.159006}, {
               335.40599999999995`, 242.159006}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {0, 1, 0}}}, {{{329.027, 248.647}, {329.027, 
               254.48700000000002`}, {327.03099999999995`, 253.936}, {
               325.73799999999994`, 252.752}, {325.16, 251.151}, {325.16, 
               253.08800000000002`}, {322.60900000000004`, 257.557}, {319.828,
                259.78}, {317.039, 257.29099999999994`}, {314.445, 253.248}, {
               314.4959999999999, 251.151}, {314.02299999999997`, 252.678}, {
               312.629, 253.936}, {310.629, 254.48700000000002`}, {310.629, 
               248.647}}}]}, 
             {Thickness[0.0012000000000000001`], CapForm["Butt"], JoinForm[
              "Round"], 
              JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {0, 1, 0}}}, {{{329.027, 248.647006}, {329.027, 
               254.48700600000004`}, {327.03099999999995`, 
               253.93600600000002`}, {325.73799999999994`, 252.752006}, {
               325.16, 251.15100600000002`}, {325.16, 253.088006}, {
               322.60900000000004`, 257.557006}, {319.828, 
               259.78000599999996`}, {317.039, 257.29100600000004`}, {314.445,
                253.24800599999998`}, {314.4959999999999, 
               251.15100600000002`}, {314.02299999999997`, 
               252.67800599999998`}, {312.629, 253.93600600000002`}, {310.629,
                254.48700600000004`}, {310.629, 248.647006}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {0, 1, 0}}}, {{{329.90999999999997`, 238.893}, {
               329.90999999999997`, 244.72899999999998`}, {
               327.72299999999996`, 244.18200000000002`}, {326.305, 
               242.99800000000002`}, {325.672, 241.393}, {325.672, 243.334}, {
               322.879, 247.803}, {319.828, 250.026}, {316.77, 247.538}, {
               313.92599999999993`, 243.495}, {313.984, 241.393}, {313.465, 
               242.924}, {311.93399999999997`, 244.18200000000002`}, {309.746,
                244.72899999999998`}, {309.746, 238.893}}}]}, 
             {Thickness[0.0012000000000000001`], CapForm["Butt"], JoinForm[
              "Round"], 
              JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {0, 1, 0}}}, {{{329.90999999999997`, 238.893006}, {
               329.90999999999997`, 244.729006}, {327.72299999999996`, 
               244.182006}, {326.305, 242.998006}, {325.672, 241.393006}, {
               325.672, 243.33400600000002`}, {322.879, 247.803006}, {319.828,
                250.02600600000002`}, {316.77, 247.538006}, {
               313.92599999999993`, 243.49500600000002`}, {313.984, 
               241.393006}, {313.465, 242.92400600000002`}, {
               311.93399999999997`, 244.182006}, {309.746, 244.729006}, {
               309.746, 238.893006}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {0, 1, 0}}}, {{{332.371, 226.909}, {332.371, 
               233.64299999999997`}, {329.648, 232.944}, {327.957, 
               230.92800000000003`}, {327.10200000000003`, 229.752}, {
               327.10200000000003`, 233.401}, {322.984, 238.959}, {319.828, 
               240.78}, {316.594, 238.91299999999998`}, {312.559, 233.166}, {
               312.559, 229.752}, {311.676, 230.92000000000002`}, {310.008, 
               232.944}, {307.28499999999997`, 233.64299999999997`}, {
               307.28499999999997`, 226.909}}}]}, 
             {Thickness[0.0012000000000000001`], CapForm["Butt"], JoinForm[
              "Round"], 
              JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {0, 1, 0}}}, {{{332.371, 226.909006}, {332.371, 
               233.64300599999999`}, {329.648, 232.944006}, {327.957, 
               230.928006}, {327.10200000000003`, 229.752006}, {
               327.10200000000003`, 233.40100600000002`}, {322.984, 
               238.95900600000002`}, {319.828, 240.780006}, {316.594, 
               238.912006}, {312.559, 233.166006}, {312.559, 229.752006}, {
               311.676, 230.920006}, {310.008, 232.944006}, {
               307.28499999999997`, 233.64300599999999`}, {
               307.28499999999997`, 226.909006}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {0, 1, 0}}}, {{{330.89799999999997`, 211.959}, {
               330.89799999999997`, 218.88500000000002`}, {328.4959999999999, 
               217.944}, {327.777, 215.627}, {327.02, 214.053}, {327.316, 
               221.077}, {323.066, 228.627}, {319.828, 230.541}, {316.59, 
               228.627}, {312.258, 220.916}, {312.637, 214.053}, {
               311.85900000000004`, 215.61599999999999`}, {311.16, 217.944}, {
               308.758, 218.88500000000002`}, {308.758, 211.959}}}]}, 
             {Thickness[0.0012000000000000001`], CapForm["Butt"], JoinForm[
              "Round"], 
              JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {0, 1, 0}}}, {{{330.89799999999997`, 
               211.95900600000002`}, {330.89799999999997`, 
               218.88500600000003`}, {328.4959999999999, 217.944006}, {
               327.777, 215.62700600000002`}, {327.02, 214.053006}, {327.316, 
               221.077006}, {323.066, 228.62700600000002`}, {319.828, 
               230.541006}, {316.59, 228.62700600000002`}, {312.258, 
               220.916006}, {312.637, 214.053006}, {311.85900000000004`, 
               215.616006}, {311.16, 217.944006}, {308.758, 
               218.88500600000003`}, {308.758, 211.95900600000002`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{412.746, 
               224.538}, {416.859, 224.538}, {416.859, 221.323}, {412.746, 
               221.323}}}]}, 
             {Thickness[0.0012000000000000001`], CapForm["Round"], JoinForm[
              "Round"], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{412.746, 
               224.538006}, {416.859, 224.538006}, {416.859, 221.323006}, {
               412.746, 221.323006}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{378.777, 
               192.791}, {382.449, 192.791}, {382.449, 175.9}, {378.777, 
               175.9}}}]}, 
             {Thickness[0.0012000000000000001`], CapForm["Round"], JoinForm[
              "Round"], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{378.777, 
               192.791006}, {382.449, 192.791006}, {382.449, 
               175.90000600000002`}, {378.777, 175.90000600000002`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{410.262, 
               192.791}, {413.934, 192.791}, {413.934, 175.9}, {410.262, 
               175.9}}}]}, 
             {Thickness[0.0012000000000000001`], CapForm["Round"], JoinForm[
              "Round"], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{410.262, 
               192.791006}, {413.934, 192.791006}, {413.934, 
               175.90000600000002`}, {410.262, 175.90000600000002`}}},
               CurveClosed->{1}]}, 
             {Thickness[0.0012000000000000001`], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{294.801, 
               211.95900600000002`}, {344.629, 211.95900600000002`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0012000000000000001`], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{310.617, 
               211.952006}, {329.086, 211.952006}, {329.086, 
               205.16700600000001`}, {310.617, 205.16700600000001`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {0, 1, 0}}}, {{{329.215, 201.47899999999998`}, {
               329.215, 208.401}, {326.695, 207.803}, {326.543, 206.873}, {
               325.742, 205.323}, {326.039, 209.518}, {323.066, 214.303}, {
               319.828, 216.21699999999998`}, {316.59, 214.303}, {313.621, 
               209.518}, {313.91799999999995`, 205.323}, {313.117, 206.873}, {
               313.01599999999996`, 207.803}, {310.441, 208.401}, {310.441, 
               201.47899999999998`}}}]}, 
             {Thickness[0.0012000000000000001`], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {0, 1, 0}}}, {{{329.215, 201.479006}, {329.215, 
               208.40100600000002`}, {326.695, 207.803006}, {326.543, 
               206.873006}, {325.742, 205.32300600000002`}, {326.039, 
               209.51800599999999`}, {323.066, 214.303006}, {319.828, 
               216.217006}, {316.59, 214.303006}, {313.621, 
               209.51800599999999`}, {313.91799999999995`, 
               205.32300600000002`}, {313.117, 206.873006}, {
               313.01599999999996`, 207.803006}, {310.441, 
               208.40100600000002`}, {310.441, 201.479006}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}}}, {{{266.801, 211.846}, {
               263.613, 210.21699999999998`}, {260.457, 208.33}, {259.66, 
               203.866}, {266.801, 203.866}}}]}, 
             {Thickness[0.0012000000000000001`], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}}}, {{{266.801, 
               211.84600600000002`}, {263.613, 210.217006}, {260.457, 
               208.33000600000003`}, {259.66, 203.86600600000003`}, {266.801, 
               203.86600600000003`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{223.004, 
               221.27599999999998`}, {227.42999999999998`, 
               221.27599999999998`}, {227.42999999999998`, 
               203.95999999999998`}, {223.004, 203.95999999999998`}}}]}, 
             {Thickness[0.0012000000000000001`], CapForm["Round"], JoinForm[
              "Round"], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{223.004, 
               221.276006}, {227.42999999999998`, 221.276006}, {
               227.42999999999998`, 203.960006}, {223.004, 203.960006}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{223.004, 
               224.538}, {227.402, 224.538}, {227.402, 221.323}, {223.004, 
               221.323}}}]}, 
             {Thickness[0.0012000000000000001`], CapForm["Round"], JoinForm[
              "Round"], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{223.004, 
               224.538006}, {227.402, 224.538006}, {227.402, 221.323006}, {
               223.004, 221.323006}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               259.39099999999996`, 217.545}, {265.7, 217.545}, {265.7, 
               204.178}, {259.39099999999996`, 204.178}}}]}, 
             {Thickness[0.001292146875], CapForm["Round"], JoinForm["Round"], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               259.39099999999996`, 217.545006}, {265.7, 217.545006}, {265.7, 
               204.178006}, {259.39099999999996`, 204.178006}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 
               3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
               0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJ7IGYCYqstJ8r2Zec45D7/vfJjU6YDjC9289z3YPNc
h8dLZx9RmILgc19fXGA7K8dhp1zr68A1OQ5VIuvcH35D8B0Tnl5QUs+F8126
c57/Vsx1OL3QddvnpzkOsbs8eZjYcx3ctn3+e0Uk1yEOxH+f41A6WYIlzC7X
IWPi2xr7izkOB04BNZTnOgg3A1k/cxwOf9WI6X8ElReF6p+Q6xDOp7tpbnyu
QwfI4rJcB5AzHwfmOgBdVSWyCupeq1wHkDZTpjwHLhAf6N5kgQjLLQJ5EPM0
cx1sQRIz8yDusc6F+Fc9D+L/Fqh/dPIcQMbEFeU6LAMKb8iD8uNyHaJSrO/7
78xzWAT05l+TXAeQs95fz3NgAIEMqLxjvkMByCKgeSxhQBUn8xzU2BqnOq/O
hbjnAoIPjg+pfDi/PmtPyeSOfEj4Lc916AT5918+1L48B6BrijJECzD4QFfv
kLPNcwBFw0r3AodVHy/5JhUg+EWgAFiM4IPjfzVCPzofHB+W+XD79e+qsDWa
5sPdB+PD3A/jw/wHDs+YfLj/b/2sy9pTkQ8PH4h9+fDwA4dvUz48fMH8vHx4
+BeCwhNoHix+vgGTyaGl+fD4A/tvez48fi8p3f5Z9yofHv8XQPxl+fD0UQ1K
z3358PQDDr/GfHj6KgaZdzofnv7A6f15Pjx9grStYy+Ap1+wez7mw9M3mH8z
H57+Z+QJNR/Ylw/PH+Dw3ZkPzz9g9S8R/PJ986X0lQvg/B0gWq0Anj8vgvxj
hcmH5W8Ajzbb3g==
               "]]}, 
             {Thickness[0.0012000000000000001`], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 
               3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
               0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJ7IGYCYqstJ8r2Zec4qCpO3PaxKdMBxj8vlMISYp7r
8Hjp7CMKUxB87uuLC2xn5TgURUj9CFyT41Alss794TcE3zHh6QUl9Vw436U7
5/lvxVyHltu3Dn1+muMQu8uTh4k91+H/+w6uqyK5DnEg/vscB92zawXC7HId
Mia+rbG/mONQyWIetK0810G4+cCphT9zHKr192X0P4LKi0L1T8h1COfT3TQ3
PtfBsfrrxwtluQ43z30PfhyY65DeWNYusgrqXqtcBy91IR9TpjwHLhAf6F5p
r7euWwTyIOZp5jp8c87ZUDAzD+Ie61yIf9XzIP5vgfpHJ88BqNo0rijXIf5q
pO6GPCg/DujOeRde++/Mc1jkuu3zX5Nch2Np7qveX89zYACBDKi8Y75DgS3Q
BUDz9vYvttx0Ms9Bja1xqvPqXIh7LiD44PiQyofzzZcENk7uyIeE3/JcByeQ
f//lQ+3Lc1i491dFhmgBBr/1deAOOVugPzmNmFa5Fzis+njJN6kAwS8CBcBi
BB8c/6sR+tH54PiwzIfbr39Xha3RNB/uPhgf5n4YH+Y/cHjG5MP9f+tnXdae
inx4+EDsy4eHHzh8m/Lh4Qvm5+XDw78QFJ5A82Dx800jpv/Q0nx4/IH9tz0f
Hr+XlG7/rHuVD4//CyD+snx4+qgGpee+fHj6AYdfYz48fRWDzDudD09/4PT+
PB+ePt0fAnMEewE8/YLd8zEfnr7B/Jv58PQ/I0+o+cC+fHj+AIfvznx4/gGr
f4ngl++bL6WvXADn75ADulCtAJ4/L4L8Y4XJh+VvAFeLyus=
               "],
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}}}, {{{245.73, 
               246.42000000000002`}, {247.59, 247.97899999999998`}, {247.59, 
               249.97899999999998`}, {246.91, 249.91299999999998`}, {246.539, 
               249.678}, {246.035, 249.02200000000002`}, {245.60899999999998`,
                250.346}, {244.672, 251.38100000000003`}, {243.414, 
               252.026}, {242.15200000000002`, 251.38100000000003`}, {
               241.21499999999997`, 250.393}, {240.789, 249.069}, {240.285, 
               249.725}, {239.914, 249.91299999999998`}, {239.23399999999998`,
                249.97899999999998`}, {239.23399999999998`, 
               247.97899999999998`}, {241.094, 246.42000000000002`}}}]}, 
             {Thickness[0.0012000000000000001`], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}}}, {{{245.73, 
               246.420006}, {247.59, 247.979006}, {247.59, 249.979006}, {
               246.91, 249.912006}, {246.539, 249.67800599999998`}, {246.035, 
               249.022006}, {245.60899999999998`, 250.34600600000002`}, {
               244.672, 251.38100600000004`}, {243.414, 
               252.02600600000002`}, {242.15200000000002`, 
               251.38100600000004`}, {241.21499999999997`, 250.393006}, {
               240.789, 249.069006}, {240.285, 249.725006}, {239.914, 
               249.912006}, {239.23399999999998`, 249.979006}, {
               239.23399999999998`, 247.979006}, {241.094, 246.420006}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}}}, {{{246.727, 
               241.405}, {247.59, 243.27599999999998`}, {247.59, 245.873}, {
               246.91, 245.80700000000002`}, {246.539, 245.569}, {246.035, 
               244.901}, {245.60899999999998`, 246.248}, {244.672, 247.295}, {
               243.414, 247.948}, {242.15200000000002`, 247.295}, {
               241.21499999999997`, 246.295}, {240.789, 
               244.95200000000003`}, {240.285, 245.61599999999999`}, {239.914,
                245.80700000000002`}, {239.23399999999998`, 245.873}, {
               239.23399999999998`, 243.27599999999998`}, {240.098, 
               241.405}}}]}, 
             {Thickness[0.0012000000000000001`], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}}}, {{{246.727, 
               241.40500600000001`}, {247.59, 243.276006}, {247.59, 
               245.873006}, {246.91, 245.80700600000003`}, {246.539, 
               245.569006}, {246.035, 244.90100600000002`}, {
               245.60899999999998`, 246.24800599999998`}, {244.672, 
               247.295006}, {243.414, 247.948006}, {242.15200000000002`, 
               247.295006}, {241.21499999999997`, 246.295006}, {240.789, 
               244.952006}, {240.285, 245.616006}, {239.914, 
               245.80700600000003`}, {239.23399999999998`, 245.873006}, {
               239.23399999999998`, 243.276006}, {240.098, 
               241.40500600000001`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}}}, {{{
               246.85500000000002`, 234.623}, {249.617, 237.991}, {249.617, 
               241.311}, {248.605, 241.198}, {248.055, 240.795}, {247.309, 
               239.666}, {246.676, 241.94}, {245.281, 242.44}, {243.414, 
               243.541}, {241.54299999999998`, 242.44}, {240.148, 
               242.02200000000002`}, {239.516, 239.74499999999998`}, {
               238.76999999999998`, 240.877}, {238.21899999999997`, 
               241.198}, {237.207, 241.311}, {237.207, 237.991}, {239.969, 
               234.623}}}]}, 
             {Thickness[0.0012000000000000001`], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}}}, {{{
               246.85500000000002`, 234.623006}, {249.617, 
               237.99100600000003`}, {249.617, 241.31100600000002`}, {248.605,
                241.198006}, {248.055, 240.795006}, {247.309, 239.666006}, {
               246.676, 241.940006}, {245.281, 242.440006}, {243.414, 
               243.541006}, {241.54299999999998`, 242.440006}, {240.148, 
               242.022006}, {239.516, 239.745006}, {238.76999999999998`, 
               240.87700600000002`}, {238.21899999999997`, 241.198006}, {
               237.207, 241.31100600000002`}, {237.207, 
               237.99100600000003`}, {239.969, 234.623006}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJRIGYC4oyJb2vsv+Y5HP6qEdNfl+OAzn+8dPYRhZh8
hx1yra8Db+Q4cF1fXGCblO+gsKEoYyJnLpxvYgwE1bkO72rsTeOs8h0OgfSX
5ToU2AJViOQ7XKt4qWaYk+ugytY41fl7noMdWGOug7ohxxqZe3kO91SAErNz
HWJ3efIwbc9zePF75cdLW3Mh7snNcxC7ee578ONch36QwcoI+ePe5p2Of3Lh
+p0Snl5QAqqDmf8N6IxDR3Ph9jOAwIJcuPvA/qvIhbsfxof5D+hroNdz4f4H
85/mwsMHnQ8ABFCbJg==
               "]]}, 
             {Thickness[0.0012000000000000001`], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJRIGYC4oyJb2vsv+Y51Ojvy+ivy3FA5z9eOvuIQky+
Q2GE1I/AGzkOXNcXF9gm5TvcfMleOpEzF85/k3PC3rg61+Fdjb1pnFW+QzVI
f1muQ4EtUIVIvkP/pjpjw5xcB1W2xqnO3/McvjnnbCiwzXVQN+RYI3Mvz2Fa
3OzeqbNzHWJ3efIwbc9zWGBq/+/S1lyIe3LzHM4LpbCEPM516D/0VSNGGSF/
3Nu80/FPLly/U8LTC0pAdTDzv2nE9B86mgu3nwEEFuTC3Qf2X0Uu3P0wPsx/
ra8Dd8i15sL9D+Y/zYWHDzofANFqmVA=
               "],
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJRIGYC4tbXgTvkFPMd6rL2lEz+kuWAzlc35Fgjsy7f
IVkgwnLLhGwHb/NOx4SN+Q52XNcXF5xF8A9/1Yjpr8txKLQFStTkO4jdPPc9
uDzHYeuJsn3zvfIdcp//XvkxKMfBcgtQQDnfYeLbGntTLqg8U76D27bPf6/M
yXGoFlnn/vBcnkNA7/Q8IeZchwyQwtw8iHqvXIdikAA3Qh5s3vVcuH4Qd/62
XLj5ViCB/ly4/SBnPY7NhbsP7F/NXLj7YXyY/1TZGqc6G+fC/Q92z85cePig
8wGGoKCb
               "]]}, 
             {Thickness[0.0012000000000000001`], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJRIGYC4tbXgTvkFPMdzJcENk7+kuWAzlc35Fgjsy7f
QdrrreuWCdkO3uadjgkb8x2+OedsKDiL4Nfo78vor8txKLTlur64Jt/hvFAK
S0h5jsPWE2X75nvlO6gqTtz2MSjHwXILUEA538FLXcjHlAsqz5Tv8P99B9fV
OTkO1SLr3B+ey3PgPK5TLcSc65Ax8W2NfW4eRL1XrkMxSIAbIQ8273ouXD+I
O39bLtx8K5BAfy7c/pvnvgc/js2Fuw/sX81cuPthfJj/VNkapzob58L9D3bP
zlx4+KDzAeAhlNE=
               "],
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJRIGYC4tbXgTvkFPMdlhTYcl3nznJA5ws3Hzi1cGa+
Q4TllhNlbVkO3uadjgkb8x3uqbA1Tt2N4Ltt+/z3Sk62QyFQ2+KafAcQVZCa
7bD1RNm++V75Dh+WH/M2d8x2ABmzTznfYfYRhQ1FP7Ig8kz5DgG90/OEurMd
qkXWuT88l+eQ+/z3yo/3sh0yJr6tsc/NcwCKVomo5TgUgwS4EfJg867nwvWD
uPO35cLNtwIJ9OfC7b957nvw49hcuPvA/tXMhbsfxof5L4xPd9Nc91y4/8Hu
2ZkLDx90PgCrxZ/i
               "]]}, 
             {Thickness[0.0012000000000000001`], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJRIGYC4tbXgTvkFPMdYlddErvOneWAzhduPnBq4cx8
B4Fiz6tlbVkO3uadjgkb8x2mxc3unbobwf//voPrak62Q6Et1/XFNfkO35xz
NhSkZjtsPVG2b75XvsOKh9ER5o7ZDpZbgALK+Q4h/7buKfqRBZFnynfgPK5T
LdSd7VAtss794bk8BzXFids+3st2yJj4tsY+N88hvbGsXUQtx6EYJMCNkAeb
dz0Xrh/Enb8tF26+FUigPxdu/81z34Mfx+bC3Qf2r2Yu3P0wPsx/YXy6m+a6
58L9D3bPzlx4+KDzASGmnw0=
               "],
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{250.555, 204.131}, {
               249.45700000000002`, 208.91299999999998`}, {248.512, 
               212.455}, {243.21899999999997`, 216.053}, {237.93, 212.455}, {
               236.984, 208.91299999999998`}, {235.88700000000003`, 
               204.131}}}]}, 
             {Thickness[0.0012000000000000001`], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{250.555, 
               204.131006}, {249.45700000000002`, 208.912006}, {248.512, 
               212.45500600000003`}, {243.21899999999997`, 216.053006}, {
               237.93, 212.45500600000003`}, {236.984, 208.912006}, {
               235.88700000000003`, 204.131006}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {0, 1, 0}}}, {{{253.277, 201.47899999999998`}, {
               253.277, 208.401}, {250.875, 207.459}, {248.70299999999997`, 
               206.065}, {247.90200000000002`, 204.51399999999998`}, {247.008,
                208.35800000000003`}, {245.285, 210.053}, {243.137, 
               212.377}, {240.99200000000002`, 210.053}, {239.555, 
               208.35800000000003`}, {238.66, 204.51399999999998`}, {237.859, 
               206.065}, {235.68800000000002`, 207.459}, {233.285, 208.401}, {
               233.285, 201.47899999999998`}}}]}, 
             {Thickness[0.0012000000000000001`], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {0, 1, 0}}}, {{{253.277, 201.479006}, {253.277, 
               208.40100600000002`}, {250.875, 207.45900600000002`}, {
               248.70299999999997`, 206.065006}, {247.90200000000002`, 
               204.514006}, {247.008, 208.35800600000002`}, {245.285, 
               210.053006}, {243.137, 212.37700600000002`}, {
               240.99200000000002`, 210.053006}, {239.555, 
               208.35800600000002`}, {238.66, 204.514006}, {237.859, 
               206.065006}, {235.68800000000002`, 207.45900600000002`}, {
               233.285, 208.40100600000002`}, {233.285, 201.479006}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
               3}}}, {{{220.434, 226.475}, {220.434, 203.866}, {223.004, 
               203.866}, {223.004, 226.53}, {222.078, 226.99800000000002`}, {
               221.207, 227.07299999999998`}, {220.434, 226.475}}}]}, 
             {Thickness[0.0012000000000000001`], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
               3}}}, {{{220.434, 226.475006}, {220.434, 
               203.86600600000003`}, {223.004, 203.86600600000003`}, {223.004,
                226.53000600000001`}, {222.078, 226.998006}, {221.207, 
               227.073006}, {220.434, 226.475006}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}}}, {{{220.516, 211.846}, {
               223.70299999999997`, 210.21699999999998`}, {226.859, 208.33}, {
               227.656, 203.866}, {220.516, 203.866}}}]}, 
             {Thickness[0.0012000000000000001`], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}}}, {{{220.516, 
               211.84600600000002`}, {223.70299999999997`, 210.217006}, {
               226.859, 208.33000600000003`}, {227.656, 
               203.86600600000003`}, {220.516, 203.86600600000003`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
               3}}}, {{{264.719, 218.62}, {264.719, 203.866}, {266.801, 
               203.866}, {266.801, 218.655}, {266.15200000000004`, 218.959}, {
               265.262, 219.006}, {264.719, 218.62}}}]}, 
             {Thickness[0.0012000000000000001`], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
               3}}}, {{{264.719, 218.620006}, {264.719, 
               203.86600600000003`}, {266.801, 203.86600600000003`}, {266.801,
                218.65500600000001`}, {266.15200000000004`, 
               218.95900600000002`}, {265.262, 219.006006}, {264.719, 
               218.620006}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}}}, {{{266.801, 211.959}, {
               263.613, 210.33}, {260.457, 208.444}, {259.66, 
               203.97899999999998`}, {266.801, 203.97899999999998`}}}]}, 
             {Thickness[0.0012000000000000001`], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}}}, {{{266.801, 
               211.95900600000002`}, {263.613, 210.33000600000003`}, {260.457,
                208.444006}, {259.66, 203.979006}, {266.801, 203.979006}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
               3}}}, {{{419.715, 226.475}, {419.715, 203.866}, {417.141, 
               203.866}, {417.141, 226.53}, {418.07, 226.99800000000002`}, {
               418.93799999999993`, 227.07299999999998`}, {419.715, 
               226.475}}}]}, 
             {Thickness[0.0012000000000000001`], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
               3}}}, {{{419.715, 226.475006}, {419.715, 
               203.86600600000003`}, {417.141, 203.86600600000003`}, {417.141,
                226.53000600000001`}, {418.07, 226.998006}, {
               418.93799999999993`, 227.073006}, {419.715, 226.475006}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 
               3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
               0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJ7IGYC4uPe5p2Op8odcp//XvmxKdMBxhe7ee57sHmu
w33/3ul59xB8hQ1FGRMfljvslGt9Hbgmx0EmKsX6Pn8FnM8AAhoIvh3X9cUF
qhUOpxe6bvv8FKpevMLBbdvnv1dEch34dDfNfc9d4VA6WYIlzC7XAUTx/S13
OHAKqKE81yFj4tsae8EKh8NfNWL6H0Hl5aH6J+Q6HAO516XCocMx4emFslwH
EDfBtsJhnfvDKpFVUPcaVjiAjDFlyoPwge5NFoiw3CKQBzFPs8LBFuTOmXkQ
9wDVg/2rnudwQen2z7owqH908hyEm4Eu861wWDb7iMKGvDwHIRDfucIB5C3/
nXkOOaBw1KuAmHM9DxJ+HlB5x3yH6XlAHUDzgLbqbjqZ5/Dpkm+SQBbUPRcQ
fHB8SOXD+fVZe0omd+Q78ILMTa9w6AT5918+xL51FQ5HQB4TLcDgx+3y5GHa
XOHQDZJwL3DYcqJs3/wzCP7Vipdqhs8QfLA/XyH0o/PB8WFYCbe/fN98KX39
Srj7YHyY+2F8mP8ugsLTqRLu/xmg8AiohIcP2L6sSnj4gcM7tBIevuDw9q6E
hz9YP9A8WPyA1aVXwuMP7L+CSnj8gs3rrITHPyiZrAOqh6UPWZAB0ZXw9LMI
mGz/hlTC0xfYvKpKePoDp/eOSnj6fLwU6LA5lfD0C3ZPbyU8fYP5jZXw9G8J
ipDiSnj+AIdXYSU8/4DVdyL4YP9vR/DB/t9VCc+f4Pg/h8mH5W8A2B3VVg==

               "]]}, 
             {Thickness[0.0012000000000000001`], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 
               3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
               0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJ7IGYC4uPe5p2Op8odVBUnbvvYlOkA458XSmEJMc91
uO/fOz3vHoKvsKEoY+LDcoeiCKkfgWtyHGSiUqzv81fA+QwgoIHg23FdX1yg
WuHQcvvWoc9PoerFKxz+v+/guiqS68Cnu2nue+4KB92zawXC7HIdJkuwhPH9
LXeoZDEP2lae65Ax8W2NvWCFQ7X+voz+R1B5eaj+CbkOx0DudalwcKz++vFC
Wa4DiJtgW+GQ3ljWLrIK6l7DCgcvdSEfU6Y8CB/oXmmvt65bBPIg5mlWOHxz
ztlQMDMP4h6gerB/1fMcLijd/lkXBvWPTp6DcPOBUwt9Kxzir0bqbsjLcxAC
8Z0rHITnXXjtvzPPIef575Uf9SocjqW5r3p/PQ8Sfh5Qecd8h+l5QB1A8/b2
L7bcdDLP4dMl3ySBLKh7LiD44PiQyofzzZcENk7uyHfgBbkvvcLBCeTff/kQ
+9ZVOCzc+6siQ7QAgx+3y5OHaXOFQwanEdMq9wKHLSfK9s0/g+BfrXipZvgM
wd8p1/o68BVCPzofHB+GlXD7y/fNl9LXr4S7D8aHuR/Gh/nvIig8nSrh/p8B
Co+ASnj4gO3LqoSHHzi8Qyvh4QsOb+9KePiD9QPNg8UPKHn5p1fC4w/sv4JK
ePyCzeushMe/+8MqkXVA9bD0IQsyILoSnn4WuW77/DekEp6+wOZVVcLTHzi9
d1TC0+fjpbOPKMyphKdfsHt6K+HpG8xvrISnf0tQhBRXwvMHOLwKK+H5B6y+
E8EH+387gg/2/65KeP4Ex/85TD4sfwMAoHLEYw==
               "],
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}}}, {{{399.008, 
               246.42000000000002`}, {400.867, 247.97899999999998`}, {400.867,
                249.97899999999998`}, {400.188, 249.91299999999998`}, {
               399.816, 249.678}, {399.312, 249.02200000000002`}, {398.887, 
               250.346}, {397.949, 251.38100000000003`}, {396.688, 252.026}, {
               395.42999999999995`, 251.38100000000003`}, {
               394.49199999999996`, 250.393}, {394.066, 249.069}, {393.562, 
               249.725}, {393.191, 249.91299999999998`}, {392.512, 
               249.97899999999998`}, {392.512, 247.97899999999998`}, {394.371,
                246.42000000000002`}}}]}, 
             {Thickness[0.0012000000000000001`], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}}}, {{{399.008, 
               246.420006}, {400.867, 247.979006}, {400.867, 249.979006}, {
               400.188, 249.912006}, {399.816, 249.67800599999998`}, {399.312,
                249.022006}, {398.887, 250.34600600000002`}, {397.949, 
               251.38100600000004`}, {396.688, 252.02600600000002`}, {
               395.42999999999995`, 251.38100600000004`}, {
               394.49199999999996`, 250.393006}, {394.066, 249.069006}, {
               393.562, 249.725006}, {393.191, 249.912006}, {392.512, 
               249.979006}, {392.512, 247.979006}, {394.371, 246.420006}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}}}, {{{400., 241.405}, {
               400.867, 243.27599999999998`}, {400.867, 245.873}, {400.188, 
               245.80700000000002`}, {399.816, 245.569}, {399.312, 244.901}, {
               398.887, 246.248}, {397.949, 247.295}, {396.688, 247.948}, {
               395.42999999999995`, 247.295}, {394.49199999999996`, 
               246.295}, {394.066, 244.95200000000003`}, {393.562, 
               245.61599999999999`}, {393.191, 245.80700000000002`}, {392.512,
                245.873}, {392.512, 243.27599999999998`}, {393.375, 
               241.405}}}]}, 
             {Thickness[0.0012000000000000001`], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}}}, {{{400., 
               241.40500600000001`}, {400.867, 243.276006}, {400.867, 
               245.873006}, {400.188, 245.80700600000003`}, {399.816, 
               245.569006}, {399.312, 244.90100600000002`}, {398.887, 
               246.24800599999998`}, {397.949, 247.295006}, {396.688, 
               247.948006}, {395.42999999999995`, 247.295006}, {
               394.49199999999996`, 246.295006}, {394.066, 244.952006}, {
               393.562, 245.616006}, {393.191, 245.80700600000003`}, {392.512,
                245.873006}, {392.512, 243.276006}, {393.375, 
               241.40500600000001`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}}}, {{{400.133, 
               234.623}, {402.895, 237.991}, {402.895, 241.311}, {401.883, 
               241.198}, {401.332, 240.795}, {400.58599999999996`, 239.666}, {
               399.953, 241.94}, {398.559, 242.44}, {396.688, 243.541}, {
               394.82, 242.44}, {393.42599999999993`, 242.02200000000002`}, {
               392.79299999999995`, 239.74499999999998`}, {392.047, 
               240.877}, {391.4959999999999, 241.198}, {390.484, 241.311}, {
               390.484, 237.991}, {393.246, 234.623}}}]}, 
             {Thickness[0.0012000000000000001`], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}}}, {{{400.133, 
               234.623006}, {402.895, 237.99100600000003`}, {402.895, 
               241.31100600000002`}, {401.883, 241.198006}, {401.332, 
               240.795006}, {400.58599999999996`, 239.666006}, {399.953, 
               241.940006}, {398.559, 242.440006}, {396.688, 243.541006}, {
               394.82, 242.440006}, {393.42599999999993`, 242.022006}, {
               392.79299999999995`, 239.745006}, {392.047, 
               240.87700600000002`}, {391.4959999999999, 241.198006}, {
               390.484, 241.31100600000002`}, {390.484, 
               237.99100600000003`}, {393.246, 234.623006}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJRIGYC4skSLGF8/JUOh79qxPTX5Tig8y8q3f5Z51Tp
sEOu9XXgjRwHxQ1FGRNdKx0UQDRnLpxvYgwE1bkOws0HTi00rHQ4BNJflusw
PU+o+YBcpcO1ipdqhjm5DgwgIFDpYMd1fXGBba6D/l0VtkbmSod7QGrq7FwH
Xt1Nc9+/r3B48Xvlx0tbcx3idnnyMJ2ucBC7ee578ONch8dLZx9RWIaQB7tz
UgVcP9j8tgq4+VEp1vf9yyvg9t/3752el1IBd98FkP8CKuDuh/Fh/osF2R9e
Afc/mN9eAQ8fdD4AYnmREg==
               "]]}, 
             {Thickness[0.0012000000000000001`], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJRIGYC4skSLGF8/JUONfr7MvrrchzQ+ReVbv+sc6p0
KIyQ+hF4I8dBcUNRxkTXSoebL9lLJ3Lmwvlvck7YG1fnOgg3Hzi10LDSoRqk
vyzXYXqeUPMBuUqH/k11xoY5uQ4MICBQ6fDNOWdDgW2ug/5dFbZG5kqHaXGz
e6fOznXg1d009/37CocFpvb/Lm3NdYjb5cnDdLrC4bxQCkvI41yHx0tnH1FY
hpA//FUjpn9SBVw/2Py2Crj5USnW9/3LK+D23/fvnZ6XUgF33wWQ/wIq4O6H
8WH+iwXZH14B9z+Y314BDx90PgAvoo88
               "],
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJRIGYC4kWu2z7/Val0qMvaUzL5S5YDOt+W6/riguxK
h2SBCMstE7IdJkuwhPHlVjrYgcTPIviHv2rE9NflOCybfURhQ1Clg9jNc9+D
y3McrLacKNtnWemQ+/z3yo9BOQ475FpfB6pVOkx8W2NvygWVF610cANae2VO
joNsVIr1/d8VDgG90/OEmHMd4nZ58jCdroCo98p1uFrxUs1wFkIebF5DBVy/
Jci8/Aq4+WD5mAq4/SDj/Z0r4O4Di2tUwN0P48P8xwACehWo/i+sgIcPOh8A
E0eazg==
               "]]}, 
             {Thickness[0.0012000000000000001`], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJRIGYC4kWu2z7/Val0MF8S2Dj5S5YDOt+W6/riguxK
B2mvt65bJmQ7TJZgCePLrXT45pyzoeAsgl+jvy+jvy7HYdnsIwobgiodzgul
sISU5zhYbTlRts+y0kFVceK2j0E5DjvkWl8HqlU6eKkL+ZhyQeVFKx3+v+/g
ujonx0E2KsX6/u8KB87jOtVCzLkOcbs8eZhOV0DUe+U6XK14qWY4CyEPNq+h
Aq7fEmRefgXcfLB8TAXcfpDx/s4VcPflPv+98qNGBdz9MD7MfwwgoFeB6v/C
Cnj4oPMBbMiPBA==
               "],
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJRIGYC4kWu2z7/Val0WFJgy3WdO8sBnZ8x8W2NfWKl
Q4TllhNlbVkOkyVYwvhyKx3uqbA1Tt2N4LsBtV3JyXZYNvuIwoagSgeg7sUF
qdkOVkBt+ywrHT4sP+Zt7pjtsEOu9XWgWqUDSFnRjyyIvGilQ0Dv9Dyh7mwH
2agU6/u/Kxxyn/9e+fFetkPcLk8eptMVDuvcH1aJqOU4XK14qWY4CyEPNq+h
Aq4f5Mx9+RVw88HyMRVw+0HG+ztXwN0HNkejAu5+GB/mP6CuTkeLClT/F1bA
wwedDwA3dZqj
               "]]}, 
             {Thickness[0.0012000000000000001`], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJRIGYC4kWu2z7/Val0iF11Sew6d5YDOj9j4tsa+8RK
B4Fiz6tlbVkOkyVYwvhyKx2mxc3unbobwf//voPrak62w7LZRxQ2BFU6fHPO
2VCQmu1gteVE2T7LSocVD6MjzB2zHXbItb4OVKt0CPm3dU/RjyyIvGilA+dx
nWqh7mwH2agU6/u/KxzUFCdu+3gv2yFulycP0+kKh/TGsnYRtRyHqxUv1Qxn
IeTB5jVUwPVbgszLr4CbD5aPqYDbDzLe37kC7r7c579XftSogLsfxof575i3
eaejRQWq/wsr4OGDzgcArUeZzg==
               "],
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{403.832, 204.131}, {
               402.734, 208.91299999999998`}, {401.789, 212.455}, {
               396.4959999999999, 216.053}, {391.207, 212.455}, {390.262, 
               208.91299999999998`}, {389.16400000000004`, 204.131}}}]}, 
             {Thickness[0.0012000000000000001`], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{403.832, 
               204.131006}, {402.734, 208.912006}, {401.789, 
               212.45500600000003`}, {396.4959999999999, 216.053006}, {
               391.207, 212.45500600000003`}, {390.262, 208.912006}, {
               389.16400000000004`, 204.131006}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}}}, {{{419.633, 211.846}, {
               416.445, 210.21699999999998`}, {413.633, 208.33}, {412.832, 
               203.866}, {419.633, 203.866}}}]}, 
             {Thickness[0.0012000000000000001`], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}}}, {{{419.633, 
               211.84600600000002`}, {416.445, 210.217006}, {413.633, 
               208.33000600000003`}, {412.832, 203.86600600000003`}, {419.633,
                203.86600600000003`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
               3}}}, {{{375.42999999999995`, 218.62}, {375.42999999999995`, 
               203.866}, {373.34400000000005`, 203.866}, {373.34400000000005`,
                218.655}, {373.9959999999999, 218.959}, {374.887, 219.006}, {
               375.42999999999995`, 218.62}}}]}, 
             {Thickness[0.0012000000000000001`], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
               3}}}, {{{375.42999999999995`, 218.620006}, {
               375.42999999999995`, 203.86600600000003`}, {
               373.34400000000005`, 203.86600600000003`}, {
               373.34400000000005`, 218.65500600000001`}, {373.9959999999999, 
               218.95900600000002`}, {374.887, 219.006006}, {
               375.42999999999995`, 218.620006}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}}}, {{{373.34400000000005`,
                211.846}, {376.53099999999995`, 210.21699999999998`}, {
               379.688, 208.33}, {380.48799999999994`, 203.866}, {
               373.34400000000005`, 203.866}}}]}, 
             {Thickness[0.0012000000000000001`], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}}}, {{{373.34400000000005`,
                211.84600600000002`}, {376.53099999999995`, 210.217006}, {
               379.688, 208.33000600000003`}, {380.48799999999994`, 
               203.86600600000003`}, {373.34400000000005`, 
               203.86600600000003`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
               3}}}, {{{375.42999999999995`, 218.62}, {375.42999999999995`, 
               203.866}, {373.34400000000005`, 203.866}, {373.34400000000005`,
                218.655}, {373.9959999999999, 218.959}, {374.887, 219.006}, {
               375.42999999999995`, 218.62}}}]}, 
             {Thickness[0.0012000000000000001`], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
               3}}}, {{{375.42999999999995`, 218.620006}, {
               375.42999999999995`, 203.86600600000003`}, {
               373.34400000000005`, 203.86600600000003`}, {
               373.34400000000005`, 218.65500600000001`}, {373.9959999999999, 
               218.95900600000002`}, {374.887, 219.006006}, {
               375.42999999999995`, 218.620006}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}}}, {{{373.34400000000005`,
                211.846}, {376.53099999999995`, 210.21699999999998`}, {
               379.688, 208.33}, {380.48799999999994`, 203.866}, {
               373.34400000000005`, 203.866}}}]}, 
             {Thickness[0.0012000000000000001`], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}}}, {{{373.34400000000005`,
                211.84600600000002`}, {376.53099999999995`, 210.217006}, {
               379.688, 208.33000600000003`}, {380.48799999999994`, 
               203.86600600000003`}, {373.34400000000005`, 
               203.86600600000003`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {0,
                1, 0}, {0, 1, 0}}}, {{{338.191, 232.01399999999998`}, {
               338.191, 237.768}, {343.156, 238.416}, {343.156, 238.416}, {
               343.156, 233.295}, {341.26599999999996`, 233.377}, {340.355, 
               231.678}, {340.355, 229.155}, {340.355, 226.627}, {341.879, 
               226.58800000000002`}, {341.879, 226.58800000000002`}, {341.879,
                212.05700000000002`}, {338.191, 212.05700000000002`}}}]}, 
             {Thickness[0.0012000000000000001`], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {0,
                1, 0}, {0, 1, 0}}}, {{{338.191, 232.014006}, {338.191, 
               237.76800599999999`}, {343.156, 238.416006}, {343.156, 
               238.416006}, {343.156, 233.295006}, {341.26599999999996`, 
               233.37700600000002`}, {340.355, 231.67800599999998`}, {340.355,
                229.15500600000001`}, {340.355, 226.62700600000002`}, {
               341.879, 226.588006}, {341.879, 226.588006}, {341.879, 
               212.05700600000003`}, {338.191, 212.05700600000003`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {0,
                1, 0}, {0, 1, 0}}}, {{{301.48799999999994`, 
               232.01399999999998`}, {301.48799999999994`, 237.768}, {
               296.52299999999997`, 238.416}, {296.52299999999997`, 
               238.416}, {296.52299999999997`, 233.295}, {298.414, 233.377}, {
               299.324, 231.678}, {299.324, 229.155}, {299.324, 226.627}, {
               297.801, 226.58800000000002`}, {297.801, 
               226.58800000000002`}, {297.801, 212.05700000000002`}, {
               301.48799999999994`, 212.05700000000002`}}}]}, 
             {Thickness[0.0012000000000000001`], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {0,
                1, 0}, {0, 1, 0}}}, {{{301.48799999999994`, 232.014006}, {
               301.48799999999994`, 237.76800599999999`}, {
               296.52299999999997`, 238.416006}, {296.52299999999997`, 
               238.416006}, {296.52299999999997`, 233.295006}, {298.414, 
               233.37700600000002`}, {299.324, 231.67800599999998`}, {299.324,
                229.15500600000001`}, {299.324, 226.62700600000002`}, {
               297.801, 226.588006}, {297.801, 226.588006}, {297.801, 
               212.05700600000003`}, {301.48799999999994`, 
               212.05700600000003`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {0, 1, 0}}}, {{{406.637, 201.55700000000002`}, {
               406.637, 208.483}, {404.234, 207.541}, {402.062, 206.147}, {
               401.262, 204.596}, {400.367, 208.44}, {398.64500000000004`, 
               210.135}, {396.4959999999999, 212.459}, {394.348, 210.135}, {
               392.90999999999997`, 208.44}, {392.01599999999996`, 204.596}, {
               391.215, 206.147}, {389.043, 207.541}, {386.641, 208.483}, {
               386.641, 201.55700000000002`}}}]}, 
             {Thickness[0.0012000000000000001`], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {0, 1, 0}}}, {{{406.637, 201.55700600000003`}, {
               406.637, 208.48300600000002`}, {404.234, 207.541006}, {402.062,
                206.147006}, {401.262, 204.59600600000002`}, {400.367, 
               208.440006}, {398.64500000000004`, 210.135006}, {
               396.4959999999999, 212.45900600000002`}, {394.348, 
               210.135006}, {392.90999999999997`, 208.440006}, {
               392.01599999999996`, 204.59600600000002`}, {391.215, 
               206.147006}, {389.043, 207.541006}, {386.641, 
               208.48300600000002`}, {386.641, 201.55700600000003`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               194.39100000000002`, 145.05700000000002`}, {445.605, 
               145.05700000000002`}, {445.60900000000004`, 132.225}, {194.395,
                132.225}}}]}, 
             {Thickness[0.0012000000000000001`], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               194.39100000000002`, 145.057006}, {445.605, 145.057006}, {
               445.60900000000004`, 132.225006}, {194.395, 132.225006}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               187.76999999999998`, 132.24499999999998`}, {452.227, 
               132.24499999999998`}, {452.22999999999996`, 119.432}, {
               187.77299999999997`, 119.432}}}]}, 
             {Thickness[0.0012000000000000001`], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               187.76999999999998`, 132.245006}, {452.227, 132.245006}, {
               452.22999999999996`, 119.432006}, {187.77299999999997`, 
               119.432006}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{207.586, 
               164.248}, {432.41400000000004`, 164.248}, {432.41400000000004`,
                155.947}, {207.586, 155.947}}}]}, 
             {Thickness[0.0012000000000000001`], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{207.586, 
               164.24800599999998`}, {432.41400000000004`, 
               164.24800599999998`}, {432.41400000000004`, 155.947006}, {
               207.586, 155.947006}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{201.012, 
               156.002}, {438.98900000000003`, 156.002}, {438.98900000000003`,
                145.127}, {201.01200000000003`, 145.127}}}]}, 
             {Thickness[0.0012000000000000001`], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{201.012, 
               156.002006}, {438.98900000000003`, 156.002006}, {
               438.98900000000003`, 145.127006}, {201.01200000000003`, 
               145.127006}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{211.512, 
               170.635}, {428.48900000000003`, 170.635}, {428.48900000000003`,
                164.31099999999998`}, {211.51200000000003`, 
               164.31099999999998`}}}]}, 
             {Thickness[0.0012000000000000001`], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{211.512, 
               170.635006}, {428.48900000000003`, 170.635006}, {
               428.48900000000003`, 164.311006}, {211.51200000000003`, 
               164.311006}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{235.062, 
               170.6}, {251.453, 170.6}, {251.453, 119.46699999999998`}, {
               235.062, 119.46699999999998`}}}]}, 
             {Thickness[0.0013056953125000002`], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{235.062, 
               170.600006}, {251.453, 170.600006}, {251.453, 
               119.46700600000003`}, {235.062, 119.46700600000003`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{238.691, 
               170.6}, {247.824, 170.6}, {247.824, 119.46699999999998`}, {
               238.691, 119.46699999999998`}}}]}, 
             {Thickness[0.001303675], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{238.691, 
               170.600006}, {247.824, 170.600006}, {247.824, 
               119.46700600000003`}, {238.691, 119.46700600000003`}}},
               CurveClosed->{1}]}, 
             {Thickness[0.0012000000000000001`], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{238.523, 164.291006}, {
               247.98800000000003`, 164.291006}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0012000000000000001`], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{238.523, 157.893006}, {
               247.98800000000003`, 157.893006}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0012000000000000001`], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{238.523, 
               151.49100599999997`}, {247.98800000000003`, 
               151.49100599999997`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0012000000000000001`], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{238.523, 
               145.09200600000003`}, {247.98800000000003`, 
               145.09200600000003`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0012000000000000001`], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{238.523, 
               138.69400600000006`}, {247.98800000000003`, 
               138.69400600000006`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0012000000000000001`], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{238.523, 
               132.29100599999998`}, {247.98800000000003`, 
               132.29100599999998`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0012000000000000001`], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{238.523, 
               125.89300600000001`}, {247.98800000000003`, 
               125.89300600000001`}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{311.52, 
               170.6}, {327.911, 170.6}, {327.911, 119.46699999999998`}, {
               311.52, 119.46699999999998`}}}]}, 
             {Thickness[0.0013056953125000002`], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{311.52, 
               170.600006}, {327.911, 170.600006}, {327.911, 
               119.46700600000003`}, {311.52, 119.46700600000003`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{315.262, 
               170.6}, {324.395, 170.6}, {324.395, 119.46699999999998`}, {
               315.262, 119.46699999999998`}}}]}, 
             {Thickness[0.001303675], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{315.262, 
               170.600006}, {324.395, 170.600006}, {324.395, 
               119.46700600000003`}, {315.262, 119.46700600000003`}}},
               CurveClosed->{1}]}, 
             {Thickness[0.0012000000000000001`], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{315.309, 164.303006}, {324.121,
                164.303006}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0012000000000000001`], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{315.309, 
               157.89700600000003`}, {324.121, 157.89700600000003`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0012000000000000001`], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{315.309, 151.495006}, {324.121,
                151.495006}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0012000000000000001`], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{315.309, 
               145.09200600000003`}, {324.121, 145.09200600000003`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0012000000000000001`], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{315.309, 
               138.69000600000004`}, {324.121, 138.69000600000004`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0012000000000000001`], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{315.309, 
               132.28400600000003`}, {324.121, 132.28400600000003`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0012000000000000001`], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{315.309, 
               125.88100600000001`}, {324.121, 125.88100600000001`}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               388.43399999999997`, 170.6}, {404.825, 170.6}, {404.825, 
               119.46699999999998`}, {388.43399999999997`, 
               119.46699999999998`}}}]}, 
             {Thickness[0.0013056953125000002`], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               388.43399999999997`, 170.600006}, {404.825, 170.600006}, {
               404.825, 119.46700600000003`}, {388.43399999999997`, 
               119.46700600000003`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{392.062, 
               170.6}, {401.195, 170.6}, {401.195, 119.46699999999998`}, {
               392.062, 119.46699999999998`}}}]}, 
             {Thickness[0.001303675], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{392.062, 
               170.600006}, {401.195, 170.600006}, {401.195, 
               119.46700600000003`}, {392.062, 119.46700600000003`}}},
               CurveClosed->{1}]}, 
             {Thickness[0.0012000000000000001`], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{391.89799999999997`, 
               164.291006}, {401.363, 164.291006}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0012000000000000001`], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{391.89799999999997`, 
               157.893006}, {401.363, 157.893006}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0012000000000000001`], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{391.89799999999997`, 
               151.49100599999997`}, {401.363, 151.49100599999997`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0012000000000000001`], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{391.89799999999997`, 
               145.09200600000003`}, {401.363, 145.09200600000003`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0012000000000000001`], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{391.89799999999997`, 
               138.69400600000006`}, {401.363, 138.69400600000006`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0012000000000000001`], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{391.89799999999997`, 
               132.29100599999998`}, {401.363, 132.29100599999998`}}},
               CurveClosed->{0}]}, 
             {Thickness[0.0012000000000000001`], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}}, {{{391.89799999999997`, 
               125.89300600000001`}, {401.363, 125.89300600000001`}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               270.42999999999995`, 192.791}, {274.10599999999994`, 
               192.791}, {274.10599999999994`, 175.9}, {270.42999999999995`, 
               175.9}}}]}, 
             {Thickness[0.0012000000000000001`], CapForm["Round"], JoinForm[
              "Round"], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               270.42999999999995`, 192.791006}, {274.10599999999994`, 
               192.791006}, {274.10599999999994`, 175.90000600000002`}, {
               270.42999999999995`, 175.90000600000002`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               278.10900000000004`, 192.791}, {281.785, 192.791}, {281.785, 
               175.9}, {278.10900000000004`, 175.9}}}]}, 
             {Thickness[0.0012000000000000001`], CapForm["Round"], JoinForm[
              "Round"], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               278.10900000000004`, 192.791006}, {281.785, 192.791006}, {
               281.785, 175.90000600000002`}, {278.10900000000004`, 
               175.90000600000002`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               285.79299999999995`, 192.791}, {289.465, 192.791}, {289.465, 
               175.9}, {285.79299999999995`, 175.9}}}]}, 
             {Thickness[0.0012000000000000001`], CapForm["Round"], JoinForm[
              "Round"], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               285.79299999999995`, 192.791006}, {289.465, 192.791006}, {
               289.465, 175.90000600000002`}, {285.79299999999995`, 
               175.90000600000002`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{350.113, 
               192.791}, {353.785, 192.791}, {353.785, 175.9}, {350.113, 
               175.9}}}]}, 
             {Thickness[0.0012000000000000001`], CapForm["Round"], JoinForm[
              "Round"], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{350.113, 
               192.791006}, {353.785, 192.791006}, {353.785, 
               175.90000600000002`}, {350.113, 175.90000600000002`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               357.79299999999995`, 192.791}, {361.46899999999994`, 
               192.791}, {361.46899999999994`, 175.9}, {357.79299999999995`, 
               175.9}}}]}, 
             {Thickness[0.0012000000000000001`], CapForm["Round"], JoinForm[
              "Round"], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               357.79299999999995`, 192.791006}, {361.46899999999994`, 
               192.791006}, {361.46899999999994`, 175.90000600000002`}, {
               357.79299999999995`, 175.90000600000002`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               365.47299999999996`, 192.791}, {369.14899999999994`, 
               192.791}, {369.14899999999994`, 175.9}, {365.47299999999996`, 
               175.9}}}]}, 
             {Thickness[0.0012000000000000001`], CapForm["Round"], JoinForm[
              "Round"], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               365.47299999999996`, 192.791006}, {369.14899999999994`, 
               192.791006}, {369.14899999999994`, 175.90000600000002`}, {
               365.47299999999996`, 175.90000600000002`}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{312.191, 
               277.08799999999997`}, {311.78499999999997`, 
               280.28799999999995`}, {328.004, 280.28799999999995`}, {
               327.59799999999996`, 277.08799999999997`}}}]}, 
             {Thickness[0.0012000000000000001`], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{312.191, 
               277.088006}, {311.78499999999997`, 280.288006}, {328.004, 
               280.288006}, {327.59799999999996`, 277.088006}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{313.277, 
               280.35}, {312.92999999999995`, 282.979}, {326.85900000000004`, 
               282.979}, {326.512, 280.35}}}]}, 
             {Thickness[0.0012000000000000001`], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{313.277, 
               280.350006}, {312.92999999999995`, 282.979006}, {
               326.85900000000004`, 282.979006}, {326.512, 280.350006}}},
               CurveClosed->{1}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               315.48799999999994`, 283.077}, {315.258, 285.709}, {
               324.53099999999995`, 285.709}, {324.301, 283.077}}}]}, 
             {Thickness[0.0012000000000000001`], CapForm["Butt"], 
              JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               315.48799999999994`, 283.077006}, {315.258, 285.709006}, {
               324.53099999999995`, 285.709006}, {324.301, 283.077006}}},
               CurveClosed->{1}]}},
            AspectRatio->Automatic,
            ImageSize->{{128}, {85}},
            PlotRange->{{0., 640.}, {0., 411.}}], ",", 
           GraphicsBox[
            {Thickness[0.0010416666666666667`], 
             {FaceForm[{RGBColor[
              0.8078430000000001, 0.06666670000000002, 0.14902], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               0., 0.}, {0., 640.}, {960., 640.}, {960., 0.}}}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0., 
               320.}, {960., 320.}, {960., 0.}, {0., 0.}}}]}},
            AspectRatio->Automatic,
            ImageSize->{{128}, {85}},
            PlotRange->{{0., 960.}, {0., 640.}}], ",", 
           GraphicsBox[
            {Thickness[0.001388888888888889], 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0., 
               0.}, {0., 480.}, {720., 480.}, {720., 0.}}}]}, 
             {FaceForm[{RGBColor[0.737255, 0., 0.17647100000000002`], Opacity[
              1.]}], FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{504., 240.}, {504., 160.47299999999998`}, {439.527, 
               96.}, {360., 96.}, {280.47299999999996`, 96.}, {216., 
               160.47299999999998`}, {216., 240.}, {216., 319.527}, {
               280.47299999999996`, 384.}, {360., 384.}, {439.527, 384.}, {
               504., 319.527}, {504., 240.}}}]}},
            AspectRatio->Automatic,
            ImageSize->{{128}, {85}},
            PlotRange->{{0., 720.}, {0., 480.}}], ",", 
           GraphicsBox[
            {Thickness[0.0016666666666666668`], 
             {FaceForm[{RGBColor[0.9294119999999999, 0.109804, 0.141176], 
              Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0., 
               0.}, {0., 400.}, {600., 400.}, {600., 0.}}}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0., 
               300.}, {600., 300.}, {600., 100.}, {0., 100.}}}]}, 
             {FaceForm[{RGBColor[0., 0.65098, 0.31764699999999996`], Opacity[
              1.]}], FilledCurveBox[{CompressedData["
1:eJxTTMoPSmJiYGDYBMTMQMzAxMDIzAxEDIwMQARhD29Ef29SYiNV4oWgIWgK
AO1qBvs=
                "], {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {
                1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3,
                 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 
                3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 
                3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 
                3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0,
                 1, 0}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
                1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3,
                 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
                1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 
                4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {
                1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {
                1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {
                1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
                1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
                1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 
                0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
                1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}, {1, 3, 3}, {1, 3, 3}}}, {CompressedData["
1:eJx9WWmUVNURHhYFhYMIAwjCBBUGjQtwYgRB5cKgaARRUfRNdw9098z0Mr28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                "], CompressedData["
1:eJxTTMoPSmViYGAwAWIQPVmCJYzPsNABTCcWONhyXV9cYFzo0Po6cIcckM8A
AmYI+S0nyvbNt0Dwl84+orDBB8GPSrG+7x9d6PAYJBFT4OBt3umYkFjocOir
Rkx/SIGD/l0VtkYg/22NvWlcCNT8pEIHPt1Nc98HF0D0AfmWIIuA/OMgA4B8
hQ1FGROB/HcgfUlQ+4D8i0q3f9YB+dUi69wfBhU4lO+bL6WfXOhgBdIfWAAx
JxlqXwDUvhSo//wLHD5d8k0SAPKrQPr9CiDqgPyrFS/VDJH4siCP+RY43Pfv
nZ4H5BuA/OGLkIeEA4J/DORuJD7Yf94I/eBw8kbIx+3y5GFC4j8AqfOChgeQ
Dw43T4T7c5//XvnRowBibjI0fD0Q/gWrA/KFmg+cWgjkuz8E+RAav/HQ8LEs
cADGztMLHoUQdykUOKCkB/4CSLjIQdUzQsNLpNBhkeu2z3+/5EPs5y10iAW5
/3s+JFyAfJCxSkA+2HyeQgdg7L2tAfLB9vBA4xfIB4cTD9S9P/Ih4cxd6LDq
I9AiIB/sbiC/AORwIB8cbtzQ+PsJNZ+r0OESKB38ync4DAoHIN8JZP9vqH1s
hRBxpgIHYVB4sELTpwCCD7ZfA8HXahe7eQ6YvjxA9vNC3RuPFj7A9A4ADNBT
Sg==
                "], CompressedData["
1:eJxTTMoPSmViYGAQBmIQHbvLk4fJvtgh9/nvlR+1Chz076qwNSLx3R9WiaxD
4j9eOvuIggOC3+GY8PRCHIJvy3V9cUFxscOhrxox/TIFDkLNB04tLC922HKi
bN98lgKHTpD6mmKHvSWTJVjO5TtcULr9s66g2MEAZO/efLj5MD7YXBUEv3zf
fCl90WIHJ6AxSofzHRQ3FGVM5C12eFtjbxp3Kd9BJirF+j57sYO6IccamXv5
EPexFTtYgRzwPt9hkeu2z385EO5pfR24Qw6o/2rFSzVDGShfsdjhIshdQP+g
hw8AONOPXA==
                "], CompressedData["
1:eJxTTMoPSmViYGAQA2IQnfv898qPS4ocGEBArsBBqPnAqYX7ixweL519REGh
wGGnXOvrwFNFDjtAtACCDyR3yN3Nh/Nlo1Ks73fnO3Q6Jjy9sKvI4aLS7Z91
RfkOwiDzCqHqffMdbLmuLy5wLnLQv6vC1miaDxGXLHLYeqJs33ytfIerFS/V
DAWKHFTZGqc6G+dD3AXkF2VMfFsD5IPdxw+1zxhqHj/UvSb5Dt7mQBcA+cdA
DBOo+UD+/vlS+neB/MkSLGF8QP4i122f/wL5VluAFn8thMjn5Dvw6W6a+567
yKF3ep5Q8xaofu8ih9hdnjxM3/MdLEHqi4sg/gSGR7XIOveHE4oc7vsDdcgU
OKCHJwB+5Zh8
                "], {{320.469, 257.85200000000003`}, {
                322.90999999999997`, 257.92999999999995`}, {323.219, 
                256.777}, {322.027, 253.35200000000003`}, {321.617, 
                252.172}, {319.914, 251.21499999999997`}, {318.25, 
                251.21499999999997`}, {315.812, 251.21499999999997`}, {
                315.29299999999995`, 251.805}, {315.605, 254.262}, {315.887, 
                256.445}, {316.96099999999996`, 257.441}, {319.383, 
                257.746}, {319.78499999999997`, 257.79699999999997`}, {
                320.14500000000004`, 257.84000000000003`}, {320.469, 
                257.85200000000003`}}, CompressedData["
1:eJxTTMoPSmViYGBQBWIQbct1fXHBxkKHKpF17g/T8h1m5Ak1H9hU6OCY8PSC
Unq+ww651teBWxDyihuKMiZuRfBzn/9e+fEJgg8273ihw+Ols48obMlzOPxV
I6a/q9DhbY29aVxSHsS8kEIH/bsqbI2SeQ7LgMo2SBU6qBtyrJH5lQtRz1Xo
cEHp9s86sTyHB/690/OA/OkgdwH5x73NOx2BfFW2xqnO4nkOVyteqhkC+f2H
gBqBfKDpO+Q4EeaD3cFRCNEnkwcRZy90qAa5Vy4P4l52qHnyeQ7l++ZL6bND
3a8ANQ/I7wU5AMifLMESxgfkg8UV8yD+Zit0uAhyr1IexJ1AftwuTx4m5TwH
kDEbgHxgqL2tAfLvg/wD5B8DuUclDxIuQD5Qd9YeFWj4APk+QOkEVYT6LSfK
9s1XQ6gHu1cdoR7sP408BwYQAPK5gd6y1ULwJ4DCRxvBD+PT3TQXiQ+mdRB8
sHlAflSK9X1/oH9vnvse/LgXGl6VhQ4g79jHQuMbKf0AAGv56A4=
                
                "], CompressedData["
1:eJxTTMoPSmViYGCQB2IQfeirRkx/XrFD6+vAHXIncx3K982X0m8tdth6omzf
/HO5Dvp3VdgaJ0Pl5+Y6CDUfOLWwu9iB6/riAlunXIeoFOv7/u3FDlZbgBr4
cx1m5AFVFBQ73PlZl7XnTY5Dlcg694d+xQ6Pl84+ovAkx2GR67bPf02KHYRB
5tyF8lWKHWRBBt3Pcch5/nvlR7liB3VDjjUy76D65aD2Aflg9wL51SBxJH7c
Lk8epvc5Dse8zTsd5aDuAfIZQADIvw1yz4cciLhsMcRfH3McPB4CbQDyvwGN
OQTkG4DEZaHmf8pxABmXAOQ7JTy9oPQZwe8HWQzkT5ZgCeOThbr/M9Q/MsUQ
e7/kQMwB8vcDg/UukD8dFD5A/tsae9O4bzkOIOfMl4Ga9z0HEi6SxQ7FGRPf
1gDD89Ml3yQBtWKHQltgCNjkQuQdoe5thfIDofZtgMZXYrHD3hKgy47lOqDH
LwAEcN+m
                "], CompressedData["
1:eJxTTMoPSmViYGCQAGIQbXBXha1xb5FD6+vAHXJbcx22nCjbN39fkYOPeadj
ApCvsKEoY+J+hPwFpds/6w4g+LJRKdb33yL45fvmS+l/LXLImPi2xj411+GY
N9CgM0UO+4HCd01yHUDK/XcWOWwF2SOX65Dz/PfKj8uKHPaWTJZg4ct1ANr6
9MKCIofHS2cfUeCBugeJDzYPyFdja5zqzJ3r8OmSb5IAEl8GZMH8IocJh75q
xAD5tlzXFxfMR+gH24/EB7t/dpHDRZC/YPY3Idyn1S5281x6kQNQNmuPQa4D
SNsGsyIHdUOONTJBuQ5XK16qGeYVOTCAQEuuw4w8oeYDXUUO4HCdm+sA9FUY
31qoeZtyHdDDGwDyRK63
                "], {{323.703, 234.539}, {325.039, 
                234.60899999999998`}, {326.49199999999996`, 
                234.35200000000003`}, {327.902, 233.758}, {330.465, 
                232.684}, {330.96099999999996`, 231.754}, {
                330.47299999999996`, 228.945}, {329.812, 225.129}, {
                327.72999999999996`, 224.70299999999997`}, {
                320.60900000000004`, 226.969}, {317.113, 
                228.08200000000002`}, {316.754, 228.61299999999997`}, {
                317.871, 230.92200000000003`}, {318.941, 233.125}, {
                321.14500000000004`, 234.40200000000002`}, {323.703, 
                234.539}}, CompressedData["
1:eJxTTMoPSmViYGAQBmIQfczbvNPxXYGDKlvjVGfjXAf9uypsje8R/GWzjyhs
+IDgM4DAJwS/WmSd+0OXQjh/h1zr68CAQocLSrd/1olB1WsUOqz+eMk3aU2O
wwP/3ul5UoUO++ZL6d/tyHGYkSfUfIChEEIH5ThsOVG2bz7QPUBVQs0mOQ6d
jglPL1wqcHhbY28ax5bjsBNk/qkCBzWQfdxQ9TsKHB4vBTo0JMdBYUNRxsTF
BRB3rcpxWOS67fPfOQUQdzzJcciYCDRpeYED1/XFBbZsUP9tKICoU4G690SB
w0WQ+41yHdDDBwASMn/g
                "], CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQYiBQ4u3TnPf7/McYhKsb7vb17gIAtivM5xaH0d
uEPOt8DhktLtn3WnoPKZBQ7fNGL6D2XmOOQ+/73y44QCh4yJb2vsH2Y7eDys
ElkXWuBQBBLYnO2gsAHIki9wuHnue/DjzmyHCyBzxKD6J2Y79B/6qhFzOR9i
H3+OQ9wuTx6m2fkOE0Di8TkOPuadjgmt+Q6Pl84+ojAlxwGoO2vPlHwH/bsq
bI1bcxzUDTnWyEzLd+idnifUvCPHAeyfGfkQek8OxF8z8x1mAKUP7MuB+GMW
1Pz9OQ5WW06U7QPaV2jLdX3xgRyH495AC+fkQ/xzMMdh/3wp/btAPtj9QD6Y
npvv4JTw9ILS4RyHiyDz5uU7WILMAfLB9myC2n8jx6EYZNDtfIi/Huc4AH3z
9AJPgcOqj5d8k15Aw5O/wOEWyF9AvnDzgVMLBaHh9RLqH6T4AQB+fMn0
                
                "], {{338.85200000000003`, 218.539}, {341.305, 
                218.73399999999998`}, {343.812, 217.008}, {343.453, 
                214.21899999999997`}, {342.9959999999999, 210.676}, {339.129, 
                209.65200000000002`}, {335.949, 212.21499999999997`}, {
                334.051, 213.74599999999998`}, {333.97999999999996`, 
                214.312}, {335.453, 216.535}, {336.29699999999997`, 
                217.805}, {337.566, 218.434}, {338.85200000000003`, 
                218.539}}, CompressedData["
1:eJxTTMoPSmViYGCQB2IQfd+/d3qeR5HD/vlS+ndrshxko1Ks73sWObS+Dtwh
V5vloH9Xha3RGyG/yHXb578+CP4OOaDKAATf27zTMSG4yKE4Y+Lbmuosh0+X
fJMEwoochJsPnFpYmeXg/rBKZF14kcNxkMKKLAeFDUUZEyOLHLacKNs3vyzL
Iff575Ufo4ocCmy5ri8ugZoXXeTAAAIlUPNiihxm5Ak1HyjKcgC7H8hXN+RY
IwPkg80B8r9pxPQfKsxymCzBEsYXW+Rw+2dd1p6CLAeQs+yB/FUfgQYVQM2P
hZoP5Gu3i908B+Q7Jjy9oJSfBRGPg9qXl+XweOnsIwpAPtAU0zgg/9BXoEVA
vgEonHKzHKaD1MVBww/GT4H6PzbLoQNkcFqRgxPIfOcsiDlA+WqRde4P5RDu
d+nOAYZEpgOf7qa5702LHCxBEu2ZDqDo8Vctcojd5cnD9DwTYr9YEcRdNlkQ
c1Sg/quAhg9S/AIATUjYeQ==
                "], CompressedData["
1:eJxTTMoPSmViYGDQA2IQPSNPqPlAQKFD3C5PHiblLAdbruuLCxILHYoyJr6t
Uc9ymA6Sryl08DbvdEwQzHJ4vHT2EYUZhQ6WW06U7Xuc6QDWv6rQoQCk8Uim
wwP/3ul5mwodLijd/lm3LNPhasVLNUMgvxdk0IRMiH4g/22NvWlcX6YDAwgA
+VYg87ozHbTbxW6e21jo8E0jpv9QZ6aDx8MqkXUboeZ3ZDoINx84tRDIB7ur
LRPiXiBfCCTemukAcrY9kA+0PWtPS6ZDtcg694cbCh2cEp5eUGrOdFgGtH4D
kA/SZtuUCXEHkL/Iddvnvw2ZDjJRKdb31xc6TDj0VSOmPtNBYQMwJIB8dUOO
NTJ1UPvWQ91Xm+kAUu4P5O+fL6V/tybToXwfkAHk94EcCOTHgsIVyAf7G8gH
Gdu/Duqeaqj9QD44HKsyIeGwthDij8pMh9znv1d+XFPooMrWONW5HBp+a6D2
l2Y68Olumvt+daGD/l0VtsZSqHuB/FUfL/kmlWRC4m011P4SaHgvKHS4CIqf
JKh/26HhmZbpsEOu9XVgDtT+iZkOiiDzQqHxtyXTYSvQefOdoPofQd3nUOjA
DQrPX9DwBvLB6n4h5ItBBv5G8GVB9v5GqD8OcugfhDzQFTvk/iL4BiD/IfHB
/hGBpk83qH6FLAf09AwAlTtZfA==
                "], {{301.66, 
                208.57399999999998`}, {302.141, 208.61299999999997`}, {
                302.641, 208.14499999999998`}, {303.477, 
                207.21899999999997`}, {304.53099999999995`, 206.059}, {
                305.76599999999996`, 203.84}, {306.215, 202.277}, {
                307.29699999999997`, 198.523}, {305.59, 
                196.95700000000002`}, {302.25, 198.66}, {298.668, 
                200.48800000000003`}, {297.79699999999997`, 
                203.38700000000003`}, {299.867, 206.648}, {300.66, 
                207.89100000000002`}, {301.148, 208.52700000000002`}, {301.66,
                 208.57399999999998`}}, CompressedData["
1:eJxTTMoPSmViYGBQBWIQDQYpxQ6OCU8vKOVnOhz+qhHTX1Ts4ATiF2c6vK2x
N41rK3Yoypj4tsY90wFE2XcXO9w89z348d8Mh8dLZx9R6Ct2iNvlycN0OcOh
fN98KX2gPFjfugyHC0q3f9a1QM1bnOFw3793eh4S/2rFSzXDFqj6RVDzkPh8
upvmvm8udnDpznn+e2GGg8IGoEuA/G9AZx4C8r3NOx0TgHz9uypsjUD+ZAmW
MD4gH+xOIP8iyP6mYof9QGfdXQC1D8gvtOW6vngB1D4kPti+xmIH2agU6/vz
Mxy028VunkPiW205UbYPyAfTQD7YXiR5kDEFSHwQ5Y+kvlpknfvDBoT8MqD1
G5D4YGVIfHA4IPF3yLW+DkTiHwMFABIfHJ9IfF6Qf+oRfDCdjOBbgiwMLoaE
0yUEv296nlCzTiacHwYKmPBMh9znv1d+jIKGV06mA3r6AQC7qQgE
                
                "], CompressedData["
1:eJxTTMoPSmViYGDQA2IQXS2yzv0hS4GDS3fO898HMxy028VunlNE8Mv3zZfS
ty5wAKvbl+EgG5Vifd+7wIEBBHZkONhyXV9ckF7gUAhirMlwsNpyomxfZYHD
fqC2u3MyHLYCufObChy4gcpsuzIcLijd/lnXUuCgbsixRqYtw+FqxUs1w7YC
h4yJb2vsGzMcWl8H7pBrh+qvyXAQaj5waiGQDzanKgNib0eBQxif7qa55RkO
x7zNOx2BfB8glVCa4TAjD6gDyAfakrWnIMNh2ewjChuAfDW2xqnO2Qj1QNtM
49IyHBa5bvv8F+ieApD7XTIcpoP05xQ4TDj0VSNGOsNBCxQe9lD/vkl3uAhy
vxTU/CPpDlWgcNmW79APUj893QHk/flp+Q6PlwIt7kh30L+rwtb4MA/irrx0
B1WQO87nQeQr0h0sQRqm50HMfQc1rywP4h6TDIi6mDyI+UD/gt0Vneew6uMl
36QWBL8X5HAkPsRfCD44fFsRfLC7gHxwuAD54HhpQ8iD3YHEj93lycPUDg1/
oHuKQAa2I9wH9geQfxwUvkA+JJ4yIOkiBuoeIB8cr0A+SFlCJzT8Y6DuAfIN
QHRsHiT9AfnCoPgH8mHpB6yvEuqe5VD3JOQ7fNOI6T8ETK/o6RkA8GtGnw==

                "], {{339.984, 185.88700000000003`}, {344.828, 186.098}, {
                347.445, 182.824}, {342.18, 178.758}, {338.79299999999995`, 
                176.141}, {333.816, 176.035}, {330.734, 178.523}, {
                328.51599999999996`, 180.312}, {328.629, 180.566}, {332.668, 
                183.285}, {335.22299999999996`, 185.}, {337.82, 185.789}, {
                339.984, 185.88700000000003`}}, CompressedData["
1:eJxTTMoPSmViYGBQBWIQfbXipZphVJmDS3fO898H0xwUNhRlTIwuc+C6vrjA
9lCaw2QJljC+2DKHm+e+Bz8Gyu+Qa30dGIdQb7XlRNm+TAT/mLd5p2NLmUPs
Lk8epuVpDhkT39bYzyxzAOoCak1zACmfv6/MYd98Kf27HmkOF5Ru/6wD8veD
+C5pDlrtYjfP9Zc5OCY8vaB0PdVBqPnAqYXlZQ5AU0zj5qU6AG1Z+TEO6p7C
VIh4GNS9eakQ9yHxP13yTRJA4jOAABKfT3fT3PehCL7HwyqRdUh8YZD9SHxF
UPgg8aNSrO/7I/HB/kXil4M8isTPBbk/BMGvFlnn/hCJDw4fvzIHdUOONTJF
qQ6HvmrE9OuUOdz5WZe1pybVARS8CZzQ8GhLdTgOEnhUCgnfiamQ+DtZ6lBo
CzRxA4IPC08YHxz+N1Ih8QfkO4Hkb0PDA8hf5Lrt8987qQ6Pl84+onChFBLe
smkQcYMyBxmQx7enOaCnHwBpDxOs
                "], {{268.883, 176.648}, {
                269.10900000000004`, 176.66}, {269.375, 176.648}, {269.66, 
                176.648}, {272.99199999999996`, 176.648}, {274.828, 
                173.906}, {274.828, 168.92200000000003`}, {274.828, 
                162.22299999999998`}, {270.746, 162.762}, {
                268.85900000000004`, 169.70299999999997`}, {267.219, 
                175.74599999999998`}, {267.055, 176.547}, {268.883, 
                176.648}}, CompressedData["
1:eJxNk21IVFEQhhcRifwgLCJExRZTCUL8EWGx7KhFREQUsfdai4XsgUVEt1NY
lEiiYRFSErHaJkuK/ogQiRLpw0Skwh+6H9ZmKRIRIWFRUSAhNHPuwDkXLofn
zpwz55137vb65uMizeVyefGlVT0BCWp9L+DzUGS6qFPC/huNX/8tCMjZ9aj/
R1xCacWGh/ljAn4ljtRvWpTwt8x/c6qf85E3d0zO3EdePtodbkIeODD2e/2e
5pfRvPIl5Jj741ob8uJaW8Nz5OtVZ77EkNU5Bqv7IF/eMnLwE3LBycC+5YiO
35r6U+Y3uCSj/U5NROdX42c38oUJKiwhQXXvav7e6t1dhxzsWW31ImemBkMe
I6709GkuXyrOaO/T+Yf3YGUjrpZezR9In8Ehz8bUYK/er/QZ8XzSFxbw9uJK
SQXefwfp6RJOndcSKh+/aZmoEbBK9x6R8OAnGuESMF549duxKxJeUWJnwNkf
5H4WC+e7n/t3jvtzQoKPjH3G/vgkvDh/e1v6rGblt8FPsHzUYHWOwWSDe05A
uCm3Y9LH/iBfowCyRfUM3kt6jHylJ6bj3RRAvkR1kM9S/5BR7XihJZ01zv2z
2I8499div5BpW8jieUYuGpXBHov1JQTkks/IlOZBVj5YrA85m+Yfue7poay0
pHB8s3m+ktxfW+crP2ydr/wy8kl21GY/kYfRplGb/UnyPNs8H/Osp5b7Mc96
anmekHd2bV2YPSWd/+od6zvN56f4vsb//R8cH8Yx
                "], CompressedData["
1:eJxTTMoPSmViYGDQAGIQfeirRkz/vEKHjIlva+wnpjoASdO4JYUQelKqg8Fd
FbbGtYUOE8AKUx0eL519RGEXlN+d6mDLdX1xweVChyKQAc2pDsuA0hteFTp4
m3c6JkSmOoC1vSt06JueJ9Ssk+oQlWJ93/9zocPekskSLN9SIOo/FDrIgiTO
pzh8uuSbJADUD7ZnT4qDwgagyS8LHbaeKNs3f1eKwwygMQdeFDqs+ghUuCPF
4WrFSzVDIN8x4ekFpe0pDvog9z4vdACqOrVwa4rDFpC+Z1DztqQ48Olumvv+
aaFDtcg694ebUhyEQeqA/ItKt3/WAflAV4XxAflg8Y0pDiBnH3gCDR8gH+zf
x4UOxSCB9SkOViALHhY63Dz3Pfjx2hSHYyCPPyh0aH0duEMOyAe7436hw52f
dVl71kDdc6/QYTXI/UA+AwgA+cdB+oB8sLvuFELEgXxwON5G8MH+vYVQD3bv
2UKHcJDH1kPDbw/UvxdSIO6GxR9/KkT/HKh8BDS+p0DDtyoVYt/0Qod986X0
73akQtw/Heq/Tmj8z0DE/wVQuM2Auqcn1UG7XezmuZmFkHjqS3XQAvFnFzoU
ggJuAjQ9IKU3ADaTNHQ=
                "]}]}},
            AspectRatio->Automatic,
            ImageSize->{{128}, {85}},
            PlotRange->{{0., 600.}, {0., 400.}}], ",", 
           GraphicsBox[{
             {Thickness[0.0017211703958691911`], 
              {RGBColor[0., 0.21960800000000003`, 0.5764710000000001], 
               Thickness[0.07213642512908776], Opacity[1.], CapForm["Butt"], 
               JoinForm[{"Miter", 4.}], 
               JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                0, 1, 0}}}, {{{21.047, 365.337471}, {507.949, 365.337471}, {
                21.047, 670.247471}, {21.047, 21.04847099999995}, {507.949, 
                21.04847099999995}, {21.047, 507.946471}}},
                CurveClosed->{1}]}, 
              {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
               FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{159.875, 
                129.36100000000002`}, {142.77299999999997`, 
                88.99700000000001}, {125.66799999999999`, 
                129.36100000000002`}}}]}}, {
              {RGBColor[
               0.8627450000000002, 0.07843140000000001, 0.23529400000000003`],
                PolygonBox[{{{21.047, 365.337}, {507.949, 365.337}, {21.047, 
                670.247}}}]}, 
              {RGBColor[
               0.8627450000000002, 0.07843140000000001, 0.23529400000000003`],
                PolygonBox[{{21.047, 21.048}, {507.949, 21.048}, {21.047, 
                507.947}}]}}, 
             {Thickness[0.0017211703958691911`], 
              {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
               FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
                1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4r0lkyVYnrk5uG37/PfKr1qH4oyJb2vq/RwW
SOnfVZlQ7dB84NRCV79Ih9eBO+Rab1Y63PpZl7XnRiKc/67G3jSOKx3OFwZp
EMyB62cAgR+5cPNh/AJbruuLU2ocgKrYGlfmOGjG9B/6eqHKIW6XJw9TdpbD
QaC12zZWOhSC1OlkOERabjlRNqnCoRVkEWuqgypb41Tn1+Vw98D4vdPzhJoj
YuF8kPN2cYbD9d8Gqe8JgpsPdo+CD9x+WHjA3IcePgAXt4qb
                "]], 
               FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}}}, {{{187.90200000000002`, 434.552}, {187.90200000000002`, 
                409.626}, {167.695, 389.42299999999994`}, {
                142.77299999999997`, 389.42299999999994`}, {117.848, 
                389.42299999999994`}, {97.645, 409.626}, {97.645, 434.552}, {
                97.645, 459.474}, {117.848, 479.677}, {142.77299999999997`, 
                479.677}, {167.695, 479.677}, {187.90200000000002`, 
                459.474}, {187.90200000000002`, 434.552}}}], 
               FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                160.04299999999998`, 476.243}, {155., 496.02099999999996`}, {
                142.77299999999997`, 479.677}}}], 
               FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{174.684, 
                466.462}, {177.594, 486.661}, {160.04299999999998`, 
                476.243}}}], 
               FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{184.465, 
                451.822}, {194.883, 469.368}, {174.684, 466.462}}}], 
               FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                187.90200000000002`, 434.552}, {204.242, 446.779}, {184.465, 
                451.822}}}], 
               FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{184.465, 
                417.282}, {204.242, 422.325}, {187.90200000000002`, 
                434.552}}}], 
               FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{174.684, 
                402.64200000000005`}, {194.883, 399.73199999999997`}, {
                184.465, 417.282}}}], 
               FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{125.504, 
                476.243}, {130.547, 496.02099999999996`}, {
                142.77299999999997`, 479.677}}}], 
               FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{110.863, 
                466.462}, {107.953, 486.661}, {125.504, 476.243}}}], 
               FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{101.082, 
                451.822}, {90.664, 469.368}, {110.863, 466.462}}}], 
               FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{97.645, 434.552}, {
                81.30499999999999, 446.779}, {101.082, 451.822}}}], 
               FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{101.082, 
                417.282}, {81.30499999999999, 422.325}, {97.645, 434.552}}}], 
               FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{110.863, 
                402.64200000000005`}, {90.664, 399.73199999999997`}, {101.082,
                 417.282}}}], 
               FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}}}, {{{208.85500000000002`, 193.19299999999998`}, {
                208.85500000000002`, 156.697}, {179.26999999999998`, 
                127.111}, {142.77299999999997`, 127.111}, {106.277, 
                127.111}, {76.691, 156.697}, {76.691, 193.19299999999998`}, {
                76.691, 229.689}, {106.277, 259.279}, {142.77299999999997`, 
                259.279}, {179.26999999999998`, 259.279}, {
                208.85500000000002`, 229.689}, {208.85500000000002`, 
                193.19299999999998`}}}], 
               FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{159.875, 
                129.36100000000002`}, {142.77299999999997`, 
                88.99700000000001}, {125.66799999999999`, 
                129.36100000000002`}}}], 
               FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                125.66799999999999`, 257.025}, {142.77299999999997`, 
                297.392}, {159.875, 257.025}}}], 
               FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{78.94100000000002, 
                176.091}, {38.574, 193.19299999999998`}, {78.94100000000002, 
                210.298}}}], 
               FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{206.605, 
                210.298}, {246.969, 193.19299999999998`}, {206.605, 
                176.091}}}], 
               FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                125.66799999999999`, 129.36100000000002`}, {90.67599999999999,
                 102.95400000000001`}, {96.043, 146.466}}}], 
               FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{159.875, 
                257.025}, {194.871, 283.4309999999999}, {189.5, 239.923}}}], 
               FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{78.94100000000002, 
                210.298}, {52.535000000000004`, 245.29}, {96.043, 239.923}}}],
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{206.605, 
                176.091}, {233.012, 141.095}, {189.5, 146.466}}}], 
               FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{96.043, 146.466}, {
                52.535000000000004`, 141.095}, {78.94100000000002, 
                176.091}}}], 
               FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{189.5, 239.923}, {
                233.012, 245.29}, {206.605, 210.298}}}], 
               FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{96.043, 239.923}, {
                90.67599999999999, 283.4309999999999}, {125.66799999999999`, 
                257.025}}}], 
               FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{189.5, 146.466}, {
                194.871, 102.95400000000001`}, {159.875, 
                129.36100000000002`}}}]}}},
            AspectRatio->Automatic,
            ImageSize->{{128}, {85}},
            PlotRange->{{0., 581.}, {0., 709.}}], ",", 
           GraphicsBox[{
             {Thickness[0.001388888888888889], 
              {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
               FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0., 
                0.}, {0., 480.}, {720., 480.}, {720., 0.}}}]}, 
              {FaceForm[{RGBColor[0.003921569999999999, 0.254902, 0.109804], 
               Opacity[1.]}], 
               FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{180., 
                480.}, {720., 480.}, {720., 0.}, {180., 0.}}}]}, 
              {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
               FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}}}, {{{594., 240.}, {594., 160.47299999999998`}, {
                529.5269999999999, 96.}, {450., 96.}, {370.47299999999996`, 
                96.}, {306., 160.47299999999998`}, {306., 240.}, {306., 
                319.527}, {370.47299999999996`, 384.}, {450., 384.}, {
                529.5269999999999, 384.}, {594., 319.527}, {594., 240.}}}]}, 
              {FaceForm[{RGBColor[0.003921569999999999, 0.254902, 0.109804], 
               Opacity[1.]}], 
               FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}}}, {{{585.4649999999999, 360.414}, {633.898, 
                305.92599999999993`}, {628.992, 222.49200000000002`}, {
                574.504, 174.059}, {520.016, 125.62899999999999`}, {436.582, 
                130.535}, {388.148, 185.023}, {339.719, 239.512}, {344.625, 
                322.941}, {399.113, 371.375}, {453.59799999999996`, 
                419.809}, {537.031, 414.902}, {585.4649999999999, 
                360.414}}}]}}, 
             {RGBColor[1., 1., 1.], 
              PolygonBox[{{473.984, 299.066}, {508.04896572377527`, 
               291.59710042426104`}, {511.47299999999996`, 256.895}, {
               529.1002640300983, 286.9815069648755}, {563.168, 279.512}, {
               539.9966282021564, 305.5796022787413}, {539.9966282021563, 
               305.5796022787413}, {557.625, 335.668}, {525.6781375521971, 
               321.6877862374376}, {502.508, 347.754}, {505.9325235671064, 
               313.0469406822399}}]}},
            AspectRatio->Automatic,
            ImageSize->{{128}, {85}},
            PlotRange->{{0., 720.}, {0., 480.}}], ",", 
           GraphicsBox[
            {Thickness[0.001388888888888889], 
             {FaceForm[{RGBColor[
              0., 0.21960800000000003`, 0.6588240000000001], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0., 
               0.}, {0., 360.}, {720., 360.}, {720., 0.}}}]}, 
             {FaceForm[{RGBColor[
              0.8078430000000001, 0.06666670000000002, 0.14902], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               0., 180.}, {720., 180.}, {720., 0.}, {0., 0.}}}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{311.77, 180.}, {0., 
               0.}, {0., 360.}}}]}, 
             {FaceForm[{RGBColor[
              0.988235, 0.8196080000000001, 0.08627450000000002], Opacity[
              1.]}], FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{148., 180.}, {148., 160.117}, {131.883, 144.}, {112., 
               144.}, {92.117, 144.}, {76., 160.117}, {76., 180.}, {76., 
               199.883}, {92.117, 216.}, {112., 216.}, {131.883, 216.}, {148.,
                199.883}, {148., 180.}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{36., 
               180.}, {40.676, 175.324}, {112., 180.}, {40.676, 184.676}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{44., 171.047}, {
               47.815999999999995`, 167.23399999999998`}, {112., 180.}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{44., 188.953}, {
               47.815999999999995`, 192.766}, {112., 180.}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               58.26200000000001, 233.738}, {58.26200000000001, 227.129}, {
               112., 180.}, {64.871, 233.738}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{57.586, 221.754}, {
               57.586, 216.359}, {112., 180.}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{70.24600000000001, 
               234.414}, {75.641, 234.414}, {112., 180.}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{112., 
               256.}, {107.324, 251.324}, {112., 180.}, {116.67599999999999`, 
               251.324}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{103.04700000000001`,
                248.}, {99.23400000000001, 244.184}, {112., 180.}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{120.953, 248.}, {
               124.766, 244.184}, {112., 180.}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{165.738, 
               233.738}, {159.129, 233.738}, {112., 180.}, {165.738, 
               227.129}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{153.754, 234.414}, {
               148.359, 234.414}, {112., 180.}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{166.414, 221.754}, {
               166.414, 216.359}, {112., 180.}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{188., 
               180.}, {183.324, 184.676}, {112., 180.}, {183.324, 175.324}}}],
               FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{180., 188.953}, {
               176.184, 192.766}, {112., 180.}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{180., 171.047}, {
               176.184, 167.23399999999998`}, {112., 180.}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{165.738, 
               126.262}, {165.738, 132.871}, {112., 180.}, {159.129, 
               126.262}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{166.414, 
               138.24599999999998`}, {166.414, 143.641}, {112., 180.}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{153.754, 125.586}, {
               148.359, 125.586}, {112., 180.}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{112., 
               104.}, {116.67599999999999`, 108.67599999999999`}, {112., 
               180.}, {107.324, 108.67599999999999`}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{120.953, 112.}, {
               124.766, 115.816}, {112., 180.}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{103.04700000000001`,
                112.}, {99.23400000000001, 115.816}, {112., 180.}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               58.26200000000001, 126.262}, {64.871, 126.262}, {112., 180.}, {
               58.26200000000001, 132.871}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{70.24600000000001, 
               125.586}, {75.641, 125.586}, {112., 180.}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{57.586, 
               138.24599999999998`}, {57.586, 143.641}, {112., 180.}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}}}, {{{275.77, 180.}, {262.242, 175.297}, {261.949, 
               160.98000000000002`}, {253.297, 172.39100000000002`}, {239.59, 
               168.24599999999998`}, {247.76999999999998`, 180.}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}}}, {{{275.77, 180.}, {262.242, 184.70299999999997`}, {
               261.949, 199.02}, {253.297, 187.60899999999998`}, {239.59, 
               191.754}, {247.76999999999998`, 180.}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}}}, {{{18., 31.176000000000002`}, {20.691000000000003`, 
               45.242000000000004`}, {8.437999999999999, 52.656}, {22.648, 
               54.440999999999995`}, {25.91, 68.387}, {32., 55.426}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}}}, {{{18., 31.176000000000002`}, {28.836000000000002`, 
               40.543}, {41.382999999999996`, 33.633}, {35.824, 46.836}, {
               46.27, 56.633}, {32., 55.426}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}}}, {{{18., 328.824}, {28.836000000000002`, 319.457}, {
               41.382999999999996`, 326.367}, {35.824, 313.16400000000004`}, {
               46.27, 303.367}, {32., 304.574}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}}}, {{{18., 328.824}, {20.691000000000003`, 314.758}, {
               8.437999999999999, 307.34400000000005`}, {22.648, 305.559}, {
               25.91, 291.613}, {32., 304.574}}}]}},
            AspectRatio->Automatic,
            ImageSize->{{128}, {85}},
            PlotRange->{{0., 720.}, {0., 360.}}], ",", 
           GraphicsBox[
            {Thickness[0.001639344262295082], 
             {FaceForm[{RGBColor[
              0.5529410000000001, 0.105882, 0.23921600000000004`], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               0., 240.}, {609.602, 240.}, {609.602, 0.}, {0., 0.}}}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
               1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJRIGZiQAd5DhhCYJABF7/1sy5rj0Sew81z34MfL9Vy
gMlPkWAJ41tr5QCTh4i7wOW3ff57pWKlF1xeha1xqvPqAAdU80Pg8rdBdEg4
XB6iPgrN/Di4/Lsae9O4VQlweaHmA6cWhiahmZ8Cl4eoT4XLQ9Sno5mfiWZ+
Fpr5OWjm5zkAADWeXto=
               "]]}},
            AspectRatio->Automatic,
            ImageSize->{{128}, {85}},
            PlotRange->{{0., 610.}, {0., 240.}}], ",", 
           GraphicsBox[
            {Thickness[0.00028935185185185184`], 
             {FaceForm[{RGBColor[0.9294119999999999, 0.160784, 0.223529], 
              Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0., 
               2304.}, {3456., 2304.}, {3456., 1152.}, {0., 1152.}}}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0., 
               1152.}, {3456., 1152.}, {3456., 0.}, {0., 0.}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 
               3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJDIGYCYm/zTseE1kkODGAw2wHGf6lmyKEjO8tBla1x
qnPEJAc+3U1z861mOrSL3TxXzjjJgWONTNSTjBlgdWtWTXQACn8Pnj7d4fbP
uiwbrYkOP4IfL5W+Ps3hsm+SwI3OCQ5yra8Dd5hNc5jq3J3z/FI/WDxi2lSH
bZ//XqkI6nM4qrCh6IXoVIj963sg+vdPcciY+LbGnqfbYe775ce8M6Y4CERY
bjnh1ukA1G1pYj3F4fHS2UcUGtvhfP27KmyNu1vh/EqQA781w/WD7Q9qgpsP
tO3phfUNcPun5wk1H4irg7uvfN98Kf271XD3A2VPLYyuhPtPNirF+n5kOdz/
IOds+FcKDx+wexaXwMNvsgRLGN/7Ynj4wviw8IfxxYHmXX40G67/4yXfpAlH
58DNB9s/fS7cfnA8ZMyDuw9sv8Z8uPsfVomscz85H+4/sPkmC+D+nwcMH+7S
BfDwAbpCt2jBAnj4AU2XuXV6ATx8z38Pfpz6aAE8/GF8WPzA+LD4g+mHxS/M
fFj8o9gPTB8w98HSD8z9sPQF8x8s/cH8D0ufsPCBpV9Y+MHSNyx80dM/AJyY
ZBE=
               "]]}, 
             {FaceForm[{RGBColor[0.9294119999999999, 0.160784, 0.223529], 
              Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 
               3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJDIGYCYh/zTscHS6c4MIDBbAcYv9CW6/pizVkOGRPf
1thXT3HwBoonBM90kG99HWihOcXhsm+SQETvDIdls48oGFyf7DD3/fJj3sen
O0SlWN8/HzsZol9wOkT/sUkO69wfVolUTXN4qWbIsUZvEti+hkdTHfaUTJZg
qZzosOVE2T75zKkOLt05z39vmuBgfd+/V1x8qsM0Z6DAzX6HT5eAFh6F2qvb
53Bqoeu24llTHLYC9c1v6IHz+XQ3zX1/uQvOB7tbvROuH+Q+/9ntcPPB7uNv
g9sP1r+4Be4+wQjLLSdKmuHuB0kvd22C+28qyH1BjXD/Ly4ASqxrgIePAEg/
VwM8/IC+DePLroeHL4wPC38Yv//QV42Ya7Ph+kHum79mDtx8HZA7iubC7U8C
KbSYB3cfWP+7eXD3B+2Qa33dOh/uP1AaOMC3AO5/UDwWeC+Ahw/IvJKSBfDw
axe7ea587gJ4+Err31U5tmkBPPxhfFj8wPiw+IPph8UvzHxY/MPsh6UPFPcB
0w/M/bD0BfMfLP3B/A9Ln7DwgaVfWPjB0jcsfNHTPwCAp1ta
               "]]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               805.758, 1717.547}, {746.906, 1762.6909999999998`}, {
               688.0740000000001, 1717.527}, {710.727, 1790.3239999999998`}, {
               651.6880000000001, 1835.195}, {724.535, 1835.043}, {746.883, 
               1907.941}, {769.254, 1835.051}, {842.102, 1835.23}, {783.082, 
               1790.336}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               1267.508, 1717.547}, {1208.6599999999999`, 
               1762.6909999999998`}, {1149.8239999999998`, 1717.527}, {
               1172.477, 1790.3239999999998`}, {1113.441, 1835.195}, {
               1186.289, 1835.043}, {1208.6329999999998`, 1907.941}, {
               1231.008, 1835.051}, {1303.8519999999999`, 1835.23}, {
               1244.8319999999999`, 1790.336}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               1036.867, 1888.9180000000001`}, {978.02, 1934.062}, {
               919.1840000000001, 1888.895}, {941.8359999999999, 
               1961.6909999999998`}, {882.8009999999999, 2006.566}, {955.648, 
               2006.41}, {977.996, 2079.309}, {1000.3669999999998`, 
               2006.4180000000001`}, {1073.2150000000001`, 2006.598}, {
               1014.191, 1961.703}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               892.156, 1443.348}, {833.309, 1488.492}, {774.4730000000001, 
               1443.328}, {797.125, 1516.125}, {738.09, 1560.996}, {810.938, 
               1560.8439999999998`}, {833.2850000000001, 1633.742}, {855.656, 
               1560.8519999999999`}, {928.504, 1561.031}, {869.48, 
               1516.137}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               1181.105, 1443.348}, {1122.258, 1488.492}, {
               1063.4260000000002`, 1443.328}, {1086.0739999999998`, 
               1516.125}, {1027.039, 1560.996}, {1099.887, 
               1560.8439999999998`}, {1122.234, 1633.742}, {1144.605, 
               1560.8519999999999`}, {1217.453, 1561.031}, {1158.434, 
               1516.137}}}]}},
            AspectRatio->Automatic,
            ImageSize->{{128}, {85}},
            PlotRange->{{0., 3456.}, {0., 2304.}}], ",", 
           GraphicsBox[
            {Thickness[0.001388888888888889], 
             {FaceForm[{RGBColor[0.9294119999999999, 0.109804, 0.141176], 
              Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0., 
               0.}, {0., 480.}, {720., 480.}, {720., 0.}}}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0., 
               400.}, {720., 400.}, {720., 80.}, {0., 80.}}}]}, 
             {FaceForm[{RGBColor[0.141176, 0.11372500000000002`, 0.309804], 
              Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0., 
               320.}, {720., 320.}, {720., 160.}, {0., 160.}}}]}},
            AspectRatio->Automatic,
            ImageSize->{{128}, {85}},
            PlotRange->{{0., 720.}, {0., 480.}}], ",", 
           GraphicsBox[
            {Thickness[0.001388888888888889], 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0., 
               0.}, {0., 480.}, {720., 480.}, {720., 0.}}}]}, 
             {Thickness[0.001388888888888889], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{110.387, 
               334.301}, {176.94899999999998`, 434.14500000000004`}, {243.512,
                389.77}, {176.94899999999998`, 289.92199999999997`}}}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{121.48, 
               314.883}, {199.137, 431.371}, {207.45700000000002`, 425.824}, {
               129.80100000000002`, 309.33599999999996`}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{146.441, 
               298.242}, {224.098, 414.72999999999996`}, {232.418, 409.184}, {
               154.762, 292.695}}}]}, 
             {Thickness[0.001388888888888889], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               476.48799999999994`, 90.23}, {543.0509999999999, 190.078}, {
               609.613, 145.69899999999998`}, {543.0509999999999, 45.855}}}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{487.582, 
               70.816}, {565.238, 187.305}, {573.559, 181.758}, {495.902, 
               65.27}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{512.543, 
               54.176}, {590.1990000000001, 170.664}, {598.52, 165.117}, {
               520.8629999999999, 48.629000000000005`}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{498.676, 
               141.539}, {504.22299999999996`, 149.859}, {587.4259999999999, 
               94.391}, {581.879, 86.07}}}]}, 
             {FaceForm[{RGBColor[0.776471, 0.047058800000000005`, 0.188235], 
              Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{426.562, 339.848}, {481.707, 303.082}, {
               496.60900000000004`, 228.578}, {459.848, 
               173.43800000000002`}, {423.082, 118.293}, {348.578, 103.391}, {
               293.43799999999993`, 140.15200000000002`}, {
               238.29299999999998`, 176.918}, {223.39100000000002`, 
               251.42200000000003`}, {260.15200000000004`, 306.562}, {
               296.91799999999995`, 361.707}, {371.42199999999997`, 
               376.60900000000004`}, {426.562, 339.848}}}]}, 
             {FaceForm[{RGBColor[
              0., 0.20392200000000002`, 0.47058800000000006`], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4gf+vdPznAocFrlu+/xXo9hBla1xqnN4nkOH
Y8LTC22FEPGQfIfW14E75CTzHKbnCTUf8Cl0KM6Y+LbmdbZDzvPfKz++K3K4
ee578OO9mQ7l++ZL6WeWQuR3ZzkwgEBDGYRmgJo7rdzhuLd5p+OiAofJEixh
fIJVEFqx0AGkzX5zNUSeq8DB4K4KW2NorUOVyDr3h89yHYCypnFXaiH0pwwH
xQ1FGRP31jjsLQGasC7VYensIwobllU76IP0ZSY52HFdX1zwtNLBasuJsn38
CQ6HvmrE9P8oh9gzNc4B6JtTC7nLIP7iioW4/2exgxcPk3b7ujiH2F2ePEzh
RQ77gcJ3WxIh6rYUOGwFGjd/UzLUXGj4mKZDxL3yHKpB7uXLdvABeiOhNdfh
1s+6rD0v8jDCFz38ASyVsr0=
               "]]}, 
             {Thickness[0.001388888888888889], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               176.94899999999998`, 45.855}, {110.387, 145.69899999999998`}, {
               176.94899999999998`, 190.078}, {243.512, 90.23}}}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{199.137, 
               48.629000000000005`}, {121.48, 165.117}, {129.80100000000002`, 
               170.664}, {207.45700000000002`, 54.176}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{224.098, 
               65.27}, {146.441, 181.758}, {154.762, 187.305}, {232.418, 
               70.816}}}]}, 
             {Thickness[0.001388888888888889], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               543.0509999999999, 289.92199999999997`}, {476.48799999999994`, 
               389.77}, {543.0509999999999, 434.14500000000004`}, {609.613, 
               334.301}}}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{565.238, 
               292.695}, {487.582, 409.184}, {495.902, 414.72999999999996`}, {
               573.559, 298.242}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               590.1990000000001, 309.33599999999996`}, {512.543, 425.824}, {
               520.8629999999999, 431.371}, {598.52, 314.883}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               504.22299999999996`, 330.141}, {498.676, 
               338.46099999999996`}, {581.879, 393.92999999999995`}, {
               587.4259999999999, 385.60900000000004`}}}]}, 
             {Thickness[0.001388888888888889], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{540.277, 
               348.168}, {529.1840000000001, 364.809}, {545.824, 375.902}, {
               556.918, 359.262}}}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               163.08200000000002`, 102.71100000000001`}, {157.535, 
               111.031}, {190.816, 133.21899999999997`}, {196.363, 
               124.898}}}]}},
            AspectRatio->Automatic,
            ImageSize->{{128}, {85}},
            PlotRange->{{0., 720.}, {0., 480.}}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           GraphicsBox[
            {Thickness[0.000925925925925926], 
             {FaceForm[{RGBColor[1., 0.6, 0.2], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0., 
               0.}, {0., 720.}, {1080., 720.}, {1080., 0.}}}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0., 
               480.}, {1080., 480.}, {1080., 240.}, {0., 240.}}}]}, 
             {FaceForm[{RGBColor[0.0705882, 0.533333, 0.027451000000000003`], 
              Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0., 
               240.}, {1080., 240.}, {1080., 0.}, {0., 0.}}}]}, 
             {FaceForm[{RGBColor[0., 0., 0.533333], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{636., 360.}, {636., 306.97999999999996`}, {593.02, 
               264.}, {540., 264.}, {486.97999999999996`, 264.}, {444., 
               306.97999999999996`}, {444., 360.}, {444., 413.02}, {
               486.97999999999996`, 456.}, {540., 456.}, {593.02, 456.}, {
               636., 413.02}, {636., 360.}}}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{624., 360.}, {624., 313.60900000000004`}, {586.391, 
               276.}, {540., 276.}, {493.60900000000004`, 276.}, {456., 
               313.60900000000004`}, {456., 360.}, {456., 
               406.39099999999996`}, {493.60900000000004`, 444.}, {540., 
               444.}, {586.391, 444.}, {624., 406.39099999999996`}, {624., 
               360.}}}]}, 
             {FaceForm[{RGBColor[0., 0., 0.533333], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{556.8009999999999, 360.}, {556.8009999999999, 
               350.72299999999996`}, {549.277, 343.199}, {540., 343.199}, {
               530.7230000000001, 343.199}, {523.1990000000001, 
               350.72299999999996`}, {523.1990000000001, 360.}, {
               523.1990000000001, 369.277}, {530.7230000000001, 376.801}, {
               540., 376.801}, {549.277, 376.801}, {556.8009999999999, 
               369.277}, {556.8009999999999, 360.}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{627.4449999999999, 348.48799999999994`}, {627.145, 
               346.188}, {625.031, 344.57}, {622.734, 344.871}, {620.434, 
               345.176}, {618.8159999999999, 347.28499999999997`}, {619.117, 
               349.58599999999996`}, {619.4219999999999, 351.883}, {621.531, 
               353.504}, {623.828, 353.199}, {626.129, 352.89799999999997`}, {
               627.75, 350.789}, {627.4449999999999, 348.48799999999994`}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{540., 
               276.}, {542.879, 326.39799999999997`}, {540., 
               350.39799999999997`}, {537.121, 326.39799999999997`}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{621.484, 326.246}, {620.5980000000001, 324.105}, {
               618.141, 323.08599999999996`}, {616., 323.97299999999996`}, {
               613.8549999999999, 324.863}, {612.8399999999999, 327.32}, {
               613.727, 329.46099999999996`}, {614.613, 331.605}, {617.07, 
               332.621}, {619.215, 331.734}, {621.3549999999999, 330.848}, {
               622.375, 328.39099999999996`}, {621.484, 326.246}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{518.258, 
               278.863}, {534.086, 326.801}, {537.516, 350.727}, {528.523, 
               328.289}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{609.9730000000001, 306.309}, {608.5619999999999, 
               304.469}, {605.9259999999999, 304.121}, {604.086, 
               305.53099999999995`}, {602.246, 306.945}, {601.898, 309.582}, {
               603.309, 311.42199999999997`}, {604.7230000000001, 313.262}, {
               607.3589999999999, 313.60900000000004`}, {609.1990000000001, 
               312.195}, {611.039, 310.78499999999997`}, {611.387, 308.148}, {
               609.9730000000001, 306.309}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{498., 
               287.254}, {525.695, 329.46099999999996`}, {535.1990000000001, 
               351.688}, {520.707, 332.34000000000003`}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{593.691, 290.027}, {591.8519999999999, 288.613}, {
               589.215, 288.96099999999996`}, {587.805, 290.801}, {586.391, 
               292.641}, {586.738, 295.277}, {588.5780000000001, 296.691}, {
               590.418, 298.10200000000003`}, {593.055, 297.754}, {
               594.4689999999999, 295.914}, {595.879, 294.074}, {595.531, 
               291.43799999999993`}, {593.691, 290.027}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               480.60200000000003`, 300.60200000000003`}, {518.277, 
               334.203}, {533.211, 353.21099999999996`}, {514.2030000000001, 
               338.277}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{573.754, 278.51599999999996`}, {571.609, 277.625}, {
               569.1519999999999, 278.64500000000004`}, {568.266, 
               280.78499999999997`}, {567.379, 282.92999999999995`}, {568.395,
                285.387}, {570.539, 286.27299999999997`}, {572.6800000000001, 
               287.16}, {575.137, 286.14500000000004`}, {576.0269999999999, 
               284.}, {576.914, 281.85900000000004`}, {575.895, 279.402}, {
               573.754, 278.51599999999996`}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{467.254, 
               318.}, {512.3399999999999, 340.707}, {531.6880000000001, 
               355.199}, {509.46099999999996`, 345.695}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{551.512, 272.555}, {549.211, 272.25}, {547.102, 
               273.871}, {546.8009999999999, 276.172}, {546.496, 278.469}, {
               548.117, 280.578}, {550.414, 280.883}, {552.715, 281.184}, {
               554.824, 279.566}, {555.129, 277.26599999999996`}, {555.43, 
               274.969}, {553.8119999999999, 272.855}, {551.512, 272.555}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{458.863, 
               338.258}, {508.289, 348.52299999999997`}, {530.727, 
               357.51599999999996`}, {506.801, 354.08599999999996`}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{528.488, 272.555}, {526.1880000000001, 272.855}, {
               524.57, 274.969}, {524.871, 277.26599999999996`}, {525.176, 
               279.566}, {527.2850000000001, 281.184}, {529.586, 280.883}, {
               531.883, 280.578}, {533.504, 278.469}, {533.1990000000001, 
               276.172}, {532.898, 273.871}, {530.7890000000001, 272.25}, {
               528.488, 272.555}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{456., 
               360.}, {506.39799999999997`, 357.121}, {530.398, 360.}, {
               506.39799999999997`, 362.879}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{506.246, 278.51599999999996`}, {504.105, 279.402}, {
               503.08599999999996`, 281.85900000000004`}, {
               503.97299999999996`, 284.}, {504.863, 286.14500000000004`}, {
               507.32, 287.16}, {509.46099999999996`, 286.27299999999997`}, {
               511.605, 285.387}, {512.621, 282.92999999999995`}, {511.734, 
               280.78499999999997`}, {510.848, 278.64500000000004`}, {
               508.39099999999996`, 277.625}, {506.246, 
               278.51599999999996`}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{458.863, 
               381.742}, {506.801, 365.914}, {530.727, 362.484}, {508.289, 
               371.477}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{486.309, 290.027}, {484.469, 291.43799999999993`}, {
               484.121, 294.074}, {485.53099999999995`, 295.914}, {486.945, 
               297.754}, {489.582, 298.10200000000003`}, {491.42199999999997`,
                296.691}, {493.262, 295.277}, {493.60900000000004`, 
               292.641}, {492.195, 290.801}, {490.78499999999997`, 
               288.96099999999996`}, {488.148, 288.613}, {486.309, 
               290.027}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{467.254, 
               402.}, {509.46099999999996`, 374.305}, {531.6880000000001, 
               364.801}, {512.3399999999999, 379.29299999999995`}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{470.027, 306.309}, {468.613, 308.148}, {
               468.96099999999996`, 310.78499999999997`}, {470.801, 
               312.195}, {472.641, 313.60900000000004`}, {475.277, 313.262}, {
               476.691, 311.42199999999997`}, {478.10200000000003`, 
               309.582}, {477.754, 306.945}, {475.914, 305.53099999999995`}, {
               474.074, 304.121}, {471.43799999999993`, 304.469}, {470.027, 
               306.309}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               480.60200000000003`, 419.39799999999997`}, {514.2030000000001, 
               381.72299999999996`}, {533.211, 366.789}, {518.277, 
               385.79699999999997`}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{458.51599999999996`, 326.246}, {457.625, 
               328.39099999999996`}, {458.64500000000004`, 330.848}, {
               460.78499999999997`, 331.734}, {462.92999999999995`, 
               332.621}, {465.387, 331.605}, {466.27299999999997`, 
               329.46099999999996`}, {467.16, 327.32}, {466.14500000000004`, 
               324.863}, {464., 323.97299999999996`}, {461.85900000000004`, 
               323.08599999999996`}, {459.402, 324.105}, {458.51599999999996`,
                326.246}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{498., 
               432.746}, {520.707, 387.66}, {535.1990000000001, 368.312}, {
               525.695, 390.539}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{452.555, 348.48799999999994`}, {452.25, 350.789}, {
               453.871, 352.89799999999997`}, {456.172, 353.199}, {458.469, 
               353.504}, {460.578, 351.883}, {460.883, 349.58599999999996`}, {
               461.184, 347.28499999999997`}, {459.566, 345.176}, {
               457.26599999999996`, 344.871}, {454.969, 344.57}, {452.855, 
               346.188}, {452.555, 348.48799999999994`}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{518.258, 
               441.137}, {528.523, 391.71099999999996`}, {537.516, 
               369.27299999999997`}, {534.086, 393.199}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{452.555, 371.512}, {452.855, 373.812}, {454.969, 
               375.42999999999995`}, {457.26599999999996`, 375.129}, {459.566,
                374.824}, {461.184, 372.715}, {460.883, 370.414}, {460.578, 
               368.117}, {458.469, 366.4959999999999}, {456.172, 366.801}, {
               453.871, 367.10200000000003`}, {452.25, 369.21099999999996`}, {
               452.555, 371.512}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{540., 
               444.}, {537.121, 393.60200000000003`}, {540., 
               369.60200000000003`}, {542.879, 393.60200000000003`}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{458.51599999999996`, 393.754}, {459.402, 395.895}, {
               461.85900000000004`, 396.914}, {464., 396.027}, {
               466.14500000000004`, 395.137}, {467.16, 392.68}, {
               466.27299999999997`, 390.539}, {465.387, 388.395}, {
               462.92999999999995`, 387.379}, {460.78499999999997`, 
               388.26599999999996`}, {458.64500000000004`, 
               389.15200000000004`}, {457.625, 391.60900000000004`}, {
               458.51599999999996`, 393.754}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{561.742, 
               441.137}, {545.914, 393.199}, {542.484, 369.27299999999997`}, {
               551.477, 391.71099999999996`}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{470.027, 413.691}, {471.43799999999993`, 
               415.53099999999995`}, {474.074, 415.879}, {475.914, 414.469}, {
               477.754, 413.055}, {478.10200000000003`, 
               410.41799999999995`}, {476.691, 408.578}, {475.277, 
               406.73799999999994`}, {472.641, 406.39099999999996`}, {470.801,
                407.805}, {468.96099999999996`, 409.215}, {468.613, 
               411.85200000000003`}, {470.027, 413.691}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{582., 
               432.746}, {554.305, 390.539}, {544.8009999999999, 368.312}, {
               559.2930000000001, 387.66}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{486.309, 429.97299999999996`}, {488.148, 431.387}, {
               490.78499999999997`, 431.039}, {492.195, 429.199}, {
               493.60900000000004`, 427.35900000000004`}, {493.262, 
               424.72299999999996`}, {491.42199999999997`, 423.309}, {489.582,
                421.89799999999997`}, {486.945, 422.246}, {
               485.53099999999995`, 424.08599999999996`}, {484.121, 
               425.92599999999993`}, {484.469, 428.562}, {486.309, 
               429.97299999999996`}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{599.398, 
               419.39799999999997`}, {561.7230000000001, 
               385.79699999999997`}, {546.7890000000001, 366.789}, {565.797, 
               381.72299999999996`}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{506.246, 441.484}, {508.39099999999996`, 442.375}, {
               510.848, 441.355}, {511.734, 439.215}, {512.621, 437.07}, {
               511.605, 434.613}, {509.46099999999996`, 433.727}, {507.32, 
               432.84000000000003`}, {504.863, 433.855}, {503.97299999999996`,
                436.}, {503.08599999999996`, 438.141}, {504.105, 
               440.59799999999996`}, {506.246, 441.484}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{612.746, 
               402.}, {567.66, 379.29299999999995`}, {548.3119999999999, 
               364.801}, {570.539, 374.305}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{528.488, 447.445}, {530.7890000000001, 447.75}, {
               532.898, 446.129}, {533.1990000000001, 443.828}, {533.504, 
               441.53099999999995`}, {531.883, 439.42199999999997`}, {529.586,
                439.117}, {527.2850000000001, 438.816}, {525.176, 
               440.43399999999997`}, {524.871, 442.734}, {524.57, 
               445.03099999999995`}, {526.1880000000001, 
               447.14500000000004`}, {528.488, 447.445}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{621.137, 
               381.742}, {571.711, 371.477}, {549.2730000000001, 362.484}, {
               573.1990000000001, 365.914}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{551.512, 447.445}, {553.8119999999999, 
               447.14500000000004`}, {555.43, 445.03099999999995`}, {555.129, 
               442.734}, {554.824, 440.43399999999997`}, {552.715, 438.816}, {
               550.414, 439.117}, {548.117, 439.42199999999997`}, {546.496, 
               441.53099999999995`}, {546.8009999999999, 443.828}, {547.102, 
               446.129}, {549.211, 447.75}, {551.512, 447.445}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{624., 
               360.}, {573.602, 362.879}, {549.602, 360.}, {573.602, 
               357.121}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{573.754, 441.484}, {575.895, 440.59799999999996`}, {
               576.914, 438.141}, {576.0269999999999, 436.}, {575.137, 
               433.855}, {572.6800000000001, 432.84000000000003`}, {570.539, 
               433.727}, {568.395, 434.613}, {567.379, 437.07}, {568.266, 
               439.215}, {569.1519999999999, 441.355}, {571.609, 442.375}, {
               573.754, 441.484}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{621.137, 
               338.258}, {573.1990000000001, 354.08599999999996`}, {
               549.2730000000001, 357.51599999999996`}, {571.711, 
               348.52299999999997`}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{593.691, 429.97299999999996`}, {595.531, 428.562}, {
               595.879, 425.92599999999993`}, {594.4689999999999, 
               424.08599999999996`}, {593.055, 422.246}, {590.418, 
               421.89799999999997`}, {588.5780000000001, 423.309}, {586.738, 
               424.72299999999996`}, {586.391, 427.35900000000004`}, {587.805,
                429.199}, {589.215, 431.039}, {591.8519999999999, 431.387}, {
               593.691, 429.97299999999996`}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{612.746, 
               318.}, {570.539, 345.695}, {548.3119999999999, 355.199}, {
               567.66, 340.707}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{609.9730000000001, 413.691}, {611.387, 
               411.85200000000003`}, {611.039, 409.215}, {609.1990000000001, 
               407.805}, {607.3589999999999, 406.39099999999996`}, {
               604.7230000000001, 406.73799999999994`}, {603.309, 408.578}, {
               601.898, 410.41799999999995`}, {602.246, 413.055}, {604.086, 
               414.469}, {605.9259999999999, 415.879}, {608.5619999999999, 
               415.53099999999995`}, {609.9730000000001, 413.691}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{599.398, 
               300.60200000000003`}, {565.797, 338.277}, {546.7890000000001, 
               353.21099999999996`}, {561.7230000000001, 334.203}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{621.484, 393.754}, {622.375, 391.60900000000004`}, {
               621.3549999999999, 389.15200000000004`}, {619.215, 
               388.26599999999996`}, {617.07, 387.379}, {614.613, 388.395}, {
               613.727, 390.539}, {612.8399999999999, 392.68}, {
               613.8549999999999, 395.137}, {616., 396.027}, {618.141, 
               396.914}, {620.5980000000001, 395.895}, {621.484, 393.754}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{582., 
               287.254}, {559.2930000000001, 332.34000000000003`}, {
               544.8009999999999, 351.688}, {554.305, 329.46099999999996`}}}],
               FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{627.4449999999999, 371.512}, {627.75, 
               369.21099999999996`}, {626.129, 367.10200000000003`}, {623.828,
                366.801}, {621.531, 366.4959999999999}, {619.4219999999999, 
               368.117}, {619.117, 370.414}, {618.8159999999999, 372.715}, {
               620.434, 374.824}, {622.734, 375.129}, {625.031, 
               375.42999999999995`}, {627.145, 373.812}, {627.4449999999999, 
               371.512}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{561.742, 
               278.863}, {551.477, 328.289}, {542.484, 350.727}, {545.914, 
               326.801}}}]}},
            AspectRatio->Automatic,
            ImageSize->{{128}, {85}},
            PlotRange->{{0., 1080.}, {0., 720.}}], ",", 
           GraphicsBox[
            {Thickness[0.0007936507936507937], 
             {FaceForm[{RGBColor[
              0.13725500000000002`, 0.623529, 0.25098000000000004`], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               0., 0.}, {0., 720.}, {1260., 720.}, {1260., 0.}}}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0., 
               480.}, {1260., 480.}, {1260., 240.}, {0., 240.}}}]}, 
             {FaceForm[{RGBColor[0.854902, 0., 0.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0., 
               240.}, {1260., 240.}, {1260., 0.}, {0., 0.}}}]}, 
             {RGBColor[1., 1., 1.], Thickness[0.0044444444444444444`], 
              Opacity[1.], CapForm["Round"], JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {
                0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1,
                 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 
                0}}, {{0, 2, 0}}}, {{{579.602, 516.398}, {646.8009999999999, 
                516.398}}, {{579.602, 494.}, {579.602, 505.19899999999996`}, {
                602., 505.19899999999996`}, {602., 494.}, {624.398, 494.}, {
                624.398, 505.19899999999996`}, {613.1990000000001, 
                505.19899999999996`}}, {{646.8009999999999, 494.}, {635.602, 
                494.}, {635.602, 505.19899999999996`}, {658., 
                505.19899999999996`}, {658., 516.398}}, {{658., 
                505.19899999999996`}, {658., 494.}, {680.398, 494.}, {680.398,
                 516.398}}, {{669.1990000000001, 516.398}, {669.1990000000001,
                 494.}}, {{590.8009999999999, 494.}, {590.805, 494.}}},
               CurveClosed->{0, 0, 0, 0, 0, 0}]}, 
             {RGBColor[1., 1., 1.], Thickness[0.005312127152597305], Opacity[
              1.], CapForm["Round"], JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}}}, {{{579.6013999999999,
                481.602}, {624.3986, 481.602}}, {{635.6013999999999, 
               481.602}, {680.3986, 481.602}}},
               CurveClosed->{0, 0}]}, 
             {RGBColor[1., 1., 1.], Thickness[0.0044444444444444444`], 
              Opacity[1.], CapForm["Round"], JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {
                0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1,
                 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 
                0}}, {{0, 2, 0}}}, {{{579.602, 226.}, {646.8009999999999, 
                226.}}, {{579.602, 203.60199999999998`}, {579.602, 214.801}, {
                602., 214.801}, {602., 203.60199999999998`}, {624.398, 
                203.60199999999998`}, {624.398, 214.801}, {613.1990000000001, 
                214.801}}, {{646.8009999999999, 203.60199999999998`}, {
                635.602, 203.60199999999998`}, {635.602, 214.801}, {658., 
                214.801}, {658., 226.}}, {{658., 214.801}, {658., 
                203.60199999999998`}, {680.398, 203.60199999999998`}, {
                680.398, 226.}}, {{669.1990000000001, 226.}, {
                669.1990000000001, 203.60199999999998`}}, {{590.8009999999999,
                 203.60199999999998`}, {590.805, 203.60199999999998`}}},
               CurveClosed->{0, 0, 0, 0, 0, 0}]}, 
             {RGBColor[1., 1., 1.], Thickness[0.005312127152597305], Opacity[
              1.], CapForm["Round"], JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}}}, {{{579.6013999999999,
                238.39799999999997`}, {624.3986, 238.39799999999997`}}, {{
               635.6013999999999, 238.39799999999997`}, {680.3986, 
               238.39799999999997`}}},
               CurveClosed->{0, 0}]}, 
             {RGBColor[1., 1., 1.], Thickness[0.0044444444444444444`], 
              Opacity[1.], CapForm["Round"], JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {
                0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1,
                 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 
                0}}, {{0, 2, 0}}}, {{{691.602, 516.398}, {758.8009999999999, 
                516.398}}, {{691.602, 494.}, {691.602, 505.19899999999996`}, {
                714., 505.19899999999996`}, {714., 494.}, {736.398, 494.}, {
                736.398, 505.19899999999996`}, {725.1990000000001, 
                505.19899999999996`}}, {{758.8009999999999, 494.}, {747.602, 
                494.}, {747.602, 505.19899999999996`}, {770., 
                505.19899999999996`}, {770., 516.398}}, {{770., 
                505.19899999999996`}, {770., 494.}, {792.398, 494.}, {792.398,
                 516.398}}, {{781.1990000000001, 516.398}, {781.1990000000001,
                 494.}}, {{702.8009999999999, 494.}, {702.805, 494.}}},
               CurveClosed->{0, 0, 0, 0, 0, 0}]}, 
             {RGBColor[1., 1., 1.], Thickness[0.005312127152597305], Opacity[
              1.], CapForm["Round"], JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}}}, {{{691.6013999999999,
                481.602}, {736.3986, 481.602}}, {{747.6013999999999, 
               481.602}, {792.3986, 481.602}}},
               CurveClosed->{0, 0}]}, 
             {RGBColor[1., 1., 1.], Thickness[0.0044444444444444444`], 
              Opacity[1.], CapForm["Round"], JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {
                0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1,
                 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 
                0}}, {{0, 2, 0}}}, {{{691.602, 226.}, {758.8009999999999, 
                226.}}, {{691.602, 203.60199999999998`}, {691.602, 214.801}, {
                714., 214.801}, {714., 203.60199999999998`}, {736.398, 
                203.60199999999998`}, {736.398, 214.801}, {725.1990000000001, 
                214.801}}, {{758.8009999999999, 203.60199999999998`}, {
                747.602, 203.60199999999998`}, {747.602, 214.801}, {770., 
                214.801}, {770., 226.}}, {{770., 214.801}, {770., 
                203.60199999999998`}, {792.398, 203.60199999999998`}, {
                792.398, 226.}}, {{781.1990000000001, 226.}, {
                781.1990000000001, 203.60199999999998`}}, {{702.8009999999999,
                 203.60199999999998`}, {702.805, 203.60199999999998`}}},
               CurveClosed->{0, 0, 0, 0, 0, 0}]}, 
             {RGBColor[1., 1., 1.], Thickness[0.005312127152597305], Opacity[
              1.], CapForm["Round"], JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}}}, {{{691.6013999999999,
                238.39799999999997`}, {736.3986, 238.39799999999997`}}, {{
               747.6013999999999, 238.39799999999997`}, {792.3986, 
               238.39799999999997`}}},
               CurveClosed->{0, 0}]}, 
             {RGBColor[1., 1., 1.], Thickness[0.0044444444444444444`], 
              Opacity[1.], CapForm["Round"], JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {
                0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1,
                 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 
                0}}, {{0, 2, 0}}}, {{{355.60200000000003`, 516.398}, {422.801,
                 516.398}}, {{355.60200000000003`, 494.}, {
                355.60200000000003`, 505.19899999999996`}, {378., 
                505.19899999999996`}, {378., 494.}, {400.39799999999997`, 
                494.}, {400.39799999999997`, 505.19899999999996`}, {389.199, 
                505.19899999999996`}}, {{422.801, 494.}, {411.60200000000003`,
                 494.}, {411.60200000000003`, 505.19899999999996`}, {434., 
                505.19899999999996`}, {434., 516.398}}, {{434., 
                505.19899999999996`}, {434., 494.}, {456.39799999999997`, 
                494.}, {456.39799999999997`, 516.398}}, {{445.199, 516.398}, {
                445.199, 494.}}, {{366.801, 494.}, {366.805, 494.}}},
               CurveClosed->{0, 0, 0, 0, 0, 0}]}, 
             {RGBColor[1., 1., 1.], Thickness[0.005312127152597305], Opacity[
              1.], CapForm["Round"], JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}}}, {{{355.6014, 
               481.602}, {400.3986, 481.602}}, {{411.60139999999996`, 
               481.602}, {456.3986, 481.602}}},
               CurveClosed->{0, 0}]}, 
             {RGBColor[1., 1., 1.], Thickness[0.0044444444444444444`], 
              Opacity[1.], CapForm["Round"], JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {
                0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1,
                 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 
                0}}, {{0, 2, 0}}}, {{{355.60200000000003`, 226.}, {422.801, 
                226.}}, {{355.60200000000003`, 203.60199999999998`}, {
                355.60200000000003`, 214.801}, {378., 214.801}, {378., 
                203.60199999999998`}, {400.39799999999997`, 
                203.60199999999998`}, {400.39799999999997`, 214.801}, {
                389.199, 214.801}}, {{422.801, 203.60199999999998`}, {
                411.60200000000003`, 203.60199999999998`}, {
                411.60200000000003`, 214.801}, {434., 214.801}, {434., 
                226.}}, {{434., 214.801}, {434., 203.60199999999998`}, {
                456.39799999999997`, 203.60199999999998`}, {
                456.39799999999997`, 226.}}, {{445.199, 226.}, {445.199, 
                203.60199999999998`}}, {{366.801, 203.60199999999998`}, {
                366.805, 203.60199999999998`}}},
               CurveClosed->{0, 0, 0, 0, 0, 0}]}, 
             {RGBColor[1., 1., 1.], Thickness[0.005312127152597305], Opacity[
              1.], CapForm["Round"], JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}}}, {{{355.6014, 
               238.39799999999997`}, {400.3986, 238.39799999999997`}}, {{
               411.60139999999996`, 238.39799999999997`}, {456.3986, 
               238.39799999999997`}}},
               CurveClosed->{0, 0}]}, 
             {RGBColor[1., 1., 1.], Thickness[0.0044444444444444444`], 
              Opacity[1.], CapForm["Round"], JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {
                0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1,
                 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 
                0}}, {{0, 2, 0}}}, {{{467.60200000000003`, 516.398}, {
                534.8009999999999, 516.398}}, {{467.60200000000003`, 494.}, {
                467.60200000000003`, 505.19899999999996`}, {490., 
                505.19899999999996`}, {490., 494.}, {512.398, 494.}, {512.398,
                 505.19899999999996`}, {501.199, 505.19899999999996`}}, {{
                534.8009999999999, 494.}, {523.602, 494.}, {523.602, 
                505.19899999999996`}, {546., 505.19899999999996`}, {546., 
                516.398}}, {{546., 505.19899999999996`}, {546., 494.}, {
                568.398, 494.}, {568.398, 516.398}}, {{557.1990000000001, 
                516.398}, {557.1990000000001, 494.}}, {{478.801, 494.}, {
                478.805, 494.}}},
               CurveClosed->{0, 0, 0, 0, 0, 0}]}, 
             {RGBColor[1., 1., 1.], Thickness[0.005312127152597305], Opacity[
              1.], CapForm["Round"], JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}}}, {{{
               467.60139999999996`, 481.602}, {512.3986, 481.602}}, {{
               523.6013999999999, 481.602}, {568.3986, 481.602}}},
               CurveClosed->{0, 0}]}, 
             {RGBColor[1., 1., 1.], Thickness[0.0044444444444444444`], 
              Opacity[1.], CapForm["Round"], JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {
                0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1,
                 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 
                0}}, {{0, 2, 0}}}, {{{467.60200000000003`, 226.}, {
                534.8009999999999, 226.}}, {{467.60200000000003`, 
                203.60199999999998`}, {467.60200000000003`, 214.801}, {490., 
                214.801}, {490., 203.60199999999998`}, {512.398, 
                203.60199999999998`}, {512.398, 214.801}, {501.199, 
                214.801}}, {{534.8009999999999, 203.60199999999998`}, {
                523.602, 203.60199999999998`}, {523.602, 214.801}, {546., 
                214.801}, {546., 226.}}, {{546., 214.801}, {546., 
                203.60199999999998`}, {568.398, 203.60199999999998`}, {
                568.398, 226.}}, {{557.1990000000001, 226.}, {
                557.1990000000001, 203.60199999999998`}}, {{478.801, 
                203.60199999999998`}, {478.805, 203.60199999999998`}}},
               CurveClosed->{0, 0, 0, 0, 0, 0}]}, 
             {RGBColor[1., 1., 1.], Thickness[0.005312127152597305], Opacity[
              1.], CapForm["Round"], JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}}}, {{{
               467.60139999999996`, 238.39799999999997`}, {512.3986, 
               238.39799999999997`}}, {{523.6013999999999, 
               238.39799999999997`}, {568.3986, 238.39799999999997`}}},
               CurveClosed->{0, 0}]}, 
             {RGBColor[1., 1., 1.], Thickness[0.0044444444444444444`], 
              Opacity[1.], CapForm["Round"], JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {
                0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1,
                 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 
                0}}, {{0, 2, 0}}}, {{{1027.6019999999999`, 516.398}, {
                1094.801, 516.398}}, {{1027.6019999999999`, 494.}, {
                1027.6019999999999`, 505.19899999999996`}, {1050., 
                505.19899999999996`}, {1050., 494.}, {1072.398, 494.}, {
                1072.398, 505.19899999999996`}, {1061.1989999999998`, 
                505.19899999999996`}}, {{1094.801, 494.}, {
                1083.6019999999999`, 494.}, {1083.6019999999999`, 
                505.19899999999996`}, {1106., 505.19899999999996`}, {1106., 
                516.398}}, {{1106., 505.19899999999996`}, {1106., 494.}, {
                1128.398, 494.}, {1128.398, 516.398}}, {{1117.1989999999998`, 
                516.398}, {1117.1989999999998`, 494.}}, {{1038.801, 494.}, {
                1038.805, 494.}}},
               CurveClosed->{0, 0, 0, 0, 0, 0}]}, 
             {RGBColor[1., 1., 1.], Thickness[0.005312127152597305], Opacity[
              1.], CapForm["Round"], JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}}}, {{{1027.6014, 
               481.602}, {1072.3986, 481.602}}, {{1083.6013999999998`, 
               481.602}, {1128.3986, 481.602}}},
               CurveClosed->{0, 0}]}, 
             {RGBColor[1., 1., 1.], Thickness[0.0044444444444444444`], 
              Opacity[1.], CapForm["Round"], JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {
                0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1,
                 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 
                0}}, {{0, 2, 0}}}, {{{1027.6019999999999`, 226.}, {1094.801, 
                226.}}, {{1027.6019999999999`, 203.60199999999998`}, {
                1027.6019999999999`, 214.801}, {1050., 214.801}, {1050., 
                203.60199999999998`}, {1072.398, 203.60199999999998`}, {
                1072.398, 214.801}, {1061.1989999999998`, 214.801}}, {{
                1094.801, 203.60199999999998`}, {1083.6019999999999`, 
                203.60199999999998`}, {1083.6019999999999`, 214.801}, {1106., 
                214.801}, {1106., 226.}}, {{1106., 214.801}, {1106., 
                203.60199999999998`}, {1128.398, 203.60199999999998`}, {
                1128.398, 226.}}, {{1117.1989999999998`, 226.}, {
                1117.1989999999998`, 203.60199999999998`}}, {{1038.801, 
                203.60199999999998`}, {1038.805, 203.60199999999998`}}},
               CurveClosed->{0, 0, 0, 0, 0, 0}]}, 
             {RGBColor[1., 1., 1.], Thickness[0.005312127152597305], Opacity[
              1.], CapForm["Round"], JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}}}, {{{1027.6014, 
               238.39799999999997`}, {1072.3986, 238.39799999999997`}}, {{
               1083.6013999999998`, 238.39799999999997`}, {1128.3986, 
               238.39799999999997`}}},
               CurveClosed->{0, 0}]}, 
             {RGBColor[1., 1., 1.], Thickness[0.0044444444444444444`], 
              Opacity[1.], CapForm["Round"], JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {
                0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1,
                 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 
                0}}, {{0, 2, 0}}}, {{{1139.6019999999999`, 516.398}, {
                1206.801, 516.398}}, {{1139.6019999999999`, 494.}, {
                1139.6019999999999`, 505.19899999999996`}, {1162., 
                505.19899999999996`}, {1162., 494.}, {1184.398, 494.}, {
                1184.398, 505.19899999999996`}, {1173.1989999999998`, 
                505.19899999999996`}}, {{1206.801, 494.}, {
                1195.6019999999999`, 494.}, {1195.6019999999999`, 
                505.19899999999996`}, {1218., 505.19899999999996`}, {1218., 
                516.398}}, {{1218., 505.19899999999996`}, {1218., 494.}, {
                1240.398, 494.}, {1240.398, 516.398}}, {{1229.1989999999998`, 
                516.398}, {1229.1989999999998`, 494.}}, {{1150.801, 494.}, {
                1150.805, 494.}}},
               CurveClosed->{0, 0, 0, 0, 0, 0}]}, 
             {RGBColor[1., 1., 1.], Thickness[0.005312127152597305], Opacity[
              1.], CapForm["Round"], JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}}}, {{{
               1139.6013999999998`, 481.602}, {1184.3986, 481.602}}, {{
               1195.6013999999998`, 481.602}, {1240.3986, 481.602}}},
               CurveClosed->{0, 0}]}, 
             {RGBColor[1., 1., 1.], Thickness[0.0044444444444444444`], 
              Opacity[1.], CapForm["Round"], JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {
                0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1,
                 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 
                0}}, {{0, 2, 0}}}, {{{1139.6019999999999`, 226.}, {1206.801, 
                226.}}, {{1139.6019999999999`, 203.60199999999998`}, {
                1139.6019999999999`, 214.801}, {1162., 214.801}, {1162., 
                203.60199999999998`}, {1184.398, 203.60199999999998`}, {
                1184.398, 214.801}, {1173.1989999999998`, 214.801}}, {{
                1206.801, 203.60199999999998`}, {1195.6019999999999`, 
                203.60199999999998`}, {1195.6019999999999`, 214.801}, {1218., 
                214.801}, {1218., 226.}}, {{1218., 214.801}, {1218., 
                203.60199999999998`}, {1240.398, 203.60199999999998`}, {
                1240.398, 226.}}, {{1229.1989999999998`, 226.}, {
                1229.1989999999998`, 203.60199999999998`}}, {{1150.801, 
                203.60199999999998`}, {1150.805, 203.60199999999998`}}},
               CurveClosed->{0, 0, 0, 0, 0, 0}]}, 
             {RGBColor[1., 1., 1.], Thickness[0.005312127152597305], Opacity[
              1.], CapForm["Round"], JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}}}, {{{
               1139.6013999999998`, 238.39799999999997`}, {1184.3986, 
               238.39799999999997`}}, {{1195.6013999999998`, 
               238.39799999999997`}, {1240.3986, 238.39799999999997`}}},
               CurveClosed->{0, 0}]}, 
             {RGBColor[1., 1., 1.], Thickness[0.0044444444444444444`], 
              Opacity[1.], CapForm["Round"], JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {
                0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1,
                 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 
                0}}, {{0, 2, 0}}}, {{{803.602, 516.398}, {870.8009999999999, 
                516.398}}, {{803.602, 494.}, {803.602, 505.19899999999996`}, {
                826., 505.19899999999996`}, {826., 494.}, {848.398, 494.}, {
                848.398, 505.19899999999996`}, {837.1990000000001, 
                505.19899999999996`}}, {{870.8009999999999, 494.}, {859.602, 
                494.}, {859.602, 505.19899999999996`}, {882., 
                505.19899999999996`}, {882., 516.398}}, {{882., 
                505.19899999999996`}, {882., 494.}, {904.398, 494.}, {904.398,
                 516.398}}, {{893.1990000000001, 516.398}, {893.1990000000001,
                 494.}}, {{814.8009999999999, 494.}, {814.805, 494.}}},
               CurveClosed->{0, 0, 0, 0, 0, 0}]}, 
             {RGBColor[1., 1., 1.], Thickness[0.005312127152597305], Opacity[
              1.], CapForm["Round"], JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}}}, {{{803.6013999999999,
                481.602}, {848.3986, 481.602}}, {{859.6013999999999, 
               481.602}, {904.3986, 481.602}}},
               CurveClosed->{0, 0}]}, 
             {RGBColor[1., 1., 1.], Thickness[0.0044444444444444444`], 
              Opacity[1.], CapForm["Round"], JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {
                0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1,
                 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 
                0}}, {{0, 2, 0}}}, {{{803.602, 226.}, {870.8009999999999, 
                226.}}, {{803.602, 203.60199999999998`}, {803.602, 214.801}, {
                826., 214.801}, {826., 203.60199999999998`}, {848.398, 
                203.60199999999998`}, {848.398, 214.801}, {837.1990000000001, 
                214.801}}, {{870.8009999999999, 203.60199999999998`}, {
                859.602, 203.60199999999998`}, {859.602, 214.801}, {882., 
                214.801}, {882., 226.}}, {{882., 214.801}, {882., 
                203.60199999999998`}, {904.398, 203.60199999999998`}, {
                904.398, 226.}}, {{893.1990000000001, 226.}, {
                893.1990000000001, 203.60199999999998`}}, {{814.8009999999999,
                 203.60199999999998`}, {814.805, 203.60199999999998`}}},
               CurveClosed->{0, 0, 0, 0, 0, 0}]}, 
             {RGBColor[1., 1., 1.], Thickness[0.005312127152597305], Opacity[
              1.], CapForm["Round"], JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}}}, {{{803.6013999999999,
                238.39799999999997`}, {848.3986, 238.39799999999997`}}, {{
               859.6013999999999, 238.39799999999997`}, {904.3986, 
               238.39799999999997`}}},
               CurveClosed->{0, 0}]}, 
             {RGBColor[1., 1., 1.], Thickness[0.0044444444444444444`], 
              Opacity[1.], CapForm["Round"], JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {
                0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1,
                 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 
                0}}, {{0, 2, 0}}}, {{{915.602, 516.398}, {982.8009999999999, 
                516.398}}, {{915.602, 494.}, {915.602, 505.19899999999996`}, {
                938., 505.19899999999996`}, {938., 494.}, {960.398, 494.}, {
                960.398, 505.19899999999996`}, {949.1990000000001, 
                505.19899999999996`}}, {{982.8009999999999, 494.}, {971.602, 
                494.}, {971.602, 505.19899999999996`}, {994., 
                505.19899999999996`}, {994., 516.398}}, {{994., 
                505.19899999999996`}, {994., 494.}, {1016.398, 494.}, {
                1016.398, 516.398}}, {{1005.1990000000001`, 516.398}, {
                1005.1990000000001`, 494.}}, {{926.8009999999999, 494.}, {
                926.805, 494.}}},
               CurveClosed->{0, 0, 0, 0, 0, 0}]}, 
             {RGBColor[1., 1., 1.], Thickness[0.005312127152597305], Opacity[
              1.], CapForm["Round"], JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}}}, {{{915.6013999999999,
                481.602}, {960.3986, 481.602}}, {{971.6013999999999, 
               481.602}, {1016.3986, 481.602}}},
               CurveClosed->{0, 0}]}, 
             {RGBColor[1., 1., 1.], Thickness[0.0044444444444444444`], 
              Opacity[1.], CapForm["Round"], JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {
                0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1,
                 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 
                0}}, {{0, 2, 0}}}, {{{915.602, 226.}, {982.8009999999999, 
                226.}}, {{915.602, 203.60199999999998`}, {915.602, 214.801}, {
                938., 214.801}, {938., 203.60199999999998`}, {960.398, 
                203.60199999999998`}, {960.398, 214.801}, {949.1990000000001, 
                214.801}}, {{982.8009999999999, 203.60199999999998`}, {
                971.602, 203.60199999999998`}, {971.602, 214.801}, {994., 
                214.801}, {994., 226.}}, {{994., 214.801}, {994., 
                203.60199999999998`}, {1016.398, 203.60199999999998`}, {
                1016.398, 226.}}, {{1005.1990000000001`, 226.}, {
                1005.1990000000001`, 203.60199999999998`}}, {{
                926.8009999999999, 203.60199999999998`}, {926.805, 
                203.60199999999998`}}},
               CurveClosed->{0, 0, 0, 0, 0, 0}]}, 
             {RGBColor[1., 1., 1.], Thickness[0.005312127152597305], Opacity[
              1.], CapForm["Round"], JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}}}, {{{915.6013999999999,
                238.39799999999997`}, {960.3986, 238.39799999999997`}}, {{
               971.6013999999999, 238.39799999999997`}, {1016.3986, 
               238.39799999999997`}}},
               CurveClosed->{0, 0}]}, 
             {RGBColor[1., 1., 1.], Thickness[0.0044444444444444444`], 
              Opacity[1.], CapForm["Round"], JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {
                0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1,
                 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 
                0}}, {{0, 2, 0}}}, {{{243.602, 516.398}, {310.801, 
                516.398}}, {{243.602, 494.}, {243.602, 505.19899999999996`}, {
                266., 505.19899999999996`}, {266., 494.}, {
                288.39799999999997`, 494.}, {288.39799999999997`, 
                505.19899999999996`}, {277.199, 505.19899999999996`}}, {{
                310.801, 494.}, {299.60200000000003`, 494.}, {
                299.60200000000003`, 505.19899999999996`}, {322., 
                505.19899999999996`}, {322., 516.398}}, {{322., 
                505.19899999999996`}, {322., 494.}, {344.39799999999997`, 
                494.}, {344.39799999999997`, 516.398}}, {{333.199, 516.398}, {
                333.199, 494.}}, {{254.80100000000002`, 494.}, {254.805, 
                494.}}},
               CurveClosed->{0, 0, 0, 0, 0, 0}]}, 
             {RGBColor[1., 1., 1.], Thickness[0.005312127152597305], Opacity[
              1.], CapForm["Round"], JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}}}, {{{
               243.60139999999998`, 481.602}, {288.39859999999993`, 
               481.602}}, {{299.6014, 481.602}, {344.39859999999993`, 
               481.602}}},
               CurveClosed->{0, 0}]}, 
             {RGBColor[1., 1., 1.], Thickness[0.0044444444444444444`], 
              Opacity[1.], CapForm["Round"], JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {
                0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1,
                 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 
                0}}, {{0, 2, 0}}}, {{{243.602, 226.}, {310.801, 226.}}, {{
                243.602, 203.60199999999998`}, {243.602, 214.801}, {266., 
                214.801}, {266., 203.60199999999998`}, {288.39799999999997`, 
                203.60199999999998`}, {288.39799999999997`, 214.801}, {
                277.199, 214.801}}, {{310.801, 203.60199999999998`}, {
                299.60200000000003`, 203.60199999999998`}, {
                299.60200000000003`, 214.801}, {322., 214.801}, {322., 
                226.}}, {{322., 214.801}, {322., 203.60199999999998`}, {
                344.39799999999997`, 203.60199999999998`}, {
                344.39799999999997`, 226.}}, {{333.199, 226.}, {333.199, 
                203.60199999999998`}}, {{254.80100000000002`, 
                203.60199999999998`}, {254.805, 203.60199999999998`}}},
               CurveClosed->{0, 0, 0, 0, 0, 0}]}, 
             {RGBColor[1., 1., 1.], Thickness[0.005312127152597305], Opacity[
              1.], CapForm["Round"], JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}}}, {{{
               243.60139999999998`, 238.39799999999997`}, {
               288.39859999999993`, 238.39799999999997`}}, {{299.6014, 
               238.39799999999997`}, {344.39859999999993`, 
               238.39799999999997`}}},
               CurveClosed->{0, 0}]}, 
             {RGBColor[1., 1., 1.], Thickness[0.0044444444444444444`], 
              Opacity[1.], CapForm["Round"], JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {
                0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1,
                 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 
                0}}, {{0, 2, 0}}}, {{{19.602, 516.398}, {86.801, 516.398}}, {{
                19.602, 494.}, {19.602, 505.19899999999996`}, {42., 
                505.19899999999996`}, {42., 494.}, {64.398, 494.}, {64.398, 
                505.19899999999996`}, {53.199000000000005`, 
                505.19899999999996`}}, {{86.801, 494.}, {75.60199999999999, 
                494.}, {75.60199999999999, 505.19899999999996`}, {98., 
                505.19899999999996`}, {98., 516.398}}, {{98., 
                505.19899999999996`}, {98., 494.}, {120.398, 494.}, {120.398, 
                516.398}}, {{109.199, 516.398}, {109.199, 494.}}, {{
                30.801000000000002`, 494.}, {30.805, 494.}}},
               CurveClosed->{0, 0, 0, 0, 0, 0}]}, 
             {RGBColor[1., 1., 1.], Thickness[0.005312127152597305], Opacity[
              1.], CapForm["Round"], JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}}}, {{{
               19.601399999999998`, 481.602}, {64.3986, 481.602}}, {{75.6014, 
               481.602}, {120.3986, 481.602}}},
               CurveClosed->{0, 0}]}, 
             {RGBColor[1., 1., 1.], Thickness[0.0044444444444444444`], 
              Opacity[1.], CapForm["Round"], JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {
                0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1,
                 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 
                0}}, {{0, 2, 0}}}, {{{19.602, 226.}, {86.801, 226.}}, {{
                19.602, 203.60199999999998`}, {19.602, 214.801}, {42., 
                214.801}, {42., 203.60199999999998`}, {64.398, 
                203.60199999999998`}, {64.398, 214.801}, {53.199000000000005`,
                 214.801}}, {{86.801, 203.60199999999998`}, {
                75.60199999999999, 203.60199999999998`}, {75.60199999999999, 
                214.801}, {98., 214.801}, {98., 226.}}, {{98., 214.801}, {98.,
                 203.60199999999998`}, {120.398, 203.60199999999998`}, {
                120.398, 226.}}, {{109.199, 226.}, {109.199, 
                203.60199999999998`}}, {{30.801000000000002`, 
                203.60199999999998`}, {30.805, 203.60199999999998`}}},
               CurveClosed->{0, 0, 0, 0, 0, 0}]}, 
             {RGBColor[1., 1., 1.], Thickness[0.005312127152597305], Opacity[
              1.], CapForm["Round"], JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}}}, {{{
               19.601399999999998`, 238.39799999999997`}, {64.3986, 
               238.39799999999997`}}, {{75.6014, 238.39799999999997`}, {
               120.3986, 238.39799999999997`}}},
               CurveClosed->{0, 0}]}, 
             {RGBColor[1., 1., 1.], Thickness[0.0044444444444444444`], 
              Opacity[1.], CapForm["Round"], JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {
                0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1,
                 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 
                0}}, {{0, 2, 0}}}, {{{131.602, 516.398}, {198.80100000000002`,
                 516.398}}, {{131.602, 494.}, {131.602, 
                505.19899999999996`}, {154., 505.19899999999996`}, {154., 
                494.}, {176.39800000000002`, 494.}, {176.39800000000002`, 
                505.19899999999996`}, {165.19899999999998`, 
                505.19899999999996`}}, {{198.80100000000002`, 494.}, {187.602,
                 494.}, {187.602, 505.19899999999996`}, {210., 
                505.19899999999996`}, {210., 516.398}}, {{210., 
                505.19899999999996`}, {210., 494.}, {232.39800000000002`, 
                494.}, {232.39800000000002`, 516.398}}, {{221.19899999999998`,
                 516.398}, {221.19899999999998`, 494.}}, {{
                142.80100000000002`, 494.}, {142.805, 494.}}},
               CurveClosed->{0, 0, 0, 0, 0, 0}]}, 
             {RGBColor[1., 1., 1.], Thickness[0.005312127152597305], Opacity[
              1.], CapForm["Round"], JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}}}, {{{131.6014, 
               481.602}, {176.39860000000002`, 481.602}}, {{
               187.60139999999998`, 481.602}, {232.39859999999993`, 481.602}}},
               CurveClosed->{0, 0}]}, 
             {RGBColor[1., 1., 1.], Thickness[0.0044444444444444444`], 
              Opacity[1.], CapForm["Round"], JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {
                0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1,
                 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 
                0}}, {{0, 2, 0}}}, {{{131.602, 226.}, {198.80100000000002`, 
                226.}}, {{131.602, 203.60199999999998`}, {131.602, 214.801}, {
                154., 214.801}, {154., 203.60199999999998`}, {
                176.39800000000002`, 203.60199999999998`}, {
                176.39800000000002`, 214.801}, {165.19899999999998`, 
                214.801}}, {{198.80100000000002`, 203.60199999999998`}, {
                187.602, 203.60199999999998`}, {187.602, 214.801}, {210., 
                214.801}, {210., 226.}}, {{210., 214.801}, {210., 
                203.60199999999998`}, {232.39800000000002`, 
                203.60199999999998`}, {232.39800000000002`, 226.}}, {{
                221.19899999999998`, 226.}, {221.19899999999998`, 
                203.60199999999998`}}, {{142.80100000000002`, 
                203.60199999999998`}, {142.805, 203.60199999999998`}}},
               CurveClosed->{0, 0, 0, 0, 0, 0}]}, 
             {RGBColor[1., 1., 1.], Thickness[0.005312127152597305], Opacity[
              1.], CapForm["Round"], JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}}}, {{{131.6014, 
               238.39799999999997`}, {176.39860000000002`, 
               238.39799999999997`}}, {{187.60139999999998`, 
               238.39799999999997`}, {232.39859999999993`, 
               238.39799999999997`}}},
               CurveClosed->{0, 0}]}, 
             {FaceForm[{RGBColor[0.854902, 0., 0.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{666.664, 
               424.33599999999996`}, {666.664, 424.33599999999996`}, {
               731.7850000000001, 373.40999999999997`}, {683.918, 
               300.22299999999996`}, {729., 327.77299999999997`}, {732.895, 
               403.53499999999997`}, {666.664, 424.33599999999996`}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}}}, {{{630., 431.57}, {619.637, 419.883}, {601.824, 
               431.504}, {607.9449999999999, 444.234}, {618.66, 
               425.03099999999995`}, {630., 440.547}, {630., 440.547}, {630., 
               440.547}, {641.3399999999999, 425.03099999999995`}, {652.055, 
               444.234}, {658.1800000000001, 431.504}, {640.3669999999998, 
               419.883}, {630., 431.57}}}], 
              FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
               3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 
               3, 3}, {1, 3, 3}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJtIGZigIINzQ6trwN3yPEXOmz7/PdKRUmzQ+7z3ys/
rsLkv19+zNv8RZODHdf1xQW+hQ5HFDYUZeg3ORz6qhHTf67QocMx4emFYwg+
WF662QFsD0sRRNyq2aF833wpfWVMvhzIIY8bHabnCTUfmFLs4GPe6ZjwqtEh
Y+LbGvvWMgdbkL3/Gh22nCjbN7+u0qHypZohx8kmh6sVQEZaFUG+N8i8hEYI
7V3m8AHknyKo/+8WOSwuANoQ1ewAcvZE6XI43wpkoWWVwzTn7pznFc0Q8zyq
HGDhN1mCJYzvOGF+1p6SyRLPEfpj+oEhwNoCNx/Gh9kvGGG55cRbhPvA/v7f
Cnd/u9jNc9+ntTgcAwkA/UeIfxgU3omtkPAFhp/Nff/e6aWtDlEp1vf9geH7
sEpknXtNq0MnKB6B4X8U5BDVFkj4A+MHnQ82z6XF4dMl3yQBYPyC43FmC8Sd
wPgHyxu0wvlg/5S3OBjcVWFrBKYfTx4m7fbXzQ5xu4Cs1Zh8sPvXQ9MHMH0C
AGVtMXs=
               "]], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{593.3399999999999, 
               424.33599999999996`}, {593.3399999999999, 
               424.33599999999996`}, {528.219, 373.40999999999997`}, {576.086,
                300.22299999999996`}, {531., 327.77299999999997`}, {527.102, 
               403.53499999999997`}, {593.3399999999999, 
               424.33599999999996`}}}]}},
            AspectRatio->Automatic,
            ImageSize->{{128}, {85}},
            PlotRange->{{0., 1260.}, {0., 720.}}], ",", 
           GraphicsBox[
            {Thickness[0.001388888888888889], 
             {FaceForm[{RGBColor[
              0.8078430000000001, 0.06666670000000002, 0.14902], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               0., 480.}, {720., 480.}, {720., 320.}, {0., 320.}}}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0., 
               320.}, {720., 320.}, {720., 160.}, {0., 160.}}}]}, 
             {Thickness[0.001388888888888889], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0., 
               160.}, {720., 160.}, {720., 0.}, {0., 0.}}}]}, 
             {FaceForm[{RGBColor[0., 0.478431, 0.23921600000000004`], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                0}, {0, 1, 0}, {0, 1, 0}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {
                1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1,
                 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 
                0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0,
                 1, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 
                3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0,
                 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 
                0}, {0, 1, 0}, {0, 1, 0}}}, {{{218.918, 180.562}, {214.781, 
                185.102}, {223.13299999999998`, 194.102}, {
                227.26999999999998`, 189.562}, {231.406, 185.02}, {223.055, 
                176.02}, {218.92200000000003`, 180.57}}, CompressedData["
1:eJxlVQ1olVUYvpqOMce1plmm2UxbUsawJWEiveXC9pOmwzVMxIbd7+d8937n
O99Wq9lIRpmV3o2MnCZOLxs1NYeVmKitFWUqNoRh+7mpSNiQFhplIkHnnOd0
L9SFy8fznfe873Oe5z3vN7PWX/Hi2Egk0ij/6tl19ewztX0WFeVseH/xUIyG
bjS5R9stun9e7r7pozESduuv66ss2vJBoqB5rkVf7rqrOF1oEV+Udy5lW1Tx
6KYn1n4VownnUnzRoEXV0YcO7twbo/tUvok2PfbZiZeOX4lR6Tve5ZsjFrX0
/jFndYVFeSr+oEWDql6ujXpbLPpOJay0qe9eyaTT1Ct1wCtiU6Wq95pDf85Z
nex1HHp18idLLh6yaZuk17PUpbtXrVt4PmmDR6NLEfXjNt4fyGId35vFOl+/
i/O02fTGleWHZ9ww66dtvL+NUaOqV+BAlxJGxenZORvmO9CjxqzXOjj/pwz8
Wwye6NECpUfK4FkeDZy5XnXpi+y6zjfggN81Rpc6dnxTWOoiLu1msPbtoyzW
z3dd7HNdOlb33p3j3nRJ0Xx8KstgrftoFu956tDvf59mNKz0HTb7jzD4nc8o
UOf60KxXMvj0NqNQJWaGn8fgy04GvTwT18ng71sm31FGZ5Wv2xn65aTRr59R
UvXFdQafJnjwu9AD3yc9xJd74Ftn3jd54Lfeo80q/1YPvJIe/D/lgdf4OOq6
cfT5tCzW/sz+D54bB4+vvQzWffkXy+B/9Ts8Q3bKifB/WOvYlUDfpEKcfzhB
0o35a5pCPKM++qUmhI59Jr4kxH1pzWLNZ4fpr3FBBuu+SfkZrOvsi8OH9izW
/dyRxbov9jPo9qNPk5p7Tu5OJ6i/YaRoXpTDlwU+4m7n0LnSJxXeU2Tw6z78
eIQj/34Tv5jjPg349ODGKQNnlnN6+qK8qWM41ldycw5O8nQ/99Vwuibb+dZc
Ti8flwJbZn06x/nrTf4Sw6uZkyrPy8y+rRxz5gWDt5s8Doeu7ZzU8i5u6kn9
dN5bjI6vBKQeyw4EmCejAXg+L7B/haBv1YZfBJ1fJhWrFtQpX3dLrH1eJUi6
Xx0dEci/VtCaI2X5Y4cEfFgnqLBbTozvBc1Uz3qz3zZxzYIuqLwPC4pfvvnx
1RYBvpNN3B6BeSh56f7aZvhcMLwdQYpm908BeFQJUu3/WzrAvLlHQLe2ALoV
B1Sg/F5odGzluBd7E6SuYVL6/7mq/0AcPPI5+qQwjvd5HP07JY56bRz3PWr6
rCzIYO3DJpHBWneJtc45CdSX+DlFOJlAvs2CRlX+PB/naxWYt3f42N8hUGel
6b+GEHEVHOfdGCLPEm70DOFbKTc+hOj3qRx+jK9DH/zg43yizsyJLNbrkxzU
rXczWPv7rIu4JhtzbJaLfjxlYa4MOlgvN9/NBvP9GmO+l9MczPdjMcSX24jv
ihleFuaa/D7/A9PgVSI=
                "], CompressedData["
1:eJxTTMoPSmViYGCQB2IQrbChKGPi8xIHoeYDpxYezXWA8atE1rk/bCtwmCzB
Esb3usThbY29aZxdIYT/ucRBq13s5jnnQgdbruuLC36WODxeOvuIgkehQ+7z
3ys/ipRC+EaFDse8zTsdDUod4nZ58jAJF0LM9y51kI1Ksb7/ucDhasVLNcMa
KP9ggcN9/97peXNKHfh0N819v7jAIWMi0ObzpQ5bTpTtm19S4HDoq0ZM/xWo
+uwCh2qQO4+UOujfVWFrTCxwuKB0+2fdhFKHHJA77AoctEHunFgKoT0R/EWu
2z7/LcmF88Hmt2VBwuE7gv/pkm+SQFAZnD8jD6giqczBB+ithN4siHt6yiDi
h7Ig9h8oc9g/X0r/Lks2xB+HyyDh8SfL4TgoPFZB+RVZEHMXlEHC2y0L4q+p
ZRB/P82EqJ9U5qDK1jjVeX6mgyVIQ3eZAwMIKGQ6CIPcu7MUQktmwuOvH+Qw
YQQfHH/Hch0AiJroxA==
                "]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1,
                 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0,
                 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {1, 3, 
                3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{1, 4, 3}, {1, 3, 3}, {
                1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {0,
                 1, 0}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 
                0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}}}, {CompressedData["
1:eJxlUltIFGEUXiQ2iDCpzSTMVrsQUW0iS1lsHukhTGGxy4bW6hJGtc7O/DNF
NZc1TCyFIsJiBdFNwqCHZDMDidzEwi6QuA9hEmUiIV0WKaiQemjOnHHmwYfh
55v//Od83/m+/OPCgRMZDocD9A/P4v6X55JFMgQyt/Z1loehum73pL9YhsGz
bTmLuuqhfEdraahMhvdzDeEnWRx88l+L8Zdk+L3p2PXhKAdprcRb0yvDiqah
190pDs4n46s9aZnezXGAbWe9CpSGPo8VzHIwie85BaRTN9LaDAf7phRXr6DA
xOifg9NiBDZfyZ4YPaMAXpfk8zD8Sx+k169BYrU87EK+lQqkCnRGEg/uhN6p
UAHmWzJ+p4WH6Z6O5+6dCs1P8dD8rXIgr1YB/Zb5nAK8vfBlY6GkwAsscAsQ
mfl778dtc74sAId4RCE9b8z77wq088ubhrIY8VumQs3jsqUZRYz0u2xs1OfY
GOkkclXSu0qw8CNdRrwhYuENzsZbe2Nh4te3EBu6bkYsPJCnK8tmaKPDkVBp
7n5GurtVaMWFVzOqbzdxHaM+V1XQ3Q1kRkx+l20cQ528jQ1/Lqq05w4Gng/r
nY1xlXx+wOAZ+jPPL8no3ZQKd7HvVwYtONepwQgSc4kwhr5t0chPn0h8/Rr1
C4pUd0ij3FSJ1K9KI54BEwc1MHJbzyx8BB/EeQvP78/g93MhNvpxIuQij3Fz
XrNIPF5p5HObiQc12I66e2xs5PO+jY3994uUh48a5fydCEHMweIo7eefSHv0
RKn/WonyeTRK/lRI9P+kWR+SyOeuKGC82UMJ9uDZGSXeT21s9FkpWPgwClp3
mva/TbawkWuvTLmpCMN/ybjHEQ==
                "], {{423.09799999999996`, 
                217.445}, {423.09799999999996`, 222.164}, {
                420.47999999999996`, 222.164}, {416.965, 222.164}, {413.754, 
                218.848}, {413.754, 215.21099999999998`}, {413.754, 
                212.727}, {423.09799999999996`, 212.727}, {
                423.09799999999996`, 217.441}}, CompressedData["
1:eJxTTMoPSmViYGBQBGIQHbfLk4dJuM7hm0ZM/6GbuQ4w/kWl2z/rJhU4XADR
YnUOM/KEmg94FToc+gpUKFfncLXipZphQKFD7vPfKz+q1EHUhRQ6bDlRtm++
Q53Dff/e6Xl2hQ4MIBBT51C+b76Uvnyhg7d5p2NCeZ0Dr+6mue//F0DMWVHn
YAXSeBZq34k6B/eHVSLr1hc4KGwoypj4G2pfQ4FDtcg694cM9Q62XNcXF5QX
OLS+Dtwh97HOYZHrts9/cwog7ttT53AcZJFXgYNsVIr1/b11EHWhCH4ByICO
XDhfla1xqvP0LIg9avVwPtC1Ty+0IPhgcyfVO+wHeufunCyIv7bXOwBd+bbm
cpaDIsi9Z+sdgL4Xav6SBQnHR/UON899D37MmQ3x59N6iD+YsiHh96Ie4o7f
WRB3Pq6HhNPJLIi6G/XQ+MiC+O9cvUMYHzAAo6HqD9c7+IDUf8100L+rwta4
v94B5Gyl9ZkQ9++Aul8/E2KfEDQ+lRB8dUOONTK3ch0AX6j2uw==
                
                "], CompressedData["
1:eJxTTMoPSmViYGBQBGIQ/Xjp7CMKp6ocqkXWuT9MKXSISrG+77+9yuFtjb1p
XE6hg3DzgVMLF1Y5eDysEllXWejw6ZJvksCsKod3IPmmQof7/r3T8/qqHNxB
8v2FDse8zTsdp1Q5LHLd9vnvBKj8viqHByC6qxCij6vaAWTthrpCh9znv1d+
tIDyewodMiYCbU6udgC7aw9Uf0e1g3a72M1zTwsdrla8VDPcA+VfLHRYBtJ3
o9qhCuT+Y4UQd3+rdjj0VSOm/0Chww651teB/6odZEEeO1wI8adQjcMFpds/
685A/WNRA1HPUwRRb1IDcb9CkYMWyB79Goh+yyKHTseEpxdcaiD6zIog7gis
gfhfugji/uwaB17dTXPfPy90YACBsBpIuCyDhq9qjcNxEH9SoYMd1/XFBbw1
UH8i3A/2J5BvueVE2b7z1Q5AV+2Qmwj1z4JqiHlzCiHunlHtMFmCJYxvNlR9
M9S/rdDwDK2GmBsG1c9XDYlPT2h4AuN/ep5Q8wFg/AMAyiz3BA==
                "], {{
                436.72299999999996`, 290.289}, {435.117, 291.484}, {
                431.72299999999996`, 297.59799999999996`}, {431.594, 
                299.543}, {431.47999999999996`, 301.21099999999996`}, {
                431.754, 301.72299999999996`}, {432.84400000000005`, 
                301.895}, {434.754, 302.191}, {435.633, 300.809}, {
                437.10200000000003`, 295.22299999999996`}, {438.305, 
                290.64500000000004`}, {438.18, 289.199}, {436.727, 
                290.289}}}]}},
            AspectRatio->Automatic,
            ImageSize->{{128}, {85}},
            PlotRange->{{0., 720.}, {0., 480.}}], ",", 
           GraphicsBox[
            {Thickness[0.001388888888888889], 
             {Thickness[0.001388888888888889], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0., 
               0.}, {0., 480.}, {720., 480.}, {720., 0.}}}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0., 
               480.}, {720., 480.}, {720., 160.}, {0., 160.}}}]}, 
             {FaceForm[{RGBColor[
              0.8078430000000001, 0.06666670000000002, 0.14902], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               0., 480.}, {720., 480.}, {720., 320.}, {0., 320.}}}]}, 
             {FaceForm[{RGBColor[0., 0.478431, 0.23921600000000004`], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{216., 
               292.}, {199.93, 242.547}, {230.363, 232.656}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{216., 292.}, {
               232.07, 242.547}, {201.637, 232.656}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{265.453, 256.07}, {
               213.453, 256.07}, {213.453, 224.07}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{265.453, 256.07}, {
               223.38700000000003`, 225.504}, {204.578, 251.395}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{166.547, 256.07}, {
               208.61299999999997`, 225.504}, {227.42200000000003`, 
               251.395}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{166.547, 256.07}, {
               218.547, 256.07}, {218.547, 224.07}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{246.566, 197.93}, {
               230.496, 247.38700000000003`}, {200.062, 237.496}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{246.566, 197.93}, {
               204.496, 228.496}, {223.305, 254.383}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{185.434, 197.93}, {
               227.504, 228.496}, {208.695, 254.383}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{185.434, 197.93}, {
               201.504, 247.38700000000003`}, {231.93800000000002`, 
               237.496}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{504., 292.}, {
               487.92999999999995`, 242.547}, {518.3629999999999, 232.656}}}],
               FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{504., 292.}, {
               520.07, 242.547}, {489.637, 232.656}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{553.453, 256.07}, {
               501.453, 256.07}, {501.453, 224.07}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{553.453, 256.07}, {
               511.387, 225.504}, {492.578, 251.395}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{454.547, 256.07}, {
               496.613, 225.504}, {515.4219999999999, 251.395}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{454.547, 256.07}, {
               506.547, 256.07}, {506.547, 224.07}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{534.5659999999999, 
               197.93}, {518.496, 247.38700000000003`}, {488.062, 237.496}}}],
               FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{534.5659999999999, 
               197.93}, {492.4959999999999, 228.496}, {511.305, 254.383}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{473.43399999999997`,
                197.93}, {515.504, 228.496}, {496.695, 254.383}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{473.43399999999997`,
                197.93}, {489.504, 247.38700000000003`}, {519.938, 
               237.496}}}]}},
            AspectRatio->Automatic,
            ImageSize->{{128}, {85}},
            PlotRange->{{0., 720.}, {0., 480.}}], ",", 
           GraphicsBox[
            {Thickness[0.0010416666666666667`], 
             {FaceForm[{RGBColor[0., 0.4, 0.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0., 
               0.}, {0., 480.}, {960., 480.}, {960., 0.}}}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0., 
               480.}, {960., 480.}, {960., 137.14499999999998`}, {0., 
               137.14499999999998`}}}]}, 
             {FaceForm[{RGBColor[0.8, 0., 0.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0., 
               480.}, {960., 480.}, {960., 342.855}, {0., 342.855}}}]}, 
             {FaceForm[{RGBColor[0.972549, 0.764706, 0.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {0,
                1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
               3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIZIGYC4k7HhKcXztQ4PF46+4jCmTyHi0q3f9a9qnHg
ur64wNYo38Fyy4myfdq1Dq2vA3fIZeY7LHLd9vlvSi1EvU++wzFv807HebUO
IGOU9PMdtgKVzz9V61BoCzThQJ7Dff/e6XlnaiHiXgi+/l0VtkbGLAeFDUUZ
E43rMPgw9SDjE0zr4OZZgdyTWAe3L26XJw/T7DpU91ypg7vXAGSuaD3cP+X7
5kvpG9fD/RuVYn3fP7je4ZtGTP+h3nyIuFO9A4jaYFYAcS9bPcQdnQUOy0Di
p+ocPl3yTRK4U+DAAAJpdRB38xdC+Axo/Fm1cD7YPtNauH6w+M8auPmyIAV7
a+D2g+k1NXD3occXAG2yx5Q=
               "]]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4h1yra8DxWod3tXYm8a9ynfIff575UenWodC
W67ri//kOzzw752eV1TrAOQV2H7Kd2AAgTm1DvvnS+nfPZPvINx84NTCo7UO
YXy6m+Yuz3cAmrZD7mWtg+WWE2X70qHqGeoc9oHUS+Q7VImsc38oVgeXB9tr
VQfXD1aeUgc3X3FDUcbE3jq4/ZMlWML49tbB3efxEGjiyzq4+8H6H9VB1OkW
QPQfrXPQbhe7eS6xACI+uw7ijrYCh0NfNWL6C+ocQNa/X13g8BZkjkWdwyLX
bZ//HiiAux/GFwL593gtnA9yRkF/LVw/OPxSauHmg8PPqhZuP9g4uVq4+9DD
HwAHcqwN
               "]]}, 
             {FaceForm[{RGBColor[0.972549, 0.764706, 0.], Opacity[1.]}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4vv+vdPzztQ6WG45UbZve7aDwV0VtsajtQ6t
rwN3yMlmO4DlV9Q6gKTnt2U5KGwoyphYWetQLbLO/SFXlsOy2UcUNnjVOjgm
PL2g1J/p8HgpUICr1uFtjb1pnF4mRP3BGoj89wyHRa7bPv+tqHGQjUqxvr8/
A6Jfo8aB6/riAttNGQ4XlG7/rLtT7XDc27zT8UKGww45oEsmVEPk32U4HPqq
EdPvUe0gA9JvnunAq7tp7nv+agd1Q441MosyHWxBCu9XOWwFuXddhsP0PKHm
AyVVDoUgiTfpDrG7PHmYvlc6xIHoxekO5fvmS+lXVjrog/wdme4wWYIljO91
hYNLd87z353pEH83VED8q5QB4a+ocAjlA1rMnOrg/rBKZN3/Kog9y1Ih7tWp
dmAAgQ1Q976odnAC+V86DRIubbUOqz5e8k26kQZx7/9ah5vnvgc/ZsxyAADR
07hx
               "]], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYCYoUNRRkTjescLLecKNu3PdvhotLtn3VWdQ6t
rwN3yMlmO4Dlw+scQNLz27Ic7vv3Ts9rq3OoFlnn/pAryyEqxfq+/9Y6B8eE
pxeU+jMdZEECX+sc3tbYm8bpZULU29VD5L9nOMTu8uRhaq+HqNufAdF/vd6B
6/riAttNGQ4z8oSaDwg2OBz3Nu90vJDhsKTAluu6eQNE/l2GgxzIYdENDjIg
jeaZDpUv1Qw5Khoc1A051sgsynR4WAV02IQGh60g967LgNBHGxwKgcYsfpPu
cAHkP5ZGhziQOxanOxwBedC50UH/rgpbY2S6w7bPf69UdDU6uHTnPP/dme6w
dDZQxf5GiH+VMiD81Y0OoXy6m+YypzrE9B/6qtHQ4DAd5O5lqRD3ZjY4MIDA
Bqh7uRscnED+l05zEG4+cGphZZ3Dqo+XfJNupDkAdcf0M9Q53Dz3PfgxY5YD
AAodtds=
               "]], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}}}, {{{451.777, 177.38700000000003`}, {446.551, 
               166.10899999999998`}, {436.10900000000004`, 164.172}, {426.977,
                173.277}, {426.977, 173.277}, {430.648, 175.871}, {434.578, 
               176.586}, {433.84400000000005`, 179.72299999999998`}, {435.355,
                184.062}, {437.484, 186.406}, {439.719, 184.883}, {
               442.83599999999996`, 181.82000000000002`}, {443.629, 
               178.266}, {449.133, 178.977}, {451.777, 177.38700000000003`}, {
               451.777, 177.38700000000003`}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}}}, {{{492.64500000000004`, 178.664}, {
               485.65200000000004`, 168.38700000000003`}, {
               475.03499999999997`, 168.176}, {467.508, 
               178.64499999999998`}, {467.508, 178.64499999999998`}, {471.551,
                180.605}, {475.547, 180.672}, {475.328, 
               183.88700000000003`}, {477.527, 187.92200000000003`}, {480.012,
                189.89100000000002`}, {481.965, 188.02}, {484.543, 184.496}, {
               484.746, 180.85500000000002`}, {490.29699999999997`, 
               180.664}, {492.64500000000004`, 178.664}, {492.64500000000004`,
                178.664}}}], 
              FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                3, 3}}}, {{{533.172, 173.26999999999998`}, {524.605, 
               164.26999999999998`}, {514.094, 165.789}, {508.371, 177.344}, {
               508.371, 177.344}, {512.6800000000001, 178.621}, {516.633, 
               178.035}, {516.9409999999999, 181.242}, {519.766, 
               184.86700000000002`}, {522.539, 186.40200000000002`}, {524.164,
                184.242}, {526.133, 180.344}, {525.738, 
               176.71899999999997`}, {531.1840000000001, 175.625}, {533.172, 
               173.26999999999998`}, {533.172, 173.26999999999998`}}}]}, 
             {RGBColor[0.972549, 0.764706, 0.], Thickness[0.011428571875], 
              Opacity[1.], CapForm["Butt"], JoinForm[{"Miter", 4.}], 
              JoinedCurveBox[{{{1, 4, 3}}}, {{{413.484, 
               152.23000000000002`}, {456.58599999999996`, 
               165.05900000000003`}, {503.414, 165.05900000000003`}, {546.516,
                152.23000000000002`}}},
               CurveClosed->{0}]}, 
             {FaceForm[{RGBColor[0.972549, 0.764706, 0.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}}}, {{{480., 332.57}, {490.078, 301.559}, {463.695, 
               320.727}, {496.305, 320.727}, {469.92199999999997`, 
               301.559}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}}}, {{{432., 319.71099999999996`}, {442.078, 288.699}, {
               415.695, 307.863}, {448.305, 307.863}, {421.92199999999997`, 
               288.699}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}}}, {{{396.863, 284.57}, {406.93799999999993`, 253.559}, {
               380.559, 272.727}, {413.16400000000004`, 272.727}, {
               386.78499999999997`, 253.559}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}}}, {{{384., 236.57}, {394.078, 205.559}, {367.695, 
               224.727}, {400.305, 224.727}, {373.92199999999997`, 
               205.559}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}}}, {{{528., 319.71099999999996`}, {517.9219999999999, 
               288.699}, {544.305, 307.863}, {511.695, 307.863}, {
               538.0780000000001, 288.699}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}}}, {{{563.137, 284.57}, {553.0619999999999, 253.559}, {
               579.4409999999999, 272.727}, {546.8359999999999, 272.727}, {
               573.215, 253.559}}}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
               0}}}, {{{576., 236.57}, {565.9219999999999, 205.559}, {592.305,
                224.727}, {559.695, 224.727}, {586.0780000000001, 
               205.559}}}]}},
            AspectRatio->Automatic,
            ImageSize->{{128}, {85}},
            PlotRange->{{0., 960.}, {0., 480.}}], ",", 
           GraphicsBox[
            {Thickness[0.0010416666666666667`], 
             {FaceForm[{RGBColor[0., 0.619608, 0.286275], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0., 
               480.}, {960., 480.}, {960., 320.}, {0., 320.}}}]}, 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0., 
               320.}, {960., 320.}, {960., 160.}, {0., 160.}}}]}, 
             {Thickness[0.0010416666666666667`], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0., 
               160.}, {960., 160.}, {960., 0.}, {0., 0.}}}]}, 
             {FaceForm[{RGBColor[
              0.8078430000000001, 0.06666670000000002, 0.14902], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               0., 480.}, {240., 480.}, {240., 0.}, {0., 0.}}}]}},
            AspectRatio->Automatic,
            ImageSize->{{128}, {85}},
            PlotRange->{{0., 960.}, {0., 480.}}], ",", 
           GraphicsBox[
            {Thickness[0.001388888888888889], 
             {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0., 
               0.}, {0., 480.}, {720., 480.}, {720., 0.}}}]}, 
             {FaceForm[{RGBColor[
              0.8078430000000001, 0.06666670000000002, 0.14902], Opacity[
              1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
               0., 480.}, {720., 480.}, {720., 320.}, {0., 320.}}}]}, 
             {Thickness[0.001388888888888889], 
              FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0., 
               160.}, {720., 160.}, {720., 0.}, {0., 0.}}}]}},
            AspectRatio->Automatic,
            ImageSize->{{128}, {85}},
            PlotRange->{{0., 720.}, {0., 480.}}]}], "}"}]}], "}"}]], 
       "ExerciseOutput",ExpressionUUID->
       "ad1fb3bf-4722-4f28-a2dd-d8db2f1cebec"],
      Apply[TextCell, 
       Cell[
        BoxData[
         RowBox[{"{", 
           RowBox[{
             RowBox[{"{", 
               RowBox[{
                 GraphicsBox[{{{{{{{
                    Thickness[0.0010416666666666667`], {{{{{{{
                    Thickness[0.0010416666666666667`], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {0., 480.}, {960., 480.}, {960., 
                    0.}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     320.}, {960., 320.}, {960., 160.}, {0., 
                    160.}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0., 0.478431, 0.23921600000000004`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     160.}, {960., 160.}, {960., 0.}, {0., 
                    0.}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.8078430000000001, 0.06666670000000002, 0.14902], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{480., 240.}, {
                    0., 0.}, {0., 480.}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    180.32800000000003`, 231.71099999999998`}, {159.875, 
                    229.80100000000002`}, {162.57, 209.36700000000002`}, {
                    148.32800000000003`, 224.22299999999998`}, {134.086, 
                    209.36700000000002`}, {136.781, 229.80100000000002`}, {
                    116.32799999999999`, 231.71099999999998`}, {133.93, 
                    242.33200000000002`}, {122.664, 259.57}, {
                    141.92200000000003`, 252.38700000000003`}, {
                    148.32800000000003`, 271.969}, {154.73399999999998`, 
                    252.38700000000003`}, {173.99200000000002`, 259.57}, {
                    162.727, 242.33200000000002`}}}]}}}}}}}}}}}}}}, 
                  AspectRatio -> Automatic, ImageSize -> {{128}, {85}}, 
                  PlotRange -> {{0., 960.}, {0., 480.}}], ",", 
                 GraphicsBox[{{{{{{{
                    Thickness[0.0020833333333333333`], {{{{{{{
                    FaceForm[{
                    RGBColor[0., 0.6, 0.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {0., 320.}, {480., 320.}, {480., 
                    0.}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0.74902, 0., 0.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     320.}, {320., 320.}, {320., 0.}, {0., 
                    0.}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0020833333333333333`], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     320.}, {160., 320.}, {160., 0.}, {0., 
                    0.}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}}}, {{{255.602, 139.32800000000003`}, {
                    262.28099999999995`, 139.32800000000003`}, {262.309, 
                    136.80100000000002`}, {263.789, 134.09}, {265.867, 
                    132.531}, {253.062, 132.531}, {255.066, 
                    134.35200000000003`}, {255.61299999999997`, 136.504}, {
                    255.602, 139.32800000000003`}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}}}, {{{255.602, 139.328}, {262.28099999999995`, 
                    139.328}, {262.309, 136.80100000000002`}, {263.789, 
                    134.09}, {265.867, 132.531}, {253.062, 132.531}, {255.066,
                     134.352}, {255.61299999999997`, 136.504}, {255.602, 
                    139.328}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    213.36700000000002`, 177.176}, {217.02700000000002`, 
                    173.14499999999998`}, {262.574, 173.07}, {266.309, 
                    177.102}, {254.66, 177.25}, {248.984, 181.207}, {230.691, 
                    181.281}, {225.39100000000002`, 177.176}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIpIGYC4t7peULNDLkON899D368M83BcsuJsn3f8xze
1dibxu1Kc2AAAZt8h7cg/r00h4yJQFZgvoP+XRW2xsB0h/3zpfTvBuRD9E9M
d5CNSrG+758P0ReQ4VAtss794ak8BzW2xqnOqzMcfMw7HRNc8yDyGzIcvEF8
wzyHRa7bPv8F8rmvLy6wlcpzKLTlur74QAbEfJE8iDmXMiDuY89zeLx09hGF
PxkOTglPLyhx5zlcULr9s04s0+HOz7qsPX9yIeaJZELs+ZDr0Po6cIecaCZE
/+dciLlA/cdBDniR68AFsvdahoNLd87z3w9zIfYdynBY/fGSb9KZXLh7QcF1
YBtUfl0GxJ0CuRD7l2VAwmVpDiScdDMchJsPnFq4Msfhm0ZM/yFg+PSBDFiT
4xC3y5OHSTvdYRXI/B05EHVv0xzQ4wMAqua5vQ==
                    
                    "]]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIpIGYC4t7peULNDLkON899D368M83BcsuJsn3f8xze
1dibxu1Kc2AAAZt8h7cg/r00h4yJQFZgvoP+XRW2xsB0h/3zpfTvBuRD9E9M
d5CNSrG+758P0ReQ4VAtss794ak8B1W2xqnOqzMcfMw7HRNc8yDyGzIcvEF8
wzyHRa7bPv8F8rmvLy6wlcpzKLDlur74QAbEfJE8hyqQOZcyIO5jz3N4snT2
EYU/GQ5OCU8vKHHnOVxQuv2zTizT4c7Puqw9f3Ih5olkQuz5kOvQ+jpwh5xo
JkT/51yHfSBzgfqPgxzwIteBC2TvtQwHl+6c578f5kLsO5ThsPrjJd+kM7lw
94KC68C2XIi/1mU4FILcKZALsX9ZBiRcluZAwkk3w0G4+cCphStzHL5pxPQf
AoZPH8iANTkOcbs8eZi00x1WgczfkQNR9zbNAT0+AKdmubk=
                    "], 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    206.129, 125.73400000000001`}, {273.703, 
                    125.73400000000001`}, {267.656, 130.664}, {212.176, 
                    130.664}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1,
                     0}, {0, 1, 0}}, {{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 
                    0}, {0, 1, 0}}}, {{{237.11299999999997`, 
                    144.24599999999998`}, {238.344, 140.55100000000002`}, {
                    241.14499999999998`, 140.55100000000002`}, {
                    238.90200000000002`, 144.25}, {237.11299999999997`, 
                    144.25}}, {{235.54299999999998`, 140.55100000000002`}, {
                    236.254, 136.895}, {239.539, 136.85500000000002`}, {
                    238.344, 140.555}}, {{241.105, 140.516}, {243.383, 
                    136.895}, {248.05100000000002`, 136.895}, {
                    244.39100000000002`, 140.555}}, CompressedData["
1:eJxTTMoPSmViYGAwB2IQ/U0jpv/QxiwHVbbGqc7tCQ6LXLd9/suQ7bB/vpT+
3QsJDkUZE9/WGGc7yEalWN/nT3RgAAGTbAfu64sLbLMSHfTvqrA1fkXwb577
HvwYyA/j09001zzR4bi3eacjR44DiEqQTHR4vHT2EQWVHIcJh75qxEhDzXuR
41Boy3V9sUyiQ5XIOveHz3IceqfnCTVPSHQoAIlH4OBzpEDcF5zjIANy3/MU
iH0ZuQ7qhhxrZLJSIfbezHXYB/JPRqrDrZ91WXsssuHyMP7bGnvTuLpUB6Hm
A6cWxhfA+VcrXqoZJhTA1XOB/CmWBzcP7O4HeRD3APmhIH8vzoeE44oUB5Dz
7JfmQ8KXHcEHh0NIskPcLk8epm4EHxwfnfmQ8GdJgfPB9NYUB6eEpxeUVudB
9EWnOqz6eMk36UcuRD40FRL+sbkQfwemQtydl+Owt2SyBMu+FIg7C6B8NgTf
EWTu+WSIO+/nOtwBhcuZZAerLSfK9t3OdfABmdebDHG/aB4kHjKSIe7uyIPE
o0uywwWl2z/r2vIcWl8H7pB7mgQJ3xt5EP+cSYKkl5t5EPvzkiD6bfIh4eaM
4IPd/zDRYQbQeQeq8h2qQeliVyIknsvzIe4NT4S6Mx81PbEg+GBzGvMdwkHm
9ydA0seJPFR+Th5cPTjeP+Wi6teEun9CAsTe5bkOLt05z39PTIDY14FQD/b3
S0T6fgcy71UOPH8BANfndxw=
                    "], {{231.289, 
                    144.21099999999998`}, {231.289, 140.555}, {235.547, 
                    140.555}, {234.684, 144.21099999999998`}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1,
                     0}, {0, 1, 0}}, {{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 
                    0}, {0, 1, 0}}}, {{{237.11299999999997`, 144.246}, {
                    238.344, 140.55100000000002`}, {241.14499999999998`, 
                    140.55100000000002`}, {238.90200000000002`, 144.25}, {
                    237.11299999999997`, 144.25}}, {{235.54299999999998`, 
                    140.55100000000002`}, {236.254, 136.895}, {239.539, 
                    136.85500000000002`}, {238.344, 140.555}}, {{241.105, 
                    140.516}, {243.383, 136.895}, {248.05100000000002`, 
                    136.895}, {244.39100000000002`, 140.555}}, CompressedData["
1:eJxTTMoPSmViYGAwB2IQ/U0jpv/QxiwHNbbGqc7tCQ6LXLd9/suQ7bB/vpT+
3QsJDkUZE9/WGGc7yEalWN/nT3RgAAGTbAeu64sLbLMSHfTvqrA1fkXwb577
HvwYyA/j09001zzR4bi3eacjR46DD5BKkEx0eLx09hEFlRyHCYe+asRIQ817
keNQaAs0QSbRoUpknfvDZzkOvdPzhJonJDoUgMQjMPl9ID5HCsR9wTkQ9z1P
gdiXkeugbsixRiYr1QHETbiZC/FPRqrDrZ91WXsssuHyMP7bGnvTuLpUB6Hm
A6cWxhfA+VcrXqoZJhTA1YP9KZYHNw/s7gd5EPcA+aEgfy/Od1gMCscVKQ4g
59kvzYeELzuCDw6HkGSHuF2ePEzdCD44PjrzHfaBzGdJgfO/guitKQ5OCU8v
KK3Og+iLTnVY9fGSb9KPXIh8aCok/GNzIf4OTIW4Oy/HYU/JZAmWfSmQcCyA
8tkQfEeQueeTHVRB7ryf63AbFC5nkh2stpwo23cbal5vMsT9onkQf2ckQ9zd
kQeJR5dkhwtKQJ1teQ6trwN3yD1NgoTvjTyIf84kQdLLzTyI/XlJEP02+ZBw
c0bwwfY9THSYAXTegap8h2pQutiV6CADiufyfEg4hCc63AG7Mx81PbEg+GBz
GvMh6bE/AZI+TuSh8nPy4OrB8f4pF1W/JjS+JyRAwml5roNzd87z3xMTIPZ1
INSD/f0Skb7fgcx7lQPPXwDcN3ca
                    "], {{231.289, 144.211}, {
                    231.289, 140.555}, {235.547, 140.555}, {234.684, 
                    144.211}}}, CurveClosed -> {1, 1, 1, 1, 1}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    231.512, 150.67199999999997`}, {234.164, 
                    150.67199999999997`}, {234.164, 144.58599999999996`}, {
                    231.512, 144.58599999999996`}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    227.76999999999998`, 144.16}, {230.35500000000002`, 
                    144.16}, {230.34, 148.637}, {230.305, 150.582}, {
                    232.05100000000002`, 152.547}, {232.89100000000002`, 
                    152.60899999999998`}, {233.816, 152.64499999999998`}, {
                    235.184, 150.773}, {235.227, 148.78900000000002`}, {
                    235.266, 144.14499999999998`}, {238.012, 144.152}, {
                    238.012, 155.67999999999998`}, {227.76999999999998`, 
                    155.625}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    248.238, 141.488}, {251.449, 141.488}, {251.449, 
                    138.988}, {248.238, 138.988}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    246.336, 145.78500000000003`}, {249.54700000000003`, 
                    145.78500000000003`}, {249.54700000000003`, 
                    143.28100000000003`}, {246.336, 143.28100000000003`}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    243.238, 150.07799999999997`}, {246.449, 
                    150.07799999999997`}, {246.449, 147.57799999999997`}, {
                    243.238, 147.57799999999997`}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    240.594, 153.695}, {243.805, 153.695}, {243.805, 
                    151.195}, {240.594, 151.195}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}}}, {{{238.465, 144.14499999999998`}, {
                    241.75, 144.031}, {247.60899999999998`, 138.844}, {
                    247.60899999999998`, 141.902}, {245.63299999999998`, 
                    143.32}, {245.63299999999998`, 145.75}, {242.758, 
                    147.39100000000002`}, {242.758, 150.004}, {
                    239.95700000000002`, 150.938}, {239.95700000000002`, 
                    154.484}, {238.539, 155.64499999999998`}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    252.344, 151.71899999999997`}, {253.129, 
                    151.71899999999997`}, {253.129, 146.08199999999997`}, {
                    252.344, 146.08199999999997`}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    252.344, 151.719}, {253.129, 151.719}, {253.129, 
                    146.082}, {252.344, 146.082}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4gmHvmrE7M502DdfSv9uRKqD1ZYTZftmZzqE
8elumtud6rC3ZLIES1mmw0Wl2z/rhFIdGEDgS4bDcW/zTscdKQ5FGRPf1mzP
cHBMeHpBqT/FwQconNCb4aB/V4WtUTHFYZHrts9/ezIcQMrsbyY7xO3y5GHq
znCwBNmzPBli7qQMB67riwtsy5Lh6sF8t2SIOZ0ZEHs1kh1unvse/Dgzw6HA
FqjiSZJDMcjg+gyHfpA/LidBxHdkQPyzIslhRp5Q8wGmTIdVHy/5JnkkQcxX
yXSIBblDHSrvlAkR50ly6JsOFIjJhPhjLVS+KNOh9XXgDrmvSQ5bgc6e35Xp
oG7IsUbGKRniroZMSDjNS4aIH4Kqf5oMoT9C+aLQ8ErPcjgGCj+XFAdukD+j
shyEmw+cWhiZ4gAAUFevAg==
                    "]]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4gmHvmrE7M502D9fSv9uRKqD1ZYTZftmZzqE
8elumtud6rC3ZLIES1mmwwWl2z/rhFIdGEDgS4bDcW/zTscdKQ5FGRPf1mzP
cHBMeHpBqT/FwQconNCb4aB/V4WtUTHFYZHrts9/ezIcMoHK7G8mO8Tt8uRh
6s5wsATZszzZ4SLI3EkZDlzXFxfYliXD1YP5bskQczozIPZqJDvcPPc9+HFm
hkOBLVDFkySHYpD99RkO/SB/XE6CiO/IgPhnRZLDjDyh5gNMmQ6rPl7yTfJI
gpivkglxhzpU3ikTIs6T5NA3HSgQk+kA8l7CWqh8UaZD6+vAHXJfkxy2Ap09
vyvTQd2QY42MUzLEXQ2ZDntA4TQvGSJ+CKr+aTKE/gjli0LDKz3L4RjIApcU
B26QP6OyHISbD5xaGJniAABSL68D
                    "], 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0.74902, 0., 0.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGI9IGYC4ts/67L2bMl0kI1Ksb5/PtmhWmSd+8NVmQ4X
lIAyz5IdjnubdzrOyXTYWzJZguVfssO7GnvTuK5MB67riwtshVIceqfnCTVX
QNWrpTiosjVOdU7OdAjj09001zwFYq431Hz7FAcfoHEJppkQcz1SHN6CzJPL
dHBKeHpBKRjK58t0cATx06F8tkyHRa7bPv8tSHGYcOirRsz/DAfh5gOnFtam
ODCAwJ8Mh0JboIt6UhxugfzzI8Nh64myffNnIfhg96xOgdjzOwNi/v4Uh1Uf
L/kmAeXB5u9JcagC+f9bhsMMoLcO7IKa/yXDoQBk/o4Uh6KMiW9rtmc4FIPo
/hSH1teBO+R6oe5RTHG4A7KvJ8NB/64KW+PNZIh+GP9oMiQcujMc1A051shs
SoarB4fnvGQHkLH2EzMcbp77Hvx4YjJE39QMh28aMf2HWqHmzYGqr0t2OAYK
xyUZkHgoSYaIr8uAxFdeMsT/O6D2ZyZDzD0LVZ+QDHHHM2h4xUHd8wdqfliy
w+Ols48oiEDj3w/K14HGl3WyAzj9OGRCwkclGRKeIZmQdMCfDAkvYHrYAjL/
W5KDAcgduZmQ+HqQBFGXnwkJ92dJEHcWZkLs+ZAEsac4EyL+NQninw6E/eB4
a4Gmpx6oe5DSMwC1Tkwb
                    "]]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGI9IGYC4ts/67L2bMl0kI1Ksb5/PtmhWmSd+8NVmQ4X
lYAyz5IdjnubdzrOyXTYUzJZguVfssO7GnvTuK5MB67riwtshVIceqfnCTVX
QNWrpTiosjVOdU7OdAjj09001zwFYq431Hz7FAcfoHEJppkQcz1SHN6CzJPL
dHBMeHpBKRjK58t0cALx06F8tkyHRa7bPv8tSHGYcOirRsz/DAfh5gOnFtam
ODCAwJ8Mh0JboIt6UhxugfzzI8Nhy4myffNnIfhg96xOgZj7OwNi3/4Uh1Uf
L/kmAeXB5u9JcagC+f9bhsMMoLcO7IKa/wVq/o4Uh6KMiW9rtmc4FIPo/hSH
1teBO+R6oe5RTHG4A7KvJ8PB4K4KW+PNZIh+IF8PxD+aDAmH7gwHdUOONTKb
kuHqweE5L9kBZKz9xAyHm+e+Bz+emOygD9I3NcMB6Ov+Q61Q8+ZA1dclOxwD
heOSDEg8lCRDxNdlQOIrLxni/x1Q92QmQ8w9C1WfkAxxx7MMh62g8IqDuucP
1PywZIfHS2cfURCBxr8flK8DjS/rZAdw+nHIdCgAhY9KMiQ8QzIh6YA/GRJe
wPQANv9bEsQduVD1D5Ig6vIzIenuWRLEv4WZEHs+JEHiqzgTEn5fkyD+6UDY
D463Fmh66oG6Byk9AwC1BkwY
                    "], 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    199.85500000000002`, 166.09}, {199.469, 163.402}, {
                    200.965, 162.51199999999997`}, {202.375, 161.988}, {
                    203.836, 161.47299999999998`}, {205.031, 159.906}, {
                    205.648, 158.488}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{196.238, 
                    157.246}, {196.85500000000002`, 154.934}, {198.477, 
                    155.223}, {199.89100000000002`, 154.703}, {201.348, 
                    154.184}, {202.88700000000003`, 152.336}, {203.5, 
                    150.922}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    204.48800000000003`, 172.414}, {205.227, 
                    172.89100000000002`}, {219.43, 148.97299999999998`}, {
                    218.691, 148.496}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    204.48800000000003`, 172.414}, {205.227, 
                    172.89100000000002`}, {219.43, 148.97299999999998`}, {
                    218.691, 148.496}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{206.016, 173.36700000000002`}, {206.016, 
                    172.512}, {205.23399999999998`, 171.73}, {204.379, 
                    171.73}, {203.523, 171.73}, {202.742, 172.512}, {202.742, 
                    173.36700000000002`}, {202.742, 174.227}, {203.523, 
                    175.004}, {204.379, 175.004}, {205.23399999999998`, 
                    175.004}, {206.016, 174.227}, {206.016, 
                    173.36700000000002`}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{206.016, 173.36700000000002`}, {206.016, 
                    172.51199999999997`}, {205.23399999999998`, 
                    171.73000000000002`}, {204.379, 171.73000000000002`}, {
                    203.523, 171.73000000000002`}, {202.742, 
                    172.51199999999997`}, {202.742, 173.36700000000002`}, {
                    202.742, 174.22700000000003`}, {203.523, 175.004}, {
                    204.379, 175.004}, {205.23399999999998`, 175.004}, {
                    206.016, 174.22700000000003`}, {206.016, 
                    173.36700000000002`}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    218.16, 192.586}, {223.914, 192.586}, {223.914, 
                    191.26600000000002`}, {218.16, 
                    191.26600000000002`}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    218.16, 192.58599999999998`}, {223.914, 
                    192.58599999999998`}, {223.914, 191.266}, {218.16, 
                    191.266}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    218.16, 190.078}, {223.914, 190.078}, {223.914, 
                    179.055}, {218.16, 179.055}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    218.16, 190.07799999999997`}, {223.914, 
                    190.07799999999997`}, {223.914, 179.05499999999998`}, {
                    218.16, 179.05499999999998`}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    217.809, 194.09}, {224.191, 194.05100000000002`}, {
                    224.441, 196.21499999999997`}, {222.281, 198.555}, {
                    221.02, 198.531}, {219.77299999999997`, 198.469}, {
                    217.758, 196.164}, {217.809, 194.09}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    217.809, 194.08999999999997`}, {224.191, 194.051}, {
                    224.441, 196.215}, {222.281, 198.555}, {221.02, 
                    198.531}, {219.77299999999997`, 198.469}, {217.758, 
                    196.164}, {217.809, 194.08999999999997`}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {CompressedData["
1:eJxTTMoPSmViYGBQBmIQ7ZTw9IKSc65D3/Q8oeacDIfHS2cfUZDJhdAxGQ5c
1xcX2P7LcQjn0900Vz/DQTYqxfr+6xyI+j/pDvp3Vdgab+Y4eJt3OiacTHe4
qHT7Z92lHAdVtsapzv3pDmDzb+c49ILUJyD4VltOlO2LT3d4W2NvGncPar5/
usMMoLIDj3IcGEDAJd1BBmTfc6h663SHRa7bPv99k+NQlDHxbY1xusNWoPD8
TzkQWg/qnp85Dj4g9+imOxwHOYwB6h+ddAeQMfPZciHm6ac7cIP8x5ULUW+a
7nDz3Pfgx7y5DnG7PHmYgPaB1fHnQtzplO7gCHI/P1TeO91hwqGvGjHcUH51
ukMYyB9A/iVQOKyCqheHmn8VGj5KuVB3ZUDCzRJqvloGJHySoepdMyD+ysp1
qBZZ5/7QKwNiT36uA8j79oHQ+ADyLUHuDM9wAJqetacgFxJvcRkQc3JzIeqS
MxyAnr2+OAOqPj0D4v74XIdikIH5GQ6FIPmAXAd1Q441MkVQ9yClDwAIJfB7

                    "], CompressedData["
1:eJxTTMoPSmViYGBQAmIQ7Zjw9IKSe66Dt3mnY0JihkPv9Dyh5oBch4yJb2vs
UzMcCm25ri+OyXWI2+XJw5Sc4aB/V4WtMRHKj89wkI1Ksb6fnOuwf76U/t2Y
DIfHS2cfUUjJdSgGGRCNkAebH5nhUAQSB/LB9oZnONw89z34MdC8/kNfNWKC
oeqjoeb7ZzgwgIBBrgPQNaZxehkOMiB58VyIO1ih6rlzIe6+kQ7h/89xCOPT
3TR3dTrEPQy5DtUi69wfVkHlmXMd1A051sh4pTus+njJN4klF+Iu53SHi0q3
f9Yx5UJou3SI/4H6rbacKNtnnQ4x51+OwyLXbZ//WqRD3P83B2KPBdT83zkQ
9wD53zRi+g/9zHHYBwofIB/s7q85kPCxhvI/5kDc45Tu4AMKp7c5Drd+1mXt
8UiHhNvLHEh4BKc7AF1TYPsMqj4Jyr+X47C3ZLIESx9U/9McB1W2xqnOx9Mh
4fwd6p4f6RB3cORC3K2ZAYln1VwHJ5A6YPijpwcAtQ3lmA==
                    "]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, CompressedData["
1:eJxlU1tIVFEUHcaSiLDQKInRJlHHnk6FWiPi1oqCsidUiNkk2j5G20or6Ali
ffjRU6IgJjFzwEl6SEUfZSJBESEmQUVIhPQVfURURESdc/eSggaGw71n77XX
XmvdWTV7NtYl+Xw+v/3PxPmofUb+yAmh0MIJPYGIoYf729LHVQt9y6s6MzDb
kHe/XOjswNe8qt9MOcnNF5YVCR2ZemPl+0FGndCno6UF1VeYNqfM742FhA67
+51Mo12XHwfDQqcuNqS2LGFyR3+haN10Jp/7rRKa+Kpzb0kyU5+bt1Vo6Z2n
B/uSmMw5i7wD+H6m/JHs5OZ68BvP9CLr7Y/jDUKnHfAkpkbX0CTKM43p5McN
9zMPCF3/PFxRE0B9I/BDmGew/1rMqxN6M/h90+gx8N8t+r6bdW/bb1F2PXiJ
e6tfkyv4yarXNeiTanRuj1DCnelG+24JXXI6ZBpKa+l/1nEb+DmG7lpa7b1C
GZW1xe/mGiqLfhjKugl9FhkadvwT4FtodL8O8C0xut95oYjbrxT+/eOvN68V
/BYYKnf4bXi2+Ooj/Aob1bET+s4zqnuXKI85Rv2Mi/KweRly7+PwP9fo3Dj0
yjaqu8XzeAXBJwb8gFF/D0EfP/ZnoSeri1rLXkPvKPgmmK6uuPfll81L2PVZ
v9bYsug28KlAXnlMXyYHE60HXuDvvcdzGvyrHfMPeakR2uLyOpn1O9iO+hRW
HSpRb5/3lVin1sPvKchTGfhkMOW6ecWoj7Dqvxh5ZeS7AH7GML8c+jxnzdk6
0T6bN09Py9+bG/zf3z+xPLCC
                    "]]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    217.848, 170.09}, {224.27, 170.09}, {224.27, 161.203}, {
                    217.848, 161.203}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    217.848, 170.09}, {224.27, 170.09}, {224.27, 161.203}, {
                    217.848, 161.203}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    218.22299999999998`, 156.121}, {224.422, 156.121}, {
                    224.422, 154.25400000000002`}, {218.22299999999998`, 
                    154.25400000000002`}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    218.22299999999998`, 156.121}, {224.422, 156.121}, {
                    224.422, 154.25400000000002`}, {218.22299999999998`, 
                    154.25400000000002`}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    218.07, 152.84}, {224.418, 152.84}, {224.418, 145.895}, {
                    218.07, 145.895}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    218.07, 152.84}, {224.418, 152.84}, {224.418, 145.895}, {
                    218.07, 145.895}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    217.625, 144.47299999999998`}, {224.566, 
                    144.47299999999998`}, {224.566, 140.58999999999997`}, {
                    217.625, 140.58999999999997`}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    217.625, 144.47299999999998`}, {224.566, 
                    144.47299999999998`}, {224.566, 140.58999999999997`}, {
                    217.625, 140.58999999999997`}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    218.48000000000002`, 157.79299999999998`}, {
                    224.07399999999998`, 157.79299999999998`}, {225.184, 
                    159.641}, {217.477, 159.641}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    218.48000000000002`, 157.793}, {224.07399999999998`, 
                    157.793}, {225.184, 159.641}, {217.477, 159.641}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    226.023, 164.602}, {226.078, 169.45700000000002`}, {
                    229.93, 169.45700000000002`}, {228.418, 168.207}, {
                    227.008, 166.695}, {226.023, 164.602}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    226.023, 164.60199999999998`}, {226.078, 
                    169.45700000000002`}, {229.93, 169.45700000000002`}, {
                    228.418, 168.20700000000002`}, {227.008, 166.695}, {
                    226.023, 164.60199999999998`}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYCYqeEpxeUorMdijImvq0JTnFY/fGSb1JMtgPX
9cUFtkYpDi7dOc9/N2Y7LHLd9vmvA4L/TSOm/1AgmnxLisPWE2X75jdlO/RN
zxNq3pPiUGgLNKkh2+H2z7qsPQ9SHFaBzAfyw/h0N839DeUfyHbYN19K/+6X
FAcGEADyweJPUhyOe5t3OgL5ba8Dd8jtTIGYcwBqf20KxF4gP26XJw+Td4pD
L8heIP9tjb1pHND970D0q2yIuEkKRN9LhHr9uypsjUB+KMg9zQj+zXPfgx9f
RagvBoXP/xQHdUOONTJA81pB7jFNhdgPDC+wu01SHWSjUqzvR0P9y4Dgg8Pl
WooDLLxV2RqnOncj+LDwBwDld7xQ
                    "], 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    218.85500000000002`, 152.016}, {223.41000000000003`, 
                    152.016}, {223.41000000000003`, 146.34}, {
                    218.85500000000002`, 146.34}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    221.76999999999998`, 149.664}, {223.37499999999997`, 
                    149.664}, {223.37499999999997`, 148.73}, {
                    221.76999999999998`, 148.73}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    221.76999999999998`, 149.664}, {223.37499999999997`, 
                    149.664}, {223.37499999999997`, 148.73}, {
                    221.76999999999998`, 148.73}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    218.969, 149.664}, {220.535, 149.664}, {220.535, 
                    148.73}, {218.969, 148.73}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    218.969, 149.664}, {220.535, 149.664}, {220.535, 
                    148.73}, {218.969, 148.73}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    220.535, 151.945}, {221.769, 151.945}, {221.769, 
                    149.629}, {220.535, 149.629}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    220.535, 151.945}, {221.769, 151.945}, {221.769, 
                    149.629}, {220.535, 149.629}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    220.535, 148.76999999999998`}, {221.769, 
                    148.76999999999998`}, {221.769, 146.30499999999998`}, {
                    220.535, 146.30499999999998`}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    220.535, 148.77}, {221.769, 148.77}, {221.769, 146.305}, {
                    220.535, 146.305}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{195.191, 
                    208.824}, {195.477, 204.371}, {194.094, 
                    201.92600000000002`}, {191.73399999999998`, 202.297}, {
                    191.086, 204.76999999999998`}, {192.566, 
                    206.42600000000002`}, {195.191, 208.824}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{195.191, 
                    208.824}, {195.477, 204.371}, {194.094, 201.926}, {
                    191.73399999999998`, 202.297}, {191.086, 
                    204.76999999999998`}, {192.566, 206.426}, {195.191, 
                    208.824}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{190.016, 
                    198.953}, {187.918, 200.02}, {189.434, 208.164}, {190.238,
                     211.57399999999998`}, {190.83200000000002`, 207.18}, {
                    191.82800000000003`, 200.93}, {190.016, 
                    198.953}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{190.016, 
                    198.95299999999997`}, {187.918, 200.01999999999998`}, {
                    189.434, 208.164}, {190.238, 211.574}, {
                    190.83200000000002`, 207.18}, {191.82800000000003`, 
                    200.93}, {190.016, 198.95299999999997`}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{190.762, 
                    198.566}, {194.285, 197.344}, {197.07399999999998`, 
                    201.137}, {198.02, 205.535}, {195.10899999999998`, 
                    201.52}, {190.375, 201.516}, {190.762, 
                    198.566}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{190.762, 
                    198.56599999999997`}, {194.285, 197.344}, {
                    197.07399999999998`, 201.137}, {198.02, 205.535}, {
                    195.10899999999998`, 201.51999999999998`}, {190.375, 
                    201.516}, {190.762, 198.56599999999997`}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{188.09, 
                    194.45700000000002`}, {185.33200000000002`, 195.184}, {
                    186.99200000000002`, 203.824}, {187.49200000000002`, 
                    207.281}, {188.098, 203.71099999999998`}, {190., 
                    195.637}, {188.09, 194.45700000000002`}}}]}}}}}}}, {{{{{{{
                    
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{188.09, 
                    194.457}, {185.33200000000002`, 195.184}, {
                    186.99200000000002`, 203.824}, {187.49200000000002`, 
                    207.281}, {188.098, 203.711}, {190., 195.637}, {188.09, 
                    194.457}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{189.031, 
                    194.727}, {189.18800000000002`, 197.707}, {192.156, 
                    196.848}, {194.207, 198.43800000000002`}, {193.871, 
                    196.94899999999998`}, {192.60899999999998`, 194.309}, {
                    189.031, 194.727}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{189.031, 
                    194.727}, {189.18800000000002`, 197.707}, {192.156, 
                    196.848}, {194.207, 198.438}, {193.871, 196.949}, {
                    192.60899999999998`, 194.309}, {189.031, 194.727}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{185.656, 
                    190.73399999999998`}, {182.92600000000002`, 
                    191.47299999999998`}, {184.566, 200.76999999999998`}, {
                    184.41, 204.598}, {185.21099999999998`, 
                    201.29299999999998`}, {187.75, 191.63299999999998`}, {
                    185.656, 190.73399999999998`}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{185.656, 
                    190.734}, {182.92600000000002`, 191.47299999999998`}, {
                    184.566, 200.76999999999998`}, {184.41, 204.598}, {
                    185.21099999999998`, 201.293}, {187.75, 
                    191.63299999999998`}, {185.656, 190.734}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{186.93, 
                    191.137}, {189.164, 190.41}, {192.129, 191.863}, {192.363,
                     194.52700000000002`}, {190.434, 193.21899999999997`}, {
                    187.359, 194.21899999999997`}, {186.93, 
                    191.137}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{186.93, 
                    191.137}, {189.164, 190.41}, {192.129, 191.863}, {192.363,
                     194.527}, {190.434, 193.219}, {187.359, 194.219}, {
                    186.93, 191.137}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{183.617, 
                    186.63299999999998`}, {181.004, 186.42200000000003`}, {
                    182.172, 194.344}, {182.176, 201.71899999999997`}, {
                    183.13299999999998`, 194.824}, {185.75, 188.512}, {
                    183.617, 186.63299999999998`}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{183.617, 
                    186.63299999999998`}, {181.004, 186.422}, {182.172, 
                    194.344}, {182.176, 201.719}, {183.13299999999998`, 
                    194.824}, {185.75, 188.51199999999997`}, {183.617, 
                    186.63299999999998`}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{184.52, 
                    186.99200000000002`}, {186.285, 186.105}, {189.445, 
                    187.52}, {190.348, 190.5}, {187.16, 189.117}, {
                    185.02700000000002`, 190.469}, {184.52, 
                    186.99200000000002`}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{184.52, 
                    186.992}, {186.285, 186.105}, {189.445, 
                    187.51999999999998`}, {190.348, 190.5}, {187.16, 
                    189.117}, {185.02700000000002`, 190.469}, {184.52, 
                    186.992}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{205.023, 
                    204.695}, {204.559, 200.83200000000002`}, {
                    202.98000000000002`, 198.586}, {200.621, 
                    198.95700000000002`}, {199.97299999999998`, 
                    201.42600000000002`}, {201.883, 203.008}, {205.023, 
                    204.695}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{205.023, 
                    204.695}, {204.559, 200.832}, {202.98000000000002`, 
                    198.58599999999998`}, {200.621, 198.957}, {
                    199.97299999999998`, 201.426}, {201.883, 
                    203.00799999999998`}, {205.023, 204.695}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{198.785, 
                    194.785}, {202.70299999999997`, 194.227}, {
                    204.11299999999997`, 197.23399999999998`}, {206.75, 
                    201.08200000000002`}, {203.055, 198.406}, {198.637, 
                    197.848}, {198.785, 194.785}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{198.785, 
                    194.785}, {202.70299999999997`, 194.227}, {
                    204.11299999999997`, 197.23399999999998`}, {206.75, 
                    201.082}, {203.055, 198.406}, {198.637, 197.848}, {
                    198.785, 194.785}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{197.672, 
                    195.22299999999998`}, {195.535, 197.789}, {197.602, 
                    201.008}, {199.23399999999998`, 203.75}, {198.883, 
                    199.668}, {200.27299999999997`, 197.39800000000002`}, {
                    197.672, 195.22299999999998`}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{197.672, 
                    195.223}, {195.535, 197.789}, {197.602, 
                    201.00799999999998`}, {199.23399999999998`, 203.75}, {
                    198.883, 199.668}, {200.27299999999997`, 
                    197.39800000000002`}, {197.672, 195.223}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{196.727, 
                    190.99200000000002`}, {196.48800000000003`, 193.5}, {
                    200.758, 194.055}, {202.691, 195.44899999999998`}, {
                    202.039, 194.}, {201.055, 190.102}, {196.727, 
                    190.99200000000002`}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{196.727, 
                    190.992}, {196.48800000000003`, 193.5}, {200.758, 
                    194.055}, {202.691, 195.449}, {202.039, 194.}, {201.055, 
                    190.10199999999998`}, {196.727, 190.992}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    195.83200000000002`, 190.93800000000002`}, {192.879, 
                    191.26999999999998`}, {194.105, 196.285}, {
                    196.22299999999998`, 199.07}, {195.33200000000002`, 
                    195.227}, {197.781, 192.55100000000002`}, {
                    195.83200000000002`, 
                    190.93800000000002`}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    195.83200000000002`, 190.938}, {192.879, 191.27}, {
                    194.105, 196.285}, {196.22299999999998`, 199.07}, {
                    195.33200000000002`, 195.227}, {197.781, 192.551}, {
                    195.83200000000002`, 190.938}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    193.60899999999998`, 186.762}, {190.24599999999998`, 
                    188.24599999999998`}, {192.40200000000002`, 192.461}, {
                    193.664, 194.94899999999998`}, {193.125, 191.684}, {
                    195.82000000000002`, 189.191}, {193.60899999999998`, 
                    186.762}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    193.60899999999998`, 186.762}, {190.24599999999998`, 
                    188.246}, {192.40200000000002`, 192.461}, {193.664, 
                    194.949}, {193.125, 191.684}, {195.82000000000002`, 
                    189.191}, {193.60899999999998`, 186.762}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    194.27299999999997`, 187.15200000000002`}, {196.035, 
                    184.848}, {199.47299999999998`, 187.84}, {200.18, 
                    191.33200000000002`}, {197.18800000000002`, 188.84}, {
                    194.977, 189.25}, {194.27299999999997`, 
                    187.15200000000002`}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    194.27299999999997`, 187.152}, {196.035, 
                    184.84799999999998`}, {199.47299999999998`, 187.84}, {
                    200.18, 191.332}, {197.18800000000002`, 188.84}, {194.977,
                     189.25}, {194.27299999999997`, 187.152}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIZIGYC4rhdnjxMwekOXNcXF9jGpTrIRKVY33dPd2AA
gTOpDpeUbv+sm5XuUJQx8W3N5DQHWZB8fLrD3pLJEiz/0iDqw9MdCm2BJvCk
O3ibdzomFKY79B/6qhFjnO5w89z34MeN6RB90ukOYXy6m+bOhtr3Lc1B3ZBj
jcy2dAenhKcXlLrTHEDW2B9Md5iRJ9R8YFOawyLXbZ//nkl3+KYR03/obhpE
/ByUr5nusH++lP7dL+kOvdOBEhbpDq2vA3fI8WZAaMd0h2KQgfoZDlUi69wf
uqVD7FPLgLhXId3hzs+6rD0yGRD3/U6D+JsDqv9kmgM4fOQzIPYdTXPoA9mj
A1V/GCofnAEJh+9pkHAqhsrzQ93Zm+HgAwoX1XSH2yD7tmQ4WG45UbaPOd3h
Iih8+zIcQkHh8jjNwaU75/lvwQyH1R8v+SbVpDno31Vha5wJDUffNIdqkD+C
EPEFABcywTw=
                    "]]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIZIGYC4rhdnjxMwekOXNcXF9jGpTrIRKVY33dPd2AA
gTOpDpeUbv+sm5XuUJQx8W3N5DQHWZB8fLrDnpLJEiz/0iDqw9MdCm2BJvCk
O3ibdzomFKY79B/6qhFjnO5w89z34MeN6RB90ukOYXy6m+bOhtr3Lc1B3ZBj
jcy2dAfHhKcXlLrTHEDW2B9Md5iRJ9R8YFOawyLXbZ//nkl3+KYR03/obhpE
/ByUr5nusH++lP7dL+kOfdOBEhbpDq2vA3fI8WZAaMd0h2KQgfoZDtUi69wf
uqVD7FPLcCgAuVch3eHOz7qsPTIZEPf9ToP4myPDoQ2k/2SaAzh85DMcvoLs
O5oGsUcHqv4wVD4Yyv+eBgmnYiifH+rO3gxIuKimO9wG2bclw8Fyy4myfczp
DhdB4duX4RAKCpfHaQ4u3TnPfwtmOKz+eMk3qSbNQf+uClvjTGg4+qZB/BGE
iC8AFarBOw==
                    "], CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIZIGYC4qKMiW9ritMcRNa5P6y6Euuwf76U/t2UNAeX
7pznv29C+QFpDu1iN899fxzrELfLk4cpOc0BSGq3b4t1WPXxkm/SlzSH3ul5
Qs0BMQ4XlW7/rJNLd/imEdN/6G00hP8p3YEBBBRiHApsua4vPpEBUR8R4xDG
p7tp7u8MB78kgQjLMzEOws0HTi2cmAlxT0kshP8wE2LOpVgHkLYDYVkOxSB3
P4+F0OuzHDKBlP3aWId9IPfeyHIA2lJgOynWAejq4McfsyD2TYh1OOZt3ul4
Jcth09z3y4+djnXYcqJs3/xtWQ5PLwAtYItzCAW5Z3KWgyVIIjzOwTEBKJOf
5bBGJirFuj/OYcKhrxox8lkONfamcbs44x1AwvenZzo8A+m3i3cAGZ+gmQlx
l3i8Q+vrwB1yvRmQ8HoWBwkHngyIvHwcJJwK0yH+B4Z/ISh8FNIh9q2Phbjj
eJoD0PdZe7bEOqDHFwBlE80j
                    "]]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIZIGYC4qKMiW9ritMcRNa5P6y6Euuwf76U/t2UNAeX
7pznv29C+QFpDm1iN899fxzrELfLk4cpOc3Bi4dJu31brMOqj5d8k76kOfRN
zxNqDohxuKh0+2edXLrDN42Y/kNvoyH8T+kODCCgEONQYMt1ffGJDIj6iBiH
MD7dTXN/Zzj4JQlEWJ6JcRBuPnBq4cRMiHtKYiH8h5kOl0DmXIp1AGk7EJbl
AHb381iHYhC9PsshC0jZr4112Ady740sB57riwtsJ8U6AF0d/PhjFsS+CbEO
x7zNOx2vZDlsmvt++bHTsQ5bTpTtm78ty+HJBaAFbHEOoSD3TM5ysAJJhMc5
OCY8vaCUn+WwRiYqxbo/zmHCoa8aMfJZDjX2pnG7OOMdQML3p2c6PAPpt4t3
ABmfoJnpUAJyl3i8Q+vrwB1yvRkOHqDwehYHCQeeDIj75eMg4VSYDvE/MPwL
QeGjkA6xb32sgyXIHcfTHO78rMvasyXWAT2+AGtDzSk=
                    "], 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    217.84, 109.32}, {218.684, 109.215}, {219.21899999999997`,
                     107.57799999999999`}, {219.637, 108.68799999999999`}, {
                    220.34, 110.48}, {219.848, 111.906}, {219.055, 111.75}, {
                    218.117, 111.5}, {216.535, 109.402}, {217.84, 
                    109.32}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    217.84, 109.32}, {218.684, 109.215}, {219.21899999999997`,
                     107.57799999999997`}, {219.637, 108.68799999999999`}, {
                    220.34, 110.47999999999999`}, {219.848, 111.906}, {
                    219.055, 111.75}, {218.117, 111.5}, {216.535, 
                    109.40199999999999`}, {217.84, 109.32}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4gmHvmrE8Kc5ZEx8W2O/NdXhuLd5p+OHVIdv
GjH9h66mQsR/pjqoG3KskXmU6qDK1jjVWT3NYeuJsn3zgXyrLUCGd5rDItdt
n/8+SXVgAIEpaRBzzqQ6FIMMWA/lP0h1KLDlur74RJrDRaXbP+s+pULM2ZcG
0eeQBrH3ZJqDJcjcZKg959Icwvh0N80tT3MoBOm/k+ZQJbLO/eG0NAfZqBTr
+7/TIO5LS4OYH5HuoH9Xha3xYqpD3/Q8oeYz6Q6OCU8vKMmnOuwtmSzB8i/d
YdXHS75JBSkQd0tkOAB9aRrHlwJx73+o/tJkCL00HeIOvmSHWz/rsvasSHcA
2lJgm5bs8Hjp7CMKHemQcFqYDPFnQrrDJZD/XiVD7NVPd5gBdMYBrxSIvRVp
DuEg//inOqCHPwBV9Ldy
                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    188.42600000000002`, 149.24599999999998`}, {
                    191.60899999999998`, 149.23399999999998`}, {192.156, 
                    153.504}, {192.156, 154.69899999999998`}, {190.59, 
                    154.39800000000002`}, {187.82800000000003`, 151.785}, {
                    188.42600000000002`, 
                    149.24599999999998`}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    188.42600000000002`, 149.246}, {191.60899999999998`, 
                    149.234}, {192.156, 153.504}, {192.156, 
                    154.69899999999998`}, {190.59, 154.398}, {
                    187.82800000000003`, 151.78500000000003`}, {
                    188.42600000000002`, 149.246}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{215.961, 
                    107.793}, {218.227, 107.277}, {218.195, 
                    112.73400000000001`}, {215.879, 115.04700000000001`}, {
                    216.89800000000002`, 111.543}, {214.176, 108.336}, {
                    215.961, 107.793}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{215.961, 
                    107.793}, {218.227, 107.27700000000002`}, {218.195, 
                    112.73400000000001`}, {215.879, 115.047}, {
                    216.89800000000002`, 111.54299999999998`}, {214.176, 
                    108.33600000000001`}, {215.961, 107.793}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{215.078, 
                    107.84}, {215.23, 105.24600000000001`}, {
                    208.71499999999997`, 108.17999999999999`}, {207.039, 
                    110.195}, {210.88700000000003`, 108.562}, {
                    214.89100000000002`, 109.91400000000002`}, {215.078, 
                    107.84}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{215.078, 
                    107.84}, {215.23, 105.24600000000001`}, {
                    208.71499999999997`, 108.17999999999998`}, {207.039, 
                    110.195}, {210.88700000000003`, 108.56199999999998`}, {
                    214.89100000000002`, 109.91399999999999`}, {215.078, 
                    107.84}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    212.22299999999998`, 111.543}, {212.45700000000002`, 
                    109.031}, {206.57399999999998`, 111.242}, {
                    204.83200000000002`, 113.203}, {208.69899999999998`, 
                    111.953}, {211.969, 113.613}, {212.22299999999998`, 
                    111.543}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    212.22299999999998`, 111.54299999999998`}, {
                    212.45700000000002`, 109.031}, {206.57399999999998`, 
                    111.24199999999999`}, {204.83200000000002`, 113.203}, {
                    208.69899999999998`, 111.953}, {211.969, 
                    113.61299999999997`}, {212.22299999999998`, 
                    111.54299999999998`}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{213.305, 
                    111.191}, {215.57, 110.67599999999999`}, {
                    215.20299999999997`, 116.32}, {213., 118.262}, {214.059, 
                    114.49600000000001`}, {211.523, 111.738}, {213.305, 
                    111.191}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{213.305, 
                    111.191}, {215.57, 110.67599999999999`}, {
                    215.20299999999997`, 116.32}, {213., 118.262}, {214.059, 
                    114.49600000000001`}, {211.523, 111.738}, {213.305, 
                    111.191}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    210.92200000000003`, 114.62499999999999`}, {
                    213.18800000000002`, 114.109}, {211.88700000000003`, 
                    118.96900000000001`}, {210.207, 120.91000000000001`}, {
                    210.48000000000002`, 117.367}, {209.363, 
                    114.91000000000001`}, {210.92200000000003`, 
                    114.62499999999999`}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    210.92200000000003`, 114.625}, {213.18800000000002`, 
                    114.10899999999998`}, {211.88700000000003`, 118.969}, {
                    210.207, 120.91}, {210.48000000000002`, 
                    117.36700000000002`}, {209.363, 114.91}, {
                    210.92200000000003`, 114.625}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    209.71899999999997`, 114.641}, {209.953, 112.051}, {
                    205.375, 114.039}, {203.598, 116.488}, {
                    207.42600000000002`, 115.238}, {209.465, 
                    116.70700000000001`}, {209.71899999999997`, 
                    114.641}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    209.71899999999997`, 114.64099999999999`}, {209.953, 
                    112.05100000000002`}, {205.375, 114.03899999999999`}, {
                    203.598, 116.488}, {207.42600000000002`, 115.238}, {
                    209.465, 116.70700000000002`}, {209.71899999999997`, 
                    114.64099999999999`}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    208.47299999999998`, 116.609}, {209.95700000000002`, 
                    117.67599999999999`}, {208.383, 120.5}, {205.555, 
                    120.324}, {205.83200000000002`, 118.617}, {206.809, 
                    115.621}, {208.47299999999998`, 116.609}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    208.47299999999998`, 116.60899999999998`}, {
                    209.95700000000002`, 117.67599999999999`}, {208.383, 
                    120.5}, {205.555, 120.32400000000001`}, {
                    205.83200000000002`, 118.61699999999999`}, {206.809, 
                    115.62100000000001`}, {208.47299999999998`, 
                    116.60899999999998`}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    219.63299999999998`, 104.902}, {219.781, 102.309}, {
                    213.266, 103.60199999999999`}, {211.21899999999997`, 
                    106.363}, {215.32800000000003`, 105.586}, {219.441, 
                    106.98}, {219.63299999999998`, 104.902}}}]}}}}}}}, {{{{{{{
                    
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    219.63299999999998`, 104.90199999999999`}, {219.781, 
                    102.309}, {213.266, 103.60199999999998`}, {
                    211.21899999999997`, 106.363}, {215.32800000000003`, 
                    105.58600000000001`}, {219.441, 106.97999999999999`}, {
                    219.63299999999998`, 104.90199999999999`}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{193.742, 
                    109.543}, {193.977, 106.95700000000001`}, {186.863, 
                    109.801}, {185.086, 112.25}, {188.91, 111.}, {
                    193.48800000000003`, 111.613}, {193.742, 
                    109.543}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{193.742, 
                    109.54299999999998`}, {193.977, 106.95700000000002`}, {
                    186.863, 109.80100000000002`}, {185.086, 112.25}, {188.91,
                     111.}, {193.48800000000003`, 111.61299999999997`}, {
                    193.742, 109.54299999999998`}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{198.105, 
                    108.44100000000002`}, {199.59, 109.508}, {196.559, 
                    112.258}, {194.14499999999998`, 112.902}, {194.418, 
                    111.199}, {196.441, 107.453}, {198.105, 
                    108.44100000000002`}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{198.105, 
                    108.441}, {199.59, 109.50799999999998`}, {196.559, 
                    112.25800000000001`}, {194.14499999999998`, 
                    112.90199999999999`}, {194.418, 111.19899999999998`}, {
                    196.441, 107.453}, {198.105, 108.441}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{198.559, 
                    106.648}, {198.71899999999997`, 104.32}, {190.93, 
                    105.598}, {188.895, 107.74600000000001`}, {195.594, 
                    106.535}, {198.34, 108.641}, {198.559, 
                    106.648}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{198.559, 
                    106.64799999999997`}, {198.71899999999997`, 104.32}, {
                    190.93, 105.59799999999998`}, {188.895, 
                    107.74600000000001`}, {195.594, 106.535}, {198.34, 
                    108.64099999999999`}, {198.559, 106.64799999999997`}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{202.207, 
                    105.098}, {203.07399999999998`, 102.93400000000001`}, {
                    195.598, 103.46100000000001`}, {192.97299999999998`, 
                    104.71900000000001`}, {197.21499999999997`, 104.754}, {
                    201.61299999999997`, 106.60199999999999`}, {202.207, 
                    105.098}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{202.207, 
                    105.09799999999998`}, {203.07399999999998`, 102.934}, {
                    195.598, 103.46100000000001`}, {192.97299999999998`, 
                    104.719}, {197.21499999999997`, 104.75400000000002`}, {
                    201.61299999999997`, 106.60199999999998`}, {202.207, 
                    105.09799999999998`}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    205.70299999999997`, 103.52}, {206.531, 101.582}, {
                    199.617, 101.62499999999999`}, {196.24599999999998`, 
                    102.695}, {200.71099999999998`, 102.73}, {
                    204.88700000000003`, 105.438}, {205.70299999999997`, 
                    103.52}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    205.70299999999997`, 103.51999999999998`}, {206.531, 
                    101.582}, {199.617, 101.625}, {196.24599999999998`, 
                    102.695}, {200.71099999999998`, 102.73000000000002`}, {
                    204.88700000000003`, 105.43799999999999`}, {
                    205.70299999999997`, 103.51999999999998`}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    210.73399999999998`, 102.48}, {211.961, 
                    100.18799999999999`}, {204.664, 99.965}, {202.297, 
                    101.09400000000001`}, {206.516, 101.67199999999998`}, {
                    209.691, 104.285}, {210.73399999999998`, 
                    102.48}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    210.73399999999998`, 102.47999999999999`}, {211.961, 
                    100.18799999999999`}, {204.664, 99.965}, {202.297, 
                    101.094}, {206.516, 101.67199999999997`}, {209.691, 
                    104.28500000000003`}, {210.73399999999998`, 
                    102.47999999999999`}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{202.191, 
                    106.398}, {199.871, 104.938}, {199.996, 109.25}, {198.148,
                     112.238}, {201.05100000000002`, 109.598}, {203.766, 
                    107.79700000000001`}, {202.191, 106.398}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{202.191, 
                    106.398}, {199.871, 104.93799999999999`}, {199.996, 
                    109.25}, {198.148, 112.238}, {201.05100000000002`, 
                    109.59799999999998`}, {203.766, 107.79700000000003`}, {
                    202.191, 106.398}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{206.305, 
                    104.848}, {204.35500000000002`, 103.12499999999999`}, {
                    202.80100000000002`, 109.043}, {201.02700000000002`, 
                    112.367}, {203.895, 109.203}, {208.102, 106.281}, {
                    206.305, 104.848}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{206.305, 
                    104.84799999999998`}, {204.35500000000002`, 103.125}, {
                    202.80100000000002`, 109.04299999999998`}, {
                    201.02700000000002`, 112.36700000000002`}, {203.895, 
                    109.203}, {208.102, 106.28100000000003`}, {206.305, 
                    104.84799999999998`}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{211.742, 
                    103.199}, {210.094, 101.289}, {205.32800000000003`, 
                    108.816}, {203.594, 112.73400000000001`}, {
                    206.23399999999998`, 109.684}, {213.055, 104.82}, {
                    211.742, 103.199}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{211.742, 
                    103.19899999999998`}, {210.094, 101.28900000000002`}, {
                    205.32800000000003`, 108.816}, {203.594, 
                    112.73400000000001`}, {206.23399999999998`, 109.684}, {
                    213.055, 104.82}, {211.742, 103.19899999999998`}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{207.105, 
                    97.45700000000001}, {206.281, 94.551}, {
                    194.15200000000002`, 100.195}, {192.797, 103.117}, {
                    199.738, 99.44100000000002}, {207.26999999999998`, 
                    100.21100000000001`}, {207.105, 
                    97.45700000000001}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{207.105, 
                    97.45700000000002}, {206.281, 94.55100000000002}, {
                    194.15200000000002`, 100.195}, {192.797, 
                    103.11699999999999`}, {199.738, 99.441}, {
                    207.26999999999998`, 100.21100000000001`}, {207.105, 
                    97.45700000000002}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYCYtmoFOv7zKkOYLo/2WFGnlDzgV8pDmF8upvm
zk52KLTlur74QYpDOIgPlHdMeHpB6XmKgxOILk52yJj4tsb+bYrDnZ91WXt8
kh1unvse/Fg1FaK/PclBla1xqnN7qoPllhNl+5yTIOadSXX4phHTf0gwyUH/
rgpbo2W6Q+vrwB1yBxMd4nZ58jDdT3eoFlnn/nBeooNLd87z35YZEH09iQ5A
ssC2LQPijnio/MEMh+kgd4slQtyzMgNibmmig495p2PC1AyIe3YnQsUzHISb
D5xaCLT/gtLtn3VhGQ6LXLd9/huT5LDq4yXfJJYMiH/XQ92/Pt2BAQS2JEHc
KZgOcf/OJIdekMUuaRB1x5Mg4bge6l/2ZEg4JUP56tDwMk2F+DM42QE9/AFt
n6we
                    "]]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYCYtmoFOv7zKkOYLo/2WFGnlDzgV8pDmF8upvm
zk52KLTlur74AZQPlHdMeHpB6XkKhC5OdsiY+LbG/m2Kw+2fdVl7fJIdbp77
HvxYNRWivj3JQZWtcapze6qD5ZYTZfuckyDmnUl1+KYR039IMMlB/64KW6Nl
ukPr68AdcgcTHeJ2efIw3U93qBZZ5/5wXqKDS3fO89+WGRB9PYkOQLLAti0D
Yn88VP5gBsTdYokQ96zMcNADmVua6OBj3umYMDUD4p7diRD7SjMchJsPnFoI
tP+CEtDlYRkOi1y3ff4bk+Sw6uMl3yQWqPr1UPevT3dgAIEtSRB3CqZD3L8z
yaF3OtBilzQHNZC640mQcFwP9S97soMTyJ3JUL46NLxMUyH+DE52QA9/AGl3
rBs=
                    "], CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{196.434, 
                    132.105}, {197.98800000000003`, 130.95700000000002`}, {
                    199.707, 135.066}, {197.73, 138.97299999999998`}, {
                    197.668, 135.21499999999997`}, {194.68, 
                    133.94899999999998`}, {196.434, 132.105}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{196.434, 
                    132.105}, {197.98800000000003`, 130.95700000000002`}, {
                    199.707, 135.066}, {197.73, 138.97299999999998`}, {
                    197.668, 135.215}, {194.68, 133.94899999999998`}, {
                    196.434, 132.105}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{197.93, 
                    128.336}, {200.08200000000002`, 127.67599999999999`}, {
                    200.758, 131.484}, {199.34, 134.535}, {
                    199.57399999999998`, 131.258}, {195.953, 129.285}, {
                    197.93, 128.336}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{197.93, 
                    128.336}, {200.08200000000002`, 127.67599999999999`}, {
                    200.758, 131.484}, {199.34, 134.535}, {
                    199.57399999999998`, 131.258}, {195.953, 
                    129.28500000000003`}, {197.93, 128.336}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{199.566, 
                    125.312}, {201.648, 124.277}, {202.43800000000002`, 
                    128.125}, {200.941, 130.984}, {201.105, 127.34}, {197.965,
                     126.262}, {199.566, 125.312}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{199.566, 
                    125.31199999999998`}, {201.648, 124.27700000000002`}, {
                    202.43800000000002`, 128.125}, {200.941, 130.984}, {
                    201.105, 127.34}, {197.965, 126.262}, {199.566, 
                    125.31199999999998`}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    198.71099999999998`, 125.07799999999999`}, {
                    197.88700000000003`, 122.617}, {193.105, 127.203}, {
                    192.30100000000002`, 129.69899999999998`}, {
                    195.26999999999998`, 126.75}, {199.305, 
                    127.07799999999999`}, {198.71099999999998`, 
                    125.07799999999999`}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    198.71099999999998`, 125.07799999999997`}, {
                    197.88700000000003`, 122.61699999999999`}, {193.105, 
                    127.203}, {192.30100000000002`, 129.69899999999998`}, {
                    195.26999999999998`, 126.75}, {199.305, 
                    127.07799999999997`}, {198.71099999999998`, 
                    125.07799999999997`}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    196.54299999999998`, 128.848}, {195.605, 126.383}, {
                    189.594, 132.727}, {188.266, 135.781}, {
                    191.23399999999998`, 132.836}, {197.21099999999998`, 
                    130.586}, {196.54299999999998`, 128.848}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    196.54299999999998`, 128.84799999999998`}, {195.605, 
                    126.38300000000001`}, {189.594, 132.72700000000003`}, {
                    188.266, 135.78100000000003`}, {191.23399999999998`, 
                    132.836}, {197.21099999999998`, 130.586}, {
                    196.54299999999998`, 128.84799999999998`}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    195.35200000000003`, 132.54299999999998`}, {194.414, 
                    129.742}, {187.879, 137.207}, {186.02700000000002`, 
                    139.85200000000003`}, {189.14499999999998`, 136.941}, {
                    196.059, 134.578}, {195.35200000000003`, 
                    132.54299999999998`}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    195.35200000000003`, 132.54299999999998`}, {194.414, 
                    129.742}, {187.879, 137.20700000000002`}, {
                    186.02700000000002`, 139.852}, {189.14499999999998`, 
                    136.941}, {196.059, 134.57799999999997`}, {
                    195.35200000000003`, 132.54299999999998`}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    195.14499999999998`, 135.312}, {197.445, 135.758}, {
                    195.012, 137.676}, {192.191, 140.79299999999998`}, {
                    192.062, 137.512}, {192.598, 135.21899999999997`}, {
                    195.14499999999998`, 135.312}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    195.14499999999998`, 135.31199999999998`}, {197.445, 
                    135.758}, {195.012, 137.676}, {192.191, 140.793}, {
                    192.062, 137.51199999999997`}, {192.598, 135.219}, {
                    195.14499999999998`, 135.31199999999998`}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{191.266, 
                    137.176}, {192.258, 138.258}, {190.312, 
                    138.71899999999997`}, {187.90200000000002`, 
                    141.42200000000003`}, {187.547, 139.602}, {190.137, 
                    136.262}, {191.266, 137.176}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{191.266, 
                    137.176}, {192.258, 138.258}, {190.312, 138.719}, {
                    187.90200000000002`, 141.422}, {187.547, 
                    139.60199999999998`}, {190.137, 136.262}, {191.266, 
                    137.176}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    202.39800000000002`, 125.016}, {203.66, 124.277}, {204.52,
                     126.859}, {202.953, 129.195}, {202.594, 
                    126.66799999999999`}, {201.24599999999998`, 125.965}, {
                    202.39800000000002`, 125.016}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    202.39800000000002`, 125.01599999999999`}, {203.66, 
                    124.27700000000002`}, {204.52, 126.85900000000001`}, {
                    202.953, 129.195}, {202.594, 126.66799999999998`}, {
                    201.24599999999998`, 125.965}, {202.39800000000002`, 
                    125.01599999999999`}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{175.047, 
                    141.297}, {172.375, 139.691}, {168.125, 146.09}, {
                    166.99200000000002`, 148.72299999999998`}, {169.34, 
                    145.69899999999998`}, {175.555, 142.941}, {175.047, 
                    141.297}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{175.047, 
                    141.29700000000003`}, {172.375, 139.691}, {168.125, 
                    146.09}, {166.99200000000002`, 148.723}, {169.34, 
                    145.69899999999998`}, {175.555, 142.941}, {175.047, 
                    141.29700000000003`}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    177.32000000000002`, 137.566}, {175.84, 
                    135.92600000000002`}, {171.184, 140.383}, {169.566, 
                    142.641}, {172.062, 140.48000000000002`}, {
                    177.97299999999998`, 140.22299999999998`}, {
                    177.32000000000002`, 137.566}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    177.32000000000002`, 137.566}, {175.84, 
                    135.92600000000002`}, {171.184, 140.383}, {169.566, 
                    142.641}, {172.062, 140.48}, {177.97299999999998`, 
                    140.223}, {177.32000000000002`, 137.566}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    179.85500000000002`, 134.22299999999998`}, {
                    179.36700000000002`, 131.984}, {172.57, 137.02}, {
                    170.98000000000002`, 139.406}, {173.914, 
                    136.64499999999998`}, {180.30100000000002`, 136.895}, {
                    179.85500000000002`, 
                    134.22299999999998`}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    179.85500000000002`, 134.223}, {179.36700000000002`, 
                    131.984}, {172.57, 137.01999999999998`}, {
                    170.98000000000002`, 139.406}, {173.914, 
                    136.64499999999998`}, {180.30100000000002`, 136.895}, {
                    179.85500000000002`, 134.223}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{178.816, 
                    131.80100000000002`}, {177.766, 129.781}, {172.238, 
                    134.781}, {170.914, 137.39100000000002`}, {174.289, 
                    134.441}, {179.672, 133.797}, {178.816, 
                    131.80100000000002`}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{178.816, 
                    131.80100000000002`}, {177.766, 129.78100000000003`}, {
                    172.238, 134.78100000000003`}, {170.914, 
                    137.39100000000002`}, {174.289, 134.441}, {179.672, 
                    133.79700000000003`}, {178.816, 131.80100000000002`}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{175.977, 
                    141.625}, {177.71899999999997`, 143.465}, {176.977, 
                    144.324}, {175.707, 147.22299999999998`}, {175.012, 
                    144.24599999999998`}, {173.961, 143.059}, {175.977, 
                    141.625}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{175.977, 
                    141.625}, {177.71899999999997`, 143.465}, {176.977, 
                    144.324}, {175.707, 147.223}, {175.012, 144.246}, {
                    173.961, 143.059}, {175.977, 141.625}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{178.289, 
                    138.15200000000002`}, {181.453, 138.012}, {
                    178.32000000000002`, 141.863}, {177.57, 145.094}, {
                    177.844, 141.41}, {176.758, 138.504}, {178.289, 
                    138.15200000000002`}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{178.289, 
                    138.152}, {181.453, 138.01199999999997`}, {
                    178.32000000000002`, 141.863}, {177.57, 145.094}, {
                    177.844, 141.41}, {176.758, 138.504}, {178.289, 
                    138.152}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{180.305, 
                    135.098}, {182.496, 135.59}, {181.863, 138.695}, {180.184,
                     142.44899999999998`}, {180.531, 138.39100000000002`}, {
                    178.32800000000003`, 136.047}, {180.305, 
                    135.098}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{180.305, 
                    135.09799999999998`}, {182.496, 135.59}, {181.863, 
                    138.695}, {180.184, 142.44899999999998`}, {180.531, 
                    138.39100000000002`}, {178.32800000000003`, 136.047}, {
                    180.305, 135.09799999999998`}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{179.559, 
                    128.961}, {178.73399999999998`, 126.49600000000001`}, {
                    172.5, 132.20299999999997`}, {171.508, 134.363}, {174.66, 
                    131.71499999999997`}, {180.117, 130.809}, {179.559, 
                    128.961}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{179.559, 
                    128.961}, {178.73399999999998`, 126.49600000000001`}, {
                    172.5, 132.203}, {171.508, 134.363}, {174.66, 131.715}, {
                    180.117, 130.809}, {179.559, 128.961}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{183.297, 
                    125.113}, {182.359, 122.648}, {175.824, 127.645}, {
                    173.824, 130.36700000000002`}, {177.762, 127.27}, {
                    183.777, 127.55499999999999`}, {183.297, 
                    125.113}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{183.297, 
                    125.11299999999997`}, {182.359, 122.64799999999997`}, {
                    175.824, 127.64499999999998`}, {173.824, 
                    130.36700000000002`}, {177.762, 127.27000000000001`}, {
                    183.777, 127.555}, {183.297, 125.11299999999997`}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{187.105, 
                    121.23}, {186.055, 117.79700000000001`}, {
                    179.22299999999998`, 123.281}, {177.184, 125.965}, {
                    181.535, 122.645}, {187.66, 123.67599999999999`}, {
                    187.105, 121.23}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{187.105, 
                    121.23000000000002`}, {186.055, 117.79700000000003`}, {
                    179.22299999999998`, 123.28100000000003`}, {177.184, 
                    125.965}, {181.535, 122.64499999999998`}, {187.66, 
                    123.67599999999999`}, {187.105, 121.23000000000002`}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{180.68, 
                    130.055}, {182.535, 129.094}, {183.285, 134.363}, {
                    182.238, 138.08200000000002`}, {182.254, 134.023}, {
                    178.516, 131.008}, {180.68, 130.055}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{180.68, 
                    130.055}, {182.535, 129.094}, {183.285, 134.363}, {
                    182.238, 138.082}, {182.254, 134.023}, {178.516, 
                    131.00799999999998`}, {180.68, 130.055}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{183.848, 
                    125.871}, {186.078, 125.21100000000001`}, {185.371, 
                    130.88700000000003`}, {183.465, 134.57}, {
                    183.21899999999997`, 130.92200000000003`}, {
                    181.57399999999998`, 127.45700000000001`}, {183.848, 
                    125.871}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{183.848, 
                    125.87100000000001`}, {186.078, 125.21100000000001`}, {
                    185.371, 130.88700000000003`}, {183.465, 134.57}, {
                    183.21899999999997`, 130.922}, {181.57399999999998`, 
                    127.45700000000002`}, {183.848, 125.87100000000001`}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{187.809, 
                    121.953}, {190.30100000000002`, 121.812}, {188.586, 
                    126.82}, {186.531, 129.641}, {186.879, 
                    125.95700000000001`}, {185.71899999999997`, 
                    122.37899999999999`}, {187.809, 121.953}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{187.809, 
                    121.953}, {190.30100000000002`, 121.81199999999998`}, {
                    188.586, 126.82}, {186.531, 129.641}, {186.879, 
                    125.95700000000002`}, {185.71899999999997`, 
                    122.37899999999999`}, {187.809, 121.953}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{183.441, 
                    119.816}, {182.691, 118.54700000000001`}, {180.859, 
                    120.895}, {177.85200000000003`, 122.60499999999999`}, {
                    180.555, 121.898}, {183.77299999999997`, 120.992}, {
                    183.441, 119.816}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{183.441, 
                    119.816}, {182.691, 118.547}, {180.859, 
                    120.89500000000001`}, {177.85200000000003`, 
                    122.60499999999999`}, {180.555, 121.898}, {
                    183.77299999999997`, 120.99199999999999`}, {183.441, 
                    119.816}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{182.016, 
                    162.008}, {184.34, 163.727}, {182.566, 166.945}, {182.016,
                     170.008}, {181.26999999999998`, 167.105}, {179.297, 
                    163.297}, {182.016, 162.008}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{182.016, 
                    162.00799999999998`}, {184.34, 163.72700000000003`}, {
                    182.566, 166.945}, {182.016, 170.00799999999998`}, {
                    181.26999999999998`, 167.105}, {179.297, 
                    163.29700000000003`}, {182.016, 162.00799999999998`}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    181.93800000000002`, 157.71899999999997`}, {178.441, 
                    158.141}, {178.969, 162.656}, {178.863, 165.52}, {179.914,
                     161.63299999999998`}, {182.777, 160.977}, {
                    181.93800000000002`, 
                    157.71899999999997`}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    181.93800000000002`, 157.719}, {178.441, 158.141}, {
                    178.969, 162.656}, {178.863, 165.51999999999998`}, {
                    179.914, 161.63299999999998`}, {182.777, 160.977}, {
                    181.93800000000002`, 157.719}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    182.48800000000003`, 158.305}, {185.441, 158.477}, {
                    185.285, 161.836}, {185.445, 165.238}, {183.945, 
                    162.11299999999997`}, {182.172, 161.629}, {
                    182.48800000000003`, 158.305}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    182.48800000000003`, 158.305}, {185.441, 158.477}, {
                    185.285, 161.836}, {185.445, 165.238}, {183.945, 
                    162.11299999999997`}, {182.172, 161.629}, {
                    182.48800000000003`, 158.305}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    182.36700000000002`, 154.129}, {180.07, 153.945}, {
                    178.875, 156.20299999999997`}, {178.348, 
                    159.72299999999998`}, {180.52700000000002`, 
                    156.48000000000002`}, {182.512, 157.48800000000003`}, {
                    182.36700000000002`, 154.129}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    182.36700000000002`, 154.129}, {180.07, 153.945}, {
                    178.875, 156.203}, {178.348, 159.723}, {
                    180.52700000000002`, 156.48}, {182.512, 157.488}, {
                    182.36700000000002`, 154.129}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{183.191, 
                    154.406}, {186.148, 154.02700000000002`}, {185.676, 
                    157.469}, {185.555, 160.004}, {184.65200000000002`, 
                    157.586}, {182.24599999999998`, 156.824}, {183.191, 
                    154.406}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{183.191, 
                    154.406}, {186.148, 154.02700000000002`}, {185.676, 
                    157.469}, {185.555, 160.004}, {184.65200000000002`, 
                    157.586}, {182.24599999999998`, 156.824}, {183.191, 
                    154.406}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{178.586, 
                    155.863}, {178.82000000000002`, 153.617}, {180.238, 
                    149.758}, {182.523, 150.625}, {183.469, 153.383}, {
                    180.516, 153.934}, {178.586, 155.863}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{178.586, 
                    155.863}, {178.82000000000002`, 153.617}, {180.238, 
                    149.758}, {182.523, 150.625}, {183.469, 153.383}, {
                    180.516, 153.934}, {178.586, 155.863}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{183.23, 
                    150.383}, {182.207, 152.35500000000002`}, {185.555, 
                    153.34}, {186.266, 155.89800000000002`}, {186.672, 
                    152.23399999999998`}, {186.33200000000002`, 
                    149.83200000000002`}, {183.23, 150.383}}}]}}}}}}}, {{{{{{{
                    
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{183.23, 
                    150.383}, {182.207, 152.35500000000002`}, {185.555, 
                    153.34}, {186.266, 155.898}, {186.672, 152.234}, {
                    186.33200000000002`, 149.832}, {183.23, 150.383}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    173.70299999999997`, 173.727}, {175.54299999999998`, 
                    175.71099999999998`}, {173.918, 178.85200000000003`}, {
                    173.36700000000002`, 181.914}, {172.621, 179.012}, {
                    171.324, 175.164}, {173.70299999999997`, 
                    173.727}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    173.70299999999997`, 173.72700000000003`}, {
                    175.54299999999998`, 175.711}, {173.918, 178.852}, {
                    173.36700000000002`, 181.914}, {172.621, 
                    179.01199999999997`}, {171.324, 175.164}, {
                    173.70299999999997`, 173.72700000000003`}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{173.648, 
                    170.039}, {170.418, 169.71099999999998`}, {169.637, 
                    176.285}, {169.305, 179.10899999999998`}, {
                    170.35500000000002`, 175.22299999999998`}, {174.078, 
                    173.445}, {173.648, 170.039}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{173.648, 
                    170.039}, {170.418, 169.711}, {169.637, 
                    176.28500000000003`}, {169.305, 179.10899999999998`}, {
                    170.35500000000002`, 175.223}, {174.078, 173.445}, {
                    173.648, 170.039}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{174.312, 
                    170.105}, {176.594, 171.285}, {176.066, 173.824}, {
                    176.781, 175.73}, {175.24599999999998`, 
                    173.39100000000002`}, {173.848, 173.055}, {174.312, 
                    170.105}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{174.312, 
                    170.105}, {176.594, 171.28500000000003`}, {176.066, 
                    173.824}, {176.781, 175.73000000000002`}, {
                    175.24599999999998`, 173.39100000000002`}, {173.848, 
                    173.055}, {174.312, 170.105}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{173.672, 
                    165.80100000000002`}, {170.29299999999998`, 165.512}, {
                    168.277, 172.789}, {168.172, 175.656}, {
                    169.22299999999998`, 171.766}, {174.066, 169.656}, {
                    173.672, 165.80100000000002`}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{173.672, 
                    165.80100000000002`}, {170.29299999999998`, 
                    165.51199999999997`}, {168.277, 172.78900000000002`}, {
                    168.172, 175.656}, {169.22299999999998`, 
                    171.76600000000002`}, {174.066, 169.656}, {173.672, 
                    165.80100000000002`}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    174.32000000000002`, 165.91}, {177.5, 
                    166.64499999999998`}, {177.117, 168.69899999999998`}, {
                    176.641, 172.02700000000002`}, {175.629, 168.676}, {
                    173.85500000000002`, 169.38700000000003`}, {
                    174.32000000000002`, 165.91}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    174.32000000000002`, 165.91}, {177.5, 
                    166.64499999999998`}, {177.117, 168.69899999999998`}, {
                    176.641, 172.02700000000002`}, {175.629, 168.676}, {
                    173.85500000000002`, 169.38700000000003`}, {
                    174.32000000000002`, 165.91}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    173.63299999999998`, 161.602}, {169.914, 160.969}, {
                    170.176, 166.848}, {167.227, 171.11299999999997`}, {
                    169.777, 167.945}, {174.375, 163.953}, {
                    173.63299999999998`, 161.602}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    173.63299999999998`, 161.60199999999998`}, {169.914, 
                    160.969}, {170.176, 166.84799999999998`}, {167.227, 
                    171.11299999999997`}, {169.777, 167.945}, {174.375, 
                    163.953}, {173.63299999999998`, 161.60199999999998`}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    174.47299999999998`, 161.80100000000002`}, {177.277, 
                    161.71899999999997`}, {177.55100000000002`, 165.941}, {
                    177.395, 167.656}, {176.75, 165.94899999999998`}, {
                    173.453, 164.32800000000003`}, {174.47299999999998`, 
                    161.80100000000002`}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    174.47299999999998`, 161.80100000000002`}, {177.277, 
                    161.719}, {177.55100000000002`, 165.941}, {177.395, 
                    167.656}, {176.75, 165.94899999999998`}, {173.453, 
                    164.328}, {174.47299999999998`, 161.80100000000002`}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{167.824, 
                    166.129}, {169.21899999999997`, 161.605}, {171.195, 
                    157.07}, {173.63299999999998`, 157.414}, {
                    174.80100000000002`, 159.98800000000003`}, {
                    171.32000000000002`, 160.316}, {167.824, 
                    166.129}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{167.824, 
                    166.129}, {169.21899999999997`, 161.605}, {171.195, 
                    157.07}, {173.63299999999998`, 157.414}, {
                    174.80100000000002`, 159.988}, {171.32000000000002`, 
                    160.316}, {167.824, 166.129}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{174.512, 
                    158.078}, {173.48800000000003`, 160.05100000000002`}, {
                    176.836, 161.035}, {177.547, 163.598}, {177.953, 
                    159.934}, {177.61299999999997`, 157.52700000000002`}, {
                    174.512, 158.078}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{174.512, 
                    158.07799999999997`}, {173.48800000000003`, 
                    160.05100000000002`}, {176.836, 161.035}, {177.547, 
                    163.59799999999998`}, {177.953, 159.934}, {
                    177.61299999999997`, 157.52700000000002`}, {174.512, 
                    158.07799999999997`}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{168.785, 
                    160.961}, {170.77299999999997`, 156.88700000000003`}, {
                    171.672, 152.20299999999997`}, {174.40200000000002`, 
                    152.883}, {175.42200000000003`, 156.05100000000002`}, {
                    171.38700000000003`, 156.71499999999997`}, {168.785, 
                    160.961}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{168.785, 
                    160.961}, {170.77299999999997`, 156.88700000000003`}, {
                    171.672, 152.203}, {174.40200000000002`, 152.883}, {
                    175.42200000000003`, 156.05100000000002`}, {
                    171.38700000000003`, 156.715}, {168.785, 160.961}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{174.969, 
                    153.656}, {173.79299999999998`, 155.812}, {
                    177.14499999999998`, 156.57399999999998`}, {177.965, 
                    159.547}, {178.41, 155.656}, {177.99200000000002`, 
                    152.883}, {174.969, 153.656}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{174.969, 
                    153.656}, {173.79299999999998`, 155.81199999999998`}, {
                    177.14499999999998`, 156.57399999999998`}, {177.965, 
                    159.547}, {178.41, 155.656}, {177.99200000000002`, 
                    152.883}, {174.969, 153.656}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{180.695, 
                    181.238}, {182.656, 180.71099999999998`}, {
                    184.71499999999997`, 182.91}, {184., 186.207}, {181.758, 
                    185.648}, {180.73, 183.61299999999997`}, {180.695, 
                    181.238}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{180.695, 
                    181.238}, {182.656, 180.711}, {184.71499999999997`, 
                    182.91}, {184., 186.20700000000002`}, {181.758, 
                    185.64799999999997`}, {180.73, 183.61299999999997`}, {
                    180.695, 181.238}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC0c0HTi08m+qw+uMl36Q7aQ5xuzx5mC6nOszI
E2o+sC/NwTHh6QWl76kODCCwJ82h0Jbr+uI3qQ57SyZLsDxLc5CNSrG+/xgq
z5Hu8LbG3jTuUaqD/l0VtkbFdLj61teBO+Rs0x22nijbN/9XKkRffDrEnG+p
DtUi69wfzkp3KM6Y+LbmdapDEYjenO5w+2dd1p4HqQ4+5p2OCWfTHQxA5u5N
dQCaWmC7Lx3i7jOpDjfPfQ9+vDLd4Q5I/R2o/CSo+rupDiDj7BOh7ruU6vAO
RHulO4Ty6W6aezjVoXc60MMa6Q5hIP7xVAj9O80BPXwAlGyLqw==
                    
                    "]]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC0c0HTi08m+qw+uMl36Q7aQ5xuzx5mC6nOszI
E2o+sC/NwTHh6QWl76kODCCwJ82h0Jbr+uI3qQ57SiZLsDxLc5CNSrG+/xgq
z5Hu8LbG3jTuUaqD/l0VtkbFdLj61teBO+Rs0x22nijbN/9XKkRffLrDXpA5
31IdqkXWuT+cle5QnDHxbc3rVIciEL053eH2z7qsPQ9SHbzNOx0TzqY7GIDM
3ZvqADS1wHZfOsTdZ1Idbp77Hvx4ZbrDHZD6O1D5SVD1d1MdQMbZJ0LddynV
4R2I9kp3COXT3TT3cKpD33SghzXSHcJA/OOpEPp3mgN6+AAAkxSLqg==
                    
                    "], CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4thdnjxM4hkO++dL6d91SXWYkSfUfOBfukPG
xLc19oqpEPpsugNYnXmqQxyI/pzuwAACGakON899D34smOEQzqe7aW5/qsPe
kskSLHYZEPkNUP2OGQ6LXLd9/nsj1cFyy4myfc5Q+3jSHLiuLy6wTcpwsAKJ
R6dB9NdlQMTL0hy2AoXnz8qA0JPSHMJA9uzOgLgzKw1i7pwMB5moFOv74VD1
VRkOws0HTi10THNY9fGSb1JKhsM3jZj+Q09THVpfB+6QS81wuKh0+2fdoVQH
WZC+5AwHVbbGqc5A94PdZZDhwA2yPyvVAT18ADOmhG0=
                    
                    "]]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4thdnjxM4hkO++ZL6d91SXWYkSfUfOBfukPG
xLc19oqpEPpsukMcSJ15KoT+nO7AAAIZqQ43z30PfiyY4RDGp7tpbn+qw96S
yRIsdhkQ+Q1Q/Y4ZDotdt33+eyPVwXLLibJ9zlD7eNIcuK4vLrBNynCwAolH
p0H012VAxMvSHLYChefPynAASc+flAaxZ3cGxJ1ZaQ6LQObOyXCQjUqxvh8O
VV+V4SDcfODUQsc0h1UfL/kmpWQ4fNWI6T/0NNWh9XXgDrnUDIcLSrd/1h1K
hehLznBQZWuc6gx0/36Quwyg9melOqCHDwAx7oRo
                    "], 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4hl5Qs0HTqU7cF1fXGBbl+pwUen2z7pN6Q6X
QHRUqoNsVIr1/e50B1W2xqnO+akO3zRi+g8tTHfonQ7UuCLV4Zi3eafjlnSH
x0tnH1G4kAoxZ1u6Q8bEtzX2jGkO1SLr3B/CzJdLcwjj090093m6AzeI75Xm
sOrjJd8kiQyIurw0iDkmGQ4gYxM60xyArsjaE5ABsXdpGsTejAyHdzX2pnFd
aRBz/TIc1A051sgUpTm8BYnrZUDEg9IcrLacKNvHneGwFUjN10pzKLAFyvxI
d+gDmcMDNf9KOkT/pVSI+U/SHUJB7lyc6oAePgBisIf1
                    
                    "]]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4hl5Qs0HTqU7cF1fXGBbl+pwUen2z7pN6RA6
KtVBNirF+n53uoMqW+NU5/xUh28aMf2HFqY79E0HalyR6nDM27zTcUu6w+Ol
s48oXEiFmLMt3SFj4tsae8Y0h2qRde4PYebLpTmE8elumvscyvdKc1j18ZJv
kkQGRF1eGsQckwwHH6CxCZ1pDkBXZO0JyHD4CrJ3aZpDL8jejAyHdzX2pnFd
aRBz/DIc1A051sgUpTm8BYnrZUDEg9IcrLacKNvHneEAouZrpTkU2AJlfkDd
zwM1/0o6RP+lVIj5T9IdQkHuXJzqgB4+AGGgh/M=
                    "], 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYCYsstJ8r2mac5TM8Taj5gluawf76U/l2TNIdV
Hy/5JrGkORjcVWFrjE1zOO5t3un4I9UhjE9309zoNIeMiW9r7B3THG6e+x78
OBKqrjfNQTYqxfq+cpqDKlvjVOfLaQ6LXLd9/usC5bunOwB1mcaFpTkwgEBD
ugPI+vlA/uOls48ovEiH0D5pDhMOfdWIkc9wqBZZ5/7QKc2B6/riAtuwDIj5
0mkQc4wyHLaC9GulQdzFnuEQt8uTh8k6zUHdkGONzLV0iLh6moNjwtMLSuXp
Dk4gGqi/H2Q+0D1AX59a+DUV4r89aQ4u3TnPf1umOfSCAqQizQE9fAAfS4EP

                    "]]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYCYsstJ8r2mac5zMgTaj5gluawf76U/l2TNIdV
Hy/5JrGkORjcVWFrjE1zOO5t3un4I9UhjE9309zoNIeMiW9r7B3THG6e+x78
ODLNQR+krjfNQTYqxfq+cpoDkDfV+XKawyLXbZ//uqQ5qIH47ukOQF2mcWFp
Dgwg0JDuALJ+PpD/ZOnsIwov0h0eg2ifNIcJh75qxMhnOFSLrHN/6JTmwHV9
cYFtWAbEfOk0h3cgc4wyHLaC9GulQdzFnuEQt8uTh8k6zUHdkGONzLV0iLh6
moNTwtMLSuXpEFoaaj7QPUBfn1r4NRXivz1pDi7dOc9/W6Y59E0HBkhFmgN6
+AAAITuBFQ==
                    "], CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4rc19qZxy9IcMiYCWb7pDr3T84SaF6Q5xO3y
5GGST4eIV6Y5zAAKH5BKdyiw5bq+uCXN4bi3eadjTLqDuiHHGpm+NAcQN2Fi
uoPVlhNl+/qh5u1EqAeb+yTdwQekrjTN4ZLS7Z91UhkQuirNASR9oCzD4ea5
78GPW9McWl8H7pCbm+Ggf1eFrXFimsM3jZj+Q0czHGSiUqzvb09z2FsyWYJl
XYaDJci+5WkOQFsKbPsyIOLToO7JzHBY5Lrt898paQ53ftZl7ZHJgLhrYRpE
/AfUfxvTHB4vnX1E4Ui6w/75Uvp310DNr0t3gIUP2N3A8AEAehyKbA==
                    
                    "]]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4rc19qZxy9IcMiYCWb7pDr3T84SaF6Q5xO3y
5GGST4eIV6Y5zAAKH5BKdyiw5bq+uCXN4bi3eadjTLqDuiHHGpm+NAcQN2Fi
uoPVlhNl+/rTHDJB+nYi1IPNfZLu4ANSV5rmcEnp9s86qQwIXQU1vyzD4ea5
78GPW9McWl8H7pCbm+Ggf1eFrXFimsM3jZj+Q0czHGSiUqzvb09z2FMyWYJl
XYaDJci+5WkOQFsKbPsyHPaCxKelQezJzHBY5Lrt898paQ53ftZl7ZHJgPhn
YZrDYpD4D6j/NqY5PF46+4jCkXSH/fOl9O+ugZpfl+4ACx+w/4DhAwB7lIpt

                    "], CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4sdLZx9RkEh1EG4+cGrhzGSH4oyJb2u0Ux0u
Kt3+WdeU7ACW90l1cOnOef57YrLD2xp70zi9VAeQMvuNyQ57SyZLsIilOlwC
qT8F5ctB9V9KdnBMeHpBiR+q/mOyQ+/0PKFmhlSHUD7dTXOFUyDijKkOW06U
7ZuvlgKx/30KRJ99ioMVSOJ+isMFkHlhKRD3nEhx2ApSb5fiwAACN1IcnEDq
tVMcZKNSrO+/htJA88HufZbiMANo7QGmFIi7PqU4rP54yTfpTbLDvvlS+nc5
Uh1unvse/PhoskMRyH7mVIdvGjH9hzZC/Y8UPgCcGY/J
                    
                    "]]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4sdLZx9RkEh1EG4+cGrhzGSH4oyJb2u0Ux0u
KN3+WdeU7ACW90l1cO7Oef57YrLD2xp70zi9VAeQMvuNyQ57SyZLsIilOlwE
qT8F5ctB9V9KdnBMeHpBiR+q/mOyQ+/0PKFmhlSHUD7dTXOFUyDijKkOW0+U
7ZuvlgKx/30KRJ99ioPVFqDE/RSI+WEpEPecSIGot0txYACBG1D12ikOslEp
1vdfQ2mg+WD3PktxmAG09gAT1JxPKQ6rP17yTXqT7LBvvpT+XY5Uh5vnvgc/
PprsUASynznV4ZtGTP+hjVD/I4UPAJkBj8Y=
                    "], 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{185.07, 137.11299999999997`}, {187.023, 
                    136.15200000000002`}, {188.504, 133.754}, {188.602, 
                    131.805}, {188.76999999999998`, 129.555}, {189.09, 
                    127.66}, {190.102, 126.062}, {188.496, 126.508}, {187.727,
                     129.07}, {187.496, 131.523}, {187.266, 134.059}, {
                    185.89800000000002`, 135.16}, {185.07, 
                    137.11299999999997`}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{185.07, 137.11299999999997`}, {187.023, 
                    136.152}, {188.504, 133.75400000000002`}, {188.602, 
                    131.805}, {188.76999999999998`, 129.555}, {189.09, 
                    127.66}, {190.102, 126.06199999999998`}, {188.496, 
                    126.50799999999998`}, {187.727, 129.07}, {187.496, 
                    131.523}, {187.266, 134.059}, {185.89800000000002`, 
                    135.16}, {185.07, 137.11299999999997`}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{189.137, 132.406}, {190.48800000000003`, 
                    129.914}, {192.375, 128.965}, {192.47299999999998`, 
                    127.113}, {192.637, 124.98400000000001`}, {192.797, 
                    124.87899999999999`}, {193.375, 122.785}, {191.785, 
                    123.20700000000001`}, {191.383, 123.348}, {190.953, 
                    126.531}, {190.691, 128.76999999999998`}, {
                    188.89800000000002`, 130.348}, {189.137, 
                    132.406}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{189.137, 132.406}, {190.48800000000003`, 
                    129.914}, {192.375, 128.965}, {192.47299999999998`, 
                    127.11299999999997`}, {192.637, 124.98400000000001`}, {
                    192.797, 124.87899999999999`}, {193.375, 
                    122.78500000000003`}, {191.785, 123.20700000000002`}, {
                    191.383, 123.34799999999998`}, {190.953, 126.531}, {
                    190.691, 128.77}, {188.89800000000002`, 
                    130.34799999999998`}, {189.137, 132.406}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{231.176, 
                    109.34400000000001`}, {231.934, 107.91400000000002`}, {
                    232.805, 105.73400000000001`}, {234.38700000000003`, 
                    106.133}, {234.41, 107.23}, {232.68, 107.988}, {231.176, 
                    109.34400000000001`}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    233.52700000000002`, 108.85499999999999`}, {236.598, 
                    107.598}, {239.24599999999998`, 107.91000000000001`}, {
                    239.57399999999998`, 105.98}, {236.69899999999998`, 
                    105.66799999999999`}, {235.64499999999998`, 
                    106.85199999999999`}, {233.52700000000002`, 
                    108.85499999999999`}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{220.68, 119.008}, {222.74599999999998`, 
                    117.316}, {224.086, 115.383}, {224.71099999999998`, 
                    112.887}, {225.363, 110.559}, {226.281, 108.703}, {
                    227.625, 106.613}, {225.434, 108.10499999999999`}, {
                    224.059, 110.141}, {223.36700000000002`, 112.586}, {
                    222.762, 114.992}, {222.05100000000002`, 116.793}, {
                    220.68, 119.008}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{223.22299999999998`, 119.016}, {
                    225.43800000000002`, 117.24600000000001`}, {
                    227.52700000000002`, 115.242}, {228.15200000000002`, 
                    112.742}, {228.805, 110.418}, {229.19899999999998`, 
                    108.637}, {230.691, 106.324}, {228.35200000000003`, 
                    107.816}, {227.42200000000003`, 110.074}, {
                    226.73399999999998`, 112.52}, {226.129, 114.926}, {
                    224.742, 116.727}, {223.22299999999998`, 119.016}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4tbXgTvkLuY4NB84tdDVL8ZBla1xqvP5HAeu
64sLbLNiHG79rMvacyPHYUaeUPOBphiHY97mnY5Pchycu3Oe/+6Mcdh6omzf
/F9Q+VkxDotct33+K5Dr0DsdKLAixsEx4ekFJfVch4Ug8S0xDqs+XvJNcsh1
kNa/q8J2MMbhotLtn3V+uRB9c6DmAfkZE9/W2LfGQMwF8r9pxPQfio1xCOfT
3TTXP9dBdJ37wyobhHovHibtdrkYiD7fXAegaVcqfkY7CIM85pnrIAfy6Ldo
h5vnvgc/toXa/zHaIW6XJ1BnrgPIuQdeRUPsE8p18EsSiLB8Eu1gtQVowf8c
h1iQutPRDrdB4fEhB+K/HdGQcHqU4wD05e2fx6D6b+U4FIMc8hxq39Uch+Og
cGOAhu/lHIj9hjEO6OEPAG3WvnI=
                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4oyJb2vsH+Y6NB84tdDVL8YhbpcnD9PjXAeu
64sLbLNiHML4dDfNvZ3rsNB12+e/LTEO3uadjgkXcx1E1rk/rOqJcfAB8ffm
OmSCzJkb46B/V4WtcWWuw8MqoIqFMQ690/OEmqfkOhSDLJof49D6OnCHXG2u
w3GQQQtiHFTZGqc6l+c6fNOI6T80NcbBMeHpBSUgf2/JZAmWuhiHWJB7gHw5
kMawGIi7ynIh5hog1M8Acg8IxTis+njJN6ki18EA5I630Q4MIADkg5QfeBXt
cFHp9s+6plwHsL+fRjv0H/qqETM510EeZP69aIi7NuQ6LAL59040xL0Hcx02
zX2//NjhaIetJ8r2zT8H9d/GaIg77+VC7DkAlb8Hdc+jaAegLaZx96Dm/YmG
hMP9XAdpUEAZxjighz8ADGG3Xg==
                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4p1yra8DlQod9s2X0r8bkerweOnsIwpGhQ5h
fLqb5nanOixy3fb5r0uhw0Wl2z/rhFIdGECgrdDhuLd5p+OOFIdjIHpJoYNj
wtMLSv0pDlEp1vf9dxY66N9VYWtUTIHQQH7GxLc19jeTIebsKnSw3HKibN/y
ZIfpeULNB7YVOnBdX1xgW5YMVw/muyVD9O0uhNirkewwWYIljO90oUOBLVDF
kySI/QcKHfoPfdWIuZzk4P6wSmTdYqh/ViQ5gKyZX1fosOrjJd8kjyQHA5D5
uYUOsbs8eZjUofJxhRB/8iQ5WIEEAgsdfIDGJqyFyrsVOgBDaYfc1ySHZcDg
2WBV6KBuyLFGxikZ4i6HQoe9JUCXzUt2yHn+e+VHOaj6p8kOIGcWsEP5otDw
OlMAoV1SHKpF1rk/vFTgINx84NTCyBQHAD+Yrl4=
                    
                    "]]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4p1yra8DlQod9s+X0r8bkerweOnsIwpGhQ5h
fLqb5nanOixy3fb5r0uhwwWl2z/rhFIdGECgrdDhuLd5p+OOFIdjIHpJoYNj
wtMLSv0pDlEp1vf9dxY66N9VYWtUTIHQQH7mxLc19jeTHS6CzNlV6GC55UTZ
vuXJDtPzhJoPbCt04Lq+uMC2LBmuHsx3S3bIAOnbXQixVyPZYbIESxjf6UKH
AlugiidJEPsPFDr0H/qqEXM5ycH9YZXIusVQ/6xIcgBZM7+u0GHVx0u+SR5J
DgYg83MLHeJ2efIwqUPl4woh/uRJcrACCQQWOoCMTVgLlXcrdACG0g65r0kO
y4DBs8Gq0EHdkGONjFMyxF0OhQ57SoAum5fskPP898qPclD1T5MdQM4sYIfy
RaHhdaYAQrukOFSLrHN/eKnAQbj5wKmFkSkOAEFwrl8=
                    "], 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0.74902, 0., 0.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGI9IGYCYuHmA6cWqhY6yEalWN8/n+xw+KtGTL9WocMF
pds/654lQ8QNCx32lkyWYPmX7NDpmPD0glWhA9f1xQW2QikOlltOlO1zhqpX
S3F4W2NvGudX6BDGp7tprnmKw6dLvkkCUVDz7VMcQJR/aqHDcW/zTkePFIh5
BYUOTkBKKRjKryh0AFFK6VB+TaHDItdtn/8WpDjskGt9HdhQ6AB2d22KAwMI
NBU6FNoCXdST4iAEEm8udNgKdNb8WQg+2D2rUxwe+PdOz2uCmr8/xUGrXezm
uWao+XtSHA6B/N9S6DAjD6hzF9T8tkKHApD5O1IcjoHcvaTQoThj4tua/hQH
kHDBTqh7FFMgNJCvf1eFrfFmMkT/Lij/aDIkPIB8dUOONTKbkuHqweE5L9kB
ZHzC9kKHm+e+Bz+emOwAssZ+a6HDN6CzDrVCzdsEVV8HjZ+1hQ5AXwk1lyQ7
VIusc3+4AhpfeckQ/y+G2p+Z7AAUDeObCVWfkOyQ+/z3yo890PCKg7qnEWp+
WLIDKNjel0LN84PyM6HxZQ01Px4aPirJDtqg8AwtdFBla5zqzJ8MCS9gegAl
k/nfkiD+8YTG14MkSHrxKHSoArn7GVTevdDh8dLZRxQ+JDncB8WXG9T9X5Mg
9lkj7DcAidtC01MP1P1I6RkA3wVEIA==
                    "]]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGI9IGYCYuHmA6cWqhY6yEalWN8/n+xw+KtGTL9WocNF
pds/654lQ8QNCx32lEyWYPmX7NDpmPD0glWhA9f1xQW2QikOlltOlO1zhqpX
S3F4W2NvGudX6BDGp7tprnmKw6dLvkkCUVDz7VMcQJR/aqHDcW/zTkePFIh5
BYUOIEopGMqvKHRwAvHTofyaQodFrts+/y1Icdgh1/o6sKHQAezu2hQHBhBo
KnQotAW6qCfFQQgk3lzoAHLW/FkIPtg9q1McHvj3Ts9rgtq3P8VBq13s5rlm
qPl7UhwOgfzfUugwIw+ocxfU/Dao+TtSHI6B3L2k0KE4Y+Lbmv4UB5BwwU6o
exRTIDSQb3BXha3xZjJE/65CBz0Q/2gyJDyAfHVDjjUym5Lh6sHhOS/ZAWR8
wvZCh5vnvgc/npjsALLGfmuhA8hZh1qh5m2Cqq+Dxs/aQgegr4SaS5IdqkXW
uT9cAY2vvGSI/xdD3ZOZ7AAUDeObCVWfkOyQ+/z3yo89hQ5bQeEVB3VPI9T8
sGQHULC9L4Wa5wflZ0LDzxpqfnyhQwEoIFSSHbRB4Rla6KDK1jjVmT8ZEl5+
UPO/JUH84wlV/yAJkl48CiHufgaVdy90eLx09hGFD0kO90Hx5QYNv69JEPus
EfaD/WULTU89UPcjpWcA3r1EHQ==
                    "], 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    280.14500000000004`, 166.09}, {280.53099999999995`, 
                    163.402}, {279.03499999999997`, 162.51199999999997`}, {
                    277.625, 161.988}, {276.16400000000004`, 
                    161.47299999999998`}, {274.969, 159.906}, {
                    274.35200000000003`, 158.488}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{283.762, 
                    157.246}, {283.14500000000004`, 154.934}, {
                    281.52299999999997`, 155.223}, {280.10900000000004`, 
                    154.703}, {278.65200000000004`, 154.184}, {277.113, 
                    152.336}, {276.5, 150.922}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    275.512, 172.414}, {274.77299999999997`, 
                    172.89100000000002`}, {260.57, 148.97299999999998`}, {
                    261.309, 148.496}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    275.512, 172.414}, {274.77299999999997`, 
                    172.89100000000002`}, {260.57, 148.97299999999998`}, {
                    261.309, 148.496}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{273.984, 173.36700000000002`}, {273.984, 
                    172.512}, {274.76599999999996`, 171.73}, {275.621, 
                    171.73}, {276.477, 171.73}, {277.258, 172.512}, {277.258, 
                    173.36700000000002`}, {277.258, 174.227}, {276.477, 
                    175.004}, {275.621, 175.004}, {274.76599999999996`, 
                    175.004}, {273.984, 174.227}, {273.984, 
                    173.36700000000002`}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{273.984, 173.36700000000002`}, {273.984, 
                    172.51199999999997`}, {274.76599999999996`, 
                    171.73000000000002`}, {275.621, 171.73000000000002`}, {
                    276.477, 171.73000000000002`}, {277.258, 
                    172.51199999999997`}, {277.258, 173.36700000000002`}, {
                    277.258, 174.22700000000003`}, {276.477, 175.004}, {
                    275.621, 175.004}, {274.76599999999996`, 175.004}, {
                    273.984, 174.22700000000003`}, {273.984, 
                    173.36700000000002`}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    256.08599999999996`, 192.586}, {261.84, 192.586}, {261.84,
                     191.26600000000002`}, {256.08599999999996`, 
                    191.26600000000002`}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    256.08599999999996`, 192.58599999999998`}, {261.84, 
                    192.58599999999998`}, {261.84, 191.266}, {
                    256.08599999999996`, 191.266}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    256.08599999999996`, 190.078}, {261.84, 190.078}, {261.84,
                     179.055}, {256.08599999999996`, 
                    179.055}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    256.08599999999996`, 190.07799999999997`}, {261.84, 
                    190.07799999999997`}, {261.84, 179.05499999999998`}, {
                    256.08599999999996`, 179.05499999999998`}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    262.191, 194.09}, {255.809, 194.05100000000002`}, {
                    255.559, 196.21499999999997`}, {257.719, 198.555}, {
                    258.97999999999996`, 198.531}, {260.227, 198.469}, {
                    262.242, 196.164}, {262.191, 194.09}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    262.191, 194.08999999999997`}, {255.809, 194.051}, {
                    255.559, 196.215}, {257.719, 198.555}, {
                    258.97999999999996`, 198.531}, {260.227, 198.469}, {
                    262.242, 196.164}, {262.191, 194.08999999999997`}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {CompressedData["
1:eJxTTMoPSmViYGBQBmIQvX++lP7dPXkOfdPzhJpzMhxko1Ks7z/Oc3i8dPYR
hZgMh28aMf2HGPMdwvl0N83Vz4CIi+RD1P9Jd7igdPtnnVq+g7d5p2PCyXQH
g7sqbI26+Q6qbI1TnfvTHcDmq+Q79ILUJyD4VltOlO2LT3cQbj5waqEi1Hz/
dIeMiW9r7GXzHRhAwCUdYp8EVL11ukPcLk8eJuF8hyKQQuN0Bx+Qvbz5DluB
0vP1oO5hy4eI66ZD9P2H+kcnHeLOn3kQcf10iP++5kHUm6Y7qBtyrJH5lAex
B2jfcZCGD3kOQFeZxjlB3f8BKu+d7lBgy3V98RcovzrdYdXHS75JQP4lkDtW
pTvsA6l/ATX/KjR87uZBzGXIcAA5Y/4xqPlqGRDz50DVu2ZA6Kl5DtUi69wf
emU4LHLd9vnvhDxIOAVC4wPItwQZFJ4BDfc8B6CrCmzjMiDhMikPEq/JGQ5A
z2rETIeqT89wKAS5f0GeQzHIwPwMhwkg+fV5kHAogroHKX0AAM/u82U=
                    
                    "], CompressedData["
1:eJxTTMoPSmViYGBQAmIQvW++lP7dHXkO3uadjgmJGQ7FGRPf1qzPcwBR9qkZ
Dv2HvmrELM5ziNvlycOUnOFwUen2z7p5UH58hsPjpbOPKMzJc9gPMicmw0E2
KsX6/uw8iDnRCHmw+ZEZDn3T84SagXzHhKcXlMIzHNQNOdbIAM0D2xMMVb8E
ar5/hgMDCFzIcwC6xjRODyr/Is9B/64KWyMrlP8lz6EXZO6NdAifId8hjE93
09zV6RD3/M9zqBZZ5/6wCir/Jw9ir1c6RN3vPIcikHud0x0MQOb+zYP40y7d
YQLIXUD9VltOlO2zTndofR24Q44x32GR67bPfy3SIeYw5UPMtYCaz5IPcQ+Q
z3V9cYEtW74DOJyB/Esgc7nyIeEDNA9sD18+xByndIetQGvmC+U73PpZl7XH
I90BZO18sXxIeASnO3zTiOk/JAlVnwTlK+Y77C2ZLMHSB9Uvle+gytY41fl4
OsReDqh7fqRDwv17nsPNc9+DH2tmOMwACh+4lefgBBIHhj96egAAMkbv9g==

                    "]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, CompressedData["
1:eJxlk1tIVFEUhoeRJEosNCpiNBNN7aYF3YzBZQURpV3EQpvEpFqbsFUR+JAl
iBR0sZJIh2KcLCLSqIgC6TKJBJmIiURZJhERPUQPPVSID7X3Wb8UNHA4HPba
//rW/6+ZU3Vg6544n8/nt89svFdXfh5IrxXKWjzxViDf0NrT1V/G2oR+ZofO
decY8s4fCZ3v/pEd+s30brRu3+Meodppt9d97Gea9ObaweBroW9HC5ZWtDK1
fx8sqhoSOuLO9zKllO9e9eGlUGOLJDWsYDJNtvKF0LbEhfciM5h87tcpqhPP
VOj63RBaeb+nJhbHFLbXulqh72caSB8erWsG3wSm3JGM+PomobNOP4H1fUYo
M77+4ppkVs5TQh2OK8CU5+oboZ+Ffi2Yvxj9Lgm97f9V8ukY+C+Ict9kOv51
S2eqvT/sfHiFc+vfYVcwxurXDviTZKjUzVki6stMo1ybRPukGp2rGPqZhjYu
P1lYWSSqO9/Q0+is3JHN8GeJ0XlLwbvMaJ8K8AaNzrdfKN/NV4D8/snX61cD
vkXQr8a31U9u6Opt24W88gy9d3OG4O8CQ5MdR7nQoMthnlHuMlFfcsBXhvzn
GuUqg18Zhp5vsANaPa9vGniqoB8wmu8J+OM3FHN1YdF7Q/A7Ct52pp0P1yf4
7b54c9u8Htixo1fBU4R9DY/7y+RsiTZDL/D33PNnOvK7PJ4f9iUitN3lOIXp
UNAmcQX1idi/66i3397/5A7ynop9ioEnhdWHZ6jPZ/WhD/vKrL72Is8I+j+B
P32sudwV5bT75s1h+T2utP/z/QOeprBY
                    "]]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    255.73, 170.09}, {262.152, 170.09}, {262.152, 161.203}, {
                    255.73, 161.203}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    255.73, 170.09}, {262.152, 170.09}, {262.152, 161.203}, {
                    255.73, 161.203}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    255.578, 156.121}, {261.777, 156.121}, {261.777, 
                    154.25400000000002`}, {255.57799999999997`, 
                    154.25400000000002`}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    255.578, 156.121}, {261.777, 156.121}, {261.777, 
                    154.25400000000002`}, {255.57799999999997`, 
                    154.25400000000002`}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    255.58200000000002`, 152.84}, {261.93, 152.84}, {261.93, 
                    145.895}, {255.582, 145.895}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    255.58200000000002`, 152.84}, {261.93, 152.84}, {261.93, 
                    145.895}, {255.582, 145.895}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    255.434, 144.47299999999998`}, {262.375, 
                    144.47299999999998`}, {262.375, 140.58999999999997`}, {
                    255.434, 140.58999999999997`}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    255.434, 144.47299999999998`}, {262.375, 
                    144.47299999999998`}, {262.375, 140.58999999999997`}, {
                    255.434, 140.58999999999997`}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    261.52, 157.79299999999998`}, {255.92600000000002`, 
                    157.79299999999998`}, {254.816, 159.641}, {
                    262.52299999999997`, 159.641}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    261.52, 157.793}, {255.92600000000002`, 157.793}, {
                    254.816, 159.641}, {262.52299999999997`, 159.641}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    253.977, 164.602}, {253.92200000000003`, 
                    169.45700000000002`}, {250.07, 169.45700000000002`}, {
                    251.58200000000002`, 168.207}, {252.99200000000002`, 
                    166.695}, {253.977, 164.602}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    253.977, 164.60199999999998`}, {253.92200000000003`, 
                    169.45700000000002`}, {250.07, 169.45700000000002`}, {
                    251.58200000000002`, 168.20700000000002`}, {
                    252.99200000000002`, 166.695}, {253.977, 
                    164.60199999999998`}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4gf+vdPzggocijImvq0JTnHQbhe7eS6wwIHr
+uICW6MUh9hdnjxM9gUOi1y3ff7rgOB/04jpPxSIJt+S4rB09hGFDXYFDn3T
84Sa96Q4uD+sElkHlL/9sy5rz4MUBy2Q+UB+GJ/uprm/oXz5Aod986X0735J
cWAAAYUCh1UfL/kmPUlxkIlKsb4PlG97HbhDbmeKg1DzgVML5aH216Y46N9V
YWsE8uNA7vBOcbDccqJsH5D/tsbeNA7o/k7HhKcXuAocekHuMUlxaAWZw41Q
D/K2PZAfCnJPM4J/89z34MdXEeqLQRL/Uxxyn/9e+RFoHljcNBViPzC8wO42
SXX4BHS2QBDUvwwI/lags+ZfS3GAhbcqW+NU524EHxb+ACCvraM=
                    "], 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    256.59, 152.016}, {261.145, 152.016}, {261.145, 146.34}, {
                    256.59, 146.34}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    256.625, 149.664}, {258.23, 149.664}, {258.23, 148.73}, {
                    256.625, 148.73}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    256.625, 149.664}, {258.23, 149.664}, {258.23, 148.73}, {
                    256.625, 148.73}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    259.465, 149.664}, {261.03099999999995`, 149.664}, {
                    261.03099999999995`, 148.73}, {259.465, 
                    148.73}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    259.465, 149.664}, {261.03099999999995`, 149.664}, {
                    261.03099999999995`, 148.73}, {259.465, 148.73}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    258.22999999999996`, 151.945}, {259.46399999999994`, 
                    151.945}, {259.46399999999994`, 149.629}, {
                    258.22999999999996`, 149.629}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    258.22999999999996`, 151.945}, {259.46399999999994`, 
                    151.945}, {259.46399999999994`, 149.629}, {
                    258.22999999999996`, 149.629}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    258.22999999999996`, 148.76999999999998`}, {
                    259.46399999999994`, 148.76999999999998`}, {
                    259.46399999999994`, 146.30499999999998`}, {
                    258.22999999999996`, 
                    146.30499999999998`}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    258.22999999999996`, 148.77}, {259.46399999999994`, 
                    148.77}, {259.46399999999994`, 146.305}, {
                    258.22999999999996`, 146.305}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{284.809, 
                    208.824}, {284.52299999999997`, 204.371}, {
                    285.90599999999995`, 201.92600000000002`}, {
                    288.26599999999996`, 202.297}, {288.914, 
                    204.76999999999998`}, {287.43399999999997`, 
                    206.42600000000002`}, {284.809, 208.824}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{284.809, 
                    208.824}, {284.52299999999997`, 204.371}, {
                    285.90599999999995`, 201.926}, {288.26599999999996`, 
                    202.297}, {288.914, 204.76999999999998`}, {
                    287.43399999999997`, 206.426}, {284.809, 208.824}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{289.984, 
                    198.953}, {292.082, 200.02}, {290.566, 208.164}, {289.762,
                     211.57399999999998`}, {289.168, 207.18}, {288.172, 
                    200.93}, {289.984, 198.953}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{289.984, 
                    198.95299999999997`}, {292.082, 200.01999999999998`}, {
                    290.566, 208.164}, {289.762, 211.574}, {289.168, 
                    207.18}, {288.172, 200.93}, {289.984, 
                    198.95299999999997`}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    289.23799999999994`, 198.566}, {285.715, 197.344}, {
                    282.92599999999993`, 201.137}, {281.97999999999996`, 
                    205.535}, {284.89099999999996`, 201.52}, {289.625, 
                    201.516}, {289.23799999999994`, 198.566}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    289.23799999999994`, 198.56599999999997`}, {285.715, 
                    197.344}, {282.92599999999993`, 201.137}, {
                    281.97999999999996`, 205.535}, {284.89099999999996`, 
                    201.51999999999998`}, {289.625, 201.516}, {
                    289.23799999999994`, 198.56599999999997`}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    291.90999999999997`, 194.45700000000002`}, {294.668, 
                    195.184}, {293.008, 203.824}, {292.508, 207.281}, {
                    291.902, 203.71099999999998`}, {290., 195.637}, {
                    291.90999999999997`, 
                    194.45700000000002`}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    291.90999999999997`, 194.457}, {294.668, 195.184}, {
                    293.008, 203.824}, {292.508, 207.281}, {291.902, 
                    203.711}, {290., 195.637}, {291.90999999999997`, 
                    194.457}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{290.969, 
                    194.727}, {290.812, 197.707}, {287.84400000000005`, 
                    196.848}, {285.79299999999995`, 198.43800000000002`}, {
                    286.129, 196.94899999999998`}, {287.39099999999996`, 
                    194.309}, {290.969, 194.727}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{290.969, 
                    194.727}, {290.812, 197.707}, {287.84400000000005`, 
                    196.848}, {285.79299999999995`, 198.438}, {286.129, 
                    196.949}, {287.39099999999996`, 194.309}, {290.969, 
                    194.727}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    294.34400000000005`, 190.73399999999998`}, {297.074, 
                    191.47299999999998`}, {295.43399999999997`, 
                    200.76999999999998`}, {295.59, 204.598}, {294.789, 
                    201.29299999999998`}, {292.25, 191.63299999999998`}, {
                    294.34400000000005`, 
                    190.73399999999998`}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    294.34400000000005`, 190.734}, {297.074, 
                    191.47299999999998`}, {295.43399999999997`, 
                    200.76999999999998`}, {295.59, 204.598}, {294.789, 
                    201.293}, {292.25, 191.63299999999998`}, {
                    294.34400000000005`, 190.734}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{293.07, 
                    191.137}, {290.83599999999996`, 190.41}, {287.871, 
                    191.863}, {287.637, 194.52700000000002`}, {289.566, 
                    193.21899999999997`}, {292.641, 194.21899999999997`}, {
                    293.07, 191.137}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{293.07, 
                    191.137}, {290.83599999999996`, 190.41}, {287.871, 
                    191.863}, {287.637, 194.527}, {289.566, 193.219}, {
                    292.641, 194.219}, {293.07, 191.137}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{296.383, 
                    186.63299999999998`}, {298.9959999999999, 
                    186.42200000000003`}, {297.828, 194.344}, {297.824, 
                    201.71899999999997`}, {296.867, 194.824}, {294.25, 
                    188.512}, {296.383, 186.63299999999998`}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{296.383, 
                    186.63299999999998`}, {298.9959999999999, 186.422}, {
                    297.828, 194.344}, {297.824, 201.719}, {296.867, 
                    194.824}, {294.25, 188.51199999999997`}, {296.383, 
                    186.63299999999998`}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    295.47999999999996`, 186.99200000000002`}, {293.715, 
                    186.105}, {290.555, 187.52}, {289.65200000000004`, 
                    190.5}, {292.84000000000003`, 189.117}, {
                    294.97299999999996`, 190.469}, {295.47999999999996`, 
                    186.99200000000002`}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    295.47999999999996`, 186.992}, {293.715, 186.105}, {
                    290.555, 187.51999999999998`}, {289.65200000000004`, 
                    190.5}, {292.84000000000003`, 189.117}, {
                    294.97299999999996`, 190.469}, {295.47999999999996`, 
                    186.992}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{274.977, 
                    204.695}, {275.441, 200.83200000000002`}, {277.02, 
                    198.586}, {279.379, 198.95700000000002`}, {280.027, 
                    201.42600000000002`}, {278.117, 203.008}, {274.977, 
                    204.695}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{274.977, 
                    204.695}, {275.441, 200.832}, {277.02, 
                    198.58599999999998`}, {279.379, 198.957}, {280.027, 
                    201.426}, {278.117, 203.00799999999998`}, {274.977, 
                    204.695}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{281.215, 
                    194.785}, {277.29699999999997`, 194.227}, {275.887, 
                    197.23399999999998`}, {273.25, 201.08200000000002`}, {
                    276.945, 198.406}, {281.363, 197.848}, {281.215, 
                    194.785}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{281.215, 
                    194.785}, {277.29699999999997`, 194.227}, {275.887, 
                    197.23399999999998`}, {273.25, 201.082}, {276.945, 
                    198.406}, {281.363, 197.848}, {281.215, 194.785}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{282.328, 
                    195.22299999999998`}, {284.465, 197.789}, {
                    282.39799999999997`, 201.008}, {280.76599999999996`, 
                    203.75}, {281.117, 199.668}, {279.727, 
                    197.39800000000002`}, {282.328, 
                    195.22299999999998`}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{282.328, 
                    195.223}, {284.465, 197.789}, {282.39799999999997`, 
                    201.00799999999998`}, {280.76599999999996`, 203.75}, {
                    281.117, 199.668}, {279.727, 197.39800000000002`}, {
                    282.328, 195.223}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    283.27299999999997`, 190.99200000000002`}, {283.512, 
                    193.5}, {279.242, 194.055}, {277.309, 
                    195.44899999999998`}, {277.96099999999996`, 194.}, {
                    278.945, 190.102}, {283.27299999999997`, 
                    190.99200000000002`}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    283.27299999999997`, 190.992}, {283.512, 193.5}, {279.242,
                     194.055}, {277.309, 195.449}, {277.96099999999996`, 
                    194.}, {278.945, 190.10199999999998`}, {
                    283.27299999999997`, 190.992}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{284.168, 
                    190.93800000000002`}, {287.121, 191.26999999999998`}, {
                    285.895, 196.285}, {283.777, 199.07}, {284.668, 
                    195.227}, {282.219, 192.55100000000002`}, {284.168, 
                    190.93800000000002`}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{284.168, 
                    190.938}, {287.121, 191.27}, {285.895, 196.285}, {283.777,
                     199.07}, {284.668, 195.227}, {282.219, 192.551}, {
                    284.168, 190.938}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    286.39099999999996`, 186.762}, {289.754, 
                    188.24599999999998`}, {287.59799999999996`, 192.461}, {
                    286.33599999999996`, 194.94899999999998`}, {286.875, 
                    191.684}, {284.18, 189.191}, {286.39099999999996`, 
                    186.762}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    286.39099999999996`, 186.762}, {289.754, 188.246}, {
                    287.59799999999996`, 192.461}, {286.33599999999996`, 
                    194.949}, {286.875, 191.684}, {284.18, 189.191}, {
                    286.39099999999996`, 186.762}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{285.727, 
                    187.15200000000002`}, {283.965, 184.848}, {280.527, 
                    187.84}, {279.82, 191.33200000000002`}, {282.812, 
                    188.84}, {285.02299999999997`, 189.25}, {285.727, 
                    187.15200000000002`}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{285.727, 
                    187.152}, {283.965, 184.84799999999998`}, {280.527, 
                    187.84}, {279.82, 191.332}, {282.812, 188.84}, {
                    285.02299999999997`, 189.25}, {285.727, 187.152}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIZIGYC4gtKt3/WhRU5cF1fXGAbl+rw6ZJvkkBMkQMD
CJxJdZiRJ9R8wKjIoShj4tuayWkQ+YAih70lkyVY/kH5IUUOhbZAE3jSHaJS
rO/7uxc59B/6qhFjnO4AVBXGZ1/kIAuSkE53uFrxUs3QCGrftzSH3Oe/V35U
KXJwSnh6Qak7zcHbvNMxQb4IYu+mNAf9uypsjZJFDt80YvoP3U1z2HKibN98
CShfM91BcQPQZaxFDr3TgRos0h1Azij4WejQ+jpwh5xjusMxkIEvCh2qRNa5
P3RLh9j3phDiXoV0B+HmA6cWfiyEuO93GsTff6D6T6Y5gMPnQyHEvqNpDlYg
B7yEqj8Mlb9W6CAD4n9Pg9h3DCrPnw4xZ2ehgw/IX6pQ+5YWOliCzGFOh/hz
R6FDKJ/uprmP0xxid3nyMH0vdFj9ERiwNWkOoGC3Ny5yuHnue/Bj3zQHULD2
I8UXAIuTyOo=
                    "]]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIZIGYC4gtKt3/WhRU5cF1fXGAbl+rw6ZJvkkBMkQMD
CJxJdZiRJ9R8wKjIoShj4tuayWkQ+YAihz0lkyVY/kH5IUUOhbZAE3jSHaJS
rO/7uxc59B/6qhFjnO4AVBXGZ1/kIAuSkE53uFrxUs3QCGrftzSH3Oe/V35U
KXJwTHh6Qak7zcHbvNMxQb4IYu+mNAf9uypsjZJFDt80YvoP3U1z2HKibN98
CShfM91BcQPQZaxFDn3TgRos0h1Azij4WejQ+jpwh5xjusMxkIEvCh2qRda5
P3RLh9j3ptChAKRQId1BuPnAqYUfCyHu+50G8fefQoc2kP6TaQ7g8PlQ6PAV
ZN/RNAcrkANeQtUfhspfg/K/p0HsOwbl86dD3LGzEOIvVah9SwsdLEHmMKdD
/Lmj0CGUT3fT3MdpDrG7PHmYvhc6rP4IDNiaNAdQsNsbFzncPPc9+LFvmgMo
WPuR4gsAigvI6Q==
                    "], CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIZIGYC4mPe5p2Ox4ocRNa5P6y6EuuguKEoY+LZIgeX
7pznv2/GOiiA+NeLHNrFbp77/jjW4YLS7Z9154ocPHmYtNu3xTpogyRaixx6
p+cJNQfEOMwAUgcKihy+acT0H3ob7QASPsBW5MAAAgoxDkBbRNbNLoSoj4hx
uFrxUs2wqdDBL0kgwvJMjEP5vvlS+uaFEPeUxEL4/IUOF0H2Xop12HKibN/8
KwUOxRkT39Y8j3UAu39FgUMmkGu/FureyQUOXNcXF9hOinWYLMESxtdeALFv
QqyDbFSK9f2pBQ6b5r5ffux0rMPS2UcUNiwpcHgK8hhbHMQ92wocLEEWhcc5
3PcH6jxR4LBGBqixP85hh1zr68APBQ419qZxuzjjHT5d8k0SMCl0eAbSbxfv
ADLeP7sQ4j7xeAdbkEN2FkLC61kcJBx+QeXl4xyApu2Qcy+C+B8Y/uDwyS+C
2Lc+1uExyIFzihyAvs/aswXqX6T4AgDJDcnj
                    "]]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIZIGYC4mPe5p2Ox4ocRNa5P6y6EuuguKEoY+LZIgeX
7pznv2/GOiiA+NeLHNrEbp77/jjW4YLS7Z9154ocvHiYtNu3xTpotwMlWosc
+qbnCTUHxDjMAFIHCoocvmnE9B96G+0AEj7AVuTAAAIKMQ5AW0TWzS6EqI+I
cbha8VLNsKnQwS9JIMLyTIxD+b75UvrmhRD3lMRC+PyFDpdA9l6Kddhyomzf
/CsFDkBXva15HusAdv+KAocsINd+LdS9kwsceK4vLrCdFOswWYIljK+9AGLf
hFgH2agU6/tTCxw2zX2//NjpWIels48obFhS4PAE5DG2OIh7thU4WIEsCo9z
uO/fOz3vRIHDGhmgxv44hx1yra8DPxQ41Nibxu3ijHf4dMk3ScCk0OEZSL9d
vAPIeP/sQocSkPvE4x1suYAO2Vno4AEKr2dxkHD4VQhxv3ycA9C0HXLuRRD/
A8MfHD75RRD71sc6PAY5cE6Rw52fdVl7tkD9ixRfAM89yek=
                    "], 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    262.16, 109.32}, {261.316, 109.215}, {260.78099999999995`,
                     107.57799999999999`}, {260.363, 108.68799999999999`}, {
                    259.66, 110.48}, {260.15200000000004`, 111.906}, {260.945,
                     111.75}, {261.883, 111.5}, {263.465, 109.402}, {262.16, 
                    109.32}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    262.16, 109.32}, {261.316, 109.215}, {260.78099999999995`,
                     107.57799999999997`}, {260.363, 108.68799999999999`}, {
                    259.66, 110.47999999999999`}, {260.15200000000004`, 
                    111.906}, {260.945, 111.75}, {261.883, 111.5}, {263.465, 
                    109.40199999999999`}, {262.16, 109.32}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4h1yra8DfxQ5ZEx8W2O/NdVBJirF+j57scM3
jZj+Q1dTHbzNOx0TmIsd1A051sg8SnUAqjKNe1PksPVE2b75QP7jpbOPKNwq
cljkuu3z3yepDgwgsK3I4ThI45lUh2MgegWU/yDVwf1hlci62UUOF5Vu/6z7
lOqwDKh9w4IiiD6HNAega3bIAeUttwAtSE6DyM8ocgjj0900tzzNwQOkf2KR
A5B0fzgtzeHTJd8kgaYiiPvS0iDmBxc56N9VYWu8mOpgBTJHssjBMeHpBSX5
VIg7GYocVn0EaixIgaj7XAjxF18KxL0MUP2lyZBw0YX6ly/ZQaj5wKmF2kUO
XNcXF9imJTuAnPXeGhp+C5Mh4edf5HAJ5L9XyQ73/Xun52UUOczIA+r0SnHQ
ahe7ee5wkUM4SKN/qgN6+AMAUBKzZA==
                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{291.574, 
                    149.24599999999998`}, {288.39099999999996`, 
                    149.23399999999998`}, {287.84400000000005`, 153.504}, {
                    287.84400000000005`, 154.69899999999998`}, {
                    289.40999999999997`, 154.39800000000002`}, {292.172, 
                    151.785}, {291.574, 149.24599999999998`}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{291.574, 
                    149.246}, {288.39099999999996`, 149.234}, {
                    287.84400000000005`, 153.504}, {287.84400000000005`, 
                    154.69899999999998`}, {289.40999999999997`, 154.398}, {
                    292.172, 151.78500000000003`}, {291.574, 149.246}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{264.039, 
                    107.793}, {261.77299999999997`, 107.277}, {261.805, 
                    112.73400000000001`}, {264.121, 115.04700000000001`}, {
                    263.10200000000003`, 111.543}, {265.824, 108.336}, {
                    264.039, 107.793}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{264.039, 
                    107.793}, {261.77299999999997`, 107.27700000000002`}, {
                    261.805, 112.73400000000001`}, {264.121, 115.047}, {
                    263.10200000000003`, 111.54299999999998`}, {265.824, 
                    108.33600000000001`}, {264.039, 107.793}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    264.92199999999997`, 107.84}, {264.77, 
                    105.24600000000001`}, {271.28499999999997`, 
                    108.17999999999999`}, {272.96099999999996`, 110.195}, {
                    269.113, 108.562}, {265.10900000000004`, 
                    109.91400000000002`}, {264.92199999999997`, 
                    107.84}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    264.92199999999997`, 107.84}, {264.77, 
                    105.24600000000001`}, {271.28499999999997`, 
                    108.17999999999998`}, {272.96099999999996`, 110.195}, {
                    269.113, 108.56199999999998`}, {265.10900000000004`, 
                    109.91399999999999`}, {264.92199999999997`, 107.84}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{267.777, 
                    111.543}, {267.543, 109.031}, {273.42599999999993`, 
                    111.242}, {275.168, 113.203}, {271.301, 111.953}, {
                    268.03099999999995`, 113.613}, {267.777, 
                    111.543}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{267.777, 
                    111.54299999999998`}, {267.543, 109.031}, {
                    273.42599999999993`, 111.24199999999999`}, {275.168, 
                    113.203}, {271.301, 111.953}, {268.03099999999995`, 
                    113.61299999999997`}, {267.777, 111.54299999999998`}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{266.695, 
                    111.191}, {264.42999999999995`, 110.67599999999999`}, {
                    264.79699999999997`, 116.32}, {267., 118.262}, {265.941, 
                    114.49600000000001`}, {268.477, 111.738}, {266.695, 
                    111.191}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{266.695, 
                    111.191}, {264.42999999999995`, 110.67599999999999`}, {
                    264.79699999999997`, 116.32}, {267., 118.262}, {265.941, 
                    114.49600000000001`}, {268.477, 111.738}, {266.695, 
                    111.191}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{269.078, 
                    114.62499999999999`}, {266.812, 114.109}, {268.113, 
                    118.96900000000001`}, {269.79299999999995`, 
                    120.91000000000001`}, {269.52, 117.367}, {270.637, 
                    114.91000000000001`}, {269.078, 
                    114.62499999999999`}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{269.078, 
                    114.625}, {266.812, 114.10899999999998`}, {268.113, 
                    118.969}, {269.79299999999995`, 120.91}, {269.52, 
                    117.36700000000002`}, {270.637, 114.91}, {269.078, 
                    114.625}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    270.28099999999995`, 114.641}, {270.047, 112.051}, {
                    274.625, 114.039}, {276.402, 116.488}, {272.574, 
                    115.238}, {270.53499999999997`, 116.70700000000001`}, {
                    270.28099999999995`, 114.641}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    270.28099999999995`, 114.64099999999999`}, {270.047, 
                    112.05100000000002`}, {274.625, 114.03899999999999`}, {
                    276.402, 116.488}, {272.574, 115.238}, {
                    270.53499999999997`, 116.70700000000002`}, {
                    270.28099999999995`, 114.64099999999999`}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{271.527, 
                    116.609}, {270.043, 117.67599999999999`}, {271.617, 
                    120.5}, {274.445, 120.324}, {274.168, 118.617}, {273.191, 
                    115.621}, {271.527, 116.609}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{271.527, 
                    116.60899999999998`}, {270.043, 117.67599999999999`}, {
                    271.617, 120.5}, {274.445, 120.32400000000001`}, {274.168,
                     118.61699999999999`}, {273.191, 115.62100000000001`}, {
                    271.527, 116.60899999999998`}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{260.367, 
                    104.902}, {260.219, 102.309}, {266.734, 
                    103.60199999999999`}, {268.78099999999995`, 106.363}, {
                    264.672, 105.586}, {260.559, 106.98}, {260.367, 
                    104.902}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{260.367, 
                    104.90199999999999`}, {260.219, 102.309}, {266.734, 
                    103.60199999999998`}, {268.78099999999995`, 106.363}, {
                    264.672, 105.58600000000001`}, {260.559, 
                    106.97999999999999`}, {260.367, 104.90199999999999`}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{286.258, 
                    109.543}, {286.02299999999997`, 106.95700000000001`}, {
                    293.137, 109.801}, {294.914, 112.25}, {291.09, 111.}, {
                    286.512, 111.613}, {286.258, 109.543}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{286.258, 
                    109.54299999999998`}, {286.02299999999997`, 
                    106.95700000000002`}, {293.137, 109.80100000000002`}, {
                    294.914, 112.25}, {291.09, 111.}, {286.512, 
                    111.61299999999997`}, {286.258, 109.54299999999998`}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{281.895, 
                    108.44100000000002`}, {280.40999999999997`, 109.508}, {
                    283.441, 112.258}, {285.855, 112.902}, {285.582, 
                    111.199}, {283.559, 107.453}, {281.895, 
                    108.44100000000002`}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{281.895, 
                    108.441}, {280.40999999999997`, 109.50799999999998`}, {
                    283.441, 112.25800000000001`}, {285.855, 
                    112.90199999999999`}, {285.582, 111.19899999999998`}, {
                    283.559, 107.453}, {281.895, 108.441}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{281.441, 
                    106.648}, {281.28099999999995`, 104.32}, {289.07, 
                    105.598}, {291.105, 107.74600000000001`}, {
                    284.40599999999995`, 106.535}, {281.66, 108.641}, {
                    281.441, 106.648}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{281.441, 
                    106.64799999999997`}, {281.28099999999995`, 104.32}, {
                    289.07, 105.59799999999998`}, {291.105, 
                    107.74600000000001`}, {284.40599999999995`, 106.535}, {
                    281.66, 108.64099999999999`}, {281.441, 
                    106.64799999999997`}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    277.79299999999995`, 105.098}, {276.92599999999993`, 
                    102.93400000000001`}, {284.402, 103.46100000000001`}, {
                    287.027, 104.71900000000001`}, {282.78499999999997`, 
                    104.754}, {278.387, 106.60199999999999`}, {
                    277.79299999999995`, 105.098}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    277.79299999999995`, 105.09799999999998`}, {
                    276.92599999999993`, 102.934}, {284.402, 
                    103.46100000000001`}, {287.027, 104.719}, {
                    282.78499999999997`, 104.75400000000002`}, {278.387, 
                    106.60199999999998`}, {277.79299999999995`, 
                    105.09799999999998`}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    274.29699999999997`, 103.52}, {273.469, 101.582}, {
                    280.383, 101.62499999999999`}, {283.754, 102.695}, {
                    279.289, 102.73}, {275.113, 105.438}, {
                    274.29699999999997`, 103.52}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    274.29699999999997`, 103.51999999999998`}, {273.469, 
                    101.582}, {280.383, 101.625}, {283.754, 102.695}, {
                    279.289, 102.73000000000002`}, {275.113, 
                    105.43799999999999`}, {274.29699999999997`, 
                    103.51999999999998`}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    269.26599999999996`, 102.48}, {268.039, 
                    100.18799999999999`}, {275.33599999999996`, 99.965}, {
                    277.703, 101.09400000000001`}, {273.484, 
                    101.67199999999998`}, {270.309, 104.285}, {
                    269.26599999999996`, 102.48}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    269.26599999999996`, 102.47999999999999`}, {268.039, 
                    100.18799999999999`}, {275.33599999999996`, 99.965}, {
                    277.703, 101.094}, {273.484, 101.67199999999997`}, {
                    270.309, 104.28500000000003`}, {269.26599999999996`, 
                    102.47999999999999`}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{277.809, 
                    106.398}, {280.129, 104.938}, {280.004, 109.25}, {
                    281.85200000000003`, 112.238}, {278.949, 109.598}, {
                    276.234, 107.79700000000001`}, {277.809, 
                    106.398}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{277.809, 
                    106.398}, {280.129, 104.93799999999999`}, {280.004, 
                    109.25}, {281.85200000000003`, 112.238}, {278.949, 
                    109.59799999999998`}, {276.234, 107.79700000000003`}, {
                    277.809, 106.398}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{273.695, 
                    104.848}, {275.64500000000004`, 103.12499999999999`}, {
                    277.199, 109.043}, {278.97299999999996`, 112.367}, {
                    276.105, 109.203}, {271.89799999999997`, 106.281}, {
                    273.695, 104.848}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{273.695, 
                    104.84799999999998`}, {275.64500000000004`, 103.125}, {
                    277.199, 109.04299999999998`}, {278.97299999999996`, 
                    112.36700000000002`}, {276.105, 109.203}, {
                    271.89799999999997`, 106.28100000000003`}, {273.695, 
                    104.84799999999998`}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{268.258, 
                    103.199}, {269.90599999999995`, 101.289}, {274.672, 
                    108.816}, {276.40599999999995`, 112.73400000000001`}, {
                    273.76599999999996`, 109.684}, {266.945, 104.82}, {
                    268.258, 103.199}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{268.258, 
                    103.19899999999998`}, {269.90599999999995`, 
                    101.28900000000002`}, {274.672, 108.816}, {
                    276.40599999999995`, 112.73400000000001`}, {
                    273.76599999999996`, 109.684}, {266.945, 104.82}, {
                    268.258, 103.19899999999998`}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{272.895, 
                    97.45700000000001}, {273.719, 94.551}, {285.848, 
                    100.195}, {287.203, 103.117}, {280.262, 
                    99.44100000000002}, {272.72999999999996`, 
                    100.21100000000001`}, {272.895, 
                    97.45700000000001}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{272.895, 
                    97.45700000000002}, {273.719, 94.55100000000002}, {
                    285.848, 100.195}, {287.203, 103.11699999999999`}, {
                    280.262, 99.441}, {272.72999999999996`, 
                    100.21100000000001`}, {272.895, 97.45700000000002}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4k+XfJME6oodZKNSrO/3JztsPVG2b35TsUMY
n+6mubOTHdwfVoms6y92CAfxgfL3/Xun5/UUOzglPL2gVJzs4G3e6ZjQWexw
52dd1h6fZIfJEixhfLlQ/e1JDm9r7E3jbIodLLcADXZOcvAAmSdZ7PBNI6b/
kGCSQ8ZEoIrkIofW14E75A4mOlxQuv2zTqDIoVpknfvDeYkOcbs8eZgeFzoU
2nJdX9yTCBHfU+jgCLI/PtEhFiQ/v9Bhep5Q8wGxRIh7Vhc66N9VYWssTXQA
ect/ayHEPbsTIfYdLXQQbj5waiHQfrC+K4UOi1y3ff4bk+Sg3S5289zfQoh/
10Pdr1HkwAACW5IcQM4oKC+CuH9nkoMVyF93ixxU2RqnOh9PcgCHpwbUv+zQ
8PKD8tWh4ZVaDPFXcLIDevgDAJdbrTE=
                    "]]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4k+XfJME6oodZKNSrO/3JztsPVG2b35TsUMY
n+6mubOTHdwfVoms64fygfL3/Xun5/UUOzgmPL2gVJzs4G3e6ZjQWexw+2dd
1h6fZIfJEixhfLlQ9e1JDm9r7E3jbIodLLcADXZOcvAAmSdZ7PBNI6b/kGCS
Q8ZEoIrkIofW14E75A4mOlxQApokUORQLbLO/eG8RIe4XZ48TI8LHQptua4v
7kmEiO8phNgfn+gQC5KfX+gwI0+o+YBYIsQ9qwsd9O6qsDWWJjqAvOW/tRDi
nt2JEPuOFjoINx84tRBo/3SQviuFDotct33+G5PkoN0udvPcX6j69VD3axQ5
MIDAliQHkDMKyosg7t+Z5GAF8tfdIgc1tsapzseTHMDhqQH1Lzs0vPygfHVo
eKUWQ/wVnOyAHv4AkzOtLg==
                    "], 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{283.566, 
                    132.105}, {282.012, 130.95700000000002`}, {
                    280.29299999999995`, 135.066}, {282.27, 
                    138.97299999999998`}, {282.332, 135.21499999999997`}, {
                    285.32, 133.94899999999998`}, {283.566, 
                    132.105}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{283.566, 
                    132.105}, {282.012, 130.95700000000002`}, {
                    280.29299999999995`, 135.066}, {282.27, 
                    138.97299999999998`}, {282.332, 135.215}, {285.32, 
                    133.94899999999998`}, {283.566, 132.105}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{282.07, 
                    128.336}, {279.91799999999995`, 127.67599999999999`}, {
                    279.242, 131.484}, {280.66, 134.535}, {
                    280.42599999999993`, 131.258}, {284.047, 129.285}, {
                    282.07, 128.336}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{282.07, 
                    128.336}, {279.91799999999995`, 127.67599999999999`}, {
                    279.242, 131.484}, {280.66, 134.535}, {
                    280.42599999999993`, 131.258}, {284.047, 
                    129.28500000000003`}, {282.07, 128.336}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    280.43399999999997`, 125.312}, {278.35200000000003`, 
                    124.277}, {277.562, 128.125}, {279.059, 130.984}, {
                    278.895, 127.34}, {282.03499999999997`, 126.262}, {
                    280.43399999999997`, 125.312}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    280.43399999999997`, 125.31199999999998`}, {
                    278.35200000000003`, 124.27700000000002`}, {277.562, 
                    128.125}, {279.059, 130.984}, {278.895, 127.34}, {
                    282.03499999999997`, 126.262}, {280.43399999999997`, 
                    125.31199999999998`}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{281.289, 
                    125.07799999999999`}, {282.113, 122.617}, {286.895, 
                    127.203}, {287.699, 129.69899999999998`}, {
                    284.72999999999996`, 126.75}, {280.695, 
                    127.07799999999999`}, {281.289, 
                    125.07799999999999`}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{281.289, 
                    125.07799999999997`}, {282.113, 122.61699999999999`}, {
                    286.895, 127.203}, {287.699, 129.69899999999998`}, {
                    284.72999999999996`, 126.75}, {280.695, 
                    127.07799999999997`}, {281.289, 125.07799999999997`}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{283.457, 
                    128.848}, {284.395, 126.383}, {290.40599999999995`, 
                    132.727}, {291.734, 135.781}, {288.76599999999996`, 
                    132.836}, {282.789, 130.586}, {283.457, 
                    128.848}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{283.457, 
                    128.84799999999998`}, {284.395, 126.38300000000001`}, {
                    290.40599999999995`, 132.72700000000003`}, {291.734, 
                    135.78100000000003`}, {288.76599999999996`, 132.836}, {
                    282.789, 130.586}, {283.457, 128.84799999999998`}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{284.648, 
                    132.54299999999998`}, {285.58599999999996`, 129.742}, {
                    292.121, 137.207}, {293.97299999999996`, 
                    139.85200000000003`}, {290.855, 136.941}, {283.941, 
                    134.578}, {284.648, 132.54299999999998`}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{284.648, 
                    132.54299999999998`}, {285.58599999999996`, 129.742}, {
                    292.121, 137.20700000000002`}, {293.97299999999996`, 
                    139.852}, {290.855, 136.941}, {283.941, 
                    134.57799999999997`}, {284.648, 132.54299999999998`}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{284.855, 
                    135.312}, {282.555, 135.758}, {284.98799999999994`, 
                    137.676}, {287.809, 140.79299999999998`}, {
                    287.93799999999993`, 137.512}, {287.402, 
                    135.21899999999997`}, {284.855, 135.312}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{284.855, 
                    135.31199999999998`}, {282.555, 135.758}, {
                    284.98799999999994`, 137.676}, {287.809, 140.793}, {
                    287.93799999999993`, 137.51199999999997`}, {287.402, 
                    135.219}, {284.855, 135.31199999999998`}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{288.734, 
                    137.176}, {287.742, 138.258}, {289.688, 
                    138.71899999999997`}, {292.09799999999996`, 
                    141.42200000000003`}, {292.453, 139.602}, {289.863, 
                    136.262}, {288.734, 137.176}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{288.734, 
                    137.176}, {287.742, 138.258}, {289.688, 138.719}, {
                    292.09799999999996`, 141.422}, {292.453, 
                    139.60199999999998`}, {289.863, 136.262}, {288.734, 
                    137.176}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    277.60200000000003`, 125.016}, {276.34000000000003`, 
                    124.277}, {275.47999999999996`, 126.859}, {277.047, 
                    129.195}, {277.40599999999995`, 126.66799999999999`}, {
                    278.754, 125.965}, {277.60200000000003`, 
                    125.016}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    277.60200000000003`, 125.01599999999999`}, {
                    276.34000000000003`, 124.27700000000002`}, {
                    275.47999999999996`, 126.85900000000001`}, {277.047, 
                    129.195}, {277.40599999999995`, 126.66799999999998`}, {
                    278.754, 125.965}, {277.60200000000003`, 
                    125.01599999999999`}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{304.953, 
                    141.297}, {307.625, 139.691}, {311.875, 146.09}, {313.008,
                     148.72299999999998`}, {310.66, 145.69899999999998`}, {
                    304.445, 142.941}, {304.953, 141.297}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{304.953, 
                    141.29700000000003`}, {307.625, 139.691}, {311.875, 
                    146.09}, {313.008, 148.723}, {310.66, 
                    145.69899999999998`}, {304.445, 142.941}, {304.953, 
                    141.29700000000003`}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{302.68, 
                    137.566}, {304.16, 135.92600000000002`}, {308.816, 
                    140.383}, {310.43399999999997`, 142.641}, {
                    307.93799999999993`, 140.48000000000002`}, {302.027, 
                    140.22299999999998`}, {302.68, 137.566}}}]}}}}}}}, {{{{{{{
                    
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{302.68, 
                    137.566}, {304.16, 135.92600000000002`}, {308.816, 
                    140.383}, {310.43399999999997`, 142.641}, {
                    307.93799999999993`, 140.48}, {302.027, 140.223}, {302.68,
                     137.566}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    300.14500000000004`, 134.22299999999998`}, {300.633, 
                    131.984}, {307.42999999999995`, 137.02}, {309.02, 
                    139.406}, {306.08599999999996`, 136.64499999999998`}, {
                    299.699, 136.895}, {300.14500000000004`, 
                    134.22299999999998`}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    300.14500000000004`, 134.223}, {300.633, 131.984}, {
                    307.42999999999995`, 137.01999999999998`}, {309.02, 
                    139.406}, {306.08599999999996`, 136.64499999999998`}, {
                    299.699, 136.895}, {300.14500000000004`, 134.223}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{301.184, 
                    131.80100000000002`}, {302.234, 129.781}, {307.762, 
                    134.781}, {309.08599999999996`, 137.39100000000002`}, {
                    305.71099999999996`, 134.441}, {300.328, 133.797}, {
                    301.184, 131.80100000000002`}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{301.184, 
                    131.80100000000002`}, {302.234, 129.78100000000003`}, {
                    307.762, 134.78100000000003`}, {309.08599999999996`, 
                    137.39100000000002`}, {305.71099999999996`, 134.441}, {
                    300.328, 133.79700000000003`}, {301.184, 
                    131.80100000000002`}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    304.02299999999997`, 141.625}, {302.28099999999995`, 
                    143.465}, {303.02299999999997`, 144.324}, {
                    304.29299999999995`, 147.22299999999998`}, {
                    304.98799999999994`, 144.24599999999998`}, {306.039, 
                    143.059}, {304.02299999999997`, 141.625}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    304.02299999999997`, 141.625}, {302.28099999999995`, 
                    143.465}, {303.02299999999997`, 144.324}, {
                    304.29299999999995`, 147.223}, {304.98799999999994`, 
                    144.246}, {306.039, 143.059}, {304.02299999999997`, 
                    141.625}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    301.71099999999996`, 138.15200000000002`}, {298.547, 
                    138.012}, {301.68, 141.863}, {302.42999999999995`, 
                    145.094}, {302.156, 141.41}, {303.242, 138.504}, {
                    301.71099999999996`, 
                    138.15200000000002`}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    301.71099999999996`, 138.152}, {298.547, 
                    138.01199999999997`}, {301.68, 141.863}, {
                    302.42999999999995`, 145.094}, {302.156, 141.41}, {
                    303.242, 138.504}, {301.71099999999996`, 138.152}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{299.695, 
                    135.098}, {297.504, 135.59}, {298.137, 138.695}, {299.816,
                     142.44899999999998`}, {299.469, 138.39100000000002`}, {
                    301.672, 136.047}, {299.695, 135.098}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{299.695, 
                    135.09799999999998`}, {297.504, 135.59}, {298.137, 
                    138.695}, {299.816, 142.44899999999998`}, {299.469, 
                    138.39100000000002`}, {301.672, 136.047}, {299.695, 
                    135.09799999999998`}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{300.441, 
                    128.961}, {301.26599999999996`, 126.49600000000001`}, {
                    307.5, 132.20299999999997`}, {308.49199999999996`, 
                    134.363}, {305.34000000000003`, 131.71499999999997`}, {
                    299.883, 130.809}, {300.441, 128.961}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{300.441, 
                    128.961}, {301.26599999999996`, 126.49600000000001`}, {
                    307.5, 132.203}, {308.49199999999996`, 134.363}, {
                    305.34000000000003`, 131.715}, {299.883, 130.809}, {
                    300.441, 128.961}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{296.703, 
                    125.113}, {297.641, 122.648}, {304.176, 127.645}, {
                    306.176, 130.36700000000002`}, {302.23799999999994`, 
                    127.27}, {296.22299999999996`, 127.55499999999999`}, {
                    296.703, 125.113}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{296.703, 
                    125.11299999999997`}, {297.641, 122.64799999999997`}, {
                    304.176, 127.64499999999998`}, {306.176, 
                    130.36700000000002`}, {302.23799999999994`, 
                    127.27000000000001`}, {296.22299999999996`, 127.555}, {
                    296.703, 125.11299999999997`}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{292.895, 
                    121.23}, {293.945, 117.79700000000001`}, {300.777, 
                    123.281}, {302.816, 125.965}, {298.465, 122.645}, {
                    292.34000000000003`, 123.67599999999999`}, {292.895, 
                    121.23}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{292.895, 
                    121.23000000000002`}, {293.945, 117.79700000000003`}, {
                    300.777, 123.28100000000003`}, {302.816, 125.965}, {
                    298.465, 122.64499999999998`}, {292.34000000000003`, 
                    123.67599999999999`}, {292.895, 121.23000000000002`}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{299.32, 
                    130.055}, {297.465, 129.094}, {296.715, 134.363}, {
                    297.762, 138.08200000000002`}, {297.746, 134.023}, {
                    301.484, 131.008}, {299.32, 130.055}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{299.32, 
                    130.055}, {297.465, 129.094}, {296.715, 134.363}, {
                    297.762, 138.082}, {297.746, 134.023}, {301.484, 
                    131.00799999999998`}, {299.32, 130.055}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    296.15200000000004`, 125.871}, {293.92199999999997`, 
                    125.21100000000001`}, {294.629, 130.88700000000003`}, {
                    296.53499999999997`, 134.57}, {296.78099999999995`, 
                    130.92200000000003`}, {298.42599999999993`, 
                    127.45700000000001`}, {296.15200000000004`, 
                    125.871}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    296.15200000000004`, 125.87100000000001`}, {
                    293.92199999999997`, 125.21100000000001`}, {294.629, 
                    130.88700000000003`}, {296.53499999999997`, 134.57}, {
                    296.78099999999995`, 130.922}, {298.42599999999993`, 
                    127.45700000000002`}, {296.15200000000004`, 
                    125.87100000000001`}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{292.191, 
                    121.953}, {289.699, 121.812}, {291.414, 126.82}, {293.469,
                     129.641}, {293.121, 125.95700000000001`}, {
                    294.28099999999995`, 122.37899999999999`}, {292.191, 
                    121.953}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{292.191, 
                    121.953}, {289.699, 121.81199999999998`}, {291.414, 
                    126.82}, {293.469, 129.641}, {293.121, 
                    125.95700000000002`}, {294.28099999999995`, 
                    122.37899999999999`}, {292.191, 121.953}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{296.559, 
                    119.816}, {297.309, 118.54700000000001`}, {299.141, 
                    120.895}, {302.148, 122.60499999999999`}, {299.445, 
                    121.898}, {296.227, 120.992}, {296.559, 
                    119.816}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{296.559, 
                    119.816}, {297.309, 118.547}, {299.141, 
                    120.89500000000001`}, {302.148, 122.60499999999999`}, {
                    299.445, 121.898}, {296.227, 120.99199999999999`}, {
                    296.559, 119.816}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{297.984, 
                    162.008}, {295.66, 163.727}, {297.43399999999997`, 
                    166.945}, {297.984, 170.008}, {298.72999999999996`, 
                    167.105}, {300.703, 163.297}, {297.984, 
                    162.008}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{297.984, 
                    162.00799999999998`}, {295.66, 163.72700000000003`}, {
                    297.43399999999997`, 166.945}, {297.984, 
                    170.00799999999998`}, {298.72999999999996`, 167.105}, {
                    300.703, 163.29700000000003`}, {297.984, 
                    162.00799999999998`}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{298.062, 
                    157.71899999999997`}, {301.559, 158.141}, {
                    301.03099999999995`, 162.656}, {301.137, 165.52}, {
                    300.08599999999996`, 161.63299999999998`}, {
                    297.22299999999996`, 160.977}, {298.062, 
                    157.71899999999997`}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{298.062, 
                    157.719}, {301.559, 158.141}, {301.03099999999995`, 
                    162.656}, {301.137, 165.51999999999998`}, {
                    300.08599999999996`, 161.63299999999998`}, {
                    297.22299999999996`, 160.977}, {298.062, 157.719}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{297.512, 
                    158.305}, {294.559, 158.477}, {294.715, 161.836}, {
                    294.555, 165.238}, {296.055, 162.11299999999997`}, {
                    297.828, 161.629}, {297.512, 158.305}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{297.512, 
                    158.305}, {294.559, 158.477}, {294.715, 161.836}, {
                    294.555, 165.238}, {296.055, 162.11299999999997`}, {
                    297.828, 161.629}, {297.512, 158.305}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{297.633, 
                    154.129}, {299.92999999999995`, 153.945}, {301.125, 
                    156.20299999999997`}, {301.65200000000004`, 
                    159.72299999999998`}, {299.47299999999996`, 
                    156.48000000000002`}, {297.48799999999994`, 
                    157.48800000000003`}, {297.633, 154.129}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{297.633, 
                    154.129}, {299.92999999999995`, 153.945}, {301.125, 
                    156.203}, {301.65200000000004`, 159.723}, {
                    299.47299999999996`, 156.48}, {297.48799999999994`, 
                    157.488}, {297.633, 154.129}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{296.809, 
                    154.406}, {293.85200000000003`, 154.02700000000002`}, {
                    294.324, 157.469}, {294.445, 160.004}, {295.348, 
                    157.586}, {297.754, 156.824}, {296.809, 
                    154.406}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{296.809, 
                    154.406}, {293.85200000000003`, 154.02700000000002`}, {
                    294.324, 157.469}, {294.445, 160.004}, {295.348, 
                    157.586}, {297.754, 156.824}, {296.809, 154.406}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{301.414, 
                    155.863}, {301.18, 153.617}, {299.762, 149.758}, {297.477,
                     150.625}, {296.53099999999995`, 153.383}, {299.484, 
                    153.934}, {301.414, 155.863}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{301.414, 
                    155.863}, {301.18, 153.617}, {299.762, 149.758}, {297.477,
                     150.625}, {296.53099999999995`, 153.383}, {299.484, 
                    153.934}, {301.414, 155.863}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{296.77, 
                    150.383}, {297.79299999999995`, 152.35500000000002`}, {
                    294.445, 153.34}, {293.734, 155.89800000000002`}, {
                    293.328, 152.23399999999998`}, {293.668, 
                    149.83200000000002`}, {296.77, 150.383}}}]}}}}}}}, {{{{{{{
                    
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{296.77, 
                    150.383}, {297.79299999999995`, 152.35500000000002`}, {
                    294.445, 153.34}, {293.734, 155.898}, {293.328, 
                    152.234}, {293.668, 149.832}, {296.77, 150.383}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    306.29699999999997`, 173.727}, {304.457, 
                    175.71099999999998`}, {306.082, 178.85200000000003`}, {
                    306.633, 181.914}, {307.379, 179.012}, {308.676, 
                    175.164}, {306.29699999999997`, 173.727}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    306.29699999999997`, 173.72700000000003`}, {304.457, 
                    175.711}, {306.082, 178.852}, {306.633, 181.914}, {
                    307.379, 179.01199999999997`}, {308.676, 175.164}, {
                    306.29699999999997`, 173.72700000000003`}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    306.35200000000003`, 170.039}, {309.582, 
                    169.71099999999998`}, {310.363, 176.285}, {310.695, 
                    179.10899999999998`}, {309.64500000000004`, 
                    175.22299999999998`}, {305.92199999999997`, 173.445}, {
                    306.35200000000003`, 170.039}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    306.35200000000003`, 170.039}, {309.582, 169.711}, {
                    310.363, 176.28500000000003`}, {310.695, 
                    179.10899999999998`}, {309.64500000000004`, 175.223}, {
                    305.92199999999997`, 173.445}, {306.35200000000003`, 
                    170.039}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{305.688, 
                    170.105}, {303.40599999999995`, 171.285}, {
                    303.93399999999997`, 173.824}, {303.219, 175.73}, {
                    304.754, 173.39100000000002`}, {306.15200000000004`, 
                    173.055}, {305.688, 170.105}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{305.688, 
                    170.105}, {303.40599999999995`, 171.28500000000003`}, {
                    303.93399999999997`, 173.824}, {303.219, 
                    175.73000000000002`}, {304.754, 173.39100000000002`}, {
                    306.15200000000004`, 173.055}, {305.688, 170.105}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{306.328, 
                    165.80100000000002`}, {309.707, 165.512}, {
                    311.72299999999996`, 172.789}, {311.828, 175.656}, {
                    310.777, 171.766}, {305.93399999999997`, 169.656}, {
                    306.328, 165.80100000000002`}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{306.328, 
                    165.80100000000002`}, {309.707, 165.51199999999997`}, {
                    311.72299999999996`, 172.78900000000002`}, {311.828, 
                    175.656}, {310.777, 171.76600000000002`}, {
                    305.93399999999997`, 169.656}, {306.328, 
                    165.80100000000002`}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{305.68, 
                    165.91}, {302.5, 166.64499999999998`}, {302.883, 
                    168.69899999999998`}, {303.35900000000004`, 
                    172.02700000000002`}, {304.371, 168.676}, {
                    306.14500000000004`, 169.38700000000003`}, {305.68, 
                    165.91}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{305.68, 
                    165.91}, {302.5, 166.64499999999998`}, {302.883, 
                    168.69899999999998`}, {303.35900000000004`, 
                    172.02700000000002`}, {304.371, 168.676}, {
                    306.14500000000004`, 169.38700000000003`}, {305.68, 
                    165.91}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{306.367, 
                    161.602}, {310.08599999999996`, 160.969}, {309.824, 
                    166.848}, {312.77299999999997`, 171.11299999999997`}, {
                    310.22299999999996`, 167.945}, {305.625, 163.953}, {
                    306.367, 161.602}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{306.367, 
                    161.60199999999998`}, {310.08599999999996`, 160.969}, {
                    309.824, 166.84799999999998`}, {312.77299999999997`, 
                    171.11299999999997`}, {310.22299999999996`, 167.945}, {
                    305.625, 163.953}, {306.367, 161.60199999999998`}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{305.527, 
                    161.80100000000002`}, {302.72299999999996`, 
                    161.71899999999997`}, {302.449, 165.941}, {302.605, 
                    167.656}, {303.25, 165.94899999999998`}, {306.547, 
                    164.32800000000003`}, {305.527, 
                    161.80100000000002`}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{305.527, 
                    161.80100000000002`}, {302.72299999999996`, 161.719}, {
                    302.449, 165.941}, {302.605, 167.656}, {303.25, 
                    165.94899999999998`}, {306.547, 164.328}, {305.527, 
                    161.80100000000002`}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{312.176, 
                    166.129}, {310.78099999999995`, 161.605}, {308.805, 
                    157.07}, {306.367, 157.414}, {305.199, 
                    159.98800000000003`}, {308.68, 160.316}, {312.176, 
                    166.129}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{312.176, 
                    166.129}, {310.78099999999995`, 161.605}, {308.805, 
                    157.07}, {306.367, 157.414}, {305.199, 159.988}, {308.68, 
                    160.316}, {312.176, 166.129}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    305.48799999999994`, 158.078}, {306.512, 
                    160.05100000000002`}, {303.16400000000004`, 161.035}, {
                    302.453, 163.598}, {302.047, 159.934}, {302.387, 
                    157.52700000000002`}, {305.48799999999994`, 
                    158.078}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    305.48799999999994`, 158.07799999999997`}, {306.512, 
                    160.05100000000002`}, {303.16400000000004`, 161.035}, {
                    302.453, 163.59799999999998`}, {302.047, 159.934}, {
                    302.387, 157.52700000000002`}, {305.48799999999994`, 
                    158.07799999999997`}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{311.215, 
                    160.961}, {309.227, 156.88700000000003`}, {308.328, 
                    152.20299999999997`}, {305.59799999999996`, 152.883}, {
                    304.578, 156.05100000000002`}, {308.613, 
                    156.71499999999997`}, {311.215, 160.961}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{311.215, 
                    160.961}, {309.227, 156.88700000000003`}, {308.328, 
                    152.203}, {305.59799999999996`, 152.883}, {304.578, 
                    156.05100000000002`}, {308.613, 156.715}, {311.215, 
                    160.961}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    305.03099999999995`, 153.656}, {306.207, 155.812}, {
                    302.855, 156.57399999999998`}, {302.03499999999997`, 
                    159.547}, {301.59, 155.656}, {302.008, 152.883}, {
                    305.03099999999995`, 153.656}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    305.03099999999995`, 153.656}, {306.207, 
                    155.81199999999998`}, {302.855, 156.57399999999998`}, {
                    302.03499999999997`, 159.547}, {301.59, 155.656}, {
                    302.008, 152.883}, {305.03099999999995`, 153.656}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{299.305, 
                    181.238}, {297.34400000000005`, 180.71099999999998`}, {
                    295.28499999999997`, 182.91}, {296., 186.207}, {298.242, 
                    185.648}, {299.27, 183.61299999999997`}, {299.305, 
                    181.238}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{299.305, 
                    181.238}, {297.34400000000005`, 180.711}, {
                    295.28499999999997`, 182.91}, {296., 
                    186.20700000000002`}, {298.242, 185.64799999999997`}, {
                    299.27, 183.61299999999997`}, {299.305, 181.238}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4vJ986X0JYsdVn+85Jt0J83hgtLtn3VixQ4z
8oSaD+xLc7jv3zs9j6XYgQEE9qQ5eDysElnHWeywt2SyBMuzNIdPQG0CfFB5
jnSHDseEpxeAfP27KmyNiulw9a2vA3fI2aY7LJt9RGEDU7GDbFSK9f34dIdF
rts+/wWaXy2yzv3hrHSH497mnY5cxQ5FGRPf1mxOdwC64tRC/mIHH6Bwwtl0
B5CwvWKxA9f1xQW2+9IdtNvFbp4Duv/mue/Bj1emOwiD1AtC5SdB1QP5YDoR
6j6g/97V2JvGeaU7XK14qWYoV+wA9KVQswaUL1PsEManu2nu7zQH9PABACpY
gi4=
                    "]]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4vJ986X0JYsdVn+85Jt0J83hgtLtn3VixQ4z
8oSaD+xLc7jv3zs9j6XYgQEE9qQ5eDysElnHWeywp2SyBMuzNIdPQG0CfFB5
jnSHDseEpxeAfP27KmyNiulw9a2vA3fI2aY7LJt9RGEDU7GDbFSK9f34dIdF
rts+/wWaXy2yzv3hrHSH497mnY5cxQ5FGRPf1mxOdwC64tRC/mIHkHDC2XQH
kLC9YrED1/XFBbb70h2028VungO6/+a578GPV6Y7CIPUC0LlJ0HVA/lgOhHq
PqD/3tXYm8Z5pTtcrXipZihX7NA3HehhDShfptghjE9309zfaQ7o4QMAKQCC
LQ==
                    "], CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4gtKt3/WfSl02D9fSv+uS6rDlhNl++YzFDlk
THxbY6+Y6uBt3umYIFnkELvLk4fJPNUBrJ6tyIEBBDJSHSZLsITxfS90COfT
3TS3P9Vhkeu2z38fFELkN0D13y+EiN9IdXi8dPYRhXtQ+3jSHKpE1rk/PFfo
YAWyODoNou5AoQPX9cUFtmVpDsuAyjdsKnTYCnLXpDSHqxUv1QwXFTrMyBNq
PpCV5qB/V4WtcWOhg0xUivX9cKj6Q4UOws0HTi10THPQbhe7ee5socM3jZj+
Q09THexABgP5F0H+OJTq8OmSb5IA0H5VtsapzkD3K2woypj4vNCBG2R/FtS/
SOEDAIZxjIA=
                    "]]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4gtKt3/WfSl02DdfSv+uS6rDlhNl++YzFDlk
THxbY6+Y6uBt3umYIFnkELfLk4fJPNUBrJ6tyIEBBDJSHSZLsITxfS90COPT
3TS3P9Vhkeu2z38fFELkN0D13y90WAwSv5Hq8Hjp7CMK96D28aQ5VImsc394
rtDBCmRxdBpE/4FCB67riwtsy9IclgGVb9hUCHHXpDSHqxUv1QwXFTrMyBNq
PpCV5qB/V4WtcWOhg2xUivX9cKj6Q4UOws0HTi10THPQbhe7ee5socNXjZj+
Q09THexABgP5YH8cSnX4dMk3SQBovypb41RnoPsVNhRlTHwOtT8L6l+k8AEA
hLmMew==
                    "], CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4q0nyvbNlypy4Lq+uMC2LtVhep5Q8wG1IodL
Srd/1kWlOny65JskYFXkoMrWONU5P9Wh9XXgDjn9IodekMIVqQ6yUSnW91WL
HB4vnX1E4UKqQ7XIOveHKkUOGRPf1tgzpjkc/qoR0w8zXy7N4WrFSzVDniIH
bhDfK81Bq13s5rnPhRB9eWkOfLqb5r5/Wujgbd7pmNCZ5gB0zamF1wsdvgGN
ObQ0zcFyC9DBpwsd3tXYm8Z1pUH03Sh0UDfkWCNTlOYA1PX0wotCiH1BaRB3
/Sp0APtTK83B/WGVyDrmIoc+kPt50hyEQeaLFkH0X0p1sAKZz1vkEApyyOJU
B/TwAQAz4ogA
                    "]]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4q0nyvbNlypy4Lq+uMC2LtVhep5Q8wG1IoeL
Srd/1kWlOny65JskYFXkoMrWONU5P9Wh9XXgDjn9Ioc+kMIVqQ6yUSnW91WL
HB4vnX1E4UKqQ7XIOveHKkUOGRPf1tgzpjkc/qoR0w8zXy7N4WrFSzVDHijf
K81Bq13s5rnPhRB9eWkOfLqb5r5/WujgY97pmNCZ5gB0zamF1wsdQMYcWprm
YLkF6ODThQ7vauxN47rSIPpuFDqoG3KskSlKcwDqenrhRSHE/KA0iLt+FTqA
tM3XSnNwf1glso4Z6n6eNAdhkPmiRRD9l1IdrEAKeYscQkEOWZzqgB4+ADLS
h/4=
                    "], CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4sdLZx9ReFLkMD1PqPmAWZqD4oaijIlPixxW
fbzkm8SS5pAx8W2N/cUih+Pe5p2OP1Idrla8VDO8VAQRd0xzmCzBEsZ3ucjB
4K4KW2NvmsMnoDaBd0UOqmyNU50vp0HE70L57ukOnY4JTy9cKXJgAIGGdAeQ
9RuAfLA7XqQ78Olumvv+ZpHDhENfNWLkMxxAVP+9Igeu64sLbMMyIOZ/KnIA
2m4aZ5ThsAyk/1WRQxhII3uGw0Wl2z/rHhU5qBtyrJG5lg5x75siB5C1SuXp
Dg/8e6fnAfX3gwwGuqd833wpfdZiiP/2pDnE7fLkYXpc5NALCpCKNAf08AEA
G6SKkQ==
                    "]]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4sdLZx9ReFLkMCNPqPmAWZqD4oaijIlPixxW
fbzkm8SS5pAx8W2N/cUih+Pe5p2OP1Idrla8VDO8VAQRd0xzmCzBEsZ3uchB
/64KW2NvmsMnoDaBd0UOQN5U58tpDgYg8btFDmogvnu6Q6djwtMLV4ocGECg
Id0BZP0GIP8JiPEi3YFPd9Pc9zeLHCYc+qoRI5/hAKL67xU5cF1fXGAblgEx
/1ORw7sae9M4owyHZSD9r4ocwkAa2TMcLird/ln3qMhB3ZBjjcy1dIh73xQ5
OAGtVSpPd3jg3zs97xPUfKB7yvfNl9JnLYb4b0+aQ9wuTx6mx0UOfdOBAVKR
5oAePgAdlIqX
                    "], CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4k7HhKcX1hQ5ZEx8W2Pvm+5gueVE2b71RQ5x
uzx5mOTTHbzNgSoOFznMyBNqPiCV7uDxsEpk3d4ih+MgiZh0h9znv1d+3FEE
UTcx3eHx0tlHFHZAzduJUN87HWjAk3SHqBTr+/5HixwuKd3+WSeVATH3UJED
SPpAWYbDZAmWMD6g+tbXgTvk5mZAzNle5PBNI6b/0NEMh0+XfJMElhQ57C0B
qlyXAbEP6H6u64sLbPsyHBa5bvv8dwvUPZkZDgZ3VdgatxY53PlZl7VHJgMi
DvQfWN0PqP+WF0HMOZLuoLChKGPiSqj5dekOsPDxAakDhg8A6B2OBw==
                    
                    "]]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4k7HhKcX1hQ5ZEx8W2Pvm+5gueVE2b71RQ5x
uzx5mOTTHbzNgSoOFznMyBNqPiCV7uDxsEpk3d4ih+MgiZh0h9znv1d+3FEE
UTcx3eHx0tlHFID8TJB5OxHqe6cDDXiS7hCVYn3f/2iRwyWl2z/rpDIg5h6C
ml+W4TBZgiWMD6i+9XXgDrm5GRB3bS9y+KYR03/oaIbDp0u+SQJLihz2lABV
rsuA2Ad0P9f1xQW2fRkOi1y3ff67pcjBB+SezAwHg7sqbI1bixzu/KzL2iOT
AXEn0H+LQep+QP23vAhizpF0B4UNRRkTV0LNr0t3gIUPWB0wfADplY4I
                    
                    "], CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYCYj7dTXPfFxc7CDcfOLVwZrLDcW/zTsesYoeL
Srd/1jUlO4DlI4sdXLpznv+emOzQ6Zjw9EJGsUPGxLc19huTHRa5bvv8t6TY
4RJI/SkovwCq/1Kyw33/3ul5FVD1H5MdLLecKNtXX+wQCjJYOMUBZF0CkA8S
nq+W4nAMJNBR7ACyRsk+xeHx0tlHFCYUO1wAmReWAnHP7GKHrSD1dikODCAw
pdjBCaReO8Xh0yXfJIGuYgfZqBTr+0Dzwe7tKXaYkSfUfIApxWE6iG4rdlj9
EajwTbKDwoaijInVxQ43z30Pfnw0GWJ/XbHDN42Y/kMbof5HCh8A/bGSfA==

                    "]]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYCYj7dTXPfFxc7CDcfOLVwZrLDcW/zTsesYocL
Srd/1jUlO4DlI4sdnLtznv+emOzQ6Zjw9EJGsUPGxLc19huTHRa5bvv8t6TY
4SJI/SkovwCq/1Kyw33/3ul5FVD1H5MdLLecKNtXX+wQCjJYOMUBZF0CkL8V
KDxfLcXhGEigo9gBZI2SfYrD46WzjyhMgJoflgJxz2yoersUBwYQmAJVr53i
8OmSb5JAV7GDbFSK9X2g+WD39hQ7zMgTaj7AlOIwHUS3FTus/ghU+CbZQWFD
UcbE6mKHm+e+Bz8+mgyxv67Y4ZtGTP+hjVD/I4UPAPqZknk=
                    "], 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{294.92999999999995`, 137.11299999999997`}, {
                    292.977, 136.15200000000002`}, {291.4959999999999, 
                    133.754}, {291.39799999999997`, 131.805}, {
                    291.22999999999996`, 129.555}, {290.90999999999997`, 
                    127.66}, {289.89799999999997`, 126.062}, {291.504, 
                    126.508}, {292.27299999999997`, 129.07}, {292.504, 
                    131.523}, {292.734, 134.059}, {294.10200000000003`, 
                    135.16}, {294.92999999999995`, 
                    137.11299999999997`}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{294.92999999999995`, 137.11299999999997`}, {
                    292.977, 136.152}, {291.4959999999999, 
                    133.75400000000002`}, {291.39799999999997`, 131.805}, {
                    291.22999999999996`, 129.555}, {290.90999999999997`, 
                    127.66}, {289.89799999999997`, 126.06199999999998`}, {
                    291.504, 126.50799999999998`}, {292.27299999999997`, 
                    129.07}, {292.504, 131.523}, {292.734, 134.059}, {
                    294.10200000000003`, 135.16}, {294.92999999999995`, 
                    137.11299999999997`}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{290.863, 132.406}, {289.512, 129.914}, {287.625, 
                    128.965}, {287.527, 127.113}, {287.363, 
                    124.98400000000001`}, {287.203, 124.87899999999999`}, {
                    286.625, 122.785}, {288.215, 123.20700000000001`}, {
                    288.617, 123.348}, {289.047, 126.531}, {289.309, 
                    128.76999999999998`}, {291.10200000000003`, 130.348}, {
                    290.863, 132.406}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{290.863, 132.406}, {289.512, 129.914}, {287.625, 
                    128.965}, {287.527, 127.11299999999997`}, {287.363, 
                    124.98400000000001`}, {287.203, 124.87899999999999`}, {
                    286.625, 122.78500000000003`}, {288.215, 
                    123.20700000000002`}, {288.617, 123.34799999999998`}, {
                    289.047, 126.531}, {289.309, 128.77}, {
                    291.10200000000003`, 130.34799999999998`}, {290.863, 
                    132.406}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{248.824, 
                    109.34400000000001`}, {248.066, 107.91400000000002`}, {
                    247.195, 105.73400000000001`}, {245.61299999999997`, 
                    106.133}, {245.59, 107.23}, {247.32000000000002`, 
                    107.988}, {248.824, 109.34400000000001`}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    246.47299999999998`, 108.85499999999999`}, {
                    243.40200000000002`, 107.598}, {240.754, 
                    107.91000000000001`}, {240.42600000000002`, 105.98}, {
                    243.30100000000002`, 105.66799999999999`}, {
                    244.35500000000002`, 106.85199999999999`}, {
                    246.47299999999998`, 108.85499999999999`}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{259.32, 119.008}, {257.254, 117.316}, {255.914, 
                    115.383}, {255.289, 112.887}, {254.637, 110.559}, {
                    253.71899999999997`, 108.703}, {252.375, 106.613}, {
                    254.566, 108.10499999999999`}, {255.941, 110.141}, {
                    256.633, 112.586}, {257.23799999999994`, 114.992}, {
                    257.949, 116.793}, {259.32, 119.008}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{256.777, 119.016}, {254.562, 
                    117.24600000000001`}, {252.47299999999998`, 115.242}, {
                    251.848, 112.742}, {251.195, 110.418}, {
                    250.80100000000002`, 108.637}, {249.309, 106.324}, {
                    251.648, 107.816}, {252.578, 110.074}, {253.266, 
                    112.52}, {253.871, 114.926}, {255.258, 116.727}, {256.777,
                     119.016}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4mqRde4P9fIdmg+cWujqF+Nw+2dd1h6DfAeu
64sLbLNiHFTZGqc6q+c7zMgTaj7QFONgteVE2T7pfAfn7pznvztjHHzMOx0T
WKHys2Ic4nZ58jC9z3PonQ4UWBHjsG++lP7dG3kOC123ff67JcYhnE9309z9
eQ7S+ndV2A7GOICoxo15DotA8nNiHLxB5gH5GRPf1ti3xkBoIP+bRkz/odgY
h1UfL/kmbchzEAU6u8oGod6Lh0m7XS4G4o5NeQ5A065U/Ix2AOo2jduW5yDX
+jpwx7doB3VDjjUyh6D2f4yG2HslzwHk3AOvoiH2vc1z8EsSiLB8Eu1wHGQB
Q75DLMhfp6Mh4cGfD/HfjmiIu2TzHZ5eULr98xhUv2q+QzGI8Rxqn1Y+1JwY
hzug8NXJh9hvGOOAHv4AioCw8w==
                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4hl5Qs0H5PIcmg+cWujqF+OwyHXb578yeQ5c
1xcX2GbFOKz6eMk3SSXPYSFIvCXGYeuJsn3z9fIcRNa5P6zqgfKd8hwyJ76t
sZ8b43BB6fbPurA8h4dVQBULYxyKM4AS2XkQen6MQzVIY1Oew3Fv807HBTEO
t37WZe3pyHP4phHTf2hqjMO++VL6d4H8vSWTJVjqoO4B8uVaXwfuCIuBqOvM
c+idDnS4AUI92B9CMQ5hfLqb5rbnORjcVWFrfBvtwAACQHmQ8gOvoiHitXkO
IOfYP412KLQF+jQnz0EeZP69aAerLUAP+edB7L0TDXGvXZ7Dprnvlx87HO0A
cnaCIdR/G6MdXLpznv9WzIPYcwAqrwh1z6NoB2FQwCpCzfsTDXG3Qp6DtD7Q
IYYxDujhDwA/rLai
                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, {{{262.832, 
                    90.67999999999999}, {262.871, 89.73400000000001}, {
                    262.97999999999996`, 88.977}, {263.543, 88.215}, {
                    260.28099999999995`, 89.523}, {255.676, 88.824}, {
                    252.52700000000002`, 87.35499999999999}, {251.125, 
                    86.68799999999999}, {249.42600000000002`, 
                    88.12499999999999}, {251.07, 89.48400000000001}, {253.414,
                     91.383}, {258.83599999999996`, 90.309}, {262.832, 
                    90.67999999999999}}, {{216.82800000000003`, 90.73}, {
                    216.875, 89.84}, {216.76999999999998`, 89.023}, {216.441, 
                    88.24600000000001}, {219.98800000000003`, 
                    89.71100000000001}, {223.79299999999998`, 88.492}, {
                    227.375, 87.051}, {229.836, 86.031}, {230.035, 87.793}, {
                    229.602, 88.402}, {228.85200000000003`, 
                    89.48400000000001}, {227.406, 90.67199999999998}, {
                    225.578, 90.699}, {224.359, 90.715}, {219.672, 90.758}, {
                    216.82800000000003`, 90.73}}, CompressedData["
1:eJxdVGtIFFEUls0sSiTLomSxB2ZGhPlDzEr8Qq2sSKzmrrurJmbQzr7uloSZ
Wr4ICdGyKBIxs7RILKRErFRE7AGFWRZiZiYqlSWRFiZh93oGAgdmds+c13fO
991ZneLcf0Tn5uYWKW75u/BdFQ/PsOKKY3Feq86MB09PNFeYrHicVrrc3c+M
npe/DwyGWFFfPlbTMceMlgrfoD4fK3Z76jacbTZhXfD8Wn21iqPnv2VGDBkx
eLOsfZW/iqyIkKQmbyMCPHIuRT60wCL99njyX7RgIMOnbud6zbZZUKs3pW69
a0BSU4ynbolWL8SAgq9xjX4rVByUgZsMOCXSBi6oiJH93zK4yeuj5u9kOC4T
p1W8WtM7md3FUNI2EZggbJmWkcYQ1OfvkTOpYq3EZWZ4sie0cPuoquFhNO+E
SvMvY4SnV7OHFbJbVPhJYA0Kvf+gouHn3zfpJxXCM67ikIyrUhB1zjYyFWdF
XuvzyugdDF0S1xcrfgUmFLf1Kdgr2idn2cifrdA+rtmQKPOtCgxeG+vL+20o
uiwI4lp/Yc/g7pzl36zNN9eOBZLXXAZXuPint6MyWiDMZxQXb6d8zojPMw7C
b2HU/70DW+4LIZxmkGHJ3k7CW8TAZT0fJ839XSF+gp0Y7hSD1SkQ06mPopzE
X4FCfUqcIJ1p87U7MS2vGoXilnLifx6DePbHHv5vz9TP49iXsig+rFZBd/rn
gOASTnzmK8TzVU59bygQqJhXKSe9vVBoH4VavDvDLkm0sEnfDPaRqds/8jky
pV5jGK7LPaVz2v8dRvVzOZ2PNkb1i7X4ZwxSXsV6F/kXG6h+jIvOy2sD+mPF
xv1cpC9XPMUPc03fRshn0i1O+/ljhNj2UOcxTudnwIRGKbRUbR8rzagW67tn
4giT/ISaqf42rvFuJv21Omn+RBPpq9tBc3wyEq9jduK7x0jn19dO/HYb0SH5
GrdiVKy9oMyE2d+Hf6Gf21o=
                    "]}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, {CompressedData["
1:eJxdUl1IVGEQXZbUKJOIHiTDVCoEsdUHkUV0j0WILSn9sH73Q9Iszd3b6nct
wmR7iIooaEUi+iMMonyRkAgpoU0k/CkoH5J+VGRZLSS1B6Mo0fpm50LRhcvc
YWbOnDnnZtY17693OhyOXP1SvN604Vz/QYWKuvXCPS0hjxZNVe5V6F1cftsa
lShZ8+6e2q0w6C28VPpeIqOnpbHDo3CisWM+9EbiBs3fasan0azxnzskIp2b
XJPDTdhy4cu+JxEDNF68EOT+5wbXU4MYIrx+AxRq3cfxPbu6faBAwiqmCZNx
P0rQmKfexMaHZdE2zS92//aLDGGipq882RmT2Fk7M5rlNVFJ/Ccknp28mrqq
xGS8MQmikZ5v8j0jEorws01E2zTiU8m8XgU4/jbwePhUpLMhgK2JZ6/t8hpY
S/x/+bneJfDh9Y8DsVk/9iQ7cy6GBfOd8/P9FQKlxCcpwPhugc0k6D95mASf
COAKxbtVcNDTbbL+532s14qtV7sP+hpfSo6ydfYhb5KYKdavpwpx/77ZfrgE
XFRfUjjjKTjUp/cthPSH00IaFcoFMsm/BIv5HBasT5IFP+kcFOyvzk/Pbs9f
HRKYp/lEi/dctvv1fFzPm4J5afwZuv+B3b+i2IdegZTcR3e+Lv/N43oMKaQT
UIPB94cVdFfX4KKBddR/TPG+lxJlRPSIwjbyQ/s91qqJVSt0E9Bnif//3z91
0Dt+
                    "], CompressedData["
1:eJxTTMoPSmViYGDQBmIQ3fo6cIdcaIHD3pLJEiznohyEmg+cWhhd4NA7PU+o
+UKUw6GvGjH9CQUOIuvcH1adiXIAq0+Gqt8X5fDpkm+SQFeBQ629adyuh5EO
S2cfUdhwpMBh09z3y48FRzrslAPq+FXg4JckEGG5JMLhasVLNcN/BQ5rZKJS
rKdHODCAQSFEfXeEwwygtQeAfDDdFOGgf1eFrZGxEGJ+ZYQDUNd9fyAf5IzW
4giHHSDzgerB5udEONz3B7ocaP43oLMPxUY4dDomPL3wA2qfP9T8T1D3u0VA
3DepwCFj4tsa+6PhEPdpFTg8rAL6eGOYA9f1xQW2/3Ih6peFOVxUuv2zbl02
xJxZUPlHWRB3bg13kAU5kDvLoRhkINA+cDj+yITw4yMcuEHqf2U6xO7y5GHq
hvkvC2L+tAgInZfl4NKd8/y3ZaTDY1CAXslyeHYBaPG7SIh6w2yI+1ZGOYC8
dd88G2p/lIO6IccaGadsh+Pe5p2OB6IcDEDivtkQc49FOdz6WZe1JyIbEt6n
oxz2z5fSv5uS7XAbJA6M30JboI9yEOqBoWIaZ5YDMU8hCiIulutwDMRfEQkx
/20uxH/LIyH2n8pzAAXrjmVQ/rx8iHqJKAeFDUUZEx2h4bszChLu7gUO2z7/
vVJxMMphy4myffP9ChyApk51Pg1Nb0jpEwCygSyW
                    
                    "]}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4gJbruuLf2Q5qLE1TnXuznGoElnn/vBblsNF
pds/69blOBjcVWFr1M12yJj4tsZ+Y46DKkiderYDUDZrTwOUL5/tcMzbvNPR
JccBRCXMzHZwSnh6QWl1tkMRSOPibIc7IPU+2Q7vauxN41ZlQ8zlzXZ4C+LX
ZTuoG3KskbmW5TAjT6j5QFC2Qyif7qa5m7McfEDmyWY7cF9fXGDbBXXn6SwH
2agU6/v9WQ7750vp312S5RAGUr88y0G4+cCphb1ZEHt2ZTn0TgcaWAHl/8py
uHnue/DjziwHyy0nyvYJZzswgMCELIfjIIfLZEPMXZ3l8E0jpv/Q1iyH1teB
O+ReZkHcty3LoQ9knk22A0j7fCAfrL8hG+LOr9Bwa4KGFzDcwOHZlg0R74P6
E+iOVR8v+SZp5Dighz8AGsWr8g==
                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    223.39100000000002`, 220.84}, {223.824, 221.148}, {
                    224.512, 219.805}, {224.02700000000002`, 219.469}, {
                    223.621, 219.19899999999998`}, {222.83200000000002`, 
                    220.465}, {223.39100000000002`, 220.84}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{224.55100000000002`, 223.566}, {224.336, 
                    223.461}, {223.90200000000002`, 223.61299999999997`}, {
                    224.031, 223.797}, {224.641, 224.668}, {225.941, 
                    225.98000000000002`}, {226.883, 226.43800000000002`}, {
                    227.172, 226.578}, {227.68, 226.066}, {227.504, 
                    225.816}, {226.93800000000002`, 225.012}, {225.566, 
                    224.062}, {224.55100000000002`, 223.566}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{234.625, 231.559}, {234.86700000000002`, 
                    232.066}, {236.316, 232.637}, {236.68800000000002`, 
                    232.977}, {237.031, 233.32800000000003`}, {237.191, 
                    232.68}, {237.047, 232.375}, {236.805, 231.871}, {
                    235.55100000000002`, 231.02}, {235.004, 230.996}, {
                    234.707, 230.984}, {234.477, 231.254}, {234.625, 
                    231.559}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{238.07, 231.39800000000002`}, {
                    238.38700000000003`, 232.285}, {239.40200000000002`, 
                    233.629}, {240.098, 234.07}, {240.45700000000002`, 
                    234.297}, {241.102, 234.121}, {240.98000000000002`, 
                    233.781}, {240.71099999999998`, 233.02700000000002`}, {
                    239.47299999999998`, 231.71499999999997`}, {238.637, 
                    231.098}, {238.383, 230.871}, {238., 231.195}, {238.07, 
                    231.39800000000002`}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{235.121, 229.184}, {234.91, 229.078}, {235.023, 
                    228.63299999999998`}, {235.227, 228.562}, {235.656, 
                    228.418}, {236.441, 228.39100000000002`}, {236.797, 
                    228.586}, {237.312, 228.906}, {237.078, 230.863}, {
                    236.38700000000003`, 229.816}, {235.92200000000003`, 
                    229.172}, {235.586, 229.379}, {235.121, 229.184}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, {{{229.289, 224.68800000000002`}, {
                    228.23399999999998`, 225.508}, {229.57, 226.66}, {230.672,
                     225.85500000000002`}, {232.82000000000002`, 224.238}, {
                    227.47299999999998`, 218.035}, {224.562, 
                    215.13299999999998`}, {224.02700000000002`, 214.566}, {
                    223.562, 215.996}, {224.242, 216.61299999999997`}, {
                    226.33200000000002`, 218.383}, {228.285, 220.496}, {
                    229.641, 222.68}, {229.90200000000002`, 223.102}, {
                    230.15200000000002`, 224.008}, {229.289, 
                    224.68800000000002`}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxNUl9I1EEQPq+4QqSgfBAzKbGSQlRQJEL87IiI6qHCAhERKYh2ZtSMHvII
vOgoMCSkf2QdFWdRcQ+hEVFymGD0EFIPJSVxiC+KhR0mQVG7N0v0g2V3fzP7
fTPfNxvb2g8eWxYIBHLs2mZX0K7pxM2xDZWCTz/PnniRIjxceLe/rVow+Xbp
0PQk4eTxy/ORFYLxvbUXG2x86PXpkXhIsPZc6s2dNCH3w72OOnvfFOq5Es4Q
Dq8qf3KrVnDE7X8IjxzePsFmF58jzWsXFDUd3fFlnHB+7sCz4kZBto5eQsvz
PXnBdaJ1XCAMO75ZVp4YaV03GI0OP0zYUrXycdEgY42rp4YUZ4j1fSnhR1lz
32iVYCReWDFVQLguNvOM/Itn67gvyrOVMB+pr2m5LcoX9Hgdgs9On18GfaOL
Zc1h0T6XDLrzk7vTxaJ92ni2n0XWPr8ZrHf4rxhOxvq0Ufwko6F1ZqIkbrDT
7f2MiRLrQMzg7q6nmd+9vt+oQWedPUVY6xjwfFFWHRJG311l9W/M6P9hVt6M
waVrtuGPDGdfa4736yurbrnenwFW3jwfj3r98gmVU6WhHmbVp9DPQ5fPryZ0
uXs3Y7sbDOvHy1P9BctjPr/J+/2eEXDfA6/vd4YrKzVIOierBRWOJ0GqU7ko
TtLr/998/gXD6ULx
                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{245.566, 229.816}, {246.023, 
                    230.21499999999997`}, {246.254, 230.88700000000003`}, {
                    246.73, 231.29299999999998`}, {246.99200000000002`, 
                    231.555}, {247.406, 231.242}, {247.34, 
                    230.61299999999997`}, {247.281, 230.11299999999997`}, {
                    246.61299999999997`, 229.68800000000002`}, {246.164, 
                    229.312}, {245.80100000000002`, 229.039}, {245.375, 
                    229.629}, {245.566, 229.816}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{250.742, 
                    231.656}, {251.418, 231.73}, {251.586, 
                    230.42600000000002`}, {250.848, 230.21499999999997`}, {
                    250.40200000000002`, 230.066}, {250.008, 231.578}, {
                    250.742, 231.656}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIxIGYC4oyJb2vsFfMdGECgJMdhkeu2z38VoPyAHIet
J8r2zTfKd+g/9FUjJjjHoXd6nlBzSL5DgS3X9cUhOQ4+5p2OCaX5Dt80YvoP
heY4AEULbCflO1huAWoEqlc35FgjA+Q/Xjr7iALQfJfunOe/J+Y73Dz3Pfjx
1ByHYpAD6vMdVNkapzpvhqqvyndY/fGSb9IchPlVIuvcH7blOOjfVWFrLMx3
COXT3TQ3GerelHyHuF2ePEzFOQ5g/0RC7WvIgdgTC5VvznEQbj5waqFnPsTc
3BwHoGrTOLt8iLmJOQ6trwN3yNlC3VMMlTfLh/irDqrfMN9h/3wp/bstUPuA
4Qd2RwWCDwtPADINlWE=
                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxNU2tIlEEU3d22LVqTLfwR0dOsllIkUiJDOrVFaRqk0A8zWaXt4f2Y2exB
UQgS/hARi5KCCCsr6EFhmJSamURFRIVE2yYisvQuwiJjiahv9l6rD4aPmbn3
3HPPuTO7QheFxjgcDqe9cuzlstf2I58PLs9W2Jk7IdLSRaj9uOHmjAzF/wZC
2JxnKfSl9ser8wl3mqdmDhQojPhLG3vzCGUdeUkuUngVr67sWktI4F2U+1bC
cTX5UM99hQfrltSteEe4NNxXWPFSoe3h3u5mj8X3IwrTS7YsG/RamL9o/JVp
HxRi50/em/WJsNngRxTmeWqaAp3Cx86/YfKLCJkDaZ6a95K/mPj8q0Jj73d/
6RxCgV02mK2xMvj6WWqAmAc0x5UQ5xVrxqmVfUBzneeEE4Zfvua+3cJvvUaD
IZ5mMS4J/kKLcXZo7n+ixX1u1axLlPi8XKPb4O0TfiHNehcSNiZnXD+1TcNh
vizCLpN4TeNAytU1Q8mid6fm/ybx667s6wnRJz+KY1ENb6QlnNsh+1sah40e
Xwi3dx+d4r4g/H2W6Ktx2fiSZDHPYcEbFD2cYfajR/gP6b/zkYiLadgqPToT
Evw30p9f/G/XMFNW5iGue0zixwq/PRpnV7d/++WWfbn4s4Bkrkb1lflLl/h0
8dOnmefvSuYfVzDHQSexjqcVqszFOMJcM0dPFVbVW29/1hH31aZY51H9mhT7
YveX8LtKIccY6f03/4k59kl9v0K/4Zki8S7B3y/zOUnuz0n9mfLeHhPzXKpY
txfyfv57j38AmbmZ6A==
                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJVIGYCYh/zTseEp/kO3NcXF9h25TjcPPc9+PHOfIfb
P+uy9izJcXi8dPYRhRf5EPGXOQ5g9X/zHYSbD5xaeDHHIWPi2xp74QKHVR8v
+SYtyHFgAAGNAodikIR2jsN9/97peWYFEP2KOQ5CIH32BQ5WW06U7ZPOcSjf
N19KH8g/7g00uCLHweNhlcg61wIHLpB7FuU4yEalWN/3LHAASScczHEAaZsf
U+CgytY41Xl7jsNkCZYwvsgChwmHvmrE9Oc4aLWL3TwXXuCgbsixRqYpx+GC
EtAnDgUOcbs8eZheZzvslGt9HehU4AAkd8g9zXZ4AHJfUIEDkBRqXgLlJ0HV
J2dD9OcUOHwDmn5INtthGTA4NhQUQNz1P8sBpO1AXAHE3yLZcPeB7ZfKhvgv
sMBhNSh8bLIh9tpC3bsfwQf7b2c2xFzjAki4xmZDwsmwwMGlO+f5b8dsB17d
TXPfqxc4WILEP2c55D7/vfKjSoHDDJA7bmU5XAS5VwgaPvezHEDRt0EMah83
1P1S0PDXz4aEnyk0vB9lOyhsKMqYCLS/COSA59kOHcDUcUGuAJIeDKDxwV3g
sBXkzyxoekBKPwAl7Amg
                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIxIGZigAKpAoeMiW9r7B9mOfDpbpr7XrjAYeuJsn3z
H2U5XFS6/bOOq8CB6/riAttjWQ4z8oSaD2gUODglPL2gtDvLofV14A65wAKH
vulAiTVZDt7mnY4JtQUOlluABhzPcqgWWef+sKvAIXaXJw+TeLbDA//e6Xmz
oPaVZjssnX1EYcMSqH3nsh1AxhxYU+Cw6uMl36QP2Q5VIP3bChzCQA4Tz3GQ
jUqxvn+4wKEXpFAkx2GnHNAFuwocbp77HvzYN8dBYUNRxsTNBQ6OIPeV5zjk
PP+98uMyqPlZOQ47QOqB9hXYAn0UkgNxx1yofRI5EPc1FTh804jpPxSa7fAJ
KCxQVeDg0g00yTAbYl9WgUMhSP8HaPh4FUDcfS3LAT08AU9cpAo=
                    "]], 
                    
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, {{{262.68, 224.742}, {
                    262.40999999999997`, 225.324}, {261.777, 224.875}, {
                    261.89099999999996`, 224.242}, {261.957, 223.668}, {
                    262.42599999999993`, 223.35500000000002`}, {
                    262.89099999999996`, 223.371}, {263.445, 
                    223.39100000000002`}, {264.617, 223.35200000000003`}, {
                    264.617, 224.27299999999997`}, {264.621, 224.918}, {
                    264.113, 225.45700000000002`}, {263.734, 224.742}, {
                    263.375, 224.098}, {262.914, 224.168}, {262.68, 
                    224.742}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{263.312, 227.176}, {263.117, 
                    227.04299999999998`}, {263.29299999999995`, 226.324}, {
                    263.52299999999997`, 226.33200000000002`}, {264.348, 
                    226.359}, {265.51599999999996`, 226.621}, {
                    266.14500000000004`, 227.059}, {266.328, 227.184}, {
                    266.25, 227.617}, {265.98799999999994`, 
                    227.60899999999998`}, {265.195, 227.58200000000002`}, {
                    263.92999999999995`, 227.605}, {263.312, 227.176}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{270.32, 225.36700000000002`}, {
                    270.91799999999995`, 226.30100000000002`}, {272.566, 
                    226.395}, {271.97299999999996`, 225.062}, {271.555, 
                    224.14499999999998`}, {267.449, 216.21899999999997`}, {
                    266.89099999999996`, 215.21099999999998`}, {
                    266.28099999999995`, 214.078}, {265.78099999999995`, 
                    214.641}, {266.215, 215.523}, {266.79699999999997`, 
                    216.656}, {270.133, 225.094}, {270.32, 
                    225.36700000000002`}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIlIGYC4p1yra8Dmwoc1A051shsynLQv6vC1lhf4PC2
xt407liWg0xUivX9/AKHY97mnY5PshyEmw+cWlhY4MB1fXGB7bosh+l5Qs0H
SgocjoPkfbIcPl3yTRLYUeDglPD0glJ2lsN9/97peWcKHPaWTJZg6ctyyHn+
e+XHewUO1SLr3B8C9VeB6HMFDhMOfdWIkYfa/7zAgQEEBLIcFrlu+/z3S4FD
P0iePcvhgtLtn3V8hRD7dLIcgKaG8UkXOuyfL6V/F2i/drvYzXO2hQ6OIPuX
Zznw6W6a+z640KEX5FCNbAeQtoTSQog9jdkQ9zYVOqz6CGQsyYaYn1fokDER
GAJ7sx1A1vanQdUvzIbQnoUQ9zlAzVMthLizAmrf3wKIftcsB6stJ8r23S1w
eLx09hEFmSwHUHD6A/3HDQq/qiyHqxUv1QyfFUDsnQYNzycFDmpsjVOdV2dB
9N0ocLh57nvw45NZEHOPFzh8Azrr0FpoeO2Ght/sLIfyfcCAWFngsBrkn54s
iPtnQOX7oeHfVwAJjwlZDh2ggGqDug/IR08PAAHY+B0=
                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    271.656, 219.258}, {271.68, 219.43}, {270.76599999999996`,
                     219.508}, {270.812, 218.621}, {270.84400000000005`, 
                    217.969}, {271.625, 217.789}, {271.762, 217.883}, {
                    272.99199999999996`, 218.781}, {271.5, 
                    218.33200000000002`}, {271.656, 219.258}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{269.863, 215.664}, {269.621, 215.605}, {
                    269.39799999999997`, 214.83200000000002`}, {269.969, 
                    214.789}, {270.49199999999996`, 214.75}, {272.539, 
                    214.97299999999998`}, {273.105, 214.93800000000002`}, {
                    273.47299999999996`, 214.953}, {273.613, 
                    215.65200000000002`}, {272.828, 215.61299999999997`}, {
                    271.875, 215.566}, {270.625, 215.805}, {269.863, 
                    215.664}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4,
                     3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, {{{220.297, 
                    228.99200000000002`}, {220.621, 228.977}, {221.512, 
                    227.824}, {221.453, 227.461}, {221.414, 
                    227.29299999999998`}, {220.5, 227.48800000000003`}, {
                    220.22299999999998`, 227.72299999999998`}, {220.016, 
                    227.89800000000002`}, {220.098, 229.}, {220.297, 
                    228.99200000000002`}}, CompressedData["
1:eJxNU1tIVFEUncSGEPGjhCIsSrL8CQsKiZCW9LCoPsrqIyYbpYF07+ldHzVI
JgZRqb3ohYjJQEgUlA7TMM6IFJaE6UQMZhIx2IMQiqiICLpnzqrpwuWwz95n
r7XXOmd+zf6tviyXy1Xq/Ga1nyAVvPlo3mVB75FLs7Lf1dn1NPezBaNDPypT
tYIdeYvvt80UfC/2tPQfFcTbZ5eMewVNn7aE5wYFJ/LvVrwdEuyKbMjNSrJu
QnBrbejr72Vq6yYFYz/r66LbFNf2TW/sy1GUjC9wNzQpjpvzCxVdXxKba1oV
a87q+1/lavveUGwsPVPurVW09n8r9uxWVBmcRkVOsvNAWbNi0dJpdwouqsW7
rZbHgOJgmVMRUKzofnIs9oJ9riuK3A1XVqcUaRmiijk796x8M8a+zxXNVx2C
rxUD5sBn4jr5tD5uv+U/yLpcxjHF3guTgVUfFefNfph4o+wfZ/4p54+o1bGP
84cUPQ7N9gjzXezTrdhu9O9Uq+tD9mljfYz7HeT7LKNHWp+EWj/P8dxLxUih
48Qp6pJkXT31GCZfUZR7J4YL7ylmONN2VJOP40+ByVcoWowuDzjHEvo5Qr+L
GE/1W1/zFQ768qoY8fLIJ0jcD7wfJ//2ycSbjI49mTite1T++ZDWoV5w2DSM
895UCV6Z+jD5VIvFCVAvn1gcH+fzi+W1TpEw+gyKvT8ete/gsVh91/MehMT6
O0VxyOBW8r30Eue/9/UH4cqIfA==
                    "]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    197.84, 210.062}, {197.71499999999997`, 209.691}, {
                    198.21099999999998`, 208.68800000000002`}, {
                    198.72299999999998`, 208.61299999999997`}, {
                    199.22299999999998`, 208.57399999999998`}, {
                    199.48000000000002`, 209.69899999999998`}, {199.316, 
                    210.062}, {199.19899999999998`, 210.33200000000002`}, {
                    197.93, 210.32800000000003`}, {197.84, 210.062}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxdU1tIVFEUnaaS6EFZfoSIlVgaRCokQ5m4zB6kVqQQUpNMNoJ7T6Q98KMk
GKwkpKzsScX0oB8NIUmT6CFSk0TEJESFDSZaQ4hCRElE1Dl37wq6cLicc9fZ
e621111QUV1SOdHlck0wy2OW26yhm5cez59FODKyuSv5CeHti/HSocmEp0We
Y/kRwt6qU6N1sSqM1uVll7cTXM5DKDaffVcI39K9TT0zCFNf36jJPU1o+dy3
oQKE1Y27Yj+ChLSsKbeSNhLm1Hc/u3aR8CiUmBH1EZK2+nMG7hJW3OmtfZij
uEUMh08xoSbXVFzGuL6m88vPMu0LxvHzu2fXnyGU31s/3T2ifW5r3WHCdns+
TjjZ8zXd20/C+yNhle9DJGUbCy6T8TKl//uhEhZ9O1l4FLH4QCz4Rpb6Oxgd
5nOondFq9XlZ+L1hHExoWzeYzNJvZkBwbhZ9aQFkRlPjglHCAYtbG5D+z9Xv
+ADC1udh5fuLxUdzv8nuY4x8y8PDsLK7Oxn7LN88hqUbOqf8C/TdwLhgcYkM
B0aqaxojw/LYo+efdE6H1d9ekvNXer+FsNzei6nfVwkP9jfPnTSmfBp0bgPK
s5kQsX6GtZ7BOzxbWfIR1fkHtf8gwaD5vl/rG/1jdk6Fqj9Mwjee/+buz/6E
xV/+t3f89Gv+tqgPpST+1Op8CjVfRxnvbN8lmi+j3+G1mLAwLni2oFrnmkqi
c5PyWar5MT46/0c2ic73msuVuu/SOc7THJp8//9//QaSPJEf
                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, {{{197.24599999999998`, 213.016}, {
                    196.977, 212.71099999999998`}, {197.883, 
                    212.10899999999998`}, {198.062, 212.266}, {198.41, 
                    212.566}, {199.766, 214.10899999999998`}, {199.504, 
                    214.648}, {199.26999999999998`, 215.13299999999998`}, {
                    197.41, 216.184}, {197.105, 215.664}, {
                    196.54299999999998`, 214.762}, {198.859, 
                    214.35500000000002`}, {198.5, 214.09}, {
                    198.32000000000002`, 213.98800000000003`}, {197.684, 
                    213.547}, {197.24599999999998`, 213.016}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{200.586, 
                    219.785}, {200.586, 219.785}, {201.168, 
                    217.79299999999998`}, {201.641, 218.621}, {202.023, 
                    219.19899999999998`}, {200.586, 219.785}, {200.586, 
                    219.785}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIZIGYC4tbXgTvkDDMdLLecKNsnnO3wrsbeNE4r04EB
BASyHRwTnl5QEs90uP2zLmsPQ7ZDKJ/uprnKmQ4FtlzXF//Icug/9FUjxjzT
YZHrts9/32Q5ZEx8W2OfCzXvcZaDcPOBUwsTMx1cunOe/+bMdrikBDQpKtOh
d3qeULNCtsMMIHVgU6aDt3mnYwJQHqx/bqbDW5A73LIdwkD2Tc90UGVrnOoc
ng2xpybTIRwknp8NcWdBpoMTyJ3FUPXpmRBzSrMdJoDc553p8E0jpv9QarYD
2L+xUPnYbIi7MjMdQM6dH5btsH++lP7dCZkOViAB+2yHiyD3NkH9bwBVXwj1
L9D9YH1pUP+aZzuoG3KskQnKdHi8dPYRBZNsB5moFOv77pkQcaNsh60g9X6Z
EHtEsh1ugcz1gJrHk+2gf1eFrdEVGj4c2Q4g6oBZJoQWg7ofKb4A4TzGsw==

                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{205.92200000000003`, 224.184}, {205.57, 
                    224.012}, {204.94899999999998`, 223.066}, {
                    204.92600000000002`, 222.63299999999998`}, {204.914, 
                    222.39800000000002`}, {205.168, 222.078}, {
                    205.36700000000002`, 222.176}, {205.73399999999998`, 
                    222.359}, {206.297, 223.254}, {206.316, 223.664}, {
                    206.33200000000002`, 223.92200000000003`}, {206.137, 
                    224.29299999999998`}, {205.92200000000003`, 224.184}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{208.191, 224.434}, {207.52, 225.254}, {208.906, 
                    226.47299999999998`}, {209.52700000000002`, 
                    224.82800000000003`}, {209.906, 223.797}, {213.918, 
                    218.516}, {214.738, 216.72299999999998`}, {
                    215.32000000000002`, 215.512}, {214.71899999999997`, 
                    215.008}, {214., 215.879}, {211.969, 
                    218.47299999999998`}, {210.30100000000002`, 
                    221.70299999999997`}, {208.191, 224.434}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, {{{212.312, 224.32000000000002`}, {
                    213.02700000000002`, 225.094}, {214.48800000000003`, 
                    226.68}, {214.094, 227.562}, {213.79299999999998`, 
                    228.324}, {212.906, 228.24599999999998`}, {212.754, 
                    228.07}, {211.88700000000003`, 227.035}, {213.371, 
                    227.29299999999998`}, {213.156, 226.941}, {
                    212.71499999999997`, 226.10899999999998`}, {
                    212.27299999999997`, 225.65200000000002`}, {212.047, 
                    224.85500000000002`}, {211.99200000000002`, 224.668}, {
                    212.184, 224.18}, {212.312, 224.32000000000002`}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{274.53499999999997`, 221.727}, {
                    274.02299999999997`, 222.14499999999998`}, {275.043, 
                    224.164}, {275.72999999999996`, 223.371}, {277.625, 
                    221.18}, {278.508, 214.062}, {279.055, 
                    208.73399999999998`}, {279.055, 208.73399999999998`}, {
                    278.203, 208.02700000000002`}, {278.195, 208.137}, {
                    278.195, 210.977}, {277.055, 219.656}, {
                    274.53499999999997`, 221.727}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJ5IGYC4m8aMf2HGHMdFrlu+/x3So4D1/XFBbbvchxc
unOe/z6Y46DK1jjVWT7XYUaeUPOBSzkOF5Ru/6xTy3XYeqJs3/xNOQ4FtkAd
HlC+XI6DuiHHGplZuQ4XQerWZTsc9zbvdLyR63Dz3Pfgx57ZDnG7PHmYXuc6
vKuxN43TynZgAIE7uQ5hfLqb5opnQ/XlQsw1garvz4WY65Xt4Jjw9IJSfq7D
vvlS+ndnZDuEg/TF5zrIRqVY35+d7RAK4jvnOrS+DtwhtzDboRBkDkOuw+Ol
s48oyGQ7FGVMfFtTDnWnE9T+kBwI7ZPt8BbkrrAcB/27KmyNW7MdgL4+tTA0
B6L/STaEBqoH++cn1H85OQ5WW4AB8D8bYm8uVP4h1Ly8HIdYkD+2Z0PCGage
HO6xUPuX5EDCNyrbAej7rD0XciDmRkDlTXIh7p4O1e8Bja8T2ZBwi86FqPuT
DbFHHOr/RKg9SPELAHwZ1xg=
                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{275.688, 209.297}, {276.03099999999995`, 
                    210.25}, {280.578, 217.883}, {281.176, 219.562}, {
                    281.47999999999996`, 220.375}, {282.789, 218.176}, {
                    281.512, 216.98800000000003`}, {280.395, 
                    215.98000000000002`}, {277.09, 210.562}, {
                    276.47299999999996`, 208.66}, {276.188, 207.805}, {
                    275.328, 208.21099999999998`}, {275.688, 209.297}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4g7HhKcXthU6vK2xN40TynY45m3e6Xik0AEk
rFSe7TA9T6j5wJNCh2qRde4PmbIdHi+dfUThRKGD/l0VtsaTWQ5a7WI3z82G
yhdlOVxQuv2zrq/QIWMi0MSzmRDzPAodVn285Ju0JdMhKsX6vr9pocNxkPia
TAcGEBApdPABchOOZkLM5yp0KAIZcDnTYYdc6+tAtkKHffOl9O/eyHTYcqJs
33yeQof9IP6fTIh9EoUOEw591Yh5nemgsAGoU7PQodCW6/riC5kOuc9/r/zo
U+iwFaTvFFQ+vtBhkeu2z39fZEL80V7ooMrWONXZPAvinhWFDnG7PHmY5mc5
wMLnIsgeYPgAAIpRiv0=
                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIxIGYCYnVDjjUyu3IdjnubdzqeyXSw3HKibN/mXIdF
rts+/z2S6bDq4yXfpAW5DlzXFxfYHst02AqUnj8v14EBBPZkOjgmPL2gND3X
AWzONIR8tcg694dNmQ5va+xN46blQug4KL8v16E4Y+LbGutMiL4yqH4rqP3l
uQ4gan5YpoNLd87z35VQ9dVQ98zIdQjn0900d30m1J5cB1W2xqnOmzMdCmyB
Li2B6t+W6aB/V4WtMTPX4ZtGTP+hk1D9FVD1lzMdjoH8PQWq/lkmRHxxrkMo
yPzHmQ4XlG7/rNsG1X830wHkDPu9uQ5WIA23ofbvy3W4ee578OOLUP8ghScA
Tmyjwg==
                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxdUksohFEUHo8skIUUeYW8IsZGEsYnC4kUitJ4JMr5uxflsfCYmkhZCHlN
iVlo2MjCa6EwSZEibCw0IRsbrChN5L/OXbl1Fvc793zn+865ye09dZ1BFosl
wIwUMwLNeB0pzW9Zl/jMtE+ffBOqCibL2pwSXbNmxkdoOagMD2yVsKhzTTh2
x1p9xRLNCt8gDEdtVTzlSoTerfWWLBLSQpwL5VbJuIP4XYaE1Zca4iTC3vng
kTtRwtUdOeatIxTumkCQrq8h9KnGfsF96wl5qu5V4NmzfJpkJzRG5GyvvAt+
P0Gs61Ew3qP13ArmbyK8KX8XAof9czHBNsKQyu/revP+59MjWJdN843r+nbt
d15gaskEOgg3KfdfjivBvAbx3C513kWYPvnItD8L9rFMaFC6/JpvVff7FqhW
cx4g9hWu5z9KiG/qKHqIljyXMe0/QSJB4TuEMKU7S7Iur+arlThS9xfCmVpg
r2S/P5rfJZGu9hJncH5TYkbpzDbY94HE3z+IMPD/P/wCd4HqJA==
                    "]], 
                    
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJVIGYCYuHmA6cW6uY56N9VYWtszHSQjUqxvs+f51Cc
MfFtTXWmwyLXbZ//iuQ5+Jh3OiaEZjqA1cvmORTacl1fHJDpwAACOnkOLt05
z397ZjoARQtsnfIcHBOeXlByz3TYeqJs33yvPIe4XZ48TMWZDheVbv+s88uD
mNuSCdEXCLVfMhNCV+Y5VIusc3/olOlw3Bto8YQ8iD0xmQ690/OEmk/kObyt
sTeNs8t0eLx09hGFB3kON899D34cC3XvB4R96oYca2S+5UHc3QiVf5HnAHRF
1p4FmQ6trwN3yD3Ng6hbBVV/DuqepZkOEw591Yg5nwfxRx/U/gt5DmpsjVOd
q6HhcTDPoR+kLjkT4q51eQ5FoPBLh9q3JM8BxLXPzHQI5dPdNHdzngPImAPT
Mh24QeG1Ks/BCRReixHqwf5ZCXXf3DwIvRIa3jOg7l2UCfEHMHzA4TQj00EV
5K750PjJyYS4qz3PoQoUnmmZDiBlCZl5kHiOh5oPDG9wOALjY/XHS75JOVD/
dmVC/OGcBwmH+ZmQdGEPTQ+tUP8jpR8ATgcJtg==
                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIxIGYC4oyJb2vsRfMdZuQJNR84lekQt8uTh0k732H/
fCn9uxcyHY55m3c6qiD4QNWmcW5Q/ptMB8stJ8r2Bec7xIL0fYfKh+U76N9V
YWu8memwyHXb578h+Q7fNGL6D53NdLiodPtnXVC+w81z34Mf78x0qBZZ5/7Q
Kt+BAQROZDqE8ulummuc73ABpG5bpsM+kD0a+Q5WIHvmZzqA3aubD3FndqaD
MNDVCzWh9oVmOqiyNU51Vs93uATS75UJEQf6b8Khrxox3pkOslEp1veF8x0e
L519RCEkE+JvvnyIu/MyHfpB6sSh7unIdABbK5bvcOtnXdaeFVD/AflgczZD
+Wz5Dj7AYEo4CnUfUngCADiJmEQ=
                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{244.664, 208.434}, {244.5, 207.691}, {244.512, 
                    207.08200000000002`}, {244.512, 206.57}, {
                    244.55100000000002`, 206.16}, {245.30100000000002`, 
                    206.42600000000002`}, {245.297, 206.477}, {245.262, 
                    207.129}, {245.41, 208.02700000000002`}, {
                    245.21499999999997`, 208.281}, {245.11299999999997`, 
                    208.414}, {244.70299999999997`, 208.57}, {244.664, 
                    208.434}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJlIGYC4mPe5p2OX3IdnBKeXlD6neVQLbLO/eG5XAfZ
qBTr+9lZDnG7PHmYZkP5pxF8/bsqbI2ZUL52rsPbGnvTuHdZDjfPfQ9+HAhV
H5/lkDERKPM2B6J+K9R8pVyH2z/rsvaEZDkcB9lfkOMgA1J/HKr/YQ7EPc5Q
84Oh+juzHEDKE3ZC5Y2zHML5dDfNPZ8N4XdD7duYA7FfOsvBcsuJsn3MuQ4F
tlzXF7tkQewtyXUwAJkXm+WwFSg9/xOCD9aXnwfng+19mOew6uMl3ySgfgYQ
MMmHmw8OPyDfCmSPNNR+03yHx0tnH1GQyXIQaj5waqEpQj3Q9U8vcBXA3Qvi
KunnQ8LPCOreyflw/15QArqYDarfGcovy4eHF9g9R/Lg4QnW9zMPHt7750vp
352SB48PML07Dx5fYL53nsMtkP6MLIi/ffPg8Q02RzIPnh4ACz7tng==
                    
                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGI5IGYC4q0nyvbN18t1EFnn/rBqTawDjN984NRC175Y
h+Pe5p2OOrkOXNcXF9gmxTpYbgEqUM91kNa/q8KmGevQ+jpwh5wsJp8BBAKg
+mVyHfaWTJZgyYt1eFdjbxonlesQv8uTh6k51qHAFmiyRK7DfxCYHuuQMfFt
jb0o1LyNsQ6Pl84+oiAA1X8u1kE2KsX6PneuA1C3dvuzWAdVtsapzuy5EPp3
LMSdTFD/8MRBzPub4/BNI6b/kGwcxH1fcxxu/6zL2mMS56BuyLFG5lWOw7bP
f69UBMY5TDj0VSPmf44DN8icXVD1nLkOD6uAJi6MQ3VPX5zDMZD/RHIdeqfn
CTU3xDnsmy+lf1cC6v5CqP3A8DAAchtj4xxAyhMUofrd4hyEQAGtmuvgBfKP
HlS/Ri7EvaJxDk4JTy8oaec6VL5UM+T4EwsxRxcaH48Q8QWOl+MIPiw+ATDa
x/g=
                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxlk19IVFEQxjcLoaiXjAhLrTDwbV8KqQi/xSSieiihKJqTWEJBo5FStJRh
i2wRaiZa0B81NSMlyHQrJZOltD8QGQsVISJSPURIRElE1Mw9xy7lhcPwu3fu
OfN9M2dZYcm2opmBQGCGrJWykmRdy4t9/ZVgdC7ZtW/tUYN/eIfB+rMHP/4c
dpxjkCZh9DmjdH/t5+NBg7cvJvPHHzvOMDb2MaIL5UuKwcPG1OBIJ+OAvM6Z
Z1D5aeu99Nsuf4IQ0KebMbgp+0zoDWGzhIIexuruJ0f6hwgXiudHBmKM9y+X
v/sRIxzW/+4yFtzaMBZu9XmN5tf4PCzp5acIoQL5cyq/jCBVrDKyX3AkM7mi
iCC7P2uW8zTkbSfc/PJqS6HU4+kOufwuRpUWkkXoVz03prP1hzCkOoT39G6c
m5RPII3tjBXJFfW5ewnfs3bXxNucP6VOfyuj68pE+2CEkKKFNDPmvG45tO48
2X40MR6U1S2a1UA2XnV8nWwdF53eONlz6lw9o2T7U+V40uWfZuSqvtnG5kdc
f9IMesTGxrDrT7bjYsZYWBzcaWBUz0nGHa23z9g+RZ3eFoNz8W+ikHFCbOut
dfNRz/itT9SgQ/29zMjQQSg3f/V7fh/z52WKvX4M+OzFp4wPOg/VPi/Wht53
+yWmc6bq7DAYb7v0aKmw977JWD+E07WeBnd+wvlb7d8HHdvKyH/3Q+7LH2aC
gDg=
                    "]], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {CompressedData["
1:eJxTTMoPSmViYGDQBGIQffPc9+DHuXkOVltOlO3rj3XQv6vC1piY5/CwSmSd
u2aswzeNmP5DkXkOBiBx3ViH/kNfNWKC8xxq7U3jdlnGOlxUuv2zzi8Pos43
1uFdDVDCK8/Bi4dJuz0Oqt49z+F14A651uJYB6HmA6cWuuY5ZE58W2PfG+sg
G5Vifd85z0GuFahiWaxD3C5PHiZnqP0HEXzRde4Pq+7EOhTYcl1fbJHn8PQC
0OJrsQ6rPl7yTTLIc/BLEoiwvAK1XwvBfwviyyH4vdPzhJpF8hxmAKkDt2Id
CkHm8eQ5rJEBOuR5rMP++VL6d1nyHNrFgCHzOdZhkeu2z38ZoHzmODi/OAPo
AXEEH+xexzgHoGkFtmxQ/6RB5QXyHP6DQHscxL/SeQ4gZ+1aGefweOnsIwoa
eQ6XQOG4Kw4SPqYIPljeAcEvAtkLDE8RUHhsiXMI49PdNNc7zyEEpHAFVH1A
nsMbUHjPjoOEHzC+gLqz9vTEOTCAQEieQ+VLNUOOGqj7QqDxkx0Hif/QPAcg
OdXZG8EHmyeN4EuDGB9jHVRB6sKh4Xkp1mErMBnNj0LEn495p2NCLNT8zbEO
lqB0lpznEA9y1+JYB/T0BwCaCyN9
                    "], {{241.98800000000003`, 
                    120.91400000000002`}, {241.92200000000003`, 121.32}, {
                    241.71099999999998`, 121.523}, {241.344, 121.523}, {
                    241.18800000000002`, 121.523}, {241.04299999999998`, 
                    121.48}, {240.914, 121.395}, {240.781, 121.309}, {
                    240.71499999999997`, 121.23400000000001`}, {
                    240.71499999999997`, 121.16799999999999`}, {
                    240.71499999999997`, 120.953}, {240.97299999999998`, 
                    120.848}, {241.484, 120.848}, {241.648, 120.848}, {
                    241.816, 120.871}, {241.98800000000003`, 
                    120.91400000000002`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJVIGYC4nA+3U1z+fMdtn3+e6ViZayD/l0VtkbOfIfb
P+uy9ujEOmRMfFtj/zfPYW/JZAkWu1gHl+6c578/5jkscgXqiIl1KAIpeJ7n
UGNvGrerM9bhDkjfnTyH3ul5Qs07Yh2+acT0H7qY5zADyD3wK9Zhy4myffOP
QeUD4iDm74Wa/y/Wwce80zFha57DwyqRde4HYx1U2RqnOq+H6p8V69D6OnCH
3Mo8B6Dsw6oSqPxiqPpIqHvnQvmeUP7MPAcvHibtdqD7q0EaJ+U5bJr7fvkx
41gHdUOONTJdeQ4hj5fOPqIR61AM0tCd58AAAgtiHUDOPDAtz0EeZPG+WIet
IPfPy3NoPnBqoes1hP2eIPOfQcNnJdS+f1DzgO7nvr64wFYqzkE2KsX6/mYo
3yrO4bg30MM78hwuKQFDPArK35MHiYdWqPr9eQ5vgN5u3R3n4JTw9ILSaQQf
7P5LeRB/AtXvmy+lf/cG1HygeRMOfdWIuY+wDxy+T/Mc/JMEIixl4hz6QB58
kweJf8Y4hwJbruuLv+Q5XAS551UsRN8vqP5bUP8yQ9PHkVgH9PQDAPNPDX8=

                    "]]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0.74902, 0., 0.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}}, {{0, 2, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 
                    0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2,
                     0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 
                    0}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}}, {{0, 2, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}}, {{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 
                    0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{1, 4,
                     3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}}}, {CompressedData["
1:eJxTTMoPSmViYGBQAWIQnfv898qPRQUOLt05z38LRjq0vg7cIVde4ODFw6Td
/i/CgQEEqgocVNgapzq/jnBwf1glsq66wKF3ep5Q840IB2/zTseE2gKHvSWT
JViORTgc+qoR019X4AAypnV1hEPGxLc19vUFDtL6d1XYOqHmlUHVt0H5QPsX
um77/HdJhMPVipdqhnkFDpkgfXsjHB74A23KKnCQBznsXISDwoaijInpBQ6V
QGUcdyIc4nZ58jAlFzg8u6B0++e7CIctJ8r2zY8pcLAEMdgjHY6BHBgGda9C
JETcH8q3gPrXs8DBCiweCbHPqcChGOTw9EgHPt1Nc99bFjjMACo/0BQJsV+/
wAHo2isVC6Hy2gUOIuuAIbMm0kG4+cCphZoFDn5JAhGWWyIh7tEocAh5vHT2
kR2RDuX75kvpq0PN3x/p8OmSb5KAWoHDIpD/z0DlVaHh9TDSARiKrwNVoOHz
Bep+5QIHkDWufFEQ9yhD7dOJgrjHGereQ5GQ8AwocLgEDJ66WZEOO0HmRRU4
PAWFVxmUn1Tg8B8EwiMdQMJ1GQUOx0Hh5gB1Xx7UPZqRDujpBQAOoQIS
                    
                    "], {{256., 104.609}, {255.879, 103.121}, {
                    253.49200000000002`, 103.184}, {253.672, 104.703}, {256., 
                    104.609}}, CompressedData["
1:eJxTTMoPSmViYGBQBmIQ/bbG3jQupcDBP0kgwrImwsGW6/riAs4CB4O7KmyN
vBEO3uadjgkf8x2cu3Oe/86McIhKsb7v717gANK262SEg+WWE2X7nKHq70Y4
LHLd9vmvQ4EDkDfV+XWEw2QJljA++wKH+F2ePEyfIxwYQMCmwGGNDNCk/xEO
h75qxPRbFDiEPF46+whHpAPIuPkmBQ7FGRPf1vBHOoDdB+TvLQGa9C/C4TBI
vVGBg3zr68Ad7yIcyvfNl9LXL3AA2nql4mGEg1a72M1z2gUOfiD/XIlw0Ae5
S73AAeQt21MRDlcrXqoZKhU4bJr7fvmxw1D90gUOqiD37obKixQ4cIPU74LK
8xY4HAcFxIEIh2Mgmq3AAegb7fZjEQ4gZ8gxFjjMyBNqPnApwiGMT3fT3N/5
Drd/1mXteRLh4AIKN2D4gf0D9O8dkPibfEh4KEdCwuMNVN4/0kENHG75EPsa
Ih1unvse/BioHxyucyIdPl3yTRJgKID4a2kkxH2c0PDbEOkg3Hzg1EJRqPuW
RTqAjLVXLXB4ekHp9s+2SIdqkXXuD2Hhmw7lA+OrdzrQAw5Q9Z7Q8BKChj9S
+gAAf3fwHg==
                    "], CompressedData["
1:eJxTTMoPSmViYGCQBGIQfeirRky/XIGDFw+TdrtdpMNxb/NOR6kCh+YDpxa6
ukU6dDgmPL0gVuAQu8uTh8k70uEYSF6kwGGR67bPf30iHay2nCjbJ1jg8OyC
0u2ffpEOtlzXFxfwI/hRKdb3/XkLHPySBCIsgeqXzT6isIGrwOFhlcg6d89I
h2og9ZCjwEGVrXGqs3OkgwxIA3uBwyWg9jqrSIec579XfmQrcKi1N43bZRjp
0Po6cIccUB5o+5UKzUgHkPXzOaDmKUY6KGwoypjIWeBQ+VLNkEMm0qF833wp
fe4Ch97peULNEpEOIOcnAN3zFOQ+sUgHd5BGoHv176qwNYpGOny65JskIAT1
vxjUfBGofZJQvhjC/Lc1QIdJFEDCQT7SQbtd7OY5yQKHjIlAGVWofdLQ8NOO
dMgF+UcG6l/jSAf08AcA2MWlpw==
                    "], {{251.82000000000002`, 
                    102.141}, {251.47299999999998`, 100.664}, {249.105, 
                    100.883}, {249.465, 102.371}, {251.82000000000002`, 
                    102.141}}, CompressedData["
1:eJxNU2tIFGEUXZaQkojQCiGzEsP+SPkjw0Q7VtLDXqY4N5PNVrMU624WJibC
IhISIZFREGIW0o8syuxJxaJhEVH2kLRVwiRDJUIqRULsuzMXbGCYGe537zn3
nDPLvbznoNvlcqWYW54Xj4ZVBxb5cFZeIggdf1bm1rl9eHrifMSsEIJdH2e0
ROYUJE1bqBnNeBg1zCg696Ny/ZSFwebLz5f1Mda1vSx7Zuqped+6ot8y3kUH
J6vcBM/jrXPdHfodSsieF9fa8IDRmb62NtXgXU27/2vq9kz/YZnbzBCYmlHL
4VXPzpyg1msZLrm6LNwYe7/DW6n8XlgIrw68ajrCTl/AcubvZqwI8V/YeNdy
9knQ+eGEunazcCYjy16EHJ5eRqLwiSX0TVYVPylhrO6PCfHHEUI/XfMllzI2
nSn5/jeeILBfTjLM1sHJBMKpBbc2D1QxjttEdf5pRozgpxNi42e3RJp6lAiZ
TRCYxjLGUvn2qB4+xn7ZN58cnCLGtFyHCEsEL58xUGGAigj3pN+j+IWEY8mG
YS47/hWq/vsYO73zKbGAMG7sbd/LMCgfyw+QoxMxhqTf4JcKb4txSXTKUX7Z
jCbhlaX8t2l/BsEsucaTwtgl8yvJ8TFJ89Gg5zcwgqJjm+JtUT6vyfHR4Nu8
+pW/2X/xKiP4MKH3zUTmYK32/yZH10b1e4Igx/x39PyY8jd5s30e0fMmjwuN
LRV9hDDJRzdDHmmdqneP+vlI+X5WPjcJEtO8Xs3HFeXfo/zrCdul3q39ft2n
i52cFJOTow8z/tgx61E9jR92TPoZEpuKAtXzK6O14ef1TuO/2DwwNFO38zWi
/M08O+9zfA6/cv1f//uf/wFpEcg1
                    "], CompressedData["
1:eJxTTMoPSmViYGCQB2IQvfrjJd+knHwHLx4m7fZ94Q6LXLd9/uuS78B1fXGB
7aZwh7hdnjxM+vkOKmyNU51XQ+Vl8h1cunOe/94Y7lAtss79IV++gydI/7Fw
B1WQuv95Dnd+1mXtuRPuINx84NTCj3kQebYIiLnP8hw2zX2//JhzBET/JSh/
dYTDRaXbP+vO5UHMORzh0Ds9T6j5RJ7DQpC9VyIg9h/Ig4g/iHDwMe90TNib
57C3ZLIEy7MIB3VDjjUy2/IcDO4CXfw2AuL+1VD7v0U4rAL5d0eew5vAHXKt
0ZEOsSD543kOr0F870iIfqB7LoHcYRUJ8efNPAdpfaCBmpEOTglPLyg9znPw
SxKIsBSJhJj/Os8h5PHS2Ud+RDh4g9wD8++1CIcZQGce+JcHCd++CIfjIAUc
+Q6bQf6NjnAAGdsomO/wsAoYEJYRDu9q7E3jpPId1shEpVirQ+UV8yH+lYDy
NfMh5gpBw8soHyIuGuFw89z34MeR0PhRjHBAj18A0DPWew==
                    "], {{
                    246.125, 100.62899999999999`}, {245.33200000000002`, 
                    99.23}, {243.08200000000002`, 99.75}, {243.883, 101.16}, {
                    246.125, 100.62899999999999`}}, {{247.434, 94.293}, {
                    241.824, 93.785}, {241.484, 95.367}, {246.19899999999998`,
                     95.793}, {246.07399999999998`, 96.051}, {245.906, 
                    96.262}, {245.695, 96.43}, {245.586, 96.523}, {245.336, 
                    96.67999999999999}, {244.95700000000002`, 96.895}, {
                    245.375, 98.34400000000001}, {245.895, 
                    98.05499999999999}, {246.27299999999997`, 97.738}, {
                    246.512, 97.395}, {246.758, 97.04700000000001}, {
                    246.95700000000002`, 96.52}, {247.10899999999998`, 
                    95.812}, {247.434, 94.293}}, CompressedData["
1:eJxFVAlIlUEQFotXeUTlI8yreiVaURqaoqKOmpSGRmXsEmpeRZa7XlHiBVES
YgcRURQiFhGUCEmFSIdE2AGFVGgm9hLNihC7y8xsd2d878HjZ5jZmW++b2aW
5hVv3eXq4uKSq/76+zM48+T9LAn947V7bxcwGLp84cGSjRIOdz5pTt7NYLQ6
fl12hIRb3yZfVhQyeLgpsj4hWEKqh+uqo5JB0NrZLX4+EgIth84klZPfQ8I5
ueBwZyXD7z8B6XnzeNQRBok577pt34TDf7fJJ2Tgg8D6+xn47yiIsdsFrG8o
ej9RyiBBx/cKKN9zarS6mEHfs1/bhh4LWFz3aUu7qn/1y/O0vHYB0TceHbir
/Dosvl7Azo4UD1eF55r2Vwtoaxy70qVst95LJbFlAjJ0oxWEZx/VO0T18wUs
1/00MEB+BLjrd+cZlMSqDFzASLetf7yVgYYRkEb9KL/pAwRYWzcMVh5jyEuY
s/8ojTNIQKHGWcMwrw/lV3zcVO4mN4HvqqifwSK4s/+098xast8VYb5hip8r
UJ9BBlW6sE2Ai/69ZfgNF6jnCOmVSHi+E38Z5Ldw1Dub+FvGkY+dAnlL5Zhf
8WdwJHPMV0b9xHLQ8ueUUv5wDqWarxIBSZrfFZx0Ir0Wc9S3mOKtHPuRAnma
RfmVna3xTBDfKr+Zs88MyjSQgwJa/BTQ9zQfNdTPGwYhA0rJOuKnj/o/IcBX
O/pI3+sCUvQ89xC/ar6ak/ULin8toEvXe8Xg+Fkl9LCTX4PnC+X/yEDDsP8S
sFn385fBRZ3nN7335ph/nPAFEJ9/BOg0dYpvo7Palyn9CyL+pwTosp0rOWyf
u7qtcQbt3xqO9edInO8wjvNppf2N43BP75eV9jfKaRt9VbyZV2VP559+b+bZ
xrFfZYdqHv05zouyjR6+hM9Lov6eHLx04fnSoZexPSXuwzBz5DP7bKf99KP4
fuIzUKKevaTnarovL+geRErUv5thPyBRx6ekXwL130P7Fy8d+2HqxFD+MQZ6
zJoiCP8k7Xe4xHmwEF/KNvfAnfheJ6FGrUnHfNJLvQ/QjoUcTt7/EZyp8Jl7
sojjPEQSfl+a52iJ90Ppb/YqTiLuQOKbS7xv6VQvi2ylp+k7R+L8hXLkJ1c6
9tXMR75EXAqPuecFZFsIXz7p+3X6vjnv/391iJxl
                    "], {{234.414, 
                    100.12899999999999`}, {232.996, 99.12499999999999}, {
                    231.93, 99.785}, {230.879, 99.}, {229.47299999999998`, 
                    99.848}, {230.812, 100.80499999999999`}, {
                    231.94899999999998`, 100.16799999999999`}, {
                    233.04299999999998`, 100.96900000000001`}, {234.414, 
                    100.12899999999999`}}, {{232.18800000000002`, 94.02}, {
                    226.695, 94.918}, {227.297, 96.46900000000001}, {231.914, 
                    95.71100000000001}, {231.94899999999998`, 95.98}, {
                    231.918, 96.21900000000001}, {231.816, 96.426}, {231.766, 
                    96.535}, {231.629, 96.742}, {231.40200000000002`, 
                    97.035}, {232.629, 98.277}, {232.945, 97.883}, {
                    233.10899999999998`, 97.49600000000001}, {
                    233.13299999999998`, 97.117}, {233.156, 96.738}, {233.035,
                     96.199}, {232.766, 95.504}, {232.18800000000002`, 
                    94.02}}, CompressedData["
1:eJxTTMoPSmViYGCQB2IQ7dKd8/x3YY7DGpmoFOv14Q4MIOCT47Dt898rFQfD
HapE1rk/NMtxeB24Q671dLjDjDyh5gNaOQ7NB04tdL0X7gDSdl89x+EhSOHP
cIdVHy/5JqlAzROPcHBKeHpBSTvHYdPc98uPOUdAzLfJcZBvBZpYF+Fw62dd
1p6IHIf4XZ48TI8jHFTZGqc6x+c41Nqbxu36GeFw89z34MeJOQ63Qep4Ih0K
bbmuL07IcdgMMk86EmJeAlS/cqTDIlegy2NyHLx4mLTb9SIh7gvPcdhbMlmC
xS7S4W0N0OC+HIf/INAe6VCUMfFtzeQch+Pe5p2OBZEO+ndVgC7IcQCHS2Qk
xD9Tchy+acT0H3KNhPhnMtQ8oPlg9/VC3SsIVd+S49A7HRhQHyIgdEGOQyzI
fasjHC4qAX2SBDW/MsJhwqGvGjHROQ5yoPAIi3CIA6mLhoanY4TD1hNl++ZH
5UD8aRABCf+4HIg7VSMc+kH606HqFSMcfIDeSAC659kFoEV8EQ7o8QsA9SzW
8A==
                    "], {{224.75, 100.67999999999999`}, {222.824, 
                    99.867}, {221.5, 101.15599999999999`}, {223.445, 
                    101.977}, {224.75, 100.67999999999999`}}, CompressedData["

1:eJxNUwtIk1EUHiOiZIXUEKtl7wfUUpMQNdtXJLWeVMa9SRlISe38lD3psYyI
MMseEpgRMpYEEiL0spBaElJRITmCitAaChllKFJS4ere/54eg3E599xzzvc4
/6SinWu3Oh0OR7b66/PbzI3nHg4S3n4vDdz7LHAlr7F/sJewzOWcVdYqcK0v
urKoi5B168n+yB0Bh/69JuR3Xr3cUieQre+fEY745hU2XRK4v/dC8pAI4fHy
zPKF5wWqd4w63txAcDcsiR2qEBAjvTdqQlx/UmBXbsKr2gpC22SF4JRAavvU
ocf2cb9KYe4L+X21MH2XEsqS3rQO1AoUNvldzgzCZn3eFFC36zqHE85cVINf
CKjuJblfAqa+l+vfB7CqKFFmuaXJRwPYs62yJ5gpDV4V22eBxOLT1oefsQAm
nPi05m6pxGFNRPXbrp77arg+HoBf69UojT6JBD2++anEes13CmGcJhaTmJE+
rN6ziBDVvH5Iox8RUnT/pA3QR4rib+sYlyjR+uQTwtqXLp63gAyuNmn4pnO+
RcL2c9ofvxiPh/Wok8ZPN8+rkritnoUSyPA/KqFlmuji+cUSkdDY1PZkQlD7
4ed5qr89xysxvmBLzrsc9tfN+hXw/sQFdFvfQfavWxj+Vdy/g/PXCUqscJ6K
z2qcz8no3cH708HzPwqDr5uMbr/Y7x5Cmt6bEcy/j7Ba++th/fvJ+D2b8185
P19ik96bAUK9RxERErs1IBXb30GQ4wzL4H30L7b3M8z6zbWgXr88UC7xQOuV
Zv2tt/F5LcOvmP2fbhk8KyRG68QYy/Cdw/j++x5/A+LsplY=
                    
                    "]}]}}}}}}}}}}}}}}, AspectRatio -> Automatic, 
                  ImageSize -> {{128}, {85}}, 
                  PlotRange -> {{0., 480.}, {0., 320.}}], ",", 
                 GraphicsBox[{{{{{{{
                    Thickness[0.0010416666666666667`], {{{{{{{
                    FaceForm[{
                    RGBColor[0., 0.596078, 0.764706], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {0., 480.}, {960., 480.}, {960., 
                    0.}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0.8784310000000001, 0., 0.20392200000000002`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     320.}, {960., 320.}, {960., 160.}, {0., 
                    160.}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0., 0.6823529999999999, 0.39607800000000004`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     160.}, {960., 160.}, {960., 0.}, {0., 
                    0.}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{536.8009999999999, 240.}, {536.8009999999999, 
                    200.23399999999998`}, {504.566, 168.}, {464.801, 168.}, {
                    425.03499999999997`, 168.}, {392.801, 
                    200.23399999999998`}, {392.801, 240.}, {392.801, 
                    279.76599999999996`}, {425.03499999999997`, 312.}, {
                    464.801, 312.}, {504.566, 312.}, {536.8009999999999, 
                    279.76599999999996`}, {536.8009999999999, 
                    240.}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0.8784310000000001, 0., 0.20392200000000002`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{540., 240.}, {540., 206.863}, {513.137, 180.}, {
                    480., 180.}, {446.863, 180.}, {420., 206.863}, {420., 
                    240.}, {420., 273.137}, {446.863, 300.}, {480., 300.}, {
                    513.137, 300.}, {540., 273.137}, {540., 
                    240.}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}}}, {{{573.105, 211.73399999999998`}, {
                    552.4649999999999, 221.52700000000002`}, {544.828, 
                    200.}, {537.16, 221.516}, {516.535, 211.695}, {526.328, 
                    232.33200000000002`}, {504.801, 239.97299999999998`}, {
                    526.3159999999999, 247.641}, {516.496, 
                    268.26599999999996`}, {537.133, 258.47299999999996`}, {
                    544.7730000000001, 280.}, {552.4409999999999, 258.484}, {
                    573.0619999999999, 268.305}, {563.2730000000001, 
                    247.668}, {584.8009999999999, 240.02700000000002`}, {
                    563.2810000000001, 232.359}}}]}}}}}}}}}}}}}}, AspectRatio -> 
                  Automatic, ImageSize -> {{128}, {85}}, 
                  PlotRange -> {{0., 960.}, {0., 480.}}], ",", 
                 GraphicsBox[{{{{{{{
                    Thickness[0.0025], {{{{{{{
                    FaceForm[{
                    RGBColor[0., 0.41568600000000006`, 0.30588200000000004`], 
                    
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {0., 240.}, {400., 240.}, {400., 
                    0.}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0.956863, 0.16470600000000002`, 0.254902], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{260., 120.}, {260., 75.816}, {224.184, 40.}, {
                    180., 40.}, {135.816, 40.}, {100., 75.816}, {100., 
                    120.}, {100., 164.184}, {135.816, 200.}, {180., 200.}, {
                    224.184, 200.}, {260., 164.184}, {260., 
                    120.}}}]}}}}}}}}}}}}}}, AspectRatio -> Automatic, 
                  ImageSize -> {{128}, {85}}, 
                  PlotRange -> {{0., 400.}, {0., 240.}}], ",", 
                 GraphicsBox[{{{{{{{
                    Thickness[0.00125], {{{{{{{
                    FaceForm[{
                    RGBColor[0., 0.12941200000000003`, 0.6784309999999999], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     1.}, {0., 400.999847}, {799.999634, 400.999847}, {
                    799.999634, 1.}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0.109804, 0.541176, 0.25882400000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{0., 401.}, {
                    800., 1.}, {799.543, 400.703}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 0.776471, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4mqRde4PJ9Q6xO7y5GFSz3SA8YWbD5xaeDLN
YYdc6+tAkVoHBhAoSHE45m3e6WhXA+EfSYLwM6ohfIlEB1uu64sLrKscZuQJ
NR+QS3CYDqJ5KuH8T5d8kwTulcP5GRPf1thvLIPrB/Nvl8LNB/NZS+H2bzlR
tm9+RwncfTA+zP0w/qqPQItasuH6Xbpznv++mws3H8zvzIfbv8h12+e/swrg
7gvl0900V7wQ7n4YH+Y/GB/mf5h+WPjAzIeFH8x+WPjC3Ice/gBATahi
                    
                    "]]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0.109804, 0.541176, 0.25882400000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJyFVWtsFFUUXleigIKI1lhSNisSpdiKqGiEVE6NxhLU+qIxtUC72e2dzu5M
iTiPvTMpj1IJNg2oKEZEYgkxPNT1UVtIrYVUKGh00ZiKpWmhaSoxBYFo0xSD
c+e7LSb7w00m2TP33nO+7zvfuXNHpPr52LWBQOAa73G9JxiQv0dNelefXtt+
r0Z1fzzXEmowaV7P7OvWLUuQc+snT56eYFHFQHpW91mVSqOLeotjFv02UqO2
FsWpt7hhm56y6OjShzcVerG/3mXRLbXtxz8siCPPaRmfVEkbHN1z4U0bdXao
ZLXtnDHv6yTq3B+nw3/NKdtscnq8PjE4mqVlxEdEnddkfLNGmwrLB9JrOfIf
0+iejbed/GEdp7+9Y4ezddRvluuTdOxv4bTwy06z7bxGLSEPSTsnX4dOjRIC
Xxunu+dP3J+zV6PGJ7669E8nB949Gk3J/3zH+V5OAi5v0YD/Cgf+kA7+2Q7N
FH9W6uSpNlITdihL7Hd18MlxoPd7OviEZNymA0eejIPV0PcZme+SDtzLHNp7
4aenI2l5vswBzwM6DbmLF6zw4kfEvo904Io49I0Hs2eLDn3qHOyL6OhHhwO9
GnTUOXY1vuiVmZZ2aJvAc0Snc+LcGYdE2fJDmbGv84hDJVM9ob6TfP906BXl
jSH3qE5zRf0rMm7W6YDQ/6IDHhs08A+5JODvNDXqE/xnuCRk7vk1gfUcF32Z
kxjPt/zgkhuDw/Hx2Of/RRw6TnTh34o4nRD9eN2lFWL/yjj8UOYCd3acdm/v
CKcedHHunEpv3T6hZOpyF3p9oIJP2KUt4s8a6edVUt/vq0jQWlws+/XA/8e+
r+505Nwp434Yi30cAYfKBf6ZChVM7tq1qpvjfaki+8Lhh9kK/NLKMY99DPtS
HP1Zwug+4ZNvOfiPVkKvHzkJGWZtrqRf7LN3ze+Q+V6sBN5m6fffYzRd6LSP
o3/Xx6DPGk5PifwDUfBKchIwC96JYj5icl4Lo+BXI+ezKUJNos/q1djHM5ik
4Rf6d29PReDr2iTliLyDcr04iXm6HAHP9Unw+TSK/ulJ6JdfOR6P8fHnpyJJ
H4uE9QxxnU2rfaIM/KM2/KYw4C2yqVvcd68y5HvIBr9GhvnKs9GfJob5mmLT
PlGvlVG/OBC00YfjDHr1W9D1BKNwylPyZwv8DzH46ZS8Lz9jmI+DFvK9z6BX
xKL9Av9GBj0WyXwLlIzYr08W+lKtyLkysZ6rQKdJJvaVKeB/ykC/cuX+Thm/
LevtMqDnBumvRgP3XAnD/ccMeX8y+O5lA3i7GObtJQM8SmX+rQb03ZoZ+/Pe
YcBvXRJfn4E5PqNAz2ED/pxWhfdBE31ZX4X5uDx2Xs5blok5yFfR/1wT/q9W
kb/IhK+eVeX9YKI/mrwPVpv0mNhfr+JecE34Z2kc3wcmz6/NjP15uMkE3nAC
7yebdIPw09wE9BoywDst77s8+X1eKO/H/3yv/wVdD4SX
                    
                    "]]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 0.776471, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxlVGtsFFUUrrUxvkB5GSoqj/BDwKYmapDK40PFitCoJQXUQkptl7Ld7kx3
trsNVmpn7s6gRolp2hqNJVYRIaQBbCuJBRvF1pBo5OGDYIMIBglQsNWA6BLv
2W9oE3eTuzNn7r3nfI9z79RSo7D8+oyMjOv0WK1Hph4t4bFOz2ACz5c9cvzp
3Ci+/Ove4k0/JfCFPK9GsWqTfhtQaFvUNZTsjiFDfvMVGidmLR99NI7mx14P
nR6nMFC34KHVY2vx3bRjf2+47ODmHz8w512Mw7vj6LeXkg7ztY6sXzL71YUl
RXEcLii9feV0hZ2RirfOZ8XxguDIU5jT8XVs32cx7J+iZ+DXf82vv1ThpfHt
+ScqYgh2RxsnFiqc3PLu/ikPp8epessU952qgc7+RssKBZne+XMN5gnQNxVG
5+x+78KLNXhb9GhSmCqAktG0+NOh5JHaToUi2eBEcX//9BsaDip0aribZ0bJ
98YEBP7mXgvFol++H9da+Er4ZCeIx41As65bMCmBlA9ZI3GK7+5qrruqON9d
TT1OKerZW828dyrE9X/uHAv3aRpbCx38ommG8yx0Cd42G0+eWD++fYuFucJ/
lY1/t/1xqKDDog/FNg6KbxELo0SHiE09CiwMHtIGDdis90SEeq5x2C+N1fTr
isM8SXPY31S9fpP65Pj67jXpS75if7Sa3FemuK7KpI4NPt+5JpokX6u//xaT
OH5V2K7hl1YYxPe7gshc3BcejkWO/j1h3C1AzyiskARGFfXcdy0OUbddComz
z+6556YQ97/j98uOIPukUsESY4z0OOX3oE0fYgH6m2Njx126sFHO/E31WPOb
PhnbAuxbux5LhffeAGZJglH1OC/npzkwvF67Eex+MEA8gVeQK/qUl1OHkw3s
k+wy5ily2C9HAuz/dgclUu+btZgvQp9x0CdC163FR4J/hs93TAXrNSrmmbCO
/s1IsN5zQfq8KIHH9ed/Xg6SZ0sC45yeA+/nVBLfBhePSsGhStb/xOW5afP1
vOjS764QLmztXTI712P8Q4j9+YBHvT+uwuJbM2d5+R6WC9FjVRizUt8EZR75
dPrz6z1cWqY7qSSMjQv1zHY/nx2mP20e5Dqp60uPU/dTs1/vGYO813nsy40G
8S/2588ZeErqZXvIE+IT/P687PLemGziQ1O/fe/y+xUDYvvxAy4E1rTTBvX8
3OV9cdigfx0u6/Wkx5PFmAaXuPpH4mt4Uutvc3leM01+n+SS558R/P8+/w+D
e6zi
                    "]]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0.109804, 0.541176, 0.25882400000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{735.695, 245.79299999999998`}, {735.309, 
                    244.707}, {733.3549999999999, 244.21899999999997`}, {
                    731.602, 244.76899999999998`}, {729.8439999999999, 
                    245.324}, {728.602, 246.812}, {728.992, 247.894}, {
                    729.379, 248.98000000000002`}, {731.3319999999999, 
                    249.469}, {733.09, 248.914}, {734.8439999999999, 
                    248.363}, {736.086, 246.875}, {735.695, 
                    245.79299999999998`}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    150.523, 248.25}, {140.324, 257.79699999999997`}, {130., 
                    248.379}, {131.105, 262.308}, {117.309, 264.508}, {
                    128.88700000000003`, 272.328}, {122.004, 
                    284.48799999999994`}, {135.336, 280.312}, {
                    140.55100000000002`, 293.277}, {145.598, 280.246}, {
                    158.98800000000003`, 284.25}, {151.945, 272.18}, {
                    163.42600000000002`, 264.21099999999996`}, {149.598, 
                    262.191}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{186.71099999999998`, 132.57}, {
                    175.71099999999998`, 139.91}, {164.996, 132.172}, {
                    168.766, 144.63299999999998`}, {157.90200000000002`, 
                    152.16}, {171.23, 152.523}, {175.227, 164.914}, {
                    179.69899999999998`, 152.676}, {193.035, 152.805}, {
                    182.469, 144.883}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    237.266, 180.226}, {227.066, 189.777}, {216.742, 
                    180.359}, {217.848, 194.289}, {204.05100000000002`, 
                    196.48800000000003`}, {215.629, 204.30800000000002`}, {
                    208.74599999999998`, 216.469}, {222.078, 212.289}, {
                    227.29299999999998`, 225.254}, {232.34, 
                    212.22299999999998`}, {245.727, 216.23}, {
                    238.68800000000002`, 204.16}, {250.168, 196.191}, {236.34,
                     194.168}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    60.870999999999995`, 149.672}, {50.672000000000004`, 
                    159.21899999999997`}, {40.348, 149.80100000000002`}, {
                    41.452999999999996`, 163.73}, {27.656000000000002`, 
                    165.93}, {39.234, 173.75}, {32.352, 185.91}, {45.684, 
                    181.73399999999998`}, {50.898, 194.695}, {55.945, 
                    181.668}, {69.332, 185.672}, {62.293000000000006`, 
                    173.601}, {73.773, 165.63299999999998`}, {59.945, 
                    163.61299999999997`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    152.54299999999998`, 33.}, {142.34, 
                    42.550999999999995`}, {132.02, 33.133}, {133.125, 
                    47.062000000000005`}, {119.324, 49.26200000000001}, {
                    130.906, 57.082}, {124.02, 69.242}, {137.35500000000002`, 
                    65.062}, {142.57, 78.027}, {147.617, 64.99600000000001}, {
                    161.004, 69.004}, {153.965, 56.933}, {165.441, 48.965}, {
                    151.617, 46.940999999999995`}}}]}}}}}}}}}}}}}}, 
                  AspectRatio -> Automatic, ImageSize -> {{128}, {85}}, 
                  PlotRange -> {{0., 800.}, {0., 401.}}], ",", 
                 GraphicsBox[{{{{{{{
                    Thickness[0.0020833333333333333`], {{{{{{{
                    FaceForm[{
                    RGBColor[0., 0.686275, 0.7921569999999999], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {0., 240.}, {480., 240.}, {480., 
                    0.}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0.996078, 0.772549, 0.047058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}}}, CompressedData["
1:eJxlVg1MlVUYvhKhY8hMjQiwAcMRukZazhrce9/vfB8jVNJqIRTdEd3vrxUI
knPK2hwRmiEaNnNUpMYKctaaojMiBmIg2SxLc8kcMn+WWYmTZobrnPO+9zsz
2O7Ys3Pu+z7neZ73nJtWXvm0eZfP55vCP1v5J4p/HtuklV1YkQufXfuxsDzX
hAj+9ebrL3d9FIZwzrnljSsB8YowFD++f2BNPPNwicAhw8MHr0/8tHZnHtRf
eerQA+0K787rvD6RYnr4wMCa7taQCZ0Cu3mQ8hzv1GBC446KmXV/GbBfrB+d
jH3iL1WD2NN7Vvl7bYh/6MsP/swPwol0zuBNB7JKm3pvXA5A6HBBXFSrg/+H
ArB+9r78kcMKC9rdo/9bT3fB2PzKpVslgPWKXFx/XsO+xS6ew2CQPZwRs6HE
hYaEM9//reuI0xSeVddzbNeI4+HRtpYjqdsdePXSrfZruxmuVzlwbJcoqHm4
78aDpU0LFW4/unTxphHwzhfBmQum7U3pUFjy7HPgU4Hv0WCcl+k97sCSuKj5
DUUKS/7RzMOS30kNWNmFE+nNk/EPou88hv7scGCRaFTN4Oua5sTofaT3E3Se
QQfeP5L6RfVGhv5H6vcxWLaYB+tnOt8Yg/e4rT3nHfiHx6amj+r94cCQ0KOR
gbC9Z1zVl3xvqv6rnW1Xa5Nd+J23qc9hMEfwm++iD/0a+rnQhYAIyrAGnMUz
o3NdrM+x9Pl+F/ue0pBPvAtTN7yrb07RsB6vL333AawT9WIUlvw6HQ9rQi/b
ge2J0UXxw4B+ZzjIbz2Db1qTsocfJX0SSZ8sBwqEPxc19GWGg/3Pashr3Mb5
yyT9Jmyv3tXa4KLQ7clY5mApw3qX6ftTGc7PKRv9jGVQ5efC7KX1lVT/gI3z
/CGDmcLPfhuShaBTdNjay437yka+FkNcacO9XJZ1GTrqERPpl0d+WpQ/A/VP
s0kvA/0sUVj6tk1huT+P9BowQMRaCyscma8IlvOQQP6VGuj/ky6IayK2Qcfz
vabw3Bi+cTXN6ywDzor7q9bF+62C6m1xaV6Jbxv5X6bj/i4X9XxLg28Fvy7K
VyNAtcjnHhfE8RPOBHCeWlzgaW9ONPy4/pKLeTmei3zyKY9Fubif51nIO7si
B/PS73j7xdeDLuHCAN6/0Q7W/Zz8z7Dwfh3U6Twm6nw3na/CxDnIMpD/MoVl
nUyFJZ+hMOp3mqG+HYTvUzhJNFig3bmeD5Q/hSX/6aaH5bxlm3g/vEPvjWHC
RXHx3VZY+hHF7sRjGjwszjWd9nfTPP8Wxvy+SPP3b5jWKe9zTNTpY7pPgvTe
+HT8PjNhjD+LM4p1rF9o4nvziU55NPF+cnTUb62J85hM+WpQ9SPv2zyx/xfi
02VifpYwaBLzdFLxl3qcM0HYXn9Fg26x/5CJeZ/GMIdvK30i2C8fRoV14V9B
EJ4VxOtMzOPOgMdf5mtLwMvHILcpqTKA+x+xJmHUI4DzUGXh/L9B/VZZyCdE
frxg4TzGaZjfNgv9Kie/hyz0/6Af+/daqFdNAOt9Z+F/COL9dl5h9Nv2sHzP
822aEz90iN8zG21vXqS/LTb2Xa5+7/wH58Ld4w==
                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{266.469, 175.172}, {268.355, 174.824}, {
                    269.29699999999997`, 175.859}, {269.578, 
                    177.26999999999998`}, {269.949, 179.15200000000002`}, {
                    269.14500000000004`, 188.63299999999998`}, {
                    269.14500000000004`, 188.63299999999998`}, {
                    269.14500000000004`, 188.63299999999998`}, {
                    264.77299999999997`, 180.184}, {264.39799999999997`, 
                    178.30100000000002`}, {264.121, 176.88700000000003`}, {
                    264.58599999999996`, 175.547}, {266.469, 175.172}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{273.348, 173.086}, {275.133, 172.375}, {276.254, 
                    173.207}, {276.805, 174.535}, {277.539, 176.309}, {
                    278.60200000000003`, 185.762}, {278.60200000000003`, 
                    185.762}, {278.60200000000003`, 185.762}, {
                    272.66400000000004`, 178.32800000000003`}, {
                    271.92999999999995`, 176.555}, {271.379, 175.227}, {
                    271.578, 173.82000000000002`}, {273.348, 173.086}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{279.691, 169.695}, {281.301, 
                    168.65200000000002`}, {282.562, 169.25}, {283.363, 
                    170.445}, {284.42999999999995`, 172.039}, {287.312, 
                    181.105}, {287.312, 181.105}, {287.312, 181.105}, {
                    280.043, 174.97299999999998`}, {278.977, 173.379}, {
                    278.176, 172.18}, {278.094, 170.762}, {279.691, 
                    169.695}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{285.25, 165.137}, {286.621, 163.797}, {
                    287.97999999999996`, 164.137}, {288.9959999999999, 
                    165.15200000000002`}, {290.355, 166.508}, {294.953, 
                    174.84}, {294.953, 174.84}, {294.953, 174.84}, {286.621, 
                    170.242}, {285.26599999999996`, 168.883}, {284.246, 
                    167.86700000000002`}, {283.89099999999996`, 
                    166.49200000000002`}, {285.25, 165.137}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{289.809, 159.578}, {290.895, 157.996}, {
                    292.29299999999995`, 158.062}, {293.49199999999996`, 
                    158.863}, {295.08599999999996`, 159.93}, {301.219, 
                    167.19899999999998`}, {301.219, 167.19899999999998`}, {
                    301.219, 167.19899999999998`}, {292.15200000000004`, 
                    164.316}, {290.559, 163.25}, {289.363, 162.453}, {288.742,
                     161.172}, {289.809, 159.578}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{293.199, 153.23399999999998`}, {293.957, 
                    151.47299999999998`}, {295.34000000000003`, 151.266}, {
                    296.668, 151.816}, {298.441, 152.55100000000002`}, {
                    305.875, 158.48800000000003`}, {305.875, 
                    158.48800000000003`}, {305.875, 158.48800000000003`}, {
                    296.42199999999997`, 157.42600000000002`}, {294.648, 
                    156.691}, {293.32, 156.141}, {292.465, 155.008}, {293.199,
                     153.23399999999998`}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{295.28499999999997`, 146.35500000000002`}, {
                    295.684, 144.477}, {297., 144.008}, {298.414, 144.285}, {
                    300.29699999999997`, 144.66}, {308.746, 149.031}, {
                    308.746, 149.031}, {308.746, 149.031}, {
                    299.26599999999996`, 149.836}, {297.383, 149.465}, {
                    295.97299999999996`, 149.184}, {294.914, 148.238}, {
                    295.28499999999997`, 146.35500000000002`}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{295.99199999999996`, 139.19899999999998`}, {
                    296.01599999999996`, 137.281}, {297.215, 136.562}, {
                    298.656, 136.562}, {300.574, 136.562}, {309.715, 
                    139.19899999999998`}, {309.715, 139.19899999999998`}, {
                    309.715, 139.19899999999998`}, {300.574, 141.84}, {
                    298.656, 141.84}, {297.215, 141.84}, {295.99199999999996`,
                     141.117}, {295.99199999999996`, 139.19899999999998`}}}], 
                    
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{295.28499999999997`, 132.04299999999998`}, {
                    294.93799999999993`, 130.156}, {295.97299999999996`, 
                    129.21899999999997`}, {297.383, 128.93800000000002`}, {
                    299.26599999999996`, 128.562}, {308.746, 
                    129.36700000000002`}, {308.746, 129.36700000000002`}, {
                    308.746, 129.36700000000002`}, {300.29699999999997`, 
                    133.738}, {298.414, 134.11299999999997`}, {297., 
                    134.395}, {295.66, 133.92600000000002`}, {
                    295.28499999999997`, 132.04299999999998`}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{293.199, 125.164}, {292.48799999999994`, 
                    123.383}, {293.32, 122.258}, {294.648, 
                    121.70700000000001`}, {296.42199999999997`, 120.973}, {
                    305.875, 119.91400000000002`}, {305.875, 
                    119.91400000000002`}, {305.875, 119.91400000000002`}, {
                    298.441, 125.848}, {296.668, 126.582}, {
                    295.34000000000003`, 127.133}, {293.93399999999997`, 
                    126.938}, {293.199, 125.164}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{289.809, 118.824}, {288.76599999999996`, 
                    117.215}, {289.363, 115.94900000000001`}, {290.559, 
                    115.148}, {292.15200000000004`, 114.082}, {301.219, 
                    111.199}, {301.219, 111.199}, {301.219, 111.199}, {
                    295.08599999999996`, 118.473}, {293.49199999999996`, 
                    119.539}, {292.29299999999995`, 120.336}, {290.875, 
                    120.418}, {289.809, 118.824}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{285.25, 113.266}, {283.90999999999997`, 
                    111.891}, {284.246, 110.535}, {285.26599999999996`, 
                    109.516}, {286.621, 108.16}, {294.953, 103.562}, {294.953,
                     103.562}, {294.953, 103.562}, {290.355, 111.891}, {
                    288.9959999999999, 113.24600000000001`}, {
                    287.97999999999996`, 114.266}, {286.605, 114.621}, {
                    285.25, 113.266}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{279.691, 108.703}, {278.10900000000004`, 
                    107.617}, {278.176, 106.21900000000001`}, {278.977, 
                    105.023}, {280.043, 103.426}, {287.312, 97.293}, {287.312,
                     97.293}, {287.312, 97.293}, {284.42999999999995`, 
                    106.359}, {283.363, 107.953}, {282.562, 
                    109.15199999999999`}, {281.28499999999997`, 109.77}, {
                    279.691, 108.703}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{273.348, 105.312}, {271.58599999999996`, 
                    104.559}, {271.379, 103.17199999999998`}, {
                    271.92999999999995`, 101.84400000000001`}, {
                    272.66400000000004`, 100.07}, {278.60200000000003`, 
                    92.637}, {278.60200000000003`, 92.637}, {
                    278.60200000000003`, 92.637}, {277.539, 102.09}, {276.805,
                     103.863}, {276.254, 105.191}, {275.121, 
                    106.04700000000001`}, {273.348, 105.312}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{238.93800000000002`, 108.703}, {
                    237.32800000000003`, 109.75}, {236.062, 
                    109.15199999999999`}, {235.262, 107.953}, {234.195, 
                    106.359}, {231.312, 97.293}, {231.312, 97.293}, {231.312, 
                    97.293}, {238.586, 103.426}, {239.648, 105.023}, {
                    240.44899999999998`, 106.21900000000001`}, {240.531, 
                    107.637}, {238.93800000000002`, 108.703}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{233.379, 113.266}, {232.004, 
                    114.60499999999999`}, {230.648, 114.266}, {229.629, 
                    113.24600000000001`}, {228.27299999999997`, 111.891}, {
                    223.676, 103.562}, {223.676, 103.562}, {223.676, 
                    103.562}, {232.004, 108.16}, {233.359, 109.516}, {234.379,
                     110.535}, {234.73399999999998`, 111.906}, {233.379, 
                    113.266}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{228.816, 118.824}, {227.73, 120.406}, {
                    226.33200000000002`, 120.336}, {225.137, 119.539}, {
                    223.539, 118.473}, {217.406, 111.199}, {217.406, 
                    111.199}, {217.406, 111.199}, {226.47299999999998`, 
                    114.082}, {228.066, 115.148}, {229.266, 
                    115.94900000000001`}, {229.883, 117.227}, {228.816, 
                    118.824}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{225.42600000000002`, 125.164}, {224.672, 
                    126.926}, {223.285, 127.133}, {221.95700000000002`, 
                    126.582}, {220.184, 125.848}, {212.75, 
                    119.91400000000002`}, {212.75, 119.91400000000002`}, {
                    212.75, 119.91400000000002`}, {222.20299999999997`, 
                    120.973}, {223.977, 121.70700000000001`}, {225.305, 
                    122.258}, {226.16, 123.391}, {225.42600000000002`, 
                    125.164}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{223.34, 132.04299999999998`}, {222.941, 
                    133.92200000000003`}, {221.625, 134.395}, {
                    220.21499999999997`, 134.11299999999997`}, {
                    218.33200000000002`, 133.738}, {209.883, 
                    129.36700000000002`}, {209.883, 129.36700000000002`}, {
                    209.883, 129.36700000000002`}, {219.359, 128.562}, {
                    221.242, 128.93800000000002`}, {222.656, 
                    129.21899999999997`}, {223.71499999999997`, 130.164}, {
                    223.34, 132.04299999999998`}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{222.63299999999998`, 139.19899999999998`}, {
                    222.60899999999998`, 141.117}, {221.41, 141.84}, {
                    219.97299999999998`, 141.84}, {218.055, 141.84}, {208.914,
                     139.19899999999998`}, {208.914, 139.19899999999998`}, {
                    208.914, 139.19899999999998`}, {218.055, 136.562}, {
                    219.97299999999998`, 136.562}, {221.41, 136.562}, {
                    222.63299999999998`, 137.281}, {222.63299999999998`, 
                    139.19899999999998`}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{223.34, 146.35500000000002`}, {223.691, 
                    148.242}, {222.656, 149.184}, {221.242, 149.465}, {
                    219.359, 149.836}, {209.883, 149.031}, {209.883, 
                    149.031}, {209.883, 149.031}, {218.33200000000002`, 
                    144.66}, {220.21499999999997`, 144.285}, {221.625, 
                    144.008}, {222.965, 144.47299999999998`}, {223.34, 
                    146.35500000000002`}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{225.42600000000002`, 153.23399999999998`}, {
                    226.141, 155.02}, {225.305, 156.141}, {223.977, 
                    156.691}, {222.20299999999997`, 157.42600000000002`}, {
                    212.75, 158.48800000000003`}, {212.75, 
                    158.48800000000003`}, {212.75, 158.48800000000003`}, {
                    220.184, 152.55100000000002`}, {221.95700000000002`, 
                    151.816}, {223.285, 151.266}, {224.691, 151.465}, {
                    225.42600000000002`, 153.23399999999998`}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{228.816, 159.578}, {229.863, 
                    161.18800000000002`}, {229.266, 162.453}, {228.066, 
                    163.25}, {226.47299999999998`, 164.316}, {217.406, 
                    167.19899999999998`}, {217.406, 167.19899999999998`}, {
                    217.406, 167.19899999999998`}, {223.539, 159.93}, {
                    225.137, 158.863}, {226.33200000000002`, 158.062}, {
                    227.75, 157.98000000000002`}, {228.816, 159.578}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{233.379, 165.137}, {234.71899999999997`, 
                    166.508}, {234.379, 167.86700000000002`}, {233.359, 
                    168.883}, {232.004, 170.242}, {223.676, 174.84}, {223.676,
                     174.84}, {223.676, 174.84}, {228.27299999999997`, 
                    166.508}, {229.629, 165.15200000000002`}, {230.648, 
                    164.137}, {232.02, 163.777}, {233.379, 165.137}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{291.562, 139.16}, {291.562, 121.324}, {277.105, 
                    106.867}, {259.27299999999997`, 106.867}, {
                    241.43800000000002`, 106.867}, {226.98000000000002`, 
                    121.324}, {226.98000000000002`, 139.16}, {
                    226.98000000000002`, 156.99200000000002`}, {
                    241.43800000000002`, 171.44899999999998`}, {
                    259.27299999999997`, 171.44899999999998`}, {277.105, 
                    171.44899999999998`}, {291.562, 156.99200000000002`}, {
                    291.562, 139.16}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{259.312, 175.879}, {261.22999999999996`, 
                    175.90200000000002`}, {261.953, 177.102}, {261.953, 
                    178.54299999999998`}, {261.953, 180.461}, {259.312, 
                    189.602}, {259.312, 189.602}, {259.312, 189.602}, {
                    256.676, 180.461}, {256.676, 178.54299999999998`}, {
                    256.676, 177.102}, {257.395, 175.879}, {259.312, 
                    175.879}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{266.469, 103.227}, {264.59, 
                    102.82799999999999`}, {264.121, 101.512}, {
                    264.39799999999997`, 100.10199999999999`}, {
                    264.77299999999997`, 98.21900000000001}, {
                    269.14500000000004`, 89.77}, {269.14500000000004`, 
                    89.77}, {269.14500000000004`, 89.77}, {269.949, 
                    99.24600000000001}, {269.578, 101.12899999999999`}, {
                    269.29699999999997`, 102.543}, {268.35200000000003`, 
                    103.60199999999999`}, {266.469, 103.227}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{259.312, 102.52}, {257.395, 
                    102.49600000000001`}, {256.676, 101.29700000000001`}, {
                    256.676, 99.859}, {256.676, 97.94100000000002}, {259.312, 
                    88.801}, {259.312, 88.801}, {259.312, 88.801}, {261.953, 
                    97.94100000000002}, {261.953, 99.859}, {261.953, 
                    101.29700000000001`}, {261.22999999999996`, 102.52}, {
                    259.312, 102.52}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{252.156, 103.227}, {250.26999999999998`, 
                    103.57799999999999`}, {249.33200000000002`, 102.543}, {
                    249.05100000000002`, 101.12899999999999`}, {248.676, 
                    99.24600000000001}, {249.48000000000002`, 89.77}, {
                    249.48000000000002`, 89.77}, {249.48000000000002`, 
                    89.77}, {253.85200000000003`, 98.21900000000001}, {
                    254.227, 100.10199999999999`}, {254.508, 101.512}, {
                    254.039, 102.85199999999999`}, {252.156, 103.227}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{245.277, 105.312}, {243.496, 106.027}, {242.371, 
                    105.191}, {241.82000000000002`, 103.863}, {241.086, 
                    102.09}, {240.02700000000002`, 92.637}, {
                    240.02700000000002`, 92.637}, {240.02700000000002`, 
                    92.637}, {245.961, 100.07}, {246.695, 
                    101.84400000000001`}, {247.24599999999998`, 
                    103.17199999999998`}, {247.05100000000002`, 
                    104.57799999999999`}, {245.277, 105.312}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{238.93800000000002`, 169.695}, {240.52, 
                    170.785}, {240.44899999999998`, 172.18}, {239.648, 
                    173.379}, {238.586, 174.97299999999998`}, {231.312, 
                    181.105}, {231.312, 181.105}, {231.312, 181.105}, {
                    234.195, 172.039}, {235.262, 170.445}, {236.062, 
                    169.25}, {237.34, 168.63299999999998`}, {
                    238.93800000000002`, 169.695}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{245.277, 173.086}, {247.039, 173.844}, {
                    247.24599999999998`, 175.227}, {246.695, 176.555}, {
                    245.961, 178.32800000000003`}, {240.02700000000002`, 
                    185.762}, {240.02700000000002`, 185.762}, {
                    240.02700000000002`, 185.762}, {241.086, 176.309}, {
                    241.82000000000002`, 174.535}, {242.371, 173.207}, {
                    243.504, 172.35200000000003`}, {245.277, 173.086}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{252.156, 175.172}, {254.035, 175.57}, {254.508, 
                    176.88700000000003`}, {254.227, 178.30100000000002`}, {
                    253.85200000000003`, 180.184}, {249.48000000000002`, 
                    188.63299999999998`}, {249.48000000000002`, 
                    188.63299999999998`}, {249.48000000000002`, 
                    188.63299999999998`}, {248.676, 179.15200000000002`}, {
                    249.05100000000002`, 177.26999999999998`}, {
                    249.33200000000002`, 175.859}, {250.27299999999997`, 
                    174.80100000000002`}, {252.156, 175.172}}}], 
                    FilledCurveBox[CompressedData["
1:eJxTTMoPSmJmYGBgBOLNQALEZmAC80fRKBpFo2gUwRAApg0EFg==
                    
                    "], CompressedData["
1:eJxdWQu0TdUaPkjJKyLlVZFHhuqEqy6SWZJBNLL3Wmu/914ka8211z77HHSS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                    
                    "]], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}}}, CompressedData["
1:eJxdVGlIFlEU/dSw1bTsh6SmZi4hYUqrIV1LKSudNyUmaSZiENK892GSoiWJ
aURotpnRahJW2GKERYtaiGaQmllmamWSBqZg0oYZvTf3OQN9MMx3uMs5794z
zyuZbd5pZ7FYbPgTzx9b/mxLWfVB2W+F/tb5Xb//KtB35Wy9Z5EVPgs8rMC3
tqhkpxIriLTCDolLrbBn17GhfS0m1uON/+U3yn4nZX6tAg0blx8OOyjjFQoI
mJRh4pC7z/bWRJn54rXa1ewX2LPAPreJGfzW0Gkd5XHMiK9J4sq9mVHvnFf3
vGyIQprAtxTwC5pS6VZDwSJ+lxQoPE1n5xVTEDOxFCuQPefmut5UiufIlPyR
FM7Ve95Oi5M4VOL1Un8QhYUJR59+X6Egj5/E/gpsnbnoznkPCq5C+CwZ96bI
m6SgzgBTn67X3dSnz8PR1OcuFmZn6tPzfmlGv8fpJ1wmDWuGPv28/Zqhp1EI
/qjBVbEIGwX49Kyh7zW4NzrentkZjfG3mqFX31e77A8K8NMvTWzTDP7rI/xP
q2bsbyI+sZ+J+gl/6XxvNPCxzz211pkgX7eGfvMlhj4dLyPony8aCPq6DcQ4
70sezkkl8MOfH8yBghhbRAFBf/hQCD+ye2CsjKCeYIq8xwmIqkdAsT/PDxN+
UWR9DoFYsa94CokPImfYZhMYFvXcD7p+Hn8n6jNNvtqLcwN7uH++qvfn5ccT
9EcVhRghPIngPhoovouk3iZZXyL1NVPYIfjKCe63hWLeDYJ+fkVRdz3Bc7dR
fH8y8y9HVI+O/5H6B6TfbFQQW0+wY4inqpA/yIV6MdTnoqJ+YLhff1X6iIH4
DLKWqDi3HAbRyU5xK8NVnOsZiTepqLOK4d6ICm5CT4XsByrur5hBt9DvpqJf
0hn0ZnGGEWLw6Xt7TWC64MtiUC382ESMeh0/kf44wHCeF8x6Pr2AQ7EE74MY
ZvhHj6cw2C7mG0AMfn3e3gS/jwKGfnQl0Nn8c0vfNRPr83xo5i8WOl+Y/YrF
fLsYlAp/hhDwFXWDZlz30RiDSjEYD4L3hYMVsSOBjBq+AA+JJ0t/B5v38f/3
8z9bA3i2
                    "]], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}}}, {{{244.824, 67.52}, {245.008, 
                    67.45700000000001}, {245.195, 67.395}, {245.258, 
                    67.21100000000001}, {245.32000000000002`, 67.023}, {
                    245.258, 66.84}, {245.195, 66.65199999999999}, {245.008, 
                    66.527}, {244.578, 66.527}, {244.453, 
                    66.65199999999999}, {244.32800000000003`, 66.84}, {
                    244.266, 67.023}, {244.32800000000003`, 
                    67.21100000000001}, {244.453, 67.395}, {244.578, 
                    67.45700000000001}, {244.824, 67.52}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    244.754, 67.273}, {244.875, 67.21100000000001}, {
                    244.93800000000002`, 67.086}, {244.875, 
                    66.96100000000001}, {244.754, 66.902}, {244.629, 
                    66.96100000000001}, {244.566, 67.086}, {244.629, 
                    67.21100000000001}, {244.754, 67.273}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{244.80100000000002`, 66.422}, {
                    244.48800000000003`, 66.418}, {244.23, 
                    66.67599999999999}, {244.23, 66.988}, {244.23, 67.301}, {
                    244.48800000000003`, 67.55499999999999}, {
                    244.80100000000002`, 67.55499999999999}, {
                    245.11299999999997`, 67.55499999999999}, {
                    245.36700000000002`, 67.301}, {245.36700000000002`, 
                    66.988}, {245.36700000000002`, 66.67599999999999}, {
                    245.11299999999997`, 66.418}, {244.80100000000002`, 
                    66.422}}}], 
                    FilledCurveBox[{CompressedData["
1:eJxTTMoPSmJiYGA4A8TMQMwA5DCOolFEQwQA/LgDRQ==
                    
                    "], CompressedData["
1:eJxTTMoPSmJiYGC4yMjAwAykGYAcxlE0ikbRKBpF9EAArgAEUA==
                    
                    "]}, {CompressedData["
1:eJxdVwlQVlUUJjSHUXIpMhMkXFLCMbGSKNJOYwbyv+23VVzGjCZ1lHfvjSnE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                    "], CompressedData["
1:eJxVWXmcFNURXhFWEhZEUOKxbEARZD04FBFY8bEgiAfszHTPTM/OxYIRAs70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                    "]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{244.754, 66.848}, {244.625, 66.848}, {244.52, 
                    66.94900000000001}, {244.52, 67.07799999999999}, {244.52, 
                    67.20700000000001}, {244.625, 67.309}, {244.754, 
                    67.309}, {244.879, 67.309}, {244.984, 
                    67.20700000000001}, {244.984, 67.07799999999999}, {
                    244.984, 66.94900000000001}, {244.879, 66.848}, {244.754, 
                    66.848}}}]}}}}}}}, {{{{{{{
                    RGBColor[0., 0.686275, 0.7921569999999999], 
                    Thickness[0.00019063687500000002`], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{244.754, 66.84799999999998}, {244.625, 
                    66.84799999999998}, {244.52, 66.94899999999998}, {244.52, 
                    67.07799999999997}, {244.52, 67.20700000000002}, {244.625,
                     67.309}, {244.754, 67.309}, {244.879, 67.309}, {244.984, 
                    67.20700000000002}, {244.984, 67.07799999999997}, {
                    244.984, 66.94899999999998}, {244.879, 
                    66.84799999999998}, {244.754, 66.84799999999998}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0.996078, 0.772549, 0.047058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, CompressedData["
1:eJxllHlIFFEcxzevxEw7bDOvDsKORXbXmTezMzuz+9sOSkQsJf/QCLMEISux
EDGKCsRERESxP8xAIygqKRErKYkOiC7KBLtLZCsRSa2IEKF97/d8YrswzHx2
3vv+ru+b1UWHc4pDLRbLvMBVELhCAldzfFhezHMDLPR30gn/85P2rT0/j+ug
dz+u6Ftph7tHm+LDejTYsLvh/u8zDij9NnV5otwF0SG2GuuKdKDLp5tN2FF/
9tCSYU1wov3j2oh2Yy43AtRY377406SDGTV4oSzNB19frnn/95PC4/uA7OnN
iC6SIfDWjLrpw/W5DoxfEsxs3XInOALyp/wAd2i+LU7U7QPU/ZIOcZ3bhqq6
AdRaX6G/jK/fBWBjgnagr+NivIJpGiF1xly+4uL5OyHnVkr16GJVcAetsztd
8Hqa33YHDF9sfbjKYQea9XDxxiBe54y8mpQg8bsNJvuziha9kflcHPj/O4mv
l3jdMlSxgiTMa1SGY5TzJX4nWOd4OtwoL2kcO0dw3yUJ85QJ+Gl/TsiwpY5O
VMa4LsLzIFjHEQKVI6nOyFICyfn73Z+zCTyjA01WMK6N8L4pqP+dQMvmgGAr
gYPUJ10KVI/uDHRK5n1Xsa5rKs7nvIJ6bRr285VLMHuf4hZ8ndbxweB9cGGc
RA+vRxXM4vYrgpmfNino20kT+z9OuK9N7jMCLpqfw4N1vyaoO+CBJFp3rMLr
9/L58f4s9YJC9TtkXNfggV/TA5UjEYTPx8Q8CmTs1wGT5yfxeCb6tUKCbHp+
Hhg8vgR021SGgedqn4x9DDeEPtNbYOD8amXsf6Qb9awEJug8K3U8d0MEdUKD
mZ2Pwlk99IkimH0PTFUwy+ORyn3pFsx0LLPM4vh07he+Xtf4PHm8TA39mTTj
Xw33+/k5ytUFs/29hmCcowf91ynDMvoQBhCb1tX2Y74KT2mchYD9StVw3lb+
Pbino4/CvYKZDwYNwU3Up2Ma+rWe9yNTEoz+dghmPjudhpzlwjnk2USfZ5j5
wW0IZnUneGAvPZC37UH8D1c2WwE=
                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}}}, CompressedData["
1:eJxlVg1MlVUYvhKhY4RlZkytWbFMqhWupg7u5T3nO5d7L5ef77s2EmXMiArL
oIgxMOfGyIgcZGoLphZZRrqy32U1Yy5+lFjNrGWsqJH86MylOKNy/XznPOee
b467fffu2Tnnfd/zPM/7fvem8urYQ1f4fL4Z7rPVfRLcZ3kLWztmZ9PbC1dX
ZDU7FMd5KQm3N3fHqCLrl6LW+wm4bCWtWvHR0bpUbnCJxGXC4IMX/vmuviNI
f9xW+sIX78QM/rx2e1piv2Nwe9WcpsPcoY8lXhekI9FlLeycTa0vuwvnBNZr
pmOf/CxidOL1J/zJU2FKvfOD3b+HchB/PEhL3LQXTwWoed7Q11NNQSr7LJKS
MBig6w6ERjbM9fD8u4bTk54UBs+V67UWiS3rJy6VEOK9ybG+hiFvJ6c9Qbdi
wbGvgyOPZZElcYNlsLpXgzC4pvLFsxvfDdLjE5f2nd/Dsb4il758TQZkBvdc
dIlb6uF9/S4xI2TuF8fQxcMqzwVBb0l8DQMPR7UuxR5W9Sdyg9W5bxn9venR
Q7UfBqfhb27+8a9NGRw6dAbpXklIDafZinfNd5hD1yFBu3oXvVfzHKffnE9u
3Dyo4/dwxNkvcL9JTuratQJ5euLxBA3KhVbNc7ow8TPkb5ow+dXvNgt5sji1
yfpsi6SsjX0Met5jUSDZdcowo52yrkoL8V08ebyg/Op2C7x+z5Cv16KZjS9Z
WxYyxNtqQXcfwT+jHkZ9QYPVPR7MpR1picWpwwS9q0Oo72lOSTLuHSHwk6b5
WROiiNRnnFHD6VszZx0KIf9PDL5eHIbOizV/yWETT51Lmo6VX6Mc8Ur1+Zmc
7pa87A3rOBy8FES0j3T8jAj6+RXtz9NhWiAJnWFBtzkR5HmYA/M88JJugY/R
qM4X1Hrma/8J8F8f1XwJ6NmeZ7Dqn08jBqv9p3LBl+vTsWNugVUejvdXHKu8
XVq/UoG6ejnmRLNlfBzHqg+X6v69VkC3qzjmW5WOd4TpftU+rNRzYK2l9zPE
fZ6hvlSm/Uvap4zk9ecNBeCP7Yzkd5rwGx+rOF9lI8+vHH4szsb+lRapsVWV
RWekzmeE2Y+5pP1WECB5KvVsSM8ZTvVS//VF4GnAIleNrv6TNvrjSgF8i4M5
tkTQU/LcIx5Wur/v4Y05bsXrYuDvBCdpH/9+ja/3sJqrmezy9RBhfsc8rOoY
cwxW87/Tga+2EXxW59C45PVfDyueEvjleJJhnozq/d1al4wY7vEAp6bD7qRN
iul1TvK6OX0OfPsGx75GB3POZ9FxeX6DgzmxykL8Cgd96fpM8bXM0b7QeLaD
flyg5/9528SPv9+U73/Q9Txro848Tq7KB0Iltqlf7Sdb686wv82G32dx+k9+
JmzDTxz7FfEeVn0VyaH7Tu7d2funDT92BEz9yl9tAeOPgbruV+dXB6hLvkcy
i6Zh8BHAvZcXos+eIfQFFaKeMgbftBSiH1MY7vFYAfQqJ8zXY/nQ/6Af/TaV
D75qAyT/o/jcdcTNwRyp87CKPxA1WOk3kkebZaI+P+bYzxHTL3hfROiG1TKT
93/nfzxF5I4=
                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxlVg1sU1UUHnNOssxNCS7LIIsKisKW9efdvv4wOO17Xdv99b3OYMYI0Ylh
AgLWptmAkCzLnETH0KFMCXFIcJEgoJCJOgnK3EBQcRoVVBS3MZdBBCdOXRa9
957b25g1eWm/3PvO/c53vnNu76ndEHn8lpSUlBn0aaNPKn0eWNH28c1gMRyc
u3yVp8WEBC7NTF3UciICK98PZaaOORGvrIKXtOfWjWwmEh+J1r1w7QeLxO/s
+a2r72wB/MkCvRWR+MNYe25anylxx/pZTSd9JoxMvnljoLUQ+svUbd7rBuSm
LcsqjBbhenQ6ZsfkVKvw7b6NxRkTQYgcz28eM90Y/4ofBvfv7r37iBtaci58
PtHkhzPxE6/lfeGGuw4FLm+ancR5RT/OT39Kl3g2W49pQIMdzx92Yrw3fLC2
h/4YckAK+3T6gMn0UzYBncow+YoPz7/TDkyWyQZN4u7xqa/rG3SJmUxbDvuR
V5WC664SOLfX3z2+h0jM1+2qxJzHN6rML4Epi3Drw0nM3xvXgdFNi6vwIKvj
aR3qR++3zrzqkJjzbyMSU9UfGb5O4J+ta3piR/3T8BoWUCfQuosWoFOc161A
diGtZMAPf1Cao+kE3mV8L+gY91kFrlIZm88m8lfgy3u//3vrAR1ep+lOHbMD
S3sqllzHeDoc5kIpuG++LuMvZHFzdXk+YcZ8UQOTEZtHYDvjZ2hYz2wH1lPR
4Mp5evAlAswV0TpN+JXA7wMVtXd0aNDODHaN4Hm9GsxhvnhUxXg7NFhgnXlw
7qsu9M9QEiM/v8Rcr8dK0Cc/q1jvDQHkt0+B9EbaOQUByGJ5riaoT00AGlh9
zhH87gng+ZcJ7lsQRF+FCOqXEZTxQqwR0qdj7tc0EW9FEH26jYCFhm3cH0R/
NxNYkkE7qCIk+lvUZ2EIXmYH1gh/jgaxz3bZ4dRN2tCzQrCT6fWZgthXCk7m
F8OOegyVof9yikQ9y4X/LKh/fZnQy4r17CiVmOf5Xkhivv/XEoxzmwWGWR3X
J3GivxKY90OXJvS3YL16fajD8zaRXxI/yQaPzYd+32jFvG73Yf4fiHj9XtGv
FvR1nRf5XbSJ/V6hpwP5ZXmFf53oz6gX6/mRG/3R7kX/Llss1n1Cz8XI5xef
6Ldi3F+lId+CJcCPGdPlfl63mhLEFR7h4wBsZsZ3K6j7ujAw9oO32nDuDhrY
H21WxPNMXPdb4WlGe3USc95vJ/GWpZTxE4n7wA7MPsUHIuIcIjH3i6pKzPln
unB+R5KYhW8cNiXm87/TRB/FnOjnuIn12K1KzOvRTv6PjxKcJ0Mm5p/nEPWO
YJ9/p0DTyU/3+tMjGG+OAizdpZ+YqEdYwXwbTTEX7DDA3t9kYv+M2jD+qsT9
aEO9VBP7tF/gbBPrWivm/w1Dxk/cb3z/iB35PGPIfqWX06FAtSH58/1gQJj1
9ymC+7cbYr4S+Jd9RgypTwLzeZfvkhjPd8ND7GL8y8A8Z3gkf9TfI/3B67vI
A119lIA1PA3z970e5OGsxP7Z4cS+g0rkf9Eh5k6l0FVF/66tQJ8POHG+ni8H
g+U36MF+myjHfrrPA+w/Sgpd5/223I3/L+JJzOOfKZMY52Yp+uErD1S7jp2O
XwrJfsH7IgT/ATGx0GU=
                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}}}, CompressedData["
1:eJxllHlIVEEcx9ejkrIoNbvtILpEXHfddHff2/ed2ZWMiC6yA42sBCk7KAs7
ycBMJKS7KAKLLoqIEK1I/0iR6CJDEMuQMrssSKWixOjN+42zlAvD8Hkz+5vf
7/v7zkxes3lxTpjNZgsxR6Y5Qs1xfHR4xrCnGmzitz8J//PumJtz3ow14Kl4
uKNmYiI23M8/NvqdgZmZZQ++H7Jj44eea51HgcjQ+OLYMQ5aD9ew8PCpTVFt
bsXjEl9PHViu/ctHgKKORXfiBhjQBzdd3JLA4BNzFpPnM+z8NC0p4hyH+VUf
XMXovAsBOj+3P1txWQB2cypsB67Wz0spCQng/fMpr37VgOrL8kOUtasCKI5t
fvYzWu5fCrSLfc8CEMsxwwzFq+7NjQwt1f7l66mo/T4jsyw0gMV34oo6RqQo
vpBW2d1b4VA8Q+SXbqf8QtJgnrqkLWdWP96We+TrHsOP6UkRN8aPjaf1bC77
Yqf1Vi73O9H1Yv6a4ac5dlkFOUmnZZz6ttJJ+ydypJSw1e3fHFjuNhv5h5Fe
V52Un4NTXfuSKV4BpznVRX0AJ522uSj+KI4JK9d5Wxe4qG/VjPSId8Fqb72M
/9FFuv+Rfbo9G4HSvA89JTKfLSmoFvt/gPadn011/DZIz4ZUxdZ6nFfxra1m
YS0aqrp7GwvOACf9ZuBxPrhEIg6m+Pe+9ffz1wa5QPjpBkOeyKdLx0ghWyOj
PCp1XBF+6WRIFfnZfaTPW0b9bPTRXMdk/Qb5KFnqE23gi2nnot0c48V6mY90
SO/rjy7r5KTXBp3ya+PyPJ3yj/Jjgbg/tZo8n0Ok3zNXo/hnubw3mopvxRui
QWR1uJjT9wgvxeMcnVZfPRhUeMJf2sLofob1Z8tnE4LxyA9M8aNyU4CEIDcI
23wG+fWlV7HlG1uQ6V56yC86o/0eN8XrlfHmSa7u86+b/LLCT/ou8Si2/n9P
U9x26WzdpG8+iGMKt3PqazikPgyPRdyhgOhigRvU71j5bjX76D6Z71AfWz5v
0hQfE7p8dUO4vPhgX75OxeRvu2JL9wMJxJdB9yIjnuaThmIrryxdsVX/Xi+y
xYW8m9iPrffwSfB9/gsDg2Cj
                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}}}, CompressedData["
1:eJxllg1MVlUYx18JlRGxFBRCBGM2P5oxm2QF78tzz70M8WNmH3wU3nvfe8lp
KzAi14yxGBCUwyxt4SwJq4HN1FqJKyILJdRVhpWhEjHmx1KnwsgRmd1z/+e9
Zwy2d/DjnPuc5/yf//Pc926r5NGnb/P5fBOczxbnE+Z8HnxNMc89kkHLFjt/
rLMpxLuyDgzdDC+iovS+lfV5RDWXVh1MeqKI8h/6vGtDNPO4gLOuedw6dPOX
l7Zn0fP+yFMf/Gt7fHqk4pm2OsnOKSdSsm06wHldFn1dtjU+PMmm+neKp1Zd
07DeZ41jH/+ZpVDp2jevlA+YFL3gs/euZmfSPZMq31aTTZpX+MZ3wxcDxB87
NMkk/cucqLDjAfp7rrPwq+Fx7fSeH29UGWPXJxqkbXr2wmgBUTK/0E4d608p
dNm5Xs0OHbpoDHk16IijquAIw+NOLmid5JiqQ8eappj03IXR3dd3MawvMulY
Ew+oeNwx7CRyv+Td/I9+8u4X4j2JTxal3zA8Tu2dPanyiEEtnKco0Gm/QUuj
wu6tzZWMujKP3fxOKvRF14b2xqnmOP455cxIxXxGzn8fG7jDpDQuSCmjh52y
t181oPcSocdBg949PGt/aR2j/o2xe7M/FfE7GD0+8NGOw+8buN8gIy5H1qsG
/ePYosxZf4HXs8Sg41yPegY/6DL+Lf6TZ3jnn+F+ijVQl3RGjguaO4d0oYOC
ep7TKeDYcH2vgnxv6YjvMLdte5yBc35TkM99Bk12ZN6UqCBejAGdfIR4fsnu
c39IdvUKmLQtPjw3ulfsrzSR38sMuq83oU88o7M8/3KTcnh9ziv0TWNCau82
E+efFfnuM9F/c4S+LTKeo8rcwubx7Pp1mYjfJp6fzNA/P4l6Ror+HRHreYw+
vt69wrpmop93Mvqe++9Pk2ZwQSeo1M2f+0vku4bRCc4PBGna3uz+jbNVnNsY
FOdlQd/WoPCfBp2qg0Ivwcslu+fHSp7p2LvPEHp1aairIjnUXyF2+yFZ1K9Q
g/6f6ORU3x9Zq8J/pmS37YpE/8Zo6PtVOuZbsYiXqot+Ffn6dPw2VeK28nev
hp6vK2Tw+59cLfxLFMt1CdeJX396TwD5T9PJcfvWeM2P9WodfvlBzNs2Hb7K
zcD+YZ34ttjidMzJbw1v/2buhwzhtxUB1LPJxFzcx+CnVyw8d1SlXD4o42zE
naiBF9u49zwN86lA8pXyzDS9QnIDn6enbeh3iqHeo4LjJCfwAxYqY9ezSfhP
MuanZHe+vGhjPrxF0MO06Tw32n+S3XqEsbE8qMCvDWJ/u0KMn/eVDf8GGbVz
PVpC66KfnPeRG+dDhnquEe8fn4rnbZsGHVvema8ifr6N902zmOeKjfm0VvAC
G/04Q4UvkmT80PttPt//u8jnooV9Sxn07ra8/N39nRbxstZcEvPhsgW/RzD4
+y6pT4j97kUkq7x+OZk0Z2HEnsQUG37cHvDyd/21OeD546gzxhJKAthfao1j
6BFAHyyy0P/V4rw0kb8u6rHEQj9GKfg+4LNQL0vUuyeI+rf6MS8GgtCrTLyP
e8Q8oEzMtw7JqLdkvC+C6IMjflrOv8/MDHr9crt7UBBzZaX8vvM/dq7buw==

                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxlVg1QVFUUXmklhkhSCQ0VirJslJZl39u37IIdUkaddBQrStP37r5Hf2ZJ
ZA4pw8QgiWNGDZpMjBExjdZYUpkxSaZZ2I+loWXgL7MRkTBqZg5DjL1zz937
xuHNvNn99t53zne+85379jZzxcLHrnO5XCPsu8a+Y+x7ypKary7PzoX7tfV5
7CkLovid/N2XhtxFoH8+JyHmXACqzhW0pD5UBJtnbFjes0aVuLnkydf7T2ZK
/PHW89vafpgGz+XGH2/6z5K4c6B8WWu1g/NY95H0WRb0DL53sX1jBnyxsna8
O9WC8e7CURklHlo/Yw7DCTFT1yUv0gDTlkUYLGxJtVMHYXJsxeYZaQwi79Z/
fWtzELY8O6ZyXyyD71btbUg5HIR/sbBfDInXJXf8dKXSuHZ9pEF1dAcgDb+8
pcPTrTax3/3QZ/9cVa/DxMVFoTOJKmzEBHU65R/tIxxnSNyGglY7eGzlvu8b
RzPK+4BC6wqDQ4220FtVifm6T5OY6/KrJuuL4h1I5IohsefUHbEV3xiAdN2r
NHDh1WxAae+d3rg+v8Scf40qMba9+4IKn35rCzGGDcPLMOBMFZB15EaRf7cC
wV32hvMG/DN0rLQ3VujRYsDd6J9qBbpWJ30466No/Qo8iI152yBf7fIBypH/
srP+PPZzhQE7eWMVyqM78a/i9bAh859APyUZUICJb1fJV5d06mein/rZrcMf
R9JPDJxWie9VXfhVhWzE4wyoRYP1q8TnHgMmoJBhjeKNNeAub9yOiW9mU7xc
B3Mepx3M9ZrOSNezGu2vYMSvSaG6ixmMyrAjP6HCSeRfxuBF7M8hFb5sSPGc
2sQof5fgu5MBjtvgHKHvdieerfKUJduGY+5Xt4jfymAmPr9epfk5zMjfVWJ+
B5iYbwXev9g+z7zA4A1M+KgCB9F/ZxkcbyrOjd/ig3ZbxvK/GGxCvX5UAGUt
94chgH5Z4KM4DWHyX7KH9P0sLPyXSbqsDQu9vITnOpjnT3LwJPSpwSAR9bo+
k/yd5+DofEUxn4c0Q+ifSfp/oJO+r2SR/5iDceyGinTye7GXdCrQqf49Ip5H
F/Mq+Lt04teZBfEoTPtSoacfDKz/6FLh3wDY7u9a7dapn/uDxP9mnXxTmEPr
a3WhZw75o1UX85ZL+y8LvtOmg716rHS/Ife/in7IEf2YFyIejQzWYOCgQn56
yaS5HZkFhWi8cRbNR42XsGbRer6XzqdFDu4vu1fVyx1ch+dppyX8Ivo9aFF/
l6sSc79omsScf0K28J+D6fx0MM/zgkU6rAzQJ7OoH/WaxLwfteq1+BOV/GrH
4/Wn+OE+zLfHgr9tW930mwJ7UY/tIt4EhfJXCz3mK9TPx8X+Oh89b1nki94s
iv9I9P2YRXrlWTTPBwXOsEDFwk0f/IzzkerEj77f+P4eH/H505TzyvVuNyV/
vr/NhPlI9IA4H/pMcb6q5O9bHH2imJ93qdkSU/4g+TbdIj+OCEn+pH9I+oP3
bWqI9peYwzB/Pi9E86CYND+vBSifKvh3+kmv2WJ/hUb/B1wmPMNf+AHqd0cY
FmB9kRCdF5Ew+XhyiOJ1iPNgcZDOtwMOpn47mN4XYfLD0RDMRWKTwnJebuDG
DMP/+LzHsw==
                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxlVg9MVVUYR6KXcwRmjRkgC4LUIeP9O+8+3oP4UBy5JNEWCzNm9O6795op
qDlK1sYYoUtDh4qLOTLGmuTMlTKmZIaJGVBOy8o0QyIio7KS5ojWPed33r0r
3nb39nvnu9/3O7/v953zUivWr1DviIqKmmY+jeYTbT7zVjX23Hokj96+eaG4
IlelCP7m9strut8IUfnxJbHRN/zAJSHas+jVtSNbmIWPbNB3jV1xWvjd/b++
1du3gOpvLO9KOWjjNxd3/jGZrFr42MebT7aWqzQycfDmhR1ZlLwyFLzWoNLs
mNK4rA3ZdJSv907FsdGZDQllCs34sq0yr0ejFV0pZqkAnU8zGbyi01B7y0cP
HAmAd6tO58zXEj8L0Jb7DhcNHrdxDk849L/1NAO8h/3IV2rQc92bmmZ/76Mo
/nnSAM94RtlX0x21ZQbq3+MBTrXxvXWnPjkwqFtY8NqtU0PC15/+9bgX61U6
9R8whdnPLCzWPYqF3zfLx1xSrP1F8FzX9EPJHTYW+z2tE6cbs1mhcd7IAZ2q
Rx9yTf/ZZ2HBv5FZWNlWsHr4N0YLVw+fT2uaitfwhIUM7zXLep1efB/W6c/J
z6tHHZL/OZ3mc/9s9ULHgcj+vbSUJ/5Chw+Oemjfull1p67b6yLfLzq9w/1U
46Vmvj5u5xd8b9v1N/KwJIOW7zAjH2Q0h/PLNNDPeB/66TboBy7ct4y46kMZ
hvQro0LTxhP3G9TEDTbGwCfOoCTeyGcU5DPzC51fz6GXeD6HjQW/Tt3CBVwv
TYdPvlPQ73Qd/Nq89EFrYvZVr05xWeYEaAz6zNfpRd6ffgZdZuqoP8iwz3GN
+LhNLGHQb1Kz8o3V5LPyf6Zi4dcYme9HDfvcxjA/lzTUrWdUlWdO0CFNzrfs
zzGN9vKCT3lpFu/nGY34mM1o9tDOnlvzVp3QaDfXa8ALvF4jP/dLiQd6ODT4
LyFb9jMs/eeE/qma1MuFfpbZWMzPLhuL+MU6xXO97nJS76MmwZCNI/MVweK9
BEPq70T/HzOg73Y39veCjTMctXsWbTTg90oXXeHnV42B/Z+Q+V4z5Lw6wbdd
9v+yG/Hd8ryo99FZzs/E8K+fxFeb9NOHAcxTiwFdSnOx/qwh9cwFnyJDzlse
4jMl3wUPo84Z3Yrnr+cbEhcHcf7G6Nh3wIv+p4eh451uuR8V89HoAl6nSp1d
4L/UxoLfXBsLPn2R+8CDOh0h9Hcts7Dwi6JYWPCPzZH+s7Hgf7dqYTFv2Sp4
b5L3TaGKfrQoFhb9aGL/xe8xcnL/mPlE3UQf5vmnEP1uXmszv5Lz93cI+ZKk
3+dIPZbJ8yRfRfw+eT4tVDE/o27kL47cj27pRxXzfNYN/apVYlygCg/62WDn
j9xvIn7EAz7dqjWvjXyeLtr8hR7XVFrG5/s0o5M8vkuV5yuDz7fb+kSwOO9S
ciyM+gF6gheuU+HHaUGLP/QPWv4Q/c0MIt4TnoLF+wVBzENVGPOz0496lWHw
v+yDXk/L+FoF/m0P0/Piwvdjf31hKuH7G5L1e8KIywgiX38Yv68M4Hy7bmP0
W7OwuM+LNPjhYpA6+P+ZrZo1L6K/LRr9C1IyyJU=
                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxlVQ1MlWUUviLdiEiwGXPgMEvNghv35/vud38EDkNmGArC/S73fj/XYDbK
LE0didzczKmxcuDQcDFnZM25ObR0zPk3kdJ+yB9qWkglQyIC+tGSGWl973ve
+35r3O2OPbzvPec5z3nOeWdVrSp7frLFYplkfBuMb5zxnac1nP3rmRx4ccdo
NM8mQwyfWtc0Pf52OUSOFyXFDXvgNjmQy2FXwVsrB+tEjg+veWHHaK+d44/3
/Lb/3JdZkLFleOkxa4DjRUlxmdt+NfHreWLk+KsyDI4f+KN7uw22pX53YaxT
hunxwSm2Ndl4nh+cgEmY1LAE6dnfz7Z6FSg7RjL5oP3W3W/Wd6jQ/2HLJ48e
9sHlx67d2XhThc9rTu9Nu+iDxKv7Vuc8pXFcOzTXkRA18YPk/G8NCO2MAQ/0
bZjWtrBSh5dOGkLccIOB+jYs12GGstz/Y7IIa42yo9U65p/qQjymcew9+lnN
6ddM3Htn44qTvSrWWS7g/WYVuloL22/tETmm5y6JY9qHKxKvL4YDpNAEjeNu
Uq9PA0I3vkYCC/mUarCe1Dni5pjybxA5lurznxv4XYTdrzy8+UyPOgGvIAEX
iLCkKiXkvcHytwtw/lnjZooGfxq0hqyM/0INniT+eVOAmUTIJbH6BThIEi/T
4H2j3LtHXdjPWvN8e7ORsFGDQ8RPUQEWGDYbbzXj/0s++zWef7Z1066CYQ2W
kh8+zvgl6djPZDf2M02Hny4ZwvwgIl+LzvwqwjmCf9agiRhsVEQ+lzX0VaWE
8UY0eMKRcHDGu170z1kTU36zTEz1ekNFXa9L8Ajxyz8K8tsnIO8MFabYjAmo
FqGIGNmqog+7RNh85ovWwisK5u8TUY/3FCDjNl4kYh1tZjzqz48mYurXeBZ/
q4I861l9lQr6ewub34cUNt+sPzMVeIckVJk/8xQgZSc2u0An9zIV2En0+kqA
ZQQ3hcFD/FLqwjwdIfRfajbrZ4j5z479GwsxvRyIq8Mc0/xXTUz7BSokE73u
t6NvoiaOzVcM03m4rjH97divMh31fduJ8feamNbdoqPfVzuwP2061n+Cxbuk
s3m1Y1xLBPn1OFE/W4Tp6UZ+WRHmXw+MkH+P69jPDraPftExT3A+ntfpTM/5
qGeBzuYtB+8nMr5Zubg/czV+f4D4YauKeLEf+ZxSoI4sKp+AfroXBMK+/z4n
q0fG+WhwIG6U8bzQAdfIfio28RwyX5NNTPksCjC/uNCXDwSwvytFjqlfJIlj
yj/Jy/xnYurnCyam8zZNRh3XeVCnXBn70SJxTPvRJP4fH2H752IA609zQ5Tk
qw/Aze7FVSnfMj3aAhgvXcD8xntE9SgRgLbRJeP93Ww/eWX09ZAT45fE3kcn
7vOojPN83on6fSCDSASqcmE/O2UeP/a+0fuDLuTzdJDPK9VbDXL+9P7aIJSQ
Qepk+2FukO1XEd+jLlOfGKZ1ZXg5xvw+OELe3RMy+nGSn/NH/f3cH7S/mX68
n14xAdPf5/txfpsrcH4aPZhvZwXy73GjXqvY/U0Svgf3KuBl+uB7sN/FISgl
9fX7cV94QjhPc/wYr5jtC8WH+63WxNhvE1O9CsL492s/0PX1aZjPC+3vcBj+
A+kU0+0=
                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}}}, CompressedData["
1:eJxllg1MlWUUx69ISETMioyBoTayxKhZc0lw33veD0Yoft/3frwfV2GU2goM
mYXd3MyUyGEUNnJWptnMrdHn0lkyFTHNMrUmmbBi5VfYF02ZUtTzPOfc95nj
bu/ufjzvPc95/v9zzsOEypp5j4z0+Xwj2NPMniT2TGtUF56ZUwxLXv4tHigw
IcF76lqyki/Ph6qiH2c3hQEu3+28tN+cD5HCTw4tz9A8jnKOGR7v/Pvf757e
WAK5a/rm7koJejw9PWlyw++Snw1Mje1+0oRPOS8pgYYxp44OdJjQ1Fp98+o/
DVxXQ8PYxz/jVci5rycvpdCCjIKP3vijNIBx9tkwiaVx6bwCx+84fWVlvw2x
3WXpSUcUSOt6e6k/3/G4/sLEKalxyTfw9asOGOsePzcYBehdkdlWWuHiuq0C
o94VVS5sLWE7GRosW8wEW+Ri3rqOPOB4zGVpf0py95WVj33ebcMT5wZ3/LWV
ft9qw5dbeEDV445LTMj7Je84OOPBxl7wzpfg4M/vbDqQ6nh8gp/3IQfe5XyT
ijrNcVD3kGSRf7LmscjvWxVeYzLv/cEexkLHfA1mVY6OFP5iw1QuSK0GX7Bt
1NEO6v0wnafUgdcPjP+g9gUNxnH/Z1H8Dg3eG2tVFS1w8Hz9GvpZ78BVJksd
Wxc+NztwhOvRpKEPW2T8//hnu+Ptn5ey6lW9z4GLc3flrimi/NJd4GWxqlNF
P7NdULjxPSrm63MxPmMuk3rewTo/qWI+xx0YxcKuG6tivIsO6uQDrJ/9kkV+
EyQLvZ6zYUNWciijB+BWXi//WJjfMxruk2ujPlkalHFfUmz8PqvC6r2sEk5a
uH+3inq8ZWH/3aXB2WPMiDYZT9Tnh8NZ1OsMir+Wfj+K9K6w0M806t8baT1M
/oyzsJ/fJD8DFvbZCB1cHneyhXEf1WAB55YonjNPRz32RWi/EvIzQvVnoH8D
EdKLeFHUY7F/l2ThF5Behwys27jkRH8lWPTDT+SfY6Bf81zgX2kNOsbfLFno
tIn69xYD/Wlzcb5VU7xjLvWrQXnF8HuhjvoVxFDPF1XM754Y1S+gL4Mu8OOP
OUXz6FcXWLW3ZBl+8s3Fevm6GPXUXcwjVEw+ucDlzawuQh0Vx3v/DK+HtVRv
MxXMZ48Ftdy39zWsp6EQzo3DOp3HxP64js7XbKJvkww4zedTueQ7eX+NlCzy
mR5E/bo00Pnfrye+TXI232CKeu16KVD9SRb1fFSy6LdME+fDK4A6KCa+NyRZ
+JGkXcv9NC+/CeL77SrE+X6NQazfCtKjLbFO/cTuI+HbNg36uB8P0P3j0zHf
QhP6T8xkmdF8n23ifbOd5nncxPm0WEf9tpnoa46OfrL7LBE/cb/l8/e/p3zu
DZGuGupth7z8xfvLQphXH82HiSGs91QN76OvpD4J9ovClyx8KAvAxyzrg5+Z
WI8bFS9/UV/rFa8+Di9v35xdo+D7OeFhjHoo2L+tYez/52m/DWHMJ0Z+1ISx
H9NVvA+GwuhXJfldHkH/d/pR92kR1KtOwXjlNC8ggPOtXjL6LRnv2SjwbXI7
/SDGV2fU6xfUMQq3W3xCyf93/gcwRuih
                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}}}, CompressedData["
1:eJxllAlIVUEUhtVsIURK27Bso03aIwlLe/+d96Rs18gyUlrJO/MyowWzMqJM
SiorsyJbLKyMiIg2QkssLNowkfaIMpVsAZOMLKOZe6Z7IR/cd993Z945//nn
nNtv8cq4ZW18fHx85bVAXn7yyu3hHx/4KBI+6lMh8D9v6HJh0rsQF0rW7O/h
H+iFKJY/Prjo+VeBFXW/ihr2AbeOh4x8Uyxo3T8ScwKHXzp6m9scOn/phLfC
4fGX7627+cpE5qfY673bupAa1fHZqcsmJspbaqJB+U+YWP9x0OgO+QzqcdQ+
k/Kd9KBpyII9ZYWtuefINwPaGR6o8MfLTZwtnzpuh68Hd+XNqDCpvkQ36a80
kdXtxeMfwR5cUfvrTdRU9H/187GH8vXmNlvrKf9xPcft7zKxn84fKmxW6RYW
OZyu8jUJ0ucbjeCtpfcLEryteHXy3i8bXW7Ir/CkGXp9ESOuFbT+lmFguy0H
3PsFvlVOX9zpEMMq5V+OgJLdcS4jP3P1/j4MssrZ1QUC8yKkM38Mqn+n1jeG
obrwyJ2+qTpeGsPJ6KuNLfMEnQMYlIwtsTp+d0b9EC+g0qSWGOTHfAHreMt1
fCZQq/yS+az6wgQ82d66Xzu0ns6C4jSB8g8T5FOzi/ys4TZb6/kOn2uQQpdy
XGtsqUo7DOw+mBK0NZIjPOlGTMAYw+bmDF68ZonDaaqfzms9BkdXGS69yoBl
ewzHGdUvDQbpi9Dn+97ANHWeAzn5cscg3d04lJz0sQyjlD+hHJ9lO2du0P6M
4AiTZXyfrM9nFic/jjHyK07rq9Z+JGj9QW7Eq/lZ/i8/g5Jfuk7HP8KQUyYX
NjvxrXgZHHLKZu7KYuT/MR2P6fO8yNFetk32awNzVfxbrdmaj1AnHvWDYfP9
AhlouMNPZDkZ9YD85sXbHKb5dbiXmv9rnPolysBLtf+5jtdi0Lw+1Vyi+7eK
U78kuKn/rjhs/T/ZYevej9O+tbr+P6b2R5//bxNXVb9EAJVKV7OJAL+h8hUw
keapD7fZei8tc9iavzKOGPVgu9abJ2y2+umjw1a9g73Ep0F+TfHSfOS5bH6g
6k2Mstmqf9ME6m//1my9Dx867+e/8LeRNg==
                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, CompressedData["
1:eJxllHlIFFEcx63EImI7sTDXMjKVjt11Z2bdza1fWYRdlJGViYgpOe9ttklI
dBhiERadmv1RVhpBRkmFR4Sl2ElUyCZlipWIhoqVnXTSvPd7zkC7MOx85r35
Hd/f9014+tbEzGEBAQFDtGujdg3VruJJgUmmp3EQwH5NFP7nx2WLaz7vccHt
7UWTAk0e/K9xwq4JlUs63lPwvPtVMZATC/XnQiztdRTY9j/Fblhrmn2j9C7R
2ZycMfcNNdhV9Sj3TpsKB4JfPfte5AKve+TLC1UqdDdNa/vxWsH851WQU28l
jEqXQFv1uk+I/Wus8C0q5WjjRX9m20ZOtAELf+6BCnWs3hIbPFzmKFzQpGLc
tzFYv08F7Wlal9cG1Wx/rwozeUAL5gsjOvP17P+4l4j6bZjfTHVm6dIqDN7J
8n2j0Hnx9L2pVguML2h4XLbB48eRthFXQkPs0L97vpy60gOffCvSx7RIyN0U
11vtEBGUfzK+iEK0lvZrlgTbmH7HKDC5hvZJqGcxxT6TZWAqdZZRuJ6Tdbz/
jIzPD1IoZ/OQZKzDS2HRITZRCZ+vF/lCZLC0Tw/KX01hR88M2wiPjD5IovCE
DdSsoB7JFLSoOyeYFIy/kEJJvBbwtIz9RVPY37f6Zth+CesZK/x21YH5Z4l4
pU7Us4vozNfPGHx5QBMmg2CczFg4cip7XEEcEf04dN7C/OlTdOZ+WqhgPQsI
xv0og6bK7vkJBP1TK/Ryivk+l2E5m2cEgVDm49EK9h8s3rfKYGX6mAkoLH65
hOtzCHz507yjJ0jG+awiqMdGCfVKHKzPjvk2EPRrrh2S2PnZPJjfDqz8hlwC
qw5rd5skONb4NSplrxGfx8sjOL9CCfU/K+IFy6jLNQKT2SA7ZFjH4tf7Mz8f
aUY87q9Lis78e+B26Mzned8BbT/ySN0+g/H8Gsx1qxXzMzugle1vGZynjOf1
BUF/hgr/Nov3u2LQf9UG8/ezDOZ9hxP0X6Xo/68Ko7W2PgwXfvitol4znODT
PjN5P8X3oMGF52kK0ZnHzTSYn79Ggn49rGC9JVRn7qceg3m/kR7kFbGo11IP
zm+YS2fuh7lxOvO6Q+ahvwP9+R9CWIsK
                    "]]}}}}}}}}}}}}}}, 
                  AspectRatio -> Automatic, ImageSize -> {{128}, {85}}, 
                  PlotRange -> {{0., 480.}, {0., 240.}}], ",", 
                 GraphicsBox[{{{{{{{
                    Thickness[0.0010416666666666667`], {{{{{{{
                    FaceForm[{
                    RGBColor[0., 0.478431, 0.23921600000000004`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     480.}, {960., 480.}, {960., 320.}, {0., 
                    320.}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     320.}, {960., 320.}, {960., 160.}, {0., 
                    160.}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.8078430000000001, 0.06666670000000002, 0.14902], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     160.}, {960., 160.}, {960., 0.}, {0., 
                    0.}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0010416666666666667`], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     480.}, {240., 320.}, {240., 160.}, {0., 
                    0.}}}]}}}}}}}}}}}}}}, AspectRatio -> Automatic, 
                  ImageSize -> {{128}, {85}}, 
                  PlotRange -> {{0., 960.}, {0., 480.}}], ",", 
                 GraphicsBox[{{{{{{{
                    Thickness[0.0016666666666666668`], {{{{{{{
                    FaceForm[{
                    RGBColor[0., 0.42352900000000004`, 0.20784300000000003`], 
                    
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {0., 400.}, {600., 400.}, {600., 
                    0.}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}, CompressedData["
1:eJxTTMoPSmJiYGBIB2JmIGZkYWZkHkqIgRHoaIaBdQMAS8ME2Q==
                    
                    "], {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 
                    3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, {CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQZaBQ73/Xun50kUOyxy3fb5r0qBw5YTZfvmA/nC
zQdOLZQtcNBuF7t5TrTYoXzffCl94QIHIZA4f7FDUcbEtzXf8x14dTfNff+/
yGFGHlBmVj5E/nyRA9j8GfkOny75JgnMKHJofR24Q25qvsOy2UcUNlQUOYC0
23fmO3Q6Jjy9AOQDeaZxm/IdqkXWuT9Mgeq/kO9gy3V9cYF/EcQ9b/MdFDYA
bQ4sgugTKYCYkwhVr1bgwAdyT26RgxbI3doFEPGyIog+Q6j67iKIOywKHKpA
9q0rgriTp8DhHcgdVVD3sBVAxBcVOYC8f/dHPkT9sSKIOyWg5l+D2m9SAHHn
zyJIOAL5D0Dhy1UMUQ/kP14KtBgYvujhDwBPyaXl
                    
                    "], CompressedData["
1:eJxlVQ1MlmUUZeSquWJEX2gNSawcEwtdmSWVV4uwOURpc9mIGeVGJd/33PuU
ljU2p4lm5oiVzp80FQdlStaatUnUyhqlox/GrBVJs2ZkgJmFrex93nPQLdnY
y/2477nnnnvu/fKqUuUL0tPS0hZHv+EZ/3yvcuLL0qrMbC+XL2trf7VTpebn
v5sHEl5mTl41bf5nKp1PHhs7cbiXxa1brircr9JdtmZdst+k8r17Lkl/S2XC
d9deuLTTpGHksLkZdSpvf7qodcsuk3XJrGVtO5l/n8nOjR+NbmlT5F1jcv/D
Rd1lEf6+3Gd753yuMrrFquvfV8kKPB5T8HmD9WerFIY6zSqNAedulZj/iyrV
9cefmVqg8nRid8kRp1JyZEli90WsU6qyPvDIJP5E9purkhMIjFD0Wcj3LlA5
ED64hfh/OeCnVH4MhU87WRj0OaDQ44yT6L+TKuca4j4HHo8b6nU54Oww6NLi
JOp2X26D4fOtzF/OeLaTW0NikUnHmG8Ha/Md9Il0i+tkOvCvVHltIPrjZAp5
2Qrcj1PgUUD+O1LIn6Eyff7RjjH3piTj+r2b+2o4t1LGL7H+r0n0u8BkSuBR
lsTnKziX4hTmUM+++lPIb3Zyx/Cu7W6Sk3F12YcPrXWYe4WDD4ap5AU9nhjq
V2XltIjQCierwrNJwaPBwX+7FO9tcvJDwNmg8kXoc4PDHPqdbCt+5/d/mhi3
s87XrPsynzdTl5mcYx198rwDnzX0T1Q3ntdhxt0O9X6hjwbIO81Q74SDr0Ya
+PVQjwn09UHyG2/op4n8Kg06RvrEflhpsiTg1nKuPfTNauafYv4eh/3J8tA/
4nd70PtKL5cG3frow7EeOOkq7wbfTPHy4R/5FWtz6J8KD70zz8WxThfTz/O8
zAh7MOgQF3v038t+y5nfwbk86rGPrezf+bPziONa8jlEffd4+Oro0Lw89J6j
58UPhPvSxTv0FO9Am8c+LOI+v0n8pKLPVzx4VXGvN3vsR7Qvv4V+n/OYYzn3
2VivjP3fyXgq92c844d4FxLEe4HvJ6hnO/PTqc+pc3F8xwZVPgnv9/BOFnHO
Z4z1DPPIIP5thn5vYL838b7c6OGXWbyn0z3mUm2Y22Ue7+0lXj/xuwx++cqg
658GH71u0OM07/Vy+vkb4j3CvA8Y1/DZSPxq4q9m3oP0+0KDLlWGOZSw36XM
v5r3cJPJqLAwx1QKwt04aLgjjbwX+8nvrvPjeL+2cn+y6Z8k/59DvHnsO09x
Vycb9noc8a4zzKtl6PuAfK4w4Ocb7tJ23sd/+X32k8EPJ/XsHOO8XsU+jvDy
/+/X/wAwLEGX
                    "], {{277.25, 304.707}, {276.43799999999993`,
                     304.637}, {275.53499999999997`, 303.688}, {274.801, 
                    301.855}, {274.168, 300.465}, {273.39799999999997`, 
                    293.18}, {273.52299999999997`, 293.18}, {273.02, 
                    291.012}, {275.789, 290.094}, {277.051, 292.879}, {
                    278.93799999999993`, 297.98799999999994`}, {278.949, 
                    300.16400000000004`}, {279.074, 302.332}, {
                    278.78099999999995`, 303.97999999999996`}, {278.062, 
                    304.777}, {277.25, 304.707}}, CompressedData["
1:eJxNU2tIk1EYHlNMIv1hEVZqU8JuhA21ixE9SmGxItT0RxcZo8twbvt2zvnm
yCjKZNmPTAoqRIbGgkpUokQq1ggpkRCVQuwmIpISEcOkpKK+s/cE/Rjfzjnv
+1zeS7bDW37CbDKZYPzk19LDnC1lHFPh1n6LmeNNYDbXupujfllX6aSJI/6+
neNaemJV6gJDtjwXchw+vmPi4DTDC9vWpuLNHJeK7dPDvQzVj/ctMedzimtj
aJL3RRynJZ6f4aYnrSEKjsbPZX1Zxxj6sox/JzlSNz1o+2pV8QHFn86Id4Tj
peTp8EnZJlOuoPuN6hwQKJ00GLo1yrsoyM8hjfCvCHTs6Z37/c2LL2d2FVZf
F3g04I+ESrzYK/PaBa4+n1939IkbRQ+Nh7AgX69dWNoQHWy/JYh/Ww3dRwSc
LRKphnB/KLyuGopP0Ynf7qJ6rNIxPvS9Yqqylvwl6ygxPjk2D9Jk/CIV/96D
G7I+STruxUYPONK95CdRJ367l/LNOum976V+OXRUygJylR/RSd96N/VvhZ/0
RVy4Y9D0FPmx1prcmfHRhThsvp90VripnhY/miV+0E04Y0pP1EP8TMd+mTev
9JQr/Vs0ii/VidemIUMOymodOxeP3daCGuoioZV5MYHhnHcLZ19pkOUOzah+
5vkof0JgRL5f8FH8uOpvq4/8DgpkStwERnqN+qTI+WlW8/DrH77CmxWQdpoL
GDYEl48Pdav+1av8WsX3lpGPKoG8D2uSzhvzHs8zzvG8P2o+CwTcn37ejY0y
0m8RNM9hRv2yKD/nGO2FMa/xfTnCaM4zBflwMsJJU3x1jPwmKD2XFf4Ap74+
ZTRv/ZzinzE1z5z8zqh9aeTU1zlG9T+l9juR03z+t+9/AejMx9k=
                    
                    "], CompressedData["
1:eJxlVg9MV1UUJixiVIzA1NV0/lg6I5uQ/UOETsMCV44shWSJzdH88d7v3304
3ruP5mbk0loTEkoxQnRkDCnHJMWKSJwabmSSERhDRoRgfwQV54rVu+87Qpts
7O7ee9453/nOd8/5edYHX3o9PCwsrNL5V6v795SkH+LP39g0ZtCi3gcjNidJ
rFcM+vONpx/PS5B0ZM6WSysv8z5e0hll/6tBzumROXESa5dBn+w+PvdguCR7
+mcZ/S0GmS3V9y+aJimj3zmpNnAeIWnbM68NnvGyfYykY9cWvLo90aA/lP/p
kjKV/Q2B9T6JuGOCdsy6PTt6psR6ScB+FvsfEMgjViKuc5+bn9KXdQ/bjwr4
iZI0dnbF+pirgp5/0kFSbSGffIPmHjS8ZSmS+rLe+zAQYZDLz7gFP2s53y8t
mq0OqgyKfqSx6q86iy4o+0b+3mT7bgO85VkUV9LaXjNsAEeWhfwjC2mrWp+z
gL+T+U+3YFdrACdZtPbo8rvDg8xnOttnGJSnzp39w2/P6O5IMhBnjQVeI9ne
z/ldFuD5EMffKShRxZuwKDWqa18oRTAe5qcnROes4flJ2ayHuBA1q3xyJRWr
Oh4NgB9N0t5nv7gysdBPyYdOFbVskLQzEFvS+qYPeFZIcqJrX+3REfcxSaUK
yLu37l19REvwu04nj+LzmkUnVaFKdeQzYCHvah1877Jo3Enr2BbfLXu3PoUW
8Lb7EC/XIrXEH/YBP03Zu3mPm+D7uk4qneofTcpWji5p0M9ek7YrvIs1SlO8
VZh0l7OkRmnkH/q7bjRk0ryIzRXpQwXQZ6YJP09o0Ft/EQ3UOgV6UQc/s03w
c4HxxZjAI33QQVMR8q3X8R56i+iEcrSK8YwVUZPy78R34zjfu/UqK4BeHzKR
57ICrPkm4kcWIP4uk7xlDtJmL/C1mXRW6WXEC/89jMfD+cSwnh3/Lr57LcpR
/HzOeBIs+L+oQT9Lrcl8XV16LVK0pabp8LeJ72N06HCHRauVv04NeR7g+h/Q
UP/TFutFm9Svm/+jGuqfzP0sXgOfGyXqVaghz6qbetTA02FJSxRx59n/93IS
r8vnRd7/rEMfv0gSCuieAPD/xP1wRgj7fyR1d1x/eeDbIPTnscnpDrElq4Lw
n2GDz8EA8ObYsN/mh+7W2dDPYtbzGhv5jWjAudpGHnWc72kb9Wjg99Ru4z0u
8IE3Z/+NE7a33MfvwCYFp3XcN2nv4lnpB95pxTRfxd/tQx9LKYb/fn5vwWLY
z9Ohp9Ji8JOpw/9bxZPvy+UjxPbD3A+S2V+Nn+eMje+9AfDzNeO5Lch91UZf
aQtSgupz+2zWfwj2VTZwmiHk876NPBpC6ONbbdQtTODesoGTBOq20QZPuQJ4
Nth4N/UC+eps3yiQr8H8HhfA/Y6Nvnjz/gPGc1IA734buu8RmAev2OjDn/J8
SWT7Ae7/Hq7nhIE632kD51UD/fk3no/f8fw8JdEnGwyeIxLf+bn/97F+E3n+
TPA8Lxewn2lzn2X+FjKenBD0dgfvy0Lw4+jd5aWL+d8vcf+AAO+1EvPII3Bf
w+8reWrv+lkytXf5XSowNyrZfzPfV7D/LoF+Ui7RpwZ4vpdJ5oX5/5jtB3m+
10uc97C/Bok+0y2QdxPzeU6g7m38+6FTkE/18w7GO8Lz8QT7/1eg33/E7/8F
5reQ52cl87+c7YcM+Fkmod/fDXyXxvN1lPXwv99j/wFFn1ST
                    
                    "], CompressedData["
1:eJxTTMoPSmViYGAQBmIQDQZ/kh0uKN3+WfeuyEG4+cCphWeTHcr3zZfSf1/k
8K7G3jRuVrLDjDyh5gMPihzegvjrkh2qRda5PzxSBBFflOzg8bBKZN3WIoeM
iUAVnCkOO+VaXwc2FTmosTVOdZZOcXi8dPYRhbQihwmHvmrEaKc4gO0Ngspz
p0D0CRY53PlZl7VHJ8UhKsX6vj93kYPVlhNl+7xTHEDUfJYiB67riwtsy6Dm
WUDd05bi4A6yPx1qfn8KRF9jkUOBLVBHR4pD3C5PHqbbRQ6qIPv4oea/LXJY
5Lrt818OqHuA/t8KsocpxeG+f+/0PCAfPXwAlnOEaw==
                    
                    "], CompressedData["
1:eJxdUmtIlEEU/ZSQkJCw6EXJKmEPERWKwKiOhZRFhAX+kCxZE74HbvtNUPFd
EexB7I/KJWiLCKulHwtSIhK9WCJ6SIEsRciiZraJhGxRSesSQjN7pz8NDMMw
Z84599xb6j9+sD3fMIwKudU5ceBiJNBEMNT6JnAq3ruqqpGwvXAkGkwLXAsU
n322l9Ax/Sf244sALb23exIanxA4P9P4sGQD8RkTjPMRqsbXFnS3CXxS/Bs1
vlxAsr253UbYtyVU1xoN4ue7/f7Flwjrahb2rW4OwFP8Vwlj2S77aZ+DosqB
m9/DhNrBoZNxx0GibDTb1aP1GhyY4XTnjm5CXetUoixjs+5RgrtNFnDLxqMS
iawlvFKCm2zGL9d+DBsfTn8tr5n1mP+thSXKX8xDcjhzKHXdYnzYw07Ff8LC
muZjWyd2efi9/vDl5yst1pP3XC4DJtdzxmM/901UXFiWHE57eK30h0yuu4OY
P2ky/0ti/pSFiMp7jFCteCtt5PozR2h53LAoX9aX85clyF+bjwiH/eR1so/6
AO7UP/g1P6vrPRfkPOMEX78wwyGX9Z8QrqxY0FQUdZG6e+OFr59Qqt7HXdYb
JJ6DKRcqxuA/fMZFDv5R9y/lsv8Zneeciz2TUnGeEFIBFArOo0fzRQT7t/T9
veB/fuJ8PgvmayGodvTKefx/Pv8COAIxWg==
                    "], CompressedData["
1:eJxTTMoPSmViYGCQAWIQ/emSb5LAmzIHBhB4UeQg1Hzg1MLnZQ7l++ZL6T8v
cpgswRLG97DM4b5/7/S8B0UO1SLr3B9eKXN4W2NvGnehyGF6HlDHtjIHPt1N
c9/nFjlcrXipZrimzMHgrgpbo2yRg/vDKpF126HqHxQ6LHLd9vkvSzlEn0+B
wzFv807HkHIHl+6c57935kLUu5c7CIPcsTPLYYdc6+vAnHIHILlDDsgH65tW
7gDSlpCYDXHPinKI+zlyHGaA5DeVO/iA5N/mOBwHKVwE1V+Z65AxEeiS+VD1
DHkQ8+eUO4BsfdiW55D7/PfKj0HlDoe+asT0pxU6gMPHpdxBYUNRxsSZhQ6P
l84+omBUDhH/VQhxR3c5xB/LCh08QO5vLIf4916hA1D26YUkqP2qRQ5WW06U
7RMth5jTUwRR/7cMYv7JIgeQ9PwvZRDzbxU56IPC8XMZxN0vixzQ4wsA2srK
og==
                    "], CompressedData["
1:eJxNU39ojWEUvi1JaAl/rDvmGtlKmisSWp5pmoWWH1k0WrfpfVsMZzKNbiFl
dNu0NCVuiHIzrm22tc3aLzYLXdev7q7PbEtICKFLyvt+79Hnq6+v533Pec5z
nnO+2b49G3cmuVyuxerV3+qe75lFhRIfD69csuM1IfQlut6XK1FXNvVY1ytC
7qldb397JSqn38gbeU6o0fHzJVz6GSTkFL+JpGdIZFlzxx/pJtweONAZXCSR
PfHF5b2NBJt/jkRFZ9CddZMQTY8n/G6Js5o/RDj+YUNrWkJgeZNKrOf7X8LE
33Wwvg4+IBQmL2g4/1lguCBQV/aUcGl187c/7zg+RtBls0cF1i6tyimOE35k
FlX3WMLofcn4sYNXaf29AnkjqsM46+1lPTHut13AEyZ5+glhmT5vEdhWsmK4
4CHnN3L9fgfb/F1kdNwSUN0OXmxhf0ICVdq4JjK+X+B75dc+bVyNg2fqQrUC
h7T/DYShhL+044Qwec2EDO+E6zOOcr02wid9XimM/+0Onqb5uh1sxw8Qtrfl
T06qEHh28P08b5T1lzO/mvc6rX+3QL9uZIgwduVcn6dE4J7Gyj977luZ3yLD
6xFYqM8t1p/K8+rgfZnF9cNk+nJzfj33lyJQmzJuS3I5xwv2y0cI6MWMCKzR
88onxB793DR2RqI1TW3SZjJ1A7xv1xx8VckOq3qT9H6clLDX6P4/P6XhjxDu
7FeV/dLM12J/SyW+qt9iyijr+e9/+QtnxnWn
                    "], CompressedData["
1:eJx9lG1IVEEUhi8S/giL2CIiQsxMtmDbXe2DCvGEFoZIn0SISEiBcO+M3jEs
yiJZQiNiMxGtCOmL6E9IlEmQiUVGP8RWIpbaNCQkosSiIiTozJlZZjLowmV4
7jl75j3vmdnlNXW7D2U4jlOCr1wnbl5+mvOWQU6PqG0bE7Dx3vPG/gcM5NL9
TsC++aG7VzoZFM19fb0+KYDymxh8aSpeV50Q8Fmu6xmwyZnb0z0CHh1uXzIn
n0H5hjNbDhwXcG1r77ffVQwc+VQKeJn75tfJCzpeIWBZ5cHNY0MMxnec6+QF
uv4NrWeFgMfdS8OpLAaY/WEk4cPKzOaOkpgLq1sWJ4fLfTg/+D1YVefCkX5M
LNRx5OqH27MykO/LPrgLTzAtXmCY9COTHuRXRz/mR634JmlA1DDpsTicysts
jprf17ahE1ac9CB38UBsAJl8iPgg28hFfVJ2PGL0k4/IDbIQcl/26U+7kMm3
ehe+JipqFiCTP8j0HXlIGok8D8c0FfaVX1ac9rUYq/Zl+yZ/YWzgxVXkgFyR
f6CsQV/3i1x61pucsZh0CpNP/QoTn800jwbtB3Jc9jubW1wYkT4G9f4nPHX+
glp/lwet0rg1Wv9Fw6Qfmb6n9SOn6yeHf+6ZsDgh97lkmPT+h9P5f/VnMfU3
pfOLtd5TXJ3XPPEP0/w8DmXvjy26E9Lx/RyeyTmu1fFSruoVCaU/xFW/23Q8
wtX52Gny0/eL7ustDp68j4063sqVn72a93Klf1Qo31ZxdX5TAvAWBmIOV/MY
1/nW/8MfLAnpTQ==
                    "], CompressedData["
1:eJxTTMoPSmViYGDQAGIQfUHp9s86lTKHDseEpxfuFTmU75svpS9f5nDM27zT
EcifkSfUfECizOHx0tlHFK4VOVSJrHN/yFcGUXewyKH1deAOue+lDjvlgKxZ
RQ6xuzx5mJ6XOhz6qhHTH1bkUA1S/6IUol68yGEHSJ0MVP/mAodPl3yTBHTK
HFTZGqc6f89z8HgItMG3zAHkHCX9HIf7/r3T8wLKHLivLy6wfZXtAHJWgneZ
AxeI35btAHa/SZnD2xp707i4bAetdrGb5+6XOgg3Hzi1cG2Wg9WWE2X7Uksd
ijImvq25nAlxz4MSiPn5mQ6HQe68VOIQB3K3fybEPpZSiPnHMiDqXUoh5gP5
y4DBsGFDqcMEkAfvZzjYghTylzms+gj0SESmQ1SK9X3/dKj7p2dBwrWuzEH/
rgpb48MsiH9XlDkUgjQ2ZEPUryxzYACBP9kQdRuh+s/nOUyWYAnjm14Gsbeh
AOKeBKj6tkIHO5D9sWUQd8wvdLAE+Te+zEFxA9DHewsh9qVAw/toIcS87DIH
A5A9Zwsh8dtU5rDIddvnv0cKIe7pL3NQAOm/WQiJj4XQ8H0DNS8Oyu8ocnAH
yZtD+UeKIO4ygLrnchHEPG0o/36RA3p6AwBMEhxV
                    
                    "], CompressedData["
1:eJxlVQtsFFUUXZCUAoIoTQOKda0KbdS0BcFPU7gtEILSIFaCkM3abmfezEDp
vvf8QNKKIKAhKIWA36INlhrExhDSVjBa15ZYYwguJYRUfiFVS+XTIn6iSOK8
OTctSTfZ7N6Z++6ce865d+6NxZ+xh4dCodX+1/x2N9QeDvfbdPdyK//ccU2X
q2fPiHbadGJN75S8To5bbPq9szg2/jtNrXV35pzZy/nNmkLms8emzYWlvySr
NT2Qsv7tOfU2Pd70/cutczQF9ffbtOni4oMZt3H8M+cfUPTWu5V3bPjDpgkb
Ej/sLlP0V1akpm2sQP4tik79s3bFV2mCkpn+v42SXnC3X66usulghp9xRNIx
c/01rj9GUdfRv0u6G2wyj6+LKPrsqg98l02req5/evW0om8M/mqbcs/cn7L+
hgJ+y8ZvhiYDK3M+9ztFU6epP9qmT0wbYU1XDB8/WeAnU9PUvNTGyVGLzi3y
OzmraFvbn1mRfAv4KofGAZ8ZFpm2E49wv7dblGPwDON+QxaF92t3e4cErqZy
MmVqPuJ+15Yjf5Sijqce3Vz4dDmtNsIsVdBlejkFtKdr8PZrDNd7Fe0zfCRj
wPGsoq9f3DFxREuMzO1FxRL6+M87ZPBOk6QN3z2M7z4JnQos8DOT+Wy0aLIp
4Ciau6Wi5/q3Fp67TsEvFyzw78dB/UsW8JQNxgG/aySZdkp7LapK+3z++Yck
dC22gTddQo8PbPSXIqnI6HXRpgffSO86OkrCT2GBeqncDwmKfrng1uHtcTpt
+F0ooFtLJfyyTJAsGH2yfu8q4BaCnjAGqq0YEgf9hh3ys2WBqIB+2Q5wl1VS
s/HdNAe4tsSB+4qgdqNfkUS9dAd8Ps/6TnRo3MMHPuyrkqhfyvVekVRjhN/B
+XFJS0xitwO9SyTmbaQLf+Vyvxs5niXRZ5EHfz7H/DR58NPrXP8LD/V/lPBT
o4f5TGN/7fLg9+WsVynn1/H8uh6uNyrwlO9BvyOcP5fzuxTz5sH/rTyv73v0
8byWazcSPA8Ng/kLDQ+bOH+cho4lHvQu1Mgf5sF/SzXmo9XFfL/E+ybikrHx
7DjHj7mon6fR/1QXc/0b41/pQpd3FO4fd+HDxYr96YKPmdxfqofr/jwG/vyX
888zv+0u7h+T8N+bLo01ep/keY6yXv1D4+B8hwM+s9RAHPQ3Q2Ef9rF/mnmf
JR3Mx2Hm85CDehcUjTH872M/TdK8Tx3gzWY+lziYnyc15jTHAf9RTcrMyX9i
IMY+FwP5Ac+7Bb1n7o/n/ISA/3byvugXwBfhfTWB8WQrnF/gDOy3oH7uYBzs
07sc+PcS+92vF+yvazw/Sa6fxvtuD8/vMj5fy3gTg3HQfx/vw60C748s9tur
As+vZ79M5/Nt/L64h/tL8vtvpEAfJ5ifm96v/wMD2V+O
                    
                    "], CompressedData["
1:eJxlVg1MlWUUvrNmLRXLLK9JKMyAVg6wksKxDimZYSbaLubMGNzLvd/7/d5P
+zGbm5FL1wTEkjYypiYk/ZnDFvmTkANMggvOOQtGzLVshc4xs9bPet/3OYOt
2Nh3z/ee95zzPOd5z/emlrkrIxMCgUCd/FfP6vZrmWszBG39pfiLlLM+XTxQ
f2pOUODZ79M9E7e8vegmQfe9ceeFnm990v6jBmUNzp245YxPi9+0fvrzMwP7
23z6quGurMENBm2a/smS4fc53jaD7l4TXjhk+7Qsd3tB6TmDYjtHXn20Mk6P
tHS9eELGP/fyz+k5CQ/7nxG07sulkyeccen7PzaLY6WCAurvLZfecaZVnpwv
KJQ07/CeIhf1XDfgv8olGfWhdbUG3te5yLOR67mV43fHSG2/MsVDfSti9NIJ
uSDtCz3XV11si1Jfmsxc62L9UJTyVJ1TXapRceujlKzwNDnAtSsKnnKdMf94
/i3n9w/YjC9Gj5X+mEhbbyO/F0Odm+2xeqS3l7/bJk/tCxrg6YhNzylcJQbw
Bxz6LXNtdXvcgP9le8zOyLn5o2Rp67r98fX/2kdkOQ3+//2zVT9Hxm2dX9qa
10qDdtRJ4hM27Sv8fPRvz6APr/Y/VTZgIf+UGHiYbYH3B6J4f9wk2a1v9m6t
AN5GE/xkVgDnaovriABfl4W491dQZ5EswGO8eyKoP8mB3+/lVKD47DXQL9lf
8M/PGYLU9tJhGzpNFeD/Bgd9IQHe5zqUUHhDAu+TuX9Sbxpv0AHemKD1SkiT
eN1ifY7a0EORQJ2tBvLeWwG9uAbevxABP1/zOVvKeKeb8FsYQR0dJvjLjSBO
jgWcWRHw5FvQcUqE9W2hnsnMT6MFvQ+HwXeHhXPSxLbcD/2GgfcHE/xsD1O6
4s000f+qMPgqGrcnqfjfCeixM0wdqsDXo8wT8zsaA95rAv1tMdGPchN1pdrk
qx+jgppVnx9kPoMm6g85eC9t9MUBDzNNUmlOhlgP0sa5cDB/ZnIeaeu+zDKB
W9oal7T1OZS25lvamv/VDlWpwMkmcEhb60La0KcD3lNMUuNhUNpal3NM1PUs
15M6bmu/Dzhfpw0cFRa9ovr2OOOtseC/0YF+91o4l7UO+O7hPu/j+CMW+HnN
gR5KbPRzAc+fqVznGtbzAsY55NCAmp/LOG6ZSyWKl+dZ15d4voUdak2Ryszz
oI/ZDs5tlgeeLtmwMzzU02cj7ywP57Wb50LQA49dNvLf4aEvkgcdf5oH3G02
Hd+wK3jjPy76dNSG33kX8eXc0/o85CJui4159LGLeqR9WeFvdoHrMM/ZJsb3
Kc+t/fy9aOa59x7HP8D11buIu4PnXpULHZfb4HO3Cz2U2qi71UX/ySapuoNX
05mPVotUuIZs/p7ELOTf5OK8y3Os4y/neN0m9hVy/e2st20ueO3lc3mbR7cr
3neaY3zr/XJu6PhXXPT3V0FDT0vmazzwdUogbloc/u8KxDvKdkLg/B6Lg+cA
6/dgHPVnmyS7E0rq5PW/BOwZPuqo5vtAq488K3n9NN8HigW+p9LWcYt5Hp/m
+8EKrkfamuflPBflfULr/klB+jPazfeHJwTyyvuHPvdLBPTf42OuFHL+XvZf
zPGlrXlaJPC97mX/At6fYH/5PWhU+aSt+c7nevt86lf48jh/H/s/LKCDfsY/
n/PL+5PGMU+Qos07y/enjPH1fwEq9CVv
                    "], CompressedData["
1:eJxTTMoPSmViYGAQBmIQXb5vvpS+d6mDbFSK9f2LRQ7HvM07HQ1KHZbNPqKw
4VKRw7sae9M4oVIHj4dVIusOFjkwgIBcqYMMSP38IoeMiW9r7MVLHQzuqrA1
9kLlI0odcp7/XvnRr8jhgX/v9LykUoelIPN0ihzA9pWWOjwGCfwodPh0yTdJ
IKTUgU9309z3RwsdhJoPnFqYDlW/r9BBGMSvLHU49FUjpn9bocPWE2X75k8q
dVjkuu3z3y+FEPvmQNXrFTkAXen+cFmpA8gbCbFFDoobijImtpY65ILcs6fI
4T7IPWFQ/10ocgCqenohqNRBAaQO6P/JEixhfP6lDtrtYjfPXYS6Fyl8AH3A
iKY=
                    "], {{238.277, 297.52}, {239.04299999999998`, 
                    297.59799999999996`}, {239.97299999999998`, 
                    296.89099999999996`}, {240.42600000000002`, 295.895}, {
                    240.91, 294.828}, {240.668, 293.812}, {239.875, 
                    293.617}, {239.086, 293.42599999999993`}, {238.062, 
                    294.129}, {237.578, 295.195}, {237.094, 296.258}, {
                    237.336, 297.301}, {238.125, 297.49199999999996`}, {
                    238.176, 297.508}, {238.227, 297.51599999999996`}, {
                    238.277, 297.52}}, CompressedData["
1:eJxTTMoPSmViYGAQBmIQfd+/d3rekSoH/bsqbI2eRQ5a7WI3z62ucnhXY28a
51XksMh12+e/E6oc3B9WiawzL3IQaj5wauHsKofW14E75ISLHOy4ri8umArl
/y90eLx09hGFC1UO3uadjgm7Cx2EQepvVjnskAOqmFbocLXipZrhoyoHPt1N
c99XFzpsOVG2b/6ZKoec579XflQrdAC75x7UPPlChw7HhKcX3kH1ixU6yEal
WN9nrXbQBrkzEqqerxoiP6PQoXzffCl94WqHi0q3f9btKoSo+1nlcPirRky/
URHEvHNVDrwg+92LHBQ2FGVMPF3l0AkS9yiCiB+Huh8YHujhAwAjvJH8
                    
                    "], {{323.22999999999996`, 289.99199999999996`}, {323.371,
                     289.367}, {323.512, 288.734}, {323.605, 288.094}, {
                    323.91799999999995`, 286.707}, {324.191, 285.332}, {
                    324.47999999999996`, 283.969}, {323.26599999999996`, 
                    285.641}, {322.262, 286.98799999999994`}, {321.828, 
                    287.469}, {319.082, 290.72999999999996`}, {
                    321.89099999999996`, 289.613}, {323.22999999999996`, 
                    289.99199999999996`}}, CompressedData["
1:eJxTTMoPSmViYGAwAWIQXSWyzv3htlIH/bsqbI2JhQ7e5p2OCWtLHWSiUqzv
xxc6XK14qWa4pNRBqPnAqYXhhQ7VIPULSh2WzT6isMGr0GF6HlBmXqnDcZBG
p0KH3Oe/V34Eqj/0VSOm36TQIWPi2xr7uaUOO+RaXwcaQPXPKHWQBZmvXehg
ueVE2b72Uof7/r3T8/QKIXQHVN4VwQe7y7fQIW6XJw9Tc6mD4oaijImhhQ7u
D4E+qC912AkyP6oQYk9NqcMFpds/62IKHT5d8k0SqCp1AIrukIuF8ksQfLD7
c0odgKY/vRADdR+QD6ajoPyMUoelIP+GFDqU75svpZ8Oda8fVD6l1OEYyIEe
CD7YfMdCBz7dTXPfJ5c6zADZY1HosMh12+e/CaUQcVOo+iio+cDwYgCBEAQf
HH6hUPXGUP/6Q+PLvNABKGsa5wO1zxoaXh7Q8LdB8MHx5YTgT5ZgCePzLHTo
APnbrdQBFNz+wVD3uEDND4e63xEa/tGFEHW2pZB4hoWvBTR+46Dy0qWQdAPk
C4PSjSQ0vmyh/pGGutewEEID5cHxAIx/cDoTL3XQahe7ee5zgQM4fdpB3fO4
AEIXlzq8A/n7VIEDKPnMv1bqYMd1fXHB1QKHByD/XYKmB61COF8bZJ4hNLwu
lELSkTc0PM9DwzewEKLvFDR+46DqD0Ddm1zogJ5fAElDb5M=
                    
                    "], CompressedData["
1:eJxTTMoPSmViYGCQBGIQffPc9+DHc3MdZKJSrO/7Fzrsny+lf3dCrsOhrxox
/QGFDrIg8fpch6sVL9UM/Qodjnubdzrm5DrskGt9HehR6OCY8PSCEn+uA5C3
Q06/0MEJxH+d43Dfv3d63pMCh0Wu2z7/Vcl1WDb7iMKGHQUOamyNU52joeZN
KoDYtwFq3oICiPl7EPyijIlva8TzHLaeKNs3f1aBA9i9vnkQd30lzC+05bq+
OCDPQWED0CT+QodjIPOfQN17v8BhC8jcbbkOnSCP3CpwALpaqBnonskSLGF8
j6HuXwINn/cFDsUg98zOdRBqPnBqIXuhgzCIBoafJcgg+UKIezfnOujfVWFr
NC90MADRe3MdrEDyrgj5DpB9wPBED38AsCXAaA==
                    
                    "], CompressedData["
1:eJxTTMoPSmViYGBQBWIQ/Xjp7CMKkyocdsi1vg50KXQ45m3e6VhR4aC4oShj
omuhw/Q8oeYDMRUOnY4JTy+YFDpYbTlRti+0wkH/rgpbo2Chg3a72M1zQD7I
mA1/ChyApuyQi69wKN83X0r/Y4FDVIr1ff9YqPn3Chy2ArXPj4Lqv1wAof0r
HN7W2JvGnSlwyH3+e+VHkwqIOTcLHCZLsITxWVZAxO8UOFiC7FeGyv/G5Mfu
8uRh4q+AiLMXQuz/XO7wwL93et4vqHselkPc+67AwZbr+uKC61A+0PxPl3yT
BC6UQ/y1F6r+djnE/fOg7vlZ7gAKpoR0KB/oXwVQeHFC3dNf4bAMZB5HgQOI
O39ChcNxkAarAgc7kH1TKxzA4V5TAKFnQN2/tMAhYyIwJGZWOBz6qhHTv6XA
oVpknfvDORUOws0HTi08CjV/NTT8ThY4HAap21UBcc/ZAkj8XamAhPOuAocL
Srd/1l2BuudUAcRfF6HueQUN/9MVDjNA8SwBjd+d0PjUK4S4f0OFw9WKl2qG
NoUQdyyE+te50AE9/QAAyMoYyQ==
                    "], CompressedData["
1:eJx9mHuMVcUdx1ckykNZhK1aRWVXKgTqk5eCawfEAraGWKM0Pimi3fs458w9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                    "], CompressedData["
1:eJxTTMoPSmViYGAwAWIQHbfLk4fJuMih9XXgDrngAgf9uypsjZpFDrZc1xcX
BBY47JADyigUOQg3Hzi10LPAYZHrts9/ZYocls4+orDBpsChWmSd+0OpIodj
3uadjiYFDpMlWML4FIscrla8VDNUK3AACSdIFjnIRqVY31eE6hcpcrADmS9b
ABFnLnL4dMk3SUChwGHLibJ981mKIO4wR/BjQe60L4C483+hQ/m++VL67gUO
Wu1iN8/9LoSY413gcN+/d3rej0KIeX5Q/d8KIe6F8T8g+BkT39bYvyx0AJKm
cX5Q970ohJjjA+U/KYSEg1uBA8ga/8eFDgwg4ACVf1DooA1yhyWCvwxkvlEB
xB1A/juQ+VpQ998thPhPvQDir+tQ84Hh9RjksAsIvhXIwRcLHRQ3FGVMVC2A
hOuZQog5mtDwPwH1jw7Uf0cKIeboIfhg80wQfLD7rKD+OVwIMccFGl8HoeYD
4/uC0u2fdfsKHXKf/1750QeaPnYWOhz6qhHT7wd1z5ZCBxmwQQWQdDO9EBIv
/lD3T4Wapw81fzrUfiVo+E+Fhj8w/i1B6icXOszIEwKmuHwHcPrcXejADTTW
dlW+A0h04Xto+FfkQ8zNhaaXqflQd0HTm3QBnA92lzKU71MECQcbaPrxhup3
hqYftyKI+QFQ/9sUOUwHuSekwAE9vwAAcUN0QQ==
                    "], {{401.562, 
                    256.668}, {401.47999999999996`, 256.684}, {401.387, 
                    256.68}, {401.289, 256.64500000000004`}, {401.289, 
                    256.64500000000004`}, {386.039, 245.797}, {
                    385.66400000000004`, 245.418}, {384.15200000000004`, 
                    244.07399999999998`}, {384.90599999999995`, 239.348}, {
                    385.66400000000004`, 239.895}, {386.758, 
                    239.47299999999998`}, {402.105, 249.875}, {401.812, 
                    251.094}, {402.484, 251.055}, {402.805, 256.445}, {
                    401.562, 256.668}}, CompressedData["
1:eJxNkl9IVGEQxReJ0r2uyNZDhoqaUC9hPoRkiJPUQ2QspXlTQmQxkCgn9hP7
t22a9BAhi/RgIiEaBUmQRIWGilioRSy79tdELFR8CBOTCpGgmd0D64XLx497
vrlzzky2l0+cSXA4HPny6pk3k7u5Oc3QodvnFte/M0V5pyGHPvNMo793nw7u
NVTXtuQvnmG6+eN4f2aRobv17paREFNV7YFZj8fQ1paRt90DTK9UX2VoKvS3
bK4D+krobzDd2b6pIkV4V37i43Thi8NdO/KEew6/WP3XFNf3rkwe8zbF9YXP
JhqHrzPNelrb608ZiuRMrwUCTP2ZckN4qEGUwmNHC24dFC6Vo+Ya0y8pkyo8
96DzdZafybXn6b1l25BRQ1eZ0tWAcEnNQjhH2K0+hH/6i/dVX0EeNvK5zFTk
/Hz/gg2/wtFchL+uBc4OXkL/NvoXDmufFYaWtF4jU3afr67tJL43MLVrLuXI
x8ex3Euh9zLtV98Fhqa1fi30udBLfw/FVp/bkJ0ixoLodwvyesIxXaKJ3RuL
c1AHO458kwy1qmAC/QtHzzfwm4R9eIf+nIaeS/muEOo5oY8wVb88kpxgIa8I
5ivs06Deoz8L/j8wZWkeFv4vnKHzsLAPwmpr2UL9j5h/MvL5hPxdmO8X6F3Q
TzHJFiyEUw39kbUclf09v7j+aGUb6n9DPxv2/z+FclwC
                    "], {{
                    172.066, 252.312}, {164.168, 252.168}, {152.598, 
                    241.953}, {152.29299999999998`, 236.285}, {160.629, 
                    240.289}, {168.816, 244.14499999999998`}, {
                    177.29299999999998`, 248.285}, {175.92600000000002`, 
                    250.32800000000003`}, {177.21099999999998`, 252.168}, {
                    172.066, 252.312}}, CompressedData["
1:eJxTTMoPSmViYGBQAmIQ7WPe6ZiwNcNh1cdLvkkS+Q7qhhxrZM5lODxeOvuI
ApB/3Buo4EWGg2xUivV9bqj8twyH1teBO+Re5jlsPVG2bz5TpgNIWcLJPIfp
eULNB4DyDCCwIs/BcgtQwfMMh6KMiW9rpuc5hPHpbpoL5Pcf+qoRA+TLgMwF
8qtE1rk/nIZQDzYHyAfrA/Lf1tibxgH5qmyNU52BfP27KkBWnkPsLk8epudQ
9wD5q0H+uAO1rz3PwTHh6QWl7VD53jyHPpDBc9D4NRkQf/TlORTacl1fnAP1
7+Q8iL8iMxz2lkyWYFmXBwmXgAyHOJC9p/Mg4ZMDte95nkMvyLwKqPl/8xwK
QOYB+eBwBvJByuwrMxy+acT0H/oLNb8Sav6/PIcZIH9XQcOPId9h/3wp/bs1
UP8z5UPsrYfGF0s+xL4OqH28+RB6JtQ+Uaj61VD3iedDzFkHNR8Yv2B3bETE
P3p6AAAFaeu5
                    "], CompressedData["
1:eJxTTMoPSmViYGAQBmIQrX9Xha3xZYWD5ZYTZfs25zlMlmAJ47tc4cB1fXGB
7bo8B4+HVSLr9kLlm/McwOqPVzhYgfj2eQ7e5p2OCQcrHGSiUqzvi+c5MIDA
swqH4yCJnlyI+vcVDuqGHGtknHIdPl3yTRL4UeHgA9LHm+twQen2z7onUPUV
OQ475FpfB36rcOidnifUnJHjAKIOsFU6xO7y5GEKz3GQBdljWOkAVLVD7iBU
vUElxHy3XIj7TSsdLoHM7cp1eLx09hEFlUoHkHPnt+VB9P2sgLh7Y57D1YqX
aoZfKiDqtuQ5gKgN7yocFrlu+/x3C9S/SOEDAHzMhuo=
                    
                    "], CompressedData["
1:eJxTTMoPSmViYGAQBmIQzXV9cYFtXY6Dj3mnY8LeXIctJ8r2zQ/LcdgKonfl
OjglPL2gZAyVXwrlO0P5ubkOt3/WZe1xyIHQLrkO/Ye+asRszoHQwrkO3CDz
d0HVb81xmJEn1HzgFNT8vhyHbxox/YcW5jhcVAKaIJTjIBuVYn3/cI5D7C5P
Hib2HAdVtsapzo9zHFy6c57//pkN0c+X63AHZF9MjoMjyD3yuQ6904ESO3Ic
jnsDLdLIdagWWef+8FWOgyXIQ9+h9s7KddC/q8LWuDTHQd2QY40M0H/75kvp
352R47AfRO/JdSjOmPi2pjvHARwu+3Id0MMHADisi5I=
                    
                    "], CompressedData["
1:eJxdk11IVFEQxy8iIn1IlA8RGq709RJmJJFhjVFYZIgGFhGySIGeezDnVhYq
QlRQhKj0YD2EmC/Rh4RERIQbPlSEhAUhYpssabqu7rZKbEsEzZwzsuKFy+F3
55w5//n/ub7aC1Xn0xzH2U0vr/OtB4tqGhG2F2Y+zfmuIffMuf0TiGC+E18Z
7NlUcDFV725Yf/3tpRQ/PPJy8d8y5uMVl1Pse+7VdS3jkfzxZNsjhM+8DmnI
4/oiwqmsnQMPAtJ/j2f3D4ieeg86h37vOPtEw8KXE7Xrbnjw/vje26WnNURZ
Z5UH5YT+Irnf58G+Fx+aBjdo+Ho1vK1wAaEguCXjWtIFviYWRyjmuuvCREV7
d8MfqW914e7G9OqsBAKWrBrtc1yrb2l/TMHNSOWrzXHRH1X2/C+Eb8k29WZO
wVruH5P9EQU5LIi4mi8mpuk+9hIf8k+N5BOb/sQ1r4+tSSM2OojvsQ+zCuq6
KAni1aN9jSXEJo+Y+Els9BIfvqOn/4YV3CqlxlGZh9j4Scx2+YlNrsTtXJhR
8I4LxI/jZCzx0VBzdv88Wt3TyuZHbPwkbsnuLwvNITTz+lNZPyMIY58SJ39M
iT5ikwex8WkWIUCfg5MyXxhhnP0iNnPOiJ5J8TeIdg0pm98wQgfnnxC/ArI/
3bV59yI4/OySPMvl/H3Xzgvib4sGHqPngOh9pu28lcJjGlb+D/8B1W5zlw==

                    "], CompressedData["
1:eJxTTMoPSmViYGCQBGIQXWDLdX2xR7JD7/Q8oWaDHAcgr8DWKdlh1cdLvklA
vv5dFbZG02QHH/NOxwTZHAewepVkB8stJ8r2sUPV9yU5PF46+4iCRLbD/vlS
+ncbkhwuKt3+Wbcp00E2KsX6/uUkiHr3TAcGMICaJ5rpALPfMeHpBaX/GRDz
6pId4nZ58jDxZzrc+VmXtedOsoMMyBzzTIg8W4qDKlvjVOfvUPPfQ82zzYK4
+0Kyw1agdfPzshz6D33ViNme7HAB5J6yLIg505Md+kD+9cmC6AtNhvjzaKaD
cPOBUwstkx1unvse/FgxC2K+MdT83CyIvGayw2qQPX+yHIoyJr6tMU+G+L8h
2yEW5G53aHi+yHaYALLfP9lhb8lkCRa5HIi/gPzbIH8Z5Dighz8Az4+pxg==

                    "], CompressedData["
1:eJxTTMoPSmViYGDQAGIQ/bbG3jRuWbHDzXPfgx9/zXLodEx4emFBscMFpds/
675B+bOKHYC8rD1fshym5wk1H5hS7DADRL/LclDYUJQxcTKCn/P898qPccUO
QNG3NcuzHBhAwA9qfmmWA1DVqYXOxQ7qhhxrZNKg5rsUO/SCDI6Aqvcodmh9
HbhDzjbL4dMl3ySBgGKIuESWwzFv805HoPmhfLqb5ipnOYDdnwdVb5rlYLnl
RNm+5mKHuF2ePEzWWQ6Pl84+otBX7FAtss79oRxUfU+xQzHIfa8zHS6C/NlU
7DDh0FeNmNWZEH9MgLp/MoIPVt+Pxu/OdAA5J2FpMcSejEwHRVB47C2GuLMl
0wHknPkfih3U2BqnOgPNv+8P9KlAiQNIu/3FTIi/IkocVn0EevQD1PysEodF
rts+/wXyPR5WiazLLHHQv6vC1hgKDR+fEoh/I7Mg5qhCzQPKg9UxQvmBWRDz
bhVDzBfJcsgFxc+hYog8Z5ZDFShc9hU7cF1fXGCrBo3PnVD1DlDzNhc77J8v
pX+3IcuhfB+QcbwYEo7roPzD0Pi/B42fI8UOhbZAE+9kQdy5HRo+X6Dhj5Te
ANdEJCY=
                    "], CompressedData["
1:eJxTTMoPSmViYGDQAGIQ3eGY8PQCX5VDccbEtzXVWQ5RKdb3/VmrHKpF1rk/
rILyf1c6HPc273SsyHLoBKl/U+lw89z34MelWQ6trwN3yN2tdFBla5zqnJ/l
ANQksu56pYP+XRW2xkSo+iuVEPOtsxz4dDfNfX8Vqp8xy0FhQ1HGxOeVDrd/
1mXtYclyEG4+cGrhT6j820yHT5d8kwRYqhz6D33ViLmcCXEXV5WDGsi+3ZkQ
839Aze/PhNgPNO/x0tlHFAoyIe64XQnRF5fp8MC/d3reKah6+0yHdzX2pnGH
Kh0YQEAlE+LfvZVQd2RAxK9VOqz+CHTImwwHIZA4c5XD1hNl++ZfynAo3zdf
Sj+3ykEWpDE6E86fkQdUCbRvhxwwhOqqHFaB9FdkOmwB6auogoTbSqj6cgQf
7CyYefszHaaDzAmrcuC6vrjAdlMmxH73Kkj4bM10uA/yjwOCD7ZXo8phP9DY
u3syIe43qYKY8yzTARSNCbZVkPBmyIKEC1A/OH4FsiDucYe61yAL4n6/Kodw
UMT5Z0HiwwOqPyULYr9eFTw9gM1XhIZPFVS/RBUkPmqyHNDTGwAQLip9
                    
                    "], CompressedData["
1:eJxllAtIVFEQhkVKJKKiN2WWUiZZWVGEWTmZ4tpLjLLLtvfutlu4mZn5OnvN
AguREIklQilEyh5GtmpaqZhE9CIiTAqJjIoyizJ7h0jUnDNndy+2oOvnec38
88+E2fdt3hUYEBCwA3/4d/SL2UHFOxhM538kW2HVqO6abOQtb86dum2yAuuo
nhaNHNN8v6AjyQolH1NbQpHrQsw7Y5Gd7v6iuEkMrn3/88Q1qMH4IzcfnJ7C
YN3owKjSDhVaQvGEicEm+zglZqlK5+fm+Tje1tsZ3pQFj8OfDx7KUGEGXvuy
JtPHPfi7vWiPj4/d+hlp6U6neBtV2LD86BrbHT9P4O+XOyGXB5a+HbaNWXCl
qn433FuPG7+YQWtLxsj20PtvzVCZhRF/2+tjsS8jH35FWvApMwh94piPuSyz
QqU+wWaKK54BT6ukTAG+3GCR+xMV0keV+ScodF5jkFCW2Te0Ru7XpP7ISa8L
J3qsDN514sWrFdjbN3Txq43BmURUeKVC+qD+Kfw+5KeuDxGL7QyaqgYu3I1V
ANXo7bT7149PHZE2xjFs/2EGM0UhFJhXOvnZo2MyH5cCrbxeJxl08bzaZHwP
5XqtQvV874K7XKdKuT9Qp/vbFfhcFLdMM/BVtE018iKu4w0FzvP7kIU+yOKe
iTrwsiWmKWDi+c/RgVe7/cc2ij9J7h+pwKyGHKe7WIe//LNcIb/V68CPJaXK
fBt10nu++T8WaV/SqS5bpT8jdKpjuAr8mtdBOvlnrEr5e1zAZQv+ZPmPeVtU
m1zk0xAVoriefxgcRBnawlR6v4zR/UtUyu8Eo7ydKvRzvWq9ftDIb27pB7dk
PC/0OKuRnli/Ffzheo3iL2AUT51G9TVwAP8YWPgn388innzpT2Shi2FdxG9g
4cM8//4K3j/Ior6XNdInT/ofWeSHLOrr0chvuXI+eGR+uXKeYD4HuP45Mv9G
Db51bbSPQ+b/LmyW+/fL/dc14DLakIUfkIX/s6X+rRr5LdvrZ3l/huyHHo3m
Wrrst4VW0gf7hYf5e62V4nV4+9dK/kMWcSRa6dvh7Xc5Pw0s/Obwz0tvP3pZ
9LfdP19fpZRXZNn981f0l90/n8V8MjAfbwOG+e2dD14WfjTMcxG/YX34/P8H
0Cyccg==
                    "], CompressedData["
1:eJxNkm9IU2EUxseIiEiRkogyqYi4m4T4QSIjfEaIRtSoD9F7iRGjICNKCLrH
NCFsmURE+MFBiJRUSCVREWIy15SVBaajFEvR/tiaOgb9ZUTQeXcPbBcul4d7
3nN+53mfjf7TB445HQ5HGb/6m7f1UUeq3cI+f8Gh7UMmvsf2+guCFgp7qj+e
Y/2OElvKWLesnhz5M2iitziwsD+YrbdCnWtL8wi115ONlQ9M+Pp2r3A2ECqe
vDwbGjCR6Z8irCud3ry028Ss92r7KWc9dl05Gf9bK+fThPOV5b6+SQXu3luc
JNwvMo/uGFCI/DIOX1skNIdf3awKKTBVYc8CYSrddKK/X+pZezUP6zs3hjY8
nCc87kjdjT5TyNfzE9n/GuNCjm5bs+Rgfo7mLcp937LnM/zx7P/1jDXznODQ
T1j63yNojMCg6IDwv5B61l9HN31Ijyis0ouwntN6XPhZ/+Y1I9MKn2/zAo0E
dmllc42JBn0RFYSnP/69JY9p85dIfVJBt/eyztzXorLr3YTlE111O+fFD7f4
n1C2/27hi8s81pn7/CL8LsIY4zV9UqjRfruEZ1bmucT/KeFnHdP172W+QThz
nAMxodDqOTI3yjrIx8Mx4TFk/hsFHZNOQ/x7rRDds63Vw5pTVNISVXbeDOGJ
KNyqYid+WnZ+uhUu6/5RCxqzeljut82y9x1TmNH7XrRQzzFeViR5vmTZ87ok
nzn5/w8WOWkh
                    "]}]}}}}}}}}}}}}}}, AspectRatio -> Automatic,
                   ImageSize -> {{128}, {85}}, 
                  PlotRange -> {{0., 600.}, {0., 400.}}], ",", 
                 GraphicsBox[{{{{{{{
                    Thickness[0.002352941176470588], {{{{{{{
                    FaceForm[{
                    RGBColor[0.662745, 0., 0.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}}, {{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 
                    0}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}}, {{1, 4, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, {{{146.555, 24.364}, {
                    148.90200000000002`, 24.364}, {150.805, 
                    22.461999999999996`}, {150.805, 20.114000000000004`}, {
                    150.805, 15.868}, {150.805, 13.524}, {148.90200000000002`,
                     11.622}, {146.555, 11.622}, {142.309, 11.622}, {142.309, 
                    24.364}}, {{146.555, 7.372}, {151.24599999999998`, 
                    7.372}, {155.05100000000002`, 11.177}, {
                    155.05100000000002`, 15.868}, {155.05100000000002`, 
                    20.114000000000004`}, {155.05100000000002`, 24.805}, {
                    151.24599999999998`, 28.610000000000003`}, {146.555, 
                    28.610000000000003`}, {138.059, 28.610000000000003`}, {
                    138.059, 7.372}}, {{129.562, 28.610000000000003`}, {
                    133.812, 28.610000000000003`}, {133.812, 7.372}, {129.562,
                     7.372}}, {{121.066, 28.610000000000003`}, {125.316, 
                    28.610000000000003`}, {125.316, 7.372}, {121.066, 
                    7.372}, {112.57, 20.708}, {112.57, 7.372}, {108.324, 
                    7.372}, {108.324, 28.610000000000003`}, {112.57, 
                    28.610000000000003`}, {121.066, 15.277999999999999`}}, {{
                    57.348, 28.610000000000003`}, {70.09, 
                    28.610000000000003`}, {70.09, 24.364}, {61.594, 24.364}, {
                    61.594, 20.114000000000004`}, {70.09, 
                    20.114000000000004`}, {70.09, 15.868}, {61.594, 15.868}, {
                    61.594, 11.622}, {70.09, 11.622}, {70.09, 7.372}, {57.348,
                     7.372}}, {{40.355, 28.610000000000003`}, {
                    44.602000000000004`, 28.610000000000003`}, {
                    44.602000000000004`, 11.622}, {53.098000000000006`, 
                    11.622}, {53.098000000000006`, 7.372}, {40.355, 
                    7.372}}, {{84.96100000000001, 11.622}, {89.20700000000001,
                     11.622}, {92.727, 11.622}, {95.57799999999999, 14.473}, {
                    95.57799999999999, 17.993}, {95.57799999999999, 21.509}, {
                    92.67199999999998, 24.352}, {89.20700000000001, 24.364}, {
                    84.96100000000001, 24.364}, {84.96100000000001, 
                    20.114000000000004`}, {89.20700000000001, 
                    20.114000000000004`}, {90.37899999999999, 
                    20.114000000000004`}, {91.332, 19.165}, {91.332, 
                    17.993}, {91.332, 16.820999999999998`}, {
                    90.37899999999999, 15.868}, {89.20700000000001, 15.868}, {
                    84.96100000000001, 15.868}}, {{89.20700000000001, 
                    32.86}, {97.418, 32.86}, {104.074, 26.204}, {104.074, 
                    17.993}, {104.074, 9.782}, {97.418, 3.126}, {
                    89.20700000000001, 3.126}, {80.99600000000001, 3.126}, {
                    74.34, 9.782}, {74.34, 17.993}, {74.34, 26.204}, {
                    80.99600000000001, 32.86}, {89.20700000000001, 32.86}}, {{
                    89.20700000000001, 28.610000000000003`}, {95.07, 
                    28.610000000000003`}, {99.82799999999999, 23.856}, {
                    99.82799999999999, 17.993}, {99.82799999999999, 
                    12.129999999999999`}, {95.07, 7.372}, {89.20700000000001, 
                    7.372}, {83.34400000000001, 7.372}, {78.586, 
                    12.129999999999999`}, {78.586, 17.993}, {78.586, 
                    23.856}, {83.34400000000001, 28.610000000000003`}, {
                    89.20700000000001, 28.610000000000003`}}}]}}}}}}}, {{{{{{{
                    
                    FaceForm[{
                    RGBColor[0.15686300000000003`, 0.6823529999999999, 0.4], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     284.2}, {424.801, 284.2}, {424.801, 
                    1.0009999999999764`}, {0., 
                    1.0009999999999764`}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    50.977, 284.2}, {127.43800000000002`, 284.2}, {
                    127.43800000000002`, 1.0009999999999764`}, {
                    50.977000000000004`, 
                    1.0009999999999764`}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4js/67L2xGQ5HFHYUJQxM9/hotLtn3Xvsh3M
Ox0Tnr7Jc2AAAY5ch56c579XxubC+SGPl84+0pMN5y+Q0r+rIpfpANR1QYk/
2+HflYqXaqrpDr3T84SaF2TA+d80YvoPdabD+VtPlO2b35XmkJ4GBF1Q+aOp
EPOMMhyKMya+rbFPc7h57nvw47/pDgW2XNcXH4Gqv5fucBvk/oB0B3vTuF2e
N9IdZgCtO7Av00EaqJ1tb7oDWPvZbIc3gTvkWudnQtzzItthxTFv807eHIfj
QMrxR7aDQITllhNluQ4gbynEZDucB1q3dH+eA3r4AADYT4vw
                    "]], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{183.75, 249.708}, {179.758, 
                    252.60999999999999`}, {181.281, 257.302}, {177.289, 
                    254.399}, {173.297, 257.302}, {174.824, 
                    252.60999999999999`}, {170.83200000000002`, 249.708}, {
                    175.766, 249.708}, {177.289, 245.012}, {178.816, 
                    249.708}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{183.75, 231.583}, {179.758, 234.485}, {181.281, 
                    239.177}, {177.289, 236.278}, {173.297, 239.177}, {
                    174.824, 234.485}, {170.83200000000002`, 231.583}, {
                    175.766, 231.583}, {177.289, 226.89100000000002`}, {
                    178.816, 231.583}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{183.75, 213.45800000000003`}, {179.758, 
                    216.36}, {181.281, 221.05200000000002`}, {177.289, 
                    218.153}, {173.297, 221.05200000000002`}, {174.824, 
                    216.36}, {170.83200000000002`, 213.45800000000003`}, {
                    175.766, 213.45800000000003`}, {177.289, 208.766}, {
                    178.816, 213.45800000000003`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{165.844, 222.74699999999999`}, {
                    161.85200000000003`, 225.64499999999998`}, {163.379, 
                    230.341}, {159.383, 227.43800000000002`}, {
                    155.39100000000002`, 230.341}, {156.918, 
                    225.64499999999998`}, {152.92600000000002`, 
                    222.74699999999999`}, {157.859, 222.74699999999999`}, {
                    159.383, 218.05200000000002`}, {160.91, 
                    222.74699999999999`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{188.738, 240.41899999999998`}, {192.73, 
                    243.32100000000003`}, {191.20299999999997`, 248.012}, {
                    195.195, 245.11399999999998`}, {199.18800000000002`, 
                    248.012}, {197.664, 243.32100000000003`}, {201.656, 
                    240.41899999999998`}, {196.72299999999998`, 
                    240.41899999999998`}, {195.195, 235.727}, {193.672, 
                    240.41899999999998`}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIJIGYC4t7peULNH4IdpPXvqrDtzHXInPi2xn5voMPr
wB1yreF5Dhkg/tQAOB+krNHVz+H64gJbruMIfuVLNUOOhHyHha7bPv818Xaw
N43b5XkDwQeqvr64pgCuPuTx0tlHdiD4xiDAWgi3D6ibh8m2EO4eGB/m3qsV
QAt7Ch2cu3Oe/14ZAeeD1d+NgqsHm8caA+dbbjlRtq88Fm4fjA9zDwMYxMPd
C+PD/ANTD/MvjA8LD5h9sPCCuQfGh7kXFt4ATMyf3A==
                    
                    "]]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0.15686300000000003`, 0.6823529999999999, 0.4], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIJIGYCYk8eJu32ZREObwJ3yLXuz3WotTeN23UzyuHm
ue/Bj2PzIHzGGDh/ep5Q84GsWAfBCMstJ04h+CDppcn5DvG7gCZ+jnPYPPf9
8mO3EXy3bZ//XqkqgKvPef575cdtCD7HGpmoFOZCuH3fNGL6D1kWwt0D48Pc
mwvS31Ho0C4GdNnnYDg/5PHS2UcOBMLVg/kzAuD8ZxeUbv+M84PbB+PD3PMU
xPfzhrsXxof5B6Ye5l8YHxYeMPtg4QVzD4wPcy8svAEeRcV0
                    
                    "]]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIJIGYCYr8kgQhLkRCHBVL6d1V+5TpIAym2h4EOvdPz
hJpn5DnE7fLkYdodAOeD9DIE+DuosTVOdX6N4E9z7s553pzvAOIyOPg4xPYf
+qrxB8EvtOW6vjirAK4++PHS2UeWIfgBIAs+F8Dtm31EYUORTCHcPTA+zL3M
YXy6m7ILHZoPnFro2hYB52/7/PdKxc4ouPo1MlEp1vej4XygKwpsP8XA7YPx
Ye65pHT7Z11VHNy9MD7MPzD1MP/C+LDwgNkHCy+Ye2B8mHth4Q0AqVub2A==

                    "]]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    111.43400000000001`, 244.97}, {115.586, 247.47}, {115.586,
                     252.23499999999999`}, {121.71100000000001`, 255.993}, {
                    121.71100000000001`, 259.173}, {89.309, 259.173}, {89.309,
                     240.016}, {98.043, 240.016}, {106.84400000000001`, 
                    244.97}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    62.828, 271.079}, {62.828, 266.309}, {56.703, 262.552}, {
                    56.703, 259.376}, {89.10499999999999, 259.376}, {
                    89.10499999999999, 278.52799999999996`}, {80.371, 
                    278.52799999999996`}, {71.57, 273.579}, {66.98, 
                    273.579}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    62.828, 247.47}, {66.98, 244.97}, {71.57, 244.97}, {
                    80.371, 240.016}, {89.10499999999999, 240.016}, {
                    89.10499999999999, 259.173}, {56.703, 259.173}, {56.703, 
                    255.993}, {62.828, 252.23499999999999`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    115.586, 266.309}, {115.586, 271.079}, {
                    111.43400000000001`, 273.579}, {106.84400000000001`, 
                    273.579}, {98.043, 278.52799999999996`}, {89.309, 
                    278.52799999999996`}, {89.309, 259.376}, {
                    121.71100000000001`, 259.376}, {121.71100000000001`, 
                    262.552}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{103.895, 266.227}, {102.727, 267.462}, {106.273, 
                    270.805}, {106.273, 273.079}, {108.34400000000001`, 
                    271.794}, {109.85199999999999`, 273.2}, {111.348, 
                    272.27799999999996`}, {109.836, 270.872}, {111.777, 
                    269.66900000000004`}, {107.543, 
                    269.66900000000004`}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    109.87899999999999`, 272.95}, {108.523, 271.684}, {109.66,
                     270.98099999999994`}, {111.016, 272.247}}, {{106.477, 
                    272.71599999999995`}, {106.477, 270.71999999999997`}, {
                    103.016, 267.454}, {103.902, 266.512}, {
                    107.46100000000001`, 269.872}, {111.066, 
                    269.872}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{96.758, 266.845}, {95.59, 268.079}, {99.137, 
                    271.42299999999994`}, {99.137, 273.69599999999997`}, {
                    101.20700000000001`, 272.41499999999996`}, {102.715, 
                    273.817}, {104.20700000000001`, 272.899}, {102.699, 
                    271.489}, {104.637, 270.28599999999994`}, {100.402, 
                    270.28599999999994`}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    102.738, 273.567}, {101.383, 272.302}, {102.52, 
                    271.59799999999996`}, {103.87499999999999`, 
                    272.86400000000003`}}, {{99.34, 273.33299999999997`}, {
                    99.34, 271.337}, {95.87499999999999, 
                    268.07099999999997`}, {96.766, 267.13}, {100.324, 
                    270.489}, {103.93, 270.489}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{104.418, 262.188}, {103.25, 
                    263.42299999999994`}, {106.79700000000001`, 266.77}, {
                    106.79700000000001`, 269.04}, {108.867, 267.759}, {
                    110.37499999999999`, 269.165}, {111.871, 268.243}, {
                    110.359, 266.83299999999997`}, {112.301, 265.63}, {
                    108.066, 265.63}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    110.402, 268.91099999999994`}, {109.04700000000001`, 
                    267.64500000000004`}, {110.184, 266.942}, {111.539, 
                    268.20799999999997`}}, {{107., 268.677}, {107., 266.68}, {
                    103.539, 263.41499999999996`}, {104.426, 262.477}, {
                    107.98400000000001`, 265.83299999999997`}, {111.59, 
                    265.83299999999997`}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{103.895, 252.317}, {102.727, 
                    251.08700000000002`}, {106.273, 247.73899999999998`}, {
                    106.273, 245.47}, {108.34400000000001`, 246.751}, {
                    109.85199999999999`, 245.345}, {111.348, 246.266}, {
                    109.836, 247.677}, {111.777, 248.876}, {107.543, 
                    248.876}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    109.87899999999999`, 245.598}, {108.523, 246.86}, {109.66,
                     247.563}, {111.016, 246.298}}, {{106.477, 245.833}, {
                    106.477, 247.82500000000002`}, {103.016, 251.095}, {
                    103.902, 252.032}, {107.46100000000001`, 248.677}, {
                    111.066, 248.677}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{96.758, 251.7}, {95.59, 250.47}, {99.137, 
                    247.122}, {99.137, 244.85200000000003`}, {
                    101.20700000000001`, 246.134}, {102.715, 244.727}, {
                    104.20700000000001`, 245.64899999999997`}, {102.699, 
                    247.055}, {104.637, 248.259}, {100.402, 
                    248.259}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    102.738, 244.98100000000002`}, {101.383, 
                    246.24299999999997`}, {102.52, 246.946}, {
                    103.87499999999999`, 245.68}}, {{99.34, 245.212}, {99.34, 
                    247.208}, {95.87499999999999, 250.477}, {96.766, 
                    251.415}, {100.324, 248.055}, {103.93, 
                    248.055}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{104.418, 256.356}, {103.25, 255.122}, {
                    106.79700000000001`, 251.778}, {106.79700000000001`, 
                    249.505}, {108.867, 250.79}, {110.37499999999999`, 
                    249.38400000000001`}, {111.871, 250.305}, {110.359, 
                    251.712}, {112.301, 252.915}, {108.066, 
                    252.915}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    110.402, 249.637}, {109.04700000000001`, 250.899}, {
                    110.184, 251.602}, {111.539, 250.33700000000002`}}, {{
                    107., 249.86800000000002`}, {107., 251.864}, {103.539, 
                    255.13}, {104.426, 256.071}, {107.98400000000001`, 
                    252.712}, {111.59, 252.712}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{74.516, 252.317}, {75.684, 
                    251.08700000000002`}, {72.137, 247.73899999999998`}, {
                    72.137, 245.47}, {70.066, 246.751}, {68.559, 245.345}, {
                    67.066, 246.266}, {68.574, 247.677}, {66.637, 248.876}, {
                    70.871, 248.876}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    68.535, 245.598}, {69.891, 246.86}, {68.754, 247.563}, {
                    67.398, 246.298}}, {{71.93400000000001, 245.833}, {
                    71.93400000000001, 247.82500000000002`}, {75.398, 
                    251.095}, {74.508, 252.032}, {70.94900000000001, 
                    248.677}, {67.34400000000001, 248.677}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{81.65599999999999, 251.7}, {82.824, 250.47}, {
                    79.277, 247.122}, {79.277, 244.85200000000003`}, {
                    77.20700000000001, 246.134}, {75.699, 244.727}, {74.203, 
                    245.64899999999997`}, {75.715, 247.055}, {73.773, 
                    248.259}, {78.008, 248.259}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    75.67199999999998, 244.98100000000002`}, {77.027, 
                    246.24299999999997`}, {75.895, 246.946}, {74.535, 
                    245.68}}, {{79.074, 245.212}, {79.074, 247.208}, {82.539, 
                    250.477}, {81.648, 251.415}, {78.09, 248.055}, {
                    74.48400000000001, 248.055}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{73.992, 256.356}, {75.16, 255.122}, {71.613, 
                    251.778}, {71.613, 249.505}, {69.543, 250.79}, {68.035, 
                    249.38400000000001`}, {66.543, 250.305}, {68.051, 
                    251.712}, {66.113, 252.915}, {70.348, 
                    252.915}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    68.012, 249.637}, {69.367, 250.899}, {68.23, 251.602}, {
                    66.87499999999999, 250.33700000000002`}}, {{
                    71.41000000000001, 249.86800000000002`}, {
                    71.41000000000001, 251.864}, {74.87499999999999, 
                    255.13}, {73.98400000000001, 256.071}, {70.426, 
                    252.712}, {66.82, 252.712}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{74.516, 266.227}, {75.684, 267.462}, {72.137, 
                    270.805}, {72.137, 273.079}, {70.066, 271.794}, {68.559, 
                    273.2}, {67.066, 272.27799999999996`}, {68.574, 
                    270.872}, {66.637, 269.66900000000004`}, {70.867, 
                    269.66900000000004`}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    68.535, 272.95}, {69.891, 271.684}, {68.754, 
                    270.98099999999994`}, {67.398, 272.247}}, {{
                    71.93400000000001, 272.71599999999995`}, {
                    71.93400000000001, 270.71999999999997`}, {75.398, 
                    267.454}, {74.508, 266.512}, {70.94900000000001, 
                    269.872}, {67.34400000000001, 269.872}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{81.65599999999999, 266.845}, {82.824, 268.079}, {
                    79.277, 271.42299999999994`}, {79.277, 
                    273.69599999999997`}, {77.20700000000001, 
                    272.41499999999996`}, {75.699, 273.817}, {74.203, 
                    272.899}, {75.715, 271.489}, {73.773, 
                    270.28599999999994`}, {78.008, 
                    270.28599999999994`}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    75.67199999999998, 273.567}, {77.027, 272.302}, {75.895, 
                    271.59799999999996`}, {74.535, 272.86400000000003`}}, {{
                    79.074, 273.33299999999997`}, {79.074, 271.337}, {82.539, 
                    268.07099999999997`}, {81.648, 267.13}, {78.09, 
                    270.489}, {74.48400000000001, 270.489}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{73.992, 262.188}, {75.16, 263.42299999999994`}, {
                    71.613, 266.77}, {71.613, 269.04}, {69.543, 267.759}, {
                    68.035, 269.165}, {66.543, 268.243}, {68.051, 
                    266.83299999999997`}, {66.113, 265.63}, {70.348, 
                    265.63}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    68.012, 268.91099999999994`}, {69.367, 
                    267.64500000000004`}, {68.23, 266.942}, {
                    66.87499999999999, 268.20799999999997`}}, {{
                    71.41000000000001, 268.677}, {71.41000000000001, 
                    266.68}, {74.87499999999999, 263.41499999999996`}, {
                    73.98400000000001, 262.477}, {70.426, 
                    265.83299999999997`}, {66.82, 
                    265.83299999999997`}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{101.12899999999999`, 
                    273.673}, {101.801, 275.309}, {98.922, 276.805}, {95.023, 
                    276.805}, {93.027, 278.73099999999994`}, {85.387, 
                    278.73099999999994`}, {83.387, 276.805}, {79.492, 
                    276.805}, {76.613, 275.309}, {77.285, 273.673}, {
                    79.85199999999999, 275.02}, {80.977, 275.02}, {
                    84.91400000000002, 270.46999999999997`}, {
                    89.20700000000001, 273.08299999999997`}, {93.5, 
                    270.46999999999997`}, {97.438, 275.02}, {98.562, 
                    275.02}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{101.12899999999999`, 
                    244.872}, {101.801, 243.23499999999999`}, {98.922, 
                    241.74299999999997`}, {95.023, 241.74299999999997`}, {
                    93.027, 239.817}, {85.387, 239.817}, {83.387, 
                    241.74299999999997`}, {79.492, 241.74299999999997`}, {
                    76.613, 243.23499999999999`}, {77.285, 244.872}, {
                    79.85199999999999, 243.524}, {80.977, 243.524}, {
                    84.91400000000002, 248.07899999999998`}, {
                    89.20700000000001, 245.46200000000002`}, {93.5, 
                    248.07899999999998`}, {97.438, 243.524}, {98.562, 
                    243.524}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{68.824, 
                    262.78999999999996`}, {66.85199999999999, 
                    262.78999999999996`}, {66.41000000000001, 
                    263.32099999999997`}, {66.41000000000001, 
                    264.71999999999997`}, {67.52, 265.45799999999997`}, {
                    65.699, 266.137}, {65.65599999999999, 266.106}, {63.305, 
                    264.47299999999996`}, {63.305, 264.03599999999994`}, {
                    59.539, 259.274}, {63.305, 254.509}, {63.305, 254.071}, {
                    65.699, 252.411}, {67.52, 253.091}, {66.41000000000001, 
                    253.82500000000002`}, {66.41000000000001, 255.227}, {
                    66.85199999999999, 255.755}, {68.824, 
                    255.755}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0},
                     {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                    0, 1, 0}, {0, 1, 0}}}, {{{63.508, 254.177}, {63.508, 
                    254.57899999999998`}, {59.797000000000004`, 259.274}, {
                    63.508, 263.96599999999995`}, {63.508, 264.368}, {65.727, 
                    265.91099999999994`}, {67.07799999999999, 265.407}, {
                    66.20700000000001, 264.829}, {66.20700000000001, 
                    263.247}, {66.758, 262.59099999999995`}, {68.621, 
                    262.59099999999995`}, {68.621, 255.95800000000003`}, {
                    66.758, 255.95800000000003`}, {66.20700000000001, 
                    255.298}, {66.20700000000001, 253.71599999999998`}, {
                    67.07799999999999, 253.141}, {65.727, 
                    252.634}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{109.586, 
                    262.78999999999996`}, {111.562, 262.78999999999996`}, {
                    112.004, 263.32099999999997`}, {112.004, 
                    264.71999999999997`}, {110.891, 265.45799999999997`}, {
                    112.71100000000001`, 266.137}, {112.758, 266.106}, {
                    115.109, 264.47299999999996`}, {115.109, 
                    264.03599999999994`}, {118.87499999999999`, 259.274}, {
                    115.109, 254.509}, {115.109, 254.071}, {
                    112.71100000000001`, 252.411}, {110.891, 253.091}, {
                    112.004, 253.82500000000002`}, {112.004, 255.227}, {
                    111.562, 255.755}, {109.586, 255.755}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{114.906, 254.177}, {
                    114.906, 254.57899999999998`}, {118.617, 259.274}, {
                    114.906, 263.96599999999995`}, {114.906, 264.368}, {
                    112.684, 265.91099999999994`}, {111.332, 265.407}, {
                    112.203, 264.829}, {112.203, 263.247}, {
                    111.65599999999999`, 262.59099999999995`}, {109.789, 
                    262.59099999999995`}, {109.789, 255.95800000000003`}, {
                    111.65599999999999`, 255.95800000000003`}, {112.203, 
                    255.298}, {112.203, 253.71599999999998`}, {111.332, 
                    253.141}, {112.684, 252.634}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{89.10499999999999, 278.52799999999996`}, {
                    89.10499999999999, 273.259}, {84.953, 
                    270.73099999999994`}, {81.066, 275.22299999999996`}, {
                    79.801, 275.22299999999996`}, {77.387, 273.954}, {76.867, 
                    275.21599999999995`}, {79.539, 276.60200000000003`}, {
                    83.46900000000001, 276.60200000000003`}, {
                    85.46900000000001, 278.52799999999996`}}, {{89.309, 
                    277.954}, {89.309, 273.259}, {93.46100000000001, 
                    270.73099999999994`}, {97.34400000000001, 
                    275.22299999999996`}, {98.613, 275.22299999999996`}, {
                    101.027, 273.954}, {101.543, 275.21599999999995`}, {
                    98.871, 276.60200000000003`}, {94.94500000000001, 
                    276.60200000000003`}, {92.94500000000001, 
                    278.52799999999996`}, {89.309, 278.52799999999996`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{89.10499999999999, 240.016}, {89.10499999999999, 
                    245.29}, {84.953, 247.817}, {81.066, 
                    243.32100000000003`}, {79.801, 243.32100000000003`}, {
                    77.387, 244.591}, {76.867, 243.329}, {79.539, 241.946}, {
                    83.46900000000001, 241.946}, {85.46900000000001, 
                    240.016}}, {{89.309, 240.591}, {89.309, 245.29}, {
                    93.46100000000001, 247.817}, {97.34400000000001, 
                    243.32100000000003`}, {98.613, 243.32100000000003`}, {
                    101.027, 244.591}, {101.543, 243.329}, {98.871, 
                    241.946}, {94.94500000000001, 241.946}, {
                    92.94500000000001, 240.016}, {89.309, 
                    240.016}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxlk21IFFEUhtcRFqqlD41+lERF9kFICFJIRDfWJTSy2dWZFZs+WEzsw9mZ
kvBHKCK2RVSEhMUWtITkSj9CQiRCJMW+IEqsCOmXiIVELUKhUnbvHd5z0Rbm
xzN75573vOc9G2PxyMlsn8+XxZ8IfzT+lAW0HYnrYfZrm3Xjeb7DKsc7k0Nd
OnF5bGVVcYnOPjR+21IYcNjwwd1X9l/WWXdm5FCM8/tNYzNNOTqrEN99jbO0
OJA6zJpPP2to1xzi2Sb+YonDVhT03PuRKPe+L1L/r/n89nfFccX31+78srlW
3d+3vm0q3LCovqX0Xeuwc1otpf/Y09KAFnQY+gPn+1tuBYMR775axTNC36DD
Jt7xgv5K4oQQlmuyN6lQ73SuS6yLgttdNhXmNw0aLDm04fG5XS5b+umBs7db
8W0uayBisMm5dGZkq8vqbn6/uC9ksHrxIs9l63ib/izD66vI9XxvMzy/ddfT
nVQszxeaLNtcXtBzxmW9039GG08pPi8KzJt0fkw0sjpKLM/fiVI9qceIkp7i
Jy8v9B+Ikt4X4txPk/oRtvV9VFwq/L2k/ADDL+lvexX5+SivumZPtPo/xjx4
Oh4OLztC85J6M4pbB16nQqZF8y65enZybpVFeZgXv4RFeZHfv7IoT2DkTeo1
j1Ie8T/yCkaecT/yvqB+QOnDvkA/9gn9gdH/XeGnpljmtixO/oHhb5cYYNom
lueabZqP9KfGpvmBMV9Zv8Wm+XM3xjs7bMoH/+rERJ1N+fk7KhqyKV9g5E/6
O1tP+QQjvziPfIPlvvoMqof9gB7sD/Riv9AP9g+M/YQfYPiF/V7gL9//xYx5
/AN4GlC2
                    "]]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}}, {{0, 2,
                     0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 
                    1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}}}, {{{89.309, 242.985}, {90.20700000000001, 
                    242.298}, {89.309, 241.61399999999998`}}, CompressedData["

1:eJxTTMoPSmViYGBQBmIQvch12+e/c0Idzn0PfrzUPM9hjUxUivV8BD9j4tsa
e9Mwh97peULNDHkOcq2vA3e4YfLfBO6Qa9XOc/gPAt9DHVYc8zbv9ETIg81L
R/DtTeN2ee6Ami8aAjEvJd9hb8lkCZayIAy+G9CZVzgKHKy2nCjbNz/QIeTx
0tlHjAocRNe5P6yKCYDzVdgapzpzBzh81YjpPyRd4NAudvPc92J/uDyYv9kP
zge7e7e/Q33WnpLJXAg+yFgRlgIHl+6c578FAyD++Zjv8A1kbmqAQwDIgZwF
DiIghSYBDkBVKz9yIPhA3/Ew8UL1LwxwyAXJaxQ4xIPEJwfC+ceBxjoGBDns
AfmTBcGX1r+rwhaY7wAKhgNcIXA+2N0KYQ7/rlS8VFubB+dPcwZaVJ3nUAwK
0OOhDgukgBri8hyaD5xa6LoMwbcEhZ97qEMPyMG1eZBwdgh1OKKwoSijM8/h
otLtn3VCoRD3ZEH5XYj0AADYPwDm
                    "], {{64.17599999999999, 
                    260.505}, {65.17599999999999, 259.376}, {63.176, 
                    259.376}}, {{89.10499999999999, 276.93399999999997`}, {
                    88.20700000000001, 276.247}, {89.10499999999999, 
                    275.559}}, {{113.238, 259.173}, {114.238, 
                    258.04400000000004`}, {115.238, 259.173}}, CompressedData["
1:eJxTTMoPSmViYGBQAmIQrcrWONX5d5hD7vPfKz/6FDpkTHxbY58a5jD7iMKG
ooxCh01z3y8/FozJj9vlycMUXOhwUen2z7pFYQ6nF7pu++yMkK8WWef+0ATB
r8vaUzKZB2p+awTEvG0FDn5JAhGWKlEY/Bvnvgc/ji9wmJEn1HzgVxTEfNMC
h70lkyVY7GLg/DUyUSnW/TFQ9xc49E4HangQ47AHpM4MyneIhfPv/AS6ZE+M
wwIp/bsqcQh+gS3X9cUpUPUdUP0FBQ63QfImMQ7MYXy6m+Kh9qfFOHzViOk/
hMQHy0cXOBzzNu90/BENkbcvcCgGeZgdwQfaUmDrFeUQ/Hjp7CMpCD5Y34EC
B6stJ8r29UfA+ds+/71SURkGca9QIZzvBmJoFTrEg+LhcpgDC8h+y0JI+H1B
8MHhFxTucBMUnpqFDi7dOc9/R4ZD/KdS6PAfBNrDIe4zLnRgAAGBcHh6AAB7
afdG
                    "]}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1,
                     0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 
                    0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 
                    0}, {0, 1, 0}}}, {{{89.10499999999999, 
                    241.61399999999998`}, {88.20700000000001, 242.298}, {
                    89.10499999999999, 242.985}}, {{65.17599999999999, 
                    259.173}, {64.17599999999999, 258.04400000000004`}, {
                    63.176, 259.173}}, CompressedData["
1:eJxTTMoPSmViYGBQBmIQnTnxbY393zCHc9+DHy81z3NQZWuc6vwbwc8AyaeG
OfROzxNqZshz2DT3/fJjwZj8N4E75Fq18xwuKt3+WbcozGHFMW/zTk+EPNi8
dATf3jRul+cOqPmtERDzUvId/JIEIixVojD4bts+/73CUeAwAyh84FeUQ8jj
pbOPGBU47C2ZLMFiFwPnr5GJSrHuj3H4qhHTf0i6AGLOA4Q8mO8QC+ff+VmX
tWdPjEN91p6SyVwI/jr3h1UiLFD1HTEQ/3zMd7gNkjeJcQgASXBC7U+Lcch5
/nvlRw4EH+g7HibeAgeQNscf0Q65IHmNAodikIfZEXyu64sLbL2iHPaA9LEg
+NL6d1XYAvMdrLacKNvXHwHng4KhojLM4d+Vipdqa/Pg/GnO3TnPq/Mc4kH2
Xg5zWCAF1BCXBwm/Lwg+OPyCwh16QA6uzXNwAWr7HRnucERhQ1FGZ57DfxBo
D4e4JyvPgQEEBMLh6QEAP70BUg==
                    "], {{114.238, 260.505}, {
                    113.238, 259.376}, {115.238, 259.376}}, CompressedData["
1:eJxTTMoPSmViYGBQAmIQvUYmKsV6fqhD7vPfKz/6FDpkTHxbY28a5jD7iMKG
ooxCB7nW14E73DD5cbs8eZiCCx3+g8D3UIfTC123fXZGyFeLrHN/aILg12Xt
KZnMAzVfNARi3rYCh70lkyVYyoIw+DfOfQ9+HF/gYLXlRNm++YEQ800LHESB
xlbFBMD5KmyNU525A6DuL3BoF7t57nuxv8MekDlmUP5mPzj/TeAOudbd/g4L
pPTvqsQh+AW2XNcXpxQ4uHTnPP8tGABRX1Dg8E0jpv9QaoADcxif7iage0De
qjIJcPgKEkfig+WjCxyAphTYLoLK2xc4xIPCaXIgnH/c27zTMSDIIfjx0tlH
UhD8YyD6QIHD9Dyh5gNcIXB+CEidQhjEvUKFcL7bts9/r2gVOhSDAvR4qAML
yH7LQofmA6cWui5D8C1B4ece6nATFJ6ahQ69IAscQiH+Uyl0uKh0+2edUCjE
fcZQfhciPQAALpL1Zg==
                    "], {{89.309, 275.559}, {
                    90.20700000000001, 276.247}, {89.309, 
                    276.93399999999997`}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0.15686300000000003`, 0.6823529999999999, 0.4], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}}}, {{{89.10499999999999, 272.552}, {80.387, 
                    267.2}, {74.04700000000001, 267.2}, {74.04700000000001, 
                    261.895}, {70.824, 259.376}, {89.10499999999999, 
                    259.376}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}}}, {{{89.309, 245.997}, {98.023, 251.345}, {
                    104.367, 251.345}, {104.367, 256.653}, {107.59, 
                    259.173}, {89.309, 259.173}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}}}, {{{107.59, 259.376}, {104.367, 
                    261.895}, {104.367, 267.2}, {98.023, 267.2}, {89.309, 
                    272.552}, {89.309, 259.376}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}}}, {{{70.824, 259.173}, {74.04700000000001, 
                    256.653}, {74.04700000000001, 251.345}, {80.387, 
                    251.345}, {89.10499999999999, 245.997}, {
                    89.10499999999999, 259.173}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{84.273, 260.19599999999997`}, {85.44100000000002,
                     261.42699999999996`}, {81.895, 264.774}, {81.895, 
                    267.04400000000004`}, {79.824, 265.762}, {78.316, 
                    267.16900000000004`}, {76.82, 266.247}, {78.332, 
                    264.837}, {76.391, 263.637}, {80.62499999999999, 
                    263.637}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    78.289, 266.91499999999996`}, {79.645, 265.653}, {78.512, 
                    264.94599999999997`}, {77.15199999999999, 266.212}}, {{
                    81.691, 266.68}, {81.691, 264.688}, {85.15599999999999, 
                    261.419}, {84.266, 260.48099999999994`}, {
                    80.70700000000001, 263.837}, {77.10199999999999, 
                    263.837}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{94.137, 258.35200000000003`}, {92.973, 
                    257.118}, {96.52, 253.77399999999997`}, {96.52, 
                    251.501}, {98.59, 252.786}, {100.098, 
                    251.38000000000002`}, {101.59, 252.30200000000002`}, {
                    100.07799999999999`, 253.708}, {102.02, 254.911}, {97.785,
                     254.911}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    100.121, 251.63}, {98.766, 252.895}, {99.902, 253.598}, {
                    101.258, 252.333}}, {{96.723, 251.864}, {96.723, 
                    253.86}, {93.258, 257.126}, {94.148, 258.067}, {
                    97.70700000000001, 254.708}, {101.309, 
                    254.708}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{84.273, 258.35200000000003`}, {85.44100000000002,
                     257.118}, {81.895, 253.77399999999997`}, {81.895, 
                    251.501}, {79.824, 252.786}, {78.316, 
                    251.38000000000002`}, {76.82, 252.30200000000002`}, {
                    78.332, 253.708}, {76.391, 254.911}, {80.62499999999999, 
                    254.911}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0.15686300000000003`, 0.6823529999999999, 0.4], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    78.289, 251.63}, {79.645, 252.895}, {78.512, 253.598}, {
                    77.15199999999999, 252.333}}, {{81.691, 251.864}, {81.691,
                     253.86}, {85.15599999999999, 257.126}, {84.266, 
                    258.067}, {80.70700000000001, 254.708}, {
                    77.10199999999999, 254.708}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{94.137, 260.19599999999997`}, {92.973, 
                    261.42699999999996`}, {96.52, 264.774}, {96.52, 
                    267.04400000000004`}, {98.59, 265.762}, {100.098, 
                    267.16900000000004`}, {101.59, 266.247}, {
                    100.07799999999999`, 264.837}, {102.02, 263.637}, {97.785,
                     263.637}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0.15686300000000003`, 0.6823529999999999, 0.4], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    100.121, 266.91499999999996`}, {98.766, 265.653}, {99.902,
                     264.94599999999997`}, {101.258, 266.212}}, {{96.723, 
                    266.68}, {96.723, 264.688}, {93.258, 261.419}, {94.148, 
                    260.48099999999994`}, {97.70700000000001, 263.837}, {
                    101.309, 263.837}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    98.57799999999999, 259.274}, {89.20700000000001, 
                    253.024}, {79.832, 259.274}, {89.20700000000001, 
                    265.52}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1,
                     0}}, {{0, 2, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}}}, {{{
                    89.10499999999999, 265.212}, {80.348, 259.376}, {
                    89.10499999999999, 259.376}}, {{89.309, 259.376}, {98.062,
                     259.376}, {89.309, 265.212}}, {{80.348, 259.173}, {
                    89.10499999999999, 253.33700000000002`}, {
                    89.10499999999999, 259.173}}, {{89.309, 
                    253.33700000000002`}, {98.066, 259.173}, {89.309, 
                    259.173}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{91.715, 263.137}, {91.715, 
                    261.42299999999994`}, {94.95700000000001, 
                    261.42299999999994`}, {94.95700000000001, 257.126}, {
                    91.715, 257.126}, {91.715, 255.407}, {86.699, 255.407}, {
                    86.699, 257.126}, {83.45700000000001, 257.126}, {
                    83.45700000000001, 261.42299999999994`}, {86.699, 
                    261.42299999999994`}, {86.699, 263.137}}}]}}}}}}}, {{{{{{{
                    
                    Thickness[0.00006663529411764707], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{91.715, 
                    263.13698200000005`}, {91.715, 261.42298200000005`}, {
                    94.95700000000001, 261.42298200000005`}, {
                    94.95700000000001, 257.125982}, {91.715, 257.125982}, {
                    91.715, 255.40698200000003`}, {86.699, 
                    255.40698200000003`}, {86.699, 257.125982}, {
                    83.45700000000001, 257.125982}, {83.45700000000001, 
                    261.42298200000005`}, {86.699, 261.42298200000005`}, {
                    86.699, 263.13698200000005`}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgAWI2IGYC4lp707hdO0MdYnd58jDlFzjA+K8Dd8i1Bhc4
cF1fXGD7KgSDv6dksgSLWYGDXCtQxi0Mgw8zb9Pc98uPBSPkj3ubdzpuCMfg
w8wPebx09pEHYRh8dPNgfJh7wOqMEHxjEBBF+AedDzb/cz7cveh8mHkw+2Dy
KO5D4sPMh/kHnY9uHowPAG5CqjE=
                    "]]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIZIGYC4pDHS2cfMQhxuL64wJarOd0Bha+d7lBjbxq3
KzMCOx+o/vbPuqw9PlEYfKeEpxeUbqc7WG05UbZPPwY73zjD4aISUIdQHAb/
y98rFS/9suHq0fmfQfxl2XD70Plg9/zPRnUvOj88B9W/6Hyg+m8aMf2HfIMw
+DD7pucJNR/ICsDgw9xbnDHxbQ2/LwYf5l+Yeqx8YHjB7EPnw8IbAN9z2dI=

                    "]]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIZIGYC4js/67L2xEQ4rDjmbd7Zme6AwjdMd/imEdN/
yDYEOx+ofkaeUPOBqCAMfk/O898rH6Y7WG45UbavPAA73zLDYdvnv1cqNH0x
+Ks+XvJN8siGq0fn904HWrQgG24fVv6PbLh70fmFtlzXFwfkwP2LzoeptwLZ
Zx+FnQ+zTykGgw9zL9g+1jgMPsy/MPVY+cDwgtmHzoeFNwBep9jy
                    
                    "]]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIZIGYC4m8aMf2H9oY4rDjmbd55Mt0Bxj+isKEoozDd
4c7Puqw9d8Ix+DD1VltOlO3bH4mdr5jhMCNPqPnAomgMfk/O898rKzMg9rXG
YvB7pwMVcmTD1WPlJ2TD7UPnF9hyXV+8IxvuXnR+IYgvkAP3Lzofph5s360g
DD7MPkuQfd8DsPOB7t32+e+VCk0/DD7MvzD16HyU8ALah5UPDG8AAlTaAA==

                    "]]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIZIGZigIIL4Q7TnLtznp9Pd4Dxp4L45ekOF5Vu/6w7
FYLBh6kvzpj4tuZ5EAa/8qWaIYdGhoPIOveHVSyB2PkNGQ6/6rL2lDj7YfD3
lEyWYGHKhqvHyo/KhtuHzl8gpX9XZVM23L1Y+Vw5cP9i5QPVx+/y5GHaHInB
h9n3TSOm/9DUaOx8oHtDHi+dfaQiFoMP8y9MPVY+MLxg9qHzYeENAGuWuLI=

                    "]]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[CompressedData["
1:eJxTTMoPSmJmYGBgBOJMIAaxGZjA/FFEOgIA9vgCgQ==
                    
                    "], CompressedData["
1:eJxtVFtIVFEUnSxEwyyloKSsRETpo/oQLYo5aUNYmY+xZpyHyJDNnblS9iA0
xBAZTFIiogdIYEoUEiYWEaE5lFj0ITkMSKkfIhYRIREmZq9ztrP2VfDC+Vh3
n/04a6+9t3vOFFesNJlMK+TxyxMlz67x1Oj6/BKR3XSgfKpKF77r32rNEnd+
D+V7unUxnDI6VxeyioeDR7KaanTxT302K9v3PH178aXE8A+p+x+LhTmz7EVe
m4EHtnWf0yy6uHM6sSHoKRaxjzY7Tm6NxJfYde3VTLpdF3tVvOkiUbV/9UhH
qi7G5ur8vbVFbN/QdWjiksTwp/yzhQv15RmY8s34xXp1v7lQHI6L2tE45BfV
X9J2x0jclrRzPDVKF6MqflyhqFH/w/6FepIK2H7wauXn+U0F7P/sx59wdcYx
0XvhxsZVvww80iErnveJ85okcG3+8rjRt/T+Ikz5r2ic72vR8+TAE43ruZUr
DZc1rpfq69L4PbDjvfAHHyWT91sHmg3ccls2IltjPhPs0uLRmO8PQ7PWyQyN
+0H8ujXuF+zoJ/zR77Oqf/sMTPcnvKyXv2FZeYLGevqZLjs87GW9UX0xGusR
dugV/vS/r0SsU/k/eRlTvoBXKPrNFcfFKfWFDEzxq72R+CdETvnU+5TXEXum
je3A8Cd+xmwcHxj52y2yo0ftXN9CfDvXT+99Y+f30XtzStlOfEoMf+K/v5T5
Awa/xGeWg/mn+BKjPypNsNPB/aM8W5xs71M6TnayP+Vvd7I+gKEfuh/vYn3R
XEgM/VH8Fhfrk96/xs126p/E8Kf7ATfrHxjzQfwkli2P5Xwtub8IYz6RD/OL
ejDfqBfz3xB8d88S72I73gt/8IH9Aoz9Az6xn8A39hf6gf2GfsGOfsIf/cb+
BMZ+hV6wf6En7GfoDfsbeoQdeoU/9Ez5Ww3sVvX91nkeeu5OPxh8bGCKH1vJ
80T96Nd53mAHhj/mFfGB06Lrb+bK/P8BIPUg9A==
                    
                    "]]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0.15686300000000003`, 0.6823529999999999, 0.4], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4m2f/16p0PR1WHHM27yzN9MBxi+w5bq++Eum
w6+6rD0lzn4Y/CMKG4oy3mZB+Mb+DjfPfQ9+fDDLoV0MyALyl4PM+5rlcPsn
UAFPgEPlSzVDjjNZDr3T84SaBQIg+s9mOayRiUqxrg+Aqy/OmPi2BsiHmWe5
5UTZvu8BcPtg/ODHS2cfmZIBVx/Tf+irxoEMuHl9IHt6MuD27y2ZLMGyLQPu
Ppg8zP0w/TD/wcyH8WHhAwDBUpeK
                    "]]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    70.145, 195.454}, {68.07, 194.134}, {68.07, 217.93}, {
                    70.145, 216.61399999999998`}, {70.148, 218.305}, {
                    71.74600000000001, 216.872}, {73.34, 218.305}, {
                    73.34400000000001, 216.61399999999998`}, {75.418, 
                    217.93}, {75.418, 194.134}, {73.34400000000001, 
                    195.454}, {73.34, 193.762}, {71.74600000000001, 
                    195.192}, {70.148, 193.762}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0.15686300000000003`, 0.6823529999999999, 0.4], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    77.57, 192.942}, {75.617, 191.466}, {75.617, 220.598}, {
                    77.57, 219.122}, {77.574, 221.059}, {79.289, 
                    219.52800000000002`}, {81.004, 221.059}, {81.008, 
                    219.122}, {82.96100000000001, 220.598}, {
                    82.96100000000001, 191.466}, {81.008, 192.942}, {81.004, 
                    191.005}, {79.289, 192.54}, {77.574, 
                    191.005}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    89.20700000000001, 221.727}, {85.785, 
                    223.92700000000002`}, {85.785, 221.032}, {83.164, 
                    223.423}, {83.164, 188.64499999999998`}, {85.785, 
                    191.032}, {85.785, 188.137}, {89.20700000000001, 
                    190.33700000000002`}, {92.62899999999999, 188.137}, {
                    92.62899999999999, 191.032}, {95.25, 
                    188.64499999999998`}, {95.25, 223.423}, {
                    92.62899999999999, 221.032}, {92.62899999999999, 
                    223.92700000000002`}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0.15686300000000003`, 0.6823529999999999, 0.4], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4m8aMf2HWOMcVhzzNu/szXSA8Qtsua4v/pLp
EPJ46ewjFbEY/CMKG4oy3mZB+AyxDjfPfQ9+fDDLoXd6nlAzkL8cZN7XLIh5
vTEOlS/VDDnOZDk4d+c8/90ZA9F/NstBla1xqrN0DFx93C5PHiYgH2beDKBx
BxZFw+2D8YNB9k7JgKsH2vJV40AG3Lw+kDt6MuD27y2ZLMGyLQPuPpg8zP0w
/TD/wcyH8WHhAwAmq49E
                    "]]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    108.27, 195.454}, {110.34400000000001`, 194.134}, {
                    110.34400000000001`, 217.93}, {108.27, 
                    216.61399999999998`}, {108.266, 218.305}, {
                    106.66799999999999`, 216.872}, {105.074, 218.305}, {
                    105.07, 216.61399999999998`}, {102.99600000000001`, 
                    217.93}, {102.99600000000001`, 194.134}, {105.07, 
                    195.454}, {105.074, 193.762}, {106.66799999999999`, 
                    195.192}, {108.266, 193.762}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0.15686300000000003`, 0.6823529999999999, 0.4], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    100.84400000000001`, 192.942}, {102.79700000000001`, 
                    191.466}, {102.79700000000001`, 220.598}, {
                    100.84400000000001`, 219.122}, {100.84, 221.059}, {
                    99.12499999999999, 219.52800000000002`}, {
                    97.41000000000001, 221.059}, {97.406, 219.122}, {95.453, 
                    220.598}, {95.453, 191.466}, {97.406, 192.942}, {
                    97.41000000000001, 191.005}, {99.12499999999999, 
                    192.54}, {100.84, 191.005}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{91.504, 216.466}, {90.691, 
                    215.76999999999998`}, {90.691, 217.82100000000003`}, {
                    92.523, 219.17299999999997`}, {89.20700000000001, 
                    221.618}, {85.891, 219.17299999999997`}, {87.723, 
                    217.82100000000003`}, {87.723, 215.76999999999998`}, {
                    86.91000000000001, 216.466}, {86.91000000000001, 
                    217.595}, {84.96900000000001, 216.001}, {87.051, 
                    214.07899999999998`}, {86.238, 212.95800000000003`}, {
                    92.17199999999998, 212.95800000000003`}, {91.363, 
                    214.07899999999998`}, {93.44500000000001, 216.001}, {
                    91.504, 217.595}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{86.70700000000001, 
                    217.16899999999998`}, {86.70700000000001, 216.372}, {
                    87.926, 215.333}, {87.926, 217.923}, {86.23, 
                    219.17299999999997`}, {89.20700000000001, 
                    221.36800000000002`}, {92.184, 219.17299999999997`}, {
                    90.488, 217.923}, {90.488, 215.333}, {91.703, 216.372}, {
                    91.703, 217.16899999999998`}, {93.137, 215.993}, {
                    91.09400000000001, 214.106}, {91.777, 213.161}, {86.637, 
                    213.161}, {87.32, 214.106}, {85.277, 
                    215.993}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{89.20700000000001, 218.055}, {90.723, 
                    219.17299999999997`}, {89.20700000000001, 220.29}, {
                    89.148, 220.24699999999999`}, {87.691, 
                    219.17299999999997`}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0.15686300000000003`, 0.6823529999999999, 0.4], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{89.20700000000001, 220.04}, {89.309, 219.966}, {
                    90.203, 219.305}, {90.383, 219.17299999999997`}, {90.203, 
                    219.04399999999998`}, {89.309, 218.38000000000002`}, {
                    89.20700000000001, 218.305}, {89.10499999999999, 
                    218.38000000000002`}, {88.20700000000001, 
                    219.04399999999998`}, {88.031, 219.17299999999997`}, {
                    88.20700000000001, 219.305}, {89.10499999999999, 
                    219.966}, {89.20700000000001, 220.04}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIRIGYC4m8aMf2HlkY6rDjmbd5ZmOlQnDHxbY1+DAZ/
mnN3zvPZmQ5+SQIRliyxGPwFUvp3VZ4h1KPze6fnCTULZDnA7IPxt33+e6Xi
YbjDvysVL9WWZjlIA7Wx7QyB82//rMva8yUIrh5EHcgKwODD7GNrnOrcreOP
wYe5F6YenQ/zL8w+GB/mHjB9NwPuXhgfAAZzj3w=
                    
                    "]]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIRIGYCYsstJ8r2lQc4VL5UM+SoyHSA8dNAYFGmgycP
k3a7mz8G//z34MdL7yPUo/P3lEyWYOHKcuidnifU/CMIzr/zsy5rz54QB71N
c98vn5flYHBXha3xbjic79Kd8/z3wki4+hlA7QeUYjD4MPvWyESlWH/H5MPc
C1OPzof5F2YfjA9zDwfIoMcZcPfC+DD/wNQDADpbjso=
                    
                    "]]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}}}, {{{109.004, 204.68}, {109.004, 
                    207.38700000000003`}, {101.766, 207.38700000000003`}, {
                    101.766, 208.02800000000002`}, {95.309, 212.266}, {
                    83.10499999999999, 212.266}, {76.648, 
                    208.02800000000002`}, {76.648, 207.38700000000003`}, {
                    69.41000000000001, 207.38700000000003`}, {
                    69.41000000000001, 204.68}, {76.648, 204.68}, {76.648, 
                    204.036}, {83.10499999999999, 199.798}, {95.309, 
                    199.798}, {101.766, 204.036}, {101.766, 
                    204.68}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}}}, {{{69.613, 207.184}, {76.848, 207.184}, {
                    76.848, 207.91899999999998`}, {83.164, 212.067}, {95.25, 
                    212.067}, {101.562, 207.91899999999998`}, {101.562, 
                    207.184}, {108.801, 207.184}, {108.801, 
                    204.88000000000002`}, {101.562, 204.88000000000002`}, {
                    101.562, 204.14499999999998`}, {95.25, 200.001}, {83.164, 
                    200.001}, {76.848, 204.14499999999998`}, {76.848, 
                    204.88000000000002`}, {69.613, 
                    204.88000000000002`}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {CompressedData["
1:eJxTTMoPSmViYGDQAWIQfftnXdaeKWEO0vp3VdhysxwyJ76tsfcNc1ggBRQI
ynL4phHTf4gVIW+15UTZvvpQOJ/r+uICWy6ovGWWgwGQauQNhei/lelgCVLf
HuKw+uMl3ySeLIeQx0tnH9kQ4jDNuTvnuXQWRN/DEIg9nFkO7WI3z31XDnX4
8vdKxUslhPq9JZMlWPyyHGrtTeN2MSLMu6gE9MGpEIg5BzPh8kDTf68szYTr
r3ypZshhkgk3X5WtcapzfCbc/lUg8yoQ6psPnFromoZwP8w8mP+mgty/PBPV
/56ZqOEjmokafkA+LHzB/tfPdEAJf6D8jDyh5gNS4XD+cW/zTscJCPMXuW77
/LcnHG4/WL1QBNx9NSD/vwyHux+o+krFznC4/zx5mLTby8Lh/oeph4UP2P8z
EOYxgMCFcHj4wuRh4Q/TD4sfmPmw+IPZD4tfmHpY/MPcDzMP5j9Y+kHxv2UW
avgA0x8AwN0vbA==
                    "], {{89.20700000000001, 208.997}, {
                    93.15599999999999, 206.032}, {89.20700000000001, 
                    203.067}, {85.258, 206.032}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {CompressedData["
1:eJxTTMoPSmViYGDQAWIQvWnu++XHPoc56IIYaVkOl5Ru/6yrCnOQ1r+rwmaZ
5bDIddvnvz3hDntKJkuwXMp0OOZt3umoEeGw+uMl3ySeLIcae9O4XS/DHaY5
d+c8V85yAKq+UrEz3OHmue/BjwWzHCpeqhlyAPV/AQq/VEKo3wsyzy3LIX6X
Jw9TM8I87uuLC2x3hUPsP5gJlwea/ntlaSZcf2z/oa8aNplw81XZGqc6x2fC
7Qcp8yxAqF8gBTQwDuF+mHkw/1WCzNmQiep/z0wHWPi8Cdwh1yqd6fCwSmSd
+0wEP3Pi2xp73zCIfguoPCNCHuh67fZloXC+1ZYTZfvkEeYbAKlG3lC4/S4g
hxWGwN0X8njp7CMbQuDuB+t7GAL3X/OBUwtd+ULh/oeph4VPcQbQgeII8xhA
4EEIPHxh8rDwh+mHxQ/MfFj8weyHxS9MPSz+Ye6HmQfzHyz9oPgfmL5g4QNL
f7Dwg/Fh4Qv2v1cWPPxh8gBYbjeA
                    "], {{89.145, 209.208}, {
                    84.918, 206.032}, {89.20700000000001, 202.813}, {
                    93.49600000000001, 206.032}, {89.20700000000001, 
                    209.251}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    77.95700000000001, 206.032}, {79.79700000000001, 
                    204.813}, {81.633, 206.032}, {79.79700000000001, 
                    207.255}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0.15686300000000003`, 0.6823529999999999, 0.4], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    79.79700000000001, 207.009}, {81.266, 206.032}, {
                    79.79700000000001, 205.055}, {78.324, 
                    206.032}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    87.371, 206.032}, {89.20700000000001, 204.813}, {91.043, 
                    206.032}, {89.20700000000001, 207.255}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0.15686300000000003`, 0.6823529999999999, 0.4], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    89.20700000000001, 207.009}, {90.67999999999999, 
                    206.032}, {89.20700000000001, 205.055}, {
                    87.73400000000001, 206.032}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    100.45700000000001`, 206.032}, {98.617, 204.813}, {96.781,
                     206.032}, {98.617, 207.255}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0.15686300000000003`, 0.6823529999999999, 0.4], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    98.617, 207.009}, {97.148, 206.032}, {98.617, 205.055}, {
                    100.09, 206.032}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYCYin9uypsG/0d0tOAQC/LIcJyy4myc/4O1xcX
2HKpZzksP+Zt3vnR30GVrXGqs3KWw+2fdVl7eALg/N7peULNCgi+S3fO89+G
AXD9IY+Xzj7iEAA334uHSbs9LwBirmuWw3Eg5VgQ4MC5RiYqJT/LwQpo/b78
AIcjChuKMnox+TOA1h2wgvILsxykQe4H2rf64yXfpJwsh4tKQBdqBTgsAHms
COHezXPfLz/WTZh/eqHrts93/eH6+0D+u+APN3+yBEsY315/uP25z3+v/Bjk
D3cfOv/wV42YfiAf5j8DoHMbQ/3h/kcPfwC3UK7R
                    
                    "]]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4ts/67L28AQ4fPl7peJlXZaDyDr3h1UiAQ6V
L9UMOSqyHLx4mLTb9QIcenKe/16ZSJivytY41Tk4wEFa/64KW2mWA9f1xQW2
SQEO5p2OCU9rshx6p+cJNSdA7YvKctj2GcgIhNrnkOVQnDHxbY15gANIG5dx
lsPrwB1yrdpQ/TpZDotcgTpkAhy+acT0H9LMcoC5H8affURhQ9EPfzgfbO4d
f7j+X0DlJYf94eaD7ev3h9tvGrfLk6fIH+6+UwuBFub6w90PVtfjD/efAZBq
vOoP9z86vwKk/o2/A+camaiU7CwHYOCuc2cMcPgHNF6tFOF+WPgDADdUstg=

                    "]]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    73.301, 214.52}, {71.74600000000001, 215.86}, {
                    70.18799999999999, 214.52}, {71.258, 213.602}, {71.258, 
                    211.47299999999998`}, {70.65199999999999, 
                    212.07899999999998`}, {70.65199999999999, 213.278}, {
                    69.266, 211.993}, {71.74600000000001, 209.516}, {74.223, 
                    211.993}, {72.836, 213.278}, {72.836, 
                    212.07899999999998`}, {72.23400000000001, 
                    211.47299999999998`}, {72.23400000000001, 
                    213.602}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    71.45700000000001, 213.696}, {70.49600000000001, 
                    214.52}, {71.74600000000001, 215.591}, {72.992, 214.52}, {
                    72.031, 213.696}, {72.031, 210.985}, {73.039, 211.993}, {
                    73.039, 212.817}, {73.93, 211.989}, {71.74600000000001, 
                    209.80200000000002`}, {69.559, 211.989}, {
                    70.44900000000001, 212.817}, {70.44900000000001, 
                    211.993}, {71.45700000000001, 210.985}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    80.848, 216.911}, {79.289, 218.24699999999999`}, {
                    77.73400000000001, 216.911}, {78.801, 215.993}, {78.801, 
                    213.864}, {78.199, 214.466}, {78.199, 
                    215.66899999999998`}, {76.812, 214.38400000000001`}, {
                    79.289, 211.903}, {81.77, 214.38400000000001`}, {80.383, 
                    215.66899999999998`}, {80.383, 214.466}, {79.777, 
                    213.864}, {79.777, 215.993}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    79.004, 216.083}, {78.043, 216.911}, {79.289, 
                    217.98100000000002`}, {80.539, 216.911}, {
                    79.57799999999999, 216.083}, {79.57799999999999, 
                    213.376}, {80.586, 214.38400000000001`}, {80.586, 
                    215.20399999999998`}, {81.477, 214.376}, {79.289, 
                    212.18800000000002`}, {77.10199999999999, 214.376}, {
                    77.99600000000001, 215.20399999999998`}, {
                    77.99600000000001, 214.38400000000001`}, {79.004, 
                    213.376}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    73.301, 197.54399999999998`}, {71.74600000000001, 
                    196.208}, {70.18799999999999, 197.54399999999998`}, {
                    71.258, 198.46200000000002`}, {71.258, 200.591}, {
                    70.65199999999999, 199.989}, {70.65199999999999, 
                    198.786}, {69.266, 200.071}, {71.74600000000001, 
                    202.55200000000002`}, {74.223, 200.071}, {72.836, 
                    198.786}, {72.836, 199.989}, {72.23400000000001, 
                    200.591}, {72.23400000000001, 
                    198.46200000000002`}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    71.45700000000001, 198.36800000000002`}, {
                    70.49600000000001, 197.54399999999998`}, {
                    71.74600000000001, 196.47299999999998`}, {72.992, 
                    197.54399999999998`}, {72.031, 198.36800000000002`}, {
                    72.031, 201.07899999999998`}, {73.039, 200.071}, {73.039, 
                    199.251}, {73.93, 200.075}, {71.74600000000001, 
                    202.262}, {69.559, 200.075}, {70.44900000000001, 
                    199.251}, {70.44900000000001, 200.071}, {
                    71.45700000000001, 201.07899999999998`}}}]}}}}}}}, {{{{{{{
                    
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    105.113, 214.52}, {106.66799999999999`, 215.86}, {108.227,
                     214.52}, {107.15599999999999`, 213.602}, {
                    107.15599999999999`, 211.47299999999998`}, {107.762, 
                    212.07899999999998`}, {107.762, 213.278}, {109.148, 
                    211.993}, {106.66799999999999`, 209.516}, {104.191, 
                    211.993}, {105.57799999999999`, 213.278}, {
                    105.57799999999999`, 212.07899999999998`}, {
                    106.17999999999999`, 211.47299999999998`}, {
                    106.17999999999999`, 213.602}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    106.95700000000001`, 213.696}, {107.918, 214.52}, {
                    106.66799999999999`, 215.591}, {105.422, 214.52}, {
                    106.383, 213.696}, {106.383, 210.985}, {
                    105.37499999999999`, 211.993}, {105.37499999999999`, 
                    212.817}, {104.48400000000001`, 211.989}, {
                    106.66799999999999`, 209.80200000000002`}, {
                    108.85499999999999`, 211.989}, {107.965, 212.817}, {
                    107.965, 211.993}, {106.95700000000001`, 
                    210.985}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    105.113, 197.54399999999998`}, {106.66799999999999`, 
                    196.208}, {108.227, 197.54399999999998`}, {
                    107.15599999999999`, 198.46200000000002`}, {
                    107.15599999999999`, 200.591}, {107.762, 199.989}, {
                    107.762, 198.786}, {109.148, 200.071}, {
                    106.66799999999999`, 202.55200000000002`}, {104.191, 
                    200.071}, {105.57799999999999`, 198.786}, {
                    105.57799999999999`, 199.989}, {106.17999999999999`, 
                    200.591}, {106.17999999999999`, 
                    198.46200000000002`}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    106.95700000000001`, 198.36800000000002`}, {107.918, 
                    197.54399999999998`}, {106.66799999999999`, 
                    196.47299999999998`}, {105.422, 197.54399999999998`}, {
                    106.383, 198.36800000000002`}, {106.383, 
                    201.07899999999998`}, {105.37499999999999`, 200.071}, {
                    105.37499999999999`, 199.251}, {104.48400000000001`, 
                    200.075}, {106.66799999999999`, 202.262}, {
                    108.85499999999999`, 200.075}, {107.965, 199.251}, {
                    107.965, 200.071}, {106.95700000000001`, 
                    201.07899999999998`}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    80.848, 195.157}, {79.289, 193.817}, {77.73400000000001, 
                    195.157}, {78.801, 196.075}, {78.801, 
                    198.20399999999998`}, {78.199, 197.598}, {78.199, 
                    196.399}, {76.812, 197.684}, {79.289, 200.161}, {81.77, 
                    197.684}, {80.383, 196.399}, {80.383, 197.598}, {79.777, 
                    198.20399999999998`}, {79.777, 196.075}}}]}}}}}}}, {{{{{{{
                    
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    79.004, 195.98100000000002`}, {78.043, 195.157}, {79.289, 
                    194.08700000000002`}, {80.539, 195.157}, {
                    79.57799999999999, 195.98100000000002`}, {
                    79.57799999999999, 198.692}, {80.586, 197.684}, {80.586, 
                    196.86}, {81.477, 197.68800000000002`}, {79.289, 
                    199.876}, {77.10199999999999, 197.68800000000002`}, {
                    77.99600000000001, 196.86}, {77.99600000000001, 
                    197.684}, {79.004, 198.692}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    97.566, 216.911}, {99.12499999999999, 
                    218.24699999999999`}, {100.67999999999999`, 216.911}, {
                    99.613, 215.993}, {99.613, 213.864}, {100.215, 214.466}, {
                    100.215, 215.66899999999998`}, {101.60199999999999`, 
                    214.38400000000001`}, {99.12499999999999, 211.903}, {
                    96.645, 214.38400000000001`}, {98.031, 
                    215.66899999999998`}, {98.031, 214.466}, {98.637, 
                    213.864}, {98.637, 215.993}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    99.41000000000001, 216.083}, {100.371, 216.911}, {
                    99.12499999999999, 217.98100000000002`}, {
                    97.87499999999999, 216.911}, {98.836, 216.083}, {98.836, 
                    213.376}, {97.82799999999999, 214.38400000000001`}, {
                    97.82799999999999, 215.20399999999998`}, {96.938, 
                    214.376}, {99.12499999999999, 212.18800000000002`}, {
                    101.309, 214.376}, {100.418, 215.20399999999998`}, {
                    100.418, 214.38400000000001`}, {99.41000000000001, 
                    213.376}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    97.566, 195.157}, {99.12499999999999, 193.817}, {
                    100.67999999999999`, 195.157}, {99.613, 196.075}, {99.613,
                     198.20399999999998`}, {100.215, 197.598}, {100.215, 
                    196.399}, {101.60199999999999`, 197.684}, {
                    99.12499999999999, 200.161}, {96.645, 197.684}, {98.031, 
                    196.399}, {98.031, 197.598}, {98.637, 
                    198.20399999999998`}, {98.637, 196.075}}}]}}}}}}}, {{{{{{{
                    
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    99.41000000000001, 195.98100000000002`}, {100.371, 
                    195.157}, {99.12499999999999, 194.08700000000002`}, {
                    97.87499999999999, 195.157}, {98.836, 
                    195.98100000000002`}, {98.836, 198.692}, {
                    97.82799999999999, 197.684}, {97.82799999999999, 
                    196.86}, {96.938, 197.68800000000002`}, {
                    99.12499999999999, 199.876}, {101.309, 
                    197.68800000000002`}, {100.418, 196.86}, {100.418, 
                    197.684}, {99.41000000000001, 198.692}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYCYin9uypsG/0dzn0Pfrw0ONMhwnLLibJz/g7X
FxfYckVnOiw/5m3e+dHfQRAkEZfpcPtnXdYengA4v3d6nlCzAoLv0p3z/Ldh
AFx/yOOls484BMDN9+Jh0m7PC3DoA+mzyXQ4DjTesQCqXyjTwQpo/b78AAeg
7uuLv2Rg8GcAtR2wCnAoBPEFMh2kQe4H2vdNI6b/kGimw0UloAu1AhwqX6oZ
cggg3Nt84NRC128ZBPmnF7pu+3zXH64f7M4L/nDzJ0uwhPHt9Yfbn/v898qP
Qf5w96HzD38Fagzyh/vPAOjcxlB/uP/Rwx8AxOmyuA==
                    
                    "]]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4ts/67L28AQ4OCU8vaDEnOkgss79YZVIgMOe
kskSLFyZDl48TNrtegEOvdPzhJoVCPNV2RqnOgcHOPy7UvFSjTfTgev64gLb
pAAHoKHr3FkzIeoSAhwcQfapZzps+/z3SkUg1D6nTIfijIlva8yh8v6ZDq8D
d8i1akP1h2Y6LHIF6pAJcLA3jdvlGZHpAHM/jD/7iMKGoh/+cH7lSzVDjjv+
cP2/gMpLDvvDzQfb1+8Ptx+kjafIH+6+UwuBFub6w90PNq/HH+4/g7sqbI1X
/eH+R+dXgNS/8XcQiLDcckIsE2IOY4CDeSfQBh6E+2HhDwCQuaLW
                    
                    "]]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYCYpfunOe/D8Y4pKcBgV6Wgypb41TnzTEO1xcX
2HKpZznU2pvG7VoYAxFXznL4phHTf6gXwQfrr0Twe6fnCTVnoOmPRJhf8VLN
kEMnxmH5MW/zTtcsBy6QQq0YB841MlEp+VkOIO0HgPwjChuKMnox+VZbTpTt
i4fyC7McHlaJrHPPjHFY/fGSb1JOlgMDCBTEOCyQ0r+rUoRw7+a575cf6ybM
fx24Q651NUI/2H2bEOZXgty/B2G/NFAZ20eE+9D5YPd9RPgP7P73CP+jhz8A
6EisBw==
                    "]]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4m8aMf2HemMcvvy9UvGyLsthb8lkCZa2GIfK
l2qGHBVZDhUgOifGoSfn+e+ViYT5a2SiUqzdYxyk9e+qsJVmORzzNu90tIhx
AJIJT2uyHFy6gQotofZFZUHUeULtc8hyiN/lycOUHONwfXGBLZdxlsOzC0q3
f+ZB9etkORgAlTfWxjiA3a2Z5QBzP4zffODUQtd5CL7IOveHVWsQ+kMeL519
ZAfC/Bl5Qs0HLiHs3/YZ6LCHCPe9Dtwh1/oY4X6weVcQ/rPacqJs33qE/9H5
YPVLYhw4QQGTneXwsAooMjPG4R/QeLVShPth4Q8Ax0u5yQ==
                    
                    "]]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYCYpfunOe/D8Y4nPse/HhpcKaDKlvjVOfNMQ7X
FxfYckVnOtTam8btWhjjIBhhueVEXKbDN42Y/kO9CD5YfyWC3zs9T6g5A01/
JML8ipdqhhw6MQ59IHU2mQ5cIIVaUP1CmQ4g4QNAPlD39cVfMjD4VltOlO2L
j3EoBPEFMh0eVomsc8+MgbhLNNOBAQQKYhwqQfYIINzbfODUQtdvGQT5rwN3
yLWuRugHu28Twnyw+B6E/dL6d1XYPiLch84Hu+8jwn9g979H+B89/AH14a/u

                    "]]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4m8aMf2HemMcnBKeXlBiznTYWzJZgqUtxmEP
iObKdKh4qWbIkRPj0Ds9T6hZgTB/jUxUirV7jMO/K0AZ3kyHY97mnY4WMQ4P
q0TWubNmOrh05zz/bRnj4AiyTz3TQVr/rgqbJ9Q+p0yH+F2ePEzJUHn/TIdn
F5Ru/8yD6g/NdDAAKm+sjXGwN43b5RmR6QBzP4zffODUQtd5CD5Q18OqNQj9
IY+Xzj6yA2H+DKCzD1xC2L/t898rFQ8R7nsduEOu9THC/WDzriD8Z7XlRNm+
9Qj/o/PB6pfEOAhEWG45IZYJMWdmjAMwVBKe8iDcDwt/ACC/qcc=
                    
                    "]]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{91.504, 195.598}, {90.691, 
                    196.29399999999998`}, {90.691, 194.24299999999997`}, {
                    92.523, 192.89100000000002`}, {89.20700000000001, 
                    190.446}, {85.891, 192.89100000000002`}, {87.723, 
                    194.24299999999997`}, {87.723, 196.29399999999998`}, {
                    86.91000000000001, 195.598}, {86.91000000000001, 
                    194.47}, {84.96900000000001, 196.063}, {87.051, 
                    197.985}, {86.238, 199.10999999999999`}, {
                    92.17199999999998, 199.10999999999999`}, {91.363, 
                    197.985}, {93.44500000000001, 196.063}, {91.504, 
                    194.47}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{86.70700000000001, 
                    194.895}, {86.70700000000001, 195.692}, {87.926, 
                    196.73499999999999`}, {87.926, 194.141}, {86.23, 
                    192.89100000000002`}, {89.20700000000001, 190.7}, {92.184,
                     192.89100000000002`}, {90.488, 194.141}, {90.488, 
                    196.73499999999999`}, {91.703, 195.692}, {91.703, 
                    194.895}, {93.137, 196.075}, {91.09400000000001, 
                    197.95800000000003`}, {91.777, 198.907}, {86.637, 
                    198.907}, {87.32, 197.95800000000003`}, {85.277, 
                    196.075}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{89.20700000000001, 194.009}, {90.723, 
                    192.89100000000002`}, {89.20700000000001, 
                    191.77399999999997`}, {89.148, 191.82100000000003`}, {
                    87.691, 192.89100000000002`}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0.15686300000000003`, 0.6823529999999999, 0.4], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{89.20700000000001, 192.02800000000002`}, {89.309,
                     192.098}, {90.203, 192.762}, {90.383, 
                    192.89100000000002`}, {90.203, 193.024}, {89.309, 
                    193.684}, {89.20700000000001, 193.759}, {
                    89.10499999999999, 193.684}, {88.20700000000001, 
                    193.024}, {88.031, 192.89100000000002`}, {
                    88.20700000000001, 192.762}, {89.10499999999999, 
                    192.098}, {89.20700000000001, 
                    192.02800000000002`}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    63.465, 154.24299999999997`}, {63.465, 156.153}, {
                    59.839999999999996`, 153.85200000000003`}, {
                    58.382999999999996`, 154.97299999999998`}, {
                    56.882999999999996`, 154.80200000000002`}, {
                    56.160000000000004`, 153.782}, {57.452999999999996`, 
                    152.79399999999998`}, {56.160000000000004`, 151.805}, {
                    56.882999999999996`, 150.782}, {58.382999999999996`, 
                    150.60999999999999`}, {59.839999999999996`, 151.731}, {
                    63.465, 149.43}, {63.465, 151.345}, {61.184, 
                    152.79399999999998`}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0.15686300000000003`, 0.6823529999999999, 0.4], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    59.828, 153.602}, {63.26200000000001, 155.786}, {
                    63.26200000000001, 154.35200000000003`}, {60.805, 
                    152.79399999999998`}, {63.26200000000001, 151.231}, {
                    63.26200000000001, 149.798}, {59.828, 
                    151.98100000000002`}, {58.324, 150.82100000000003`}, {
                    56.996, 150.97299999999998`}, {56.438, 151.762}, {
                    57.785000000000004`, 152.79399999999998`}, {56.438, 
                    153.82100000000003`}, {56.996, 154.60999999999999`}, {
                    58.324, 154.762}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    63.465, 160.88700000000003`}, {63.465, 162.798}, {
                    59.839999999999996`, 160.497}, {58.382999999999996`, 
                    161.618}, {56.882999999999996`, 161.446}, {
                    56.160000000000004`, 160.42700000000002`}, {
                    57.452999999999996`, 159.43800000000002`}, {
                    56.160000000000004`, 158.45000000000002`}, {
                    56.882999999999996`, 157.43}, {58.382999999999996`, 
                    157.255}, {59.839999999999996`, 158.38000000000002`}, {
                    63.465, 156.075}, {63.465, 157.989}, {61.184, 
                    159.43800000000002`}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0.15686300000000003`, 0.6823529999999999, 0.4], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    59.828, 160.251}, {63.26200000000001, 162.43}, {
                    63.26200000000001, 160.997}, {60.805, 
                    159.43800000000002`}, {63.26200000000001, 157.876}, {
                    63.26200000000001, 156.442}, {59.828, 158.626}, {58.324, 
                    157.466}, {56.996, 157.618}, {56.438, 158.407}, {
                    57.785000000000004`, 159.43800000000002`}, {56.438, 
                    160.47}, {56.996, 161.255}, {58.324, 
                    161.411}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    63.465, 144.696}, {63.465, 142.786}, {59.839999999999996`,
                     145.08700000000002`}, {58.382999999999996`, 143.966}, {
                    56.882999999999996`, 144.137}, {56.160000000000004`, 
                    145.157}, {57.452999999999996`, 146.14499999999998`}, {
                    56.160000000000004`, 147.137}, {56.882999999999996`, 
                    148.157}, {58.382999999999996`, 148.329}, {
                    59.839999999999996`, 147.208}, {63.465, 149.509}, {63.465,
                     147.598}, {61.184, 146.14499999999998`}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0.15686300000000003`, 0.6823529999999999, 0.4], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    59.828, 145.33700000000002`}, {63.26200000000001, 
                    143.153}, {63.26200000000001, 144.58700000000002`}, {
                    60.805, 146.14899999999997`}, {63.26200000000001, 
                    147.708}, {63.26200000000001, 149.141}, {59.828, 
                    146.95800000000003`}, {58.324, 148.118}, {56.996, 
                    147.966}, {56.438, 147.177}, {57.785000000000004`, 
                    146.14899999999997`}, {56.438, 145.118}, {56.996, 
                    144.329}, {58.324, 144.177}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    114.94900000000001`, 154.24299999999997`}, {
                    114.94900000000001`, 156.153}, {118.574, 
                    153.85200000000003`}, {120.031, 154.97299999999998`}, {
                    121.531, 154.80200000000002`}, {122.254, 153.782}, {
                    120.96100000000001`, 152.79399999999998`}, {122.254, 
                    151.805}, {121.531, 150.782}, {120.031, 
                    150.60999999999999`}, {118.574, 151.731}, {
                    114.94900000000001`, 149.43}, {114.94900000000001`, 
                    151.345}, {117.23, 152.79399999999998`}}}]}}}}}}}, {{{{{{{
                    
                    FaceForm[{
                    RGBColor[0.15686300000000003`, 0.6823529999999999, 0.4], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    118.586, 153.602}, {115.15199999999999`, 155.786}, {
                    115.15199999999999`, 154.35200000000003`}, {117.609, 
                    152.79399999999998`}, {115.15199999999999`, 151.231}, {
                    115.15199999999999`, 149.798}, {118.586, 
                    151.98100000000002`}, {120.09, 150.82100000000003`}, {
                    121.418, 150.97299999999998`}, {121.977, 151.762}, {
                    120.62499999999999`, 152.79399999999998`}, {121.977, 
                    153.82100000000003`}, {121.418, 154.60999999999999`}, {
                    120.09, 154.762}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    114.94900000000001`, 160.88700000000003`}, {
                    114.94900000000001`, 162.798}, {118.574, 160.497}, {
                    120.031, 161.618}, {121.531, 161.446}, {122.254, 
                    160.42700000000002`}, {120.96100000000001`, 
                    159.43800000000002`}, {122.254, 158.45000000000002`}, {
                    121.531, 157.43}, {120.031, 157.255}, {118.574, 
                    158.38000000000002`}, {114.94900000000001`, 156.075}, {
                    114.94900000000001`, 157.989}, {117.23, 
                    159.43800000000002`}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0.15686300000000003`, 0.6823529999999999, 0.4], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    118.586, 160.251}, {115.15199999999999`, 162.43}, {
                    115.15199999999999`, 160.997}, {117.609, 
                    159.43800000000002`}, {115.15199999999999`, 157.876}, {
                    115.15199999999999`, 156.442}, {118.586, 158.626}, {
                    120.09, 157.466}, {121.418, 157.618}, {121.977, 
                    158.407}, {120.62499999999999`, 159.43800000000002`}, {
                    121.977, 160.47}, {121.418, 161.255}, {120.09, 
                    161.411}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    114.94900000000001`, 144.696}, {114.94900000000001`, 
                    142.786}, {118.574, 145.08700000000002`}, {120.031, 
                    143.966}, {121.531, 144.137}, {122.254, 145.157}, {
                    120.96100000000001`, 146.14499999999998`}, {122.254, 
                    147.137}, {121.531, 148.157}, {120.031, 148.329}, {
                    118.574, 147.208}, {114.94900000000001`, 149.509}, {
                    114.94900000000001`, 147.598}, {117.23, 
                    146.14499999999998`}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0.15686300000000003`, 0.6823529999999999, 0.4], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    118.586, 145.33700000000002`}, {115.15199999999999`, 
                    143.153}, {115.15199999999999`, 144.58700000000002`}, {
                    117.609, 146.14899999999997`}, {115.15199999999999`, 
                    147.708}, {115.15199999999999`, 149.141}, {118.586, 
                    146.95800000000003`}, {120.09, 148.118}, {121.418, 
                    147.966}, {121.977, 147.177}, {120.62499999999999`, 
                    146.14899999999997`}, {121.977, 145.118}, {121.418, 
                    144.329}, {120.09, 144.177}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{107.016, 
                    172.934}, {107.016, 170.17299999999997`}, {109.027, 
                    170.17299999999997`}, {109.027, 168.95000000000002`}, {
                    111., 168.95000000000002`}, {111., 171.17299999999997`}, {
                    109.238, 171.17299999999997`}, {109.238, 
                    172.934}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0.15686300000000003`, 0.6823529999999999, 0.4], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{109.039, 
                    172.731}, {109.039, 170.97299999999998`}, {
                    110.79700000000001`, 170.97299999999998`}, {
                    110.79700000000001`, 169.153}, {109.227, 169.153}, {
                    109.227, 170.372}, {107.21900000000001`, 170.372}, {
                    107.21900000000001`, 172.731}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    112.94100000000002`, 168.575}, {112.94100000000002`, 
                    165.813}, {114.94900000000001`, 165.813}, {
                    114.94900000000001`, 164.591}, {116.926, 164.591}, {
                    116.926, 166.817}, {115.164, 166.817}, {115.164, 
                    168.575}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0.15686300000000003`, 0.6823529999999999, 0.4], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{114.965, 
                    168.376}, {114.965, 166.61399999999998`}, {116.723, 
                    166.61399999999998`}, {116.723, 164.79399999999998`}, {
                    115.15199999999999`, 164.79399999999998`}, {
                    115.15199999999999`, 166.016}, {113.145, 166.016}, {
                    113.145, 168.376}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{71.398, 
                    172.934}, {71.398, 170.17299999999997`}, {69.387, 
                    170.17299999999997`}, {69.387, 168.95000000000002`}, {
                    67.41400000000002, 168.95000000000002`}, {
                    67.41400000000002, 171.17299999999997`}, {
                    69.17599999999999, 171.17299999999997`}, {
                    69.17599999999999, 172.934}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0.15686300000000003`, 0.6823529999999999, 0.4], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    69.37499999999999, 172.731}, {69.37499999999999, 
                    170.97299999999998`}, {67.617, 170.97299999999998`}, {
                    67.617, 169.153}, {69.18799999999999, 169.153}, {
                    69.18799999999999, 170.372}, {71.195, 170.372}, {71.195, 
                    172.731}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{107.016, 
                    132.64899999999997`}, {107.016, 135.415}, {109.027, 
                    135.415}, {109.027, 136.634}, {111., 136.634}, {111., 
                    134.411}, {109.238, 134.411}, {109.238, 
                    132.64899999999997`}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0.15686300000000003`, 0.6823529999999999, 0.4], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{109.039, 
                    132.85200000000003`}, {109.039, 134.61399999999998`}, {
                    110.79700000000001`, 134.61399999999998`}, {
                    110.79700000000001`, 136.43}, {109.227, 136.43}, {109.227,
                     135.212}, {107.21900000000001`, 135.212}, {
                    107.21900000000001`, 
                    132.85200000000003`}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{71.398, 
                    132.64899999999997`}, {71.398, 135.415}, {69.387, 
                    135.415}, {69.387, 136.634}, {67.41400000000002, 
                    136.634}, {67.41400000000002, 134.411}, {
                    69.17599999999999, 134.411}, {69.17599999999999, 
                    132.64899999999997`}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0.15686300000000003`, 0.6823529999999999, 0.4], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    69.37899999999999, 132.85200000000003`}, {
                    69.37899999999999, 134.61399999999998`}, {67.617, 
                    134.61399999999998`}, {67.617, 136.43}, {
                    69.18799999999999, 136.43}, {69.18799999999999, 
                    135.212}, {71.195, 135.212}, {71.195, 
                    132.85200000000003`}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    112.94100000000002`, 137.009}, {112.94100000000002`, 
                    139.76999999999998`}, {114.94900000000001`, 
                    139.76999999999998`}, {114.94900000000001`, 140.993}, {
                    116.926, 140.993}, {116.926, 138.76999999999998`}, {
                    115.164, 138.76999999999998`}, {115.164, 
                    137.009}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0.15686300000000003`, 0.6823529999999999, 0.4], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{114.965, 
                    137.212}, {114.965, 138.97}, {116.723, 138.97}, {116.723, 
                    140.79}, {115.15199999999999`, 140.79}, {
                    115.15199999999999`, 139.571}, {113.145, 139.571}, {
                    113.145, 137.212}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{65.473, 
                    168.575}, {65.473, 165.813}, {63.465, 165.813}, {63.465, 
                    164.591}, {61.488, 164.591}, {61.488, 166.817}, {63.25, 
                    166.817}, {63.25, 168.575}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0.15686300000000003`, 0.6823529999999999, 0.4], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{63.449, 
                    168.376}, {63.449, 166.61399999999998`}, {61.691, 
                    166.61399999999998`}, {61.691, 164.79399999999998`}, {
                    63.26200000000001, 164.79399999999998`}, {
                    63.26200000000001, 166.016}, {65.27, 166.016}, {65.27, 
                    168.376}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{65.473, 
                    137.009}, {65.473, 139.76999999999998`}, {63.465, 
                    139.76999999999998`}, {63.465, 140.993}, {61.488, 
                    140.993}, {61.488, 138.76999999999998`}, {63.25, 
                    138.76999999999998`}, {63.25, 137.009}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0.15686300000000003`, 0.6823529999999999, 0.4], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    63.452999999999996`, 137.212}, {63.452999999999996`, 
                    138.97}, {61.691, 138.97}, {61.691, 140.79}, {
                    63.26200000000001, 140.79}, {63.26200000000001, 
                    139.571}, {65.27, 139.571}, {65.27, 
                    137.212}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJRIGYC4odVIuvcNSMcKl+qGXIsSHWQ1r+rwqYI5S9J
dXh6Qen2z2PhDue/Bz9eeh6T78nDpN2eFu5wfXGBLddiTL5Ld87z3xvDHZoP
nFroWpfqcAmovW5XuMMCKaBFVakOe0smS7D4hTssP+Zt3uma6rBGJirF+j2C
D3NfD9CYlYmpDqpsjVOdkyPg8n5JAhGWLJFwvuWWE2X7pkfAzT8OFHZcEAG3
f9Pc98uPvY6Auw+drwIyvzsC7r+LIPdmRUDU7U91cAb5xzPCYRqIsR7hPlj4
AQCthJsa
                    "]]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0.15686300000000003`, 0.6823529999999999, 0.4], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYCYrnW14E7joU7CERYbjlxLNVBHsQ/F+4gCOIf
SnV4WCWyzl0zwuH64gJbrumE+UDdcq3NEXD9YH53BNx8VbbGqc6TIxycEp5e
UDqc6tA7PU+o+QJUflmqg7T+XRW2mxEOX/5eqXi5KNXhuLd5pyNQXm/T3PfL
56U6ZEx8W2PfGuGwQAqosAqT75cENOlJhMM05+6c595Q8zMQfJh7dUHmZaU6
gIR/vwyHy+8tmSzBkofgZ4LMPxsONx+d7wLS3xgOdx/Y/MpwuPtr7U3jdjWG
w/23RiYqxXp/ONz/6OEPAFeYtek=
                    "]]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJRIGYC4syJb2vsfcMcKl+qGXIsSHVY6Lrt818XKH9J
qkPsLk8eptehDue/Bz9eeh6Tf1Hp9s+6rlCH64sLbLkWY/KbD5xa6HotFELX
pTrIt74O3HEv1GGBlP5dlapUBy6QwqJQh+XHvM07XVMdVNkapzoLh8H5MPf1
5Dz/vTIx1WGNTFSKdTtCHkQ5aoTD+Zvnvl9+bHcY3Hy/JIEIyyNhcPsZQEAg
HO4+dH5xBtDC9WFw/4Hd2xfmsAlk7v5Uh70lkyVY8sIcpjl35zxfj3AfLPwA
brqWLQ==
                    "]]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0.15686300000000003`, 0.6823529999999999, 0.4], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4thdnjxMr0MdBCIst5w4luoQD+J/DnUQBPEP
pTpkTnxbY+8b5nB9cYEt13TC/OIMoMDyMLh+qy0nyvatD4Obv0YmKsV6e5iD
U8LTC0qHUx1u/6zL2vMFKr8s1WGR67bPf/+EOXz5e6Xi5aJUB5F17g+rgPJ6
m+a+Xz4v1eFhFVBkZZjDAin9uypVmPze6XlCzRzhDtOcu3Oee0P194TB+TD3
6oLMy0p12FsyWYKFDyHvAqR+TwyF88HmfwxFtQ+JD9a/LBTuPoO7KmyNc0Ph
7v+mEdN/aGko3H+qbI1TnR+Hwv2PHv4Az+G4JA==
                    
                    "]]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJRIGYC4odVIuvcC0McKl+qGXIsSHXY9vnvlYpKKH9J
qsPrwB1yrZdDHM5/D3689Dwmv13s5rnvxqEO1xcX2HItxuT3Ts8Tan4R4tB8
4NRC17pUBwYQeBDisEBK/65KVaoD0PaHVT6hDsuPeZt3uqY6qLA1TnVeHQLn
w9zXk/P898rEVIc1MlEp1uYIebC504Lh/BlA6w4wIcznBjnkVzDcfvlWoA/W
BcPdh84Hm8+P8B/YvQYhDpvmvl9+bH+qQ8jjpbOPBIQ4THPuznm+HuE+WPgB
AHmtmBI=
                    "]]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0.15686300000000003`, 0.6823529999999999, 0.4], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4k1z3y8/djnEQSDCcsuJY6kOYP7pEAdBEP9Q
qsPDKpF17oUhDtcXF9hyTSfMf3pB6fZPMYT+ZyA+H8L8NTJRKdbsIQ5OCUCV
h1MdnLtznv8+GQyRX5bqsO3z3ysVB4MdvgCpl4tSHbhABp8KdtADOWxeqoP+
XRW2RtEQhwVSQFYVJr/5wKmFrtuCHaaBDPZOdXABmW8YAufD3KsLMi8r1aF3
ep5Q8waEPFD2YZVOKJyfOfFtjf1ZhPnofLB+iVC4+8DmK4bC3R/yeOnsI0B5
mP9U2RqnOt9G+B89/AH5hbwF
                    "]]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJRIGYC4odVIuvcNSMcdDfNfb98UoKDtP5dFTbFCAfB
CMstJ/oSHJ5eULr981i4w/XFBbZcyZh8Tx4m7fa0cAeQ9mP9mHyX7pznvzeG
O6z6eMk3aUuCwyWg9rpd4Q690/OEmnckOOwtmSzB4hfuAHbH2wSHNTJRKdbv
EXyY+8DuupjgoMrWONU5OQIu75ckEGHJEgnnA11dtm96BNz8497mnY4LIuD2
g931OgLuPnS+Csj87gi4/y6C3JsV4fDl75WKl0UJDs4g/3hCw6cJ4T5Y+AEA
1rqfLA==
                    "]]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0.15686300000000003`, 0.6823529999999999, 0.4], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYCYrnW14E7joU7VL5UM+TISXCQB/HPhTtMc+7O
eZ6f4PCwSmSdu2aEw+a575cfm02YD9Qt19ocAdcP5ndHwM1XZWuc6jw5wuEN
SBwo3zs9T6j5AlR9d4KDtP5dFbabEQ6bQOb1Jzgc9zbvdLwA1T8lwSFj4tsa
+9YIiL4dmHy/JIEIyycRDkByy4lnUPMzEHyYe8HmnUhwAFn7+2U4XH5vyWQJ
ljwEPxNk/tlwuPnofBeQ/sZwuPvA5leGw91fa28at6sxHO6/NTJRKdb7w+H+
Rw9/AICQthA=
                    "]]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJRIGYC4syJb2vsfcMcdDfNfb98UoLDQtdtn/+6hDkI
RlhuOdGX4BC7y5OH6XWow/XFBbZcyZj8i0q3f9Z1hTqAtB/rx+Q3Hzi10PVa
qMOqj5d8k7YkOMi3vg7ccS/UoXd6nlDzjgQHLpBBRaEOD6tE1rm/TXBQZWuc
6iwcBufD3Cetf1eF7WKCwxqZqBTrdoT8MW/zTkeNcDh/M8je3WFw8/2SBCIs
j4TB7WcAAYFwuPvQ+cUZQAvXh8H9B3ZvX5jDl79XKl4WJTjsLZkswZIHDZ8m
hPtg4QcAl/CaPw==
                    "]]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0.15686300000000003`, 0.6823529999999999, 0.4], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4thdnjxMr0MdKl+qGXLkJDjEg/ifQx2mOXfn
PM9PcMic+LbG3jfMYfPc98uPzSbML84ACiwPg+u32nKibN/6MLj5a2SiUqy3
hzm8Cdwh1wqUv/2zLmvPF6j67gSHRa7bPv/9E+awCWRef4KDyDr3h1VfoPqn
JDg8rAKKrAxz6J2eJ9S8A5MPpjnCHQQiLLeceAbV3xMG58PcCzbvRILD3pLJ
Eix8CHkXoDN+TwyF88HmfwxFtQ+JD9a/LBTuPoO7KmyNc0Ph7v+mEdN/aGko
3H+qbI1TnR+Hwv2PHv4A+Nm4Sw==
                    "]]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJRIGYC4odVIuvcC0McdDfNfb98UoLDts9/r1RUhjgI
RlhuOdGX4PA6cIdc6+UQh+uLC2y5kjH57WI3z303DnUAaT/Wj8nvnZ4n1Pwi
xGHVx0u+SVsSHBhA4EEIRHxHggPQ9odVPqEOYHe8TXBQYWuc6rw6BM6HuU9a
/64K28UEhzUyUSnW5gj55gOnFrpOC4bzZwCNPcCEMJ8b5NBfwXD75VuBPlgX
DHcfOh9sPj/Cf2D3GoQ4fAEGy8uiBIeQx0tnHwmAhk8Twn2w8AMAouOcJA==

                    "]]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0.15686300000000003`, 0.6823529999999999, 0.4], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4k1z3y8/djnEofKlmiFHToIDmH86xGGac3fO
8/wEh4dVIuvcC0McNoPEZxPmP72gdPunGEL/MxCfD2H+GpmoFGv2EIc3gTvk
WoHyIGW/TwZD1HcnOGz7/PdKxcFgiDv6Exy4ri8usD0VDNE/JcFB/64KW6No
iEPv9Dyh5h2Y/OYDpxa6bgt2EIiw3HLiWYKDC8h8wxA4H+ZesHknEiD6NiDk
gbIPq3RC4fzMiW9r7M8izEfng2mJULj7wOYrhsLdH/J46ewjQHmY/1TZGqc6
30b4Hz38ASKMvCw=
                    "]]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{69.18799999999999, 
                    170.372}, {69.18799999999999, 166.016}, {
                    63.26200000000001, 166.016}, {63.26200000000001, 
                    139.571}, {69.18799999999999, 139.571}, {
                    69.18799999999999, 135.212}, {109.227, 135.212}, {109.227,
                     139.571}, {115.15199999999999`, 139.571}, {
                    115.15199999999999`, 166.016}, {109.227, 166.016}, {
                    109.227, 170.372}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{109.027, 
                    170.17299999999997`}, {109.027, 165.813}, {
                    114.94900000000001`, 165.813}, {114.94900000000001`, 
                    139.76999999999998`}, {109.027, 139.76999999999998`}, {
                    109.027, 135.415}, {69.387, 135.415}, {69.387, 
                    139.76999999999998`}, {63.465, 139.76999999999998`}, {
                    63.465, 165.813}, {69.387, 165.813}, {69.387, 
                    170.17299999999997`}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{106.46100000000001`, 
                    168.497}, {71.94900000000001, 168.497}, {
                    71.94900000000001, 163.251}, {65.137, 163.251}, {65.137, 
                    142.333}, {71.94900000000001, 142.333}, {
                    71.94900000000001, 137.08700000000002`}, {
                    106.46100000000001`, 137.08700000000002`}, {
                    106.46100000000001`, 142.333}, {113.277, 142.333}, {
                    113.277, 163.251}, {106.46100000000001`, 
                    163.251}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{106.262, 168.298}, {
                    106.262, 163.048}, {113.074, 163.048}, {113.074, 
                    142.536}, {106.262, 142.536}, {106.262, 137.29}, {
                    72.15199999999999, 137.29}, {72.15199999999999, 
                    142.536}, {65.34, 142.536}, {65.34, 163.048}, {
                    72.15199999999999, 163.048}, {72.15199999999999, 
                    168.298}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{65.137, 
                    146.317}, {77.633, 137.08700000000002`}, {100.781, 
                    137.08700000000002`}, {113.277, 146.317}, {113.277, 
                    159.26999999999998`}, {100.781, 168.497}, {77.633, 
                    168.497}, {65.137, 159.26999999999998`}}}]}}}}}}}, {{{{{{{
                    
                    FaceForm[{
                    RGBColor[0.15686300000000003`, 0.6823529999999999, 0.4], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 
                    0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{100.715, 
                    168.298}, {100.766, 168.259}, {112.992, 159.227}, {
                    113.074, 159.165}, {113.074, 146.41899999999998`}, {
                    112.992, 146.35600000000002`}, {100.766, 137.329}, {
                    100.715, 137.29}, {77.699, 137.29}, {77.648, 137.329}, {
                    65.422, 146.35600000000002`}, {65.34, 
                    146.41899999999998`}, {65.34, 159.165}, {65.422, 
                    159.227}, {77.648, 168.259}, {77.699, 
                    168.298}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{103.195, 
                    165.684}, {75.117, 165.684}, {75.117, 163.454}, {71.531, 
                    163.454}, {71.531, 142.13}, {75.117, 142.13}, {75.117, 
                    139.899}, {103.29700000000001`, 139.899}, {
                    103.29700000000001`, 142.13}, {106.883, 142.13}, {106.883,
                     163.454}, {103.29700000000001`, 163.454}, {
                    103.29700000000001`, 165.684}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{103.09400000000001`, 
                    165.48100000000002`}, {103.09400000000001`, 163.255}, {
                    106.67999999999999`, 163.255}, {106.67999999999999`, 
                    142.329}, {103.09400000000001`, 142.329}, {
                    103.09400000000001`, 140.102}, {75.32, 140.102}, {75.32, 
                    142.329}, {71.73400000000001, 142.329}, {
                    71.73400000000001, 163.255}, {75.32, 163.255}, {75.32, 
                    165.48100000000002`}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{72.406, 
                    145.02800000000002`}, {78.516, 139.899}, {99.898, 
                    139.899}, {106.008, 145.02800000000002`}, {106.008, 
                    160.555}, {99.898, 165.684}, {78.516, 165.684}, {72.406, 
                    160.555}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0.15686300000000003`, 0.6823529999999999, 0.4], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 
                    0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{99.824, 
                    165.48100000000002`}, {99.883, 165.43800000000002`}, {
                    105.73400000000001`, 160.52}, {105.80499999999999`, 
                    160.46200000000002`}, {105.80499999999999`, 145.122}, {
                    105.73400000000001`, 145.063}, {99.883, 
                    140.14899999999997`}, {99.824, 140.102}, {78.59, 
                    140.102}, {78.531, 140.14899999999997`}, {
                    72.67999999999999, 145.063}, {72.609, 145.122}, {72.609, 
                    160.46200000000002`}, {72.67999999999999, 160.52}, {
                    78.531, 165.43800000000002`}, {78.59, 
                    165.48100000000002`}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{73.473, 
                    145.52800000000002`}, {78.902, 140.966}, {99.512, 
                    140.966}, {104.938, 145.52800000000002`}, {104.938, 
                    160.059}, {99.512, 164.618}, {78.902, 164.618}, {73.473, 
                    160.059}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 
                    0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{99.438, 
                    164.415}, {99.492, 164.36800000000002`}, {104.664, 
                    160.024}, {104.738, 159.96200000000002`}, {104.738, 
                    145.622}, {104.664, 145.559}, {99.492, 
                    141.21599999999998`}, {99.438, 141.16899999999998`}, {
                    78.977, 141.16899999999998`}, {78.922, 
                    141.21599999999998`}, {73.74600000000001, 145.559}, {
                    73.67599999999999, 145.622}, {73.67599999999999, 
                    159.96200000000002`}, {73.74600000000001, 160.024}, {
                    78.922, 164.36800000000002`}, {78.977, 
                    164.415}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{81.363, 
                    165.48100000000002`}, {97.051, 165.48100000000002`}, {
                    97.051, 166.30200000000002`}, {95.398, 
                    167.72299999999998`}, {93.85199999999999, 
                    166.38700000000003`}, {92.30499999999999, 
                    167.72299999999998`}, {90.754, 166.38700000000003`}, {
                    89.20700000000001, 167.72299999999998`}, {87.66, 
                    166.38700000000003`}, {86.109, 167.72299999999998`}, {
                    84.562, 166.38700000000003`}, {83.016, 
                    167.72299999999998`}, {81.363, 
                    166.30200000000002`}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{96.848, 165.684}, {93.953, 165.684}, {93.953, 
                    166.208}, {95.398, 167.454}, {96.848, 
                    166.208}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{93.75, 165.684}, {90.85499999999999, 165.684}, {
                    90.85499999999999, 166.208}, {92.30499999999999, 
                    167.454}, {93.75, 166.208}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{90.65199999999999, 165.684}, {87.758, 165.684}, {
                    87.758, 166.208}, {89.20700000000001, 167.454}, {
                    90.65199999999999, 166.208}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{87.559, 165.684}, {84.664, 165.684}, {84.664, 
                    166.208}, {86.109, 167.454}, {87.559, 
                    166.208}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{84.46100000000001, 165.684}, {81.566, 165.684}, {
                    81.566, 166.208}, {83.016, 167.454}, {84.46100000000001, 
                    166.208}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{66.863, 
                    149.696}, {68.195, 148.14899999999997`}, {66.863, 
                    146.598}, {68.281, 144.95000000000002`}, {
                    71.73400000000001, 144.95000000000002`}, {
                    71.73400000000001, 160.634}, {68.281, 160.634}, {66.863, 
                    158.985}, {68.195, 157.43800000000002`}, {66.863, 
                    155.88700000000003`}, {68.195, 154.341}, {66.863, 
                    152.79399999999998`}, {68.195, 
                    151.24299999999997`}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{68.37499999999999, 145.153}, {67.12899999999999, 
                    146.598}, {68.37499999999999, 148.048}, {71.531, 
                    148.048}, {71.531, 145.153}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{68.37499999999999, 148.24699999999999`}, {
                    67.12899999999999, 149.696}, {68.37499999999999, 
                    151.141}, {71.531, 151.141}, {71.531, 
                    148.24699999999999`}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{68.37499999999999, 151.345}, {67.12899999999999, 
                    152.79399999999998`}, {68.37499999999999, 
                    154.23899999999998`}, {71.531, 154.23899999999998`}, {
                    71.531, 151.345}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{68.37499999999999, 154.442}, {67.12899999999999, 
                    155.88700000000003`}, {68.37499999999999, 
                    157.33700000000002`}, {71.531, 157.33700000000002`}, {
                    71.531, 154.442}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{68.37499999999999, 157.54}, {67.12899999999999, 
                    158.985}, {68.37499999999999, 160.43}, {71.531, 160.43}, {
                    71.531, 157.54}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{81.363, 
                    140.102}, {97.051, 140.102}, {97.051, 139.282}, {95.398, 
                    137.86}, {93.85199999999999, 139.196}, {92.30499999999999,
                     137.86}, {90.754, 139.196}, {89.20700000000001, 
                    137.86}, {87.66, 139.196}, {86.109, 137.86}, {84.562, 
                    139.196}, {83.016, 137.86}, {81.363, 
                    139.282}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{96.848, 139.899}, {93.953, 139.899}, {93.953, 
                    139.376}, {95.398, 138.13}, {96.848, 
                    139.376}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{93.75, 139.899}, {90.85499999999999, 139.899}, {
                    90.85499999999999, 139.376}, {92.30499999999999, 
                    138.13}, {93.75, 139.376}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{90.65199999999999, 139.899}, {87.758, 139.899}, {
                    87.758, 139.376}, {89.20700000000001, 138.13}, {
                    90.65199999999999, 139.376}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{87.559, 139.899}, {84.664, 139.899}, {84.664, 
                    139.376}, {86.109, 138.13}, {87.559, 
                    139.376}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{84.46100000000001, 139.899}, {81.566, 139.899}, {
                    81.566, 139.376}, {83.016, 138.13}, {84.46100000000001, 
                    139.376}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{111.551, 
                    149.696}, {110.21900000000001`, 148.14899999999997`}, {
                    111.551, 146.598}, {110.133, 144.95000000000002`}, {
                    106.67999999999999`, 144.95000000000002`}, {
                    106.67999999999999`, 160.634}, {110.133, 160.634}, {
                    111.551, 158.985}, {110.21900000000001`, 
                    157.43800000000002`}, {111.551, 155.88700000000003`}, {
                    110.21900000000001`, 154.341}, {111.551, 
                    152.79399999999998`}, {110.21900000000001`, 
                    151.24299999999997`}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{110.039, 145.153}, {111.285, 146.598}, {110.039, 
                    148.048}, {106.883, 148.048}, {106.883, 
                    145.153}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{110.039, 148.24699999999999`}, {111.285, 
                    149.696}, {110.039, 151.141}, {106.883, 151.141}, {
                    106.883, 148.24699999999999`}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{110.039, 151.345}, {111.285, 
                    152.79399999999998`}, {110.039, 154.23899999999998`}, {
                    106.883, 154.23899999999998`}, {106.883, 
                    151.345}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{110.039, 154.442}, {111.285, 
                    155.88700000000003`}, {110.039, 157.33700000000002`}, {
                    106.883, 157.33700000000002`}, {106.883, 
                    154.442}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{110.039, 157.54}, {111.285, 158.985}, {110.039, 
                    160.43}, {106.883, 160.43}, {106.883, 
                    157.54}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{82.031, 
                    141.16899999999998`}, {83.191, 142.286}, {
                    84.35199999999999, 141.16899999999998`}}}]}}}}}}}, {{{{{{{
                    
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    83.191, 144.622}, {82.05499999999999, 
                    145.52800000000002`}, {80.922, 145.04}, {80.715, 
                    143.74299999999997`}, {81.79700000000001, 142.79}, {80.02,
                     141.071}, {82.223, 141.071}, {83.191, 142.005}, {
                    84.15599999999999, 141.071}, {86.363, 141.071}, {84.586, 
                    142.79}, {85.664, 143.74299999999997`}, {
                    85.46100000000001, 145.04}, {84.324, 
                    145.52800000000002`}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0.15686300000000003`, 0.6823529999999999, 0.4], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{81.10199999999999, 144.895}, {82.023, 
                    145.29399999999998`}, {83.191, 144.364}, {83.254, 
                    144.415}, {84.35499999999999, 145.29399999999998`}, {
                    85.277, 144.895}, {85.44900000000001, 
                    143.82100000000003`}, {84.285, 142.798}, {85.973, 
                    141.16899999999998`}, {84.35199999999999, 
                    141.16899999999998`}, {83.191, 142.286}, {82.031, 
                    141.16899999999998`}, {80.406, 141.16899999999998`}, {
                    82.09400000000001, 142.798}, {80.93400000000001, 
                    143.82100000000003`}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    88.04700000000001, 141.16899999999998`}, {
                    89.20700000000001, 142.286}, {90.367, 
                    141.16899999999998`}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    89.20700000000001, 144.622}, {88.074, 
                    145.52800000000002`}, {86.938, 145.04}, {
                    86.73400000000001, 143.74299999999997`}, {87.812, 
                    142.79}, {86.035, 141.071}, {88.238, 141.071}, {
                    89.20700000000001, 142.005}, {90.17599999999999, 
                    141.071}, {92.37899999999999, 141.071}, {
                    90.60199999999999, 142.79}, {91.684, 
                    143.74299999999997`}, {91.477, 145.04}, {90.34, 
                    145.52800000000002`}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0.15686300000000003`, 0.6823529999999999, 0.4], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{87.121, 144.895}, {88.043, 
                    145.29399999999998`}, {89.20700000000001, 144.364}, {
                    89.27, 144.415}, {90.371, 145.29399999999998`}, {91.293, 
                    144.895}, {91.465, 143.82100000000003`}, {
                    90.30499999999999, 142.798}, {91.988, 
                    141.16899999999998`}, {90.367, 141.16899999999998`}, {
                    89.20700000000001, 142.286}, {88.04700000000001, 
                    141.16899999999998`}, {86.426, 141.16899999999998`}, {
                    88.109, 142.798}, {86.94900000000001, 
                    143.82100000000003`}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{96.383, 
                    141.16899999999998`}, {95.223, 142.286}, {94.062, 
                    141.16899999999998`}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    95.223, 144.622}, {96.359, 145.52800000000002`}, {
                    97.49600000000001, 145.04}, {97.699, 
                    143.74299999999997`}, {96.617, 142.79}, {98.398, 
                    141.071}, {96.191, 141.071}, {95.223, 142.005}, {94.258, 
                    141.071}, {92.051, 141.071}, {93.82799999999999, 
                    142.79}, {92.75, 143.74299999999997`}, {92.953, 145.04}, {
                    94.09, 145.52800000000002`}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0.15686300000000003`, 0.6823529999999999, 0.4], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{97.312, 144.895}, {96.391, 
                    145.29399999999998`}, {95.223, 144.364}, {95.16, 
                    144.415}, {94.059, 145.29399999999998`}, {93.137, 
                    144.895}, {92.96900000000001, 143.82100000000003`}, {
                    94.12899999999999, 142.798}, {92.44100000000002, 
                    141.16899999999998`}, {94.062, 141.16899999999998`}, {
                    95.223, 142.286}, {96.383, 141.16899999999998`}, {98.008, 
                    141.16899999999998`}, {96.32, 142.798}, {97.48, 
                    143.82100000000003`}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{82.031, 
                    164.415}, {83.191, 163.298}, {84.35199999999999, 
                    164.415}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    83.191, 160.96200000000002`}, {82.05499999999999, 
                    160.055}, {80.922, 160.548}, {80.715, 161.841}, {
                    81.79700000000001, 162.79399999999998`}, {79.98, 
                    164.548}, {82.184, 164.548}, {83.191, 
                    163.57899999999998`}, {84.195, 164.548}, {86.402, 
                    164.548}, {84.586, 162.79399999999998`}, {85.664, 
                    161.841}, {85.46100000000001, 160.548}, {84.324, 
                    160.055}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0.15686300000000003`, 0.6823529999999999, 0.4], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{81.10199999999999, 160.68800000000002`}, {82.023,
                     160.29}, {83.191, 161.22}, {83.254, 
                    161.16899999999998`}, {84.35499999999999, 160.29}, {
                    85.277, 160.68800000000002`}, {85.44900000000001, 
                    161.762}, {84.285, 162.786}, {85.973, 164.415}, {
                    84.35199999999999, 164.415}, {83.191, 163.298}, {82.031, 
                    164.415}, {80.406, 164.415}, {82.09400000000001, 
                    162.786}, {80.93400000000001, 161.762}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    88.04700000000001, 164.415}, {89.20700000000001, 
                    163.298}, {90.367, 164.415}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    89.20700000000001, 160.96200000000002`}, {88.074, 
                    160.055}, {86.938, 160.548}, {86.73400000000001, 
                    161.841}, {87.812, 162.79399999999998`}, {
                    85.99600000000001, 164.548}, {88.203, 164.548}, {
                    89.20700000000001, 163.57899999999998`}, {90.215, 
                    164.548}, {92.418, 164.548}, {90.60199999999999, 
                    162.79399999999998`}, {91.684, 161.841}, {91.477, 
                    160.548}, {90.34, 160.055}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0.15686300000000003`, 0.6823529999999999, 0.4], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{87.121, 160.68800000000002`}, {88.043, 160.29}, {
                    89.20700000000001, 161.22}, {89.27, 
                    161.16899999999998`}, {90.371, 160.29}, {91.293, 
                    160.68800000000002`}, {91.465, 161.762}, {
                    90.30499999999999, 162.786}, {91.988, 164.415}, {90.367, 
                    164.415}, {89.20700000000001, 163.298}, {
                    88.04700000000001, 164.415}, {86.426, 164.415}, {88.109, 
                    162.786}, {86.94900000000001, 161.762}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{96.383, 
                    164.415}, {95.223, 163.298}, {94.062, 
                    164.415}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    95.223, 160.96200000000002`}, {96.359, 160.055}, {
                    97.49600000000001, 160.548}, {97.699, 161.841}, {96.617, 
                    162.79399999999998`}, {98.43400000000001, 164.548}, {
                    96.23, 164.548}, {95.223, 163.57899999999998`}, {
                    94.21900000000001, 164.548}, {92.016, 164.548}, {
                    93.82799999999999, 162.79399999999998`}, {92.75, 
                    161.841}, {92.953, 160.548}, {94.09, 
                    160.055}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0.15686300000000003`, 0.6823529999999999, 0.4], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{97.312, 160.68800000000002`}, {96.391, 160.29}, {
                    95.223, 161.22}, {95.16, 161.16899999999998`}, {94.059, 
                    160.29}, {93.137, 160.68800000000002`}, {
                    92.96900000000001, 161.762}, {94.12899999999999, 
                    162.786}, {92.44100000000002, 164.415}, {94.062, 
                    164.415}, {95.223, 163.298}, {96.383, 164.415}, {98.008, 
                    164.415}, {96.32, 162.786}, {97.48, 
                    161.762}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    104.738, 158.567}, {104.738, 157.048}, {
                    104.73400000000001`, 157.048}, {103.816, 
                    157.805}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIpIGYC4oWu2z7/vRLpcPPc9+DHd5MdvmnE9B86G+nw
70rFS7WHyQ6WW06U7Zse6bDimLd5509MPli9a6TDqo+XfJO+JDtkTHxbY68a
6eDJw6Tdfg2Tv0YmKsU6PBKib2+yw7MLSrd/xkH5OxHyYPdsReiX1r+rwjYX
kw+zX5WtcapzPcJ9C6SACqow+TD/gd0zKdkB5n+w+FSovGkUxP5cBN8x4ekF
peXJDr3T84SaOaLg7oXJ94HEzyD454Hal/5PdvAC2aMX5SAYAXQJU4pDyOOl
s48IRDmkgcC3ZIcZQG0HPkHd9wrhHlh8AACwN8WQ
                    
                    "]]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0.15686300000000003`, 0.6823529999999999, 0.4], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIZIGYC4jUyUSnW+lEOC6T076pcSnbwSxKIsPwS6fBN
I6b/0M5kB5j8EYUNRRkLEXxpoHK2ymQHkXXuD6uuRDqkpwHBPEy+5ZYTZfum
RzoIRgBZTckOrwN3yLVOjnSw6HRMeNqQ7NB84NRC175Ih4dVQJ2NyQ6b5r5f
fiw40sEcJN+SDHGHL1S+NdlBha1xqrN3pMO578GPl7YnQ9xhGenQOz1PqHlG
skPGxLc19qaRDtOcu3Oez052UAWpt450+PL3SsVLoHvA5hQi/IfOh+nfCHLH
dYT5TglPLyjdRthf+VLNkOMNwn1g/75DuB/s33cI/4Gk0z4h/A+W/4QIH3B4
fECEH9hdVzH5sPDXBVn0K9kBAPEyyhI=
                    "]]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    104.738, 153.555}, {104.738, 152.032}, {
                    104.73400000000001`, 152.032}, {103.816, 
                    152.79}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4oWu2z7/vRLpcERhQ1GGbbLDN42Y/kNnIx0K
bbmuL3ZIdrDccqJs3/RIB2n9uypskZh8sHrXSIdpzt05z4OTHTImvq2xV410
2FsyWYLFDJO/RiYqxTo80uFhlcg6d9lkh2cXlG7/jIPyJRHyYPeIIvSD3fMn
CYMPs18wAuiye0lw9/XkPP+98iYmH+a/PSD3fEpygPkfbP/XJIenIPeYRTmY
dzomPD2D4C+QAnk42aF3ep5QM0cU3L0w+T6QuA6CD7YnNdmh+cCpha5iUQ72
pnG7PCOg4fU10uHL3ysVL72SHdDDHwCGkrqO
                    "]]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0.15686300000000003`, 0.6823529999999999, 0.4], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGI5IGYC4jUyUSnW+lEO3zRi+g8ZJjv4JQlEWH6JdHhY
JbLOXTLZASYvrX9XhY0Rwe+dnifUfCPJAajqYdWVSIeb574HP/6LybfccqJs
3/RIh+YDpxa6PkpyeB24Q651cqTDqo+XfJMeJEHE+yIdQh4vnX0EyN809/3y
Y8FQ+SdJEHf5RjoEg+SBfBW2xqnO3pEOjglPLyg9T4K4yzLSofKlmiHHjySH
jIlva+xNIx04QQ79neSgClJvHengxcOk3f4vCeKvQoT/CPFh+u1N43Z5miTD
zQeLmyfD7dcFOdwqGe6+NyB/eifD3Q8OD99kuP/A/vZLhvsfLB+YDA8fsHhQ
Mjz8wOERkAwPX3B4mGDyYfGzQArosKhkBwC57tdw
                    
                    "]]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    104.738, 147.016}, {104.738, 148.536}, {
                    104.73400000000001`, 148.536}, {103.816, 
                    147.778}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIpIGYC4oWu2z7/vRLpEPx46ewjIUkO3zRi+g+djXRY
cczbvDMwycFyy4myfdMjHf5dqXipZonJB6t3jXRoPnBqoatdkkPGxLc19qqR
DrH9h75qxGDy18hEpViHRzpI699VYStNcnh2Qen2z7hIB/NOx4SnFQj5EJB7
ahD6u3Oe/145FZMPs58DpHEzwn0FtlzXF+/A5MP8FwNyz4IkB5j/wfbPSXJ4
CnKPWZTDwyqRde5HEXyw+3uSHHqn5wk1c0TB3QuTB7snFcG/vhhoozHUf3pR
Due/A0NYPwnib8Eoh8qXaoYcNkkO8bs8eZg+Rzqs+njJN8kD4R5YfAAAHKjI
7g==
                    "]]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0.15686300000000003`, 0.6823529999999999, 0.4], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIZIGYC4jUyUSnW+lEOvdPzhJoTkhz8kgQiLL9EOph3
OiY8rUhygMk/rBJZ5z4Rwe/Jef575c4kB6Dow6orkQ6rPl7yTZqCybfccqJs
3/RIh2nO3TnP1yc5vA7cIdc6OdLhm0ZM/6GNSQ7NB04tdO2LdFhxzNu8E8jf
NPf98mPBUPm1SRDaN9LhiMKGogwgX4Wtcaqzd6TD9cUFtlyrkxyk9e+qsFlG
OiyQAjJmJTlkTHxbY28a6QD0xZYT05IcVEHqrSMh5k5OgvijEOE/dD5MP9j8
aIT5574HP14ajrBfF2SgG8J99qZxuzxdEO4H+9cZ4T+wvAPC/2B5e0T4gM1x
RIQf2L+xmHxY+Fe+VDPksEhyAAAQD8ZG
                    "]]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    73.67999999999999, 158.567}, {73.67999999999999, 
                    157.048}, {74.598, 157.805}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIpIGYCYv27KmyNR4Mcbp77Hvz4brLD7Z91WXvOBDn8
u1LxUu1hssOMPKHmA0zBDiuOeZt3/sTkL3Td9vlvSLDDqo+XfJO+JDtkTHxb
Y18a7ODJw6Tdfg2T/zpwh1yrc7DDN42Y/kN7kx3egPjWUP5OhDzYPVsR+qVB
Dp2LyYfZr8rWONW5HuG+BVJABVWYfJj/wO6ZlOwA8z/Y/qlQ+RRoeOQi+I4J
Ty8oLU92cOnOef57YhDcvTD5vulAi84g+ODwYEhxUAG5KzvI4friAlsu5hQH
oGuvVHQGOehumvt++bdkh2KQh5YHObQcOLXQ9RXCPbD4AAA628bg
                    
                    "]]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0.15686300000000003`, 0.6823529999999999, 0.4], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIZIGYC4teBO+Ras4McFkjp31W5lOzQfODUQtdlQQ7f
NGL6D+1MdoDJH1HYUJSxEMGXBipnq0x22FsyWYLlWJBDehoQzMPkx+/y5GFi
DnYQjLDccqIp2eHpBaXbP9mCHSw6HROeNiQ7+CUJRFjyBDs8rBJZ594IlXcL
djAHybckO9z+WZe1xwcq35rssEYmKsXaP9jh3Pfgx0vbkx22ff57pSIx2KF3
ep5Q84xkh4yJb2vsU4Mdpjl35zyfDVUfH+zwBajsJdA9YHM0g+H+Q+fD9G+c
+375sesI850SQC5D2F/5Us2Q4w3CfWD/vkO4H+zfdwj/gaTTPiH8D5b/hAgf
cHh8QIQf2F1XMfmw8NfdBHTgr2QHAFQuzOI=
                    "]]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    73.67999999999999, 153.555}, {73.67999999999999, 
                    152.032}, {74.598, 152.79}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYCYv27KmyNR4McjihsKMqwTXa4/bMua8+ZIIdC
W67rix2SHWbkCTUfYAp2kAYpjMTkL3Td9vlvSLDDNOfunOfByQ4ZE9/W2JcG
O+wtmSzBYobJfx24Q67VOdjhYZXIOnfZZIc3IL41lC+JkAe7RxShH+yeP0kY
fJj9ghGWW07cS4K7ryfn+e+VNzH5MP/tAbnnU5IDzP9g+78mOQDJh1Up0PA4
i+B78jBpt7MlO7gAvfl7YhDcvTD52P5DXzV0klH1p0LDpyXIofKlmiFHBNQ/
S4McdDfNfb/cK9kBPfwBsn+wQQ==
                    "]]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0.15686300000000003`, 0.6823529999999999, 0.4], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGI5IGYC4teBO+Ras4McvmnE9B8yTHZoPnBqoeuyIIeH
VSLr3CWTHWDy0vp3VdgYEfze6XlCzTeSHPaWTJZgORbkcPPc9+DHfzH58bs8
eZiYgyHmPkpyeHpB6fZPtmCHVR8v+SY9SHLwSxKIsOQJdgh5vHT2kQdQeTeo
/JMkh9s/67L2+AQ7BIPkgfw1MlEp1v7BDo4JQJXPkxy2ff57pSIx2KHypZoh
x48kh4yJb2vsU4MdOEEKf0PVxwc7ePEwabf/S4L4SzMY7j9CfJh+e9O4XZ4m
yXDzVdkapzqbJ8Pt19009/1yq2S4+96Awsk7Ge5+cHj4JsP9Bw4Pv2S4/8Hy
gcnw8AHLByXDww8cHgHJ8PAFh4cJJh8WPwukgBEWlewAAIKx2k0=
                    
                    "]]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    73.67999999999999, 147.016}, {73.67999999999999, 
                    148.536}, {74.598, 147.778}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIpIGYCYv27KmyNR4Mcgh8vnX0kJMnh9s+6rD1nghxW
HPM27wxMcpiRJ9R8gCnY4d+Vipdqlpj8ha7bPv8NCXZoPnBqoatdkkPGxLc1
9qXBDrH9h75qxGDyXwfukGt1DnaQBllcmuTwBsS3DnYw73RMeFqBkA8BuacG
ob875/nvlVMx+TD7OdbIRKVsRrivwJbr+uIdmHyY/2JA7lmQ5ADzP9j+OUkO
IuvcH1alQPlHEPzz34Eh1J3k4AKyeGIQ3L0w+QVSQJPSEHzdTXPfLzdKcgBR
x7KDILR+kgPQtVcqOoMg4WGT5FAM8tDyIIfe6UCHeiDcA4sPAMpDxDI=
                    
                    "]]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0.15686300000000003`, 0.6823529999999999, 0.4], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIZIGYC4teBO+Ras4MceqfnCTUnJDk0Hzi10HVZkIN5
p2PC04okB5j8wyqRde4TEfyenOe/V+5McthbMlmC5ViQw6qPl3yTpmDy43d5
8jAxBztMc+7Oeb4+yeHpBaXbP9mCHb5pxPQf2pjk4JckEGHJE+yw4pi3eedG
qLwbVH5tksPtn3VZe3yCHY4obCjKAPLXyESlWPsHO1xfXGDLtTrJYdvnv1cq
EoMdFkjp31WZleSQMfFtjX1qsAPQ1C0npkHVxwc7bJr7fvmxyUkQf2gGw/2H
zofpB5sfjTD/3Pfgx0vDEfbrggx0Q7jP3jRul6cLwv1g/zoj/AeWd0D4Hyxv
jwgfsH8dEeEH9m8sJh8W/pUv1Qw5LJIcAHL8yRY=
                    
                    "]]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIRIGYCYk8eJu32aeEOXiB6VZIDjL9p7vvlxx4nOci1
vg7cYRaBwf/y90rFS79kuHp0vr1p3C7PjmSHGXlCzQeUMPnXFxfYch1PdrDc
cqJsX3koBh+mvl3s5rnvzJh8mH1gdyWHYPBh7oWpR+fD/AuzD51//nvw46XZ
SXD3ovNh6gHRGpUg
                    "]]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{84.262, 154.266}, {84.262, 156.055}, {86.074, 
                    156.055}, {86.074, 158.016}, {89.10499999999999, 
                    158.016}, {89.10499999999999, 155.993}, {86.238, 
                    154.364}, {86.238, 152.89100000000002`}, {81.762, 
                    152.89100000000002`}, {81.762, 154.266}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{94.15199999999999, 151.32100000000003`}, {
                    94.15199999999999, 149.52800000000002`}, {92.34, 
                    149.52800000000002`}, {92.34, 147.567}, {89.309, 
                    147.567}, {89.309, 149.591}, {92.17599999999999, 
                    151.22}, {92.17599999999999, 152.692}, {96.65199999999999,
                     152.692}, {96.65199999999999, 
                    151.32100000000003`}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{94.15199999999999, 156.055}, {94.15199999999999, 
                    154.266}, {96.65199999999999, 154.266}, {
                    96.65199999999999, 152.89100000000002`}, {
                    92.17599999999999, 152.89100000000002`}, {
                    92.17599999999999, 154.364}, {89.309, 155.993}, {89.309, 
                    158.016}, {92.34, 158.016}, {92.34, 156.055}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{86.074, 149.52800000000002`}, {84.262, 
                    149.52800000000002`}, {84.262, 151.32100000000003`}, {
                    81.762, 151.32100000000003`}, {81.762, 152.692}, {86.238, 
                    152.692}, {86.238, 151.22}, {89.10499999999999, 
                    149.591}, {89.10499999999999, 147.567}, {86.074, 
                    147.567}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    86.44100000000002, 152.692}, {86.44100000000002, 
                    151.329}, {89.10499999999999, 149.813}, {
                    89.10499999999999, 152.692}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0.15686300000000003`, 0.6823529999999999, 0.4], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    89.10499999999999, 155.76999999999998`}, {
                    86.44100000000002, 154.259}, {86.44100000000002, 
                    152.895}, {89.10499999999999, 152.895}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    91.973, 152.895}, {91.973, 154.259}, {89.309, 
                    155.76999999999998`}, {89.309, 152.895}}}]}}}}}}}, {{{{{{{
                    
                    FaceForm[{
                    RGBColor[0.15686300000000003`, 0.6823529999999999, 0.4], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    89.309, 149.813}, {91.973, 151.329}, {91.973, 152.692}, {
                    89.309, 152.692}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxlk1soRFEUhseMJCkltyRFiKR48CBhF5qkCXPmOIw5o8SDEh7klmia5EGS
JEoUkhSe5FYkJHmQpDRJroUkSUhM2WfrX2XOqf3wtfblX//6T1xNk7XOZDAY
/PjK5cvI12bLcJR/bimbfJnbLy5RGdhem31Z8lzFVt+8p+0ei47zMp0bRQt2
djhVuPKWVqxj7/zriSVaof2+fN0ZtmT2yPSeLws9bTY2MNoY6g6UiQ3adyWz
h29+4bv0V2+XmSZvYFViiQGukfxdiTj9IiHANSExTV7wjcS6NKEpMnFBf8P9
97qN7b4nOwattr/zbitxX4Tn6NMtsbOZ5pwgs8Sylg9at0Zl4vqh5648Sznr
eEzKCFyW2BiXs21UqF4UbEzti6gkXojhTkba6X6h/0ohtt3Oju81K6Rvmtvp
/akgFufPKqg/oT9OIT6JP//q3ignf0R9SCH/wpfM150Oh47h/weXsbOo6hjz
eypbi+01VesY88d+X0Z+8J4vI3//9HJGP8KXY5X6FX6GOMkPMPzSxth/p5Kf
YPgtDG1RaR5gzKtO87PHSfMEY95iXqFOygPqyAsYecL9yBsYeYQ+5BWMPKM/
5B2M/wH+/PtfuH+/A1q+Rg==
                    "]]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGI7IGYC4pDHS2cfWRDrMO/98mPe86Mc5FpfB+74Foed
rx7ugKIeid984NRC12ehDsUZE9/W+Mdg8B1M43Z5toQ4ePEwabf3hcP5D6tE
1rkvDHN48Xvlx0tfgyHycuEOh75qxPSvCnbIBGq3vxsB59faAzVKRjpcX1xg
y/U+2MFqy4myff3hcP43oLJDT8MdFDcUZUx0DXGQ1r+rwvYzEpUvGOlQ+VLN
kCMk2METZB9bOJwPts83zEHs5rnvwYeDHdpBjMmhcPltn/9eqegMRuUvDIKb
f/tnXdaeLSFw/vQ8oeYDXKFw94HDqyEYzgfbtzcY7j+wuTWhcD44fH6GwsOn
AiTPEwoPv9hdQB94B2DwYeH/C+icks++GHxY/KVY3/fvdffGzgfGP4p6JP4O
UMJ4EA23D53/B+hcX6dYuHthfJh/wOFwIRbuXzAtEwcPDxgfFl5gd12PhYcn
jA8Lb3C8NsbC4wOFD4yvw6DwLIqDxyeMjxLfzHHw9ACTh6UXFD4wPcHMh6U3
GB+WHmHug6VXGB+WnmH+g6V3GB+WH2DhA8svsPCD5Sd0Piz8YfkRxgcAsCzF
DA==
                    "]]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIpIGYC4syJb2vsfcMcdsi1vg7UCHFw6c55/ntnuMPr
QKAIc6jDcW/zTscL0Rj8qBTr+/6pYQ7bPv+9UqEYi8H35GHSbl8W7lCcAbSg
PA6DD7ZPIQquHp3/sEpknXtiNNw+dH5A7/Q8ocMxcPfC+DD/NB84tdB1XqwD
SLj5QQhcnuv64gLbUwEYfJj5pnG7PHk++WHwYe7bUzJZgsXNB4MP8x9MPTof
Fj4w+9D5sPCFuRfGBwBbbLNz
                    "]]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIpIGYCYlW2xqnOh6Md/qz8eMm3KMwBxt8h1/o6UCDU
wZOHSbt9WzicnznxbY29b5jDvPfLj3mbhzi0i9089/1xCFz+6QWl2z+vBWDw
Yea/CQTKcPtj8EHGBG8Od2AAgQQf7HzhKFT1SHwH07hdniHRcPvQ+c0HTi10
3RYDdy+Mj+Kf/li4f2HysPBA58PMv/2zLmuPSCwGH+a+i0ogkTjsfKD/UNQj
8WHhAwAvx8Mv
                    "]]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIpIGYC4syJb2vsfcMcdNrFbp7rD3HY9vnvlYqF4Q4O
pnG7PGNCHYozgArKozH469wfVonsC3MIebx09pETMRj8ee+XH/P+H+4g3/o6
cIdcHHb+8UhU9Uj8+qw9JZM5ouH2ofP/rPx4yTcrBu5eGB/mH4EIyy0nzGId
pPXvqrD9DIHLx+/y5GFSDsTgw8z/VQdkLPbH4MPcl2J937/3uw92PtB/KOqR
+LDwgdmHzoeFL8y9MD4Agr3JpQ==
                    "]]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0.15686300000000003`, 0.6823529999999999, 0.4], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIpIGYC4otKt3/WZUU7+PdOzxM6HeYA40vr31Vhywx1
2FsyWYJlXjicnznxbY29b5iDYITllhPzQhxE17k/rPoTApdnAAGDQAw+zHyg
aWF8e/0x+BUv1Qw5eCIcVhzzNu8U9MXgH/6qEdO/KxKuHp3/JnCHXOvvKLh9
6HzFDUUZE2Nj4O6F8WH+0WoXu3lOPRbuX5g8LDzQ+TDzK0Hu3BODwYe5r9be
NG6XYBwGH+Y/mHp0Pix8AIvmoTA=
                    "]]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    70.738, 93.11}, {70.738, 87.759}, {79.09400000000001, 
                    87.759}, {70.738, 93.30199999999999}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    70.94100000000002, 92.923}, {78.422, 87.962}, {
                    70.94100000000002, 87.962}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4jUyUSnWy8MdpPXvqrAlhjvA+J8u+SYJCEQ4
vA7cIdeajeBnTnxbY+8b5hDQOz1P6HCEQ429adwuzzCHkMdLZx85EOHw7ILS
7Z96oXD1qmyNU50/h2DwYfZt+/z3SoUnJh/oivv+S8Pg6tH5zQdOLXT9Fgq3
D8aHuU/s5rnvwc6hcPfD5GH+Q+fDzAe7IzACgw9zHwAveoMP
                    
                    "]]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1,
                     0}}}, {{{89.20700000000001, 98.809}, {93.29700000000001, 
                    96.251}, {85.117, 96.251}}, {{93.29700000000001, 
                    87.848}, {89.20700000000001, 85.29}, {85.117, 
                    87.848}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    94.41000000000001, 90.583}, {94.41000000000001, 
                    88.05199999999999}, {89.309, 88.05199999999999}, {89.309, 
                    90.583}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    89.10499999999999, 90.583}, {89.10499999999999, 
                    88.05199999999999}, {84.004, 88.05199999999999}, {84.004, 
                    90.583}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    97.062, 93.31700000000001}, {97.062, 90.786}, {
                    91.96100000000001, 90.786}, {91.96100000000001, 
                    93.31700000000001}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    91.758, 93.31700000000001}, {91.758, 90.786}, {
                    86.65599999999999, 90.786}, {86.65599999999999, 
                    93.31700000000001}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    86.453, 93.31700000000001}, {86.453, 90.786}, {
                    81.35199999999999, 90.786}, {81.35199999999999, 
                    93.31700000000001}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    94.41000000000001, 96.048}, {94.41000000000001, 93.516}, {
                    89.309, 93.516}, {89.309, 96.048}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    89.10499999999999, 96.048}, {89.10499999999999, 93.516}, {
                    84.004, 93.516}, {84.004, 96.048}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4odVIuvcI0McwLRjpAOMv0Ou9XXgh0gHg7sq
bI2yCP4amagU6/9BDgG90/OEFkc5VL5UM+T4E+QgrQ9UuDAKQj8MhKsHcRuX
YvJh9skDhXfIYfKBttz3b42Aq0fne/IwabdfC4fbB+PD3AcypVU5HO5+mDzM
f+h8mPl7SyZLsKiFYvBh7gMAHJ14OA==
                    "]]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1,
                     0}}}, {{{75.988, 106.309}, {80.082, 103.755}, {71.898, 
                    103.755}}, {{80.07799999999999, 95.35199999999999}, {
                    75.988, 92.79400000000001}, {71.898, 
                    95.35199999999999}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    81.191, 98.083}, {81.191, 95.55199999999999}, {76.09, 
                    95.55199999999999}, {76.09, 98.083}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    75.887, 98.083}, {75.887, 95.55199999999999}, {70.785, 
                    95.55199999999999}, {70.785, 98.083}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    84.395, 100.81700000000001`}, {84.395, 98.286}, {79.293, 
                    98.286}, {79.293, 100.81700000000001`}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    79.09, 100.81700000000001`}, {79.09, 98.286}, {73.988, 
                    98.286}, {73.988, 100.81700000000001`}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    73.785, 100.81700000000001`}, {73.785, 98.286}, {68.684, 
                    98.286}, {68.684, 100.81700000000001`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    81.191, 103.55199999999999`}, {81.191, 101.02}, {76.09, 
                    101.02}, {76.09, 103.55199999999999`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    75.887, 103.55199999999999`}, {75.887, 101.02}, {70.785, 
                    101.02}, {70.785, 103.55199999999999`}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4odVIuvcHSMcIHSkA4y/Q671deCHSIdFrts+
/61B8FXZGqc6z450COidnie0OMrBi4dJu31epIO0/l0VtoVRDkDVVyp2RsHV
LwTp/4LJh9m3ee775ceqozH4USnW9/1bI+Dq0fmeIHuvhcPtg/Fh7nsdCLRR
ORzufpg8zH/ofJj5QN7DqpJwDD7MfQD7y4xs
                    "]]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1,
                     0}}}, {{{102.426, 106.309}, {98.332, 103.755}, {106.516, 
                    103.755}}, {{98.336, 95.35199999999999}, {102.426, 
                    92.79400000000001}, {106.516, 
                    95.35199999999999}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    97.223, 98.083}, {97.223, 95.55199999999999}, {102.324, 
                    95.55199999999999}, {102.324, 98.083}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    102.527, 98.083}, {102.527, 95.55199999999999}, {
                    107.62899999999999`, 95.55199999999999}, {
                    107.62899999999999`, 98.083}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    94.02, 100.81700000000001`}, {94.02, 98.286}, {99.121, 
                    98.286}, {99.121, 100.81700000000001`}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    99.324, 100.81700000000001`}, {99.324, 98.286}, {104.426, 
                    98.286}, {104.426, 100.81700000000001`}}}]}}}}}}}, {{{{{{{
                    
                    FaceForm[{
                    RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    104.62899999999999`, 100.81700000000001`}, {
                    104.62899999999999`, 98.286}, {109.73, 98.286}, {109.73, 
                    100.81700000000001`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    97.223, 103.55199999999999`}, {97.223, 101.02}, {102.324, 
                    101.02}, {102.324, 103.55199999999999`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    102.527, 103.55199999999999`}, {102.527, 101.02}, {
                    107.62899999999999`, 101.02}, {107.62899999999999`, 
                    103.55199999999999`}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4jUyUSnWy8MdFDcUZUxMjXKA8T15mLTbt0U6
vA7cIdeajeBnTnxbY+8bBhFnjnSosTeN2+UZ5vDi98qPl1gjHZ5dULr9Uy8U
rl6VrXGq8+cQDD7Mvm2f/16p8MTkP6wSWeeuGA1Xj84H2v468EI03D4YH+Y+
sZvnvgc3x8DdD5OH+Q+dDzNfWv+uCltgBAYf5j4Ayk2BGA==
                    
                    "]]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1,
                     0}}}, {{{89.20700000000001, 100.29400000000001`}, {
                    93.29700000000001, 102.85199999999999`}, {85.117, 
                    102.85199999999999`}}, {{93.29700000000001, 111.255}, {
                    89.20700000000001, 113.813}, {85.117, 
                    111.255}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    94.41000000000001, 108.52}, {94.41000000000001, 
                    111.05199999999999`}, {89.309, 111.05199999999999`}, {
                    89.309, 108.52}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    89.10499999999999, 108.52}, {89.10499999999999, 
                    111.05199999999999`}, {84.004, 111.05199999999999`}, {
                    84.004, 108.52}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    97.062, 105.79}, {97.062, 108.321}, {91.96100000000001, 
                    108.321}, {91.96100000000001, 105.79}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    91.758, 105.79}, {91.758, 108.321}, {86.65599999999999, 
                    108.321}, {86.65599999999999, 105.79}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    86.453, 105.79}, {86.453, 108.321}, {81.35199999999999, 
                    108.321}, {81.35199999999999, 105.79}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    94.41000000000001, 103.05499999999999`}, {
                    94.41000000000001, 105.587}, {89.309, 105.587}, {89.309, 
                    103.05499999999999`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    89.10499999999999, 103.05499999999999`}, {
                    89.10499999999999, 105.587}, {84.004, 105.587}, {84.004, 
                    103.05499999999999`}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    70.738, 105.99300000000001`}, {70.738, 111.345}, {
                    79.09400000000001, 111.345}, {70.738, 
                    105.80499999999999`}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}}}, {{{
                    70.94100000000002, 106.17999999999999`}, {71.23, 
                    106.37599999999999`}, {77.91000000000001, 
                    110.80499999999999`}, {78.422, 111.141}, {
                    70.94100000000002, 111.141}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    107.67599999999999`, 93.11}, {107.67599999999999`, 
                    87.759}, {99.32, 87.759}, {107.67599999999999`, 
                    93.30199999999999}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}}}, {{{107.473, 
                    92.923}, {107.184, 92.73100000000001}, {100.504, 
                    88.298}, {99.992, 87.962}, {107.473, 
                    87.962}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    107.67599999999999`, 105.99300000000001`}, {
                    107.67599999999999`, 111.345}, {99.32, 111.345}, {
                    107.67599999999999`, 
                    105.80499999999999`}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}}}, {{{107.473, 
                    106.17999999999999`}, {107.184, 106.37599999999999`}, {
                    100.504, 110.80499999999999`}, {99.992, 111.141}, {
                    107.473, 111.141}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    72.37899999999999, 100.255}, {72.37899999999999, 
                    98.848}, {70.09, 98.848}, {70.09, 
                    100.255}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    70.30499999999999, 100.04}, {72.16399999999999, 100.04}, {
                    72.16399999999999, 99.063}, {70.30499999999999, 
                    99.063}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    74.48400000000001, 102.989}, {74.48400000000001, 
                    101.583}, {72.191, 101.583}, {72.191, 
                    102.989}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    72.406, 102.774}, {74.265, 102.774}, {74.265, 101.797}, {
                    72.406, 101.797}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    79.785, 102.989}, {79.785, 101.583}, {77.49600000000001, 
                    101.583}, {77.49600000000001, 102.989}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    77.71100000000001, 102.774}, {79.57000000000001, 
                    102.774}, {79.57000000000001, 101.797}, {
                    77.71100000000001, 101.797}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    77.684, 100.255}, {77.684, 98.848}, {75.395, 98.848}, {
                    75.395, 100.255}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    75.609, 100.04}, {77.46799999999999, 100.04}, {
                    77.46799999999999, 99.063}, {75.609, 
                    99.063}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    82.988, 100.255}, {82.988, 98.848}, {80.695, 98.848}, {
                    80.695, 100.255}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    80.91400000000002, 100.04}, {82.77300000000001, 100.04}, {
                    82.77300000000001, 99.063}, {80.91400000000002, 
                    99.063}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    79.785, 97.52}, {79.785, 96.114}, {77.49600000000001, 
                    96.114}, {77.49600000000001, 97.52}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    77.71100000000001, 97.30499999999999}, {79.57000000000001,
                     97.30499999999999}, {79.57000000000001, 96.332}, {
                    77.71100000000001, 96.332}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    74.48400000000001, 97.52}, {74.48400000000001, 96.114}, {
                    72.191, 96.114}, {72.191, 97.52}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    72.406, 97.30499999999999}, {74.265, 97.30499999999999}, {
                    74.265, 96.332}, {72.406, 96.332}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    87.699, 110.489}, {87.699, 109.083}, {85.41000000000001, 
                    109.083}, {85.41000000000001, 110.489}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    85.62499999999999, 110.274}, {87.48399999999998, 
                    110.274}, {87.48399999999998, 109.301}, {
                    85.62499999999999, 109.301}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    93.004, 110.489}, {93.004, 109.083}, {90.715, 109.083}, {
                    90.715, 110.489}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    90.93, 110.274}, {92.789, 110.274}, {92.789, 109.301}, {
                    90.93, 109.301}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    85.051, 107.759}, {85.051, 106.35199999999999`}, {82.758, 
                    106.35199999999999`}, {82.758, 107.759}}}]}}}}}}}, {{{{{{{
                    
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    82.973, 107.54}, {84.832, 107.54}, {84.832, 
                    106.56700000000001`}, {82.973, 
                    106.56700000000001`}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    90.35199999999999, 107.759}, {90.35199999999999, 
                    106.35199999999999`}, {88.062, 106.35199999999999`}, {
                    88.062, 107.759}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    88.277, 107.54}, {90.136, 107.54}, {90.136, 
                    106.56700000000001`}, {88.277, 
                    106.56700000000001`}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    95.65599999999999, 107.759}, {95.65599999999999, 
                    106.35199999999999`}, {93.363, 106.35199999999999`}, {
                    93.363, 107.759}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    93.582, 107.54}, {95.44099999999999, 107.54}, {
                    95.44099999999999, 106.56700000000001`}, {93.582, 
                    106.56700000000001`}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    87.699, 105.024}, {87.699, 103.618}, {85.41000000000001, 
                    103.618}, {85.41000000000001, 105.024}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    85.62499999999999, 104.809}, {87.48399999999998, 
                    104.809}, {87.48399999999998, 103.832}, {
                    85.62499999999999, 103.832}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    93.004, 105.024}, {93.004, 103.618}, {90.715, 103.618}, {
                    90.715, 105.024}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    90.93, 104.809}, {92.789, 104.809}, {92.789, 103.832}, {
                    90.93, 103.832}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    100.918, 102.989}, {100.918, 101.583}, {98.62899999999999,
                     101.583}, {98.62899999999999, 102.989}}}]}}}}}}}, {{{{{{{
                    
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    98.84400000000001, 102.774}, {100.703, 102.774}, {100.703,
                     101.797}, {98.84400000000001, 101.797}}}]}}}}}}}, {{{{{{{
                    
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    106.223, 102.989}, {106.223, 101.583}, {103.93, 
                    101.583}, {103.93, 102.989}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    104.148, 102.774}, {106.00699999999999`, 102.774}, {
                    106.00699999999999`, 101.797}, {104.148, 
                    101.797}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    97.71900000000001, 100.255}, {97.71900000000001, 
                    98.848}, {95.426, 98.848}, {95.426, 
                    100.255}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    95.641, 100.04}, {97.5, 100.04}, {97.5, 99.063}, {95.641, 
                    99.063}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    103.02, 100.255}, {103.02, 98.848}, {100.73, 98.848}, {
                    100.73, 100.255}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    100.94500000000001`, 100.04}, {102.804, 100.04}, {102.804,
                     99.063}, {100.94500000000001`, 99.063}}}]}}}}}}}, {{{{{{{
                    
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    108.324, 100.255}, {108.324, 98.848}, {106.035, 98.848}, {
                    106.035, 100.255}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    106.25, 100.04}, {108.109, 100.04}, {108.109, 99.063}, {
                    106.25, 99.063}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    100.918, 97.52}, {100.918, 96.114}, {98.62899999999999, 
                    96.114}, {98.62899999999999, 97.52}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    98.84400000000001, 97.30499999999999}, {100.703, 
                    97.30499999999999}, {100.703, 96.332}, {98.84400000000001,
                     96.332}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    106.223, 97.52}, {106.223, 96.114}, {103.93, 96.114}, {
                    103.93, 97.52}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    104.148, 97.30499999999999}, {106.00699999999999`, 
                    97.30499999999999}, {106.00699999999999`, 96.332}, {
                    104.148, 96.332}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    87.699, 95.485}, {87.699, 94.079}, {85.41000000000001, 
                    94.079}, {85.41000000000001, 95.485}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    85.62499999999999, 95.27}, {87.48399999999998, 95.27}, {
                    87.48399999999998, 94.297}, {85.62499999999999, 
                    94.297}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    93.004, 95.485}, {93.004, 94.079}, {90.715, 94.079}, {
                    90.715, 95.485}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    90.93, 95.27}, {92.789, 95.27}, {92.789, 94.297}, {90.93, 
                    94.297}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    85.051, 92.755}, {85.051, 91.348}, {82.758, 91.348}, {
                    82.758, 92.755}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    82.973, 92.536}, {84.832, 92.536}, {84.832, 91.563}, {
                    82.973, 91.563}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    90.35199999999999, 92.755}, {90.35199999999999, 91.348}, {
                    88.062, 91.348}, {88.062, 92.755}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    88.277, 92.536}, {90.136, 92.536}, {90.136, 91.563}, {
                    88.277, 91.563}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    95.65599999999999, 92.755}, {95.65599999999999, 91.348}, {
                    93.363, 91.348}, {93.363, 92.755}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    93.582, 92.536}, {95.44099999999999, 92.536}, {
                    95.44099999999999, 91.563}, {93.582, 
                    91.563}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    87.699, 90.02}, {87.699, 88.614}, {85.41000000000001, 
                    88.614}, {85.41000000000001, 90.02}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    85.62499999999999, 89.80499999999999}, {87.48399999999998,
                     89.80499999999999}, {87.48399999999998, 
                    88.82799999999999}, {85.62499999999999, 
                    88.82799999999999}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    93.004, 90.02}, {93.004, 88.614}, {90.715, 88.614}, {
                    90.715, 90.02}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    90.93, 89.80499999999999}, {92.789, 89.80499999999999}, {
                    92.789, 88.82799999999999}, {90.93, 
                    88.82799999999999}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    118.15199999999999`, 40.345}, {98.301, 29.661}, {80.113, 
                    29.661}, {60.26200000000001, 40.345}, {60.26200000000001, 
                    57.946}, {80.113, 68.62599999999999}, {98.301, 
                    68.62599999999999}, {118.15199999999999`, 
                    57.946}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0.15686300000000003`, 0.6823529999999999, 0.4], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{98.25, 
                    29.864}, {117.94900000000001`, 40.466}, {
                    117.94900000000001`, 57.825}, {98.25, 68.423}, {80.164, 
                    68.423}, {60.465, 57.825}, {60.465, 40.466}, {80.164, 
                    29.864}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    116.54700000000001`, 41.312999999999995`}, {97.898, 
                    31.278}, {80.516, 31.278}, {61.867, 
                    41.312999999999995`}, {61.867, 56.977}, {80.516, 
                    67.012}, {97.898, 67.012}, {116.54700000000001`, 
                    56.977}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{116.34400000000001`, 41.434}, {
                    116.34400000000001`, 49.044}, {89.309, 49.044}, {89.309, 
                    31.480999999999998`}, {97.848, 31.480999999999998`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{62.07, 49.247}, {89.10499999999999, 49.247}, {
                    89.10499999999999, 66.809}, {80.566, 66.809}, {62.07, 
                    56.855999999999995`}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{80.566, 31.480999999999998`}, {89.10499999999999,
                     31.480999999999998`}, {89.10499999999999, 49.044}, {
                    62.07, 49.044}, {62.07, 41.434}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{116.34400000000001`, 56.855999999999995`}, {
                    97.848, 66.809}, {89.309, 66.809}, {89.309, 49.247}, {
                    116.34400000000001`, 49.247}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGI5IGYC4qcXlG7/LItwWCClf1eFzdUhfpcnD5NyuIPu
prnvl4c5w/n3VNgapzY7Orh05zz/zRjhAOQ5d9s4OBRnTHxbsz0Mg7/O/WGV
yDknh0wg1943zOH64gJbLncniHmPQ+HyMD5Mf+/0PKHmGSGo5pWHwu2H8WHu
UwUpVA6Bu/+bRkz/IdNgDP7Jsn3zpeR94OphfJh51vf9e6ef84Xz/12peKm2
0B/unsqXaoYcJQFw96Lzwf4L94P7V3FDUcbEu37w8IDJw/gw/bDwRDEPGN4w
+2F8mPtg8QVz/+2fdVl7UiIx+DD/AwAX3Mlr
                    "]]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{97.801, 56.04}, {92.34400000000001, 59.501}, {
                    92.34400000000001, 63.36}, {95.41400000000002, 65.61}, {
                    91.07, 65.61}, {91.07, 60.309}, {89.309, 61.427}, {89.309,
                     49.247}, {101.371, 49.247}, {101.371, 56.04}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{80.609, 42.251}, {86.07, 38.786}, {86.07, 
                    34.927}, {83., 32.67700000000001}, {87.34400000000001, 
                    32.67700000000001}, {87.34400000000001, 37.977}, {
                    89.10499999999999, 36.86}, {89.10499999999999, 49.044}, {
                    77.039, 49.044}, {77.039, 42.251}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{91.07, 32.67700000000001}, {95.41400000000002, 
                    32.67700000000001}, {92.34400000000001, 34.927}, {
                    92.34400000000001, 38.786}, {97.801, 42.251}, {101.371, 
                    42.251}, {101.371, 49.044}, {89.309, 49.044}, {89.309, 
                    36.86}, {91.07, 37.977}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{86.07, 59.501}, {80.609, 56.04}, {77.039, 
                    56.04}, {77.039, 49.247}, {89.10499999999999, 49.247}, {
                    89.10499999999999, 61.43}, {87.34400000000001, 60.309}, {
                    87.34400000000001, 65.61}, {83., 65.61}, {86.07, 
                    63.36}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}}}, {{{97.43400000000001, 54.755}, {100.098, 
                    54.755}, {100.098, 43.532000000000004`}, {
                    97.43400000000001, 43.532000000000004`}, {
                    89.20700000000001, 38.312999999999995`}, {80.98, 
                    43.532000000000004`}, {78.316, 43.532000000000004`}, {
                    78.316, 54.755}, {80.98, 54.755}, {89.20700000000001, 
                    59.973}, {89.262, 59.942}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}}}, {{{97.37499999999999, 54.552}, {
                    89.20700000000001, 59.73500000000001}, {81.039, 54.552}, {
                    78.52, 54.552}, {78.52, 43.73500000000001}, {81.039, 
                    43.73500000000001}, {89.20700000000001, 38.552}, {
                    97.37499999999999, 43.73500000000001}, {99.895, 
                    43.73500000000001}, {99.895, 54.552}, {97.406, 
                    54.552}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIPIGYC4uKMiW9rroc5zJoJBJreDij8k14O7WI3z30X
DsfO5/Ry+A8C5WHY+S+9HbivLy6wvRWOwT//Pfjx0tleDs0HTi10bYvA4C8/
5m3eudHDYUaeUPOBS+HY+YWeDnKtrwN3qEVg8MHm3fZ0eHpB6fbPbeFw/sMq
kXXuK8McDn/ViOmf5AGXB7vP0x2uH50f0Ds9T2izO9x+rPxiD7j70flg8zrd
UMMDie+UAHSJtSs8/LDypd3h4Y+VH+0Gjz+s/N+uEPdWhWPwIf5xc8gEKrf3
DXMwi9vlyaPk4WC15UTZPvlQuDyMDw5PoP54oDKmw5h8mP1AnnZ7GyYfrB7o
/ovA4K9TCsPgw/x/HBitjgdCMPiw8PNLEoiwFMHkw8LfEuTe4zj4wPjbNPf9
8mPFmHxY/KuyNU51fozgg9PPx1B4+oHJw9IXTD86H5Y+YfZj5QPTN8z96HxY
/oD5H50Py1+w8MPKB+ZPWPhj5QPzNyz+sPKB5QMs/tH5pqD0UuQFTz/g8GHy
hKcvmDyMD9MPAIz0HZY=
                    "]]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIPIGYCYrnW14E70kIcpkiwhPGddXeYkSfUfGAXJp+X
SbtdLNLD4WGVyDp3RUx+QO/0PKHFbg6ZE9/W2J/F5LcBrZELdXXQv6vC1iga
hsFfcczbvJPR3QEk3Do5FIMPcqZcqZuD1ZYTZfvOY/JXgtQ/dIW4VwiTDzbv
INQ9vmEOhbZc1xc7eDhYgvS3h8PlYXyY/otKt3/WnQrD4MPsf3oBKMAWjsGH
uX+h67bPf1vCMPgw/0PCJxyDDws/cPhWRmDwYeEP9v/9cAw+LP42zX2//Jhx
BAY/jE9301x9aPhuDofzjwOd6TghzOHwV42Y/kkecHmw/756wvWj8z9d8k0S
iPCE24/OP/89+PHS0x5w96PzweHT6AX3Pzo/HOS+897w8EPn3wMmo6nKXvDw
R+eD/bfeCx5/6HywemdvePxj5Sd7wdNP9p6SyRJPPODpCyaPwgfqh6VPdD7M
flj6RufD3A/LH+h8mP9h+QudDws/WP5E58PCH5a/0fmw+IOVD+h8WPyDw/cZ
gu/cnfP8Nyci/cDkYekLph/GBwDIKwPE
                    "]]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{107.613, 48.255}, {107.613,
                     46.294000000000004`}, {109.992, 46.294000000000004`}, {
                    109.992, 48.255}, {112.35499999999999`, 48.255}, {
                    112.35499999999999`, 42.704}, {109.992, 42.704}, {109.992,
                     44.665000000000006`}, {107.613, 44.665000000000006`}, {
                    107.613, 42.704}, {105.25, 42.704}, {105.25, 48.255}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{99.16, 
                    40.88399999999999}, {99.16, 38.923}, {101.539, 38.923}, {
                    101.539, 40.88399999999999}, {103.902, 
                    40.88399999999999}, {103.902, 35.333}, {101.539, 
                    35.333}, {101.539, 37.294000000000004`}, {99.16, 
                    37.294000000000004`}, {99.16, 35.333}, {96.79700000000001,
                     35.333}, {96.79700000000001, 40.88399999999999}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{107.613, 50.036}, {107.613,
                     51.997}, {109.992, 51.997}, {109.992, 50.036}, {
                    112.35499999999999`, 50.036}, {112.35499999999999`, 
                    55.586999999999996`}, {109.992, 55.586999999999996`}, {
                    109.992, 53.626000000000005`}, {107.613, 
                    53.626000000000005`}, {107.613, 55.586999999999996`}, {
                    105.25, 55.586999999999996`}, {105.25, 50.036}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{70.801, 48.255}, {70.801, 
                    46.294000000000004`}, {68.422, 46.294000000000004`}, {
                    68.422, 48.255}, {66.059, 48.255}, {66.059, 42.704}, {
                    68.422, 42.704}, {68.422, 44.665000000000006`}, {70.801, 
                    44.665000000000006`}, {70.801, 42.704}, {73.164, 
                    42.704}, {73.164, 48.255}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{70.801, 50.036}, {70.801, 
                    51.997}, {68.422, 51.997}, {68.422, 50.036}, {66.059, 
                    50.036}, {66.059, 55.586999999999996`}, {68.422, 
                    55.586999999999996`}, {68.422, 53.626000000000005`}, {
                    70.801, 53.626000000000005`}, {70.801, 
                    55.586999999999996`}, {73.164, 55.586999999999996`}, {
                    73.164, 50.036}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{99.16, 57.403}, {99.16, 
                    59.364}, {101.539, 59.364}, {101.539, 57.403}, {103.902, 
                    57.403}, {103.902, 62.958}, {101.539, 62.958}, {101.539, 
                    60.997}, {99.16, 60.997}, {99.16, 62.958}, {
                    96.79700000000001, 62.958}, {96.79700000000001, 
                    57.403}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{79.254, 
                    40.88399999999999}, {79.254, 38.923}, {76.87499999999999, 
                    38.923}, {76.87499999999999, 40.88399999999999}, {74.512, 
                    40.88399999999999}, {74.512, 35.333}, {76.87499999999999, 
                    35.333}, {76.87499999999999, 37.294000000000004`}, {
                    79.254, 37.294000000000004`}, {79.254, 35.333}, {81.617, 
                    35.333}, {81.617, 40.88399999999999}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{79.254, 57.403}, {79.254, 
                    59.364}, {76.87499999999999, 59.364}, {76.87499999999999, 
                    57.403}, {74.512, 57.403}, {74.512, 62.958}, {
                    76.87499999999999, 62.958}, {76.87499999999999, 60.997}, {
                    79.254, 60.997}, {79.254, 62.958}, {81.617, 62.958}, {
                    81.617, 57.403}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{105.453, 48.052}, {105.453,
                     42.907}, {107.41000000000001`, 42.907}, {
                    107.41000000000001`, 44.864}, {110.195, 44.864}, {110.195,
                     42.907}, {112.15199999999999`, 42.907}, {
                    112.15199999999999`, 48.052}, {110.195, 48.052}, {110.195,
                     46.091}, {107.41000000000001`, 46.091}, {
                    107.41000000000001`, 48.052}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{97., 40.68}, {97., 
                    35.536}, {98.95700000000001, 35.536}, {98.95700000000001, 
                    37.497}, {101.742, 37.497}, {101.742, 35.536}, {103.699, 
                    35.536}, {103.699, 40.68}, {101.742, 40.68}, {101.742, 
                    38.720000000000006`}, {98.95700000000001, 
                    38.720000000000006`}, {98.95700000000001, 40.68}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{105.453, 
                    50.23500000000001}, {105.453, 55.38399999999999}, {
                    107.41000000000001`, 55.38399999999999}, {
                    107.41000000000001`, 53.423}, {110.195, 53.423}, {110.195,
                     55.38399999999999}, {112.15199999999999`, 
                    55.38399999999999}, {112.15199999999999`, 
                    50.23500000000001}, {110.195, 50.23500000000001}, {
                    110.195, 52.196000000000005`}, {107.41000000000001`, 
                    52.196000000000005`}, {107.41000000000001`, 
                    50.23500000000001}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{72.96100000000001, 
                    48.052}, {72.96100000000001, 42.907}, {71.004, 42.907}, {
                    71.004, 44.864}, {68.21900000000001, 44.864}, {
                    68.21900000000001, 42.907}, {66.262, 42.907}, {66.262, 
                    48.052}, {68.21900000000001, 48.052}, {68.21900000000001, 
                    46.091}, {71.004, 46.091}, {71.004, 48.052}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{72.96100000000001, 
                    50.23500000000001}, {72.96100000000001, 
                    55.38399999999999}, {71.004, 55.38399999999999}, {71.004, 
                    53.423}, {68.21900000000001, 53.423}, {68.21900000000001, 
                    55.38399999999999}, {66.262, 55.38399999999999}, {66.262, 
                    50.23500000000001}, {68.21900000000001, 
                    50.23500000000001}, {68.21900000000001, 
                    52.196000000000005`}, {71.004, 52.196000000000005`}, {
                    71.004, 50.23500000000001}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{97., 57.606}, {97., 
                    62.755}, {98.95700000000001, 62.755}, {98.95700000000001, 
                    60.794000000000004`}, {101.742, 60.794000000000004`}, {
                    101.742, 62.755}, {103.699, 62.755}, {103.699, 57.606}, {
                    101.742, 57.606}, {101.742, 59.567}, {98.95700000000001, 
                    59.567}, {98.95700000000001, 57.606}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{81.41400000000002, 
                    40.68}, {81.41400000000002, 35.536}, {79.45700000000001, 
                    35.536}, {79.45700000000001, 37.497}, {76.67199999999998, 
                    37.497}, {76.67199999999998, 35.536}, {74.715, 35.536}, {
                    74.715, 40.68}, {76.67199999999998, 40.68}, {
                    76.67199999999998, 38.720000000000006`}, {
                    79.45700000000001, 38.720000000000006`}, {
                    79.45700000000001, 40.68}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{81.41400000000002, 
                    57.606}, {81.41400000000002, 62.755}, {79.45700000000001, 
                    62.755}, {79.45700000000001, 60.794000000000004`}, {
                    76.67199999999998, 60.794000000000004`}, {
                    76.67199999999998, 62.755}, {74.715, 62.755}, {74.715, 
                    57.606}, {76.67199999999998, 57.606}, {76.67199999999998, 
                    59.567}, {79.45700000000001, 59.567}, {79.45700000000001, 
                    57.606}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{113.145, 
                    57.079}, {105.312, 61.294000000000004`}, {105.312, 
                    57.079}}}]}}}}}}}, {{{{{{{
                    Thickness[0.00006663529411764707], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{65.27, 
                    41.208000000000006`}, {73.10199999999999, 36.993}, {
                    73.10199999999999, 41.208000000000006`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{65.27, 
                    57.079}, {73.10199999999999, 61.294000000000004`}, {
                    73.10199999999999, 57.079}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{113.145, 
                    41.208000000000006`}, {105.312, 36.993}, {105.312, 
                    41.208000000000006`}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{105.516, 
                    57.282000000000004`}, {105.516, 60.958}, {
                    112.34400000000001`, 57.282000000000004`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{72.898, 
                    41.009}, {72.898, 37.333}, {66.07, 
                    41.009}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{72.898, 
                    57.282000000000004`}, {72.898, 60.958}, {66.07, 
                    57.282000000000004`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{105.516, 
                    41.009}, {105.516, 37.333}, {112.34400000000001`, 
                    41.009}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{57.18, 
                    33.649}, {57.555, 32.044}, {58.832, 30.829}, {59.137, 
                    29.161}, {59.75, 30.899}, {60.312, 32.356}, {59.891, 
                    34.259}, {59.59, 35.62200000000001}, {58.445, 36.591}, {
                    58.312, 37.989}, {57.066, 36.868}, {56.797000000000004`, 
                    35.278000000000006`}, {57.18, 33.649}}, CompressedData["
1:eJxTTMoPSmViYGCQBGIQHWG55URZno/Dh+XHvM1fWjnsLZkswfLNx6HpwKmF
rmWWDqZxuzx5Nvk68DBpt4tFWkD4TX4OTglPLyjNNnfQiuk/9DXCz+G4t3mn
4wMLiP5lfg6ZE9/W2F+1dHgTuEOu9befA5B8HXjDysEMpD/J3+Fk2b75Uvw2
Du1iN899n+wP0e9g69A7PU+o2cHfYYGU/l2VZXYO2z//vVIh6e9gD7L4ja3D
Itdtn/8+8XOQZAnj0w2ydUixvu/fuxzK32TjwN441bnbx89B3ZBjjcwua4c+
kHkCfg7lQOv071o5HP6qEdPP5OewRiYqxXq+JcT9M3wh/rG2cgA5jynb1yF7
D9AjKtYQ9Ua+DkDX75BjtXGYIgG06K6Pw5WKl2qGHrYQ+SAfhxZQeIXZOfyq
y9pTstnbAWSMNru9gx3X9cUFd70dYoHWaMyxdQCqAnrA26EC5B5ZGwf08AcA
SLunQg==
                    "], CompressedData["
1:eJxTTMoPSmViYGCQBGIQvbdksgRLmr9D84FTC12nmTloxvQf+urh73Cl4qWa
4QlTh97peULNBv4OjglPLyj9NnEAqzfzdwgESSibOLA3TnXuvuPnkL0HKPHE
xMHgrgpbY6qfQ8bEtzX2paYObwJ3yLX+9nX4BzJQ0MwhbpcnD1O2r4O6Icca
mV9mDoe/agBt9HFYIxOVYj3fHGKej4/D++XHvM1PWjicXui67XOsj4MxCAib
Q8zb7eOwzv1hlcg6UwdbruuLC3J9Ie5ZbOKw7fPfKxWafg4gYdsuY4h5PP4Q
/Z+NHEDOZDnm76DKBpQ4bejg0p3z/PdKfwceJu12sUhjh1wg7+MnfwegLa8D
Z5g4hDxeOvuIRIDDAil9oM/MHGYAg+OAUQDEvynmEPskAxxA3tI+buEAMrZ7
j7+DJEsYn+4lS4cIyy0nyvb5Q9yzysKBERjmDBP8HaJTrO/7rzV3QA9/ADmb
pE4=
                    "], CompressedData["
1:eJxTTMoPSmViYGCQBGIQ3Xzg1ELXtgCHzIlva+xDDR22ff57pWJmgMMuTx4m
bXUDB6stJ8r2nQ9w+LPy4yXfJD2H2z/rsvZ8CXCYL6V/V8VNx0EaSLFNDHCI
sAQqtNOF8C0DHGzu+/dOf6fnADR92+e9/hD9TgYOKdZAied+Dg6mcbs8dQwh
+v75OjysElnnftDQofKlmiGHja9DBsg9X40cpkiwhPHN9XXgur64wFbLwIG9
capzd4+fA8h57WK6DnEgh772dwAZOz1PG+KP3AAHe5D5PloQfZcCHGL6D33V
uKPlsGnu++XHkgMdFoDcz6bpEA/SHxzosBXozflSOg7fNIAqTQMd2ED25Og7
rJGJSrFmD3QAWydpCFH/OMBB3ZBjjYyUEcT+3QEO84DGeosbQ8JnSYCDJNDZ
ukYmDn5JAhGWLQEQd3gZO4CC429JgEM50Db9WCMH9PAHACGno/o=
                    
                    "], CompressedData["
1:eJxTTMoPSmViYGCQBGIQfftnXdaeL4EOW0+U7ZsvpeXw9ILS7Z9iQQ7fgx8v
ne2i4SCyzv1hlUuQw0651teBO9QcREH8miCH3ul5Qs0Nqg7PQOrfBTrsAMlb
qDpkTnxbY18b6LBASv+uCpuGgypb41TnzwEOhhxrZKJUNByaD5xa6DovAKpe
A6LeFyqfou4wWYIljO+tP4S/RN3BAGhKYyxUfYWqw7bPf69UnAxwuO8PdMEk
ZYh73QIdVn285JskoOzAdX1xge2rQIc0MFCCujPIodAWKLNBGeIfk2AHa5AB
esoQ+QdBEH1cqg6ePEza7duCIO5vU3dw6c55/rsRqt9Ay+GbRkz/IVuYvC7E
/X8DHdJB1j3Th5hXAQsPA4j6tVD3TdBzAIf3mUCHCMstJ8rsdBzQwx8AQtmv
2g==
                    "], {{79.67599999999999, 9.384}, {75.781, 
                    8.722999999999999}, {72.051, 7.863999999999999}, {68.074, 
                    7.824999999999999}, {72.523, 6.274}, {76.71900000000001, 
                    5.993}, {81.133, 7.595}, {83.52, 8.462}, {85.348, 
                    8.927}, {87.15199999999999, 8.798}, {89.785, 8.606}, {
                    92.98400000000001, 7.566999999999999}, {96.527, 
                    3.8329999999999997`}, {97.918, 4.946}, {92.84400000000001,
                     9.47}, {86.199, 10.493}, {79.67599999999999, 9.384}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{121.254, 
                    33.649}, {120.87899999999999`, 32.044}, {
                    119.60199999999999`, 30.829}, {119.293, 29.161}, {118.684,
                     30.899}, {118.121, 32.356}, {118.543, 34.259}, {
                    118.84400000000001`, 35.62200000000001}, {119.988, 
                    36.591}, {120.121, 37.989}, {121.367, 36.868}, {121.637, 
                    35.278000000000006`}, {121.254, 33.649}}, CompressedData["

1:eJxTTMoPSmViYGCQBGIQLbLO/WFVSpzDh+XHvM1fWjmEPF46+4hCnEPTgVML
XcssHWbkCTUfOBTrwMOk3S4WaQHhR8U6OCU8vaA029xhjUxUinV+rMNxb/NO
xwcWEP0esQ6ZE9/W2F+1dNhbMlmCRS7WYYdc6+vAG1YO00H6X8U4nCzbN1+K
38ah1t40btfFGIh+B1uHN4FAlb9jHBZI6d9VWWbn8OyC0u2ffLEOIGWeb2wd
HlYBXawZ6yDJEsanG2Tr8B8E3KH8TTYOQF1sjaWxDuqGHGtkdlk7vAaZNznW
oRxonf5dK4dLQOPqZsVC3D3fEmL+Oah/rK0cmkH+fhbrkL0H6HAVa4eLIPVM
cQ6tIINYbSD+0o1zuFLxUs3QwxYiXxTn0ALSF2bn4NKd8/z3wTiHXZ7AEGO3
d1jkuu3z3zVxDrH9h75qzLF1uPOzLmvPnDiHCpB7ZG0c0MMfAB6Psig=
                    
                    "], CompressedData["
1:eJxTTMoPSmViYGCQBGIQ3Ts9T6j5RYxD84FTC12nmTk8vaB0++e3GIcrFS/V
DE+YOrwO3CHXyhzr4JgAlPlt4hDyeOnsIwyxDoEgjcomDgZ3VdgadWMdsveU
TJZ4YuIgrQ8UyIx1yJj4tsa+1NRhL1CYZV6swz+QgYJmEHuexTqoG3Kskfll
5nAJaF2dVZzDGpmoFOv55g4g7Y2lcQ7vlx/zNj9p4QCUzdqTE+dgDALC5g7f
NGL6D9nGOaxzf1glss7UYaHrts9/n0Dds9jEQa4V6OK2WAeu64sLbLuMIeaJ
xkL0fzaCuH9HjIMqW+NU59OGEPXHYhx4mLTbxSKNHVy6c57/XhjjsAMkMcPE
IX6XJw9Tc4zDAimQSWZQ/8VA/JtiDlHfGOMAUqZ93AISHntjHCRZwvh0L1k6
iIIcuicG4p5VFg6b5gJ9djnGITrF+r7/WnMH9PAHAACeqxo=
                    
                    "], CompressedData["
1:eJxTTMoPSmViYGCQBGIQrX9Xha1RNMYhc+LbGvtQQweX7pznvxljHHZ58jBp
qxs4VLxUM+Q4E+3wZ+XHS75Jeg5PLyjd/rks2mG+FFCnm47D9Dyh5gNcMQ4R
lltOlNnpOlwEStclxTjY3Pfvnf5Oz+HOz7qsPXtiIPqdDBz+g4B6rIODadwu
Tx1DB9F17g+r5sQ6PKwSWed+0NDhm0ZM/6G/sQ4ZIPd8NYK462ysA9f1xQW2
WgYOYPeGxjqAnNcupuvQfODUQtdlMQ7WIPvytCF8vRgHe5D5PloQc09GOwBN
/apxRwtiv3m0wwKQ+9k0HUIeL519xCPaYeuJsn3zpXQc9pZMlmBJi3Zga5zq
3J2j7yACct+UaAewdZKGEPU7oh3UDTnWyEgZQfgPoh3mvV9+zFvcGBI+36Id
JFnC+HSNTBzWyESlWIvHQNzvZewg1/o6cIdajEM50Db9WCMH9PAHAKgmrgU=

                    "], CompressedData["
1:eJxTTMoPSmViYGCQBGIQ/fSC0u2fy6Ictp4o2zdfSstBZJ37w6qWKIfvwY+X
znbRcFgjE5ViHR7lsFOu9XXgDjUIXz7KoXd6nlBzgypE/Zoohx0geQtVBy8e
Ju12uWiHBVL6d1XYNByOeZt3Oq6IdjDkAOpU0XAwAIo2/o2GqteAqPeLgcin
qDtkTHxbY78Uyl+i7tB84NRCV7sYiPoKVQeu64sLbC9FO9z3B7pgkrLD7Z91
WXtCoh1WfbzkmySg7LDt898rFRujHNLAQMkhbpcnD5N0lEOhLVDnBmUHsH/T
Ih2sQQboKTuosjVOdd4dCTGXSxVi/9NIiPvb1B1q7U3jdklC9RtoOewtmSzB
EhcFldeFuH9elEM6yLpn+hDzlGH+M4CofxcFcd8EPYdnIPvPRTlEWG45UWan
44Ae/gAy+KYv
                    "], {{98.758, 9.384}, {102.65199999999999`, 
                    8.722999999999999}, {106.383, 7.863999999999999}, {
                    110.359, 7.824999999999999}, {105.91000000000001`, 
                    6.274}, {101.715, 5.993}, {97.301, 7.595}, {
                    94.91400000000002, 8.462}, {93.082, 8.927}, {91.281, 
                    8.798}, {88.648, 8.606}, {85.44900000000001, 
                    7.566999999999999}, {81.906, 3.8329999999999997`}, {
                    80.512, 4.946}, {85.59, 9.47}, {92.23400000000001, 
                    10.493}, {98.758, 9.384}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGItIGYC4r0lkyVY0nwcri8usOU6nO3AAAIKvg7nvgc/
Xjo92wEoG8ZX6+nw5e+Vipf7suB8jjUyUSni2Q6/6rL2lCz2hqvf9hmk0Atu
nmncLk+eIh+H5gOnFrrK5UDEj3s7gO11Q/Cl9e+qsPHmOCx0BZpQ4oXBf1gl
ss49MMfBlguoI9cXYh5TrsPrwB1yra/94PwU6/v+veL+Dpvmvl9+7HAOxD2W
fnC+S3fO89+a/g7nQe7thsofDHAw73RMeCqSC5dfIAV0wLxcuH5IOCHMh/Fh
9oNp9Vy4+2B8mPt7p+cJNd9A8EMeL519RCYP7n90Pti9j3Ph4fcGZB53Hjx8
BSIst5xIy4OHP9i9k/Lg8ZMGAkL5cD7Y3Ox8ePzC1MPiH2beKZAD3/rC7bMD
+Weuj8M/oK1qe3MdKl+qGXLU+ELiozPXYfYRhQ1FGv6Q+Hqb6wDy5oGsQHh4
wuTB/rPJgesHh8eCHLj5haCAy8mB2w9LLwCJMSw+
                    
                    "]]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGItIGYC4uuLC2y5vvs6nP8e/HhpfK6DS3fO89+a/g6O
CU8vKC3PdciY+LbG/mqAg3knUEQEIa+7ae775U05DjD9C6T076qcgvH94Px2
sZvnvl/2c5jmDNKY46AZ03/oa4UvnN83PU+oeYKXgx7IPD8E/3XgDrlW4RwI
vdobg7/8mLd5Z2iOgxbIvBk+Ds0HTi10lYPqF/CGuONwtsNFpds/6055O5wD
+W96tsNkCZYwvlpPiHo+BH8qyD3HsyDu++EDV//sAtAAOx+4eWD6uC/cPi8e
Ju32Mh+HQluu64tzchwqX6oZctT4OqwAuW9ljsPsIwobijT8Hb5pAA12zXF4
CjIvLBAenjB5sL4nuXD99qZxuzwbcuHm/7tS8VJtby7c/jegcODOg7tPIMJy
y4m0PLj7weE/KQ/uv5sgDyXmw/lg/dL58PCBqYeFH8w8WPjC7IOFP9h9V3Lh
fHB4iOXB4w+d7wRKT7dz4fEPdo9uLjx9wPiw9ANLjwD6gjUe
                    
                    "]]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    64.93, 232.74299999999997`}, {63.379, 231.298}, {
                    63.12500000000001, 232.74299999999997`}, {63.379, 
                    234.18800000000002`}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    63.523, 233.76999999999998`}, {63.343999999999994`, 
                    232.74299999999997`}, {63.523, 231.71599999999998`}, {
                    64.62499999999999, 232.74299999999997`}}}]}}}}}}}, {{{{{{{
                    
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    54.473, 231.192}, {55.93, 232.64899999999997`}, {54.473, 
                    234.11399999999998`}, {52.684, 234.11399999999998`}, {
                    52.684, 236.165}, {50.977, 237.872}, {50.977, 227.43}, {
                    52.684, 229.141}, {52.684, 231.192}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    54.391, 233.911}, {55.645, 232.64899999999997`}, {54.391, 
                    231.39100000000002`}, {52.483999999999995`, 
                    231.39100000000002`}, {52.483999999999995`, 229.227}, {
                    50.977, 227.72}, {50.977, 237.58700000000002`}, {
                    52.483999999999995`, 236.07899999999998`}, {
                    52.483999999999995`, 233.911}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGItIGYC4r0lkyVY0nwc1NgapzpLpzowgICCr0PlSzVD
jg8pDkDZML5aTwfHhKcXlMQR/PPfgx8vzU9x+FWXtadksTdc/bbPf69UvPSC
m2cat8uTp8jHwZOHSbu9LNXh+uICW67j3g7paUAwD8E/orChKCM11WGhK9CE
Ei8M/opj3uadK1MdbLmAOnJ9HXQ3zX2/PCrN4XXgDrnW135wfor1ff9ecX+I
e2TSIO6x9IPzXbpznv/WhMo/SYXIHwxw+Ad0tVouQh7kvLRvCP1g9+5DmA/j
w+wHWX+sPg3uPhgf5n6LTmAIGqTD+dL6d1XYStPh/kfng91nkw4PP7B5yenw
8AXHx/50ePiD3fMqHR4/ghGWW05kZcD5qqD4OJwBj1+Yelj8w8w7BXLgW1+4
fXYg/8z1gcSHaDrEXTW+Dj3AYFr5MM1hNkhCwx8i75ruMD1PqPlAViA8PGHy
YP9NTYXrB6ae2Ud+pMLNNweFz5FUuP2w9AIALMwnGw==
                    
                    "]]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGItIGYC4uuLC2y5vvs6VL5UM+TYkebg0p3z/LemvwPn
GpmolP9pDhkT39bYXw1w+Hel4qVaLkIerO92qgNMfxoIKKVB+X5wfrvYzXPf
L/s52JvG7fIMSXPQjOk/9LXCF87vm54n1DzBy+HzX6AFy1Lh/M1z3y8/lp3q
8Dpwh1zram8MPtDU4MdrUx20QObN8HHw5GHSbi+D6hfwdlBja5zqLJ3qcFHp
9s+6U94Q/31IcZgswRLGV+vpoLsJaGAagg8yRkMhBeK+Hz5w9c8uAA2w84Gb
B/bfcV+4fV5g2sfBvNMx4emRVIi+Gl+I+xjTHGYfUdhQpOHvsLcEaNO8VIen
IPPCAuHhCZNf/fGSb5JNOlx/L8gfN9Lg5oOUZYimw+0HOf9YcjrcfUDbLyjt
T4e7Px0U/q/S4f5rOXBqoeuuDDgfrL84Ax4+MPWw8IOZBwtfmH2w8Aer00Hw
9UAK8tLh8YfOB6szTofH/wIp/bsqbYj0AePD0g8sPQIAa2kuwg==
                    
                    "]]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    64.93, 179.501}, {63.379, 178.059}, {63.12500000000001, 
                    179.501}, {63.379, 180.946}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    63.523, 180.52800000000002`}, {63.343999999999994`, 
                    179.501}, {63.523, 178.477}, {64.62499999999999, 
                    179.501}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    54.473, 177.95000000000002`}, {55.93, 179.411}, {54.473, 
                    180.876}, {52.684, 180.876}, {52.684, 182.923}, {50.977, 
                    184.634}, {50.977, 174.192}, {52.684, 175.903}, {52.684, 
                    177.95000000000002`}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    54.391, 180.67299999999997`}, {55.645, 179.411}, {54.391, 
                    178.153}, {52.483999999999995`, 178.153}, {
                    52.483999999999995`, 175.985}, {50.977, 174.477}, {50.977,
                     184.348}, {52.483999999999995`, 182.841}, {
                    52.483999999999995`, 
                    180.67299999999997`}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGItIGYC4r0lkyVY0nwc5r1ffsz7eYwDAwgo+DrUZ+0p
mTwhxgEoG8ZX6+lwfXGBLdf9KDj/0yXfJIEJ0Q6/6oAKF3vD1W/7/PdKxUsv
uHmmcbs8eYp8HF78Xvnx0txYiDnHvR2iUqzv+79F8MVvnvseXB3rsNAVaEKJ
FwZ/01yggcxxDrZcQB25vg7r3B9WiaTFO7wO3CHX+toPzgcZ2yvu7xDyeOns
Iy/iIO6x9IPzXbpznv/WhMpXQOUPBjj4907PE+qOh8sLRlhuOeGXANcvAOKL
JcDNh/Fh9oPIwA3xcPfB+DD3/wOGilpnApx/RGFDUcbZBLj/0fmrPgIDeEoC
PPxi+w991diTAA9fsL3iifDwB7vXKRE1vg4j+Oe/Bz9eKp0Ej1+Yelj8w8w7
BXLgW1+4fXYg/8z1cfimEdN/KDfBofKlmiFHja8DKHoeWyY4zAY5XMPfoQcY
bCvnJjgAQ7H5QFYgPDxh8l2OCU8v3IqF6/8DTA6+i+Lg5h/+CrTAKg5uPyy9
AAAMfju0
                    "]]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGItIGYC4uuLC2y5vvs6OJjG7fIUSHBw6c55/lvT32Hj
3PfLj4UnOGRMfFtjfzXAwb93ep5Qdzxc3pOHSbs9Lc4Bpl9xQ1HGxK8wvh+c
3y5289z3y34O0vp3Vdgi4x00Y/oPfa3whfP7gMY2T/By8AKZ9y8Wzt8h1/o6
sCPW4XUgkLXaG4NvD3IvT5yDFsi8GT4OL36v/HhpLlS/gLfDPKDzvZ/HOFxU
uv2z7pS3Q33WnpLJE2IcJkuwhPHVekLU10bD+WD3fIyCuO+HD1z9swtAA+x8
4OaB/XfcF24f2N1lPg6Hv2rE9FvFOVS+VDPkqIGG55Y4h9lHFDYUafg7nD0D
BG9iHZ6CzAsLhIcnTB5o6vXFUxLg+i06HROeGiTAzf8GNP5QbgLc/ligMzX2
JMDdBw4X8US4+wUjLLeccEqE+w8cX0JJcD5Y/5lEePjA1MPCD2YeLHxh9sHC
3xzkvhYE//PfKxUvjyXA4w+dvxmUnroT4PE/BeSOvfHw9AHjw9IPLD0CAG7u
Lxc=
                    "]]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    64.93, 126.262}, {63.379, 124.81700000000001`}, {
                    63.12500000000001, 126.262}, {63.379, 
                    127.708}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    63.523, 127.29}, {63.343999999999994`, 126.262}, {63.523, 
                    125.235}, {64.62499999999999, 126.262}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    54.473, 124.712}, {55.93, 126.17299999999999`}, {54.473, 
                    127.634}, {52.684, 127.634}, {52.684, 129.684}, {50.977, 
                    131.395}, {50.977, 120.95}, {52.684, 122.661}, {52.684, 
                    124.712}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    54.391, 127.43}, {55.645, 126.17299999999999`}, {54.391, 
                    124.915}, {52.483999999999995`, 124.915}, {
                    52.483999999999995`, 122.74700000000001`}, {50.977, 
                    121.239}, {50.977, 131.106}, {52.483999999999995`, 
                    129.598}, {52.483999999999995`, 127.43}}}]}}}}}}}, {{{{{{{
                    
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGItIGYC4r0lkyVY0nwcwvh0N83V93dgAAEFX4fDXzVi
+pv8HICyYXy1ng4ny/bNl5L3hvP/Xal4qdbo4/CrLmtPyWJvuPptn/8CZbzg
5pnG7fLkKfJx8OJh0m73C3C4vrjAluu4t8M694dVIvMQ/MqXaoYcOgEOC12B
JpR4YfDBBm0JcLDlAurI9XXwBJknFuTwOnCHXOtrPzg/xfq+f6+4vwPQ9HXu
MwMh7rH0g/NdunOe/9aEymtC5Q8GOGye+375MesguDzYfX7BcP1g/j2E+TA+
zP6Qx0tnH0kIgrsPxoe5P6B3ep7Q4WA4X+zmue/B3iFw/6Pzwe67GQwPP7B5
GiHw8E0FueN+CDz8we4xC4XHj0CE5ZYTZmFwvlY70IbnYfD4hamHxT/MvFMg
B771hdtnB/LPXB+HClB89ARD4qXG14Gtcapzt0qww+wjChuKNPwh8m+CHYC+
bD6QFQgPT5g82H/dAXD9XY4JTy8EBcLNB8u/DoDbD0svADOPI54=
                    
                    "]]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGItIGYC4uuLC2y5vvs6PKwSWed+McjBpTvn+W9Nf4dP
l3yTBBKCHTImvq2xvxrgsHnu++XHrBHy84Bcb/FAB5j+de5AE5bB+H5wfrvY
zXPfL/s55Ak1HzjFGeSgGdN/6GuFL5zfNx3ImuAF0bc+AM4Pebx09hGLAIfX
gTvkWld7Y/CnSLCE8e0NcNACmTfDx8GLh0m73Q+qX8DbIYxPd9NcfX+Hi0q3
f9ad8nY4/FUjpr/Jz2EySF+tJ0R/rA+cH9AL1OjsDXHfDx+4+mcXgAbY+cDN
A7vzuC/cPjBd5uMA8mbw6wCHypdqhhw1vhBzUwMdZh9R2FCk4e8QlWJ9339u
gMNTkHlhgfDwhMmbxe3y5LkVDNf/Z+XHS75CwXDzK0DiPcFw+8HhoRECd18q
0Pje+yFw94PD3ywU7r8Xv4EGXg2D88H6PcLg4QNTDws/mHmw8IXZBwv/vyD3
7QqG88HutAuBxx86H6jqdeCJYHj8K24oypiYGwRPHzA+LP3A0iMAEvclyg==

                    "]]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    64.93, 73.02}, {63.379, 71.579}, {63.12500000000001, 
                    73.02}, {63.379, 74.46600000000001}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    63.523, 74.048}, {63.343999999999994`, 73.02}, {63.523, 
                    71.99700000000001}, {64.62499999999999, 
                    73.02}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    54.473, 71.47}, {55.93, 72.93}, {54.473, 74.395}, {52.684,
                     74.395}, {52.684, 76.44200000000001}, {50.977, 
                    78.15299999999999}, {50.977, 67.712}, {52.684, 69.423}, {
                    52.684, 71.47}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    54.391, 74.192}, {55.645, 72.93}, {54.391, 
                    71.67299999999999}, {52.483999999999995`, 
                    71.67299999999999}, {52.483999999999995`, 69.505}, {
                    50.977, 67.99700000000001}, {50.977, 77.868}, {
                    52.483999999999995`, 76.36}, {52.483999999999995`, 
                    74.192}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGItIGYC4uKMiW9r0uMcri8usOU6nO1wUen2zzquOIdz
34MfL52e7VD5Us2Q4068w5e/Vype7suC8znWyESliGc7hDxeOvvICYR6/bsq
bI2q8XDztn0GakyMc2g+cGqhq1yOw9MLQAu2xTnsLZksweKG4EuDNPLmODCA
QEI8Bv9hlcg698Ach01z3y8/9jgWYh5TrgPQtVl7VBB8+dbXgTv4YiHqDuc4
fNOI6T9Ui+CD3cca63Ae5N7uHIg9N6MdzDsdE56K5MLlF0gBWfNy4frB7k1D
mA/jw+wHisq1qufC3Qfjw9zfOz1PqPkGgg8ON5k8uP/R+RBzcuHh9wZkHnce
PHwFIiy3nEjLg4c/2L2T8uDxkwYCQvlwPjg+svPh8QtTD4t/mHlgdy+OhdsH
dod3nMM/YPSr7c11EF3n/rDqTiwkPjpzIeHOFgsJx7e5DlZbTpTt00eEJ0we
7E6bHLh+cHgsyIGbX2jLdX1xTg7cflh6AQANNjHl
                    
                    "]]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGItIGYC4mcXlG7/nBfrcP578OOl8bkO+ndV2BpZYx0c
E55eUFqe65Ax8W2N/dFoB/NOoIgIQl5309z3y5tyHGD6F0gBZU5B+XII/nFv
oE6DWIdpzt05z3/nOOwtmSzBcg/B57q+uMA2KN5BD2SeH4L/OnCHXKtwjsPt
n3VZe47EYfCXHwMaHAo1zy/OofnAqYWucjkOLiBjBeMdQMZwHc6GuH9rnMM5
kP+mZztUvlQz5LgTD1HPh+BPBbnneBbEPDmE+rhdnjxM1XFw856C/LctFm7f
GpmoFOv4OIdCW6DLc3IcRNe5P6y6E+uwAuS+lTkQdWyxDt80YvoPueZA/OGM
CE+YPNgdT3Lh+u1NgTY35MLN/3el4qXa3ly4/W9A5nDnwd0nEGG55URaHtz9
4PCflAf3302QhxLz4Xywful8ePjA1MPCD8U8YPjC7IOFP9h9V3LhfLA/xPLg
8YfOdwKlp9u58PgHu0c3F54+YHxY+oGlRwBWgTbg
                    
                    "]]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    113.48400000000001`, 232.74299999999997`}, {115.035, 
                    231.298}, {115.289, 232.74299999999997`}, {115.035, 
                    234.18800000000002`}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    114.891, 233.76999999999998`}, {115.07, 
                    232.74299999999997`}, {114.891, 231.71599999999998`}, {
                    113.789, 232.74299999999997`}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    123.94100000000002`, 231.192}, {122.48400000000001`, 
                    232.64899999999997`}, {123.94100000000002`, 
                    234.11399999999998`}, {125.73, 234.11399999999998`}, {
                    125.73, 236.165}, {127.438, 237.872}, {127.438, 227.43}, {
                    125.73, 229.141}, {125.73, 231.192}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    124.023, 233.911}, {122.77, 232.64899999999997`}, {
                    124.023, 231.39100000000002`}, {125.93, 
                    231.39100000000002`}, {125.93, 229.227}, {127.438, 
                    227.72}, {127.438, 237.58700000000002`}, {125.93, 
                    236.07899999999998`}, {125.93, 233.911}}}]}}}}}}}, {{{{{{{
                    
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGItIGYC4uKMiW9r0uMc1NgapzpLpzpcVLr9s44rzqHy
pZohx4cUCH0n3sEx4ekFJXEE//z34MdL81McQh4vnX3kBEK9/l0VtkbVeLh5
2z7/vVKRGOfgycOk3V6W6gA05fbPbXEO6WlAMA/BP6KwoSgjNdWBAQQS4jH4
K455m3euTHXYNPf98mOPYx10QYyoNAega7P2qCD48q2vA3fwxULcI5Pm8E0j
pv9QLYIPdh8rlP8k1UEaJHAz2uHflYqXarkIeZDz0r4h9IPduw9hPowPsx/s
rvo0uPtgfJj7LTqBIWiQDueD7S1Nh/sfnQ92n006PPzA5iWnw8MXHB/70+Hh
D3bPq3R4/AhGWG45kZUB56uC4uNwBjx+Yeph8Q8zD+g7udbFsXD7wLQ3NH5E
0x1E17k/rLoT69CT8/z3yodpDs0HTi10ZYuFyLumO1htOVG2Tx8RnjB5sP+m
psL1B4Pc/SMVbr45KHyOpMLth6UXALDCLMI=
                    "]]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGItIGYC4mcXlG7/nBfrUPlSzZBjR5qD/l0VtkbWWAfO
NTJRKf/THDImvq2xPxrt8O9KxUu1XIT89cUFtly3Ux1g+tNAQCkNwpdD8I97
m3c6GsQ62JvG7fIMSXPYWzJZguUegs8FMigo3uHzX6AFy1Lh/M1z3y8/lp3q
cPtnXdaeI3EY/Jvnvgc/XpsKMc8vzsGTh0m7vSzVwaU75/lvwXgHNbbGqc7S
qRD3b42D+O9DCoS+E++guwloYBqCH9N/6KuGQgrEPDmEeqAreZiq4+DmPQX5
b1ss3D5QMFnHxzkAfZnw9Eiqg+g694dVd2Ih7mNMc2g+cGqhK1ssxNx5qQ6v
A3fItTojwhMmv/rjJd8km3S4/t7peULNN9Lg5h9R2FCUIZoOtx/k/GPJ6XD3
AW2/oLQ/He7+dFD4v0qH+68FZM+uDDgfrL84Ax4+MPWw8EMxDxi+MPtg4d8H
cp8Ogq8HUpCXDo8/dD7Y38bp8PhfIAVMSW2I9AHjw9IPLD0CAMdZMIQ=
                    
                    "]]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    113.48400000000001`, 179.501}, {115.035, 178.059}, {
                    115.289, 179.501}, {115.035, 180.946}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    114.891, 180.52800000000002`}, {115.07, 179.501}, {
                    114.891, 178.477}, {113.789, 179.501}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    123.94100000000002`, 177.95000000000002`}, {
                    122.48400000000001`, 179.411}, {123.94100000000002`, 
                    180.876}, {125.73, 180.876}, {125.73, 182.923}, {127.438, 
                    184.634}, {127.438, 174.192}, {125.73, 175.903}, {125.73, 
                    177.95000000000002`}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    124.023, 180.67299999999997`}, {122.77, 179.411}, {
                    124.023, 178.153}, {125.93, 178.153}, {125.93, 175.985}, {
                    127.438, 174.477}, {127.438, 184.348}, {125.93, 
                    182.841}, {125.93, 180.67299999999997`}}}]}}}}}}}, {{{{{{{
                    
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGItIGYC4uKMiW9r0uMc5r1ffsz7eYzDRaXbP+u44hzq
s/aUTJ4Q41D5Us2Q4068w/XFBbZc96Pg/E+XfJMEJkQ7hDxeOvvICYR6/bsq
bI2q8XDztn3+e6UiMc7hxe+VHy/NjXV4egFowbY4h6gU6/v+bxF88ZvnvgdX
xzowgEBCPAZ/01yggcxxEPpxrMM694dVImnxDkDXZu1RQfDlW18H7uCLhbjr
RZzDN42Y/kO1CD7YfaxQfkWcgzRI4Ga0g3/v9Dyh7ni4vGCE5ZYTfglw/QIg
vlgC3HwYH2b/DjmgxIZ4uPtgfJj7/12peKnWmQDnH1HYUJRxNgHuf3T+qo/A
AJ6SAA+/2P5DXzX2JMDDF+gKuVbxRHj4g93rlIgaX4cR/PPfgx8vlU6Cxy9M
PSz+YeaB6cWxcPvA/vGGhmNugoMoKKDvxDqAouexZYJD84FTC13ZYh16cp7/
Xjk3wcFqy4myffqI8ITJdzkmPL1wKxau/w8wOfguioObf/gr0AKrOLj9sPQC
AJB0QVs=
                    "]]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGItIGYC4mcXlG7/nBfr4GAat8tTIMFB/64KWyNrrMPG
ue+XHwtPcMiY+LbG/mi0g3/v9Dyh7ni4vCcPk3Z7WpwDTL/ihqKMiV+hfDkE
/7i3eaejQayDNEhjZLzD3pLJEiz3EHyu64sLbIPiHbxA5v2LhfN3yLW+DuyI
dbj9sy5rz5E4DL49yL08cRDz/OIcXvxe+fHS3FgHl+6c578F4x3mAZ3v/TwG
4v6tcQ71WXtKJk+Icah8qWbIcSceor42Gs4Hu+djFMQ8OYR6kC1M1XFw856C
/LctFm7fGpmoFOv4OIfDXzVi+q3iHETXuT+sugMNzy1xDs0HTi10ZYt1OHsG
CN7EOrwOBPrEGRGeMPkCW6DPpyTA9Vt0OiY8NUiAm/8NaPyh3AS4/bH9h75q
7EmAuw9srngi3P2CEZZbTjglwv0Hji+hJDgfrP9MIjx8YOph4YdiHjB8YfbB
wt8c5L4WBP/z3ysVL48lwOMPnb8ZlJ66E+DxP0WCJYxvbzw8fcD4sPQDS48A
yt4w2Q==
                    "]]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    113.48400000000001`, 126.262}, {115.035, 
                    124.81700000000001`}, {115.289, 126.262}, {115.035, 
                    127.708}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    114.891, 127.29}, {115.07, 126.262}, {114.891, 125.235}, {
                    113.789, 126.262}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    123.94100000000002`, 124.712}, {122.48400000000001`, 
                    126.17299999999999`}, {123.94100000000002`, 127.634}, {
                    125.73, 127.634}, {125.73, 129.684}, {127.438, 131.395}, {
                    127.438, 120.95}, {125.73, 122.661}, {125.73, 
                    124.712}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    124.023, 127.43}, {122.77, 126.17299999999999`}, {124.023,
                     124.915}, {125.93, 124.915}, {125.93, 
                    122.74700000000001`}, {127.438, 121.239}, {127.438, 
                    131.106}, {125.93, 129.598}, {125.93, 
                    127.43}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGItIGYC4uKMiW9r0uMcwvh0N83V93e4qHT7Zx1XnMPh
rxox/U1+DpUv1Qw57sQ7nCzbN19K3hvO/3el4qVao49DyOOls4+cQKjXv6vC
1qgaDzdv2+e/VyoS4xy8eJi02/0CHJ5eAFqwLc5hnfvDKpF5CD7YXJ0ABwYQ
SIjH4DuYxu3y3BLgsGnu++XHHsc6eILMEwtyALo2a48Kgi/f+jpwB1+sA9D0
de4zAx2+AZ11qBbBB7uPFcrXDHSQBgncjHbYDDLXOgguD3afXzBcP5h/D2E+
jA+zHxwOCUFw98H4MPcH9E7PEzocDOeL3Tz3Pdg7BO5/dD7YfTeD4eEHNk8j
BB6+qdb3/Xvvh8DDH+wes1B4/AhEWG45YRYG52u1A214HgaPX5h6WPzDzAP6
Tq51cSzcPrB/vOMcKkDm9AQ7iII03ol1YGuc6tytEuzQfODUQle2WIj8m2AH
qy0nyvbpI8ITJg/2X3cAXH+XY8LTC0GBcPPB8q8D4PbD0gsAt4UpRQ==
                    
                    "]]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGItIGYC4mcXlG7/nBfr8LBKZJ37xSAH/bsqbI2ssQ6f
LvkmCSQEO2RMfFtjfzTaYfPc98uPWSPk5wG53uKBDjD969yBJiyD8uUQ/OPe
5p2OBrEOeULNB05xBjnsLZkswXIPwee6vrjANijeAURxrQ+A80MeL519xCLA
4fbPuqw9R+Iw+FMkWML49gZAzPOLc/DiYdJu9wtwcOnOef5bMN4hjE9301x9
f4j7t8Y5HP6qEdPf5OdQ+VLNkONOPER/rA+cH9A7PU/I2RtinhxCfdwuTx6m
6ji4eU9B/tsWC7dvjUxUinV8nIPYzXPfg18HOIiCPH4n1mEyyPzUQAegLxe6
ssU6AFXd958b4PA6cIdcqzMiPGHyZiCLbgXD9f9Z+fGSr1Aw3PwKkDt7guH2
g8NDIwTuvlSg8b33Q+DuB4e/WSjcfy9+Aw28Ggbng/V7hMHDB6YeFn4o5vnF
we2Dhf9fkPt2BcP54PCwC4HHHzof6OvXgSeC4fGvuKEoY2JuEDx9wPiw9ANL
jwBu5yeM
                    "]]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    113.48400000000001`, 73.02}, {115.035, 71.579}, {115.289, 
                    73.02}, {115.035, 74.46600000000001}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    114.891, 74.048}, {115.07, 73.02}, {114.891, 
                    71.99700000000001}, {113.789, 73.02}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    123.94100000000002`, 71.47}, {122.48400000000001`, 
                    72.93}, {123.94100000000002`, 74.395}, {125.73, 74.395}, {
                    125.73, 76.44200000000001}, {127.438, 
                    78.15299999999999}, {127.438, 67.712}, {125.73, 69.423}, {
                    125.73, 71.47}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    124.023, 74.192}, {122.77, 72.93}, {124.023, 
                    71.67299999999999}, {125.93, 71.67299999999999}, {125.93, 
                    69.505}, {127.438, 67.99700000000001}, {127.438, 
                    77.868}, {125.93, 76.36}, {125.93, 
                    74.192}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIxIGYC4uuLC2y5jns7fNWI6T8UXegA46uyNU51ti90
WOi67fPfEi8MPscamaiUxEIHWy6gjlxfh5vnvgc/3lno8Dpwh1zraz84P8X6
vn+vuL9DfdaeksmzCh2Auq9UWPrB+S7dOc9/a/o71IH4dVD5gwEOxiBwuNDh
otLtn3VZgXD+7CMKG4o0/B0CeqfnCYUXOlS+VDPkqPF1iNvlycPUWehgB3LP
XB+IfH6hwymQg9/6OtwAuce90GFvyWQJljQfh6sVQI1ShQ4MIKDgC7GfpdAB
KBvGV+vpsEBK/67KjAI4H2zvkQKHXyCFi73h6sHufekFN88U5JAiH7h9AIMo
ngA=
                    "]]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIxIGYC4otKt3/WnfJ2qMvaUzKZpdBhsgRLGF+tp8ON
c9+DH+8vgPOTBCIst8wpcNCM6T/09YcPXP2zC0AD7Hwcrla8VDOUKnS4vrjA
luu4L0S/e6GDFw+TdnuZj0NA7/Q8ofxCh0qgMo4aX4c3gTvkWnsLHWYfUdhQ
pOHvINR84NTC6EKHpyDzwgIdjEHgcKFDxsS3NfZXA+B8l+6c5781/R3WuT+s
EqmC2vfd1+HF75UfL82F8f3g/Haxm+e+X/aDuH9bIcT9Fb5wfh/QWc0TvByA
vpFgSUDwwbRTocNrkDtXe2PwwXRyoYMWyLwZPnD/gtUJeMPDAwD7p6Dc
                    
                    "]]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{64.832, 
                    284.2}, {63.379, 282.845}, {63.141, 
                    284.2}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    63.358999999999995`, 284.2}, {63.523, 283.262}, {64.527, 
                    284.2}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{55.93, 284.2}, {50.977, 
                    284.2}, {50.977, 278.977}, {52.684, 280.688}, {52.684, 
                    282.739}, {54.473, 282.739}, {55.93, 
                    284.19599999999997`}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0.9803919999999999, 0.6823529999999999, 
                    0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{50.977, 279.262}, {50.977, 
                    284.2}, {55.645, 284.2}, {55.645, 284.19599999999997`}, {
                    54.391, 282.93799999999993`}, {52.483999999999995`, 
                    282.93799999999993`}, {52.483999999999995`, 
                    280.77}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIxIGYC4qcXlG7/3Bbn8FUjpv9QdKEDjK/K1jjV2b7Q
gQEEEuIx+BxrZKJSEgsdNs19v/zY41iHm+e+Bz/eWehw+2dd1h4VBF++9XXg
Dr5Yh/qsPSWTZxU6fAPZU4vg699VYWtkjXWoA/HrCh2kQQI3ox2MQeAw1D4D
BL/5wKmFrmyxDgG90/OEwgsdRNe5P6y6E+sQt8uTh6kT6h7vOIh8fqED0Ha5
1sWxDjdA7nEvdCjOmPi2Jj3O4WrFSzVDqUKHi0Dv1nHFQexnKXSoBApz3Il3
WCAFdMiMAjh/9hGFDUVHChxCHi+dfeQEQj3Y/arxcPO2ff57pSIxDm4fAAsQ
m/A=
                    "]]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIxIGYC4oyJb2vst8Y51GXtKZnMUuhQ+VLNkONOvMON
c9+DH+8vgPOTBCIst8wpcNhbMlmCRQ6hPm6XJw9TdZzD1QqgQqlCh6cXlG7/
3BYL0e9e6LBGJirFOj7OIaB3ep5QfqGD6Dr3h1V3Yh3eBO6Qa+0tdGg+cGqh
K1usgxCIEV3o8Bok7hztYAwChwsdwO47iuDr31Vha2SNdQAZI1JV6PAMZN+8
WIcXv1d+vDQXypdD8I97m3c6GsRC3L+tEOL+ewg+1/XFBbZB8Q57QOIJCH4f
0LnNToUOt38CfXokDoMPdmcy1Dy/OLh/Xbpznv8WjIeHBwDCJaEs
                    
                    "]]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{113.582, 
                    284.2}, {115.035, 282.845}, {115.273, 
                    284.2}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    115.05499999999999`, 284.2}, {114.891, 283.262}, {113.887,
                     284.2}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{122.48400000000001`, 
                    284.2}, {127.438, 284.2}, {127.438, 278.977}, {125.73, 
                    280.688}, {125.73, 282.739}, {123.94100000000002`, 
                    282.739}, {122.48400000000001`, 
                    284.19599999999997`}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{127.438, 279.262}, {
                    127.438, 284.2}, {122.77, 284.2}, {122.77, 
                    284.19599999999997`}, {124.023, 282.93799999999993`}, {
                    125.93, 282.93799999999993`}, {125.93, 
                    280.77}}}]}}}}}}}}}}}}}}, AspectRatio -> Automatic, 
                  ImageSize -> {{128}, {85}}, 
                  PlotRange -> {{0., 425.}, {0., 285.}}], ",", 
                 GraphicsBox[{{{{{{{
                    Thickness[0.0025], {{{{{{{
                    FaceForm[{
                    RGBColor[0., 0.6, 0.709804], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     200.}, {400., 200.}, {400., 136.}, {0., 
                    136.}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.8078430000000001, 0.06666670000000002, 0.14902], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     136.}, {400., 136.}, {400., 64.}, {0., 
                    64.}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     132.}, {400., 132.}, {400., 68.}, {0., 
                    68.}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0.117647, 0.709804, 0.22745100000000001`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     64.}, {400., 64.}, {400., 0.}, {0., 0.}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{80., 168.}, {80., 154.74599999999998`}, {69.254, 
                    144.}, {56., 144.}, {42.746, 144.}, {32., 
                    154.74599999999998`}, {32., 168.}, {32., 181.254}, {
                    42.746, 192.}, {56., 192.}, {69.254, 192.}, {80., 
                    181.254}, {80., 168.}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0., 0.6, 0.709804], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{88., 168.}, {88., 154.74599999999998`}, {77.254, 
                    144.}, {64., 144.}, {50.746, 144.}, {40., 
                    154.74599999999998`}, {40., 168.}, {40., 181.254}, {
                    50.746, 192.}, {64., 192.}, {77.254, 192.}, {88., 
                    181.254}, {88., 168.}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{70.398, 
                    153.602}, {68.918, 149.035}, {71.199, 
                    148.29299999999998`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{70.398, 
                    153.602}, {71.883, 149.035}, {69.60199999999999, 
                    148.29299999999998`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{74.965, 
                    150.285}, {70.164, 150.285}, {70.164, 147.883}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{74.965, 
                    150.285}, {71.082, 147.461}, {69.67199999999998, 
                    149.40200000000002`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{73.223, 
                    144.918}, {71.738, 149.48000000000002`}, {
                    69.45700000000001, 148.738}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{73.223, 
                    144.918}, {69.34, 147.738}, {70.75, 149.68}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    67.57799999999999, 144.918}, {71.46100000000001, 
                    147.738}, {70.051, 149.68}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    67.57799999999999, 144.918}, {69.062, 
                    149.48000000000002`}, {71.34400000000001, 148.738}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{65.836, 
                    150.285}, {69.71900000000001, 147.461}, {
                    71.12899999999999, 149.40200000000002`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{65.836, 
                    150.285}, {70.637, 150.285}, {70.637, 147.883}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    89.60199999999999, 153.602}, {88.117, 149.035}, {90.398, 
                    148.29299999999998`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    89.60199999999999, 153.602}, {91.082, 149.035}, {88.801, 
                    148.29299999999998`}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{94.164, 
                    150.285}, {89.363, 150.285}, {89.363, 147.883}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{94.164, 
                    150.285}, {90.281, 147.461}, {88.871, 
                    149.40200000000002`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{92.422, 
                    144.918}, {90.938, 149.48000000000002`}, {
                    88.65599999999999, 148.738}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{92.422, 
                    144.918}, {88.539, 147.738}, {89.94900000000001, 
                    149.68}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{86.777, 
                    144.918}, {90.66, 147.738}, {89.25, 149.68}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{86.777, 
                    144.918}, {88.262, 149.48000000000002`}, {90.543, 
                    148.738}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{85.035, 
                    150.285}, {88.918, 147.461}, {90.32799999999999, 
                    149.40200000000002`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{85.035, 
                    150.285}, {89.836, 150.285}, {89.836, 147.883}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{108.801, 
                    153.602}, {107.316, 149.035}, {109.598, 
                    148.29299999999998`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{108.801, 
                    153.602}, {110.285, 149.035}, {108., 
                    148.29299999999998`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{113.363, 
                    150.285}, {108.566, 150.285}, {108.566, 147.883}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{113.363, 
                    150.285}, {109.48, 147.461}, {108.07, 
                    149.40200000000002`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{111.621, 
                    144.918}, {110.137, 149.48000000000002`}, {
                    107.85499999999999`, 148.738}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{111.621, 
                    144.918}, {107.738, 147.738}, {109.148, 149.68}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{105.98, 
                    144.918}, {109.863, 147.738}, {108.453, 149.68}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{105.98, 
                    144.918}, {107.46100000000001`, 149.48000000000002`}, {
                    109.74600000000001`, 148.738}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    104.23400000000001`, 150.285}, {108.117, 147.461}, {
                    109.527, 149.40200000000002`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    104.23400000000001`, 150.285}, {109.035, 150.285}, {
                    109.035, 147.883}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{128., 
                    153.602}, {126.516, 149.035}, {128.80100000000002`, 
                    148.29299999999998`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{128., 
                    153.602}, {129.484, 149.035}, {127.199, 
                    148.29299999999998`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{132.566, 
                    150.285}, {127.766, 150.285}, {127.766, 147.883}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{132.566, 
                    150.285}, {128.684, 147.461}, {127.27, 
                    149.40200000000002`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    130.82000000000002`, 144.918}, {129.34, 
                    149.48000000000002`}, {127.05499999999999`, 148.738}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    130.82000000000002`, 144.918}, {126.938, 147.738}, {
                    128.348, 149.68}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    125.17999999999999`, 144.918}, {129.062, 147.738}, {
                    127.65199999999999`, 149.68}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    125.17999999999999`, 144.918}, {126.66, 
                    149.48000000000002`}, {128.945, 148.738}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    123.43400000000001`, 150.285}, {127.316, 147.461}, {
                    128.73, 149.40200000000002`}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    123.43400000000001`, 150.285}, {128.23399999999998`, 
                    150.285}, {128.23399999999998`, 147.883}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    147.19899999999998`, 153.602}, {145.71499999999997`, 
                    149.035}, {148., 148.29299999999998`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    147.19899999999998`, 153.602}, {148.684, 149.035}, {
                    146.40200000000002`, 148.29299999999998`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{151.766, 
                    150.285}, {146.965, 150.285}, {146.965, 147.883}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{151.766, 
                    150.285}, {147.883, 147.461}, {146.47299999999998`, 
                    149.40200000000002`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{150.02, 
                    144.918}, {148.539, 149.48000000000002`}, {146.254, 
                    148.738}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{150.02, 
                    144.918}, {146.137, 147.738}, {147.547, 149.68}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{144.379, 
                    144.918}, {148.262, 147.738}, {146.85200000000003`, 
                    149.68}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{144.379, 
                    144.918}, {145.863, 149.48000000000002`}, {
                    148.14499999999998`, 148.738}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{142.637, 
                    150.285}, {146.52, 147.461}, {147.93, 
                    149.40200000000002`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{142.637, 
                    150.285}, {147.434, 150.285}, {147.434, 147.883}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    89.60199999999999, 172.80100000000002`}, {88.117, 
                    168.23399999999998`}, {90.398, 167.49200000000002`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    89.60199999999999, 172.80100000000002`}, {91.082, 
                    168.23399999999998`}, {88.801, 167.49200000000002`}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{94.164, 
                    169.484}, {89.363, 169.484}, {89.363, 
                    167.08200000000002`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{94.164, 
                    169.484}, {90.281, 166.66}, {88.871, 168.605}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{92.422, 
                    164.117}, {90.938, 168.684}, {88.65599999999999, 
                    167.941}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{92.422, 
                    164.117}, {88.539, 166.93800000000002`}, {
                    89.94900000000001, 168.879}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{86.777, 
                    164.117}, {90.66, 166.93800000000002`}, {89.25, 
                    168.879}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{86.777, 
                    164.117}, {88.262, 168.684}, {90.543, 167.941}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{85.035, 
                    169.484}, {88.918, 166.66}, {90.32799999999999, 
                    168.605}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{85.035, 
                    169.484}, {89.836, 169.484}, {89.836, 
                    167.08200000000002`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{108.801, 
                    172.80100000000002`}, {107.316, 168.23399999999998`}, {
                    109.598, 167.49200000000002`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{108.801, 
                    172.80100000000002`}, {110.285, 168.23399999999998`}, {
                    108., 167.49200000000002`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{113.363, 
                    169.484}, {108.566, 169.484}, {108.566, 
                    167.08200000000002`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{113.363, 
                    169.484}, {109.48, 166.66}, {108.07, 168.605}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{111.621, 
                    164.117}, {110.137, 168.684}, {107.85499999999999`, 
                    167.941}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{111.621, 
                    164.117}, {107.738, 166.93800000000002`}, {109.148, 
                    168.879}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{105.98, 
                    164.117}, {109.863, 166.93800000000002`}, {108.453, 
                    168.879}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{105.98, 
                    164.117}, {107.46100000000001`, 168.684}, {
                    109.74600000000001`, 167.941}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    104.23400000000001`, 169.484}, {108.117, 166.66}, {
                    109.527, 168.605}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    104.23400000000001`, 169.484}, {109.035, 169.484}, {
                    109.035, 167.08200000000002`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{128., 
                    172.80100000000002`}, {126.516, 168.23399999999998`}, {
                    128.80100000000002`, 167.49200000000002`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{128., 
                    172.80100000000002`}, {129.484, 168.23399999999998`}, {
                    127.199, 167.49200000000002`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{132.566, 
                    169.484}, {127.766, 169.484}, {127.766, 
                    167.08200000000002`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{132.566, 
                    169.484}, {128.684, 166.66}, {127.27, 168.605}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    130.82000000000002`, 164.117}, {129.34, 168.684}, {
                    127.05499999999999`, 167.941}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    130.82000000000002`, 164.117}, {126.938, 
                    166.93800000000002`}, {128.348, 168.879}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    125.17999999999999`, 164.117}, {129.062, 
                    166.93800000000002`}, {127.65199999999999`, 168.879}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    125.17999999999999`, 164.117}, {126.66, 168.684}, {
                    128.945, 167.941}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    123.43400000000001`, 169.484}, {127.316, 166.66}, {128.73,
                     168.605}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    123.43400000000001`, 169.484}, {128.23399999999998`, 
                    169.484}, {128.23399999999998`, 167.08200000000002`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    147.19899999999998`, 172.80100000000002`}, {
                    145.71499999999997`, 168.23399999999998`}, {148., 
                    167.49200000000002`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    147.19899999999998`, 172.80100000000002`}, {148.684, 
                    168.23399999999998`}, {146.40200000000002`, 
                    167.49200000000002`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{151.766, 
                    169.484}, {146.965, 169.484}, {146.965, 
                    167.08200000000002`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{151.766, 
                    169.484}, {147.883, 166.66}, {146.47299999999998`, 
                    168.605}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{150.02, 
                    164.117}, {148.539, 168.684}, {146.254, 167.941}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{150.02, 
                    164.117}, {146.137, 166.93800000000002`}, {147.547, 
                    168.879}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{144.379, 
                    164.117}, {148.262, 166.93800000000002`}, {
                    146.85200000000003`, 168.879}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{144.379, 
                    164.117}, {145.863, 168.684}, {148.14499999999998`, 
                    167.941}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{142.637, 
                    169.484}, {146.52, 166.66}, {147.93, 168.605}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{142.637, 
                    169.484}, {147.434, 169.484}, {147.434, 
                    167.08200000000002`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{108.801, 
                    192.}, {107.316, 187.434}, {109.598, 186.691}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{108.801, 
                    192.}, {110.285, 187.434}, {108., 186.691}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{113.363, 
                    188.684}, {108.566, 188.684}, {108.566, 186.285}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{113.363, 
                    188.684}, {109.48, 185.863}, {108.07, 187.805}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{111.621, 
                    183.316}, {110.137, 187.883}, {107.85499999999999`, 
                    187.141}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{111.621, 
                    183.316}, {107.738, 186.137}, {109.148, 188.078}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{105.98, 
                    183.316}, {109.863, 186.137}, {108.453, 188.078}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{105.98, 
                    183.316}, {107.46100000000001`, 187.883}, {
                    109.74600000000001`, 187.141}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    104.23400000000001`, 188.684}, {108.117, 185.863}, {
                    109.527, 187.805}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    104.23400000000001`, 188.684}, {109.035, 188.684}, {
                    109.035, 186.285}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{128., 192.}, {
                    126.516, 187.434}, {128.80100000000002`, 186.691}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{128., 192.}, {
                    129.484, 187.434}, {127.199, 186.691}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{132.566, 
                    188.684}, {127.766, 188.684}, {127.766, 186.285}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{132.566, 
                    188.684}, {128.684, 185.863}, {127.27, 187.805}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    130.82000000000002`, 183.316}, {129.34, 187.883}, {
                    127.05499999999999`, 187.141}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    130.82000000000002`, 183.316}, {126.938, 186.137}, {
                    128.348, 188.078}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    125.17999999999999`, 183.316}, {129.062, 186.137}, {
                    127.65199999999999`, 188.078}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    125.17999999999999`, 183.316}, {126.66, 187.883}, {
                    128.945, 187.141}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    123.43400000000001`, 188.684}, {127.316, 185.863}, {
                    128.73, 187.805}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    123.43400000000001`, 188.684}, {128.23399999999998`, 
                    188.684}, {128.23399999999998`, 186.285}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    147.19899999999998`, 192.}, {145.71499999999997`, 
                    187.434}, {148., 186.691}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    147.19899999999998`, 192.}, {148.684, 187.434}, {
                    146.40200000000002`, 186.691}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{151.766, 
                    188.684}, {146.965, 188.684}, {146.965, 186.285}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{151.766, 
                    188.684}, {147.883, 185.863}, {146.47299999999998`, 
                    187.805}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{150.02, 
                    183.316}, {148.539, 187.883}, {146.254, 187.141}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{150.02, 
                    183.316}, {146.137, 186.137}, {147.547, 188.078}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{144.379, 
                    183.316}, {148.262, 186.137}, {146.85200000000003`, 
                    188.078}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{144.379, 
                    183.316}, {145.863, 187.883}, {148.14499999999998`, 
                    187.141}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{142.637, 
                    188.684}, {146.52, 185.863}, {147.93, 187.805}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{142.637, 
                    188.684}, {147.434, 188.684}, {147.434, 
                    186.285}}}]}}}}}}}}}}}}}}, AspectRatio -> Automatic, 
                  ImageSize -> {{128}, {85}}, 
                  PlotRange -> {{0., 400.}, {0., 200.}}], ",", 
                 GraphicsBox[{{{{{{{
                    Thickness[0.001893939393939394], {{{{{{{
                    FaceForm[{
                    RGBColor[0., 0.47058800000000006`, 0.368627], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {0., 352.}, {528., 352.}, {528., 
                    0.}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.9843139999999999, 0.8196080000000001, 
                    0.08627450000000002], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBWIuIGZigIKGAofHS2cfUbhV6LD1RNm++VYFDse8zTsd
WQod+g991YjZnAfnCzUfOLWQv8Dh0yXfJIEGqLop+Q4FtlzXF4fkO8DM2yHX
+jpQr8BBNirF+r5pIVz+bY29adwHhH6wumWFcPNBVMJRhP2LXLd9/iuQ5ZD7
/PfKj0lQd+ZkOaz+CDRgTr4DUPcOudxMB5funOe/X+ZB5JdkOfROzxNqfpLn
4Jjw9ILS/yyHapF17g935ULEU7Ih+h7mOYTx6W6aOzsH4s7beQ6qbI1TnRdn
O8Tu8uRhmp7vsApkD0eOwxZQuMQVQNzHmQ2hWQsc9O+qsDV+L4a7D2SMf3Ux
XF6rXezmud9FcP1g/+sVw82/WvFSzXBTEdx+K5BC32K4++77A13cUAx3P8i5
79cWw/0HCtYCzxK4/8HyJ4vh4VOUMfFtzeF0iP53OZDwcUh32D9fSv/ulWyH
CaD45U6DyP/KhqpLcwAZf0ANKp+d5lAIsogny6EYZF51OsTcxVkOcSB/xGdA
1J3PdLAEuV85w+H2z7qsPQzZDqEgBxlnQsJ5ejZE/f90Bx9Q+OzNhsSzXCnc
fReUgDoZSuHy4PBJK4HrB7v/XQncfLD6CyVw+4+DzHMqhbtvJyh9nSqFux+k
rL+jFO4/sPyvUrj/eUHhF18KDx8AMi5sNg==
                    "]]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}, {{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 
                    0}, {1, 3, 3}}, {{1, 4, 3}, {0, 1, 0}, {1, 3, 3}}, {{1, 4,
                     3}, {0, 1, 0}, {1, 3, 3}}, {{1, 4, 3}, {0, 1, 0}, {1, 3, 
                    3}}, {{1, 4, 3}, {1, 3, 3}}}, {CompressedData["
1:eJxVVWtIFFEUFosSkwiLiLCyd9nD+hFSYp2KsKwoCxSiYhzc2XF3Z3RmZ5Me
SBGSPUlKKiKkRKEyidCealJSIZQmkmmGWUSSmElFVPSYe87M2RRk+Pbee+53
vvPdc6bKuVs8kREREbvtf/HFv/15EFSL+/f1aYA4kAvR7WV5KScCDtZhlMBH
fIxrnuyqL01TGc8ccaBk9UMF+vetWLLzrYMzPSDCrriWC3kpdsQ52fCu/Hxj
fLUOrdNe/SjweWBZtR1oig6zF0dVxv1RGD9an3R4ZbXKGOO151C8LB1WSe9b
pvX56NwLHTqefd/6rscPG+xjUqGzP8nhv1aHlWJ/aYDWZzr8YzXotFnUFmlQ
Z52aMPyPn84lavBc8Kv3McZ7fDmMz+qxBxseeGHswYami3c0yBi94MaFZAWW
Cr5lOpx88G3O9r9OvjEa3XdFIf5PfVDYl357co0Xjp+xA21WGaN+C8P4sdAh
RnX08MInsf7RS/FueEnHBBV23F0XE5nv7JdUuDLYulFe5IX60omJr4tURx+F
6hrph/vi9zcK5b1co3MvPVSnNp10W5RNv2/WKJ7lgaviu91PeSYpMEvokZzD
GPlEq4wxTq9Cev30UB26nTjHPKTngEJ1qZMp/4oc0rVOorzbAowvrbn55XeU
xhj1THF82yBRXnkanWuUYKfQZZhGOl+XSIfiANWzQqL7Jocxno/zMUbeaY5+
RhbF/apAl/BNrUz7K526XpRJJ0mhup+UwRB6jlHID0dl4q15Qbi/NiKL3p3f
0W+kRHqU+RmTDzXGia9njDhQnkv39Ergvl/0S7pMPBYYvI78400+T/4KMsb6
plmM84Vh1oWYX2rPnnFV30PMP+HQ+I5nzSHOL/66qRZfDnH+k7ZlJ3cXhlgf
9Gmnxfrh/sEg63tYGOKzydh2Y8boW2HcIvIvMLl+eD7V5Pqi3bNMrj/qs9dk
fyCfkjDG++ZbjFGPohD7r3uTfdOYXexPjHssxP6lr8X+xvcoh/E8oU96kHGc
uD/T5PezVuhZYvD7Qj9LJr8/ezW1pyDI7xPzvWfx+8V4zRa/b+Tz0eL3j/lF
h7g/YP4/LO4fuN5rcX9Bnu1hjHqeCzIWbW1gt8n9C+teZXB/Q79MN7n/oZ6q
yf3RxW7/dLHbX2NFHZJN7r+C7qZ+g/sz6tRlcP/G9TqD+7v24dflwdMG93/k
32zwfEC+nw2eHy5254uL3fmD+ZYbPJ8w3lyD51eRIHLC4PmG/JoMnn8uHjIf
bTxkfqYZQ+frf/P3HzZeSso=
                    "], CompressedData["
1:eJxTTMoPSmViYGAQB2IQDQYNBQ6WW06U7WtOdOC+vrjAdlW+g8FdFbZG2wSH
CYe+asTcznXgAom/inO4ee578OO72XD+qo+XfJNE0uB8sHkOaQ419qZxuzLj
HL5pxPQfyk1zEFnn/rDqTayDcPOBUwvnpjnMyBNqPlAUCzHPNAfO3zdfSv8u
Rx6cX2ALNHlLvsOmue+XHzsMNR/o3oyJb2vsKxMcPB5WiaxTLYTLK2woypj4
uxCuf7IESxjf0yI4vxxkwcZSOL/1deAOuZOlcPeBzX9QCne/drvYzXNfS+H+
A5snWAzn75QDmiBUBOdXgwzSKoSHH3r4AgC2fJ4U
                    "], {{186.059, 
                    111.742}, {186.969, 110.74600000000001`}, {
                    187.90200000000002`, 109.77}, {188.85200000000003`, 
                    108.809}, {339.148, 108.809}, {340.09799999999996`, 
                    109.77}, {341.03099999999995`, 110.74600000000001`}, {
                    341.941, 111.742}}, {{195.336, 102.758}, {197.195, 
                    101.16799999999999`}, {199.105, 99.637}, {201.07, 
                    98.17599999999999}, {326.92999999999995`, 
                    98.17599999999999}, {328.895, 99.637}, {330.805, 
                    101.16799999999999`}, {332.66400000000004`, 102.758}}, {{
                    207.758, 93.59}, {211.164, 91.44100000000002}, {214.695, 
                    89.48}, {218.35200000000003`, 87.727}, {309.648, 
                    87.727}, {313.305, 89.48}, {316.83599999999996`, 
                    91.44100000000002}, {320.242, 93.59}}, {{225.055, 
                    84.793}, {237.105, 80.}, {250.24599999999998`, 77.367}, {
                    264., 77.367}, {277.754, 77.367}, {290.895, 80.}, {
                    302.945, 84.793}}}]}}}}}}}}}}}}}}, AspectRatio -> 
                  Automatic, ImageSize -> {{128}, {85}}, 
                  PlotRange -> {{0., 528.}, {0., 352.}}], ",", 
                 GraphicsBox[{{{{{{{
                    Thickness[0.0020833333333333333`], {{{{{{{
                    FaceForm[{
                    RGBColor[0., 0.501961, 0.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     240.}, {480., 240.}, {480., 0.}, {0., 
                    0.}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 0.8784310000000001, 0.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{134.445, 170.}, {134.445, 141.16}, {111.062, 
                    117.777}, {82.223, 117.777}, {53.379, 117.777}, {30., 
                    141.16}, {30., 170.}, {30., 198.84}, {53.379, 
                    222.22299999999998`}, {82.223, 222.22299999999998`}, {
                    111.062, 222.22299999999998`}, {134.445, 198.84}, {
                    134.445, 170.}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0.501961, 0.12549000000000002`, 0.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIVIGYCYmn9uypsG4MdHi+dfUQhIMGh+cCpha7fwnDy
K1+qGXLIhDtcULr9s64sweGbRkz/obdhDsIghZ0JDsUZE9/W7A9z2D9fSv/u
nASH14E75Fq5wxwWuW77/HcBVL8NVP5JggMDCCwIc1j18ZJvUkGiw96SyRIs
68IcfMw7HRNcEx2AtmTteRMGoSckQczTDoe4506yQ429adwuz3AHyy0nyvY9
TsXgg/13MQwn/5g30KIXYQ7qhhxrZJxSHS6C/LUozMEKJJ+f4nAHZG9MmAPI
W/ZzkyH63MMcZuQJNR/oSnYAWsbD9DvUoRXksJdJkPBaF+pQBNLgngRRtyjU
AWRto2USJBxiQh0mHPqqEXM70WGNTFSKtXgoxPzaRIfjIPcIhDr0TgdqrEh0
iAeZvzjEASScoJgIMcc0BOLeUwkOmSB9sSEQe14lOISAAybE4S0oILYlQPzD
FAIxdw5U/d1gB1W2xqnOixMg4XESGv8TEhxE1rk/rNoSDPFPLVQeKX2g8wEC
hwLd
                    "]]}}}}}}}, {{{{{{{
                    RGBColor[0.48235300000000003`, 0.192157, 0.], 
                    Thickness[0.002314814583333333], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIVIGYCYmn9uypsG4MdipbOY1UMSHBoPnBqoeu3MJz8
ypdqhhwy4Q4JSves6ssSHL5pxPQfehvmsKjpMPeizgSH4oyJb2v2hzn4zZct
uDsnweF14A65Vu4wBwPXnSb/FkD120DlnyQ4MIDAgjAHy49X+5IKEh32lkyW
YFkX5nDbrKcpwTXR4fbPuqw9b8Icsn42rt4zIQlinnY4xD13kh1q7E3jdnmG
O5zYfHr7vsepGHyw/y6G4eQf8zbvdHwR5rDNgPutjFOqw0UloI2LoPL5KQ53
QPbHhDn8mPBhr/3cZAfLLSfK9rmHOajliR450JXsALSMh+l3qIPI65Cfci+T
IOG1LtSBKWOKXq17ksOMPKHmA4tCHfbdUXdvtExyWOS67fPfmFAHuUM/MmNu
JzqskYlKsRYPhZhfm+hwHOQegVAHmemFwc0ViQ7xIPMXhzjcAoWHYqIDyPmN
piEQ955KcMgEBrd9bAjEPa8SHEIeL519RCHEoabGqSxuWwLEP0whDmHeVqcc
50DV3w122MLacs15cQIkPE5C439CgoPIOveHVVuCIf6phcojpQ90PgBfPP92

                    "], CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 0.8784310000000001, 0.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{360.,
                     57.145}, {363.305, 46.863}, {373.402, 50.688}, {
                    367.42999999999995`, 41.69500000000001}, {376.715, 
                    36.184}, {365.957, 35.25}, {367.43799999999993`, 
                    24.555}, {360., 32.379}, {352.562, 24.555}, {354.043, 
                    35.25}, {343.28499999999997`, 36.184}, {352.57, 
                    41.69500000000001}, {346.59799999999996`, 50.688}, {
                    356.695, 46.863}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{360.,
                     217.14499999999998`}, {363.305, 206.863}, {373.402, 
                    210.68800000000002`}, {367.42999999999995`, 201.695}, {
                    376.715, 196.184}, {365.957, 195.25}, {
                    367.43799999999993`, 184.555}, {360., 192.379}, {352.562, 
                    184.555}, {354.043, 195.25}, {343.28499999999997`, 
                    196.184}, {352.57, 201.695}, {346.59799999999996`, 
                    210.68800000000002`}, {356.695, 206.863}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{300.,
                     152.14499999999998`}, {303.305, 141.863}, {313.402, 
                    145.68800000000002`}, {307.42999999999995`, 136.695}, {
                    316.715, 131.184}, {305.957, 130.25}, {
                    307.43799999999993`, 119.55499999999999`}, {300., 
                    127.37899999999999`}, {292.562, 119.55499999999999`}, {
                    294.043, 130.25}, {283.28499999999997`, 131.184}, {292.57,
                     136.695}, {286.59799999999996`, 145.68800000000002`}, {
                    296.695, 141.863}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    413.332, 168.14499999999998`}, {416.641, 157.863}, {
                    426.734, 161.68800000000002`}, {420.762, 152.695}, {
                    430.047, 147.184}, {419.29299999999995`, 146.25}, {
                    420.77299999999997`, 135.555}, {413.332, 143.379}, {
                    405.895, 135.555}, {407.375, 146.25}, {396.621, 
                    147.184}, {405.902, 152.695}, {399.92999999999995`, 
                    161.68800000000002`}, {410.027, 157.863}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{384., 120.}, {386.613, 113.59400000000001`}, {
                    393.512, 113.09}, {388.227, 108.62499999999999`}, {
                    389.879, 101.91000000000001`}, {384., 
                    105.55499999999999`}, {378.121, 101.91000000000001`}, {
                    379.77299999999997`, 108.62499999999999`}, {
                    374.48799999999994`, 113.09}, {381.387, 
                    113.59400000000001`}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJ/IGZigIE8BzDlkOpw52dd1p6eLDgfTB9Id1Bla5zq
XJwE50P0xcH52z7/vVIhGY6qvyHQAcV8IF/dkGONzLx8VPmuAoj5h4McHi+d
fURBotDhPwgcD3EQbj5waiFvocPrwB1yrZtDHIDk60CWQofijIlva6aHOChs
KMqY+LPAAcS1bw1xuFrxUs3wUoHDjDyh5gNOIQ6TJVjC+FYWODy7oHT7J1+I
wzFv807HugIHkDKON8EOIG5CcIGDtP5dFbaTwQ5VIuvcH6oVOICs2bEt2KEa
xP+UD+eD3TsDwY/b5cnDZJ8P1w8272Ue3PxQPt1Ncyfnwe0Hyzvmwd239UTZ
vvmfcuHul41Ksb6/OBfuf7D6yFyIPdKhDv2HvmrECOc61Nqbxu2qDIXoO5vj
0DsdaOCNUIcJIPnuHKj5YQ5WW4AW+OdA1O8Mg/hfJAfiXsNwh70lwBC6l+1w
GxRvW8Ih7lmXDZF3jICYV5/tsMgVGMNnIiDhE5bt4NKd8/x3YqQDSFmjaTYk
Pv5HQs2Hqp8T5fCuBmjxryxI+nCMdtg3X0r/7ossiPybaIh/rmdB9M2IceC6
vrjA9lwWhPaKhfNh6Q3G/6YR039oaxxcvyXIn+nxcPPB7uJMgNsPTl/xCXD3
geU3JsDdfxwkzpAI9x84vP0T4f4Hq5uZCA8fsH/vJ8LDTwiUTlWT4OFbBJJP
T4KHv1PC0wtKi5Pg8QM2514SPP7A7hdOhscvWL1zMjz+LwKTT11RMjx9gINj
TjI8/fiA1O1NhqcviPnJ8PQHTh8/kuHpcw/I3Vwp8PQL9o90Cjx9F9gCQ1ol
BZ7+YXxY/oDxYfkHph+Wv2Dmw/IfzH5Y/oS5D5Z/Ye6H5W+wOVuS4fkfHO/L
kuHlA8z/sPLjLSie56Wgli+w8gupfAMAErP+jA==
                    
                    "]]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0., 0.501961, 0.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {CompressedData["

1:eJxdVwlsFGUUhspVJA1qQQUUVAS8KCagBSR9oFJ67uwxu7M7uwWZ+eeoFEtB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                    "], {{100., 176.39100000000002`}, {101.812, 176.695}, {
                    100.039, 173.637}, {99.16799999999999, 173.68}, {99.242, 
                    174.781}, {96.543, 174.676}, {98.21900000000001, 
                    175.63299999999998`}, {98.762, 175.984}, {99.367, 
                    176.25}, {100., 176.39100000000002`}}}]}}}}}}}}}}}}}}, 
                  AspectRatio -> Automatic, ImageSize -> {{128}, {85}}, 
                  PlotRange -> {{0., 480.}, {0., 241.}}], ",", 
                 GraphicsBox[{{{{{{{
                    Thickness[0.0010416666666666667`], {{{{{{{
                    Thickness[0.0010416666666666667`], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     480.}, {960., 480.}, {960., 320.}, {0., 
                    320.}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     320.}, {960., 320.}, {960., 160.}, {0., 
                    160.}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0., 0.478431, 0.23921600000000004`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     160.}, {960., 160.}, {960., 0.}, {0., 
                    0.}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.8078430000000001, 0.06666670000000002, 0.14902], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{0., 480.}, {
                    320., 240.}, {0., 0.}}}]}}}}}}}}}}}}}}, AspectRatio -> 
                  Automatic, ImageSize -> {{128}, {85}}, 
                  PlotRange -> {{0., 960.}, {0., 480.}}], ",", 
                 GraphicsBox[{{{{{{{
                    Thickness[0.0010416666666666667`], {{{{{{{
                    Thickness[0.0010416666666666667`], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     480.}, {960., 480.}, {960., 320.}, {0., 
                    320.}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     320.}, {960., 320.}, {960., 160.}, {0., 
                    160.}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0., 0.478431, 0.23921600000000004`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     160.}, {960., 160.}, {960., 0.}, {0., 
                    0.}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.8078430000000001, 0.06666670000000002, 0.14902], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{0., 480.}, {
                    320., 240.}, {0., 0.}}}]}}}}}}}}}}}}}}, AspectRatio -> 
                  Automatic, ImageSize -> {{128}, {85}}, 
                  PlotRange -> {{0., 960.}, {0., 480.}}]}], "}"}], ",", 
             RowBox[{"{", 
               RowBox[{
                 GraphicsBox[{{{{{{{
                    Thickness[0.0010416666666666667`], {{{{{{{
                    FaceForm[{
                    RGBColor[0.8509800000000001, 0., 0.0705882], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {0., 480.}, {960., 480.}, {960., 
                    0.}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0., 0.2, 0.627451], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     320.}, {960., 320.}, {960., 160.}, {0., 
                    160.}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0.9490200000000001, 0.6588240000000001, 0.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     160.}, {960., 160.}, {960., 0.}, {0., 
                    0.}}}]}}}}}}}}}}}}}}, AspectRatio -> Automatic, 
                  ImageSize -> {{128}, {85}}, 
                  PlotRange -> {{0., 960.}, {0., 480.}}], ",", 
                 GraphicsBox[{{{{{{{{
                    Thickness[0.0008333333333333334], {
                    FaceForm[{
                    RGBColor[0.870588, 0.160784, 0.06274510000000001], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {0., 800.}, {1200., 800.}, {1200., 
                    0.}}}]}}}}}}}}, {{{{{{{
                    RGBColor[1., 0.870588, 0.], 
                    
                    PolygonBox[{{{156.4073211147477, 585.837018249545}, {
                    129.465, 502.91799999999995`}, {200., 
                    554.1649280840463}, {270.53499999999997`, 
                    502.91799999999995`}, {243.5926788852523, 
                    585.837018249545}, {243.59267888525227`, 
                    585.837018249545}, {314.125, 637.082}, {
                    226.94199026174442`, 637.082}, {226.9419902617444, 
                    637.082}, {200., 720.}, {173.0580097382556, 637.082}, {
                    85.87499999999999, 637.082}}, {{365.699, 
                    699.4219999999999}, {394.02059683525385`, 
                    705.9407992661736}, {408.97299999999996`, 681.02}, {
                    411.5242212411751, 709.96961920159}, {439.84400000000005`,
                     716.488}, {413.10086862161455`, 727.8604005035999}, {
                    415.65200000000004`, 756.809}, {396.57181807195605`, 
                    734.8893074829407}, {369.828, 746.262}, {
                    384.7797301874549, 721.3423223683757}}, {{440.402, 
                    634.3439999999999}, {469.0343335503074, 
                    629.361789846223}, {473.14500000000004`, 600.594}, {
                    486.7292087861558, 626.2827677708841}, {486.7292087861558,
                     626.2827677708842}, {515.3589999999999, 
                    621.3009999999999}, {495.1246145642034, 
                    642.1591160197714}, {508.71099999999996`, 
                    667.8519999999999}, {482.6172094551196, 
                    655.0520653855589}, {462.383, 675.91}, {466.4935753121953,
                     647.1428479638266}}, {{465.6480604418864, 
                    514.7602115466024}, {457.66400000000004`, 486.816}, {
                    480.5486352299245, 504.73064709811763`}, {504.656, 
                    488.504}, {494.6909275247808, 515.8015762641411}, {
                    517.5740000000001, 533.715}, {488.53181121238066`, 
                    532.6734000943798}, {478.566, 559.9730000000001}, {
                    470.58218157485607`, 532.0296355119963}, {441.539, 
                    530.988}}, {{366.582, 418.01599999999996`}, {
                    394.60952440391605`, 425.7048046163738}, {
                    394.60952440391605`, 425.70480461637374`}, {410.582, 
                    401.42599999999993`}, {411.9307747145386, 
                    430.4565517714337}, {411.9307747145386, 
                    430.45655177143374`}, {439.957, 438.14500000000004`}, {
                    412.7643509911082, 448.3981538726199}, {414.113, 
                    477.42599999999993`}, {395.95886570694836`, 
                    454.73476442005847`}, {368.76599999999996`, 
                    464.98799999999994`}, {384.7381266235573, 
                    440.70972583588684`}}}]}}}}}}}}, AspectRatio -> Automatic,
                   ImageSize -> {{128}, {85}}, 
                  PlotRange -> {{0., 1200.}, {0., 800.}}], ",", 
                 GraphicsBox[{{{{{{{
                    Thickness[0.001388888888888889], {{{{{{{
                    FaceForm[{
                    RGBColor[0.870588, 0.160784, 0.06274510000000001], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {0., 480.}, {720., 480.}, {720., 
                    0.}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{359.97299999999996`, 240.07}, {275.762, 
                    275.66}, {313.09, 385.33599999999996`}, {393.625, 
                    379.82}, {377.33599999999996`, 371.449}, {
                    374.97299999999996`, 355.824}, {384.277, 
                    341.35200000000003`}, {394.695, 325.14500000000004`}, {
                    383.316, 299.07}, {369.234, 292.734}, {
                    346.08599999999996`, 282.316}, {341.449, 254.535}, {
                    359.97299999999996`, 240.07}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0.870588, 0.160784, 0.06274510000000001], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{355.41799999999995`, 319.26599999999996`}, {
                    350.684, 311.828}, {348.965, 320.47999999999996`}, {
                    340.42199999999997`, 322.688}, {348.125, 327.}, {
                    347.58599999999996`, 335.801}, {354.055, 329.809}, {
                    362.258, 333.043}, {358.57, 325.03499999999997`}, {
                    364.172, 318.22999999999996`}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}}}, {{{360.449, 240.99200000000002`}, {
                    350.262, 246.21899999999997`}, {342.051, 257.117}, {
                    338.47299999999996`, 270.137}, {334.383, 285.074}, {
                    336.734, 301.133}, {344.941, 314.168}, {343.172, 
                    315.28099999999995`}, {334.66, 301.73799999999994`}, {
                    332.219, 285.09}, {336.465, 269.58599999999996`}, {
                    340.246, 255.809}, {348.637, 244.71099999999998`}, {
                    359.4959999999999, 239.137}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{360.059, 240.047}, {367.883, 331.137}, {483.727, 
                    329.52299999999997`}, {503.371, 251.227}, {490.371, 
                    264.133}, {474.78099999999995`, 261.551}, {
                    463.89099999999996`, 248.23}, {451.699, 233.312}, {
                    423.387, 236.078}, {413.008, 247.516}, {395.945, 
                    266.312}, {368.094, 262.133}, {360.059, 
                    240.047}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0.870588, 0.160784, 0.06274510000000001], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{433.969, 268.85200000000003`}, {
                    425.43399999999997`, 271.059}, {433.133, 275.363}, {
                    432.59, 284.172}, {439.07, 278.18}, {447.27299999999997`, 
                    281.40999999999997`}, {443.574, 273.40599999999995`}, {
                    449.188, 266.60200000000003`}, {440.42999999999995`, 
                    267.637}, {435.691, 260.207}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}}}, {{{361.082, 239.879}, {
                    362.90599999999995`, 251.184}, {370.72999999999996`, 
                    262.35900000000004`}, {382.012, 269.78499999999997`}, {
                    394.949, 278.29299999999995`}, {410.949, 
                    281.01599999999996`}, {425.883, 277.242}, {
                    426.39799999999997`, 279.26599999999996`}, {410.887, 
                    283.176}, {394.29699999999997`, 280.355}, {380.867, 
                    271.527}, {368.93399999999997`, 263.672}, {360.969, 
                    252.262}, {359.02299999999997`, 
                    240.21499999999997`}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{360.062, 239.961}, {449.10900000000004`, 
                    260.668}, {483.375, 149.996}, {414.97999999999996`, 
                    107.117}, {423.23799999999994`, 123.46900000000001`}, {
                    415.965, 137.496}, {399.92999999999995`, 143.738}, {
                    381.977, 150.72299999999998`}, {375.855, 178.504}, {
                    383.527, 191.91}, {396.129, 213.945}, {383.551, 
                    239.14499999999998`}, {360.062, 239.961}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0.870588, 0.160784, 0.06274510000000001], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{410.29699999999997`, 178.566}, {409.758, 
                    187.36700000000002`}, {416.22999999999996`, 181.375}, {
                    424.441, 184.60899999999998`}, {420.746, 176.598}, {
                    426.35200000000003`, 169.79299999999998`}, {
                    417.59799999999996`, 170.84}, {412.85900000000004`, 
                    163.39800000000002`}, {411.137, 172.047}, {402.605, 
                    174.258}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}}}, {{{360.22299999999996`, 238.934}, {
                    371.53499999999997`, 240.691}, {384.582, 
                    236.70299999999997`}, {395.129, 228.26999999999998`}, {
                    407.219, 218.594}, {414.754, 204.21899999999997`}, {
                    415.777, 188.848}, {417.863, 188.984}, {416.789, 
                    204.945}, {408.977, 219.85200000000003`}, {
                    396.43399999999997`, 229.89800000000002`}, {
                    385.27299999999997`, 238.82000000000002`}, {
                    371.96099999999996`, 242.871}, {359.902, 
                    240.996}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{359.984, 239.92600000000002`}, {407.191, 
                    161.637}, {312.527, 94.848}, {250.60899999999998`, 
                    146.648}, {268.715, 143.844}, {279.809, 155.098}, {
                    280.789, 172.277}, {281.883, 191.512}, {306.414, 
                    205.918}, {321.53499999999997`, 202.762}, {346.387, 
                    197.586}, {366.465, 217.336}, {359.984, 
                    239.92600000000002`}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0.870588, 0.160784, 0.06274510000000001], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{317.117, 173.18}, {325.32, 176.41}, {321.621, 
                    168.40200000000002`}, {327.234, 161.598}, {
                    318.47299999999996`, 162.637}, {313.734, 
                    155.19899999999998`}, {312.02299999999997`, 163.848}, {
                    303.484, 166.055}, {311.176, 170.36700000000002`}, {
                    310.641, 179.164}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}}}, {{{359.055, 239.461}, {
                    364.22299999999996`, 229.24599999999998`}, {
                    364.46099999999996`, 215.602}, {359.699, 202.965}, {
                    354.22999999999996`, 188.477}, {342.89099999999996`, 
                    176.86700000000002`}, {328.59, 171.14499999999998`}, {
                    329.363, 169.20299999999997`}, {344.21099999999996`, 
                    175.156}, {355.97299999999996`, 187.191}, {361.648, 
                    202.23}, {366.688, 215.598}, {366.42599999999993`, 
                    229.512}, {360.91799999999995`, 
                    240.40200000000002`}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{359.92599999999993`, 239.99200000000002`}, {
                    300.055, 170.90200000000002`}, {207.281, 240.297}, {
                    237.414, 315.188}, {240.34, 297.105}, {
                    254.47299999999998`, 290.03099999999995`}, {271.113, 
                    294.40599999999995`}, {289.746, 299.309}, {311.027, 
                    280.42999999999995`}, {312.699, 265.078}, {315.453, 
                    239.844}, {340.445, 226.85200000000003`}, {
                    359.92599999999993`, 
                    239.99200000000002`}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0.870588, 0.160784, 0.06274510000000001], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{283.199, 260.137}, {288.809, 253.336}, {280.047, 
                    254.375}, {275.309, 246.934}, {273.59, 255.59}, {265.055, 
                    257.79699999999997`}, {272.75, 262.09799999999996`}, {
                    272.21099999999996`, 270.89799999999997`}, {278.688, 
                    264.91799999999995`}, {286.887, 268.141}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}}}, {{{359.195, 240.73399999999998`}, {
                    351.074, 232.66}, {338.176, 228.21899999999997`}, {
                    324.684, 228.84}, {309.215, 229.562}, {294.672, 
                    236.766}, {284.809, 248.598}, {283.203, 247.262}, {
                    293.453, 234.98000000000002`}, {308.53499999999997`, 
                    227.512}, {324.58599999999996`, 226.762}, {
                    338.85900000000004`, 226.098}, {352.008, 230.648}, {
                    360.66400000000004`, 239.254}}}]}}}}}}}}}}}}}}, 
                  AspectRatio -> Automatic, ImageSize -> {{128}, {85}}, 
                  PlotRange -> {{0., 720.}, {0., 480.}}], ",", 
                 GraphicsBox[{{{{{{{
                    Thickness[0.001388888888888889], {{{{{{{
                    FaceForm[{
                    RGBColor[0.996078, 0., 0.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {0., 480.}, {720., 480.}, {720., 
                    0.}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0., 0., 0.5843139999999999], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     480.}, {360., 480.}, {360., 240.}, {0., 
                    240.}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2,
                     0}, {0, 1, 0}, {0, 1, 0}}}, {{{204., 360.}, {180., 
                    270.}, {156., 360.}, {180., 450.}}, {{180., 336.}, {270., 
                    360.}, {180., 384.}, {90., 360.}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2,
                     0}, {0, 1, 0}, {0, 1, 0}}}, {{{200.785, 348.}, {135., 
                    282.059}, {159.21499999999997`, 372.}, {225., 
                    437.941}}, {{168., 339.215}, {257.941, 315.}, {192., 
                    380.78499999999997`}, {102.059, 405.}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2,
                     0}, {0, 1, 0}, {0, 1, 0}}}, {{{192., 339.215}, {102.059, 
                    315.}, {168., 380.78499999999997`}, {257.941, 405.}}, {{
                    159.21499999999997`, 348.}, {225., 282.059}, {200.785, 
                    372.}, {135., 437.941}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0., 0., 0.5843139999999999], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{231., 360.}, {231., 331.832}, {208.168, 309.}, {
                    180., 309.}, {151.83200000000002`, 309.}, {129., 
                    331.832}, {129., 360.}, {129., 388.168}, {
                    151.83200000000002`, 411.}, {180., 411.}, {208.168, 
                    411.}, {231., 388.168}, {231., 360.}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{225., 360.}, {225., 335.148}, {
                    204.85200000000003`, 315.}, {180., 315.}, {155.148, 
                    315.}, {135., 335.148}, {135., 360.}, {135., 
                    384.85200000000003`}, {155.148, 405.}, {180., 405.}, {
                    204.85200000000003`, 405.}, {225., 384.85200000000003`}, {
                    225., 360.}}}]}}}}}}}}}}}}}}, AspectRatio -> Automatic, 
                  ImageSize -> {{128}, {85}}, 
                  PlotRange -> {{0., 720.}, {0., 480.}}], ",", 
                 GraphicsBox[{{{{{{{
                    Thickness[0.001388888888888889], {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.9372550000000001, 0.698039, 0.17647100000000002`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {0., 480.}, {720., 480.}, {720., 
                    0.}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.886275, 0.23921600000000004`, 0.15686300000000003`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{0., 0.}, {
                    720., 0.}, {720., 480.}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{385.395, 
                    329.92999999999995`}, {381.402, 331.34400000000005`}, {
                    378.828, 329.28499999999997`}, {378.957, 324.133}, {
                    379.082, 318.97999999999996`}, {381.789, 316.02}, {
                    385.78099999999995`, 317.953}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{385.395, 
                    329.93}, {381.402, 331.344}, {378.828, 329.285}, {378.957,
                     324.133}, {379.082, 318.98}, {381.789, 316.02}, {
                    385.78099999999995`, 317.953}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    388.89799999999997`, 339.574}, {385.578, 342.199}, {
                    382.477, 341.074}, {380.941, 336.15200000000004`}, {
                    379.40999999999997`, 331.234}, {381.02, 327.562}, {
                    385.41799999999995`, 
                    328.10900000000004`}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    388.89799999999997`, 339.57399999999996`}, {385.578, 
                    342.19899999999996`}, {382.477, 341.07399999999996`}, {
                    380.941, 336.152}, {379.40999999999997`, 
                    331.23400000000004`}, {381.02, 327.562}, {
                    385.41799999999995`, 328.109}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    394.42999999999995`, 348.914}, {391.566, 
                    352.03499999999997`}, {388.328, 351.42199999999997`}, {
                    386.02299999999997`, 346.812}, {383.72299999999996`, 
                    342.203}, {384.72299999999996`, 338.32}, {389.156, 
                    338.15200000000004`}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    394.42999999999995`, 348.914}, {391.566, 
                    352.03499999999997`}, {388.328, 351.422}, {
                    386.02299999999997`, 346.812}, {383.72299999999996`, 
                    342.203}, {384.72299999999996`, 338.32}, {389.156, 
                    338.152}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{390.805, 
                    303.527}, {385.90999999999997`, 301.727}, {385.395, 
                    295.027}, {388.48799999999994`, 290.90599999999995`}, {
                    391.578, 286.78499999999997`}, {397.242, 286.012}, {
                    400.332, 290.90599999999995`}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{390.805, 
                    303.52700000000004`}, {385.90999999999997`, 
                    301.72700000000003`}, {385.395, 295.02700000000004`}, {
                    388.48799999999994`, 290.906}, {391.578, 286.785}, {
                    397.242, 286.01199999999994`}, {400.332, 290.906}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{385.137, 317.695}, {380.5, 
                    319.23799999999994`}, {376.324, 313.012}, {375.605, 
                    307.39099999999996`}, {374.707, 300.309}, {364.66, 
                    297.99199999999996`}, {370.199, 287.301}, {371.355, 
                    294.125}, {375.867, 297.85900000000004`}, {379.469, 
                    298.117}, {383.078, 298.375}, {388.48799999999994`, 
                    299.148}, {390.805, 303.527}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{385.137, 317.695}, {380.5, 319.238}, {376.324, 
                    313.01199999999994`}, {375.605, 307.391}, {374.707, 
                    300.30899999999997`}, {364.66, 297.99199999999996`}, {
                    370.199, 287.30100000000004`}, {371.355, 294.125}, {
                    375.867, 297.85900000000004`}, {379.469, 
                    298.11699999999996`}, {383.078, 298.375}, {
                    388.48799999999994`, 299.14799999999997`}, {390.805, 
                    303.52700000000004`}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{399.82, 
                    290.133}, {394.40999999999997`, 288.848}, {393.637, 
                    281.633}, {397.5, 276.484}, {400.805, 272.074}, {411.148, 
                    273.137}, {410.895, 277.512}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{399.82, 
                    290.133}, {394.40999999999997`, 288.84799999999996`}, {
                    393.637, 281.633}, {397.5, 276.48400000000004`}, {400.805,
                     272.07399999999996`}, {411.148, 273.137}, {410.895, 
                    277.51199999999994`}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, {{{415.14500000000004`, 
                    246.73399999999998`}, {415.39799999999997`, 251.371}, {
                    407.93399999999997`, 253.172}, {404.328, 
                    252.27299999999997`}, {400.719, 251.371}, {393.828, 
                    252.40200000000002`}, {392.219, 256.26599999999996`}, {
                    390.93399999999997`, 253.172}, {392.801, 249.824}, {
                    398.01599999999996`, 248.15200000000002`}, {401.965, 
                    246.883}, {401.879, 244.031}, {400.719, 242.742}, {
                    403.684, 242.227}, {412.441, 242.227}, {
                    415.14500000000004`, 
                    246.73399999999998`}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, {{{415.14500000000004`, 246.734}, {
                    415.39799999999997`, 251.371}, {407.93399999999997`, 
                    253.17199999999997`}, {404.328, 252.273}, {400.719, 
                    251.371}, {393.828, 252.402}, {392.219, 256.266}, {
                    390.93399999999997`, 253.17199999999997`}, {392.801, 
                    249.824}, {398.01599999999996`, 248.152}, {401.965, 
                    246.883}, {401.879, 244.031}, {400.719, 242.742}, {
                    403.684, 242.22700000000003`}, {412.441, 
                    242.22700000000003`}, {415.14500000000004`, 246.734}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{410.895, 276.355}, {405.613, 278.672}, {402.484, 
                    275.141}, {400.465, 271.719}, {397.5, 266.695}, {388.355, 
                    273.137}, {385.26599999999996`, 266.43799999999993`}, {
                    389.453, 268.242}, {393.715, 264.395}, {395.695, 
                    263.09}, {401.363, 259.355}, {412.309, 
                    260.51599999999996`}, {413.855, 
                    269.27299999999997`}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{410.895, 276.355}, {405.613, 
                    278.67199999999997`}, {402.484, 275.14099999999996`}, {
                    400.465, 271.719}, {397.5, 266.695}, {388.355, 273.137}, {
                    385.26599999999996`, 266.438}, {389.453, 
                    268.24199999999996`}, {393.715, 264.395}, {395.695, 
                    263.09000000000003`}, {401.363, 259.355}, {412.309, 
                    260.51599999999996`}, {413.855, 269.273}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    413.984, 270.172}, {408.703, 266.18}, {
                    406.64500000000004`, 261.414}, {406.77299999999997`, 
                    258.195}, {406.902, 254.977}, {411.40999999999997`, 
                    247.895}, {416.305, 247.508}, {419.137, 
                    253.30100000000002`}, {420.555, 265.53499999999997`}, {
                    413.984, 270.172}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    413.984, 270.17199999999997`}, {408.703, 
                    266.17999999999995`}, {406.64500000000004`, 261.414}, {
                    406.77299999999997`, 258.195}, {406.902, 254.977}, {
                    411.40999999999997`, 247.895}, {416.305, 
                    247.50799999999998`}, {419.137, 253.30100000000002`}, {
                    420.555, 265.53499999999997`}, {413.984, 
                    270.17199999999997`}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{392.094, 
                    245.316}, {392.094, 247.25}, {394.92599999999993`, 
                    248.023}, {396.855, 247.379}, {398.789, 
                    246.73399999999998`}, {401.75, 244.805}, {400.719, 
                    242.742}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{392.094, 
                    245.316}, {392.094, 247.25}, {394.92599999999993`, 
                    248.023}, {396.855, 247.379}, {398.789, 246.734}, {401.75,
                     244.805}, {400.719, 242.742}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    362.98799999999994`, 255.879}, {362.47299999999996`, 
                    258.195}, {366.207, 262.188}, {371.22999999999996`, 
                    260.}, {376.25, 257.809}, {376.895, 253.559}, {374.832, 
                    251.88700000000003`}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    362.98799999999994`, 255.879}, {362.47299999999996`, 
                    258.195}, {366.207, 262.188}, {371.22999999999996`, 
                    260.}, {376.25, 257.80899999999997`}, {376.895, 
                    253.559}, {374.832, 251.88700000000003`}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{375.219, 
                    251.629}, {374.832, 252.918}, {378.449, 
                    255.48800000000003`}, {384.621, 253.945}, {390.805, 
                    252.40200000000002`}, {392.32, 248.42200000000003`}, {
                    392.094, 245.316}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{375.219, 
                    251.629}, {374.832, 252.91799999999998`}, {378.449, 
                    255.488}, {384.621, 253.945}, {390.805, 252.402}, {392.32,
                     248.422}, {392.094, 245.316}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, {{{362.34400000000005`, 255.879}, {
                    365.562, 258.324}, {364.34400000000005`, 
                    262.96099999999996`}, {361.441, 264.379}, {356.16, 
                    266.953}, {358.094, 273.648}, {354.742, 
                    274.93799999999993`}, {351.395, 276.227}, {348.176, 
                    278.543}, {348.047, 280.863}, {346.371, 
                    277.64500000000004`}, {347.402, 274.68}, {
                    349.72299999999996`, 272.621}, {352.039, 270.559}, {
                    347.91799999999995`, 262.188}, {350.879, 
                    260.}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, {{{362.34400000000005`, 255.879}, {
                    365.562, 258.324}, {364.34400000000005`, 262.961}, {
                    361.441, 264.379}, {356.16, 266.953}, {358.094, 
                    273.64799999999997`}, {354.742, 274.938}, {351.395, 
                    276.22700000000003`}, {348.176, 278.543}, {348.047, 
                    280.863}, {346.371, 277.645}, {347.402, 
                    274.67999999999995`}, {349.72299999999996`, 272.621}, {
                    352.039, 270.55899999999997`}, {347.91799999999995`, 
                    262.188}, {350.879, 260.}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{293.316, 
                    257.68}, {290.60900000000004`, 261.92999999999995`}, {
                    284.172, 261.16}, {281.469, 258.195}, {278.762, 
                    255.23399999999998`}, {279.148, 250.85500000000002`}, {
                    281.72299999999996`, 
                    248.92600000000002`}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{293.316, 
                    257.67999999999995`}, {290.60900000000004`, 261.93}, {
                    284.172, 261.15999999999997`}, {281.469, 258.195}, {
                    278.762, 255.234}, {279.148, 250.85500000000002`}, {
                    281.72299999999996`, 248.92600000000002`}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{308.77, 
                    263.99199999999996`}, {307.73799999999994`, 269.656}, {
                    300.914, 270.301}, {297.18, 268.887}, {293.445, 
                    267.469}, {290.867, 261.801}, {293.316, 
                    257.68}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{308.77, 
                    263.99199999999996`}, {307.73799999999994`, 269.656}, {
                    300.914, 270.30100000000004`}, {297.18, 
                    268.88700000000006`}, {293.445, 267.469}, {290.867, 
                    261.80100000000004`}, {293.316, 257.67999999999995`}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{319.07, 264.76599999999996`}, {321.52, 
                    269.527}, {316.754, 276.613}, {311.34400000000005`, 
                    277.64500000000004`}, {306.828, 278.5}, {
                    301.49199999999996`, 278.47999999999996`}, {299.754, 
                    282.92199999999997`}, {298.66, 279.059}, {301.559, 
                    276.613}, {304.90599999999995`, 274.42199999999997`}, {
                    308.254, 272.234}, {304.262, 266.566}, {309.672, 
                    263.348}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{319.07, 264.766}, {321.52, 
                    269.52700000000004`}, {316.754, 276.61299999999994`}, {
                    311.34400000000005`, 277.645}, {306.828, 278.5}, {
                    301.49199999999996`, 278.48}, {299.754, 282.922}, {298.66,
                     279.05899999999997`}, {301.559, 276.61299999999994`}, {
                    304.90599999999995`, 274.422}, {308.254, 
                    272.23400000000004`}, {304.262, 266.56600000000003`}, {
                    309.672, 263.34799999999996`}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{318.555, 
                    264.60200000000003`}, {317.42999999999995`, 268.012}, {
                    319.715, 272.555}, {324.34400000000005`, 
                    272.23799999999994`}, {328.969, 271.91799999999995`}, {
                    331.605, 268.555}, {329.566, 
                    264.35200000000003`}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{318.555, 
                    264.602}, {317.42999999999995`, 268.01199999999994`}, {
                    319.715, 272.555}, {324.34400000000005`, 272.238}, {
                    328.969, 271.918}, {331.605, 268.555}, {329.566, 
                    264.352}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    328.85900000000004`, 264.34400000000005`}, {
                    328.22299999999996`, 267.879}, {331.121, 272.055}, {
                    335.66, 271.09}, {340.195, 270.125}, {342.332, 
                    266.42599999999993`}, {339.727, 262.551}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    328.85900000000004`, 264.344}, {328.22299999999996`, 
                    267.879}, {331.121, 272.055}, {335.66, 
                    271.09000000000003`}, {340.195, 270.125}, {342.332, 
                    266.42600000000004`}, {339.727, 262.55100000000004`}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    339.08599999999996`, 262.719}, {338.625, 
                    266.28099999999995`}, {341.734, 270.309}, {346.215, 
                    269.117}, {350.699, 267.92999999999995`}, {352.648, 
                    264.125}, {349.85200000000003`, 260.387}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    339.08599999999996`, 262.719}, {338.625, 
                    266.28100000000006`}, {341.734, 270.30899999999997`}, {
                    346.215, 269.11699999999996`}, {350.699, 267.93}, {
                    352.648, 264.125}, {349.85200000000003`, 
                    260.38700000000006`}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{261.375, 
                    203.72299999999998`}, {252.75, 203.72299999999998`}, {
                    250.641, 201.668}, {249.39800000000002`, 
                    192.77299999999997`}, {247.85500000000002`, 
                    181.69899999999998`}, {262.92199999999997`, 180.41}, {
                    261.375, 203.72299999999998`}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{261.375, 
                    203.723}, {252.75, 203.723}, {250.641, 201.668}, {
                    249.39800000000002`, 192.77300000000002`}, {
                    247.85500000000002`, 181.699}, {262.92199999999997`, 
                    180.41000000000003`}, {261.375, 203.723}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    265.242, 215.312}, {251.977, 220.336}, {244.766, 
                    199.344}, {231.629, 203.078}, {236.32800000000003`, 
                    195.60899999999998`}, {247.72299999999998`, 203.062}, {
                    251.977, 202.305}, {259.188, 201.016}, {274.77, 
                    203.72299999999998`}, {265.242, 215.312}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    265.242, 215.312}, {251.977, 220.33599999999996`}, {
                    244.766, 199.344}, {231.629, 203.07800000000003`}, {
                    236.32800000000003`, 195.60900000000004`}, {
                    247.72299999999998`, 203.06200000000007`}, {251.977, 
                    202.305}, {259.188, 201.01600000000002`}, {274.77, 
                    203.723}, {265.242, 215.312}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{256.613, 
                    186.594}, {250.04299999999998`, 189.555}, {242.961, 
                    179.512}, {244.25, 175.13299999999998`}, {245.883, 
                    169.57}, {260.863, 174.102}, {256.613, 
                    186.594}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{256.613, 
                    186.59400000000005`}, {250.04299999999998`, 189.555}, {
                    242.961, 179.51200000000006`}, {244.25, 
                    175.13299999999998`}, {245.883, 169.57000000000005`}, {
                    260.863, 174.10200000000003`}, {256.613, 
                    186.59400000000005`}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxlVGlIVFEUniwqF2pS2y1arIwQkwhR0U5URGU12aAzzvbefbOmY2ISpmaI
rahZZAuUie2E9MNKSsxKBlFplUJFzGwTNQmVLIuod+cbJqiBx51z37nf+c73
nfsWst2JlvEKhWKc/GyXHx/5OZceWPgoPo382y5nxPWLtCxyclVIdRptiTq2
VmgWyY/vxzuptOFrmP6ISBFdoRMLljipvmJORNcNgR7yNcBJnWP5u+rKTFRy
Vga0p9K6orTen756SuA4gw7st+uAl2mnjy8WdY5d03nq2mgbU2qigzWUESdn
XLFSdfmX641BWpLZtVS+tiH/8N/484578w/F6pHvstP+NauNtdMMlGk/OZg3
004rOc8SA/jV2Ygf25CfQoN5cuIbqzeOudO0t/63xRu78cosVDPy61X2/WTE
B81kqN0U4DPgibMkmn5rY09OiIYU/KeRwL9YTSEp5tjuKJF6coJvbSxQUxXf
iDAh3qemuVzA5ToK5uerVPQg69SsCTVaUr+/et6lSqTRMH1pQ5ceeK5E6LDY
iLVQTW6/fATUzUiCX4dFrz5GzjNWgh+hGjrBfXsuoX5PCvLnS/BhWEu87AIV
o0/8fL72Pzx3v0cF6HFSS5Ub5H8fjOjLlASeVXr43ZyMfkYNtGRiwel1I8l4
/8STf0CD/SAB+X1azIVLgF8GHeo1iYidHr5nGHTr01HSlPDq8jaJWjndGCP8
GzBTdt/SyMkJevS9wIp5iDRhvlosdGRGx7NvhSa8V1roJT+/2UTR/LxkJj42
a04biYcVNRJwuw3Qp53BH6UJugUyb3233isY3Rxq3cqUAvr5LgHfz0SXuF6z
LMAPF+guxzda4WO/QMd5fpoNutwW0G+6HfsXBMzzJBvwLgrwM9cKnGER811s
pmSuS6mIOncl8DB77quvBH73GOqsYrSUr/4M9zyaoY8iRuu5L7MlrEMMeinM
uDd7GfTvNYP/DxF+rbeAzzsG3aba6NCAfEEfi7j/T20UxC/YJpFy+RgGOrz1
3fq8ddAeTrzI871pdJDs1s73HSLqq/7mu/1ptOOcgqHfeQ7Pd8vDb0sq8M4z
+vf79gfoVTIT
                    "]]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxlVGlIVGEUnSzalDKLsjJps4wQk4gyKU+kRWk1meiMs733vVnVMYmISrFC
s0JbJK2gjfZ+DP0wExNbGcSijSiyxbIFSs2ipJ2od98dRqiBx5v7vbuce869
3wSxOsPRV6fT9VGfFeoToj4HCiJKr87Px+BHJwrndcqYmjDQF1Wbj/TZOxZI
N2Q+n+/FnutfYs3bZMS3Te6/JcaLq0fHxLedlXCF3mFePPtRkttUbcPO/WpC
dx5Qkf/21yAz5+n2oJLOW02cb40b7+5NfPrjtAmhWl0X0kW4IXGEAYXzVI+T
TtQd/nimebgRKrqbxx662L+8136/siF6a5KZ/f1ubE6eZW0cZsEad1V38Sg3
ZhDOnRbG1+RCmRqWWpKD7mLV8bkzaM+ta1l3+Y8jaGv5qh2o6/n9YP3FbLbL
7JAal4SFdAXstQpGnFv8cmOUATr6GRTGX5mJqBx70ovZMt5sVD22ZMJHB/E2
tJO9IRNjicBpJo736XFp7d7IfvVGGF6fOujXZ+BrrHn39TYz9JTPn4Fa4mGS
lfkozYSmV4jEdQuzWK9yOciPlXAmKWgnPSYbWLe7CuN5mcP+0QrCiPfPRlDZ
8XrB8SXG//Jp/W6X0EB8VBlxLLW+5/cbK/dly8Jywukzs943srmfrxao7Ncs
7Mnm77cC/psMiKHz4RL7dxh5XvwS62Uxcb0WmW1vAO8+gUjircOErCFxtYcf
KXhAcOdaWb8uO9Z3TEkYmG7GU+p7vJPnIcHG83XTgcqRj+98K7Xx93AHxy+1
IZHiFTtobJJrVJ5V82i9gjn054WF+WkVrE+4jec3QgTra3xPF/B9ur9MhEvc
z/cAvsE2HCe+Ih3IpfxxEi5QfqsT+0jHTgm7yD/fhSnEy3mJ+y1w874cknie
B7igyXNEYj2LnKinPJ9lnu9KO/OyW+Y+Ligcbw/s6yCF8TUI5n+mYH1CBdJo
PxMF91EhkEK6jFawiN6fBPOls+MD7c06wXXe2hn/T5n1SnEwnleC9RjqQnmX
uqDXZN7/2y7e2yUyimgMIzzB+ho/7R7usyJw3zR78OTOt1WvH8tcX9/rr+nT
7OY4neB+x3kQq91bAXxpeZzvoMC/99tff9QyQQ==
                    "], 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    237.42200000000003`, 151.691}, {231.758, 156.07}, {
                    223.90200000000002`, 150.789}, {218.49200000000002`, 
                    152.85200000000003`}, {218.49200000000002`, 
                    149.24599999999998`}, {220.297, 143.836}, {
                    226.21899999999997`, 141.777}, {228.023, 143.062}, {
                    236.137, 150.148}, {237.42200000000003`, 
                    151.691}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    237.42200000000003`, 151.69099999999997`}, {231.758, 
                    156.07000000000005`}, {223.90200000000002`, 
                    150.78900000000004`}, {218.49200000000002`, 
                    152.85199999999998`}, {218.49200000000002`, 
                    149.24599999999998`}, {220.297, 143.83599999999996`}, {
                    226.21899999999997`, 141.77700000000004`}, {228.023, 
                    143.06200000000007`}, {236.137, 150.14799999999997`}, {
                    237.42200000000003`, 151.69099999999997`}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{246.309, 
                    164.184}, {237.42200000000003`, 168.691}, {235.879, 
                    157.48800000000003`}, {228.92200000000003`, 159.805}, {
                    229.18, 156.586}, {231.758, 152.594}, {
                    237.42200000000003`, 151.691}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{246.309, 
                    164.18400000000003`}, {237.42200000000003`, 
                    168.69099999999997`}, {235.879, 157.488}, {
                    228.92200000000003`, 159.805}, {229.18, 156.586}, {
                    231.758, 152.59400000000005`}, {237.42200000000003`, 
                    151.69099999999997`}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{251.59, 
                    174.359}, {238.453, 179.512}, {236.777, 
                    166.89100000000002`}, {229.05100000000002`, 169.336}, {
                    230.85500000000002`, 164.95700000000002`}, {241.93, 
                    162.641}, {247.598, 164.184}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{251.59, 
                    174.35899999999998`}, {238.453, 179.51200000000006`}, {
                    236.777, 166.89099999999996`}, {229.05100000000002`, 
                    169.33599999999996`}, {230.85500000000002`, 164.957}, {
                    241.93, 162.64099999999996`}, {247.598, 
                    164.18400000000003`}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{269.617, 
                    229.605}, {266.141, 234.5}, {258.801, 230.508}, {257.641, 
                    224.71099999999998`}, {256.484, 218.918}, {259.316, 
                    210.805}, {264.21099999999996`, 212.605}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{269.617, 
                    229.605}, {266.141, 234.5}, {258.801, 
                    230.50799999999998`}, {257.641, 224.711}, {256.484, 
                    218.918}, {259.316, 210.805}, {264.21099999999996`, 
                    212.60500000000002`}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{278.504, 
                    245.062}, {272.453, 246.477}, {265.4959999999999, 
                    245.83200000000002`}, {266.27, 239.91}, {263.953, 
                    238.879}, {263.309, 231.281}, {269.617, 
                    229.605}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{278.504, 
                    245.06199999999998`}, {272.453, 246.477}, {
                    265.4959999999999, 245.832}, {266.27, 239.91}, {263.953, 
                    238.879}, {263.309, 231.28100000000003`}, {269.617, 
                    229.605}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{282.4959999999999, 249.05100000000002`}, {
                    276.574, 256.008}, {269.965, 255.844}, {266.27, 
                    252.918}, {259.445, 247.508}, {252.812, 250.598}, {
                    252.621, 245.18800000000002`}, {256.742, 248.344}, {
                    260.348, 244.547}, {263.695, 245.70299999999997`}, {
                    267.043, 246.863}, {269.49199999999996`, 
                    240.42600000000002`}, {278.762, 243.129}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{282.4959999999999, 249.05100000000002`}, {
                    276.574, 256.008}, {269.965, 255.844}, {266.27, 
                    252.91799999999998`}, {259.445, 247.50799999999998`}, {
                    252.812, 250.59799999999998`}, {252.621, 245.188}, {
                    256.742, 248.344}, {260.348, 244.547}, {263.695, 
                    245.703}, {267.043, 246.863}, {269.49199999999996`, 
                    240.42600000000002`}, {278.762, 243.129}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    268.203, 145.125}, {269.105, 143.44899999999998`}, {
                    274.641, 142.676}, {277.348, 145.512}, {
                    280.92999999999995`, 149.266}, {276.96099999999996`, 
                    159.676}, {271.29299999999995`, 160.44899999999998`}, {
                    265.625, 161.22299999999998`}, {265.113, 148.73}, {
                    268.203, 145.125}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    268.203, 145.125}, {269.105, 143.449}, {274.641, 
                    142.676}, {277.348, 145.51200000000006`}, {
                    280.92999999999995`, 149.26600000000002`}, {
                    276.96099999999996`, 159.676}, {271.29299999999995`, 
                    160.449}, {265.625, 161.223}, {265.113, 
                    148.73000000000002`}, {268.203, 145.125}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{261.762, 
                    144.86700000000002`}, {269.875, 141.906}, {273.355, 
                    148.602}, {268.977, 152.85200000000003`}, {267.816, 
                    151.434}, {263.566, 146.285}, {261.762, 
                    144.86700000000002`}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{261.762, 
                    144.86700000000002`}, {269.875, 141.906}, {273.355, 
                    148.60200000000003`}, {268.977, 152.85199999999998`}, {
                    267.816, 151.43400000000003`}, {263.566, 
                    146.28500000000003`}, {261.762, 144.86700000000002`}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYCYtmoFOv7r3McvM07HRN2Jji8q7E3jduV47DI
ddvnvyoJDtUi69wf7sp2OA5SwAOVn5XlYHBXha2xNsbBpTvn+e/KTAeu64sL
bB9FONw89z34cWqGwzeNmP5DqVEOVltOlO2Tz3CI3eXJw/Q6HK7+TeAOuVbp
KIi6ziyHNTJAhyyPcGAAgYhsh5DHS2cfuRDlkDHxbY39xBwHoGuuVEjGOTgl
PL2gNDkXIr8g1mH1x0u+STx5DkDTtduvxUP9kefgCFJXn+gAMvb+9QKHKpA/
yhId7vv3Ts97U+CgD3L/x2QHoCkKG3IKHOJA7lNOcRBuPnBq4cZcuHr08AEA
nyiJLw==
                    "]]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYCYtmoFOv7r3McfMw7HRN2Jji8q7E3jduV47DA
ddvnvyoJDtUi69wf7sp2OOYNVMADlZ+V5WBwV4WtsTbGwaU75/nvykwHnuuL
C2wfRTjcPPc9+HFqhsMPjZj+Q6lRDlZbTpTtk89wSNjlycP0Ohyu/k3gDrlW
6SiHbyB1nVkOa2SADlke4cAAAhHZDhGPl84+ciHKIWPi2xr7iTkOWz7/vVIh
GefglPD0gtLkXIj8gliH1R8v+Sbx5Dl48DBpt1+Ld/AG+yMPoq4+0QFk7P3r
BQ41IH+UJTrc9++dnvemAOL+j8kOQFMUNuQUQNynnOIg3Hzg1MKNuXD16OED
AKdgiUI=
                    "], CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{434.59, 328.512}, {444.895, 
                    325.16400000000004`}, {445.148, 311.77}, {
                    456.9959999999999, 307.39099999999996`}, {468.848, 
                    303.012}, {470.008, 292.453}, {479.66400000000004`, 
                    295.027}, {470.648, 297.477}, {471.29299999999995`, 
                    307.90599999999995`}, {461.895, 310.47999999999996`}, {
                    450.867, 313.504}, {446.695, 330.316}, {
                    437.93799999999993`, 
                    332.89099999999996`}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{434.59, 328.51199999999994`}, {444.895, 
                    325.164}, {445.148, 311.77}, {456.9959999999999, 
                    307.391}, {468.848, 303.01199999999994`}, {470.008, 
                    292.453}, {479.66400000000004`, 295.02700000000004`}, {
                    470.648, 297.477}, {471.29299999999995`, 307.906}, {
                    461.895, 310.48}, {450.867, 313.504}, {446.695, 
                    330.31600000000003`}, {437.93799999999993`, 332.891}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC0c0HTi2UrXOISrG+769Z4HBR6fbPOqs6hxl5
Qs0HzuU7vK2xN40zq3OQBSl4nOfgbd7pmHC+1mFvyWQJlmV5DrG7PHmY2Osc
GEAgASofWefg0p3z/PfCPIels48obGirc3gHMscq32EZiO9U5wC2lzfP4dMl
3ySBAij/b45D+b75Uvq3oeadyHFwf1glsm55nYO6IccamVm5DkBbw/ik6x1a
XwfukPubC1H3rQ7Cb82D8K3qHSYc+qoR453nYLXlRNm+0nqHm+e+Bz+emAsx
r7ge4k+5XAegpteBZ+odVn0EOuRJLkS9Yb3DY5DD3+Q5gLjz/eod9O+qsDUu
zXcAAC1GhAA=
                    "]]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC0c0HTi2UrXOISrG+769Z4HBR6fbPOqs6hxl5
Qs0HzuU7vK2xN40zq3OQBSl4nOfgbd7pmHC+1mFPyWQJlmV5DrG7PHmY2Osc
GEAgASofWefg3J3z/PfCPIels48obGirc3gHMscq32EZiO9U5wC2lzfP4dMl
3ySBAij/b45D+b75Uvq3oeadyHFwf1glsm55nYO6IccamVm5DkBbw/ik6x1a
XwfukPubC1H3rQ7Cb82D8K3qHSYc+qoR453nYLXlRNm+0nqHm+e+Bz+emAsx
r7ge4k+5XAegpteBZ+odVn0EOuRJLkS9Yb3DY5DD3+Q5gLjz/eod9O6qsDUu
zXcAACtug/0=
                    "], CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIxIGYC4p1yra8DP1U6rP54yTeJJ8MhKsX6vn9vpYNw
84FTC/dmOBz3Nu90TKp0UDfkWCNzL93h0FeNmH6DSocJIIY2VJ6p0qEoY+Lb
muIMB6Dm6XlHKhy+AZUdqs1wmJ4n1HxgTYWDEMg8U6j5zJUOxSD1+hkOi1y3
ff57o8JB/64KW+PKdIfc579XfmyodOgFaexIh8vfPPc9+HFhugOv7qa5779X
OFSLrHN/+CsVYm57hYMP0BkJvGkOQN/skPtf4TADZK9WKsQ8m0qHfpB7r6c5
aLeL3Tw3t9IBZL39xDS4fbd/1mXtaYDqP13pcAvE/wE1fzrUf86pDpMlWML4
Xlc6hPEBHeIO5fNWOQBNM43TS3Ow5bq+uEC8CuLepWkOAJL2qh0=
                    
                    "]]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIxIGYC4p1yra8DP1U6rPp4yTeJJ8MhKsX6vn9vpYNQ
84FTC/dmOBz3Nu90TKp0UDPkWCNzL93h0FeNmH6DSoc+EEMbKs9U6VCSMfFt
TXGGA1Dz9LwjFQ7fgMoO1WY4TM8DmrSmAmKeKdR8Zqh6/QyHRa7bPv+9UeFg
cFeFrXFlukPu898rPzYAzQdp7EiHy9869z34cWG6A6/uprnvv1c4VImsc3/4
KxVibnuFgw/QGQm8aQ5A3+yQ+1/hMA1kr1YqxDybSocJIPdeT3PQbhe7eW5u
pUMW0Hr7iWlw++78rMva0wDVfxrK/wE1fzrUvc6pDpMlWML4Xlc6hPEBHeIO
5fNWObyrsTeN00tzsOW6vrhAvAri3qVpDgCTRqol
                    "], 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIlIGYC4rhdnjxMzoUOMlEp1vfbExxkQbRsoYNQ84FT
C48mOMzIA7I2FThsPVG2b/6jBAeFDUUZEzsLHFpfB+6Q25jgsEMOyEoocAjn
0900tz7BYTpIfV6Bgypb41Tn4gSHqxUv1QwXFDiA7clOcPB4WCWy7mIBxNyk
BAf9uypsjYKFELo13uFtjb1p3LICh01z3y8/VhzvkPv898qPJQUOIOtas+Md
7LiuLy5oLXAwAKnvjYWolytwEFnn/rAqJ9ZhC8idHgUOIOe7zotxKN83X0r/
YIED0HbtdrVYh/v+vdPz3hQ4SIMs5IyDuO9JgUNxxsS3Nf6xDgwgoFQIUb8s
xgEUHP6chQ7/QeB4tIMiyP+hhQ5PLyjd/rks2gGkzV6z0AHkLFujOAcrkAMW
FjqAvOkuGAcJn4JCh15QwPyIhfinpdDhDcg/1jEOtiCNtwsdnoHMWxfjwKsL
8nmhA8hZHD4xkHA6VOiwyHXb578x0RD3/4G6b1q0g7d5p2PC9UKIO1KjIeF8
utDBEuSO5VEOIGPr/hU6iILCxyYKYr5+ESS8fKIh7vtRCAkPyXgH9PQAANOF
8IM=
                    "]]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIlIGYC4rhdnjxMzoUOMlEp1vfbExxkQbRsoYNQ84FT
C48mOMzIA7I2FThsO1G2b/6jBAeFDUUZEzsLHNpeB+6Q25jgsEOu9XVgQoFD
GJ/uprn1CQ7TQerzChzU2BqnOhcnOFyteKlmuKDAAWxPdoKDx8MqkXUXCyDm
JiU46N9VYWsULHQwANGt8Q5va+xN45YVOGyZ+375seJ4h9znv1d+LClweAO0
rjU73sGO6/rigtYCiPreWIh6uQIHkXXuD6tyYh22gNzpUeDQAnS+67wYh/J9
86X0DxY4+PAwaberxTrc9++dnvemwEECZDFnHMR9TwocSjImvq3xj3VgAAGl
Qoj6ZTEOoODw5yyEiJ+IdlAE+T+00OHFBaXbP5dFO4C02WsWOvAAnWVrFOdg
BXLAwkKHJ0BvugvGQcKnoNChBxQwP2Ih/mkphPjHOsbBFuSf21Dz1sU48AKD
8f3yQgeQszh8YiDhdKjQYYHrts9/Y6Ih7v9T6OABct+0aAdv807HhOuFDjkg
d6RGQ8L5dKGDBcgdy6McQMbW/SuEhI9NFMR8/SII3yca4r4fhZDwkIx3QE8P
ACEa65k=
                    "], CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{556.676, 274.34400000000005`}, {566.535, 
                    274.34400000000005`}, {574.523, 282.33599999999996`}, {
                    574.523, 292.195}, {574.523, 302.051}, {566.535, 
                    310.043}, {556.676, 310.043}, {546.8159999999999, 
                    310.043}, {538.828, 302.051}, {538.828, 292.195}, {
                    538.828, 282.33599999999996`}, {546.8159999999999, 
                    274.34400000000005`}, {556.676, 
                    274.34400000000005`}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{556.676, 274.344}, {566.535, 274.344}, {574.523, 
                    282.336}, {574.523, 292.195}, {574.523, 
                    302.05100000000004`}, {566.535, 310.043}, {556.676, 
                    310.043}, {546.8159999999999, 310.043}, {538.828, 
                    302.05100000000004`}, {538.828, 292.195}, {538.828, 
                    282.336}, {546.8159999999999, 274.344}, {556.676, 
                    274.344}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxdVGtIVEEUXm2RMBULDZMwrYiebAUVKtrZLNRKtASTKBHJksX23rm+3Ycz
V9IkJETIIkwkM+yHbKYmUZuViPgj1AyJFN3ETMosIySix8w9lxVcGIbZmXPm
e82NypFO564yGAw+fCTz4cvH+SfJAb5Ldsirm7cfviVBlEvJq0txgPb/Jhni
/MfuysMO6D9xqMacJMPiSEpO8G4nTKXWNlj9Zbh3uy/SVeX01keK+kcV8Lwp
3DRhlKB6/bvXS1so2ELaEz0jEkyLAiuFoc3vfznTZChx84N1FPtWybjfQSHJ
Ux7SXibDxrMXYicHKZgmtvoxkww3resqez/p9QEytMgcYSCDnogrn0/56f02
MDiSPcOPSPCGt800M+Ao0qcfSlA2t23f6kwGglacWwKD+JUxOMnpZTdKWN/M
sH+/BJanhfVhLxgIGKk7ZHj5c/u564sM+YTLcCPhWv5spAr1YcaMoFxdr/0q
cDUOZI3KyP+iCq1CpyldP4sKb0s5kAyC/ZNVmBR6thAoFffvVIGjmRlyEexv
VuHy7O+271SBV+L+YQbRnQPF7jMK4vdRcY5Q8Pw4gy6+3fRA72/U8RURELIm
zjHvOjiTd+pniDeLAHd9V7WbIc4ggjgGGPpxjOA9zxj6YCE4dzHg6vdElBC4
Ks536/q1Evgg7lMZ4g9XsF8aQz2+EfSnkGF+PDq+bAZi8lgJ+lXOgN8y2JxA
oPvHn9HSSwxzZtb1SWeYVxNBfZKW8Wt+xjKI1wwnsFbwXbPcP3BPR+PCVwpZ
or5gea3lrZJgLuap1x+tfo4in079/nGK+n3U9R6hqEeUAgv3+csZo5jPfAV1
cVNoELod1P1qo5irLwSOC/0bKfJ5TKBPEC1esR9K8T3eIYhrqAL9qSEQI3JR
VOH1V9P7qNPrh/Ze/zq8+mtzjwPzHKPgeq8D85mnIE+XHfNfq6BPPnbk06tg
Dv/ZEActwHzE23DfWAhBQs9oG9aHFiCPFrv3+7Ly+/MfbnUMuQ==
                    
                    "]]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxdVGtIFFEUXksizMSemIRpRfRkK6iwSL+lIu1BVmASJRI9TGxn7mil7q7e
O1JmESFFD8JCMsN+hJmVRC32wMQfoZskYaEmZVJZGRERPebsGVZo4TLcvXPO
+V53EnZpW/aMdDgcYdZKtdYIa+28lxo54ocX+ys+eZMvaEioM7IrNvqQSf9P
07EyovOK3u5D8/pl5a4UHUOBjbui5xeje9PJc+4IHVcvPomvO1ocqo+n+lsl
8F+Odb4O11A2+eWzHzMkPBNvrO0NaOijArdE+/Sun8VpOg7TixWS+x7V+bxe
IqW3aOKNQh1Tt+9e0d0q4Xw9c5Ry6jjvHl/a9F4iQPWROqp1C+FYhca4Ix82
j7L7TVFwZb1tm96l4bnVNsOlYKHY2ndTQ+HArEWjMxSI1kq/Bgf9ChWIXlal
xvVVivE1a8i5n3865qECwdg0R8ej77N3nBpSKCI+sTrOrjqR2x9v4kxMeHrU
HluvxSYGvclLMjt05r/XRA3p1GPrl2PiRYEFJF1w/1QTPaRntUABzZ9r4jgR
qBPc32Uit/9X7Vdp4DHNb1dY3tByyL/NYPxhJj/jDH7/lQIdX75u9w+38R0U
IFnXDqjQPjojsaGlWTHeTAHL9XllfsU4owTKCUeLYj/WCJ7zQOEc+ZAj2I/b
Cpb6jXGHBY7R+3ds/WoE3tA8UzH+WIP7pSnW44tgf/IVsik/vTa+LMV5cQv2
q0hhQmlTa9UqgTvffncU7FOcM5etz1bFeXUK1idlGH/QzxUKSUHDBcYR3zHD
/ccuqK/8PCi5Pm94H8xbqcAGysUnGfInWD8gmU+DPf+VZP3e2XoHJOuRYODz
NevmdErOZ66BNtLFL1m3pbZftZJxfxRYR/pX2njuCjwhoof+O58k8ZQCe0nw
PWwrYX/KBefiYEnI36Deq4tDfgTv6x9fSP/gs9HHeV5u8H6hDx2Uz2wDB4hn
nZfzf9Jgn8K8zKfJQCLN++thfWQe5yPJw+fh+YgiPRM9XD8pj+9PtTf0ffn/
+/MPmF0Mzg==
                    "], CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{337.22999999999996`, 138.945}, {346.758, 
                    138.945}, {354.48799999999994`, 146.672}, {
                    354.48799999999994`, 156.19899999999998`}, {
                    354.48799999999994`, 165.73}, {346.758, 
                    173.45700000000002`}, {337.22999999999996`, 
                    173.45700000000002`}, {327.699, 173.45700000000002`}, {
                    319.97299999999996`, 165.73}, {319.97299999999996`, 
                    156.19899999999998`}, {319.97299999999996`, 146.672}, {
                    327.699, 138.945}, {337.22999999999996`, 
                    138.945}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{337.22999999999996`, 138.945}, {346.758, 
                    138.945}, {354.48799999999994`, 146.67200000000003`}, {
                    354.48799999999994`, 156.199}, {354.48799999999994`, 
                    165.73000000000002`}, {346.758, 173.457}, {
                    337.22999999999996`, 173.457}, {327.699, 173.457}, {
                    319.97299999999996`, 165.73000000000002`}, {
                    319.97299999999996`, 156.199}, {319.97299999999996`, 
                    146.67200000000003`}, {327.699, 138.945}, {
                    337.22999999999996`, 138.945}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, CompressedData["
1:eJxFUw1IFEEUvqykX4kKKSkpMZHLyIIQrcMvKiQsLAOJLGv3bnYv0bKdOY0K
SU6RECupSCiRCosiQsxMKs0yUgKlhAopM7Myy35UJESFdu4NtjAsb2bf976f
2eX64VQ21eFwTLGXy15B9qoPL/qx86SF2tbcxspgN+auqqn4fd/CzxOJ6zJy
dVw8NN/fFMpxT57n61i6x7O+28WR8WDrnKASHccW3knqyeBoEOcWTfugUX8L
x+aSrL6xHg3eMhtphGNFcMGFTX6NcCIESiVwpAZ7en14g8D70fzMRzEaPqbY
J98FzddV/xNBfZkaknrsiSUCDvlc1vD6aH/Umt3qfEij/TBB/NJ15DVWhq2O
E0iQAle66T1doLP9765enxunNh748tIpcGuwY7ve6sbVLXXDE7Gq3uFBudQf
rb4v8pC+FEF67nrInyyBbXE20oQHx6UfOQKvIt6N5kcwqmsF4TgZ+fxH4LFN
qyuHIVn2zfSR3usM3VJ/jI/88TDiU+gjPQ/Vea2PdCQzVF16tqy6UdXpBs3b
4CMfBgwE8v0qyMcyAzK+lGblb52BpyPRe88YAgv8TS+uVBjolYBpAi2SWJZB
ffGKb6HC/8ZJ31oDzuLQzvZmTufjiu8Ax+y313JcToP8H+aYJesag3z4xBEv
+fYak3kE9DpMwo8ROCuJ7Tcn8wj4W2XSXF3xOW+Sn7cF3cM3JuloU/qemxiy
Y5xXrvJI9cIliSQKusd+L+X3mSMtxA42z4t90udiTrqzvZP3O5BTv5qfyhEl
809XfMPU94tN8nsGJ50JBrL7xm4OLuE4LQcNMKrHLcL5xWD/NWkh3RaOSGLV
jPo6LNJRyojvDYv2axjtH7QQ2xUZXNDGKE/X//ofZNLBEA==
                    
                    "]]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, CompressedData["
1:eJxFUw1IFEEUvqykwiQqpMSkREQuIwtCsg6/iJKwsAwksqzdu929RE125jRK
pFCRMCvpR6FEKiwCETEzKRPLMAkUEyoqzMzKLDN/kBAV2udbbGFY3sy89/3t
rlNPJmnzHQ7HPGu5rOVnrcbQwl8HzppoaM9urvR3Y+mGuoo/j0wM58ZtSc1W
UZa5PL8lSKCezvNUrDns2dbrEkh9vCfAr1jF6ZU18X2pAk3yyqoFnxTufymw
uzh9YKpPgbf0d27chECE/7lrO/MVPKQ5YRIXaHC4Agu9MfSpxIfJvLSmKAWf
E0vKMn9KjBC+avc/k4yfpiC+z0IslnDQc1PBm1ODEZsOSeY/pvB+sGR+KSpy
miuDN8ZIxNKA9W5+L7TwOv8e7Pe5cX7H8W9dTonq0e59arsbt3c1jM9E2/V+
D8pJf6R9v9DD+hIl63ngYX/SJfbGWJNmPDhDfmRJdId9nMwL07iul7hO95wa
6xiRaLFo9WRpSKC+xT72+66GXtIf5WN/PBrzKfCxnif2eb2PdSRoqLrxYm1t
s12n6Iy33cc+DOmYzfe7RBr5WKqD4ktslYzXoOP5ROSRS7qExe7VrQod/TQw
WaKNiKXr7P9WCbKxp8Ce/0Owvs06nEVB7ztbBeuZtvkOCSx5dyfL5dTZ/3GB
AKrrdPbzi2C+/fpcHhdJr8Pg+VESl4nYMWMuj1l/qwy8JlzV5nPVYD+rJXKp
762BFaSjw9bXZmDMinFZuZ1HkhcuIhYnEUJG5Hs5v68CyYFWsDleHCWfiwT7
leGd+75n8Qdt/CSBcMo/xeYbbN9fbbDfiwTnHasjY2Dq/miI4DyHNK6nTXTR
nGEN1l+THNhrwiRitRr7021yHiUa871n8n6dxvpOmIjusRh0aJyn63/9D4+S
wSA=
                    "], CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    293.059, 181.441}, {291.89799999999997`, 184.789}, {
                    293.43399999999997`, 187.805}, {294.215, 
                    190.45700000000002`}, {296.21099999999996`, 
                    197.21899999999997`}, {294.98799999999994`, 
                    198.95700000000002`}, {288.93799999999993`, 198.055}, {
                    288.42199999999997`, 194.836}, {291.512, 
                    184.27299999999997`}, {293.059, 181.441}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    293.059, 181.44099999999997`}, {291.89799999999997`, 
                    184.78900000000004`}, {293.43399999999997`, 187.805}, {
                    294.215, 190.457}, {296.21099999999996`, 
                    197.21900000000005`}, {294.98799999999994`, 198.957}, {
                    288.93799999999993`, 198.055}, {288.42199999999997`, 
                    194.83599999999996`}, {291.512, 184.27300000000002`}, {
                    293.059, 181.44099999999997`}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    288.613, 197.668}, {290.16, 196.121}, {295.633, 
                    195.414}, {296.21099999999996`, 200.309}, {296.879, 
                    205.92600000000002`}, {294.60200000000003`, 208.102}, {
                    289.707, 205.91}, {289.324, 204.621}, {288.871, 
                    199.344}, {288.613, 197.668}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    288.613, 197.668}, {290.16, 196.12099999999998`}, {
                    295.633, 195.41400000000004`}, {296.21099999999996`, 
                    200.30900000000003`}, {296.879, 205.926}, {
                    294.60200000000003`, 208.10200000000003`}, {289.707, 
                    205.91000000000003`}, {289.324, 204.62099999999998`}, {
                    288.871, 199.344}, {288.613, 197.668}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    289.77299999999997`, 206.102}, {291.832, 205.266}, {
                    296.277, 203.594}, {298.72299999999996`, 
                    208.35500000000002`}, {300.777, 212.35500000000002`}, {
                    298.078, 215.441}, {293.832, 215.184}, {292.801, 
                    214.023}, {290.73799999999994`, 209.90200000000002`}, {
                    289.77299999999997`, 206.102}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    289.77299999999997`, 206.10200000000003`}, {291.832, 
                    205.26600000000002`}, {296.277, 203.59400000000005`}, {
                    298.72299999999996`, 208.35499999999996`}, {300.777, 
                    212.35499999999996`}, {298.078, 215.44099999999997`}, {
                    293.832, 215.18400000000003`}, {292.801, 
                    214.02300000000002`}, {290.73799999999994`, 
                    209.90200000000004`}, {289.77299999999997`, 
                    206.10200000000003`}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    293.574, 215.57}, {294.08599999999996`, 214.023}, {
                    299.367, 208.871}, {303.22999999999996`, 212.605}, {
                    307.094, 216.344}, {307.094, 221.879}, {301.301, 
                    223.941}, {299.754, 223.684}, {295.117, 
                    218.27299999999997`}, {293.574, 215.57}}}]}}}}}}}, {{{{{{{
                    
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    293.574, 215.57000000000005`}, {294.08599999999996`, 
                    214.02300000000002`}, {299.367, 208.87099999999998`}, {
                    303.22999999999996`, 212.60500000000002`}, {307.094, 
                    216.344}, {307.094, 221.87900000000002`}, {301.301, 
                    223.94099999999997`}, {299.754, 223.68400000000003`}, {
                    295.117, 218.27300000000002`}, {293.574, 
                    215.57000000000005`}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    301.301, 223.941}, {302.457, 220.71899999999997`}, {
                    306.062, 215.184}, {312.762, 217.758}, {319.457, 
                    220.336}, {316.625, 228.70299999999997`}, {
                    313.53499999999997`, 230.379}, {311.72999999999996`, 
                    230.25}, {304.39099999999996`, 226.90200000000002`}, {
                    301.301, 223.941}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    301.301, 223.94099999999997`}, {302.457, 
                    220.71900000000005`}, {306.062, 215.18400000000003`}, {
                    312.762, 217.75799999999998`}, {319.457, 
                    220.33599999999996`}, {316.625, 228.703}, {
                    313.53499999999997`, 230.379}, {311.72999999999996`, 
                    230.25}, {304.39099999999996`, 226.902}, {301.301, 
                    223.94099999999997`}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    313.53499999999997`, 230.379}, {313.02, 227.547}, {
                    313.53499999999997`, 219.82000000000002`}, {322.676, 
                    219.94899999999998`}, {331.82, 220.078}, {329.246, 
                    230.766}, {326.92599999999993`, 232.312}, {323.191, 
                    232.312}, {316.883, 232.184}, {313.53499999999997`, 
                    230.379}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    313.53499999999997`, 230.379}, {313.02, 227.547}, {
                    313.53499999999997`, 219.82}, {322.676, 219.949}, {331.82,
                     220.07800000000003`}, {329.246, 230.76600000000002`}, {
                    326.92599999999993`, 232.31199999999998`}, {323.191, 
                    232.31199999999998`}, {316.883, 232.184}, {
                    313.53499999999997`, 230.379}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{327.312, 
                    231.92600000000002`}, {326.28499999999997`, 
                    229.73399999999998`}, {323.96099999999996`, 215.324}, {
                    341.867, 219.305}, {344.184, 219.82000000000002`}, {
                    350.234, 233.08200000000002`}, {327.312, 
                    231.92600000000002`}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{327.312, 
                    231.92600000000002`}, {326.28499999999997`, 229.734}, {
                    323.96099999999996`, 215.324}, {341.867, 219.305}, {
                    344.184, 219.82}, {350.234, 233.082}, {327.312, 
                    231.92600000000002`}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    337.10200000000003`, 230.637}, {335.301, 
                    228.83200000000002`}, {339.93399999999997`, 214.281}, {
                    352.039, 216.727}, {364.14500000000004`, 219.176}, {
                    353.97299999999996`, 232.953}, {337.10200000000003`, 
                    230.637}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    337.10200000000003`, 230.637}, {335.301, 228.832}, {
                    339.93399999999997`, 214.281}, {352.039, 
                    216.72700000000003`}, {364.14500000000004`, 219.176}, {
                    353.97299999999996`, 232.953}, {337.10200000000003`, 
                    230.637}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{347.402, 
                    228.44899999999998`}, {345.47299999999996`, 
                    224.45700000000002`}, {348.371, 212.605}, {363.309, 
                    212.605}, {376.848, 212.605}, {362.60200000000003`, 
                    228.191}, {347.402, 228.44899999999998`}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{347.402, 
                    228.44899999999998`}, {345.47299999999996`, 
                    224.45700000000002`}, {348.371, 212.60500000000002`}, {
                    363.309, 212.60500000000002`}, {376.848, 
                    212.60500000000002`}, {362.60200000000003`, 228.191}, {
                    347.402, 228.44899999999998`}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{359.121, 
                    224.969}, {358.15200000000004`, 222.758}, {356.965, 
                    210.195}, {374.578, 209.129}, {387.328, 
                    208.35500000000002`}, {384.23799999999994`, 
                    226.38700000000003`}, {359.121, 224.969}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{359.121, 
                    224.969}, {358.15200000000004`, 222.75799999999998`}, {
                    356.965, 210.195}, {374.578, 209.12900000000002`}, {
                    387.328, 208.35499999999996`}, {384.23799999999994`, 
                    226.38700000000003`}, {359.121, 224.969}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{378.055, 
                    219.691}, {375.867, 215.82800000000003`}, {373.547, 
                    206.168}, {392.863, 205.395}, {405.23799999999994`, 
                    204.89800000000002`}, {397.629, 219.434}, {378.055, 
                    219.691}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{378.055, 
                    219.69099999999997`}, {375.867, 215.82799999999997`}, {
                    373.547, 206.168}, {392.863, 205.39499999999998`}, {
                    405.23799999999994`, 204.89799999999997`}, {397.629, 
                    219.43400000000003`}, {378.055, 219.69099999999997`}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    394.15200000000004`, 216.727}, {391.32, 212.863}, {
                    393.40599999999995`, 205.285}, {400.59, 
                    203.85200000000003`}, {409.605, 202.047}, {410.895, 
                    210.547}, {404.715, 214.668}, {398.53099999999995`, 
                    218.789}, {394.15200000000004`, 216.727}, {
                    394.15200000000004`, 216.727}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    394.15200000000004`, 216.72700000000003`}, {391.32, 
                    212.863}, {393.40599999999995`, 205.28500000000003`}, {
                    400.59, 203.85199999999998`}, {409.605, 
                    202.04700000000003`}, {410.895, 210.54700000000003`}, {
                    404.715, 214.668}, {398.53099999999995`, 
                    218.78900000000004`}, {394.15200000000004`, 
                    216.72700000000003`}, {394.15200000000004`, 
                    216.72700000000003`}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    402.90999999999997`, 214.92600000000002`}, {
                    400.85200000000003`, 211.32000000000002`}, {402.125, 
                    202.562}, {415.78499999999997`, 202.562}, {418.621, 
                    202.562}, {429.441, 213.637}, {402.90999999999997`, 
                    214.92600000000002`}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    402.90999999999997`, 214.926}, {400.85200000000003`, 
                    211.32}, {402.125, 202.56200000000007`}, {
                    415.78499999999997`, 202.56200000000007`}, {418.621, 
                    202.56200000000007`}, {429.441, 213.637}, {
                    402.90999999999997`, 214.926}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{297.184, 46.98}, {308.246, 46.98}, {317.219, 
                    55.949}, {317.219, 67.012}, {317.219, 
                    78.07799999999999}, {308.246, 87.051}, {297.184, 
                    87.051}, {286.117, 87.051}, {277.148, 
                    78.07799999999999}, {277.148, 67.012}, {277.148, 
                    55.949}, {286.117, 46.98}, {297.184, 
                    46.98}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{297.184, 46.98000000000002}, {308.246, 
                    46.98000000000002}, {317.219, 55.94900000000001}, {
                    317.219, 67.01200000000006}, {317.219, 
                    78.07800000000003}, {308.246, 87.05099999999999}, {
                    297.184, 87.05099999999999}, {286.117, 
                    87.05099999999999}, {277.148, 78.07800000000003}, {
                    277.148, 67.01200000000006}, {277.148, 
                    55.94900000000001}, {286.117, 46.98000000000002}, {
                    297.184, 46.98000000000002}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxdVwtQVFUYRjGnFJ0syyegZNb4ptREI38lI80H8lriJexe7j4k3Lv3LrLs
7t01K3NMzQdSmWEPi4rspeaDEMmUmlJkzEZNhcxHpZmWOA41dc/5Dpepndm5
HM7j//7v//7v3B1qXZRaFBkREdHF+B43vl2Nb+/Rn2y6ss9Py6cVnGsa5qXF
dVUDx77rp2vNc6y3R3np8dbyvlu9forOlqac2afREw8ZKxf6aV3/bpm9t2j0
XdnPw+Mj/HTH0vqvX7epdIAtiAnQ2FPDui9RPTT0I49jzZcB+i0wdUL+QIUS
e3z/pntmkFrmraws6eGmpy60v3t1UpAyGZA9xeTvuzW51RXAeKOLLrN9wwJ0
Jzu/1Yn9CQFS2B81TqosMSKf9hODH3fFQRHsU+vHvrcd1HD9/tzV6/3U09iW
OMuBeJv9dCTu5E19up3e3rh/yEcn/DR5W2Np3UI78hodoJXs4Ag78CcG6Pih
G2lnt8iIJwcQ77BMTeyczQHabmyvqpOxf3uAnv11/s6YlWLc3rme8zw+SPfF
31ozeKuMfZ4g8I2QwWd1kF5icSbLxOvT2jnP8++nUznjaUcR7YwxIo3XzXme
f4lOBurLgTQZ9azUzfM4nnW6iYctm3pK7J9sx/rYkJk/x9cjBD4P2LG+KITz
sh00Ytndxw/tCdEbM3b88fcQwX9kmN67aghovQPnzQmjXq86yMn2e8Jk4YnZ
iclq3rgwtRllakhwkFENj+OBMPQz1E7j2PN66L/4bgvTbKbDCsFXY4hY+aom
ivx1gSdChl4/EPjHyNBXSwjrJDF/NWTyx/H0CmO9R9R3Yhh6tIj6URj6eUAm
V622rn+uwJshA39p2OSb6+XpsFmvt9wGEe+E6SALnFtEXzB91ot8vBL1yUrY
1rhF8Ndoo1lRXUcu2xSG/oMS8tQ71/+Hz70SfcniZwj8GyScP6lz3ME3r0eL
BDyxYdT5NYnOsL5sEvxJEuXtnhnVtSpEg9nGg2L+hRD09aAEfmaL+c9stIvp
sWvnmO/vJ/T0qM3UG4+nW6kXk8GHOvpvkBV1adOR75FC1KdVpx9u6q7aUYWo
X5OOfvyqAD71cIiYLE5VF5jrZzLeji1AvV4JUQ0HlA+9UIjY49bifOBbrZvz
3L9KdWJtlji3gBidawbp4C+zADhPBfHsWWj2J4/7VSH6YWMQec6xYv8a0c89
bPDBa0Hkv8qG/KvE+jyb6Qcd/Hf4B++PmzZKZn68V/jTfhvOjQuAlxgJT8Mv
ub+skujsFsPgogLAO0Uy/ZzzmSvOL/SDv4sSfHysn+7tvqQi6VMJfNWWg+9e
wm/qxLiiCLzo5aaeOY33lWP/F0Wo56hy+E2yDH5/95n9xOv3iw95NIh+/s0H
fUfb4d87fchrrvDngz7E324H3pM+9F+88PsdPtxXSx3m+tVs4oYD/z/rQ/9a
nfD/3T7ay/Lf5sT90OCjBMZXPxfqcthH0xn+FS74720+8Frjgk77lCGfnguB
47gX+5zF4CvsoROM77ISzL+soL/fcuKesHhwziaZRjL9xKuoV6wN/D4i5vOs
yO95D7FlN5YugK8c80Cv0xeAzwiVmll+k/Ohz3YxH5eH/hyh0qMrii+0D8gD
zidU6K04V/iWivrdk4P9hSrqSDno//Uq1t2RA91vV+k8M4JV2dBBsyruiRyc
O05DP27IEbxr6LeqbOT1rQY912fD3yO9xP49Q34S9ftHI+OUo2W7LIg7yYt7
IToTdTDeW/j5w9PB93kN8c+lwp8uach/bZo5z89bLtb/pKG/ojOwvkWjWFaY
MZnIb4kGPdgz0X8rNOB7zIJ8s8X+CRb4zQiN0hmwzRbx3qPR64yH8VnA/bcK
PM0WxD+qEjs2+WMLcH8s+P3RAt1fFHoIWdAffTWaa709K+HPDOCJ1IgtK7+U
Dn0M0Uw+OuL7mN/VpsL/b6jgPzaVnmd4z6v0uXGNdTudgnpVq7i3XCnojyyV
GMydbSnQwXMqJTH9OOeDrw0q/cM+D6Wa+ujgn/vfYjGfnAa9O1XwdUs66msX
+fvSEfduFXwnp6Pf3vFgbMlAf671CH/JQD+3KuaY55uqgO9n0swxr0d9CvQy
S4wb5yNemxv8fZMKPF0U3Avvp8FfDrvBS1Qm/PMuBfhnZCG/MwoNYo29Kwv9
eEBBvaqehH6iPWZ/cH7+Usx+4P3YrJDKCLuQi/yeUaCTTfk4v49i3kccj0UB
v4mFlM9wJinmfcrjDlDM+5bDOO3GuEAS78Vu6GugBB+qXmTeVy8yAbUXwx92
5cOvnE7Mjy5A3tNk4AvmwhcXFiGf0hzUt0Iy/YHXx1+EPmkR/mKVcc4H+cRe
P97c74APJBZgXYoL7xeRhThvwlPQZ6nVxNvx/sLvm3luxFnnRL09Cu7VeUI3
VV74atAN/pLKoINLJXga9xn3/7/E749Z5cj3Q7fp99yXunigj2WLUddKFXwe
XYw+OKZBH8vL0CfHvOb9wWFGliL+1ADm13rp/7+//gXT0gfv
                    
                    "]]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxdVwlsVFUULRSNYjGiKIiUTYIGRUBB22rlAiKLIKXb1G5MZ37/LNQ6f5nS
6fxZEBARRHZUxKIColbcAEEbrIBQjQo2iAFSaAUFFUVcQFKJzn3n9TfaZPLn
zdvuPfecc38HuB7LLk9OSkrqlPgcTnw6Jz5XD3137dmPw/TUGOd3BwYFadbO
2t7DXgvTb01TXdekBGlia02PzcEw9SlU7j3+sUkP3bNgjHNmmFb06pJ/9QaT
vq7+YfCIpDBdN6fhs5fcBu3lBX0tGtY86PLZhk4D3ta9Sz+x6Gdr9KjS3hpl
dv3mlcCkCB2f9vTqyq4BevRU22vn0iKUz4F8WEHhHpsntPotjNf4sW+QRdfy
+a0+7E+3KMBf6ny0ujIxcyxMYxPhDzzrpST+qw/TL7xvo5d2/Xlr8TMrwsTb
Mid7cd+6MDUNPHoxOtZDG9fs6f/2kTBlbGms2jnTQ8s5r6EWLeaDkzyIP9Oi
I19eyDmxQcV9qoX79qt0gM9ZZxFvr92pYv9Wi574afr2vk/LcVvH+gWM88gI
DR5xRV2fzSpt5X16BPENUYHnpgit4nsyVBL1ae2YF/n3jJLFOG0rp+195/00
fWTUnhf5V0bJ9C792cpRUc/VUfs8Ec/yqB0PLxvdLPdneLC+X8zOX8TXNQY8
93qwvjyG8wq9NGT+DYe//DBGL4/f9vul/hL/5Di9fi5BoBVenDc1jnq94CUf
79fjqO9ZDzGtpg2P0/lEmXaleylRDd17Z5yGM38GePD8M/bf+K6M0xTm4UqJ
V2OMtnGcd8v8ozKeJBV8fVPGf4cKfrXEsE6R8+diNn4inm5x+pXX67K+d8t4
HbJ+FAd/7lTJX28u71Us481TEX9V3MZb8OXxuF2v9QzEq3HopLicdjM/G2Q+
QYW6F6RvadwQpzrGr9FNk1M63zZ/bRz8jyjgWbRj/X/w/EihT/j+vDjyXaXg
/LSOcTveOtejRUE8/eI490UFujwQo3WMn6JQyQeTUjrXxqD/fXJ+UQz8uksB
PlPk/Ptu2sF87NwxFvt7xmgRA/GA2+Yb8nBRN6bBW1Ho7yYX6nI+iny/KkN9
WqN05GLUX397Gep3IAo9fuqET90Xo4YELZo3Oe31Exm3QzNQr+djVCcCKgVf
KEb8uKKiFPE9E7XnRV2qpB4edhLDufSmKPDLdyLO5gieV5XZ+hT1+LQMelgT
IT/nOdWF/Uulnru6cc5vEeS/2I38a+X6ErftB+34t/uH0MdFN01gP/7IAp57
3PQsnzvQAr/6KsAn4ZfCXxYrdGJDwuBSLMR7r2L7ucCzWJ5fFgZ+pxXgPixM
gy+fvXLcewrwqq8B3t2k3+yU45Xl8Odojc1nAeMtNdi/uxz1vL0GfjNBxbpf
Q7aeRP1+DCGPXVLPv4SAZ6oH/r09hPwelv68L4T7t3oQ79EQ9DdC+v22EOKY
47XXL+GJC15K5d9PhKBflw/+/0GI2Faat/jQH3aFgFdPP/i6P0TE8S/0w3+v
DNFJxrXOj77XvRr5XDUTfe9wELr0VQCvuE5HGe/qSsw/p8Ef1/toHvcJh448
1qp0G/NnhIH7+7mB7/1yvsSF/J7UaVFi2YU5M6iGcTmkUwrzdewM4Jlk0EHO
L6MU/GyT8wNLoM8hBj2wsOJU240lyO8hg9Yz3yqKUYcMgwZx/W4uwv4yA3Wk
Iuh/hYF11xZBb1sNOs1GsLiQ9vEPTQZViD5RBB8ebkKPq4roK4G7Cb3VFgK/
L0xaIoyyEP6eHKS5iZ/Hq4+gfv+YtOX3Swerdzhwb1oQ9U7NB78T7y1T+PzB
ucD7exP3f5cNfzpjIv9lOfa8OG+BXH/SpL9YX6l5WN9iUn8uzB35yG+2SWlc
D08+9LfQRHwPOpBvoUl/8P5RDvjNEJMKOLB1Dui9twk9jyxA3JcMxNPkwP0H
DTrJhXzHgXq8I/H91gE9nzZwf8wBffQwaYrrmoL0P/IQT7JJvKzmTC740d+0
8Wi/X/hdfTb8/4IB/Ptl05Mc7/cGNSTaWJdjWajXJnm/Pwv6KDCoD+NxPgs8
eMIgYv74pgOvVZIfadk2P9rxF/43S85PzAHffQbwviwX9fUY1ML5h3LRL2+Q
+U7Ihd5e1TF25EGfy3Twc3ce9Nyq2WORb7YGPs/NsceiHg1Z4MtkjXL5S+N0
3Hc+APw+z0Y8nTRycl94Iwe62x/AeSn58M/rNcQ/vgD5HdeoFwt7RwH0uFdD
vLWPgD+puq0Pgc/fmq0HoccmDf30VDHym6uBJ2tLcX53ze5HIh6Hhn6RWUal
HOc4ze6nwjdu1Ox+K34/FsD7nFOBn2wMoB/1VuBDmx6z+5XwybYK+MOOUviV
z4f5oU70oTEq4osUw9dnliOfqiLUd6Vi+4OoT7icPmcgWqS/uFTg92Yp3gv3
eJFXphN6yvIDj+QynDfqUeLXrC5VLjve9vcX4fPTAngu96HeugbfmqZTugAg
CF+NBHDPuGrw4Ewlnol+Jvz/b/n/x+Qa6PCtgO33Vbygkw5+zJ+F/rTaAJ4H
Z8HXDpngx4Jq8P1Q0O4fIszkKtw/2sL8siD9//+vfwEGCv4t
                    "], 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{515.8549999999999, 121.215}, {528.031, 
                    121.215}, {537.898, 131.08200000000002`}, {537.898, 
                    143.254}, {537.898, 155.42600000000002`}, {528.031, 
                    165.297}, {515.8549999999999, 165.297}, {503.684, 
                    165.297}, {493.812, 155.42600000000002`}, {493.812, 
                    143.254}, {493.812, 131.08200000000002`}, {503.684, 
                    121.215}, {515.8549999999999, 121.215}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{515.8549999999999, 121.21500000000003`}, {
                    528.031, 121.21500000000003`}, {537.898, 
                    131.08200000000005`}, {537.898, 143.25400000000002`}, {
                    537.898, 155.426}, {528.031, 165.29700000000003`}, {
                    515.8549999999999, 165.29700000000003`}, {503.684, 
                    165.29700000000003`}, {493.812, 155.426}, {493.812, 
                    143.25400000000002`}, {493.812, 131.08200000000005`}, {
                    503.684, 121.21500000000003`}, {515.8549999999999, 
                    121.21500000000003`}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{431.758, 
                    337.27}, {426.863, 315.633}, {430.984, 
                    305.84799999999996`}, {438.195, 296.31600000000003`}, {
                    453.10200000000003`, 276.621}, {464.984, 
                    231.66799999999998`}, {447.984, 202.305}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{457.512, 227.676}, {
                    459.574, 228.44899999999998`}, {463.43799999999993`, 
                    230.895}, {464.34000000000003`, 235.14499999999998`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{459.059, 
                    237.07399999999998`}, {459.703, 240.81199999999998`}, {
                    465.4959999999999, 242.41799999999998`}, {465.625, 
                    246.414}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{459.188, 251.629}, {
                    458.801, 255.492}, {464.984, 258.969}, {464.078, 
                    262.832}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{455.84000000000003`, 
                    265.53499999999997`}, {455.324, 267.72700000000003`}, {
                    460.98799999999994`, 271.84799999999996`}, {459.445, 
                    275.324}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{451.59, 
                    279.05899999999997`}, {450.42999999999995`, 281.508}, {
                    454.29299999999995`, 284.34000000000003`}, {452.621, 
                    286.914}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{445.40599999999995`, 
                    289.875}, {445.02, 291.55100000000004`}, {447.402, 
                    295.223}, {446.117, 297.40999999999997`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{439.227, 302.625}, {
                    439.73799999999994`, 303.27}, {441.805, 
                    304.81600000000003`}, {440.965, 306.746}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{434.977, 311.961}, {
                    435.812, 312.414}, {438.324, 313.188}, {438.004, 
                    315.055}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{306.062, 
                    69.14499999999998}, {300.914, 70.945}, {
                    294.47299999999996`, 68.37099999999998}, {293.188, 
                    63.988}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{297.051, 
                    60.}, {297.695, 64.375}, {304.39099999999996`, 
                    66.30900000000003}, {306.449, 64.25}, {302.199, 
                    66.56600000000003}, {300.141, 58.327999999999975`}, {
                    303.875, 58.06600000000003}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{338.51599999999996`, 
                    161.86700000000002`}, {335.42599999999993`, 160.32}, {
                    334.527, 154.65599999999995`}, {338.51599999999996`, 
                    150.40200000000004`}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    343.15200000000004`, 160.57800000000003`}, {340.965, 
                    158.77700000000004`}, {341.094, 153.36700000000002`}, {
                    344.312, 152.07800000000003`}, {341.60900000000004`, 
                    154.01200000000006`}, {344.312, 157.35899999999998`}, {
                    346.246, 157.488}, {348.176, 157.61700000000002`}, {
                    349.465, 155.29700000000003`}, {347.14500000000004`, 
                    152.98000000000002`}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{524.094, 
                    147.832}, {516.883, 149.76200000000006`}, {
                    511.08599999999996`, 141.39099999999996`}, {
                    517.6519999999999, 133.92200000000003`}, {
                    517.5269999999999, 141.13299999999998`}, {522.676, 
                    145.89799999999997`}, {528.988, 144.60900000000004`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    526.09, 139.62099999999998`}, {524.3159999999999, 
                    139.62099999999998`}, {523.3199999999999, 
                    138.23400000000004`}, {523.3199999999999, 
                    136.88299999999998`}, {523.3199999999999, 
                    135.46500000000003`}, {524.543, 134.113}, {526.539, 
                    134.113}, {527.828, 134.113}, {528.8589999999999, 
                    135.59400000000005`}, {528.8589999999999, 
                    136.75400000000002`}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{551.523, 
                    297.73400000000004`}, {552.6840000000001, 293.355}, {
                    558.738, 291.55100000000004`}, {563.5, 292.582}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{563.5, 
                    295.414}, {559.766, 295.285}, {556.676, 298.762}, {
                    556.934, 301.72700000000003`}, {556.934, 
                    299.53499999999997`}, {561.9569999999999, 298.504}, {
                    563.5, 299.922}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{307.867, 
                    148.344}, {306.83599999999996`, 150.92200000000003`}, {
                    310.957, 153.49599999999998`}, {311.08599999999996`, 
                    155.94099999999997`}, {311.215, 158.39099999999996`}, {
                    315.72299999999996`, 160.32}, {320.35900000000004`, 
                    155.68400000000003`}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{318.172, 
                    183.11700000000002`}, {317.27, 182.73000000000002`}, {
                    316.4959999999999, 182.21500000000003`}, {
                    315.72299999999996`, 181.957}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{327.055, 
                    169.07800000000003`}, {325.96099999999996`, 
                    169.01200000000006`}, {323.707, 169.14099999999996`}, {
                    322.484, 169.98000000000002`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{322.547, 
                    164.18400000000003`}, {321.648, 163.73400000000004`}, {
                    319.648, 162.961}, {318.49199999999996`, 
                    162.70300000000003`}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{278.375, 
                    86.39799999999997}, {278.246, 84.07800000000003}, {
                    280.566, 80.73400000000004}, {281.85200000000003`, 
                    79.70300000000003}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{288.42199999999997`, 
                    91.93799999999999}, {287.133, 90.00800000000004}, {
                    286.35900000000004`, 86.65599999999995}, {287.133, 
                    84.33999999999997}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    307.60900000000004`, 84.21100000000001}, {
                    305.29299999999995`, 85.75799999999998}, {
                    306.83599999999996`, 89.75}, {306.578, 
                    92.32400000000001}, {306.32, 94.89799999999997}, {
                    309.28499999999997`, 99.02000000000004}, {315.078, 
                    95.543}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{285.97299999999996`, 
                    98.89099999999996}, {288.29299999999995`, 
                    99.27700000000004}, {290.73799999999994`, 
                    99.14799999999997}, {292.28499999999997`, 
                    98.50800000000004}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{315.33599999999996`, 
                    106.23400000000004`}, {314.305, 104.81599999999997`}, {
                    314.051, 103.27000000000004`}, {313.92199999999997`, 
                    102.238}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{326.156, 106.488}, {
                    324.35200000000003`, 106.488}, {322.805, 
                    105.20300000000003`}, {322.03499999999997`, 
                    103.91400000000004`}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{301.172, 172.426}, {
                    303.22999999999996`, 171.71900000000005`}, {308.574, 
                    168.43400000000003`}, {308.77, 165.02000000000004`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{323.062, 189.168}, {
                    316.754, 189.29700000000003`}, {314.305, 195.738}, {
                    319.07, 195.738}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{334.395, 
                    180.53900000000004`}, {331.949, 179.51200000000006`}, {
                    333.10900000000004`, 175.26200000000006`}, {
                    336.58599999999996`, 173.199}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{319.328, 
                    140.10200000000003`}, {318.105, 141.64799999999997`}, {
                    319.715, 146.152}, {323.707, 144.805}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{328.72999999999996`, 
                    93.09800000000001}, {328.984, 97.02300000000002}, {
                    333.945, 99.344}, {335.941, 94.89799999999997}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{310.441, 
                    81.89499999999998}, {310.121, 86.20700000000005}, {
                    312.309, 87.625}, {314.242, 87.87900000000002}, {316.172, 
                    88.137}, {318.941, 86.531}, {320.22999999999996`, 
                    83.695}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{272.066, 
                    78.67200000000003}, {272.324, 81.25}, {274.512, 
                    83.95299999999997}, {276.832, 83.56600000000003}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{507.73799999999994`, 
                    193.031}, {506.062, 191.80900000000003`}, {504.969, 
                    186.33599999999996`}, {511.34400000000005`, 185.82}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{497.949, 
                    184.01600000000002`}, {497.949, 183.375}, {
                    498.78499999999997`, 182.473}, {499.305, 182.086}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{528.3439999999999, 
                    173.71500000000003`}, {526.668, 175.00400000000008`}, {
                    522.3519999999999, 169.78500000000003`}, {
                    526.2810000000001, 165.988}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{487.39099999999996`, 
                    130.445}, {486.42199999999997`, 134.113}, {
                    489.83599999999996`, 135.08200000000005`}, {493.055, 
                    134.30900000000003`}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{479.148, 156.457}, {
                    481.078, 157.74599999999998`}, {483.012, 
                    159.16400000000004`}, {485.46099999999996`, 159.805}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{478.121, 142.293}, {
                    478.121, 145.38299999999998`}, {479.66400000000004`, 
                    147.957}, {481.078, 148.73000000000002`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{489.449, 
                    177.83599999999996`}, {489.191, 174.10200000000003`}, {
                    490.73799999999994`, 170.49599999999998`}, {
                    491.89799999999997`, 168.56200000000007`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{520.102, 
                    177.57800000000003`}, {518.234, 177.}, {516.559, 
                    176.28900000000004`}, {515.8519999999999, 
                    174.74599999999998`}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{518.039, 
                    167.02000000000004`}, {518.9409999999999, 
                    167.78900000000004`}, {519.9730000000001, 
                    168.69099999999997`}, {520.4219999999999, 
                    169.33599999999996`}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{566.719, 279.445}, {
                    566.719, 275.84000000000003`}, {562.215, 273.906}, {
                    559.254, 276.22700000000003`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{576.512, 
                    279.31600000000003`}, {578.504, 277.77}, {585.395, 
                    279.25}, {583.7850000000001, 283.24199999999996`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{568.137, 258.582}, {
                    566.719, 258.84000000000003`}, {564.2730000000001, 
                    260.38700000000006`}, {563.242, 261.67199999999997`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{582.305, 269.273}, {
                    579.988, 268.75800000000004`}, {578.4409999999999, 
                    269.273}, {577.2810000000001, 269.785}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{545.73, 256.395}, {
                    547.016, 256.395}, {550.105, 256.90999999999997`}, {
                    552.234, 258.004}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{541.8669999999998, 
                    279.188}, {540.191, 279.379}, {538.9649999999999, 
                    279.05899999999997`}, {538.004, 278.414}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{567.8159999999999, 
                    272.879}, {567.3669999999998, 271.266}, {566.207, 
                    268.75800000000004`}, {564.7890000000001, 
                    267.65999999999997`}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{537.488, 267.211}, {
                    540.707, 268.629}, {544.6990000000001, 
                    257.67999999999995`}, {552.4259999999999, 261.543}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{553.07, 272.879}, {
                    552.039, 271.461}, {551.398, 269.273}, {551.266, 
                    267.34000000000003`}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{399.047, 289.621}, {
                    400.078, 289.746}, {401.879, 290.133}, {
                    402.26599999999996`, 291.422}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{266.527, 169.723}, {
                    270.39099999999996`, 167.531}, {273.09799999999996`, 
                    163.79700000000003`}, {271.42199999999997`, 
                    158.26200000000006`}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{443.60200000000003`, 
                    301.469}, {444.762, 300.695}, {449.14500000000004`, 
                    300.695}, {451.59, 301.59799999999996`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{454.68, 298.891}, {
                    454.551, 297.09000000000003`}, {455.066, 290.262}, {
                    451.59, 288.84799999999996`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{452.875, 289.746}, {
                    456.09799999999996`, 288.719}, {462.53499999999997`, 
                    289.105}, {464.59799999999996`, 295.02700000000004`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{460.09, 290.004}, {
                    461.762, 287.43}, {462.277, 282.406}, {457.258, 
                    279.703}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{461.375, 285.754}, {
                    465.10900000000004`, 284.469}, {473.73799999999994`, 
                    284.34000000000003`}, {472.83599999999996`, 
                    291.67999999999995`}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{469.875, 285.754}, {
                    472.453, 282.14799999999997`}, {483.78499999999997`, 
                    277.898}, {481.984, 285.371}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{459.445, 275.324}, {
                    463.824, 274.293}, {470.008, 277.25800000000004`}, {
                    467.42999999999995`, 284.98400000000004`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{479.79299999999995`, 
                    281.121}, {480.43799999999993`, 278.156}, {
                    494.85900000000004`, 275.06600000000003`}, {
                    492.92999999999995`, 281.762}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{490.22299999999996`, 
                    277.898}, {492.92999999999995`, 271.719}, {
                    507.22299999999996`, 272.23400000000004`}, {502.715, 
                    280.477}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{500.39799999999997`, 
                    274.03499999999997`}, {503.22999999999996`, 
                    270.55899999999997`}, {515.8519999999999, 272.621}, {
                    510.828, 280.99199999999996`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{510.699, 274.164}, {
                    518.555, 268.24199999999996`}, {527.6990000000001, 
                    276.74199999999996`}, {517.7810000000001, 282.922}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{522.2890000000001, 
                    276.09799999999996`}, {529.246, 270.55899999999997`}, {
                    537.746, 280.605}, {531.691, 283.438}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{467.301, 278.414}, {
                    469.48799999999994`, 277.77}, {474.125, 
                    278.02700000000004`}, {475.156, 282.02}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{473.41799999999995`, 
                    279.31600000000003`}, {473.16, 273.457}, {483.012, 
                    271.203}, {485.52299999999997`, 277.96500000000003`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{482.23799999999994`, 
                    274.293}, {484.043, 270.43}, {492.668, 
                    268.88700000000006`}, {494.08599999999996`, 274.422}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{492.668, 
                    271.84799999999996`}, {494.08599999999996`, 
                    267.98400000000004`}, {501.555, 268.371}, {503.617, 
                    272.363}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{500.914, 269.785}, {
                    503.22999999999996`, 264.766}, {512.762, 264.766}, {
                    514.949, 272.105}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{513.277, 
                    268.88700000000006`}, {517.012, 266.56600000000003`}, {
                    524.996, 267.469}, {524.3519999999999, 
                    274.67999999999995`}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{522.805, 
                    269.52700000000004`}, {528.3439999999999, 265.023}, {
                    536.1990000000001, 269.398}, {532.3359999999999, 277.}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{531.949, 263.605}, {
                    534.914, 264.121}, {536.4569999999999, 270.043}, {
                    533.3669999999998, 271.59000000000003`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{463.309, 
                    262.57399999999996`}, {469.48799999999994`, 265.922}, {
                    470.648, 271.59000000000003`}, {466.39799999999997`, 
                    277.129}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{468.59, 
                    268.24199999999996`}, {472.453, 265.922}, {
                    479.79299999999995`, 268.371}, {481.078, 
                    274.03499999999997`}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{473.871, 
                    267.59799999999996`}, {476.055, 264.766}, {476.441, 
                    261.285}, {473.60900000000004`, 258.06600000000003`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{475.672, 
                    263.99199999999996`}, {482.4959999999999, 
                    268.24199999999996`}, {490.9959999999999, 
                    260.38700000000006`}, {484.688, 255.621}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{483.527, 264.379}, {
                    485.074, 264.766}, {487.777, 267.59799999999996`}, {
                    488.03099999999995`, 270.81600000000003`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{486.617, 261.414}, {
                    489.449, 264.379}, {508.77, 258.324}, {
                    496.53099999999995`, 252.14499999999998`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{495.633, 
                    269.52700000000004`}, {499.367, 268.11299999999994`}, {
                    501.301, 262.832}, {495.633, 261.031}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{500.527, 256.652}, {
                    504.648, 260.902}, {517.5269999999999, 258.195}, {512.891,
                     252.78900000000002`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{509.801, 258.324}, {
                    512.117, 266.17999999999995`}, {525.898, 261.285}, {
                    521.391, 258.06600000000003`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{506.965, 
                    266.17999999999995`}, {507.35200000000003`, 264.637}, {
                    507.47999999999996`, 260.773}, {504.90599999999995`, 
                    258.711}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{518.555, 
                    267.72700000000003`}, {519.07, 266.438}, {
                    518.9409999999999, 263.99199999999996`}, {
                    517.7810000000001, 262.445}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{527.3119999999999, 
                    267.59799999999996`}, {528.086, 266.17999999999995`}, {
                    529.375, 263.477}, {526.539, 261.285}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{417.078, 326.836}, {
                    417.203, 319.496}, {419.78099999999995`, 314.602}, {
                    429.695, 319.238}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{420.168, 318.082}, {
                    415.27299999999997`, 311.51199999999994`}, {420.809, 
                    304.43}, {430.469, 311.51199999999994`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{405.10200000000003`, 
                    314.85900000000004`}, {411.79699999999997`, 
                    307.64799999999997`}, {423.77299999999997`, 312.93}, {
                    416.047, 323.875}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{424.16, 
                    308.67999999999995`}, {422.871, 301.59799999999996`}, {
                    428.668, 300.17999999999995`}, {433.42999999999995`, 
                    303.398}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{399.172, 313.703}, {
                    400.395, 306.582}, {407.672, 300.953}, {414.758, 
                    305.332}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{407.93399999999997`, 
                    303.914}, {407.93399999999997`, 293.74199999999996`}, {
                    421.969, 292.582}, {425.191, 303.14099999999996`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{420.168, 296.703}, {
                    424.672, 287.43}, {434.46099999999996`, 291.164}, {437.68,
                     296.832}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{410.25, 
                    311.51199999999994`}, {412.055, 307.004}, {415.66, 
                    301.98}, {424.03099999999995`, 305.719}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{384.49199999999996`, 
                    313.703}, {385.65200000000004`, 309.969}, {
                    392.35200000000003`, 305.461}, {400.078, 310.609}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{389.258, 308.938}, {
                    385.137, 302.88300000000004`}, {393.379, 297.219}, {
                    403.29699999999997`, 306.23}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{394.15200000000004`, 
                    301.469}, {395.828, 292.969}, {399.172, 
                    286.14099999999996`}, {411.28099999999995`, 
                    297.09000000000003`}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{405.227, 292.711}, {
                    409.605, 287.30100000000004`}, {416.305, 283.953}, {
                    422.613, 293.09799999999996`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{427.25, 
                    291.164}, {426.863, 284.72700000000003`}, {428.148, 
                    281.508}, {433.172, 281.762}, {437.133, 
                    281.96500000000003`}, {440.89799999999997`, 
                    285.11299999999994`}, {443.09, 288.461}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{432.27299999999997`, 
                    281.762}, {432.14500000000004`, 274.422}, {
                    437.93799999999993`, 268.629}, {448.758, 
                    276.09799999999996`}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{436.78099999999995`, 
                    273.137}, {434.719, 267.59799999999996`}, {
                    440.89799999999997`, 258.582}, {453.008, 263.219}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{411.148, 
                    287.81600000000003`}, {410.379, 280.73400000000004`}, {
                    416.945, 275.969}, {427.508, 285.11299999999994`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{416.305, 279.961}, {
                    416.691, 274.164}, {423.258, 267.211}, {
                    432.91799999999995`, 277.25800000000004`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{420.941, 272.621}, {
                    420.168, 262.703}, {429.309, 259.871}, {
                    437.03499999999997`, 267.469}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{407.16, 279.961}, {
                    409.219, 279.832}, {410.895, 281.633}, {
                    411.92199999999997`, 282.922}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{411.53499999999997`, 
                    272.75}, {413.34000000000003`, 272.363}, {
                    416.43399999999997`, 274.03499999999997`}, {417.465, 
                    276.09799999999996`}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{416.047, 261.031}, {
                    418.105, 258.84000000000003`}, {425.059, 
                    260.38700000000006`}, {425.96099999999996`, 
                    263.34799999999996`}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{423.77299999999997`, 
                    261.15999999999997`}, {427.637, 252.14499999999998`}, {
                    437.93799999999993`, 252.531}, {442.188, 262.703}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{440.258, 
                    259.09799999999996`}, {442.188, 253.816}, {447.082, 
                    250.469}, {455.066, 252.273}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{444.121, 253.688}, {
                    439.613, 246.34799999999998`}, {445.53499999999997`, 
                    237.719}, {455.578, 246.219}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{446.566, 242.742}, {
                    446.055, 238.105}, {450.305, 232.824}, {
                    456.09799999999996`, 232.184}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{427.508, 256.266}, {
                    425.96099999999996`, 245.832}, {433.42999999999995`, 
                    240.81199999999998`}, {442.832, 246.34799999999998`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{416.559, 251.242}, {
                    419.008, 249.309}, {423.387, 249.05100000000002`}, {
                    427.508, 250.59799999999998`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{432.53099999999995`, 
                    244.547}, {430.21099999999996`, 235.78900000000002`}, {
                    439.227, 229.477}, {446.953, 239.26600000000002`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{420.03499999999997`, 
                    249.824}, {420.168, 245.316}, {424.547, 
                    240.42600000000002`}, {432.14500000000004`, 241.84}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{453.395, 232.824}, {
                    448.23799999999994`, 229.34799999999998`}, {
                    447.21099999999996`, 223.168}, {454.42199999999997`, 
                    219.176}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{440.77, 234.629}, {
                    441.03099999999995`, 229.34799999999998`}, {443.477, 
                    226.38700000000003`}, {449.27, 225.871}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{433.172, 237.332}, {
                    425.445, 230.25}, {433.043, 222.00800000000004`}, {
                    442.188, 228.961}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{438.582, 226.773}, {
                    436.008, 218.65999999999997`}, {445.668, 
                    213.76600000000002`}, {450.816, 222.00800000000004`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{422.613, 244.031}, {
                    419.78099999999995`, 236.047}, {423.387, 
                    230.76600000000002`}, {429.953, 231.28100000000003`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{412.441, 
                    245.57399999999998`}, {412.828, 240.81199999999998`}, {
                    416.945, 239.137}, {421.582, 240.16799999999998`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{415.39799999999997`, 
                    240.555}, {411.92199999999997`, 233.85500000000002`}, {
                    417.203, 230.25}, {424.16, 232.824}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{445.28099999999995`, 
                    217.887}, {444.121, 213.637}, {444.762, 
                    210.54700000000003`}, {451.074, 209.12900000000002`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{445.668, 
                    211.83599999999996`}, {438.066, 208.35499999999996`}, {
                    437.42199999999997`, 201.01600000000002`}, {443.348, 
                    196.25}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{439.547, 
                    220.01200000000006`}, {435.555, 216.406}, {436.328, 
                    210.15999999999997`}, {440.707, 207.71500000000003`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{405.742, 243.516}, {
                    401.363, 239.19899999999998`}, {405.551, 
                    227.28900000000002`}, {415.207, 233.793}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{430.855, 
                    228.44899999999998`}, {424.92999999999995`, 223.555}, {
                    427.637, 214.668}, {437.42199999999997`, 217.113}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{421.066, 232.184}, {
                    417.977, 223.426}, {420.941, 220.33599999999996`}, {
                    427.895, 220.20700000000005`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{399.305, 
                    243.902}, {394.02299999999997`, 239.91}, {395.441, 
                    234.242}, {397.758, 231.66799999999998`}, {400.078, 
                    229.09}, {404.453, 230.25}, {405.871, 
                    233.59799999999998`}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{388.227, 247.379}, {
                    382.305, 239.78100000000003`}, {388.227, 
                    230.76600000000002`}, {396.60200000000003`, 233.469}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    419.90999999999997`, 224.84}, {413.855, 222.652}, {
                    409.23799999999994`, 217.15599999999995`}, {412.953, 
                    212.34799999999996`}, {415.14500000000004`, 
                    209.51600000000002`}, {424.672, 209.12900000000002`}, {
                    427.375, 220.07800000000003`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{408.965, 
                    231.92600000000002`}, {405.48799999999994`, 226.902}, {
                    406.64500000000004`, 222.137}, {413.082, 
                    219.69099999999997`}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{408.578, 
                    222.52300000000002`}, {404.84000000000003`, 220.461}, {
                    402.395, 218.01600000000002`}, {403.29699999999997`, 
                    213.50800000000004`}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{400.207, 230.379}, {
                    398.789, 224.328}, {400.465, 220.59000000000003`}, {
                    404.195, 218.78900000000004`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{400.078, 223.168}, {
                    394.28099999999995`, 223.555}, {391.32, 
                    221.10500000000002`}, {393.25, 215.44099999999997`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{393.76599999999996`, 
                    221.75}, {388.10200000000003`, 223.812}, {387.195, 
                    228.703}, {389.64500000000004`, 233.85500000000002`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{388.871, 226.258}, {
                    382.691, 226.}, {379.98799999999994`, 
                    222.91000000000003`}, {379.98799999999994`, 
                    218.65999999999997`}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{380.5, 
                    250.34}, {375.99199999999996`, 248.41}, {374.578, 
                    242.35500000000002`}, {376.25, 239.00799999999998`}, {
                    377.92599999999993`, 235.66}, {383.207, 235.402}, {
                    386.42599999999993`, 237.59}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{367.879, 255.105}, {
                    363.758, 250.469}, {368.52299999999997`, 241.453}, {
                    375.867, 243.64499999999998`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{357.32, 258.711}, {
                    353.457, 253.30100000000002`}, {357.707, 
                    244.28900000000002`}, {367.621, 246.863}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{368.137, 221.75}, {
                    367.105, 228.191}, {373.805, 232.441}, {382.047, 
                    224.07}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{378.055, 
                    237.07399999999998`}, {375.605, 234.88700000000003`}, {
                    374.449, 231.41}, {374.832, 228.57799999999997`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{346.758, 
                    261.80100000000004`}, {342.508, 254.59}, {
                    347.66400000000004`, 248.023}, {356.805, 
                    250.59799999999998`}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{370.58599999999996`, 
                    243.902}, {364.53099999999995`, 237.84799999999998`}, {
                    366.594, 231.79700000000003`}, {371.10200000000003`, 
                    228.32}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{366.719, 236.816}, {
                    357.578, 236.691}, {357.062, 226.129}, {
                    364.53099999999995`, 222.781}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{359.76599999999996`, 
                    247.379}, {356.03099999999995`, 244.805}, {354.871, 
                    237.719}, {361.312, 234.88700000000003`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{359.508, 231.539}, {
                    355.64500000000004`, 233.34}, {351.008, 231.152}, {
                    351.395, 226.64499999999998`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{353.715, 231.41}, {
                    350.234, 239.652}, {340.062, 238.234}, {340.965, 
                    229.734}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{356.547, 241.582}, {
                    354.35900000000004`, 241.195}, {349.97999999999996`, 
                    239.91}, {348.305, 236.559}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{348.949, 
                    250.85500000000002`}, {344.828, 246.219}, {348.047, 
                    240.684}, {351.395, 239.523}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{336.715, 263.863}, {
                    335.941, 258.324}, {338.133, 255.621}, {
                    345.08599999999996`, 256.137}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{339.16400000000004`, 
                    256.78100000000006`}, {336.457, 250.082}, {340.062, 
                    247.121}, {347.01599999999996`, 247.50799999999998`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{340.707, 248.539}, {
                    336.58599999999996`, 243.64499999999998`}, {
                    339.41799999999995`, 238.363}, {343.40999999999997`, 
                    236.176}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{338.777, 
                    242.35500000000002`}, {331.43799999999993`, 243.258}, {
                    330.277, 234.758}, {332.72299999999996`, 
                    230.76600000000002`}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    332.85200000000003`, 264.508}, {328.34400000000005`, 
                    262.57399999999996`}, {325.77, 256.90999999999997`}, {
                    328.215, 253.43}, {330.66400000000004`, 249.953}, {
                    335.555, 251.11299999999997`}, {338.258, 
                    252.91799999999998`}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{329.758, 
                    251.88700000000003`}, {326.027, 246.219}, {329.371, 
                    241.969}, {333.367, 240.29700000000003`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    315.33599999999996`, 265.152}, {312.375, 
                    262.05899999999997`}, {314.176, 255.75}, {
                    321.39099999999996`, 255.621}, {327.195, 255.516}, {
                    330.14500000000004`, 261.031}, {328.34400000000005`, 
                    264.895}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{320.35900000000004`, 
                    255.621}, {318.043, 250.469}, {319.457, 244.93}, {328.215,
                     245.832}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{331.949, 237.719}, {
                    326.539, 240.16799999999998`}, {319.328, 237.719}, {
                    322.42199999999997`, 231.28100000000003`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{321.648, 246.863}, {
                    319.457, 243.773}, {320.22999999999996`, 239.395}, {
                    322.676, 236.691}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{321.262, 238.621}, {
                    317.656, 237.977}, {314.176, 236.047}, {316.367, 
                    230.379}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{315.85200000000003`, 
                    235.016}, {311.215, 236.434}, {305.29299999999995`, 
                    233.082}, {308.89799999999997`, 228.32}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{308.125, 232.824}, {
                    304.133, 233.469}, {299.367, 229.219}, {
                    303.22999999999996`, 224.969}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{301.688, 
                    228.44899999999998`}, {298.078, 227.547}, {293.832, 
                    223.426}, {297.566, 220.20700000000005`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{319.84400000000005`, 
                    248.66799999999998`}, {314.691, 246.34799999999998`}, {
                    314.176, 240.555}, {316.625, 236.305}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{314.43399999999997`, 
                    259.355}, {306.707, 256.395}, {306.83599999999996`, 
                    246.09}, {315.33599999999996`, 242.871}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{311.72999999999996`, 
                    245.188}, {307.094, 242.484}, {306.191, 237.332}, {
                    309.28499999999997`, 233.984}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{303.617, 263.219}, {
                    300.527, 262.188}, {300.78499999999997`, 252.66}, {
                    309.027, 252.91799999999998`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{295.117, 260.}, {
                    288.93799999999993`, 255.879}, {296.40599999999995`, 
                    245.445}, {306.449, 252.91799999999998`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{300.914, 250.34}, {
                    300.012, 246.09}, {301.172, 241.453}, {307.9959999999999, 
                    240.938}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{301.301, 244.676}, {
                    296.40599999999995`, 242.871}, {295.504, 232.824}, {
                    304.39099999999996`, 232.055}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{285.715, 253.816}, {
                    279.40599999999995`, 248.023}, {290.867, 243.}, {295.117, 
                    251.371}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{276.96099999999996`, 
                    244.16}, {273.867, 240.42600000000002`}, {284.688, 
                    230.637}, {289.453, 246.992}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{290.60900000000004`, 
                    247.25}, {290.867, 243.38700000000003`}, {293.188, 
                    241.066}, {297.949, 240.81199999999998`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{297.824, 
                    237.07399999999998`}, {290.22299999999996`, 
                    235.91799999999998`}, {287.777, 226.38700000000003`}, {
                    296.277, 224.328}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{283.78499999999997`, 
                    238.363}, {283.527, 234.758}, {287.262, 
                    231.79700000000003`}, {291.512, 232.441}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{295.375, 224.582}, {
                    288.42199999999997`, 223.03900000000004`}, {287.52, 
                    214.02300000000002`}, {293.703, 214.53900000000004`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{290.47999999999996`, 
                    206.168}, {284.688, 207.906}, {284.559, 
                    214.79700000000003`}, {289.707, 217.37099999999998`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{285.715, 
                    212.223}, {280.824, 209.25799999999998`}, {282.754, 
                    202.176}, {285.332, 201.14499999999998`}, {
                    287.90599999999995`, 200.113}, {289.965, 
                    201.40200000000004`}, {290.22299999999996`, 
                    203.59400000000005`}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{289.83599999999996`, 
                    193.676}, {290.35200000000003`, 190.32799999999997`}, {
                    277.92599999999993`, 191.61700000000002`}, {284.301, 
                    202.04700000000003`}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{284.234, 193.098}, {
                    280.051, 186.52700000000004`}, {286.875, 
                    181.18400000000003`}, {291.191, 186.78500000000003`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{284.816, 185.176}, {
                    283.141, 179.89499999999998`}, {289.51599999999996`, 
                    176.098}, {293.637, 180.21900000000005`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{270.90599999999995`, 
                    234.629}, {268.59, 229.863}, {280.18, 
                    228.06199999999998`}, {280.953, 237.84799999999998`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{267.688, 227.547}, {
                    265.371, 218.27300000000002`}, {282.883, 
                    220.20700000000005`}, {278.375, 232.184}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{278.762, 226.}, {
                    281.21099999999996`, 224.582}, {288.551, 
                    224.45700000000002`}, {290.35200000000003`, 
                    232.31199999999998`}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{285.074, 225.742}, {
                    285.59, 223.29700000000003`}, {287.777, 
                    220.33599999999996`}, {289.83599999999996`, 
                    219.43400000000003`}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{276.703, 
                    223.29700000000003`}, {275.92999999999995`, 
                    218.27300000000002`}, {280.953, 214.152}, {286.746, 
                    214.53900000000004`}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{277.60200000000003`, 
                    218.40200000000004`}, {274.77, 214.53900000000004`}, {
                    273.867, 207.07000000000005`}, {282.754, 206.555}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{264.082, 217.113}, {
                    262.66400000000004`, 213.12099999999998`}, {
                    271.03499999999997`, 209.}, {275.92999999999995`, 
                    215.57000000000005`}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{261.504, 
                    206.94099999999997`}, {260.79699999999997`, 
                    203.91400000000004`}, {268.332, 199.85899999999998`}, {
                    272.582, 212.73400000000004`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{269.234, 206.168}, {
                    271.03499999999997`, 202.949}, {277.09, 
                    200.37099999999998`}, {280.824, 206.68400000000003`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{274.77, 202.82}, {
                    273.227, 198.312}, {277.477, 194.06200000000007`}, {
                    282.625, 195.35199999999998`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{265.113, 
                    203.85199999999998`}, {264.082, 197.41000000000003`}, {
                    271.551, 193.676}, {276.188, 197.02300000000002`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{260.219, 
                    201.01600000000002`}, {258.027, 192.77300000000002`}, {
                    268.59, 189.68400000000003`}, {272.582, 
                    195.86700000000002`}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{269.875, 193.418}, {
                    270.262, 188.781}, {277.477, 184.78900000000004`}, {
                    283.141, 188.652}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{257., 189.555}, {256.484,
                     187.49599999999998`}, {265.113, 185.43400000000003`}, {
                    266.39799999999997`, 192.64499999999998`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{262.02, 
                    187.75400000000002`}, {264.082, 182.473}, {
                    271.03499999999997`, 181.18400000000003`}, {275.027, 
                    187.625}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{272.71099999999996`, 
                    185.04700000000003`}, {273.60900000000004`, 180.152}, {
                    279.92199999999997`, 177.449}, {285.46099999999996`, 
                    180.79700000000003`}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{287.777, 
                    178.86700000000002`}, {286.35900000000004`, 
                    172.29700000000003`}, {293.188, 167.02000000000004`}, {
                    297.43799999999993`, 170.625}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{276.832, 
                    180.02300000000002`}, {274.77, 172.812}, {
                    283.78499999999997`, 168.69099999999997`}, {288.809, 
                    172.68400000000003`}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{266.012, 
                    183.62900000000002`}, {265.4959999999999, 
                    176.93400000000003`}, {270.777, 172.94099999999997`}, {
                    276.832, 175.90200000000004`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{254.55100000000002`, 
                    182.988}, {252.75, 178.60900000000004`}, {262.277, 
                    175.00400000000008`}, {266.78499999999997`, 178.738}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{248.629, 
                    171.01200000000006`}, {251.07399999999998`, 168.176}, {
                    259.574, 171.01200000000006`}, {260.348, 177.32}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{258.027, 
                    172.68400000000003`}, {261.121, 169.07800000000003`}, {
                    268.46099999999996`, 167.14799999999997`}, {
                    271.42199999999997`, 174.875}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{268.848, 
                    170.88299999999998`}, {268.719, 165.344}, {278.633, 
                    161.35199999999998`}, {281.85200000000003`, 
                    171.52700000000004`}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{293.508, 
                    169.52700000000004`}, {292.605, 166.824}, {
                    294.72999999999996`, 162.51200000000006`}, {299.176, 
                    161.99599999999998`}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{285.332, 
                    171.20300000000003`}, {284.688, 168.113}, {289.195, 
                    163.79700000000003`}, {293.957, 165.53500000000003`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{294.85900000000004`, 
                    164.25}, {293.574, 160.89799999999997`}, {294.668, 
                    156.07000000000005`}, {299.176, 156.137}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{295.312, 
                    158.00400000000008`}, {291.96099999999996`, 
                    155.17200000000003`}, {293.379, 150.14799999999997`}, {
                    298.207, 149.95299999999997`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{293.574, 153.238}, {
                    288.809, 150.02000000000004`}, {290.47999999999996`, 
                    142.938}, {296.79299999999995`, 143.32}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{279.148, 
                    166.89099999999996`}, {279.148, 159.93400000000003`}, {
                    287.777, 158.906}, {289.453, 165.344}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{286.10200000000003`, 
                    161.223}, {284.816, 157.10200000000003`}, {
                    288.16400000000004`, 153.10900000000004`}, {293.445, 
                    154.27000000000004`}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{287.133, 
                    111.51200000000006`}, {288.29299999999995`, 
                    109.83599999999996`}, {293.059, 112.67200000000003`}, {
                    291.77, 115.50400000000008`}, {290.47999999999996`, 
                    118.33599999999996`}, {285.43399999999997`, 
                    116.79700000000003`}, {285.97299999999996`, 113.832}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{290.60900000000004`, 
                    116.66400000000004`}, {291.254, 122.332}, {284.559, 
                    123.23000000000002`}, {282.883, 118.33599999999996`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{285.332, 
                    121.17200000000003`}, {287.004, 124.00400000000008`}, {
                    281.34000000000003`, 127.86700000000002`}, {279.02, 
                    123.74599999999998`}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{281.082, 
                    125.42200000000003`}, {282.625, 129.543}, {276.188, 
                    131.344}, {275.672, 127.60900000000004`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{274.254, 
                    133.02000000000004`}, {275.027, 135.08200000000005`}, {
                    282.23799999999994`, 133.793}, {279.148, 129.543}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{284.688, 
                    124.39099999999996`}, {287.52, 126.96500000000003`}, {
                    282.754, 132.24599999999998`}, {279.79299999999995`, 
                    130.312}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{303.746, 
                    116.53500000000003`}, {301.49199999999996`, 
                    116.27700000000004`}, {299.176, 114.79700000000003`}, {
                    300.848, 110.031}, {302.008, 106.72300000000001`}, {
                    306.965, 106.555}, {307.672, 108.55099999999999`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    300.46099999999996`, 114.15199999999999`}, {
                    298.27299999999997`, 115.57000000000005`}, {293.508, 
                    113.18799999999999`}, {295.695, 108.55099999999999`}, {
                    297.34400000000005`, 105.05900000000003`}, {
                    301.49199999999996`, 106.488}, {302.137, 108.293}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{288.16400000000004`, 
                    107.52000000000004`}, {289.258, 105.59000000000003`}, {
                    294.72999999999996`, 106.42200000000003`}, {295.695, 
                    108.55099999999999`}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{291.89799999999997`, 
                    113.89499999999998`}, {293.059, 114.668}, {295.18, 
                    113.70300000000003`}, {295.633, 112.738}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{291.512, 
                    145.64099999999996`}, {287.777, 143.195}, {290.094, 
                    135.723}, {295.89099999999996`, 137.65599999999995`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{290.35200000000003`, 
                    139.586}, {287.39099999999996`, 137.27000000000004`}, {
                    290.094, 130.05900000000003`}, {295.633, 
                    132.76200000000006`}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{291.254, 
                    132.76200000000006`}, {289.195, 130.699}, {291.191, 
                    124.96900000000005`}, {296.53499999999997`, 
                    126.06200000000007`}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{290.47999999999996`, 
                    129.926}, {289.324, 130.445}, {286.29699999999997`, 
                    130.05900000000003`}, {285.008, 128.125}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{287.133, 
                    156.00800000000004`}, {284.301, 153.301}, {
                    285.65200000000004`, 147.76200000000006`}, {
                    290.93399999999997`, 147.312}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{286.10200000000003`, 
                    150.33999999999997`}, {282.047, 148.344}, {282.047, 
                    140.29700000000003`}, {290.16, 139.973}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{285.78099999999995`, 
                    141.26200000000006`}, {283.527, 139.457}, {284.621, 
                    132.50400000000008`}, {290.41799999999995`, 133.406}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{287.648, 
                    133.66400000000004`}, {286.812, 132.82799999999997`}, {
                    286.684, 130.699}, {287.39099999999996`, 129.801}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{285.074, 136.305}, {
                    283.012, 136.238}, {280.309, 134.75799999999998`}, {
                    279.59799999999996`, 132.63299999999998`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{275.863, 
                    140.10200000000003`}, {276.637, 142.16400000000004`}, {
                    283.012, 142.03500000000003`}, {283.46099999999996`, 
                    135.98000000000002`}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{284.105, 143.195}, {
                    283.203, 143.}, {281.469, 142.16400000000004`}, {
                    281.01599999999996`, 140.42200000000003`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{281.34000000000003`, 
                    162.05900000000003`}, {278.57, 159.54700000000003`}, {
                    277.219, 151.62900000000002`}, {285.65200000000004`, 
                    150.08200000000005`}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{275.734, 
                    145.70300000000003`}, {275.734, 147.832}, {281.469, 
                    149.63299999999998`}, {283.46099999999996`, 
                    146.47700000000003`}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{272.066, 
                    157.23000000000002`}, {272.902, 155.62099999999998`}, {
                    276.895, 153.43}, {279.34000000000003`, 
                    155.23400000000004`}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    251.33200000000002`, 169.85199999999998`}, {
                    251.20299999999997`, 166.11700000000002`}, {
                    254.29299999999998`, 162.77000000000004`}, {258.543, 
                    163.281}, {262.79299999999995`, 163.79700000000003`}, {
                    263.695, 167.531}, {262.40599999999995`, 
                    169.98000000000002`}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{259.188, 
                    163.15599999999995`}, {256.355, 159.676}, {259.832, 
                    154.78500000000003`}, {263.051, 156.199}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{262.40599999999995`, 
                    165.60200000000003`}, {264.082, 166.24599999999998`}, {
                    269.617, 167.02000000000004`}, {271.29299999999995`, 
                    164.44099999999997`}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{244.508, 
                    164.57000000000005`}, {243.21899999999997`, 
                    162.64099999999996`}, {251.20299999999997`, 
                    160.70700000000005`}, {253.906, 164.44099999999997`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{251.20299999999997`, 
                    162.51200000000006`}, {250.945, 159.93400000000003`}, {
                    252.23399999999998`, 155.555}, {258.801, 
                    157.35899999999998`}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{259.832, 
                    153.36700000000002`}, {260.863, 155.555}, {255.969, 
                    159.16400000000004`}, {252.23399999999998`, 
                    155.17200000000003`}, {248.5, 151.18}, {252.75, 
                    146.67200000000003`}, {255.066, 148.21500000000003`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{242.70299999999997`, 
                    161.99599999999998`}, {240.77299999999997`, 
                    158.64799999999997`}, {248.242, 152.531}, {
                    252.49200000000002`, 158.195}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    237.74599999999998`, 156.199}, {235.039, 153.43}, {
                    238.38700000000003`, 148.344}, {242.445, 
                    149.89099999999996`}, {246.5, 151.43400000000003`}, {
                    246.117, 155.68400000000003`}, {245.148, 
                    156.77700000000004`}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{232.531, 
                    151.04700000000003`}, {230.34, 149.055}, {232.465, 
                    144.35199999999998`}, {235.49200000000002`, 
                    144.35199999999998`}, {238.516, 144.35199999999998`}, {
                    240.38700000000003`, 146.73400000000004`}, {239.805, 
                    149.76200000000006`}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{244.82800000000003`, 
                    151.43400000000003`}, {244.441, 148.473}, {
                    248.82000000000002`, 146.41400000000004`}, {
                    251.65200000000002`, 149.18}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{251.781, 
                    154.59000000000003`}, {252.168, 155.23400000000004`}, {
                    251.848, 156.32799999999997`}, {251.20299999999997`, 
                    156.844}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{227.82800000000003`, 
                    147.05900000000003`}, {225.316, 145.05900000000003`}, {
                    230.727, 139.52300000000002`}, {234.137, 
                    144.60900000000004`}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{247.21099999999998`, 
                    148.14799999999997`}, {245.602, 146.60500000000002`}, {
                    248.176, 142.551}, {250.75, 143.77300000000002`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{238.38700000000003`, 
                    145.31599999999997`}, {238.77299999999997`, 142.551}, {
                    244.184, 140.488}, {247.598, 144.738}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{241.35200000000003`, 
                    142.551}, {240.516, 140.80900000000003`}, {
                    242.18800000000002`, 138.03900000000004`}, {244.25, 
                    138.426}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{292.605, 
                    126.64499999999998`}, {290.60900000000004`, 
                    122.71500000000003`}, {296.984, 118.14499999999998`}, {
                    301.621, 122.91000000000003`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{297.242, 
                    120.78500000000003`}, {296.277, 118.65999999999997`}, {
                    297.43799999999993`, 115.695}, {299.176, 
                    114.60200000000003`}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{291.191, 
                    116.33999999999997`}, {291.641, 118.27300000000002`}, {
                    294.40999999999997`, 120.07800000000003`}, {
                    296.92199999999997`, 119.17200000000003`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{287.84000000000003`, 
                    121.43}, {288.227, 123.168}, {290.547, 124.906}, {
                    292.28499999999997`, 124.45299999999997`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{439.484, 
                    201.78900000000004`}, {430.34000000000003`, 
                    201.65999999999997`}, {434.203, 186.98000000000002`}, {
                    442.059, 189.94099999999997`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{436.52299999999997`, 
                    190.973}, {434.719, 188.00800000000004`}, {438.195, 
                    183.30900000000003`}, {442.059, 186.07800000000003`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{441.03099999999995`, 
                    185.49599999999998`}, {438.324, 180.99200000000002`}, {
                    447.984, 174.10200000000003`}, {451.848, 
                    181.18400000000003`}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{448.758, 
                    178.48000000000002`}, {448.883, 174.23000000000002`}, {
                    461.246, 171.52700000000004`}, {459.445, 
                    180.02300000000002`}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{458.28499999999997`, 
                    175.39099999999996`}, {461.246, 170.36700000000002`}, {
                    472.324, 169.85199999999998`}, {471.16400000000004`, 
                    177.32}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{468.715, 172.168}, {
                    471.03499999999997`, 168.82}, {481.85200000000003`, 
                    166.76200000000006`}, {481.465, 173.71500000000003`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{424.805, 
                    214.53900000000004`}, {426.348, 210.54700000000003`}, {
                    431.625, 209.12900000000002`}, {437.42199999999997`, 
                    211.449}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{421.453, 
                    211.70700000000005`}, {425.059, 209.387}, {
                    419.78099999999995`, 198.82799999999997`}, {414.242, 
                    203.07800000000003`}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{421.453, 205.137}, {
                    425.445, 203.20700000000005`}, {430.34000000000003`, 
                    204.62099999999998`}, {431.758, 210.28900000000004`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{429.309, 
                    205.91000000000003`}, {429.695, 202.949}, {433.945, 
                    200.62900000000002`}, {439.484, 201.78900000000004`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{419.395, 202.82}, {
                    424.547, 198.44099999999997`}, {417.078, 189.426}, {
                    413.727, 193.54700000000003`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{421.328, 199.473}, {
                    423.77299999999997`, 197.668}, {430.082, 198.699}, {
                    430.727, 203.46500000000003`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{427.895, 199.473}, {
                    428.40999999999997`, 196.37900000000002`}, {430.855, 
                    195.223}, {434.332, 195.09400000000005`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{419.90999999999997`, 
                    195.223}, {422.484, 191.61700000000002`}, {
                    428.92199999999997`, 190.586}, {431.758, 
                    195.35199999999998`}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{428.92199999999997`, 
                    192.64499999999998`}, {428.668, 189.168}, {
                    432.53099999999995`, 186.33599999999996`}, {
                    436.52299999999997`, 187.10900000000004`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{414.887, 184.918}, {
                    418.234, 183.24599999999998`}, {421.84000000000003`, 
                    189.555}, {419.008, 193.93400000000003`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{418.75, 178.223}, {
                    422.742, 177.96500000000003`}, {423.258, 
                    184.01600000000002`}, {419.52299999999997`, 
                    187.36700000000002`}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{427.895, 
                    172.68400000000003`}, {431.242, 173.457}, {
                    430.21099999999996`, 180.79700000000003`}, {
                    422.09799999999996`, 181.44099999999997`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{438.066, 
                    167.27700000000004`}, {441.28499999999997`, 168.176}, {
                    438.71099999999996`, 176.28900000000004`}, {429.828, 
                    175.77300000000002`}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{450.305, 
                    164.44099999999997`}, {452.48799999999994`, 
                    167.78900000000004`}, {445.28099999999995`, 173.457}, {
                    439.355, 170.49599999999998`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{456.35200000000003`, 
                    159.805}, {460.348, 158.64799999999997`}, {463.051, 
                    169.20700000000005`}, {450.42999999999995`, 167.531}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{463.691, 159.805}, {
                    467.172, 160.70700000000005`}, {469.621, 
                    167.02000000000004`}, {459.445, 164.957}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{471.42199999999997`, 
                    159.293}, {474.512, 157.74599999999998`}, {
                    475.92999999999995`, 166.76200000000006`}, {466.527, 
                    164.312}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{419.52299999999997`, 
                    187.36700000000002`}, {423.387, 185.176}, {429.441, 
                    187.75400000000002`}, {428.92199999999997`, 
                    192.64499999999998`}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{427.375, 
                    188.39499999999998`}, {428.668, 186.07800000000003`}, {
                    428.148, 181.57000000000005`}, {425.703, 
                    180.41000000000003`}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{427.762, 182.988}, {
                    430.34000000000003`, 181.957}, {433.816, 
                    182.85899999999998`}, {435.875, 186.98000000000002`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{432.27299999999997`, 
                    182.988}, {433.043, 181.18400000000003`}, {433.305, 
                    177.57800000000003`}, {431.625, 175.77300000000002`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{432.91799999999995`, 
                    179.89499999999998`}, {435.75, 178.35199999999998`}, {
                    439.09799999999996`, 180.41000000000003`}, {440.512, 
                    183.375}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{438.71099999999996`, 
                    180.79700000000003`}, {440.77, 179.51200000000006`}, {
                    442.574, 173.457}, {439.09799999999996`, 
                    171.01200000000006`}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{441.03099999999995`, 
                    173.844}, {443.477, 173.71500000000003`}, {447.082, 
                    173.71500000000003`}, {449.39799999999997`, 176.805}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{447.727, 
                    175.13299999999998`}, {449.91799999999995`, 174.488}, {
                    452.48799999999994`, 170.88299999999998`}, {451.59, 
                    167.65999999999997`}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{451.715, 168.82}, {
                    454.168, 169.07800000000003`}, {458.414, 
                    170.75400000000002`}, {459.574, 173.71500000000003`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{458.414, 171.781}, {
                    460.477, 170.625}, {461.895, 168.176}, {461.633, 
                    165.344}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{461.633, 167.406}, {
                    464.078, 167.531}, {466.27, 168.82}, {466.914, 
                    171.52700000000004`}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{466.27, 169.723}, {
                    468.074, 169.07800000000003`}, {470.262, 
                    167.02000000000004`}, {470.395, 164.57000000000005`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{470.133, 
                    166.11700000000002`}, {471.93799999999993`, 166.375}, {
                    473.22299999999996`, 167.531}, {474.383, 
                    169.33599999999996`}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{479.277, 
                    169.59400000000005`}, {481.59799999999996`, 
                    167.27700000000004`}, {478.508, 159.54700000000003`}, {
                    473.73799999999994`, 160.96500000000003`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{429.828, 
                    325.67999999999995`}, {425.059, 322.844}, {
                    411.53499999999997`, 323.746}, {418.234, 
                    334.94899999999996`}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{431.113, 
                    333.27700000000004`}, {421.715, 329.543}, {410.121, 
                    336.754}, {422.227, 344.609}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{419.008, 
                    347.18399999999997`}, {411.148, 347.18399999999997`}, {
                    405.871, 334.562}, {416.43399999999997`, 330.188}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    388.48799999999994`, 341.906}, {386.42599999999993`, 
                    337.914}, {393.76599999999996`, 333.53499999999997`}, {
                    398.789, 337.52700000000004`}, {402.68, 340.621}, {
                    402.395, 348.988}, {400.078, 352.207}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{384.49199999999996`, 
                    332.375}, {381.91799999999995`, 323.875}, {
                    400.85200000000003`, 323.35900000000004`}, {397.887, 
                    336.88300000000004`}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{383.465, 319.754}, {
                    384.105, 313.31600000000003`}, {401.625, 315.375}, {
                    395.953, 328.38300000000004`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{398.01599999999996`, 
                    331.988}, {399.43399999999997`, 330.05899999999997`}, {
                    403.29699999999997`, 326.707}, {409.863, 327.352}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{401.105, 341.133}, {
                    401.688, 338.812}, {405.613, 337.01199999999994`}, {
                    410.637, 338.75}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{225.383, 
                    145.19099999999997`}, {220.93800000000002`, 
                    142.03500000000003`}, {227.766, 137.07800000000003`}, {
                    230.27299999999997`, 142.551}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{221.90200000000002`, 
                    142.738}, {217.461, 139.586}, {224.289, 
                    134.62900000000002`}, {226.797, 140.10200000000003`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{218.23399999999998`, 
                    140.35899999999998`}, {213.789, 137.20300000000003`}, {
                    220.617, 132.24599999999998`}, {223.129, 
                    137.71900000000005`}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{214.371, 
                    138.17200000000003`}, {210.121, 135.918}, {215.078, 
                    130.37900000000002`}, {219.395, 135.27300000000002`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{210.184, 136.043}, {
                    205.934, 133.793}, {210.895, 128.25400000000002`}, {
                    215.207, 133.14799999999997`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{231.758, 142.676}, {
                    231.691, 139.39499999999998`}, {237.93800000000002`, 
                    138.03900000000004`}, {240.191, 142.938}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{235.684, 
                    139.64799999999997`}, {233.754, 137.20300000000003`}, {
                    237.29299999999998`, 134.176}, {239.227, 
                    135.27300000000002`}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{227.379, 
                    140.10200000000003`}, {227.184, 137.332}, {232.594, 
                    135.723}, {235.23399999999998`, 138.75}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{230.34, 
                    137.20300000000003`}, {228.602, 134.949}, {232.016, 
                    131.92200000000003`}, {234.20299999999997`, 
                    132.82799999999997`}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{223.77299999999997`, 
                    137.59000000000003`}, {223.965, 135.39799999999997`}, {
                    227.055, 132.89099999999996`}, {230.40200000000002`, 
                    134.30900000000003`}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{225.76999999999998`, 
                    134.62900000000002`}, {224.48000000000002`, 
                    133.46900000000005`}, {225.125, 130.76200000000006`}, {
                    226.92600000000002`, 129.926}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{219.07, 134.824}, {
                    218.555, 132.82799999999997`}, {221.969, 
                    129.28500000000003`}, {225.445, 131.60200000000003`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{219.781, 
                    132.50400000000008`}, {217.71899999999997`, 
                    130.89499999999998`}, {217.977, 128.445}, {220.617, 
                    128.125}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{214.82000000000002`, 
                    132.76200000000006`}, {214.562, 131.41000000000003`}, {
                    216.305, 129.21900000000005`}, {218.49200000000002`, 
                    129.47700000000003`}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{203.812, 
                    132.89099999999996`}, {201.75, 131.79700000000003`}, {
                    207.031, 126.195}, {210.312, 131.41000000000003`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{198.72299999999998`, 
                    130.57400000000007`}, {196.148, 129.34799999999996`}, {
                    202.523, 123.168}, {205.35500000000002`, 
                    129.47700000000003`}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{215.40200000000002`, 
                    130.832}, {213.406, 130.37900000000002`}, {212.117, 
                    127.48000000000002`}, {213.789, 126.32400000000001`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{208.89800000000002`, 
                    129.801}, {208.641, 128.64099999999996`}, {211.086, 
                    126.71100000000001`}, {213.08200000000002`, 127.418}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{207.22299999999998`, 
                    129.28500000000003`}, {205.29299999999998`, 
                    128.05900000000003`}, {206.32000000000002`, 
                    124.64799999999997`}, {208.57399999999998`, 
                    125.16400000000004`}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{200.33200000000002`, 
                    127.031}, {198.531, 125.68}, {199.754, 
                    122.97300000000001`}, {202.266, 123.61700000000002`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{203.617, 
                    127.22300000000001`}, {203.684, 126.51600000000002`}, {
                    205.29299999999998`, 125.42200000000003`}, {
                    206.64499999999998`, 125.87099999999998`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{194.086, 
                    128.38299999999998`}, {191.836, 127.418}, {191.961, 
                    121.75}, {199.562, 124.83999999999997`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{189., 
                    126.12900000000002`}, {185.844, 124.58200000000005`}, {
                    186.875, 120.332}, {193.766, 124.39099999999996`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{194.344, 
                    124.06600000000003`}, {193.508, 123.42200000000003`}, {
                    192.605, 120.59000000000003`}, {195.762, 
                    121.68799999999999`}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{188.55100000000002`, 
                    122.71500000000003`}, {187.262, 121.55900000000003`}, {
                    188.098, 119.17200000000003`}, {190.934, 
                    120.07800000000003`}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{181.918, 122.332}, {
                    179.602, 120.97700000000003`}, {184.68800000000002`, 
                    119.17200000000003`}, {188.098, 122.781}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{183.465, 
                    120.65599999999995`}, {182.434, 119.625}, {182.434, 
                    116.60200000000003`}, {185.137, 117.695}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{176.895, 
                    119.43400000000003`}, {175.35200000000003`, 
                    118.27300000000002`}, {177.98800000000003`, 
                    116.72700000000003`}, {182.82000000000002`, 
                    118.85199999999998`}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{178.82800000000003`, 
                    117.75799999999998`}, {177.023, 116.27700000000004`}, {
                    177.21899999999997`, 114.41000000000003`}, {
                    179.85500000000002`, 114.988}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{173.48000000000002`, 
                    116.92200000000003`}, {171.48800000000003`, 
                    115.11700000000002`}, {174.383, 113.89499999999998`}, {
                    177.859, 115.375}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{173.547, 
                    114.92200000000003`}, {170.13299999999998`, 
                    113.37900000000002`}, {171.61299999999997`, 
                    110.54700000000003`}, {173.738, 111.64099999999996`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{287.52, 
                    105.07400000000007`}, {286.727, 103.37099999999998`}, {
                    289.324, 101.98400000000004`}, {291.77, 
                    102.37099999999998`}, {294.121, 102.738}, {296.367, 
                    104.67599999999999`}, {294.60200000000003`, 
                    107.39099999999996`}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{294.72999999999996`, 
                    104.043}, {297.051, 102.238}, {301.172, 
                    104.30099999999999`}, {301.172, 107.00800000000004`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    436.78099999999995`, 376.93399999999997`}, {426.477, 
                    382.08599999999996`}, {405.10200000000003`, 391.617}, {
                    399.047, 383.887}, {404.582, 386.207}, {420.809, 
                    383.758}, {434.203, 371.395}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    436.78099999999995`, 376.93399999999997`}, {426.477, 
                    382.086}, {405.10200000000003`, 391.617}, {399.047, 
                    383.887}, {404.582, 386.207}, {420.809, 383.758}, {
                    434.203, 371.395}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{443.027, 377.47999999999996`}, {431.113, 
                    391.35900000000004`}, {424.09799999999996`, 388.25}, {
                    415.53099999999995`, 393.03099999999995`}, {407.484, 
                    397.52299999999997`}, {394.668, 398.441}, {392.184, 
                    391.29699999999997`}, {403.941, 397.02299999999997`}, {
                    414.734, 388.219}, {421.363, 387.15200000000004`}, {
                    430.469, 385.691}, {435.60900000000004`, 
                    378.65200000000004`}, {438.27299999999997`, 
                    375.414}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{443.027, 377.48}, {431.113, 391.359}, {
                    424.09799999999996`, 388.25}, {415.53099999999995`, 
                    393.031}, {407.484, 397.523}, {394.668, 
                    398.44100000000003`}, {392.184, 391.297}, {403.941, 
                    397.023}, {414.734, 388.219}, {421.363, 387.152}, {
                    430.469, 385.69100000000003`}, {435.60900000000004`, 
                    378.652}, {438.27299999999997`, 375.414}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{487.90599999999995`, 379.254}, {
                    481.72299999999996`, 393.41799999999995`}, {468.504, 
                    389.719}, {462.66400000000004`, 395.73799999999994`}, {
                    454.168, 404.49199999999996`}, {432.66, 412.605}, {
                    423.77299999999997`, 406.555}, {443.348, 
                    407.58599999999996`}, {451.684, 393.062}, {462.148, 
                    388.008}, {469.621, 384.402}, {477.60200000000003`, 
                    376.676}, {487.90599999999995`, 379.254}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{487.90599999999995`, 379.254}, {
                    481.72299999999996`, 393.418}, {468.504, 389.719}, {
                    462.66400000000004`, 395.738}, {454.168, 404.492}, {
                    432.66, 412.605}, {423.77299999999997`, 406.555}, {
                    443.348, 407.586}, {451.684, 393.062}, {462.148, 
                    388.008}, {469.621, 384.402}, {477.60200000000003`, 
                    376.676}, {487.90599999999995`, 379.254}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    464.727, 380.79699999999997`}, {454.168, 
                    393.93399999999997`}, {437.93799999999993`, 
                    405.52299999999997`}, {430.469, 401.14500000000004`}, {
                    440.258, 400.629}, {443.348, 393.805}, {450.305, 
                    389.42599999999993`}, {457.258, 385.047}, {454.168, 
                    378.73799999999994`}, {464.727, 
                    380.79699999999997`}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    464.727, 380.797}, {454.168, 393.93399999999997`}, {
                    437.93799999999993`, 405.523}, {430.469, 401.145}, {
                    440.258, 400.629}, {443.348, 393.805}, {450.305, 
                    389.426}, {457.258, 385.047}, {454.168, 378.738}, {
                    464.727, 380.797}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{414.5, 
                    357.617}, {403.42199999999997`, 361.73799999999994`}, {
                    381.789, 363.79699999999997`}, {371.742, 351.176}, {
                    388.48799999999994`, 348.34400000000005`}, {413.727, 
                    349.89099999999996`}, {414.5, 357.617}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{414.5, 
                    357.617}, {403.42199999999997`, 361.738}, {381.789, 
                    363.797}, {371.742, 351.176}, {388.48799999999994`, 
                    348.344}, {413.727, 349.891}, {414.5, 357.617}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, {{{412.441, 352.72299999999996`}, {
                    401.363, 357.875}, {392.715, 350.68}, {382.305, 
                    351.691}, {362.47299999999996`, 353.625}, {348.305, 
                    352.465}, {346.504, 342.93399999999997`}, {
                    357.83599999999996`, 353.10900000000004`}, {376.895, 
                    344.73799999999994`}, {384.621, 346.79699999999997`}, {
                    392.35200000000003`, 348.85900000000004`}, {420.941, 
                    347.055}, {429.953, 343.191}, {425.316, 
                    348.85900000000004`}, {418.105, 350.40599999999995`}, {
                    412.441, 352.72299999999996`}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, {{{412.441, 352.723}, {401.363, 
                    357.875}, {392.715, 350.67999999999995`}, {382.305, 
                    351.69100000000003`}, {362.47299999999996`, 353.625}, {
                    348.305, 352.46500000000003`}, {346.504, 
                    342.93399999999997`}, {357.83599999999996`, 353.109}, {
                    376.895, 344.738}, {384.621, 346.797}, {
                    392.35200000000003`, 348.85900000000004`}, {420.941, 
                    347.055}, {429.953, 343.19100000000003`}, {425.316, 
                    348.85900000000004`}, {418.105, 350.406}, {412.441, 
                    352.723}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, {{{447.21099999999996`, 382.215}, {
                    444.637, 390.715}, {444.762, 399.72999999999996`}, {
                    457.512, 399.08599999999996`}, {454.29299999999995`, 
                    403.078}, {442.445, 405.137}, {440.512, 390.199}, {
                    426.477, 400.5}, {411.148, 402.305}, {408.32, 
                    393.41799999999995`}, {415.53099999999995`, 
                    399.60200000000003`}, {426.734, 395.094}, {440.125, 
                    379.895}, {441.28499999999997`, 380.539}, {444.375, 
                    381.828}, {447.21099999999996`, 382.215}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, {{{447.21099999999996`, 
                    382.21500000000003`}, {444.637, 390.71500000000003`}, {
                    444.762, 399.73}, {457.512, 399.086}, {
                    454.29299999999995`, 403.078}, {442.445, 405.137}, {
                    440.512, 390.199}, {426.477, 400.5}, {411.148, 402.305}, {
                    408.32, 393.418}, {415.53099999999995`, 399.602}, {
                    426.734, 395.094}, {440.125, 379.895}, {
                    441.28499999999997`, 380.539}, {444.375, 
                    381.82800000000003`}, {447.21099999999996`, 
                    382.21500000000003`}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIxIGYC4h1yra8D91U58Opumvtevdzh0FeNmH67Koed
IPGqcgdbruuLCyZWOhzzNu90ZKhweFtjbxp3oMpBNirF+r5pBVw9mF9d4ZD7
/PfKjw2VDotct33+G1PhINx84NTCqZUODCCQBzXPusLh0yXfJIFf5Q6djglP
LzhB6VNQ+/nKHbacKNs336HcoVpknfvDK2UOVyteqhmuKHMo3zdfSn91uYP7
wyqRdcFlEHddKHe4oHT7Z92WMgegq3fIrSyHmL8Eql653AGkLOFimUPGRKAP
Msvh/gU52399ucN9/97peXXlDuDwEKt0MLirwtZoWw7xV3YVRF13mcOy2UcU
NpyC+jcS6i6BGofHS4ESSWUO6OEJADBhoUo=
                    "]]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIxIGYC4h1yra8D91U58Olumvtevdzh0FeNmH67Kgew
eFW5gy3X9cUFEysdjnmbdzoyVDi8rbE3jTtQ5SAblWJ937QCrh7Mr65wyH3+
e+XHhkqHRa7bPv+NqXAQbj5wauHUSgcGEMiDmmdd4fDpkm+SwK9yh07HhKcX
nKD0Kaj9fOUOW06U7ZvvUO5QLbLO/eGVMoerFS/VDFeUOZTvmy+lv7rcweNh
lci64DKIuy6UO1xUuv2zbkuZA9DVO+RWlkPMXwJVr1zu4ANUlnCxzCFjItAH
meVw/4Kc7b++3OG+f+/0vLpyiL/FKh3076qwNdqWQ/yVXQVR113msGz2EYUN
p6D+jYS6S6DG4fFSoERSmQN6eAIAMlGhTg==
                    "], 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{422.227, 
                    356.328}, {416.066, 368.90599999999995`}, {396.082, 
                    357.48799999999994`}, {392.055, 369.672}, {386.555, 
                    351.82}, {420.47299999999996`, 361.699}, {422.227, 
                    356.328}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{422.227, 
                    356.32800000000003`}, {416.066, 368.906}, {396.082, 
                    357.488}, {392.055, 369.672}, {386.555, 351.82}, {
                    420.47299999999996`, 361.699}, {422.227, 
                    356.32800000000003`}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{549.3359999999999, 342.676}, {553.5269999999999, 
                    340.594}, {557.148, 343.867}, {550.738, 
                    346.43799999999993`}, {554.934, 344.355}, {558.59, 
                    347.551}, {552.1800000000001, 350.117}, {556.375, 
                    348.039}, {560.031, 351.22999999999996`}, {553.621, 
                    353.801}, {551.91, 352.078}, {549.4649999999999, 
                    345.77}, {549.3359999999999, 342.676}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{549.3359999999999, 342.676}, {553.5269999999999, 
                    340.594}, {557.148, 343.867}, {550.738, 346.438}, {
                    554.934, 344.355}, {558.59, 347.55100000000004`}, {
                    552.1800000000001, 350.11699999999996`}, {556.375, 
                    348.039}, {560.031, 351.23}, {553.621, 353.801}, {551.91, 
                    352.078}, {549.4649999999999, 345.77}, {549.3359999999999,
                     342.676}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4vJ986X0bRodjnmbdzq+K3PwAVIJbY0OQPLp
ha5yh8qXaoYcZo0Ob2vsTeMOlDvobpr7fvmERofW14E75BIrHBYX2HJdv9Xo
sOVE2b75TyocOkD65kHNs6l0AJv/tNHh8FeNmP5FlQ5LQOp/Nzro31Vhazxc
6fCwSmSdu26Tgx3X9cUFrFUORxU2FGUYNjmAtCe4V0Hk/ZscJkuwhPFtroTY
f6XR4b5/7/S8eZUO05y7c57faXSwBelfX+EQ23/oq8ajRoeMiUAXi1c4yIEc
uq7R4YLS7Z91KhUODCAwu9FBq13s5jnlcoj7pyH8H5Vifd+/pdFh6ewjChvK
yhzQwwcAOMWKPA==
                    "]]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4vJ986X0bRodjnubdzq+K3PwAVIJbY0OQPLp
ha5yh8qXaoYcZo0O72rsTeMOlDvobpr7fvmERofW14E75BIrHBYX2HJdv9Xo
sOVE2b75TyocOkD65jU6HAOZZ1PpADb/aaPDoa8aMf2LKh2WgNT/bnTQv6vC
1ni40uFhlcg6d90mB6Do4gLWKoejChuKMgybIO5wr4LI+zc5TJFgCePbXAmx
/0qjw33/3ul58yodpjl35zy/0+hgB9K/vsIhth9o06NGh4yJb2vsxSsc5EAO
XdfocFHp9s86lQoHBhCY3eig3S5285xyOcT90xD+j0qxvu/f0uiwbPYRhQ1l
ZQ7o4QMAO9WKRA==
                    "], CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{555.648, 362.512}, {560.797, 
                    373.58599999999996`}, {566.711, 373.371}, {569.555, 
                    377.707}, {574.9649999999999, 385.949}, {
                    586.4219999999999, 376.289}, {596.082, 383.629}, {594.41, 
                    373.199}, {581.4019999999999, 376.93399999999997`}, {
                    575.738, 370.23799999999994`}, {570.07, 363.539}, {
                    565.434, 360.449}, {555.648, 362.512}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{555.648, 362.512}, {560.797, 373.586}, {566.711, 
                    373.371}, {569.555, 377.707}, {574.9649999999999, 
                    385.949}, {586.4219999999999, 376.289}, {596.082, 
                    383.629}, {594.41, 373.199}, {581.4019999999999, 
                    376.93399999999997`}, {575.738, 370.238}, {570.07, 
                    363.539}, {565.434, 360.449}, {555.648, 362.512}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{556.934, 358.90599999999995`}, {565.949, 
                    366.117}, {572.594, 361.305}, {578.828, 
                    365.08599999999996`}, {594.535, 374.617}, {
                    600.8519999999999, 363.156}, {614.887, 367.66}, {611.148, 
                    358.648}, {590.418, 366.375}, {581.4019999999999, 
                    359.676}, {572.387, 352.97999999999996`}, {540.707, 
                    346.543}, {556.934, 358.90599999999995`}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{556.934, 358.906}, {565.949, 366.117}, {572.594, 
                    361.305}, {578.828, 365.086}, {594.535, 374.617}, {
                    600.8519999999999, 363.156}, {614.887, 
                    367.65999999999997`}, {611.148, 358.648}, {590.418, 
                    366.375}, {581.4019999999999, 359.676}, {572.387, 
                    352.98}, {540.707, 346.543}, {556.934, 358.906}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, {{{530.664, 307.52}, {530.531, 
                    311.641}, {526.668, 316.92199999999997`}, {521.262, 
                    317.566}, {515.8519999999999, 318.207}, {513.531, 
                    323.875}, {509.414, 324.133}, {505.29299999999995`, 
                    324.39099999999996`}, {502.58599999999996`, 332.633}, {
                    496.91799999999995`, 332.504}, {491.254, 332.375}, {
                    488.93799999999993`, 325.03499999999997`}, {502.199, 
                    318.34000000000003`}, {515.4649999999999, 311.641}, {
                    530.148, 303.914}, {530.664, 307.52}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, {{{530.664, 307.52}, {530.531, 
                    311.64099999999996`}, {526.668, 316.922}, {521.262, 
                    317.56600000000003`}, {515.8519999999999, 318.207}, {
                    513.531, 323.875}, {509.414, 324.133}, {
                    505.29299999999995`, 324.391}, {502.58599999999996`, 
                    332.633}, {496.91799999999995`, 332.504}, {491.254, 
                    332.375}, {488.93799999999993`, 325.03499999999997`}, {
                    502.199, 318.34000000000003`}, {515.4649999999999, 
                    311.64099999999996`}, {530.148, 303.914}, {530.664, 
                    307.52}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{513.918, 
                    304.043}, {508.254, 303.78499999999997`}, {
                    507.47999999999996`, 295.543}, {502.074, 
                    295.28499999999997`}, {509.539, 291.29299999999995`}, {
                    514.949, 297.09}, {518.8119999999999, 
                    302.23799999999994`}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{513.918, 
                    304.043}, {508.254, 303.785}, {507.47999999999996`, 
                    295.543}, {502.074, 295.285}, {509.539, 291.293}, {
                    514.949, 297.09000000000003`}, {518.8119999999999, 
                    302.238}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{518.555, 
                    303.012}, {513.664, 298.89099999999996`}, {512.246, 
                    290.262}, {519.328, 287.816}, {515.0780000000001, 
                    293.676}, {526.8009999999999, 296.316}, {523.191, 
                    301.727}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{518.555, 
                    303.01199999999994`}, {513.664, 298.891}, {512.246, 
                    290.262}, {519.328, 287.81600000000003`}, {
                    515.0780000000001, 293.676}, {526.8009999999999, 
                    296.31600000000003`}, {523.191, 301.72700000000003`}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{523.449, 
                    302.754}, {519.586, 295.28499999999997`}, {529.504, 
                    294.383}, {526.9259999999999, 288.719}, {532.594, 
                    290.004}, {533.496, 300.695}, {528.3439999999999, 
                    303.527}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{523.449, 
                    302.754}, {519.586, 295.285}, {529.504, 
                    294.38300000000004`}, {526.9259999999999, 288.719}, {
                    532.594, 290.004}, {533.496, 300.695}, {528.3439999999999,
                     303.52700000000004`}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, {{{485.58599999999996`, 
                    318.72299999999996`}, {494.85900000000004`, 
                    319.23799999999994`}, {503.34000000000003`, 
                    314.22299999999996`}, {509.027, 306.10200000000003`}, {
                    512.633, 300.953}, {524.738, 298.89099999999996`}, {
                    528.8589999999999, 303.012}, {532.98, 307.133}, {530.664, 
                    315.89099999999996`}, {520.3589999999999, 313.059}, {
                    517.7810000000001, 317.43799999999993`}, {510.312, 
                    315.89099999999996`}, {506.71099999999996`, 
                    319.4959999999999}, {503.10200000000003`, 
                    323.10200000000003`}, {489.191, 333.40599999999995`}, {
                    485.58599999999996`, 
                    318.72299999999996`}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, {{{485.58599999999996`, 318.723}, {
                    494.85900000000004`, 319.238}, {503.34000000000003`, 
                    314.223}, {509.027, 306.102}, {512.633, 300.953}, {
                    524.738, 298.891}, {528.8589999999999, 
                    303.01199999999994`}, {532.98, 307.133}, {530.664, 
                    315.891}, {520.3589999999999, 313.05899999999997`}, {
                    517.7810000000001, 317.438}, {510.312, 315.891}, {
                    506.71099999999996`, 319.496}, {503.10200000000003`, 
                    323.102}, {489.191, 333.406}, {485.58599999999996`, 
                    318.723}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}}}, {{{520.3589999999999, 
                    313.059}, {517.914, 312.543}, {517.141, 
                    308.29299999999995`}, {518.6840000000001, 
                    306.10200000000003`}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{520.3589999999999, 
                    313.05899999999997`}, {517.914, 312.543}, {517.141, 
                    308.293}, {518.6840000000001, 306.102}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}}}, {{{525.641, 
                    310.47999999999996`}, {526.414, 309.195}, {525.898, 
                    307.39099999999996`}, {525.512, 
                    306.48799999999994`}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{525.641, 310.48}, {
                    526.414, 309.195}, {525.898, 307.391}, {525.512, 
                    306.488}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}}}, {{{500.27, 
                    318.34000000000003`}, {505.03099999999995`, 318.082}, {
                    505.93799999999993`, 314.60200000000003`}, {
                    511.08599999999996`, 313.316}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{500.27, 
                    318.34000000000003`}, {505.03099999999995`, 318.082}, {
                    505.93799999999993`, 314.602}, {511.08599999999996`, 
                    313.31600000000003`}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJ5IGZigAKheofc579XflxQ4rD1RNm++TwNDrG7PHmY
4kscsvaUTJYobXDImPi2xl61xEE2KsX6/tYGh9bXgTvkbhc7bAGp/9YA0T+h
2IFXd9Pc91GNDjvkgCpqih2Wzj6isGFTo4MVSOHaYgdbruuLC7iaIObdh8pv
bnI49FUjpp+nxOGyb5JAxOomh8cgCaNiCP9mk4O3eadjwvxihw7HhKcX5jU5
dIJokRIHwQjLLSc0ofKaJQ7TnLtznmtDzZtSAqE/NULkv0LNP9noYHBXha1x
a4nDts9/r1S8b3TQahe7eW5/CUSdQJODcPOBUwsNSxzK982X0j/aCPHX92KI
fZcbIf5PLnG4oHT7Z928Rgc+kPzhEoeYfqCN6Y1w+3WAwsu7oPrrSxys7/v3
Tl/XCHE/RwnEn/GN8PAEOeO7TqPDMZBD9hU7LCkAhtjjBgdQsPs/Lnbw4mHS
bl+LiA+w+8qh/PQSiL6eOggdVuqAHr8AWwfnhw==
                    
                    "]]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJ5IGZigAKheoec579XflxQ4rD1RNm++TwNDnG7PHmY
4kscsvaUTJYobXDImPi2xl61xEE2KsX6/tYGh9bXgTvkbhc7bAGp/9YA0T+h
2IFXd9Pc91GNDjvkgCpqih2Wzj6isGFTo4MVSOHaYgdbruuLC7iaIObdh8pv
bnI4/FUjpp+nxOGyb5JAxOomh8cgCaNiCP9mk4OPeadjwvxihw7HhKcX5jU5
dIFokRIHwQjLLSc0ofKaJQ7TnLtznmtDzZtS4nAIRH9qhMh/hZp/stFB/64K
W+PWEodtn/9eqXjf6KDdLnbz3P4SB2+QOoEmB6HmA6cWGpY4lO+bL6V/tNGB
D+Sv78UQ+y43QvyfXOJwQen2z7p5UPnDJQ4x/UAb0xvh9usAhZd3QeXrSxys
7/v3Tl/XCHE/RwnEn/GN8PAEOeO7TqPDcZBD9hU7LCkAhtjjBgdQsPs/Lnbw
4mHSbl+LiA+w+8qh/PQSh2MgfT11EP1hpQ7o8QsAYl/nkA==
                    "], 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{538.648, 336.754}, {533.496, 
                    334.43799999999993`}, {536.8439999999999, 329.027}, {
                    528.8589999999999, 325.93799999999993`}, {520.875, 
                    322.84400000000005`}, {515.3359999999999, 315.762}, {
                    517.141, 309.71099999999996`}, {522.5509999999999, 
                    321.559}, {532.0780000000001, 321.043}, {
                    535.4259999999999, 325.68}, {538.777, 330.316}, {543.668, 
                    337.141}, {538.648, 336.754}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{538.648, 336.754}, {533.496, 334.438}, {
                    536.8439999999999, 329.02700000000004`}, {
                    528.8589999999999, 325.938}, {520.875, 322.844}, {
                    515.3359999999999, 315.762}, {517.141, 309.711}, {
                    522.5509999999999, 321.55899999999997`}, {
                    532.0780000000001, 321.043}, {535.4259999999999, 
                    325.67999999999995`}, {538.777, 330.31600000000003`}, {
                    543.668, 337.14099999999996`}, {538.648, 336.754}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIxIGYC4gtKt3/WPWhwcH9YJbLuf4mDLdf1xQX3Ghwy
Jr6tsc8sgdCLGxw+XfJNElhQ4uBj3umYsKvBYensIwobzhQ72Nz3751+sMFh
Rp5Q84GuYgcGEDjf4ADknVooX+wQlWJ9339HgwNIWd6WIgeBCMstJ341QMRF
ix0qX6oZclyA6n9Q7DDNuTvn+dsGB4O7KmyNuiUQdX8aHLaeKNs3P6jEYXEB
0IV8jQ475FpfB/aUOGTtKZksIdboYLUFqGBviQOIms/WCHF3eomDzqa575ez
NzqA/XkMar5hI8TcuVA+fyPE3XYlEP/0NjrIghQcLIG4zxyqvroU4m8tqHq/
UgdPHibtduZGB2GQf/+WOKCHJwBBqZ8M
                    "]]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIxIGYC4gtKt3/WPWhw8HhYJbLuf4mDLdf1xQX3Ghwy
Jr6tsc8sgdCLGxw+XfJNElhQ4uBj3umYsKvBYdnsIwobzhQ72Nz3751+sMFh
ep5Q84GuYgcGEDjf4ADknVooX+wQlWJ9339Hg8MDoLK8LUUOAhGWW078aoCI
ixY7VL5UM+S40OAwA6T/QbHDNOfunOdvGxz076qwNeqWQNT9aXDYcqJs3/yg
EofFBUAX8jU67JBrfR3YU+KQtadksoRYo4MVSMHeEog6tkaIu9NLHHQ2zX2/
nL3R4SLIn8eg5hs2QsydC+XzN0LcbVcC8U9vo4MMSMHBEoj7zKHqq0sdloL8
rQVV71fq4MnDpN3O3Ajx798SB/TwBABCqZ8M
                    "], 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, {{{513.7890000000001, 345.383}, {
                    515.0780000000001, 343.449}, {516.3669999999998, 
                    338.559}, {515.207, 335.85200000000003`}, {
                    517.7810000000001, 337.39799999999997`}, {521.52, 
                    341.39099999999996`}, {522.676, 344.094}, {
                    527.9569999999999, 343.32}, {530.016, 336.754}, {524.996, 
                    333.92199999999997`}, {528.086, 333.92199999999997`}, {
                    533.3669999999998, 333.92199999999997`}, {536.328, 
                    337.39799999999997`}, {532.7230000000001, 
                    341.39099999999996`}, {521.52, 347.57}, {
                    513.7890000000001, 345.383}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, {{{513.7890000000001, 
                    345.38300000000004`}, {515.0780000000001, 
                    343.44899999999996`}, {516.3669999999998, 
                    338.55899999999997`}, {515.207, 335.852}, {
                    517.7810000000001, 337.398}, {521.52, 341.391}, {522.676, 
                    344.094}, {527.9569999999999, 343.32}, {530.016, 
                    336.754}, {524.996, 333.922}, {528.086, 333.922}, {
                    533.3669999999998, 333.922}, {536.328, 337.398}, {
                    532.7230000000001, 341.391}, {521.52, 347.57}, {
                    513.7890000000001, 345.38300000000004`}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxdlAtIFVEQhm8aYaESZWVFZlFiRphgRfZwCsQyohKSkhKRSimy8Ozr7u69
dxeJXkiYhVSEpVkJJVoWFhVa9jIQsfIWYmYikvZAJaSH1R7/g1ALy2H3zMz5
/29md07WgdTdgS6Xa4xzpzp3gHNn3F0fHDDToISaZ8qD+wpNzq9rvBhi0Kz0
XSs6nit0qG9LbcSQTqsn+MsOvlaoOHdSfl2Tjvh2hVz8StWJh28aUuj9poLi
3JM6Lef72SrxpeSXjrw9KuUUfjYTOwwaaNmYNTFDo+a5bd+9GSat4vVLVLrF
4/M8qP9ZxL/0QMd4DfqmeKk06fbgsEujpxuWHV2T4sXaq0L3Yy+Vn2uIrFqp
kR5WmdyZ5kPefA1663x0dE1md3ODSsmdTsQLH/H0TL+Ktc1Hc6rycgq7xXO/
D3F9Ku29JxWFL7Do4bfoHSfGadC32ULdGqF/p0UGP3edSi8dm9vyLaFDhc9K
i2Lb542z41Q6wnU0ivzfCrgMWFQb4TiOEueF2NTFDUWr5P4YFRc0zQZXJ35k
P8GmSdzfbJUcKq+0bBv58SryvDZ4NSjwfcoG360KPeI+1tngpSikPiiZEbvS
ppjDU982HZexH2/Dzw+JnC4XFHdZ4FwvET+mtswi/jo3XKaU4ICFh1cJ/6Uy
RXKON33o3x0Zujf7aCefux5J9NkLXWESPeHAL3jpMtdzlqFulUfMDaPQRTfO
f93uoRC+DjHw7jVRz8/Ql0smvdYcUBr7d76mM/Rz0ADvPAZuzEB/sxm4hZk4
12KY21YDfq4y6Moy4b+a0RczcUnGBxOc7zKcU29i3uIkcJzswf5aCfEt4ryv
ov47A/6yJSoKH5sW6tdHeYzEpxjoS4WE7+qPgbw0sZ9uIv+6BH/7DKzVEvy7
DMzzRhn1T+uYs2AZuj658b5c8F+qQ5+P4bv2aDj/DEPcFZUW8/ktF8/O3I1w
OSLiSxTa3/Ozoj+IgZNHhY5WCf25pmH/jchPdCNvnwRup92j8zXynfjd4Bgo
ow9jdehMkwUnHf6ZDB4xOuLzZXBI0vF/OCbmr1X8R4Zl9LnGLXgp9P//8C8A
IlPh
                    "]]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxdVAlIFFEY3lSiQiXMym6Nig5CBCsyy98gNCsyoaWiRKRSKix8c+3M7O4M
EmoRYRZ2EFZmJVRYWVhUWNllIJ1uER0mImklKiHdzdvvIZQwDOP7j+96G5e7
PWtTqMvlGuQ8Wc4T4jzZ15aGh4wzaH7dA+XmDYVGFDU0HY8waMK6jQvePVRo
Z9eq+on9Oi0aFqja8UKhioKoooZmHfVvFHLxvyydePnKfoXer9xTUbBPnOep
xF+VP3U6yPs2q5Rf9tlMeWdQ79MVucOzNXo8+fU3X7aJ+ZUqXeb1hV70fxb1
z7zAMVQDvpE+OrHkSt8vl0b3l80rTc3w4d2pAvddH5060hhbm6yRHn0+rdXt
pyjeN1UD3gY/labmtD9uVCmt1al45KflTntOQCU+Jue1n+JqC/PL2sV3j5/S
eV2XSluuS+UxMyy6/XX6+r2DNeDLtDC3TuDfYJHB96ar9MyhuaZIfLtVWsh5
nrco/s2UwXaCSiUcR5Po/61Al16L6ic6jKeJfRE2tVU7hKar5Pk4LWHIaBu6
OvXB8yQb/Cap5KjyXMuz0Z+oos9nQ69GBbz329B3tUJ3OI90G3opCqk3K8fG
J9s0q3jUq+bdMs4Tbej4XSLH5T0VbRaN5zrfkoivqa+y4HuMTBnhIbOKF1qo
PyFTLNfxkh/+XZWBO9NPwdx1SJQU9NlHuziuaInuccGPCf8OM+LrCmq9IjeM
ImdfPNq91ot3P4PenSbmBRh8OWnSc80RSmP/5msMg599BvQuZNCNGfA3j0G3
aBN8LIa8txjw7wwDrlwT/C8w+mKmzMn+YELnawz+3jIxN0GimVzHEV6cL5ZQ
/1Ts6xbz3xrglydReUyYOzKgD+gRrM8wSOG+1Ejw7Y+B++QW5+tM9J+TwG+r
gTxfkMDfZcCHFTLmH9CRs3AZuD55aD//f7XQf64OfH6Ge+3VsP8QQ/9pFfmt
Ft9O7oK6lIj6SoW2dfyo6RnCcB+9Kj3hOFok+HNWw/lL0Z/iQd9WCff7gGcg
X8E9AQ/yGCrDhzAd990tI8/ROvgzGXrM1FFfJEOPJTp47RL5a9Hgzy8Z+arz
CL0U+v/38C8RUlPn
                    "], CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{546.875, 367.90999999999997`}, {
                    547.2230000000001, 367.188}, {547.4019999999999, 
                    366.246}, {547.4019999999999, 365.08599999999996`}, {
                    547.4019999999999, 359.41799999999995`}, {
                    538.9019999999999, 359.16}, {538.391, 350.789}, {538.121, 
                    346.414}, {537.617, 343.965}, {534.6519999999999, 
                    344.47999999999996`}, {531.691, 344.9959999999999}, {
                    529.117, 349.633}, {531.949, 355.039}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{546.875, 367.90999999999997`}, {
                    547.2230000000001, 367.188}, {547.4019999999999, 
                    366.246}, {547.4019999999999, 365.086}, {
                    547.4019999999999, 359.418}, {538.9019999999999, 
                    359.15999999999997`}, {538.391, 350.789}, {538.121, 
                    346.414}, {537.617, 343.96500000000003`}, {
                    534.6519999999999, 344.48}, {531.691, 344.996}, {529.117, 
                    349.633}, {531.949, 355.039}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}}}, {{{437.93799999999993`, 
                    372.29699999999997`}, {435.805, 373.79699999999997`}, {
                    433.668, 374.40599999999995`}, {431.758, 
                    374.42199999999997`}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{437.93799999999993`, 
                    372.297}, {435.805, 373.797}, {433.668, 374.406}, {
                    431.758, 374.422}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    484.594, 382.684}, {491.414, 379.72999999999996`}, {
                    494.73799999999994`, 372.64500000000004`}, {504.648, 
                    372.29699999999997`}, {514.1840000000001, 371.965}, {
                    520.102, 358.133}, {536.07, 367.148}, {536.504, 
                    367.39099999999996`}, {536.9259999999999, 367.617}, {
                    537.3359999999999, 367.828}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    484.594, 382.68399999999997`}, {491.414, 379.73}, {
                    494.73799999999994`, 372.645}, {504.648, 372.297}, {
                    514.1840000000001, 371.96500000000003`}, {520.102, 
                    358.133}, {536.07, 367.148}, {536.504, 367.391}, {
                    536.9259999999999, 367.617}, {537.3359999999999, 
                    367.82800000000003`}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}}}, {{{508., 380.301}, {506.578,
                     378.03499999999997`}, {506.254, 374.879}, {
                    506.64500000000004`, 372.105}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{508., 380.301}, {506.578,
                     378.03499999999997`}, {506.254, 374.879}, {
                    506.64500000000004`, 372.105}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{476.828, 351.176}, {464.727, 351.176}, {461.633, 
                    344.9959999999999}, {461.633, 339.07}, {461.633, 
                    333.148}, {467.301, 325.42199999999997`}, {477.348, 
                    325.42199999999997`}, {487.39099999999996`, 
                    325.42199999999997`}, {492.801, 331.60200000000003`}, {
                    492.801, 338.301}, {492.801, 344.9959999999999}, {486.617,
                     351.176}, {476.828, 351.176}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{476.828, 351.176}, {464.727, 351.176}, {461.633, 
                    344.996}, {461.633, 339.07}, {461.633, 
                    333.14799999999997`}, {467.301, 325.422}, {477.348, 
                    325.422}, {487.39099999999996`, 325.422}, {492.801, 
                    331.602}, {492.801, 338.30100000000004`}, {492.801, 
                    344.996}, {486.617, 351.176}, {476.828, 351.176}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{479.02, 325.68}, {478.762, 329.027}, {
                    472.71099999999996`, 328.512}, {472.965, 
                    331.08599999999996`}, {473.22299999999996`, 
                    333.66400000000004`}, {476.316, 334.691}, {476.316, 
                    338.301}, {476.316, 341.90599999999995`}, {
                    481.72299999999996`, 342.16400000000004`}, {483.527, 
                    339.328}, {485.328, 336.4959999999999}, {
                    490.73799999999994`, 330.957}, {491.89799999999997`, 
                    333.79299999999995`}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{479.02, 325.67999999999995`}, {478.762, 
                    329.02700000000004`}, {472.71099999999996`, 
                    328.51199999999994`}, {472.965, 331.086}, {
                    473.22299999999996`, 333.664}, {476.316, 
                    334.69100000000003`}, {476.316, 338.30100000000004`}, {
                    476.316, 341.906}, {481.72299999999996`, 342.164}, {
                    483.527, 339.328}, {485.328, 336.496}, {
                    490.73799999999994`, 330.957}, {491.89799999999997`, 
                    333.793}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}}}, {{{483.527, 339.328}, {
                    480.691, 336.4959999999999}, {479.40599999999995`, 
                    330.699}, {483.141, 326.195}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{483.527, 339.328}, {
                    480.691, 336.496}, {479.40599999999995`, 
                    330.69899999999996`}, {483.141, 326.195}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}}}, {{{487.39099999999996`, 
                    334.949}, {486.48799999999994`, 333.02}, {486.234, 
                    330.059}, {487.262, 328.254}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{487.39099999999996`, 
                    334.94899999999996`}, {486.48799999999994`, 333.02}, {
                    486.234, 330.05899999999997`}, {487.262, 328.254}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{535.488, 344.414}, {
                    544.9569999999999, 343.645}, {546.5659999999999, 
                    354.074}, {539.484, 354.719}}}, CurveClosed -> {0}]}}}}}}}
                    , {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{523.8359999999999, 
                    372.555}, {520.555, 376.742}, {513.02, 378.156}, {512.891,
                     369.27}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    511.98799999999994`, 359.16}, {508.77, 367.148}, {500.527,
                     368.305}, {496.14500000000004`, 364.312}, {492.504, 
                    360.99199999999996`}, {492.414, 352.33599999999996`}, {
                    500.27, 350.53499999999997`}, {502.97299999999996`, 
                    353.754}, {508.254, 358.004}, {511.98799999999994`, 
                    359.16}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    511.98799999999994`, 359.15999999999997`}, {508.77, 
                    367.148}, {500.527, 368.305}, {496.14500000000004`, 
                    364.312}, {492.504, 360.992}, {492.414, 352.336}, {500.27,
                     350.53499999999997`}, {502.97299999999996`, 353.754}, {
                    508.254, 358.004}, {511.98799999999994`, 
                    359.15999999999997`}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}}}, {{{508.445, 364.184}, {
                    503.809, 368.305}, {496.984, 360.51599999999996`}, {
                    503.168, 353.367}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{508.445, 
                    364.18399999999997`}, {503.809, 368.305}, {496.984, 
                    360.51599999999996`}, {503.168, 353.367}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    523.8359999999999, 372.555}, {521.004, 375.582}, {514.824,
                     373.199}, {516.559, 367.082}, {517.914, 369.914}, {
                    520.809, 372.29699999999997`}, {523.8359999999999, 
                    372.555}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    506.328, 356.059}, {508.28099999999995`, 
                    357.47299999999996`}, {510.29299999999995`, 358.637}, {
                    511.98799999999994`, 359.16}, {511.062, 361.453}, {
                    509.727, 363.184}, {508.184, 364.39099999999996`}, {
                    506.71099999999996`, 365.40599999999995`}, {502.477, 
                    359.715}, {506.328, 356.059}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    498.72299999999996`, 366.504}, {494.08599999999996`, 
                    369.594}, {489.83599999999996`, 369.336}, {
                    488.41799999999995`, 366.762}, {485.074, 366.891}, {
                    482.305, 364.44100000000003`}, {482.172, 359.547}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{489.324, 357.488}, {
                    483.78499999999997`, 361.28499999999997`}, {476.188, 
                    359.871}, {476.703, 351.371}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{473.35200000000003`, 
                    346.543}, {476.055, 348.73}, {479.91799999999995`, 
                    350.27700000000004`}, {482.883, 346.414}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{514.691, 
                    354.90999999999997`}, {513.664, 353.496}, {512.891, 
                    351.305}, {514.5619999999999, 347.957}, {512.504, 
                    350.664}, {507.35200000000003`, 350.664}, {501.812, 
                    343.44899999999996`}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{526.9259999999999, 
                    355.297}, {520.23, 354.527}, {520.3589999999999, 
                    350.14799999999997`}, {525.766, 348.21500000000003`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{479.277, 371.652}, {
                    473.60900000000004`, 372.812}, {469.48799999999994`, 
                    369.46500000000003`}, {477.348, 366.633}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{490.09799999999996`, 
                    375.51599999999996`}, {482.10900000000004`, 377.449}, {
                    478.89099999999996`, 375.391}, {482.4959999999999, 
                    373.586}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{467.043, 
                    343.44899999999996`}, {466.78499999999997`, 
                    340.61699999999996`}, {468.328, 336.88300000000004`}, {
                    472.965, 341.133}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{468.59, 
                    334.94899999999996`}, {468.59, 334.17999999999995`}, {
                    468.46099999999996`, 333.27700000000004`}, {467.941, 
                    332.633}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{450.043, 
                    372.68399999999997`}, {445.148, 374.102}, {444.25, 
                    378.609}, {449.91799999999995`, 378.223}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{448.371, 362.254}, {
                    442.96099999999996`, 364.055}, {442.96099999999996`, 
                    369.336}, {447.465, 368.82}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{458.414, 364.957}, {
                    452.10200000000003`, 366.504}, {451.848, 370.883}, {
                    456.613, 370.238}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{459.188, 378.352}, {
                    455.84000000000003`, 378.609}, {450.688, 374.875}, {
                    459.316, 372.68399999999997`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{468.59, 370.883}, {
                    460.734, 372.039}, {460.863, 368.82}, {465.4959999999999, 
                    366.762}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{474.512, 378.352}, {
                    468.46099999999996`, 379.508}, {466.39799999999997`, 
                    375.902}, {470.52, 374.359}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{455.453, 356.07}, {
                    453.969, 357.293}, {452.75, 363.156}, {459.828, 
                    361.414}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{470.133, 357.875}, {
                    465.371, 359.15999999999997`}, {460.863, 354.527}, {
                    465.23799999999994`, 351.82}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{476.441, 
                    363.40999999999997`}, {471.42199999999997`, 364.312}, {
                    467.172, 362.898}, {469.875, 361.094}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGZigAKXKocZeULNB7pKHYSbD5xaWFrlcEHp9s+6
aaUOx7zNOx33VUHoulIHxQ1FGRN1qx1ko1Ks73uWOgiB1BdXO+Q+/73yo0ap
g3a72M1zrjUO1SLr3B8+KoGYd7IGLg/mO9Y42HJdX1zwvcRh2ewjChtuVTsY
3FVhazyKMG86yD1rSh0OfdWI6eepdvh0yTdJYEophA6ocuDT3TT3fW4pxN0M
VQ6trwN3yO0sdXhXY28ad6gKrv8wSL9WNcT9bmUOvCB97DUOIG7CQYR7d8gB
TZhT6vB4KdBBU2ocFED+bIbyb9U4uD+sElnXXgrxl0oNRDypDKLftNoBHI7X
Sh0mS7CE8clWO5Tvmy+l317msBNkble1g9WWE2X7BMsg7pxaA1G/CMqXrYX7
HwCZTbJg
                    "]]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGZigAKXKofpeULNB7pKHYSbD5xaWFrlcFHp9s+6
aaUOx7zNOx33VTkcB9F1pQ6KG4oyJupWO8hEpVjf9yx1EAKpL652yHn+e+VH
jVIH7Xaxm+dcaxyqRNa5P3xUAjHvZA1cHsx3rHGw47q+uOB7icOy2UcUNtyq
dtC/q8LWeBRh3gyQe9aUOhz6qhHTz1Pt8OmSb5LAlFIIHVDlwKe7ae773FKI
OoYqh9bXgTvkdpY6vKuxN407VAXXfxikX6sa4n63MgdekD72GgcfIDfhIMK9
O+SAJswpdXi8FOigKTUQfzZD+bdqHDweAn3UXupQDfKXSg1EPKkMot+02gEc
jtdKHSZLsITxyVY7lO+bL6XfXuawE2RuV7WD5ZYTZfsEyyDunFoDUb8Iypet
hfsfAJlVsmE=
                    "], CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}}}, {{{523.57, 372.555}, {
                    520.738, 372.027}, {518.2030000000001, 370.367}, {516.559,
                     367.082}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{523.57, 372.555}, {
                    520.738, 372.027}, {518.2030000000001, 370.367}, {516.559,
                     367.082}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}}}, {{{436.26599999999996`, 
                    358.395}, {434.672, 360.379}, {435.395, 362.355}, {
                    433.684, 363.91799999999995`}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{436.26599999999996`, 
                    358.395}, {434.672, 360.379}, {435.395, 362.355}, {
                    433.684, 363.918}}}, CurveClosed -> {0}]}}}}}}}}}}}}}}, 
                  AspectRatio -> Automatic, ImageSize -> {{128}, {85}}, 
                  PlotRange -> {{0., 720.}, {0., 480.}}], ",", 
                 GraphicsBox[{{{{{{{
                    Thickness[0.0008680555555555555], {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.968627, 0.8784310000000001, 0.09019610000000002], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {0., 576.}, {1152., 576.}, {1152., 
                    0.}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    1152., 296.}, {1152., 160.}, {0., 400.}, {0., 
                    536.}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0008680555555555555], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    1152., 160.}, {1152., 40.}, {0., 280.}, {0., 
                    400.}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.8117650000000001, 0.06666670000000002, 0.14902], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, CompressedData["
1:eJxdVn9QVFUUJiMW0RwSJjPUUScUB0r4wzADPMokg0BOUWoSu++9fbtLZGpR
aex7yy77HtoPKjKTqRxGQdEgYjSVzIgRA2vS8WdYiMg4hZrlGEEy2tS977ux
k8y8Yb+9957znfN997ydpqx+0nVnWFjYHezZwJ5R7KleNT7YpgZo8dhRievH
2en1BdLPxy/5SZ8/x36gyk7X6jtyUtf6KbnngYjAUQetUB/tXZLgJ29sU1Zf
q0Rh/G+in34a9hUfvCRR0u4t1+qj/GQ/kD121BiZclJZxMgQLj748sb7IkK4
qOo3bX64n97ezIick0awFX+bhPwMN05imf9xEGP73db+MoqPCGzKLHDQ2taa
+2dvKqOhhGffOXSXg1qmmL8+saiM1t/747G/9tjpj5N5SvQxH8XNZgU846Dj
07uHfSt9xLLMsT8u0dTml4qqbD76itEKH5Lohf6bu66/pxM7nX/xFZk6eAHJ
OnjtkmklXz+v0dPjHty95ZRM7NTScSUafc1o9HwvE8veMiVeo0peT7WMeGEa
dfI4fhn8u7yIXyj6860X67ki3pde2nvk1daaeSJeg1hPktHvHSF8cftHh6dW
34Y/9NK8z1mAbpn4v5qdXvCNUZCfxbfqKVRoB9vefMWL77cr4DNNE3ortO2x
fQN/p2kUw9f7FMrqK41tytdoKY93M4QtPWzOEWz5aryTfud9Xiz6k+ZE/zI0
6uZ+UZ2UyIWaqIHnL07UP0ujNelRXbWqivXnRL5Olc6suzwjpVEDryQXdJyk
0wmua4YLdZTp8NeAirjVOvp2QSVuo97PdOhzXIWf94Sw5Z+2ELbit+jg/6cK
/7yvw2+FLuhbrBO/NtO7XKhbEflj3MhbpKM/tW46NMgOrtJpTFftmvQVHuj7
hU7LeH3XPMgX60O+Wx4q5ffA7kP9tiLoVulDnWfE+Zs+5An3IP80P/hVqdh/
2k/8mvTMdRJv65q6AL3LiXQruCdnA/QIb1S7Qtw+zQvLRf3CH/5yxBtU6DXW
/si0IPrqdtI9y9nJG0HE61VxH98ywCPKA157DehZ54GvjxiUy3121AO/XjFw
Hxi2+NpM4jTTj3mQJ87EfNnpQf+TTWq4zi52roey+dzKNBHnhhv1ZJvQud5N
H2S+ubI/y0R9M92It8gkPg4CZ1zIx85bffzUhfpSTfif6Wvxjxfx+lXMkwQT
/junEm9TW46J+mLFec2Eng4XsV2n1+0X+9Nc0L/LpIXcL+0q+jcg4i9Toc+Q
SS/yD1edqO+C2F8g8FkT/Yp3ot4TJk3m5weUEWzxvhrCVr97FPBn560+/qDQ
KQaXD5qYD//pH1eBfA1C/5QK8J8bwtZ8fkMewZZPl4r5nlwxMo8s/FDF/+dT
UghbfphcAT0WyFTHG3l3BZVwYQrE/j4TOm2XiV/Plk6TPuH6t8jo50aTCvl9
2y+jn8+bNDMlsnHSPhn12k3MhyaZDvOBv9Ckkxwz/pY/Jpi4r/kiHvOj1T/2
Pmvn+BuBVQnvx48NwcdB/FYkBA3onO2AfgUG8XaU5jqITZfKzQ8beH8tcUCH
yQZt5f2sc4BftAEfzZCgV6QBv+ZLZI0Fm4H5sVoiDutHG5gPpyWK5vVGifUJ
MvIxbPk3T8Z9HB3CFn9bCGdwvsNB+H+WTHx8Z10O4n18S6INfH9rEPNnvQR/
1AbhvzwJ/EuC4BMm1s+XE6fZkWgH38hyeooLKRXS7b83/gUIKM2n
                    
                    "]]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 0.8, 0.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIlIGYC4qMKG4oyBFscLijd/lnHluTQ6Zjw9IJ2i8Pq
j5d8k2ySHI6A5P1aHDImvq2xP5nkYHPfv3d6TItDgS3X9cUWyQ6yUSnW99Nb
HLzNgTonJjts//z3SkVmiwMDCGxIdugAmZfV4qDG1jjV2TvF4RPQWIGcFodL
IPtupUDUZUPNY0l14NPdNPd9SovDKpD9JqkOj5fOPqIQ1+LwTSOm/1BmqkO7
2M1z36NbHLaeKNs3Py/VgRek3gvB3way3wrBBznP37zF4TjIgRmpDotBFum1
OOwtmSzBYpbqoAPUvlwJav7bFAc7oDMKFFschJsPnFoYmAIxR6fF4V2NvWmc
VIqDNcj/xi0OMiCDvyc7HP4K1GjS4tB/CMgA8sHh4NwCcbdACsS94S0OF0H+
NUpxAHmzAOj+/fOl9O8apEDUA/m90/OEmllSIOEM5BeBGJOTHQQiLLecMGpx
AJoS/HhnksPDKpF17hxQvmuSwxKQf/40O2wBuVMtCeK+T80OliAB5iQHg7sq
bI0fmyH+/5EIic93zZBwv5HokLUHGBD/mh1A0aR0P9EBPT0AAPiN+JY=
                    
                    "]]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 0.831373, 0.16470600000000002`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIZIGYC4qWzjyhsONboILrO/WGVTbxDxsS3NfYPGh0Y
QKAh3kEgwnLLiXeNDpvnvl9+7He8A5D0Nv/Z6ND6OnCHXGmCgy3X9cUF/xod
CkGMDQkOfLqb5r5nbHK4qHT7Z927BIfKl2qGHDD+vwQHmagU6/tA9QUg9SqJ
DrIg/udGh60nyvbNV0p0ALvneaODS3fO898/Exwu+yYJRNxvdABZY3svweEK
iH8P6r4LCQ7yIIcA3dt/6KtGzPQEiHufNULsYU9w+HQJqOFWo0Pv9Dyh5hPx
DhX75kvpT2t08OJh0m7vi3fQv6vC1tjf6BDyGGhzRzzE3JpGh1p707hdE+Mh
5mQ1OswAaj+wKN5hC8idXo0O8bs8eZgOxzuAtCnYNzps+/z3SsXKeIcOx4Sn
F7yg4RUdD3GvX6ODH5CydIl3ABnnH97oIAIKb5V4B5CzDsQ1QsJdNN6hE6S/
oNHhuLd5p+OHOIj6zY0OD6uAOjjjHdDjCwB5h8qs
                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJ5IGYC4qgU6/v+wU0OFS/VDDly4h1i+g991QhvcvgP
Au3xDpd9kwQiUpocQh4vnX1kR7zD1hNl++YXNDkc8zbvdLwR78AAAo1NDhkT
39bYMyY4bP/890pFZ5ODDMhg8QQHkLKECU0O++dL6d91SHB4WCWyzn1Jk0MR
SMP2BAeb+/690xc0OQg3Hzi1UDbRAeyeZqj88kQHW67riwuKmxxAlO2nRIcj
ChuKMnKaHI6DDP6Q6DA9T6j5QHyTQ+vrwB1ycxMdgLY9vRDS5OADsjc00eHT
JaAHQqH2B0Dlgf4pBBnsAJXPbYL4wyLRoV3s5rnvJU0OVluAHpVPhPi/Euo+
xkSHC0q3f9Z1NTnE7fLkYepOcLADOay1yUH/rgpbo2MCxDyg+4CqsvYA/Qs2
NxRqPpCvs2nu++V+TQ7VwGB4aJQA8Z9Hk4MXD5N2+7t4h/fLgSHrCg3vDfEO
wNiI6XdqcpAHeTAPwd8MNOZYNIK/DRTumvGQ8PVucnDpznn+2zDeAT1+AaDz
25I=
                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4vfLj3mbqzY5PF46+4iCTYLD4a8aMf2aTQ4T
DgEZ2QkOny75JgloNzkwgMCBBAfr+/6907WaHO78rMvak5PokDnxbY09kL/q
I1Dhh0QHPt1Nc99rQM1LSHIAURvUmxxaXwfukEtNcpCNSrG+rwxVX5LkMM25
O+e5QJOD5ZYTZfuckxyAqosy+KD6VZIcsvaUTJbghcoLJzmU75svpc/f5HDz
3Pfgx28TIe4ThrrvQqJDuxhQRqLJAegq07hFiQ7yIIslmxzCQA4rT4TYJw41
/0iCw1agsfNFmxwuKt3+WXco3uEy0LgIoPrmA6cWupbFO6CHDwDaDYs8
                    
                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJRIGYC4mnO3TnPdzQ6HPc273RckeBQvm++lP7uRoeL
Srd/1l1KcIjtP/RVY1+jA0j4rkaig/5dFbbG/Y0Oj5fOPqKQkeiwpMCW6/qB
RgeQspjliQ6fLvkmCRyB8r8nOmw5UbZv/rFGBxegNb8lkyDmn210eFtjbxpX
lORgfd+/dzpQ/ptGTP+hziSHGJDGrVDzI5IcsvaUTJZY0egQt8uTh8k4yWEx
yL5VjQ6WIIM3Jzo8rBJZ57620aH1deAOOcdEB8EIoAxQvVPC0wtK2VD3L4L6
TyLB4YjChqKMBVD7mRIc2sVunvsOlGcAAY4EhwqQ+1ZB3aOZ4FD5Us2QY0Oj
wyLXbZ//uiRA/LOt0QGoK/hxbYIDevgBAAJ8n60=
                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxdVQ9MlVUUf6IjYvJUaIRmSFhpmqJsCaXU79Ws/IOumI41dPfe77W9LA2V
JMn47p2pUWPkmFpzRQqGERUrYq0RGhC2aoWwxaohQ5blnBG2MtfKvvPOKbbe
9u3b+e495/zO75zfeTeZJx9+dGIoFJoQPKXBkxA8Nz4SXTpU7NCX/f2Vyk0K
m9rLajNiDskD9aUFRxVGG3tW5T3ucHR5269/dSuE6LfVIaJ+6M0u19iX/u1X
l7c7vLwldffJPo2lQ2urD5U7fByEmbTE4FJfoZm60+HO1s92dBQZrMqriqhd
Dhd33XPHxoMGVRToKYeNH62YnHDYcP6o5DcGvYQrwBfbH3gUSLzArun8bW5J
nkF3Vsu2WInDB0H4ur81nu6om5Fj5Px9jZ3nb12ctEH8ryjQ55oih+304YRi
PKsd1oUXvPdqreI4BQ5pu09+fqRK4RDVlSPxGhWCW6ONtzlU00Gr4vxzpb4u
hbMV173zwDyH34M0necVGkoLkgcWOGwNXvWLNG4n/9nCZ75mPNc4zFmc1Dwz
UWOY/C9aULi6bxRKKPGIZX6/U8jcc+GhD89Zxpum+fwny/2bp9kvOI/XG9Go
p/xnLeMp1MzfoMWJgKZBpUGwSgcs16Okny2W8azUCLoyf1+T5X7dr7n+44Jn
zbj9TAB7eMu4Hc+3R6Of2tVo0TQWJH5dY1pxwNQxid+kMXLscHdWg+V3q0YX
8bFf8LVL/grJ36GxgepdY7lvn2iQW8tCwXNGIz7PGRY5gzcnuumG5zFB7HWG
+xuS+M8Zjj9F6v/DMB/pgm+hx/3MtCB1tJd5INpHsyxSaT4OeNy/2YKvzQOl
Xztf+nfO47pyxT8UZf984WtGlPPfbXFLojtwX964HdcZxu24ntZHWQ/ZUn8k
iudJP+lSf3aU+x22CLpYNJISxSKqO8WyXq963I8pwsdpj/maZrGNBqbWY70k
/YvHA2UNX/DZHjL4mers9JnHStHnXp/1+obBEz/++ebYEp91s97DZrIzfJ7H
Vzw8SAOe4oNg1h/3eB4TfdZbcB7X0eVKxv2sx3thoo+XiOgbPK57us/4xwxO
U/5cn9+dBuWk/1qJHzOcv9nHKXKMCb4en/mNyf2vxS6R8zM+7iIcs2Q/XfJZ
//2a7XyZj70yfzuknxUaj1GdL1i+Xy778EWLHspfprGM7GrR53LNeq6xXHea
6K9G+E+TeX5b5iuseX6+kP5dqzlOr8SboHn+Tlnmb1BhFsXvtriX+t8v+6zL
Ml8dsl8+tVzvu+o/f+6HYn6+lHk+qHjOhmXeXlPcv19Evw2yX6/K/DZL/EmO
9d+ieF6SZf+3iX9Y9v9bClNpP6Q6nl8n8a53HL9Y9u1MByorc4VifueIHVF8
b5nEz1VYSfoplH0Lhf//3/0DDjwhTA==
                    "]]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 0.8, 0.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxdUwtIVEEU3SwspL8iESXmD8NEIiopwmMfTKzEjTKiZGZeoUn00SgrseQa
YlKb9DFYRFwNrajMNCzUxCwkQqwUy1jKJCJEQvuIZNDMztCDFoad8979nHPu
fUvEYef+qQ6HY4o8CfL4ydMT9n6ioIjQeuzygmnPGWbHNlR8u0lIV5c5HA71
ayc0dR1vqxQceW2VC+O6CdcPzaf2AY5rG0oPfukl7FDxgQKdofU5WQOEQGp/
UZVsY1++08aujp/RezKFrt9FeNc9vn2oRKA4WN5abOyrf9/GyyS92nuEoRvu
ztA6gZTVJYmskXB79PVWMWnqPSK8Urq2WXj4/U9v3gNCnDfCv7DJ4Fs2PqH0
1Np4i6pXRRjJT1iZ4bHwVNJ0VRDWs889YaWW7l9O2Ps4eaZfpqX7S7xT6U+3
oGjVuwkZ6n24hewWaayHcG44rTmkT2BM0pxbYd67BRqVL6Wk6xwwesjoTROo
PrIuoL+AUK78XmXji+rBIhsH9Mubv4Cy1XWGtA8/uPb7rI0HTwXdTSq0sU/v
eVNf5vvmdIXwS5bpWCx0vPQnJ6tsJD9J4JPCDYQn0jZvhMAbKWdXs+E7z8S3
Ek7Lv8Ex/g/7+n20sWeTnEQR1/n5hDXKiGGmeaSS5uVlOPk1avmMeMOnj+n9
WGHy3zKEKGNjCBvlmvyeMPGRBDn97JYgrv0OJ1xSxsRwvbcRZp4pZr+jzD5a
HLv3rf2QGk3IVXpdHDXK36UEBRPucN0/lnBUPq6e5Him/I00+ke55hNs4q9y
Pd8AwoDis9n0m05IVP3Hma4/y/jzkul5BRp9dQbHG/+LmZ6v0/hxgek8y+Ay
pvvmmno1DP9/338BdlTBuQ==
                    "]]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.8117650000000001, 0.06666670000000002, 0.14902], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{647.48, 164.172}, {646.242, 166.059}, {646.984, 
                    168.336}, {648.8399999999999, 168.336}, {649.938, 
                    168.336}, {650.1519999999999, 168.066}, {
                    650.2810000000001, 166.48800000000003`}, {650.395, 
                    165.172}, {650.145, 164.375}, {649.414, 
                    163.71499999999997`}, {648.4219999999999, 162.816}, {
                    648.3589999999999, 162.83200000000002`}, {647.48, 
                    164.172}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 0.8, 0.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJpIGYC4iu+SQIRdS0O/Ye+asR8TnKQjUqxvj+1xcHb
vNMxITDZYUmBLdf1+S0Q8cPJDgwgsKDFASS8uCTFIWtPyWQJIF+4+cCphT9T
HDx5mLTbN7c4XFS6/bNOLtUBaMrTC2egfL9Uhxl5Qs0HnkD56xB8yy0nyvY9
RvDf1dibxkmlOSydfURhw70Wh6KMiW9rxNMcdDbNfb/8MtQ9t1Mh/NMtDoUg
92xIdeDTBQocaHG4ADJ/WirE/TNbHLYCjZ8PtL9d7Oa57/0tDn3TgRbZpDpc
BvkfyAfba5QK8U9vi4MPyP+9KRBzuqDuPQf1f0uLA8hbSu3JDkcVNhRlZLY4
LHLd9vkvS7LDY5CDI6H6tyZB9Ee0ODiB1K+Ghm8ygg+Wz0Dwj4DMK2lxCAN5
5HSSA3r8AABNAMog
                    "]]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 0.831373, 0.16470600000000002`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIxIGYC4ul5Qs0HttQ76N9VYWssTHbIff575cdD9Q4+
5p2OCVOTHa5WvFQzvFHv8LbG3jTuXrIDn+6mue8f1zvIRqVY3xdOcXB/WCWy
7n29Q8ZEoArPFIfDXzVi+hkaHG6e+x78uDUFYg5rg8PWE2X75s9KcQBpXy7Q
4OCU8PSC0ukUhyu+SQIRXA0Ora8Dd8i9TIHY86Eewr+ZAqHv1jvc/lmXtedC
ioMd1/XFBVfrHS4qAUUOpTg8Xjr7iMKlegdvkD0LUyDuOA5Vb5LioLChKGPi
5nqHb0BnHTqaDFG/qN7BpTvn+e+JyQ7vQPY11UPETZIh6hvrHY6DDDRIdtgC
cncfgg+2ZyqCfwjk32X1DsLNB04t9E12QA9PAEFxqOI=
                    
                    "]]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 0.8, 0.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    623.727, 154.941}, {624.012, 155.79299999999998`}, {
                    622.383, 156.40200000000002`}, {621.6840000000001, 
                    155.70299999999997`}, {621.383, 155.406}, {621.305, 
                    154.895}, {621.508, 154.566}, {621.9649999999999, 
                    153.824}, {623.438, 154.07}, {623.727, 
                    154.941}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 0.831373, 0.16470600000000002`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJFIGYC4ul5Qs0H2OodMia+rbEXTHEo3zdfSt+w3uG4
t3mno02Kg9WWE2X7Iusdbv+sy9qzAMGvFlnn/vAegl8EMoA91QFo2qmF5vUO
qz5e8k0ySXVYNvuIwgYJBD9ulycPEzeCD7bvY53DzXPfgx/Lpjoc+qoR03+n
zoEBDFIh9Jw6h4tKQBcsSnGIBekPr4PYsxXm3jqHCSCN+qkOj5cCLRSqcwjl
0900d3Kqg8fDKpF1H2sd1A051sicSnWYLMESxncVwY9Ksb7vvxHBlwEJrK+F
hMfcVIdOx4SnFy7VOuwHWnO3JdXBEuTfx7UOra8Dd8hVpjpot4vdPAc0vw8U
kDGpDnZc1xcX/K11AOo2jdNLdbAF8eXrHKpA4bUsBWKfcZ3DDFC496VA9PfW
QcKlPsXhEzBYBE7UQewrSXHYCrRu/qk6iPv0oPJn6hxU2RqnOrOnQOLhQp1D
P8j/z5Mh5l9F8MHm30TwweH5oc6BG+gs21/JDujxDwBgU+hd
                    
                    "]]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.8117650000000001, 0.06666670000000002, 0.14902], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    495.555, 164.176}, {495.09, 165.383}, {495.746, 
                    166.516}, {496.90999999999997`, 166.516}, {497.977, 
                    166.516}, {498.22999999999996`, 165.727}, {
                    497.65200000000004`, 164.21499999999997`}, {497.25, 
                    163.176}, {495.949, 163.148}, {495.555, 
                    164.176}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 0.8, 0.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    667.9449999999999, 166.383}, {668.23, 167.238}, {
                    666.5980000000001, 167.848}, {665.9019999999999, 
                    167.148}, {665.602, 166.85200000000003`}, {665.523, 
                    166.34}, {665.7230000000001, 166.012}, {666.1840000000001,
                     165.266}, {667.656, 165.516}, {667.9449999999999, 
                    166.383}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.8117650000000001, 0.06666670000000002, 0.14902], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxdVH1MTWEcvtKaUaY7i1HkM1tr5Q8jiYc7U0hj8zHS0ilOt9x76x4k9x6d
e8+RRtJExtJizcfMWopUYkiGJWQ0a/lqrRn5nJls3p/f3WzO9u7de97fx/P8
nuecKen2NZnDTSbTMLEsYvmJtaA3uaTinIb59fd2tu6RkFJ66/usGg0fXIvm
pKoSYnqmB2hlGqJpL5ZwzHIgp9+l4e6KucWLyyXsX5zW12n25T+Q0CC2qvJC
zAzQjlr2ZOBtzck74fMKsW50VF3l+kxU2Mzemx0qTi+98vV3wjYsHPn8jKPS
DRM956ygsmnxbkTMHnExNN0GEX2/+pELHwnPmlxEFoV0d4S5GU+EE/GUP1nF
xoy43mS3wrhXqQivzZPLmhWE0sVeFZubEgP9BhUQnNqdKvd7oYBgDTpV7Gqt
mhD92JefpnL9agVymXizQsWXJ0npY2wKnuUPzJzd5eb4JCfjbXMjlvhPzON6
YSrjbncwT6jY3v/r/Gc4+H6Lipc/VWtLlx1BdK5SceGzaPDOxvH5ezFK0Io/
kY1imm9RIYz3qxsnRWXB2qIcGS9reDxVVFBl3CGiBRraCYhDxm4Bb0SlT6+1
MuNu0JBK/C0yBs8K5b758s0y4kj/EA9I9pRxMs8lx8M4UmQEbxDMmj24Ltr6
n5K5/5AHhyn+vQyS48ccL+ufnIXb4nVpn5f5FFoZxy6d59GWg02k0y0dT6h/
gR3LA/0ii77reCVg2C442D9BBjrpPiCPdf2ts/5mJwSqrvyvOvuv3sn9u3X2
UaYCglXa5Kv3xqfvZZ19N6TgqRjHhlod1yaJiZp3cHzdv/NVqn/t3/nv/AZ0
hBGQSoX972+wngkKssgfSwwkvC4Ye6nECUprzDbYNzV5SCR+Bb77hlzGsc/A
cdo/OdhHLoPnYbUzX8lALhl7aDvrFWPghgjrCcxmv93UsUTYYqrFp0esznod
3Mp1z3s5viWD5xvsxSFq/FDiea30MB+vxHimeeCgfooEgrmsUcMM+n7tEv7/
P/wBILPrVg==
                    "]]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 0.8, 0.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}}}, CompressedData["
1:eJxdk3tIVEEUxjcLW6REtBehm4nlRklJyEZm+5WhiG5mQYaUiNxZLxJmDyLN
FpyTSPlHRERBlMgmgURYRPbYNtGtrEDMDULKYrUHIj62sLAImtkZErow93Lu
3HPO9/3O3JUVh3azuRaLZY5YG8WKEutu73F/SwLBIi+fge5p+/5zSwk/xKP7
hYHa0dUZ1kTCyUW38kITBjYMpUY3JBHG652ZZbEMTUsG+37aCOK+ZySdYbhO
fJhC2NF88OvvfIakUiPrYyrh/YynylfIkB3z1luTRjhqnh+vL2Lo/P7nzYkM
woSsV8ow0nYlkJxFeNKyfP2QwbAw/c7VyVyt5zBDSNbfpfWcZYjoLyEUOM5s
K7/NINsVmQS/zLe6YWscK77v1vm1blT5jl1YVkxoDw+4Kk5X4p7sn6fr/arE
1I1nBY6thNcp72Y81SZ6JI8thEJZv1HHmwibZeNHpuKTqf0/MJVfu65XZ8Jb
IxwLPpeq46kr11T61xCkLNtiU/l1EFZFN1zMCVYqHi69/1Tr3UnYGytAlLgV
PxFLfM4kN4SraXshIYG6XraGmYqFn+3ln/tTgpqnU8+jlam8HELZw/wFUV6G
Sel3PindPXpeM1zlv2LKd5ireQQYLksfnzgGJJ92BlFlbVMfx3M5gHqGfvk+
wJGWYb2Z6NHz8XOlT8wn6KqI29fJ/+m9Lvl0cKVrcDaO8Dw1G0fO5zqGQHLH
EfPDbPxNjDEuxJXuMUP1H+aQad5eAwckjy8c8bJfm6F4jHJIjNnXDKyQoKe4
4ttsqPMWQ3gssM8T+///H38BLhp1tg==
                    "]]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0.831373, 0., 0.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    606.387, 168.33200000000002`}, {605.305, 169.984}, {
                    605.762, 171.195}, {607.4689999999999, 171.195}, {608.406,
                     171.195}, {608.9409999999999, 170.816}, {
                    609.2890000000001, 169.90200000000002`}, {
                    610.3359999999999, 167.14499999999998`}, {607.992, 
                    165.879}, {606.387, 168.33200000000002`}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 0.8, 0.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxdVQ1IllcUth9E1pBmK9yW2d9KaKLRRitzPmXRmko/o6byuZp1rxphTjN1
uXrvdSExnPthVph89DdxcylOo8CZq2i1KMK2RdMIaRElzdmoLcbY7nnPoRcm
vMjh3nvO8zznOeeblr91jRoTERExyn3F7hvtvoz5exZv+NXD7LlRrZPXKSTf
mBlpRjwMPN65uXuLwububZ/FjjL4ni4eUKjsCT+fFG2QSe9+UnjQl5U/fobB
u6lPXTucrFFB5ykGp9y/GzM1qu7OmhuVY3Blev/jnZM03nh69JxaFxd+cr86
bWIQ+/kH1JN4x7PHlg8eUyiie7lS72uFrvPbe8LlBks23L4y/bDU3y35mhRe
czBK9ht8OeIO9ilMzt2UcvNQEEfQX5vUc/G+4pia3i6p95HCM9kLOs+flPuV
CqH60w8TThn8Vp32ytu5gue0wYSa3h8O5ihQ+pXDBtcv//nmrSKp/5zFoWXH
//jHvY/fPbT6xDSLddGJHU0VEr9s8SjBZc5T+L35XMb8JRYfuzKhDOGz2qKU
CKVL/pBF3V4H9HWFM+5afbXFYuL/luBrscz/O4VO0qfNMq9ojbNT20sL2y1u
HW08OzVWcz+7LUqoXwkai26urNt7wYLShOZp7u89yz7I0qBn7UMWvk+KNAbf
c0JdkveVkq9X8OyS81ap/6lmXActzlGCI5r5NljEkH5d8r7WIo6InpF6u4L4
qpMje2sQTyH91otejUHs+60kiP26a4VPvuBZo1m/css+ytXYQ8Bd/aUfbrnz
9zuCv07452n2T4PwSxN/N1n23xy57/gtIOEnaNROck4Iy/k4jZc6moabGwXv
sMIXxK9c6rUoHCEhN1m8GGk+Tw8r7keOZZ86f5LMJassiNYU529KU7/coowI
tinG/6rFt07GsZdlXmcI3z7xe7xlv59QrEuc6NUq8xQr+n4j/o6R+KLcj7JI
8veCzOeIeXLu4/nFsJ+Pip/7DOvRHMS+n68GsT8PdxTclPxYeVHm567gaTHM
d1Cxvh/I+2uih2fYj9dlX1UZno+/ZH7K5P1E8UOpYf3jNc9TheH9tkgz/h2G
dcrWPD8u9udho5y7+2sJb5nGCuJfJvxqNOMpFj1qxL/rDc/bNo0U6udCg69o
n2RqNKS7xicZ3Kd9kh/ElCb15yBeSPlTCthvLxj2X0EB79FI4ZdYwPq5/e3r
d0n81u/x/glpkCy9DyROlniM6DVe8P/rYRzVvyf7yeXrJ306FfPt8XgfFirG
d0B+L0rFvyGP+Q6I/7I85vNI8f5f4TGfIYVEwpcp5x2K+a3y2D9V0r88j/3r
9u0w+eV9j/d/quJ+hoVvnPT/gsdzOlvh/79n/wGN1yE9
                    
                    "]]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.8117650000000001, 0.06666670000000002, 0.14902], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{544.4259999999999, 180.895}, {544.2230000000001, 
                    181.42200000000003`}, {544.4730000000001, 
                    182.02700000000002`}, {545.0659999999999, 182.461}, {
                    545.891, 183.062}, {546.1519999999999, 183.059}, {
                    546.7850000000001, 182.42600000000002`}, {547.195, 
                    182.016}, {547.387, 181.312}, {547.215, 180.859}, {
                    546.8009999999999, 179.781}, {544.8439999999999, 
                    179.805}, {544.4259999999999, 180.895}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 0.8, 0.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxdVAtIFUEUfRmIRJhURIhFRWaQphJlZeJJrQhTy0BF/GU2s0/r+emnJHbF
wkTMTEyhREJMCpOorBBTs8yICglN+oiI/SRK+lhIBc28mRhwYdg9O3f2nnPu
vbs0PTt230ybzTZDrDCxXMTqXXItz3pKyA2ZNdSYw1AwviLQ7S0honz/h9+X
GfyHl7sWj5G6NzHUOuaWdL8ndDV4+g9HcBU/TrCqPheGtnH4Xa+faP5ImFfS
/fjiXQ6bvEYNLl3w8tmvQYOPdooP9RNOftp1Z3GFwVe+Po9KD5i2P8mwKDEj
eETw/VIYujblFVPf6yXUSV7tDEmVPZMrbxDi3QWTbIYHUt8JraeKQewmVRYR
vF2La8InGLbPdllVWkg4KAXM4cjsOFS98DihLzKobLMvx7lwcfAUKR0ZHDJ9
TD3BSz4McVw6LzLUEcaaxMMPDl+p///5Cxy3vv8dyHeQ4p3KIV+nZRF8At1a
vFJ0vEPjs9q/XM33Hlf8s7T+QY4d8nwyIbldMO/jyJf+xBE23nx0pLOLYyAq
3SMhlvBTyOy5yrFpJKaidichRcaXc9RIPdEEeWzY0vWJ1PnjOCaaH0YGRRDO
SKNiuOK9XvMP57gv/fMmHJvfum3UYXCe9K/a4DZBp6FV6w/T/IItpZfrfC8s
pfew9svDrnwsJsjwhq0GO+sbbbBTf7xd5SnQepPtKl+Owd9EG3nsNVi4964/
lbBBJog32OlPqMFOfqvtqh+idP2fWMrvdbr/MyyVz5UgunD3mOjf/mWvp4pc
dL32cMXXkxAn+9GHq/700/tTDAFyrrYQ3kwVZXb8YUpPgp7HAB1vab8TDZbT
GuJu8Gk5mC1M8TxAqs/KmJof0nzTmOrfOs3Xj+G25N+m67uGYfr/4B9wp97J

                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxdVX9ollUU/pwwhooMlTAx54bNzRrmLD5Jp4+JmDmzFFF0Wzbme+99v9S2
ZGm6Uu6VjxGyrEzZsGHLH6T5K1uy1lwr8lfKmqL9kmk6rKlME5X+CLvnPQcH
ffDyfYdz33Oe57nPOV9m6Yq5S/vGYrE+/lnqnxT/fPp6Qb8Lay0G29aT208H
eGxR2cROHz+eun7ztLjCd3dzimqqLI7NildPhUJRTdvdnA0WW5cPsq3PKlRP
XdLVftji13/eDpuHKjRQvZMW/S74X/kKBfSjU+o1KOyo+37kgW6LT6Y33vn3
ksKTh7b17Lpu8Ru9f0thVUv9sLHdEr+kMXNAyhPJPy36U70mzecfSL39mvHl
OjznYWTVaaz+K3tc2hiH0ePS9g6v1bhCDUc7DCJ+8zXjz3CMv1b4pTvmPV7i
G8LnSACiveSs8C0NmI+PiWbDhAA7ic8NiXWAvztml6anOGy4/vKREZsCDKe6
wxxIpqz7AXp2/TArnuOgN91cO6VYIUaffMf67lbYQn3GO9zzMNpOKHw07d3X
rvn4s9u+MDTC5pUfDH1a3v9G4meEzxnN3wUSd2uuP93xfaQY1me2Y/3TDAzV
KRG9Ug02U78Kh5+y/A3485F+lQ5vDdk347LPj704KnX9O5LPN3yfSYeNBHyh
QSHpVS39lhvWLyn8thrmZ4Vfl0HkP58/6q/9YixkvB9LPi9E8pFfztz/2qGD
+oUhDh+vbKk/5pBN97+nN474DEk8jKP+lQnG3+qwYGDeoW37E3iK8H/p2D/1
CUymg587rCF+7ydY170ST07AVz236gvhly71Gh3eoIMPQo6/cqxLV8h+8PUj
HOdDno+Dou++EGe9PRbWOdapSvgm5T7LQ5Bd5iwT/q+G7P/FgmeM9HtR+n1r
uP4EB6/SvCuPGvbxRMfznGm4bq7oW2YY3wDHdX407Oc7lvMHJO/nLfJrhmF/
XZX8JQ2frdC/W7znx6jI5yd1ztm45ZzMR4lh/Kcs41lm8AcZp80yn5kGt8j/
TZbx58r7zRbtdL/3NPvhhOyb3Rp5NO/tlnVap9mv52V/FPbGEd54b1xOxNoV
+71F+lcpnsed8v6HivvWWvbpdsW4aiyKm7zy13rj6HyOfhhH816mma+zKKHz
r2iQzXrWyT7N1LhM/NdY9m+TwghaDCss++mqYp+EluepQuNN2n9K9OzQ7L8S
4f+z5vmZJ/p4PaL9UCjx8xoZVL9Q+BZoFNO+myv7dJTGC+SnYunv922E3+OJ
9stIxfNQbrlPY8B+XSn3kx0wLv//QGWL4gH+///xHxEf4Jk=
                    
                    "]]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.8117650000000001, 0.06666670000000002, 0.14902], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    640.777, 199.99200000000002`}, {639.508, 
                    200.92200000000003`}, {640.09, 202.41}, {
                    641.7230000000001, 202.41}, {643.211, 202.41}, {644.387, 
                    201.184}, {643.9609999999999, 200.07399999999998`}, {
                    643.586, 199.098}, {642.059, 199.059}, {640.777, 
                    199.99200000000002`}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    652.1990000000001, 203.47299999999998`}, {
                    651.7930000000001, 204.754}, {652.746, 
                    206.05100000000002`}, {654.094, 206.05100000000002`}, {
                    655.094, 206.05100000000002`}, {655.375, 204.848}, {
                    654.754, 203.23}, {654.3009999999999, 202.055}, {652.602, 
                    202.21499999999997`}, {652.1990000000001, 
                    203.47299999999998`}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 0.8, 0.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    516.082, 182.812}, {516.1800000000001, 183.316}, {515.918,
                     183.684}, {515.4609999999999, 183.684}, {514.496, 
                    183.684}, {513.914, 182.83200000000002`}, {514.371, 
                    182.094}, {514.8399999999999, 181.33200000000002`}, {
                    515.879, 181.76999999999998`}, {516.082, 182.812}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    556.75, 187.359}, {556.75, 188.105}, {556.4689999999999, 
                    188.38700000000003`}, {555.848, 188.266}, {554.488, 
                    188.004}, {554.3399999999999, 186.281}, {555.672, 
                    186.281}, {556.418, 186.281}, {556.75, 186.617}, {556.75, 
                    187.359}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, CompressedData["
1:eJxdVGlIVUEYfWWJWZaVhJipbRaPwgyyjVef2mZloUGCaYkUzlzS1CJtm7ll
YhphWVEQJmkJhYlIi4k+xYXCH2pFqYmFWEhEheWCWNHM/QYHfHAZzn13vu98
55yZhYnHoo+42Gy2SeKJEc9k8WQ4i3yCtnLYcvlo/9hoErzL/BoYHMfh+9nN
aw6GEGgcWh6XX8nhdsqcrHo7gfupDvcODxPSxFLiS6DvwZ2mAC8THg28iUxc
TsCoOXHde6MJXa0j+/p6CWwSn6VGmFArXk8JpNAg68WYMCyWhngK7Yu6R1ms
xs0BFekkXuPc0IQv7YdMuHJLEEjVOF8WytF4/ZNXJ52NFPyzv0VVRZpQvPXZ
77/1FE6Jcdy2mLDU9fzN8CyKfENMmC5oOewUek97lW+fZYKk6bhAwCZ/U014
KsoVpRPk+4/jPJTAp72CyWcOvrGHN35KIuCxsrLwZxvH+VIInBHleis49ssg
QK4JJR9zrHuWwAK57wWHZcFuZb55BOu0KX2LlX42E/V3peP4YHXEjMnzNbb4
rKHoV6fyaw8FOb5fHUceYRRX4Z/Fw0FhblZ9y72bHNLli8VKD8bx/TQKG6SO
URykzSWdyt9V6vsOjaUd9a50HNeJGPV4UbDnzOtqDVf9dyp8QGFGcf7jat5K
tb+Ao1+Din+RyuNsA36JWHmWcZw/yMDvq1X/bQZU+YkdTo1fyzw1aDxT+tOs
6kVpbM15SOOgniWu59MMSO4fezhQw+HDKDNqMg2Q7SpKNbb0ztPYqpPNMT/p
BkjZUo8rvVcamBfCMZ8uBryQfKPV/C0UcRjHvJVTKJX97Bx1yKY4f4DC5xR2
53jeLlKQ8e39yND/AorzNDLMo3MCHta4W/L3NDDfTob97UrvKgYx8kOht3U+
Sxn2dxiYk1wGL3etzQ311tjiM0jHsZX/5xTk2EU3GOb9LkU9mhjmN1nx/8HQ
33Dl/xDDviEUZJuEEYZ1RN52yAM7qv5/T9CfPwzvo3YCMl57Z6u8viXo12qO
uRF5tupv5rBb1i0kmJMVHOvtJ7j6cbgqhfEn6IePOh+1SXBJ3jeBGlv3j11j
a/86lY/OJJh4v/4H4LaNtA==
                    "]]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 0., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    502.648, 195.906}, {502.648, 196.754}, {503.125, 
                    196.871}, {504.469, 196.35500000000002`}, {505.16, 
                    196.09}, {505.195, 195.934}, {504.64500000000004`, 
                    195.58200000000002`}, {503.566, 194.89800000000002`}, {
                    502.648, 195.047}, {502.648, 195.906}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.8117650000000001, 0.06666670000000002, 0.14902], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    504.72999999999996`, 198.164}, {504.72999999999996`, 
                    198.617}, {507.008, 199.809}, {507.875, 199.809}, {
                    508.887, 199.809}, {508.328, 198.359}, {507.199, 
                    198.055}, {505.562, 197.617}, {504.72999999999996`, 
                    197.65200000000002`}, {504.72999999999996`, 
                    198.164}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 0.8, 0.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    539.324, 194.605}, {539.324, 195.73399999999998`}, {
                    537.2930000000001, 195.578}, {537.0740000000001, 
                    194.434}, {536.93, 193.695}, {537.164, 193.52}, {538.105, 
                    193.65200000000002`}, {538.777, 193.75}, {539.324, 
                    194.176}, {539.324, 194.605}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    628.9609999999999, 202.547}, {629.168, 203.621}, {627.668,
                     204.348}, {626.875, 203.555}, {626.082, 202.762}, {
                    626.805, 201.258}, {627.883, 201.465}, {628.379, 
                    201.562}, {628.8669999999998, 202.047}, {
                    628.9609999999999, 202.547}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxdUltIVFEUHZVEwspS/BhM7KVSyDQfERXmEpGKiqigDymLwYk4Z66lQfTw
7ptJhD+9oEaI0J4Q1DRUyiAymZSFhFYQojXkMEhEWVRkmESdM/vQQBcO96z9
XvusBb792/wZLpcrTR2vOunqbFzZWrknSHjY7vbEwgLLTuWPDN4hNO47N9E0
LPDt1WZfTohQ4s26XTAqECk8+XHrdUJt94bsdI9E34/SnWcuGv9NifKZw9cO
BI3/vkTixqXHRSp/oqliRW1UQnUbfzFAeDtFoue5RFFYdcp10PnsULSdJFY9
UJdFDudB4vXhD8Xe5Q7m19SteTdHokD/PQ5OB+vntWRLznM7UFNFCscF52c4
aFPu3m7BeQonebYKtrtTeH38aF6oLIWTfH2m/qcUfqoDcuQ/7IktzmyulJhV
du/ylxIHmnZ5l4RLf7+I54lL5Lb0DlyJEXbMVoHTku2PiOOyAujXdTuI+Sqc
nMNP3E/htbrwLsKxvNC6+GfJfoswMvhze8Jv+h0nbNL2JwK6THgvYbXew13B
/mLCqN53qYmftPFy4ZspOmHmSdhsH5PQ69qi8JLM5gtVBwPMU2Eth4q5Fu8r
jXBWP/xug6uJeTZYsN5P3/raSJhUsuizLdZTg5n/vMX1q4zeOiyu/8fmOTot
3kO/ze9aY7FuwjaiOj4SYD202cx3RoD1M2Til5p9e40e1ftfre76/ruOmI8j
WJ9HzL5sgf/1/xc+N1Nd
                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIlIGYC4vfLj3mbt7Q4fNOI6T9Umu3QLnbz3Pe2Fofb
P+uy9jRkO4DlO1sc9O+qsDXORPDvgOTXIPiPl84+onAg20E2KsX6fm+LQ8bE
tzX2L7Mdtpwo2zd/covDcaAqR44ch8u+SQIRM1scVNkapzqr5zgwgMC8Focq
kXXuD90Q/K0gfX4IvrohxxqZvByHT5eABkxscVjkuu3z35wch+l5Qs0HgO4t
tOW6vtgnx+EhyKCaFocwPt1Nc7VzHI4obCjKKGlxqAaZr4XG90Lw43Z58jAF
5zgcBfErWxyKQB5IznEAimq317c4TDj0VSMmP8ehwzHh6YW+FofW14E75Hpz
HLL2lEyWmNDicEkJGGKrchyAofhVo7nFwaU75/nvgzkOOpvmvl9eBA2fB1D1
SdDwWQm1P6HFYQbIH35Q98e3OABlTeOEoPYD5cHhwAE1Pwfq3zfZEPeUQd17
ORtiTgU0vI5B47MMyl+U7TDNGeiwYqh7UrIdfIDRklAFtc8PGp9I6QEAyt/y
gg==
                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxdU2tIVEEYXa3UXhIWEVpmoiWYmFFJmewxkQiLrSSLEgnRsO7cW27Qg0QQ
Z5AIswepJCG9kCIkpIdEmJiERqTmUkiamIqYbivKmv4ImrkzONCF4XJm5jvf
d873zYa8s4cLFjgcjgC+wFcgX+uO56cMBDC8bL/QXNdg4PLYxqSQpQy7XvCN
TgP7lgXGl4cxsPFDTZF+jWficipbA8g89hY7t+eGEnRFf58rCWc4GprQeC+R
wFf/ITM5huF84U1vcSbB1bSTI11OhiurGvYO3iWw82cw5L7hTOME7/2ceCfD
km8Pz6WeMrFeJN7GJG+Vid0DrorqWIbMZM7Ua0q+hSqfy0KriB+nqLHCylqe
WvKeh2K/+Pst9BzIW3GsW2P7vF3j8tW9n/90UCT2xwSVFlmY+sIDeij4btZQ
gYVX0389l4Yo3tWFJ/YftGScl2JTUsiztTssDD2ubYsKVn7x+mzM6+2bKznz
lphYzsv0bWXIFvUGm2iLeu4ujGeIDSq9k95JwF31x3G/mgV/jfI3XPn9hEg+
B8MeLjs6wsSk8HeKolrozTalT8MUgian3JR9HdQ4Rfj3g8p8HKcKo/soVpa1
fLxfpLFb9CtLYzt/gonXQj/ns31bbMp6fRTXRQGfiDxfxCDCnacJNnO59dyP
LcLPBCL1z1Cpb9ZAVfo1Mjqp/B0xECmM+0Vl/78auCgujmls841qbOv+SeUc
TRs4wX8urs8hvjUEwmafR+F8NX+1VPbniCn5b2ssaFyVGtv9rVD60zS+IfyM
0PhBBp+MCaWXx9v97lPzXaPiO4j05ZGqv1G9jxYq99PIvN82X5Mh8bC6f8uQ
8zJB0S367DbkPPzW2Nbn09h+P7NU+l9h4P/3/g+ufdx1
                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4mnO3TnPLVsdeqfnCTUb5DlU7JsvpW/W6nDc
27zTMSHPwYuHSbv9ZYuDbFSK9f3Z+Q66m+a+X/4QwQfL30XwQZT/nRaIeR35
DhkT39bYA+XVDTnWyITlO1zxTRKIuNfiADZeMt+h8qWaIceDFodqkXXuD/ny
HbZ9/nul4hXUPOZ8h0+XgBo+tjjsBzrr7p88iHmsrQ4Gd1XYGvfmOVwGmSfe
6uCY8PSCUnmegx3X9cUFmq0OhbZABtA/D6uABgP9p8bWONX5d67Doa8aMf1W
rQ6rPgINZsiD2GPd6iDUfODUQtY8iLw1VL10ngN6+AAAnyeB0w==
                    
                    "]]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.8117650000000001, 0.06666670000000002, 0.14902], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGI1IGYC4k+XfJMEjNsdLird/lnHlOnQ6Zjw9IJzu4Nw
84FTCzkzHZbNPqKwIaTd4ZtGTP+hixkO7WI3z333a3fgvr64wLYrw+HwV6CE
b7uDjzlQZ22GwzTn7pzn7u0Oqz4CDU7JcLgAMteu3aFaZJ37Q68MBz7dTXPf
m7Q77J8vpX/XIMPBk4dJu1293aH1deAOOdEMh8qXaoYc4u0Ox72BBv5Jh/C/
tUHsO5XuYHPfv3f6iTYHyy0nyvYtTnfQARq3fHKbA0h5wsp0B6Arv2rMRvDt
uIAaU9scQMrnL4Pq92hzuARy1y6o+cptDo+XAj36Jt3hYRXQocxtDkIg/wPd
IxuVYn3/eatDxsS3NfamUP8/bXXQv6vC1rgUwd8H8s+ODAdgaBVlANWDzTuS
4bCkwJbr+stWSPiczYCY/6YV4p5rGQ7g8P/QCgnfu1D1X1odXIDB+PthBkTf
v1aI/19lOBwFmc/Z5nAM5MErUPuF2hzCQAF7HGq/epvDnZ91WXvWZEDCJ6jN
IRQkn5wBDx+wfYlQ8w+2OQBNCX4cC43Pu20OoGCzbcpwkANFzK82SPyszHDY
CnK3bDvEvuvQ+FVqd1jkuu3z3x9Q/yClJwDhcCPP
                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, CompressedData["
1:eJxdVg9MVlUU/zQKpSA0Y6wQBUwoKHJNnRZxnMs/aX/dypp/mGUjHsL37nsp
uaSR416ck09yiVszVhqIMiMjZWbYAoFyKRnZyAiRlJBEhIwpMbv3/Q7i+ra3
t/Pdc8/9nd/5nXNfzKrsF1ff5vP5Runnff2M1k9vWf2imf8oejLkl13+VpeK
s8Zv/Ebbr77+eNtz2l4W+PZqwoCibZFBL4VpW/+7pVjbm+aknW/6zaWfnlkV
vvSaollVjWtrzri0rqbkvuRBhXeLS293TZ02ZkhRw6KZm+acGrHDHj6w8/KP
LplX2RDvP+lS+/oJ++ffUFRv/OsYj7aro/O7X6hy6bLB6yugS++kTl+x2yWf
9ysg7fX9xwEXuLV/epH2WOfS9rmbMzt1/KbYM9dy57m0WIdNu67oIRXRciKY
8V5VtKZzsPxKnUPhSzWSi4w/1QHOFsazR1DHpx/WTW5U1HdKJ/6sIGNWHlT0
pYZfct3GOVs5n89s8GMx/kyblhs+5zF/CTbixyjk0eOniSaBCXz+535KMXUZ
z/tL/eBnnCJtVUcX+8FnuIJfnh/4wxTNN46Wn3b79Uoo432e/UM5/2Q/mbTS
7mT8v2eDnxDmb1Y2cGlbmD9UFh2bXCnSxyr65KmD/UOZa8BHCPM7I/NmPK/e
ZCHuWI6XYiHvYEXx08ZURM22UJ/bFRm6SmZY4ONfifWpFvD0STqq6WgNt+B3
QdJWTeOywQzo86SkLUYoTRnQywGJd2kG9PCBpB6jl73sf4s9zvD1ikQeFeyf
Kukeo6crGdBbIsfX53s83mJ76/ES+UdY4CtO0orDC+8afb8FfURLajkxsKRj
ooU6TZI02yRyw4L+pzDeMJtqdVoBbXt5bh+xTdnbte3xFcd4j/D6dEnJrVPu
yOu2SVelOWexhI7uFVRn6vWapJ9zdOFJkEaVqHIlJZr6rxbgt1BSjHYr2sDr
hbxf2wWmXoV8Xq5AvjsYTyHH3yfB2yFBT5v9XzOeNkGmTIF6ScatqF/AT9fL
69dgB/1wWoK3SAfvVklmzGQlODTJCL1dQq+POeD/D4n+SOF1bUeZwLpfvfz/
5PotdOgJE+gSn7/EIdNG1VpPjxp8yx2eXxL9nc77fQr4bQd10HotNXVc7wD/
3azv9xzKOOJui4zg+ZnvgLco1nMBx4vleaAc9F+8Ap/D+xN5vm5woIcktt/i
/Unc/2846KMkxveyg/o/qJDfXM7nAQXdPeJAL1E834Ic1FfPB4/f0wLnB/H8
OSxoh9HhEOtPzztvfgxwvTbz/Otjfbwp0O9/sb4WcLxO7q9YrneHRF+PYn21
SfRBuw0+Wvm8Rtaztj0c1TZ417Y3N6rsm/rwzqu04XdWoh57bcQ5x3os4345
PzwPbPDSyXreY9Mhw28X67Xchp4vSuS1z8a86JaYdxU2nTPC72H/L3i+93J+
X9mYJ/2sz+Mjtud/nOd9P+tZ2x4OrT/vPrtgY76Gcj2CBM6P5/syRuBNikLN
O1Ug35V8X68UwJOjgD9fAG8u6ykggOdd9t8pwHeeAp/7uV4b+X45KlCffF5v
FtBnwfB9JcBvQKHfYhzaZfTykUJd0lmvxzherYP50aCgpwbur3pFC8x99YND
3vdIDfdLnAt83ynMkbUu+l/fx978LHehi7OcT60LvXYp1LuZv096uX9/dXE/
9nE/6O8Xb378zefr75v/fw/9B6bsL9Y=
                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}}}, CompressedData["
1:eJxdU21IVFEQ3SwUKhaxEOnDTCSiDyTIzKw8UiGxlNQPsbAQMTQh3b3vaktt
QSy9SSJD9oeVlJSGFCKLX6mYLCnrIiRWRkiESERU6GIpFhZ0b3N/9eDymHfP
zJxzZt7mkqqT55Y7HI5l6mSoE6NOQ2WCP9RDmPXlZJwdldjZcT/a2kcYcWXW
5qo42hp2ZQ4Qvr8+VhIfkeiK1Aw2DRJ6k69/OzEs8UZ9LhwiBJJWFDifS8aN
EGZ0vXaJ+MKsrkiYcOHz0pO5exLewaZ16f3EdUolHjcOpwQ7CHnTl9a2r5d4
9uPPhFf1V1He9JgFTaM4QPiogdKCUxP0E7p1/jYLKluU+0z9eYH9U/m3GryE
Nf7Q6MNJgRu5xZ/GawgaVj8kUHT7xcLWakKCvu8UOLo6ZjtZxHWbTb6HkP4h
LfZao8Dp0uypfDcxj7sCDv2cIhxc+a7ZXW3ibIJOqywQqNX9Uoi/7xU4oHGr
CMqt3uRNAlpm3k+b68cJ3NH+z9js21cPJrSfszY26MZRDyhxcmxRxRt1vOBh
v6I23nq/bNn128P95myENUGn0TNvo0/PJ1WwP4sGv0dgh57vks36XYJ1xxHO
9KvMMoGKARlISiSU16sJXhH8TjN+BEy93YTLej4tAhf1PHOM3qeCeR4y82oz
94eNX93GryPEuJeC9R03+FiL9RQR+7LPYr0VxD5WWYz3mf18ZPbjpuHTZfah
jrhOr4Xzmn+d2d+Q2R+F/zfXMonx1Pe/rj4w/YKS79sIWXpBhyT7GSTGqf1v
cSsmnYRXOlb/x///z1+Qv4VC
                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxdUmtIlEEU3VbIUFlSJMooH6gsVqyCtWVEJwzFR8UGgYSpSIFEm8vMlGVP
seUiq8gaqCChuOWyFSGhsESIiIq/QouIiCiLkIhQg9Doj3eY+eUHF74zc++5
55472Y3NZy8lOByOLRxuDidHZvCXL95GaAr/vn38mUJvaejKUjuh7lVFipNx
ZYpzHwUJWaOiKRxTOJb0IRIgwq30F+WLj5Wp6yDM53z6d3dIoWViMMMTsrjf
5ncS+q6mtU92KnScaPgx/4BwZGzu+kS9wrQmvk/wfM7d2papMKMx6/n+ZGA6
a1YitYYzmwnc5WDdc4nLr9XDnfWEBc3fKlGo63yEVq2nTOLdqcbtNScJ/qX/
sdV0afhLCOPcbvCbgOvAy0fLXss3KRAJsMICwvsbP/OL4vZ+N0G3Hx0RWInO
VnldZOYKCxz9cqarL8nqDQnc5LJtiYRs7U9QYD+XRxMIVV6e9J5AhfYv0frV
I4wfyRYPC1TrPJfFTy3eZfGcwJ+3PJCbEN/Li1oXqO2e+usuIpy/yErypPG/
mMCntd3F0vh8iEyfUuvXYUKJ9tsnQTs+vlkrI7OHgDR85+x8MQk9fpT97Nc8
X6XRf5rg0J9bmb4XyPjkt9hP2KN/wgqLehHXCAW6UcTe37H75ve0+b1tADk1
HF8=
                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJZIGYC4qMKG4oyXNsdGEBgVonDp0u+SQLu7Q7a7WI3
z80sceDT3TT3vUe7w9sae9O4GSUOD6tE1rl7tztUA6mHU0ocrgCVR/hB5SeU
OFS+VDPkCGp34AXpay9xkI1Ksb4f2u5Qvm++lH51icPjpbOPKHi1O+Q+/73y
YwBUvxPUPAmofS7tDjvkWl8H3iuG8z1AFt8thrsPZMyGPcUOtlzXFxc4tDsA
Ve+Qmw5Vb94OEa8udogGWu9v1u4wWYIljK+9GOI+43aHjIlAF08sdgApX67b
7iADcidMv3q7Qw7IffOKHQzuqrA1KrY7LHLd9vnvgmKHrD0lkyWkoe5bADVP
rt3hagWQ8aPYIab/0FcNoH59kD7PEocOx4SnF4zaIe4uK3GY5tyd89yi3cHb
vNMxobfE4Qgo/O2h/geG7/Q8oeYDzoj4AIe3C9R8IH9JAdBnQD44HIF89PgD
AJqJyQQ=
                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    733.2810000000001, 283.699}, {733.3629999999999, 
                    283.58599999999996`}, {733.2890000000001, 283.574}, {
                    733.2810000000001, 283.641}, {733.2810000000001, 
                    283.656}, {733.2810000000001, 283.68}, {733.2810000000001,
                     283.699}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}}}, {{{707.8159999999999, 215.309}, {708.172, 
                    215.23399999999998`}, {708.512, 215.141}, {
                    708.8159999999999, 215.023}, {710.133, 214.52}, {
                    712.0780000000001, 213.465}, {715.109, 212.684}, {707.777,
                     212.758}, {707.777, 212.758}, {707.8119999999999, 
                    215.11299999999997`}, {707.8159999999999, 215.309}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGI1IGZigALudoe4XZ48TNzZDrZc1xcXiLc7qBtyrJER
ynbg0900971yuwM3UNj2VpbD0tlHFDbItzvMyBNqPjApy0EHKL1crt3h5rnv
wY9bsxy2ff57pUKq3WH/fCn9uzlZDvp3Vdgahdsd+g991YgJznLwNu90TOBp
h9CWWRD7mNodvmnE9B+SzXL4sPyYt/m3NofbP+uy9rBkQey52+ZQLbLO/eGl
TIdPl3yTBPa0ORwHGbAm0wFoytMLU9og9m/MdPABmTsLwQf6Sru9qM0BpExp
faZDDMghsW0Q/x7OdIhKsb7v79jmUAByyJdMiH2abRD/y2U52IHcJ9oGcZ9t
lkPlSzVDDpE2h70lkyVY1iH4YP8czHJ4DAogoPpCkHlnshymOnfnPBeDuudq
loN86+vAHRJQ99zPgrhPus0BZI3tsyyI/+TbHC4pAUPgFdQ8tTaIuz5lOUSD
3KvX5nAHFD53shyOKmwoyjBtg6i7kOVwGBjM/S5tDhkT39bYb81y2HqibN/8
FKg8MD5g4QOOz6wsBzmQe7a1OQBVm8alZTkATe+dfhpqX1eWw3tQfDxscxBu
PnBq4cYsh6w9QI//hpr3AKr/XxsknhmzHdDTEwBJJQ8N
                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGI1IGYC4qw9JZMlFNsdjnubdzryZDnobJr7frl+u4Mq
W+NUZ+Esh+gU6/v+du0OEw591Yi5nelw2TdJIMKy3YEBBKZkOjxeOvuIgkW7
Q+wuTx6m9kyH98uPeZsbtzvsBRrLkpfp8OkSUIN2u0Pv9Dyh5pBMBxB1QKnd
4ZLS7Z91VpkOYPvF2x2qRda5P5TLdJgBkudod7h57nvwY1ao/jdtEPuuZDhs
PVG2b/6RNgcfoHMT1mY4AF3XO31am4NTwtMLSpszHGL6gQ6di+Bv+/z3SkVe
G8R/GzIcjipsKMoIbYO4+0gGxD6TNodvGiCdUP2SbRD/ymdC7GFsg7jPLtNB
rvV14I7/rQ6OIPPXI/gXQf45lOnQLgZ0OUMbxP1nof5jboOovw4NH1aoex5k
QtzH0eZQlDHxbc3zTIj/eNocwvh0N819nekwzbk757kI1P9fMh0ugOyRg5p/
N9OhA2SwWpsDSLv9xUyHw0Bn91u0QdRty3SIBfknDiqfC42vuVD/ZWc6XAHF
5z6o/elQ8661OchGASO+OxMSHh/aIOG0CepevnaIeQ+h/hdqh8gzZTmgpycA
OWwazA==
                    "]], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGI1IGYCYtmoFOv7MysdLird/lnHlOnwtsbeNK6i0kG4
+cCphZyZDltOlO2bH1bp8E0jpv/QxQyHT5d8kwSSKh24ry8usO3KcKgWWef+
MKXSwce80zGhNsPhasVLNcOCSodVH4EKUzIc4nZ58jA1V0LUeWU4PF46+4jC
tEqH/fOl9O8aZDjkPv+98uOGSofW14E75EQzHPh0N819f7HS4bg30MA/6RC+
cBXEvlPpDh2OCU8v5FU5WIIctjjdYRnQuA03qhxAyhNWpjt4PKwSWXcSwQeb
a1oN8ccymP5qh0sg/+6Cmr+zGuKuN+kOtlxAi35WOwiB/A90zzGQQQY1DhkT
QSED9b9JjYP+XRW2xqUI/j6Qf3ZkOJSDGIY1EPOOZDjskAO6QKcGEj5nMyDm
q9dA3HMtw0EGFP7yNZDwvQtVL1bj4NKd8/z3wwyIvcw1EP+/gpr/thriritQ
+29VO4SBPHIcKr+x2uHOz7qsPWsyIOETVe0QCpJPzoCHD9i+RKj5tVUON899
D34cC41PlyoHkDNtmzIcDn8FKuSqgoTjygyH6XnAkDlSCbHvOjR+d1c6LHLd
9vnvjwwH9PQEADfzHaQ=
                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, CompressedData["
1:eJxNVg1MllUU/kDS/iTSZAz8Q52iZkg/OCjguPJvaVZstbU0c1nEh/C9P8q9
9003MkauGWotWs2x/sDPmEGhETotYOpyKZraiAiRqDmUMnPOrNG99zkJ3/bt
7tz3nnOe85zn3PdNXV3y5JoRoVAoRv+363+s/k+udwu2jRWUe+sPH0W6fDox
pfPaxjGCnnnhwe7l2l7co+7afaegt5LinorX9ub5q/raEwTWn3ycGy0oq/HI
+gOdPo3d9PW3H9wiqPRAdXJ6h0/xcz7f8ftNgg4/Om/z/JNDtl1P+PTJ+22T
6+PY/7hPOQZHjKBD5nybT+0GT0hQ08Ty/icafbJ4B0vp4it5D6z82KeQ/Qka
Y/JW+mTcVmn/gm36RKlPp8X56Rk6vo2z0Mf+bYJmVSR2HBvFeMcJWvvb9eil
No/OLt9SVTyL8ed51GsALmU8O13gLBH058llqxMec2mPNqu3C6x/O7Siecnt
sd1cz2cO+Jkpgb/IoUWGT0+CvzQH8fdL1DEQQZ4zEvkbIqS9miZ2sn9NhPsk
sV8VodGGx24J3soiwH9OIk84Ar9fJPA+HgHvfRL1p0fAx3kJ/D+XwO6XWLNK
gOuCJNdsVBQD10VJHy7Ye/nforWoU5+3/GYW3Yhn+01hqirWnbnA8XLC6Nsf
kmZk3Fw3PjuM/vwlyYSpzgyDj5EKz6eH4Zei6KBO25UQpndNvHsVbW25kvbs
9ULo83lFW0yi9kLo9z2FvDWF0MNpRQMm7y4+P8zuNnwtDZC3js+XBdDFpULo
LRogvs4/wTR0mG2fNwSoPzEMvpoDWml0kBIGry0BdRy7mt87IYy+fRNQtil4
MAz97w2AN94hjW5Rj7YtH+8M2XbVtuWrifHudygw+28HlN41bWRZv4M5fSkA
znEu+pUVwI9c6Dw2oNmm/2tc8NurKNXUsYGfn1Pw17blSds230YX9R5XwPMm
x48q6PxL9n9NAU+3C3yugt9lF/zqftl5HeVBp/kKvCV5WBcq9CXNI9PmyocU
9HqfR+NNonkKeXP4eabCvp5XW3+6Qv+WeJizaZw/36NWcz5Z0VyDb4XH95fC
3BWw/6AEfseD3rRea0yflAf8PazvVz3g+l5iLss9xDnEen6d4+2TmJMKD/PX
IMGn9rd9iEqc2+BBDzVsr2P/Wp7/Fz3gqmV8T3vgt06ivoe5nj0Sce7x0HeN
x/YlzuP+SvB7xgX+q3z/NLvQcZwCfn3f2bwJ3K83+P5LYX28zPqZoZBnsYt6
Mni+pnC/sxTqjmF9kMJ91eNgfwHnO8J6fkSB9yYH+9q2fWx0bujD5qt3gDdX
oR+7HPhlsx5reV7u//8+4HhzWc87eV7msF6jDnQ1WwH3pw7ui5kK912dA9xT
+fwXfL9P4vr2OeA1ifV5dMi254/yfZ/Eeta2vQe0/uy9+Cvn7+N+xLnIr/Vi
46e6PIcS936ei3pJAsdzLtY7JPCXu8A7gvVU6QJPiM/v4Pn8R4Cn3dyvawL3
1EEXea/w81MudDUg+H3lYv+swLylevSV0UuLAC49T3bO1nG8Vg86dfh9fZjn
yxWo8zt+vonfn1N94CsSmPP1PnS3TIC3qA/ecvl7pdWHXu8W6Pcp/j6ZJDC/
P/p4Pybz+15/v9i4iZy/i78vhn0P/QeJPxcd
                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}}}, CompressedData["
1:eJxdk01IVFEUxyeLMSKmshKpSadJWgghLeyT6u8mCymphYsgkcHQRWlz3k3P
fX2ARZiVC3OhKSVlCUXIUEpT0CCMqAiJFRFDhMkQNUVZUVDUonc9d9XA5bx7
556P/++cuzbScPDIfJ/PN89bJd7K8taz8OvfZ64wvpzaVVI1oXC7ZyQUu8wY
K9/cWurtQzGqa29hfH++L7J0XKGrPufc8FlGPP/8pwMjCodqtk9XaEZH3oLK
wBOFNeYgyvhs4g0ovK1o66wnxrH3f+5861bwvCduXGIMjjcmemsUhoztZpTN
uCsGViuJ08bwdmUzkw7q2r1IKUbaFKYcsb9Y/IocNCV6VxVna4n/g3ChtPrd
VEBjucmTItGVo0VHkrDH5FmppY4HJH55GoEN96/N9hFajX9Qo/hNob+5h2Aw
VBdosVcJPvPbr7Fz0au+4yfs/qLGtNFZSaI7oeV8C8GjFM/PaLEFhB3Gb4kr
8bMJU4Z/oSt8P0aF5zoXQfMxG5XzsCtcf0aFW8jFS86s3/g3KvmCLkZNgQHC
UaMn18Uj058wCZ9l9v4mQr/p70JX9JeT8Pyqcfjx3sVZtYSiltzU5Ast3E+T
1PnQ8uiw8To1Tpr+3CLh3Gz13iWpg7XEvUeSp8nyGrK8GrXoeUqiL2Lv+x3R
s1vLnG1zbJ+1cGtw5L5fy3zetPORYaln0M5DmqWPcUfqTtv5Hbbz84GFc61C
ldGdZMkXU/J/P2OrAZ1UwvM6S5+8+Z+b+y7G3Lvx3sf/7+cf+nSByQ==
                    
                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGINIGYC4kNfNWL6/1Q4ZEx8W2O/usThasVLNcMfFQ5x
uzx5mID83Oe/V378UuGgsKEoY+LKEofW14E75D5WOFSLrHN/uKTEweCuClvj
2wqHC0q3f9YtKHEQbj5wauFLKH8GVP3zCofpeULNB3pKHIC2mMZ9q3Cw3HKi
bF98iUP5vvlS+v8rHPRB5shD+X8rHB4vnX1E4Vixw33/3ul5CpUQfWuKHbTb
xW6ec6x0uAgyv6rYYZHrts9/YyodqkDucSt2iEqxvu9fXglxt0gxxLzuSoet
QOvmPyqCmDsBat6BIoedckAXrqqE+HsHVP5EpQOI2rCsCOLvx5UQcyYWOXQ6
Jjy98KoS4t7uIgc+3U1z33+sdFAEqWstclgG0vej0sHbHKiyvgjijg+VkPCa
VAQJj5dQ/qIiSLg/hvJXQflnofwTRQ4yIA+tr3TYAXLnjyIHj4dAn86thPhT
tRjijumVDuB4NCmGhMukSgdbruuLC5yLHbRA4dVf6WAFCu/AYodPl3yTBIoq
If4oKIaYFwr138piiL+B4TkDFF8PiiHuT6p0YAABjRKIv1wrIf7OhfJVKx1k
QQ6aWOJgB7JXtBJi72KoPGslJL6B6Qk9vQEAyQEzcw==
                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJZIGYC4vJ986X0SysdGEBgVomDbFSK9f3CSgftdrGb
52aWODxeOvuIQl6lw9sae9O4GSUOtlzXFxdkVjpUi6xzfzilxAGk3D8ZKj+h
xIFPd9Pc99GVDrwgur3E4Zi3eadjSKUD2J7qEgfLLSfK9mVXOuQ+/73yYwBU
fzXUPAmofWWVDjvkWl8H3iuG8z0eVomsu1sMdx9IeMOeYgegqh1y9ZUQejpU
/YRKiDurix1A1idMrnSYLMESxtdeDHHfzEqHjIlAF08shpizpNJBBmQuTP+G
SocckPvmFTssct32+e+eSgi9oBgSLieh7lsANe9wpcPVipdqhj+KIe7cWOmg
f1eFrdGzxOEdKFxmVTp8uuSbJFBWAlHXVwlxV28JJFwaof4Hhu8Fpds/6yoQ
8QH2RznUfCAfbC8wPMDunAXVjxR/AKgq1GU=
                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{418.719, 
                    283.699}, {418.637, 283.58599999999996`}, {
                    418.71099999999996`, 283.574}, {418.719, 283.641}, {
                    418.719, 283.656}, {418.719, 283.68}, {418.719, 
                    283.699}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}}}, {{{444.184, 215.309}, {443.828, 
                    215.23399999999998`}, {443.48799999999994`, 215.141}, {
                    443.184, 215.023}, {441.867, 214.52}, {
                    439.92199999999997`, 213.465}, {436.89099999999996`, 
                    212.684}, {444.22299999999996`, 212.758}, {
                    444.22299999999996`, 212.758}, {444.188, 
                    215.11299999999997`}, {444.184, 215.309}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGI1IGZigIJXlQ5xuzx5mLizHVpfB+6Qu1jpoG7IsUZG
KNvh8dLZRxR2VDpwX19cYHsry2HLibJ98w9UOszIE2o+MCnLYRlQesOhSoeb
574HP27NcpgswRLGd7rSYf98Kf27OVkOi1y3ff57o9Kh/9BXjZjgLIeMiW9r
7J9XOnibdzomWGZB7Ptd6fBNI6b/kGyWg8KGooyJwlUOt3/WZe1hyXK4oARk
uVQ5VIusc394KdNBJirF+n57lcNxkAFrMh2AppnGXauC2L8xE2L+aQQ/9/nv
lR+lqh0cE55eUFqf6eDxsEpknWs1xL+HMyHuqK12KLDlur74SybEvjXVEP/L
Qd13tRriPtssB17dTXPfX6922FsC9Ok6BB9szsEsBytQAAHVF4LMO5PlcLXi
pZrhpWqIe65mOYCCof8c1D33syDuO1HtwAUK32dZDrIg/x2sdrgEcserLAdL
kHmbqyHh/SkLYs/iaoc7oPC5k+VQvg8Y0FOrIfF0IcuhChROZdWQcNia5TAd
pM8MKp+TBQ8fcHxmZTkcBrlnUhUkHNOyHDpBDsuogtjXleWgCIoP2yoH4eYD
pxZuzHLQbhe7eY6zCmLeA6h+pioH/bsqbI2M2Q7o6QkAI9Mfpg==
                    "]], 
                    
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGI1IGYCYu12sZvn9lY6HPc273TkyXJYNvuIwoYFlQ6q
bI1TnYWzHEDCCc2VDhMOfdWIuZ3pEJVifd+/t9KBAQSmZDpYbjlRtq+/0iF2
lycPU3umg8KGooyJMysd9pZMlmDJy3SQBWlYWenQOz1PqDkk0+Gi0u2fdbsq
HS6BaKtMB7D9FysdqkXWuT+Uy3S4ABJ/V+lw89z34MesmQ4yIP3qVRD7rmQ4
gIw5UFbl4ANy19oMByD59MKlKgcnIKW0OcPB42GVyLqjCD7QFWF8ytUQ/23I
cCjfN19KP7Ta4fFSoEePZEDsm1bt8E0jpv/QV6j+s9UQ/8pnOmRMfFtj/7ca
4j67TAeQcD9DjQPIWqX1CD7YX4cyHT5d8k0S+FcNcf9ZqP9+VkPUX890UASF
z1eoex5kQtz3vtqhCGTR80yI/55VO4Tx6W6a+zrT4WrFSzXDa9UQ/3/JdIgD
hfNhqPl3Mx3e1dibxm2qhrjzYqZDFcidfdUQf23LdHAH+ccZKp+b6WAFii9g
+ID9lw2Nz+YqiP3pUPOCqiDx1g3VL1/lMAPkrk1Q9z6uhJj3MNPhMMj/tyoh
8kxZDujpCQCbLRZr
                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxdU1tIVFEUHZUsQiRL+gi1mYFISosgkwp1pUWY2WsQLNSmsce9Z8LUj2lI
Ec6ZRKOPyZ6GiFSEESIS0YswsWka+ojRJAkTG0z6CLGQXkTQ2e1bQhcOh3Xu
PnuvtfY+Ds+JfUcSbDZbnF7r9YrXK3YqtXf7ewnaYkcNhOx99cZFidq8haM3
Wg20bnFPRXdJFOrN6TJRERz8kpktkX7g8OaJBsG7Q2JForxUNCHg7+9attYp
cX3bvdlf3y28RmK6sSCn6rVA1Dn2o6lQYtPdiK+/Q0BHjfgPSkze7AjZDYHk
7DudM945/Kk7XJLrm8MZzR/3PmiSqHpUnBTvEszvvEQa8Zgv0F6zODDwUGLl
ugU9aT4TO3PP6AiJ25+HSz17TNY3LPFE0xqPmpz3mUQD6V8lQNHRiMRG4ndM
gNLu1ve1G7V5iV7QcdesxJuX31yTZV6cJH1xCvVG23TjFS/rSVCct92LlHKd
aZ4ChY1r/KrUs6g8RbFf1db9dAWSleHwgq71bVCs74KAdrsimK9goy9TsP85
Cs9LtLC3JvuVpfBVhw1eNbEjKX51S7Ziv2vMf/n+4uVUCHOY0rirLRw2uY5f
IUw/UgVmyP+AwhD1Ld/qV1BhSWDgxbX9AvcJdypUEl/t1+Wis8c/3FLsT53A
n/l6rLhOm0Ax8Yso9r9HsD8jlp6IQJaW0z2hcI6Ejwnm+06B2uIctfCU4nl8
as1TSIHsL4iZaFmqK/cqnr/TJvvbrLBV0/o5ZLC+SgtLg3nZrXjD4HlNtvQd
Mthv3e86eg9uA/+/l983MH9T
                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxdVAtIVEEUtU1MzNI+RNiWupWZGmIQ9mH1mkR+sk0lUFtFrKB9T3eHkhQV
YyZMLULKxCJD+mFa2RZmImYhYRIk9jUVMRURCbO0EoOimXcHH7TweJydmTvn
nHvu889yJB1d6OLisoA/Fv4Y+FMelTnWE8vga1HktozfNugxDcwVxzBwET93
BZpn/rzP53hTmPs9o48Cy1J2NHXx/Y+7TrbXmhQoE+f3M9jNX6ZoBZZseXRt
KoLBsQuTRZGDCgwXrGzcG8ygkL+G41Ss68fgV6C1oqNchWr78tPPVzDw6L1J
zN0qTL9NyPL2ZnBZ/D+iwjsOUzwZVHT8DLTOyvOLGLyMDy+Pcs+G0dtXX/i5
6lg7/5fO4xBOp+4jRf5bVVDacitXd1IQtE1PFND0P6PQ8J0fLFNwfytF/rE6
1vgH6fiu2O+pgJBb10LhuDgwY4NvdZ3x4c061vQ16DivvdYn9BKFjW60KjpZ
AUHfWUqhf65YaWtRkH8hhRNiv68K6UJ4AUV/OP99XFYmx5p/r1VoEn3g+I3o
28VsWJt2ZNcQpZDRGutp8MpBH2so3NjDO2m0o3+NFBaLeq/sqP+BrDch150U
+rpnk0dtDpgSejjWeBkILBWC71D4bDlfbQ8i6EclhQ/5EwFhSQRKV/GTZyjy
sBG4RcwevWUUJkW+cgnm54qO4zwNwaX1OrYJ3zso+nRI1u+mMCTuiyCYx34K
JV8SW9atJ8hrhCLvEAK+YmGMQujgBjeaSrDf4xTzqsj1SQoxIpglst4Piavk
fTw/wULIfVnfwEDIsTwkIGKV6c7Qh3oyn1+tjzUE3yaGflh1rOnbrmMtX14E
rKK/mxkYxQVe0l8zw77sJHjvATkPmdI/KwM/J0+UQ+ohDP3Ik3yYnN9iAmYR
HCbX+X6troNhPuIJ5Auf0+S6v9RnYfjuc+B8WSTfVAdURZ/LHufzruVj0I7+
Jst5vm6XfWeY5085WOcUgwCR9zU5yO8sg4NC6OHsefyUl3HtVOexNl9GFeeJ
8x8Q9ZwK5iJH8kmU35cU+X2alvOVwCBd6Ou1wf/ft3+czzj7
                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxdlGtIVEEUxzeNCBF7ECJlZhEhLCFCtqxWeyJKzEp6ED1URHusljZ7R0vF
ghkrDSvZRA2k1B6KH4oILbGyJyWLREoPREIjRKS0LPpgD2jmnmMDLQzL796Z
8/if/9zFWUe27Q92OBzT1EpWK0itb32bs2Y7JZxZmzn86iSDVYOp5+qiJSzc
sy9x8AaD6/XPom+FSHjyIyataoiBIssbbPgaWx3y7rf4x2HLb1/6MiBgbtmj
QFOd4Svr73z/U2E4xaUyljHYpP/7BQyptPklDL62PE9xvRVwrKthfmwhg4v5
KlKvAGd5eP/LPAb6eEuPgGZdF2Ogsl9lDwU49E9S/FYBH3Xhlxl4/WOlnkYB
vUsGJk/0MUgODXKWK7b7jfHBnF3utu5G2l/ggwr9vFmAbtPf4oO27qNdDfcE
xL5fOkPMsqBO1xMQkNGpIu21MG8P1XvQgkStX4C4ycL43QL1HLOw3y4BeSO/
WiciOdbXJFDnNA7Fo8viZtZO9c/x3Fmqp9JwR9SpT1vPG1bUEeXn8FTPoUag
LtUc0qrUZBoN2/NtN2znf0EsKH8/5dtN7weJUzjqOyzgTZHaCMQjhmvXVR4e
GTVs6/yZ+t/Osf9x4kMcNup5TAiMU89xDj8FVEdM3xn2gINyzesi5bcp/lAy
72ZSqGHbL+HEfsN2vBzD46We+IwEDlG2UBL956L+4iTqmUn6uSX6zuLohw0S
7HtymuOctkjQ5aeqedzV9aVT/hrSg0uI1BuqOO4rkpCgjaT0tX1bTOePc/QP
p3xeDmv0HHIkPt/B0a8eij9pQe79guoIl8Q4FyzsJ1WCW8dfQH7LpvedPjyf
K/H+FPrw/nolpGv/LvKh3gck+ucxw3PplL+W7lOSRJ2KGT73kH7qPtr3YSXl
z6bvR7xh21crDNv1xkpo1/fKYvD/9+cvJcQFmA==
                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxlVwtwVsUVDtZSxiJoKkgQIUErWmxAGQZFIQdioVZtpqIOtYAMJTMIqOi/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                    "]], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{581.3359999999999, 389.578}, {577.234, 
                    386.332}, {573.5509999999999, 389.105}, {
                    573.5509999999999, 366.90999999999997`}, {
                    581.3359999999999, 366.812}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJxIGYC4gtKt3/WvWl0KN83X0pfvsqhXezmue/nGx2u
VrxUM5SrclhSYMt1fWOjg7d5p2OCbJVDh2PC0wvTGh1m5Ak1HxCqcqgEKuNo
gcpzVzkwgEBxo0NUivV9//+VDoIRlltOpEDNf13p8Hjp7CMK6Y0QdXWVEPHs
Jof7/r3T8wIqIeIbmxwmS7CE8b2sdHhUJbLOfVGTA9id/yodjihsKMqY0OTQ
+jpwhxzQvmVA4zbUNMHdo7Np7vvlSU0O1UBtD2Wg7ndtgpgL9M+2z3+vVGg1
OYCMfQjke/IwabdrQdUzVDlsOVG2bz6Q3wny56NKVP6RSgdYeIHtP4rga4EC
7jGCD6ZZqhzQwxcAkzSlgA==
                    "]], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{579.914, 451.809}, {577.98, 
                    432.89799999999997`}, {597.4409999999999, 423.395}, {
                    587.59, 436.562}, {601.043, 440.91799999999995`}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{577.746, 456.734}, {574.7890000000001, 
                    456.734}, {572.605, 455.633}, {572.605, 454.32}, {572.605,
                     453.012}, {574.7890000000001, 451.89799999999997`}, {
                    577.746, 451.89799999999997`}, {580.6990000000001, 
                    451.89799999999997`}, {582.8669999999998, 453.012}, {
                    582.8669999999998, 454.32}, {582.8669999999998, 
                    455.633}, {580.6990000000001, 456.734}, {577.746, 
                    456.734}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    579.9219999999999, 452.824}, {574.871, 
                    452.78499999999997`}, {574.871, 413.277}, {580.02, 
                    413.258}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}}}, {{{555.91, 
                    412.60200000000003`}, {555.094, 402.10900000000004`}, {
                    552.434, 394.789}, {548.73, 386.715}, {557.605, 
                    394.949}, {563.7810000000001, 387.617}, {
                    570.4730000000001, 395.078}, {577.2930000000001, 
                    388.77299999999997`}, {583.8549999999999, 
                    395.33599999999996`}, {590.672, 387.35900000000004`}, {
                    596.59, 393.92199999999997`}, {606.629, 386.715}, {
                    602.984, 394.79299999999995`}, {598.055, 401.637}, {
                    598.676, 412.98799999999994`}, {588.953, 405.77}, {
                    565.8519999999999, 404.469}, {555.91, 
                    412.60200000000003`}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 0.8, 0.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{621.996, 130.48800000000003`}, {622., 
                    129.80100000000002`}, {621.3199999999999, 129.176}, {
                    620.5740000000001, 129.176}, {619.824, 129.176}, {619.145,
                     129.80100000000002`}, {619.148, 130.48800000000003`}, {
                    619.145, 131.172}, {619.824, 131.797}, {620.5740000000001,
                     131.797}, {621.3199999999999, 131.797}, {622., 
                    131.172}, {621.996, 130.48800000000003`}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{627.031, 132.164}, {627.035, 
                    131.48000000000002`}, {626.3549999999999, 
                    130.85500000000002`}, {625.609, 130.85500000000002`}, {
                    624.8589999999999, 130.85500000000002`}, {
                    624.1800000000001, 131.48000000000002`}, {
                    624.1840000000001, 132.164}, {624.1800000000001, 
                    132.85200000000003`}, {624.8589999999999, 133.477}, {
                    625.609, 133.477}, {626.3549999999999, 133.477}, {627.035,
                     132.85200000000003`}, {627.031, 
                    132.164}}}]}}}}}}}}}}}}}}, AspectRatio -> Automatic, 
                  ImageSize -> {{128}, {85}}, 
                  PlotRange -> {{0., 1152.}, {0., 576.}}], ",", 
                 GraphicsBox[{{{{{{{
                    Thickness[0.001388888888888889], {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.8627450000000002, 0.141176, 0.12156900000000001`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {0., 360.}, {720., 360.}, {720., 
                    0.}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 0.7803919999999999, 0.14902], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{0., 360.}, {
                    0., 0.}, {360., 180.}}}]}}}}}}}, {{{{{{{
                    Thickness[0.001388888888888889], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{0., 360.}, {
                    0., 0.}, {240., 180.}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{61.824, 
                    236.348}, {71.20700000000001, 174.05100000000002`}, {
                    100.87499999999999`, 178.52}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{61.824, 
                    236.348}, {106.035, 191.465}, {84.66, 170.414}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{134.883, 
                    224.207}, {78.535, 196.035}, {91.953, 
                    169.19899999999998`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{134.883, 
                    224.207}, {105.859, 168.29299999999998`}, {79.23, 
                    182.117}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{27.703, 
                    170.617}, {89.85199999999999, 160.289}, {94.77, 
                    189.883}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{27.703, 
                    170.617}, {84.051, 198.79299999999998`}, {
                    97.46900000000001, 171.95700000000002`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{145.914, 
                    150.97299999999998`}, {101.70700000000001`, 195.859}, {
                    80.332, 174.805}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{145.914, 
                    150.97299999999998`}, {83.766, 161.30100000000002`}, {
                    88.684, 190.895}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    79.67199999999998, 117.85199999999999`}, {108.699, 
                    173.766}, {82.074, 187.59}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    79.67199999999998, 117.85199999999999`}, {70.289, 
                    180.148}, {99.95700000000001, 184.617}}}]}}}}}}}}}}}}}}, 
                  AspectRatio -> Automatic, ImageSize -> {{128}, {85}}, 
                  PlotRange -> {{0., 720.}, {0., 360.}}], ",", 
                 GraphicsBox[{{{{{{{
                    Thickness[0.00125], {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.9098040000000001, 0.06666670000000002, 
                    0.17647100000000002`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {0., 480.}, {800., 480.}, {800., 
                    0.}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 0.9372550000000001, 0.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    407.26599999999996`, 325.914}, {400.543, 
                    343.51599999999996`}, {414.945, 370.715}, {400.543, 
                    383.51599999999996`}, {405.34400000000005`, 364.316}, {
                    389.34400000000005`, 343.51599999999996`}, {393.824, 
                    325.914}, {398.305, 308.316}, {413.984, 308.316}, {
                    407.26599999999996`, 325.914}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    420.695, 323.801}, {416.812, 342.234}, {435.289, 
                    366.848}, {423.07, 381.742}, {424.809, 362.027}, {405.75, 
                    343.98799999999994`}, {407.42199999999997`, 325.902}, {
                    409.094, 307.82}, {424.582, 305.367}, {420.695, 
                    323.801}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    433.633, 319.60900000000004`}, {432.684, 
                    338.42599999999993`}, {454.78099999999995`, 
                    359.84400000000005`}, {445.043, 376.469}, {443.676, 
                    356.72299999999996`}, {422.03099999999995`, 341.887}, {
                    420.85200000000003`, 323.76599999999996`}, {419.676, 
                    305.641}, {434.58599999999996`, 300.79699999999997`}, {
                    433.633, 319.60900000000004`}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    445.758, 313.449}, {447.758, 332.18}, {
                    472.93799999999993`, 349.879}, {465.91799999999995`, 
                    367.82}, {461.47999999999996`, 348.53499999999997`}, {
                    437.78099999999995`, 337.26599999999996`}, {
                    433.78099999999995`, 319.551}, {429.78099999999995`, 
                    301.83599999999996`}, {443.754, 294.715}, {445.758, 
                    313.449}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    456.76599999999996`, 305.465}, {461.672, 
                    323.65200000000004`}, {489.312, 337.195}, {485.184, 
                    356.01599999999996`}, {477.78099999999995`, 337.66}, {
                    452.613, 330.23799999999994`}, {445.89099999999996`, 
                    313.363}, {439.172, 296.49199999999996`}, {451.855, 
                    287.277}, {456.76599999999996`, 305.465}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    466.39099999999996`, 295.85900000000004`}, {474.082, 
                    313.055}, {503.5, 322.105}, {502.367, 
                    341.34000000000003`}, {492.184, 324.367}, {
                    466.16400000000004`, 320.97299999999996`}, {456.887, 
                    305.363}, {447.60900000000004`, 289.75}, {458.695, 
                    278.66}, {466.39099999999996`, 295.85900000000004`}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    474.395, 284.863}, {484.684, 300.64500000000004`}, {
                    515.1519999999999, 304.984}, {517.043, 324.156}, {504.332,
                     308.98799999999994`}, {478.09799999999996`, 309.707}, {
                    466.49199999999996`, 295.73799999999994`}, {454.887, 
                    281.77}, {464.105, 269.082}, {474.395, 284.863}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    480.578, 272.754}, {493.207, 286.72999999999996`}, {
                    523.98, 286.25}, {528.848, 304.89099999999996`}, {
                    513.9219999999999, 291.89799999999997`}, {488.125, 
                    296.71099999999996`}, {474.477, 284.727}, {460.828, 
                    272.746}, {467.945, 258.77299999999997`}, {480.578, 
                    272.754}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    484.79299999999995`, 259.824}, {499.453, 
                    271.65200000000004`}, {529.7730000000001, 266.363}, {
                    537.496, 284.01599999999996`}, {520.719, 
                    273.51599999999996`}, {495.99199999999996`, 282.305}, {
                    480.637, 272.605}, {465.28499999999997`, 
                    262.90599999999995`}, {470.129, 247.99200000000002`}, {
                    484.79299999999995`, 259.824}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    486.92999999999995`, 246.395}, {503.262, 255.785}, {
                    532.383, 245.816}, {542.7700000000001, 262.043}, {524.559,
                     254.297}, {501.512, 266.848}, {484.828, 259.668}, {
                    468.14500000000004`, 252.49200000000002`}, {
                    470.59799999999996`, 237.004}, {486.92999999999995`, 
                    246.395}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    486.945, 232.797}, {504.543, 239.516}, {531.742, 
                    225.117}, {544.543, 239.516}, {525.3439999999999, 
                    234.71499999999997`}, {504.543, 250.71499999999997`}, {
                    486.945, 246.23399999999998`}, {469.34400000000005`, 
                    241.754}, {469.34400000000005`, 226.07399999999998`}, {
                    486.945, 232.797}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    484.828, 219.363}, {503.262, 223.24599999999998`}, {
                    527.875, 204.76999999999998`}, {542.7700000000001, 
                    216.98800000000003`}, {523.055, 215.25}, {
                    505.01599999999996`, 234.309}, {486.92999999999995`, 
                    232.637}, {468.848, 230.965}, {466.395, 
                    215.48000000000002`}, {484.828, 219.363}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    480.637, 206.42600000000002`}, {499.453, 207.379}, {
                    520.871, 185.277}, {537.496, 195.016}, {517.754, 
                    196.38700000000003`}, {502.914, 218.031}, {
                    484.79299999999995`, 219.207}, {466.668, 
                    220.38700000000003`}, {461.824, 205.47299999999998`}, {
                    480.637, 206.42600000000002`}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    474.477, 194.305}, {493.207, 192.30100000000002`}, {
                    510.90599999999995`, 167.121}, {528.848, 174.141}, {
                    509.562, 178.58200000000002`}, {498.29299999999995`, 
                    202.281}, {480.578, 206.277}, {462.863, 210.277}, {
                    455.742, 196.305}, {474.477, 194.305}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    466.49199999999996`, 183.29299999999998`}, {484.684, 
                    178.38700000000003`}, {498.22299999999996`, 150.75}, {
                    517.043, 154.875}, {498.688, 162.277}, {
                    491.26599999999996`, 187.445}, {474.395, 194.168}, {
                    457.52, 200.88700000000003`}, {448.305, 
                    188.20299999999997`}, {466.49199999999996`, 
                    183.29299999999998`}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    456.887, 173.672}, {474.082, 165.977}, {483.133, 
                    136.562}, {502.367, 137.691}, {485.39799999999997`, 
                    147.875}, {482.004, 173.895}, {466.39099999999996`, 
                    183.172}, {450.777, 192.44899999999998`}, {439.688, 
                    181.363}, {456.887, 173.672}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    445.89099999999996`, 165.668}, {461.672, 155.379}, {
                    466.012, 124.91000000000001`}, {485.184, 123.016}, {
                    470.01599999999996`, 135.73}, {470.734, 161.961}, {
                    456.76599999999996`, 173.566}, {442.79699999999997`, 
                    185.172}, {430.10900000000004`, 175.95700000000002`}, {
                    445.89099999999996`, 165.668}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    433.78099999999995`, 159.48000000000002`}, {447.758, 
                    146.85200000000003`}, {447.277, 116.07799999999999`}, {
                    465.91799999999995`, 111.21100000000001`}, {
                    452.92599999999993`, 126.141}, {457.73799999999994`, 
                    151.93800000000002`}, {445.758, 165.58200000000002`}, {
                    433.77299999999997`, 179.23}, {419.805, 
                    172.11299999999997`}, {433.78099999999995`, 
                    159.48000000000002`}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    420.85200000000003`, 155.26999999999998`}, {432.684, 
                    140.605}, {427.39099999999996`, 110.289}, {445.043, 
                    102.562}, {434.543, 119.34}, {443.332, 144.066}, {433.633,
                     159.42200000000003`}, {423.93399999999997`, 
                    174.77299999999997`}, {409.02299999999997`, 169.93}, {
                    420.85200000000003`, 155.26999999999998`}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    407.42199999999997`, 153.129}, {416.812, 136.797}, {
                    406.84400000000005`, 107.67999999999999`}, {423.07, 
                    97.289}, {415.324, 115.5}, {427.875, 138.547}, {420.695, 
                    155.23}, {413.52, 171.914}, {398.03099999999995`, 
                    169.461}, {407.42199999999997`, 153.129}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    393.824, 153.117}, {400.543, 135.516}, {
                    386.14500000000004`, 108.316}, {400.543, 95.516}, {
                    395.742, 114.715}, {411.742, 135.516}, {
                    407.26599999999996`, 153.117}, {402.78499999999997`, 
                    170.71499999999997`}, {387.105, 170.71499999999997`}, {
                    393.824, 153.117}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    380.39099999999996`, 155.23}, {384.27299999999997`, 
                    136.797}, {365.79699999999997`, 112.184}, {
                    378.01599999999996`, 97.289}, {376.28099999999995`, 
                    117.004}, {395.33599999999996`, 135.04299999999998`}, {
                    393.66400000000004`, 153.129}, {391.99199999999996`, 
                    171.21099999999998`}, {376.508, 173.664}, {
                    380.39099999999996`, 155.23}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    367.453, 159.42200000000003`}, {368.40599999999995`, 
                    140.605}, {346.305, 119.18799999999999`}, {356.047, 
                    102.562}, {357.414, 122.309}, {379.059, 
                    137.14499999999998`}, {380.234, 155.26999999999998`}, {
                    381.414, 173.39100000000002`}, {366.5, 
                    178.23399999999998`}, {367.453, 159.42200000000003`}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    355.332, 165.58200000000002`}, {353.328, 
                    146.85200000000003`}, {328.148, 129.15200000000002`}, {
                    335.168, 111.21100000000001`}, {339.60900000000004`, 
                    130.496}, {363.309, 141.766}, {367.309, 
                    159.48000000000002`}, {371.305, 177.19899999999998`}, {
                    357.33599999999996`, 184.316}, {355.332, 
                    165.58200000000002`}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    344.324, 173.566}, {339.414, 155.379}, {311.777, 
                    141.836}, {315.902, 123.016}, {323.305, 141.371}, {
                    348.477, 148.79299999999998`}, {355.195, 165.668}, {
                    361.91799999999995`, 182.539}, {349.22999999999996`, 
                    191.754}, {344.324, 173.566}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    334.699, 183.172}, {327.004, 165.977}, {297.59, 
                    156.92600000000002`}, {298.719, 137.691}, {308.902, 
                    154.664}, {334.92599999999993`, 158.059}, {344.203, 
                    173.672}, {353.47999999999996`, 189.281}, {
                    342.39099999999996`, 200.371}, {334.699, 183.172}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    326.695, 194.168}, {316.40599999999995`, 
                    178.38700000000003`}, {285.93799999999993`, 174.047}, {
                    284.047, 154.875}, {296.758, 170.04299999999998`}, {
                    322.98799999999994`, 169.324}, {334.594, 
                    183.29299999999998`}, {346.199, 197.266}, {336.984, 
                    209.94899999999998`}, {326.695, 194.168}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    320.512, 206.277}, {307.879, 192.30100000000002`}, {
                    277.105, 192.781}, {272.23799999999994`, 174.141}, {
                    287.168, 187.13299999999998`}, {312.965, 
                    182.32000000000002`}, {326.613, 194.305}, {340.258, 
                    206.285}, {333.141, 220.258}, {320.512, 206.277}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    316.29699999999997`, 219.207}, {301.633, 207.379}, {
                    271.316, 212.668}, {263.594, 195.016}, {280.367, 
                    205.516}, {305.094, 196.727}, {320.449, 
                    206.42600000000002`}, {335.805, 216.125}, {330.957, 
                    231.039}, {316.29699999999997`, 219.207}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    314.156, 232.637}, {297.824, 223.24599999999998`}, {
                    268.707, 233.21499999999997`}, {258.316, 
                    216.98800000000003`}, {276.53099999999995`, 
                    224.73399999999998`}, {299.578, 212.184}, {316.258, 
                    219.363}, {332.941, 226.539}, {330.48799999999994`, 
                    242.02700000000002`}, {314.156, 232.637}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    314.14500000000004`, 246.23399999999998`}, {296.543, 
                    239.516}, {269.34400000000005`, 253.914}, {256.543, 
                    239.516}, {275.742, 244.316}, {296.543, 228.316}, {
                    314.14500000000004`, 232.797}, {331.742, 237.277}, {
                    331.742, 252.95700000000002`}, {314.14500000000004`, 
                    246.23399999999998`}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    316.258, 259.668}, {297.824, 255.785}, {
                    273.21099999999996`, 274.262}, {258.316, 262.043}, {
                    278.03099999999995`, 263.78099999999995`}, {296.074, 
                    244.72299999999998`}, {314.156, 246.395}, {332.242, 
                    248.066}, {334.695, 263.555}, {316.258, 259.668}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    320.449, 272.605}, {301.633, 271.65200000000004`}, {
                    280.215, 293.754}, {263.594, 284.01599999999996`}, {
                    283.33599999999996`, 282.64500000000004`}, {298.172, 
                    261.}, {316.29699999999997`, 259.824}, {
                    334.41799999999995`, 258.64500000000004`}, {
                    339.26599999999996`, 273.559}, {320.449, 272.605}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    326.613, 284.727}, {307.879, 286.72999999999996`}, {
                    290.18, 311.90999999999997`}, {272.23799999999994`, 
                    304.89099999999996`}, {291.527, 300.449}, {
                    302.79299999999995`, 276.75}, {320.512, 272.754}, {
                    338.227, 268.754}, {345.34400000000005`, 282.727}, {
                    326.613, 284.727}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    334.594, 295.73799999999994`}, {316.40599999999995`, 
                    300.64500000000004`}, {302.863, 328.28099999999995`}, {
                    284.047, 324.156}, {302.39799999999997`, 316.754}, {
                    309.824, 291.58599999999996`}, {326.695, 284.863}, {
                    343.566, 278.14500000000004`}, {352.78499999999997`, 
                    290.828}, {334.594, 295.73799999999994`}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    344.203, 305.363}, {327.004, 313.055}, {317.953, 
                    342.469}, {298.719, 341.34000000000003`}, {315.691, 
                    331.156}, {319.08599999999996`, 305.137}, {334.699, 
                    295.85900000000004`}, {350.312, 286.582}, {
                    361.39799999999997`, 297.668}, {344.203, 305.363}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    355.195, 313.363}, {339.414, 323.65200000000004`}, {
                    335.078, 354.121}, {315.902, 356.01599999999996`}, {
                    331.07, 343.301}, {330.35200000000003`, 317.07}, {344.324,
                     305.465}, {358.29299999999995`, 293.85900000000004`}, {
                    370.977, 303.074}, {355.195, 313.363}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    367.309, 319.551}, {353.328, 332.18}, {353.812, 
                    362.953}, {335.168, 367.82}, {348.16400000000004`, 
                    352.895}, {343.35200000000003`, 327.09799999999996`}, {
                    355.332, 313.449}, {367.312, 299.801}, {
                    381.28499999999997`, 306.91799999999995`}, {367.309, 
                    319.551}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    380.234, 323.76599999999996`}, {368.40599999999995`, 
                    338.42599999999993`}, {373.695, 368.746}, {356.047, 
                    376.469}, {366.543, 359.691}, {357.754, 334.965}, {
                    367.453, 319.60900000000004`}, {377.15200000000004`, 
                    304.258}, {392.066, 309.10200000000003`}, {380.234, 
                    323.76599999999996`}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    393.66400000000004`, 325.902}, {384.27299999999997`, 
                    342.234}, {394.242, 371.35200000000003`}, {
                    378.01599999999996`, 381.742}, {385.762, 
                    363.53099999999995`}, {373.21099999999996`, 340.484}, {
                    380.39099999999996`, 323.801}, {387.57, 307.117}, {
                    403.055, 309.57}, {393.66400000000004`, 
                    325.902}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.9098040000000001, 0.06666670000000002, 
                    0.17647100000000002`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{486.945, 239.516}, {486.945, 191.797}, {448.262, 
                    153.117}, {400.543, 153.117}, {352.828, 153.117}, {
                    314.14500000000004`, 191.797}, {314.14500000000004`, 
                    239.516}, {314.14500000000004`, 287.234}, {352.828, 
                    325.914}, {400.543, 325.914}, {448.262, 325.914}, {
                    486.945, 287.234}, {486.945, 239.516}}}]}}}}}}}, {{{{{{{
                    RGBColor[1., 0.9372550000000001, 0.], 
                    Thickness[0.021882977499999998`], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{485.59799999999996`, 240.81199999999998`}, {
                    485.59799999999996`, 193.89099999999996`}, {447.559, 
                    155.85199999999998`}, {400.637, 155.85199999999998`}, {
                    353.715, 155.85199999999998`}, {315.676, 
                    193.89099999999996`}, {315.676, 240.81199999999998`}, {
                    315.676, 287.73400000000004`}, {353.715, 325.773}, {
                    400.637, 325.773}, {447.559, 325.773}, {
                    485.59799999999996`, 287.73400000000004`}, {
                    485.59799999999996`, 240.81199999999998`}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 0.9372550000000001, 0.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{464.621, 244.23399999999998`}, {464.621, 
                    208.45700000000002`}, {435.93399999999997`, 179.453}, {
                    400.543, 179.453}, {365.156, 179.453}, {336.469, 
                    208.45700000000002`}, {336.469, 244.23399999999998`}, {
                    336.469, 280.012}, {365.156, 309.01599999999996`}, {
                    400.543, 309.01599999999996`}, {435.93399999999997`, 
                    309.01599999999996`}, {464.621, 280.012}, {464.621, 
                    244.23399999999998`}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.9098040000000001, 0.06666670000000002, 
                    0.17647100000000002`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}}}, {{{464.621, 279.707}, {414.574, 
                    279.707}, {374.004, 238.68800000000002`}, {374.004, 
                    188.094}, {374.004, 137.496}, {414.574, 96.477}, {464.621,
                     96.477}, {459.4959999999999, 92.93}, {407.508, 92.93}, {
                    365.367, 135.535}, {365.367, 188.094}, {365.367, 
                    240.648}, {407.508, 283.254}, {459.4959999999999, 
                    283.254}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}}}, {{{456.078, 285.76599999999996`}, {
                    402.719, 285.76599999999996`}, {359.465, 242.035}, {
                    359.465, 188.094}, {359.465, 134.148}, {402.719, 
                    90.418}, {456.078, 90.418}, {450.949, 86.453}, {
                    395.42999999999995`, 86.453}, {350.41799999999995`, 
                    131.961}, {350.41799999999995`, 188.094}, {
                    350.41799999999995`, 244.227}, {395.42999999999995`, 
                    289.72999999999996`}, {450.949, 289.72999999999996`}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}}}, {{{447.53499999999997`, 
                    292.49199999999996`}, {390.504, 292.49199999999996`}, {
                    344.27, 245.75}, {344.27, 188.094}, {344.27, 130.434}, {
                    390.504, 83.691}, {447.53499999999997`, 83.691}, {
                    442.40599999999995`, 79.391}, {383.02299999999997`, 
                    79.391}, {334.887, 128.059}, {334.887, 188.094}, {334.887,
                     248.129}, {383.02299999999997`, 296.79699999999997`}, {
                    442.40599999999995`, 296.79699999999997`}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}}}, {{{336.469, 279.707}, {
                    386.51599999999996`, 279.707}, {427.08599999999996`, 
                    238.68800000000002`}, {427.08599999999996`, 188.094}, {
                    427.08599999999996`, 137.496}, {386.51599999999996`, 
                    96.477}, {336.469, 96.477}, {341.594, 92.93}, {393.578, 
                    92.93}, {435.72299999999996`, 135.535}, {
                    435.72299999999996`, 188.094}, {435.72299999999996`, 
                    240.648}, {393.578, 283.254}, {341.594, 283.254}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}}}, {{{345.012, 285.76599999999996`}, {
                    398.367, 285.76599999999996`}, {441.621, 242.035}, {
                    441.621, 188.094}, {441.621, 134.148}, {398.367, 
                    90.418}, {345.012, 90.418}, {350.137, 86.453}, {405.66, 
                    86.453}, {450.668, 131.961}, {450.668, 188.094}, {450.668,
                     244.227}, {405.66, 289.72999999999996`}, {350.137, 
                    289.72999999999996`}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}}}, {{{353.555, 292.49199999999996`}, {
                    410.58599999999996`, 292.49199999999996`}, {456.82, 
                    245.75}, {456.82, 188.094}, {456.82, 130.434}, {
                    410.58599999999996`, 83.691}, {353.555, 83.691}, {358.68, 
                    79.391}, {418.062, 79.391}, {466.203, 128.059}, {466.203, 
                    188.094}, {466.203, 248.129}, {418.062, 
                    296.79699999999997`}, {358.68, 
                    296.79699999999997`}}}]}}}}}}}}}}}}}}, AspectRatio -> 
                  Automatic, ImageSize -> {{128}, {85}}, 
                  PlotRange -> {{0., 800.}, {0., 480.}}], ",", 
                 GraphicsBox[{{{{{{{
                    Thickness[0.0020833333333333333`], {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.8078430000000001, 0.06666670000000002, 0.14902], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {0., 320.}, {480., 320.}, {480., 
                    0.}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0., 0.15686300000000003`, 0.407843], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     240.}, {480., 240.}, {480., 80.}, {0., 
                    80.}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{304., 160.}, {304., 124.65199999999999`}, {
                    275.348, 96.}, {240., 96.}, {204.65200000000002`, 96.}, {
                    176., 124.65199999999999`}, {176., 160.}, {176., 
                    195.348}, {204.65200000000002`, 224.}, {240., 224.}, {
                    275.348, 224.}, {304., 195.348}, {304., 
                    160.}}}]}}}}}}}}}}}}}}, AspectRatio -> Automatic, 
                  ImageSize -> {{128}, {85}}, 
                  PlotRange -> {{0., 480.}, {0., 320.}}], ",", 
                 GraphicsBox[{{{{{{{
                    Thickness[0.0004464285714285714], {{{{{{{
                    FaceForm[{
                    RGBColor[0.8, 0., 0.003921569999999999], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {0., 1120.}, {2240., 1120.}, {2240., 
                    0.}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     80.}, {2240., 80.}, {2240., 0.}, {0., 0.}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     240.}, {2240., 240.}, {2240., 160.}, {0., 160.}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     400.}, {2240., 400.}, {2240., 320.}, {0., 320.}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     560.}, {2240., 560.}, {2240., 480.}, {0., 480.}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     720.}, {2240., 720.}, {2240., 640.}, {0., 640.}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     880.}, {2240., 880.}, {2240., 800.}, {0., 800.}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     1040.}, {2240., 1040.}, {2240., 960.}, {0., 
                    960.}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0.003921569999999999, 0., 0.4], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     1120.}, {1120., 1120.}, {1120., 480.}, {0., 
                    480.}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 0.8, 0.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4k7HhKcXztQ4MICAwwSHx0tnH1GoK4HzwXRD
tgNYnXIvnA+mGTrh/PJ986X077Sg6m9odEAxH8hvfR24Q+5sPZx/Qen2zzqf
RocjChuKMj40QvRXNkH0bWxy+HTJN0ngVKPDUZB8aZNDBcgevkaHy0DhiJAm
B+v7/r3TvRrgfFuu64sLzCvh/Nznv1d+tCmGmOPfCud3gMz/1QHng81Z1gPX
/7BKZJ37wn64+TB+u9jNc9+lGuH8Q181YvofNULMr+l3yJj4tsZ+dpPDNOfu
nOfm/Q6CEZZbTqQ3OoC41cwTHHbKAUPgVT08fNHDHwDvCqa9
                    "]], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIZIGYC4k+XfJMEHnY5XFC6/bNOotVh64myffO3tjvI
RqVY39/f5uDFw6TdvrTDwce80zEhttlBIMJyy4m2NoeKffOl9I3aHLZ//nul
4m6rAwMIHGhy4NXdNPe9WauDXOvrwB1A+WnO3TnPRZsdPEHmxDc7HP6qEdPP
0eLwsEpknfvBNgdBkHm3GxwuA50RIdPqcAgkb97ssGz2EYUNB9sh5jrUQ+yf
1w5R97bJ4fFSoALGTofj3kAJp3oHW67riwvSuhxs7vv3TrdodgAJJzh0Qdxz
r8FB/64KW+PzHog5XC0Q/Q7dDttA7pdqdtgC8veiPof3y495m1u2OgBVPb1w
thvi7kdQ/zn0O4DDq7MN4n6gfNaekskSqzog5izog7hjezvE/3bdEPOedDno
AJ2x/HEPRL6jwyEaGLz+dl0QcxV6IOGeCFV3qcNBBhT+/6C0XA8k3Ga2OwBD
pSijvQPi3v3tDgDqbsmS
                    "]]}}}}}}}}}}}}}}, AspectRatio -> 
                  Automatic, ImageSize -> {{128}, {85}}, 
                  PlotRange -> {{0., 2240.}, {0., 1120.}}], ",", 
                 GraphicsBox[{{{{{{{
                    Thickness[0.001736111111111111], {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.8235290000000001, 0.06274510000000001, 
                    0.20392200000000002`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {0., 384.}, {576., 384.}, {576., 
                    0.}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0., 0.494118, 0.22745100000000001`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    96., 288.}, {480., 288.}, {480., 96.}, {96., 
                    96.}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{376., 192.}, {376., 156.65200000000002`}, {
                    347.348, 128.}, {312., 128.}, {276.65200000000004`, 
                    128.}, {248., 156.65200000000002`}, {248., 192.}, {248., 
                    227.348}, {276.65200000000004`, 256.}, {312., 256.}, {
                    347.348, 256.}, {376., 227.348}, {376., 
                    192.}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0., 0.494118, 0.22745100000000001`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{400., 192.}, {400., 156.65200000000002`}, {
                    371.348, 128.}, {336., 128.}, {300.65200000000004`, 
                    128.}, {272., 156.65200000000002`}, {272., 192.}, {272., 
                    227.348}, {300.65200000000004`, 256.}, {336., 256.}, {
                    371.348, 256.}, {400., 227.348}, {400., 
                    192.}}}]}}}}}}}}}}}}}}, AspectRatio -> Automatic, 
                  ImageSize -> {{128}, {85}}, 
                  PlotRange -> {{0., 576.}, {0., 384.}}], ",", 
                 GraphicsBox[{{{{{{{
                    Thickness[0.00026041666666666666`], {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.7686270000000001, 0.15294100000000005`, 0.184314], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {0., 1920.}, {3840., 1920.}, {3840., 
                    0.}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.003921569999999999, 0.31764699999999996`, 
                    0.5921569999999999], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    1280., 1920.}, {2560., 1920.}, {2560., 0.}, {1280., 
                    0.}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.976471, 0.8117650000000001, 0.007843139999999998], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{816., 1264.}, {816., 1166.797}, {
                    737.2030000000001, 1088.}, {640., 1088.}, {542.797, 
                    1088.}, {464., 1166.797}, {464., 1264.}, {464., 
                    1361.203}, {542.797, 1440.}, {640., 1440.}, {
                    737.2030000000001, 1440.}, {816., 1361.203}, {816., 
                    1264.}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.7686270000000001, 0.15294100000000005`, 0.184314], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{832., 1344.}, {832., 1237.961}, {746.039, 
                    1152.}, {640., 1152.}, {533.9609999999999, 1152.}, {448., 
                    1237.961}, {448., 1344.}, {448., 1450.039}, {
                    533.9609999999999, 1536.}, {640., 1536.}, {746.039, 
                    1536.}, {832., 1450.039}, {832., 1344.}}}]}}}}}}}, {{{{{{{
                    
                    FaceForm[{
                    RGBColor[
                    0.976471, 0.8117650000000001, 0.007843139999999998], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{768., 1312.}, {768., 1241.309}, {710.691, 
                    1184.}, {640., 1184.}, {569.309, 1184.}, {512., 
                    1241.309}, {512., 1312.}, {512., 1382.6909999999998`}, {
                    569.309, 1440.}, {640., 1440.}, {710.691, 1440.}, {768., 
                    1382.6909999999998`}, {768., 1312.}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGZigIKGRgcw7TDDAcaXb30daPFmukO72M1z3480
QugZ0x1sua4vLrBuAsvviJ3uwKe7ae77jU0Ozt05z6uVoPIRzRBzGKZD6RY4
/9BXjZj+5Qj+p0u+SQJ+rXD9h0HyR1rh5le+VDPksG6D2w9xXxvcfTA+qvuh
/ANQ/oNWCH0Bjc8wE5VvAOU7QPUXQPkNUPkDaOph8g5QfgIaXwCND3NPAw5+
wwwHAN8kadg=
                    "]], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    288., 1056.}, {448., 1056.}, {448., 288.}, {288., 
                    288.}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    832., 1056.}, {992., 1056.}, {992., 288.}, {832., 
                    288.}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    480., 928.}, {800., 928.}, {800., 864.}, {480., 864.}}}], 
                    
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    480., 480.}, {800., 480.}, {800., 416.}, {480., 416.}}}], 
                    
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1,
                     0}}}, {{{480., 1056.}, {800., 1056.}, {640., 960.}}, {{
                    480., 384.}, {800., 384.}, {640., 288.}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{809.602, 672.}, {809.602, 578.3319999999999}, {
                    733.668, 502.39799999999997`}, {640., 
                    502.39799999999997`}, {546.3319999999999, 
                    502.39799999999997`}, {470.39799999999997`, 
                    578.3319999999999}, {470.39799999999997`, 672.}, {
                    470.39799999999997`, 765.668}, {546.3319999999999, 
                    841.602}, {640., 841.602}, {733.668, 841.602}, {809.602, 
                    765.668}, {809.602, 672.}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.7686270000000001, 0.15294100000000005`, 0.184314], 
                    Thickness[0.005], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{809.602, 672.}, {809.602, 578.3320000000001}, {
                    733.668, 502.39800000000014`}, {640., 
                    502.39800000000014`}, {546.3319999999999, 
                    502.39800000000014`}, {470.39799999999997`, 
                    578.3320000000001}, {470.39799999999997`, 672.}, {
                    470.39799999999997`, 765.6680000000001}, {
                    546.3319999999999, 841.6020000000001}, {640., 
                    841.6020000000001}, {733.668, 841.6020000000001}, {
                    809.602, 765.6680000000001}, {809.602, 672.}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.7686270000000001, 0.15294100000000005`, 0.184314], 
                    Thickness[0.005], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGZigIEWhy7HhKcXfLocbO77907fiOA/Xjr7iEJS
q8MyILWBucsBxN1wv9Uha0/JZIm2ToeHVSLr3GPbHLx4mLTbOTodgLJFGcva
HMDGRnTA+cfAdDucLxBhueXElza4/gcg2qUNbv4KEH2sFW7/ExDt2Qp3H8Td
rQ4w98P4YPP9muF82agU6/tzmxzkQPS2FgcQ5a/QBKEtWxzkWl8H7ljUCKF3
N0PMj2x0+LD8mLc5N4IPoZvgfLDxKxrh+rd9/nul4nsD3Pxpzt05zysb4PZv
OVG2b/6Perj7PtTYm8al1cPdD+MDANeSp3k=
                    "], 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.7686270000000001, 0.15294100000000005`, 0.184314], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{672., 756.8009999999999}, {672., 739.125}, {
                    657.672, 724.8009999999999}, {640., 724.8009999999999}, {
                    622.328, 724.8009999999999}, {608., 739.125}, {608., 
                    756.8009999999999}, {608., 774.4730000000001}, {622.328, 
                    788.8009999999999}, {640., 788.8009999999999}, {657.672, 
                    788.8009999999999}, {672., 774.4730000000001}, {672., 
                    756.8009999999999}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{672., 587.1990000000001}, {672., 
                    569.5269999999999}, {657.672, 555.1990000000001}, {640., 
                    555.1990000000001}, {622.328, 555.1990000000001}, {608., 
                    569.5269999999999}, {608., 587.1990000000001}, {608., 
                    604.875}, {622.328, 619.1990000000001}, {640., 
                    619.1990000000001}, {657.672, 619.1990000000001}, {672., 
                    604.875}, {672., 587.1990000000001}}}]}}}}}}}}}}}}}}, 
                  AspectRatio -> Automatic, ImageSize -> {{128}, {85}}, 
                  PlotRange -> {{0., 3840.}, {0., 1920.}}], ",", 
                 GraphicsBox[{{{{{{{
                    Thickness[0.0006944444444444445], {{{{{{{
                    FaceForm[{
                    RGBColor[0.996078, 0.796078, 0.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     960.}, {1440., 960.}, {1440., 480.}, {0., 
                    480.}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.9176470000000001, 0.15686300000000003`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     480.}, {1440., 480.}, {1440., 0.}, {0., 
                    0.}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0.20392200000000002`, 0.698039, 0.2], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     640.}, {1440., 640.}, {1440., 320.}, {0., 
                    320.}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{812.992, 
                    378.68}, {512.0659999999999, 160.04299999999998`}, {
                    627.008, 513.8009999999999}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{684.48, 
                    336.92199999999997`}, {383.555, 555.559}, {755.52, 
                    555.559}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{605.055, 
                    446.23799999999994`}, {720., 800.}, {834.9449999999999, 
                    446.23799999999994`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{684.48, 
                    555.559}, {1056.4450000000002`, 555.559}, {755.52, 
                    336.92199999999997`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{812.992, 
                    513.8009999999999}, {927.934, 160.04299999999998`}, {
                    627.008, 378.68}}}]}}}}}}}}}}}}}}, AspectRatio -> 
                  Automatic, ImageSize -> {{128}, {85}}, 
                  PlotRange -> {{0., 1440.}, {0., 960.}}], ",", 
                 GraphicsBox[{{{{{{{
                    Thickness[0.0020833333333333333`], {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {0., 240.}, {480., 240.}, {480., 
                    0.}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    120., 240.}, {480., 240.}, {480., 160.}, {120., 
                    160.}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0., 0.501961, 0.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    120., 80.}, {480., 80.}, {480., 0.}, {120., 
                    0.}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    27.629, 198.945}, {40.523, 198.945}, {41.234, 198.945}, {
                    41.809, 198.406}, {41.809, 197.738}, {41.809, 191.664}, {
                    41.809, 190.996}, {41.234, 190.45700000000002`}, {40.523, 
                    190.45700000000002`}, {27.629, 190.45700000000002`}, {
                    26.914, 190.45700000000002`}, {26.34, 190.996}, {26.34, 
                    191.664}, {26.34, 197.738}, {26.34, 198.406}, {26.914, 
                    198.945}, {27.629, 198.945}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002951354166666667], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    27.629, 198.945}, {40.523, 198.945}, {41.234, 198.945}, {
                    41.809, 198.406}, {41.809, 197.738}, {41.809, 191.664}, {
                    41.809, 190.996}, {41.234, 190.457}, {40.523, 190.457}, {
                    27.629, 190.457}, {26.914, 190.457}, {26.34, 190.996}, {
                    26.34, 191.664}, {26.34, 197.738}, {26.34, 198.406}, {
                    26.914, 198.945}, {27.629, 198.945}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    27.957, 198.594}, {40.191, 198.594}, {40.867, 198.594}, {
                    41.413999999999994`, 198.098}, {41.413999999999994`, 
                    197.48800000000003`}, {41.413999999999994`, 191.918}, {
                    41.413999999999994`, 191.305}, {40.867, 190.812}, {40.191,
                     190.812}, {27.957, 190.812}, {27.281, 190.812}, {26.738, 
                    191.305}, {26.738, 191.918}, {26.738, 
                    197.48800000000003`}, {26.738, 198.098}, {27.281, 
                    198.594}, {27.957, 198.594}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752291666666667], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    27.957, 198.594}, {40.191, 198.594}, {40.867, 198.594}, {
                    41.413999999999994`, 198.098}, {41.413999999999994`, 
                    197.488}, {41.413999999999994`, 191.918}, {
                    41.413999999999994`, 191.305}, {40.867, 190.812}, {40.191,
                     190.812}, {27.957, 190.812}, {27.281, 190.812}, {26.738, 
                    191.305}, {26.738, 191.918}, {26.738, 197.488}, {26.738, 
                    198.098}, {27.281, 198.594}, {27.957, 198.594}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIFIGYCYn7dTXPfH3dwiNvlycPUn+FwfXGBLZe6owMX
iNGXARHXdnQoypj4tqY5w2H2EYUNRRWODsLNB04trMxwWOi67fPfLY4ON899
D37cmuEQYbnlRNk/RwcGEKjJcADKXqnY6egA0m5fmOFwUen2z7pTjg5Anmlc
UoaDtP5dFTZFJwdVtsapzskI/oRDXzVi/DMcKl+qGXLccXQ47m3e6RiAME82
KsX6vjPUvexODt80YvoPmSLM5wZJaGU4uHTnPP/d6egAdNW++WYI/4Ddb5gB
8Ze+o0MxiJbPcICFB9g/slD1ux0g7tPPcBBd5/6wKsXBYdXHS75JFlD/mzhA
3KOd4fAJKCxww95hEVgc6j5xBwenhKcXlIDu/QJ0/stj9g6PlwJD0ifDoV0M
aJMxgg9xnz3EP6kZDqdAFuyFyqdkOBwGBku/EDS+ijMcpkiwhPGttYf4uw5q
nrKDgxXIw93Q8ItxgLinAeGfY6DwbMlwAADQteMG
                    
                    "]]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.00017376208333333334`], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIFIGYCYn7dTXPfH3dwiNvlycPUn+FwfXGBLZe6owMX
iNGXARHXdnQozpj4tqY5w2H2EYUNRRWODkLNB04trMxwWOi67fPfLY4ON899
D37cmuEQYbnlRNk/RwcGEKjJcADKXqnY6egA0m5fmOFwUen2z7pTjg7vauxN
45IyHKT176qwKTo5qLI1TnVORvD7D33ViPHPcKh8qWbIccfR4Zi3eadjAMI8
2agU6/vOUPeyOzl804jpP2SKMB/sfq0MB5funOe/Ox0dgK7aN98M4R+w+w0z
HIpADtOH+k8+wwEWHmD/yELV73aAuE8/w0F0nfvDqhQHh1UfL/kmWUD9b+Lg
IANyj3aGwyegsMANe4dFYHGo+8QdHJwSnl5QArr3C9D5L4/ZOzxeCgxJnwyH
djGgTcYIPsR99hD/pGY4nAJZsNfe4QlIPiXD4TAwWPqFoPFVnOEwRYIljG+t
PcTfdVDzlB0cQNGwrxsafjEOEPc0IPxzHBSeLRkOAMzd4wM=
                    "], 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{34.602000000000004`, 194.79299999999998`}, {
                    34.602000000000004`, 194.406}, {34.234, 194.094}, {
                    33.785000000000004`, 194.094}, {33.336, 194.094}, {32.973,
                     194.406}, {32.973, 194.79299999999998`}, {32.973, 
                    195.176}, {33.336, 195.48800000000003`}, {
                    33.785000000000004`, 195.48800000000003`}, {34.234, 
                    195.48800000000003`}, {34.602000000000004`, 195.176}, {
                    34.602000000000004`, 
                    194.79299999999998`}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.00018712128065294733`], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{34.602000000000004`, 194.79308092799997`}, {
                    34.602000000000004`, 194.40591648}, {34.234, 
                    194.093901888}, {33.785000000000004`, 194.093901888}, {
                    33.336, 194.093901888}, {32.973, 194.40591648}, {32.973, 
                    194.79308092799997`}, {32.973, 195.175489056}, {33.336, 
                    195.488454912}, {33.785000000000004`, 195.488454912}, {
                    34.234, 195.488454912}, {34.602000000000004`, 
                    195.175489056}, {34.602000000000004`, 
                    194.79308092799997`}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{28.723, 
                    198.23399999999998`}, {27.531000000000002`, 
                    197.176}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{28.723, 
                    198.23399999999998`}, {27.531000000000002`, 197.176}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{29.516000000000002`, 
                    198.23399999999998`}, {28.324, 197.176}}}]}}}}}}}, {{{{{{{
                    
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{29.516000000000002`, 
                    198.23399999999998`}, {28.324, 197.176}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{30.309, 
                    198.23399999999998`}, {29.117000000000004`, 
                    197.176}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{30.309, 
                    198.23399999999998`}, {29.117000000000004`, 197.176}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{31.102, 
                    198.23399999999998`}, {29.91, 197.176}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{31.102, 
                    198.23399999999998`}, {29.91, 197.176}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{31.895, 
                    198.23399999999998`}, {30.703, 197.176}}}]}}}}}}}, {{{{{{{
                    
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{31.895, 
                    198.23399999999998`}, {30.703, 197.176}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{32.688, 
                    198.23399999999998`}, {31.496, 197.176}}}]}}}}}}}, {{{{{{{
                    
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{32.688, 
                    198.23399999999998`}, {31.496, 197.176}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{33.48, 
                    198.23399999999998`}, {32.289, 197.176}}}]}}}}}}}, {{{{{{{
                    
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{33.48, 
                    198.23399999999998`}, {32.289, 197.176}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{34.273, 
                    198.23399999999998`}, {33.086, 197.176}}}]}}}}}}}, {{{{{{{
                    
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{34.273, 
                    198.23399999999998`}, {33.086, 197.176}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{35.066, 
                    198.23399999999998`}, {33.879, 197.176}}}]}}}}}}}, {{{{{{{
                    
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{35.066, 
                    198.23399999999998`}, {33.879, 197.176}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{35.858999999999995`, 
                    198.23399999999998`}, {34.672000000000004`, 
                    197.176}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{35.858999999999995`, 
                    198.23399999999998`}, {34.672000000000004`, 197.176}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{36.652, 
                    198.23399999999998`}, {35.465, 197.176}}}]}}}}}}}, {{{{{{{
                    
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{36.652, 
                    198.23399999999998`}, {35.465, 197.176}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{37.445, 
                    198.23399999999998`}, {36.258, 197.176}}}]}}}}}}}, {{{{{{{
                    
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{37.445, 
                    198.23399999999998`}, {36.258, 197.176}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{34.273, 
                    198.23399999999998`}, {33.086, 197.176}}}]}}}}}}}, {{{{{{{
                    
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{34.273, 
                    198.23399999999998`}, {33.086, 197.176}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{38.23800000000001, 
                    198.23399999999998`}, {37.050999999999995`, 
                    197.176}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{38.23800000000001, 
                    198.23399999999998`}, {37.050999999999995`, 197.176}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{39.031, 
                    198.23399999999998`}, {37.843999999999994`, 
                    197.176}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{39.031, 
                    198.23399999999998`}, {37.843999999999994`, 197.176}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{39.828, 
                    198.23399999999998`}, {38.637, 197.176}}}]}}}}}}}, {{{{{{{
                    
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{39.828, 
                    198.23399999999998`}, {38.637, 197.176}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{40.621, 
                    198.23399999999998`}, {39.43, 197.176}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{40.621, 
                    198.23399999999998`}, {39.43, 197.176}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{39.43, 
                    198.23399999999998`}, {40.621, 197.176}}}]}}}}}}}, {{{{{{{
                    
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{39.43, 
                    198.23399999999998`}, {40.621, 197.176}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{38.637, 
                    198.23399999999998`}, {39.828, 197.176}}}]}}}}}}}, {{{{{{{
                    
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{38.637, 
                    198.23399999999998`}, {39.828, 197.176}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{37.843999999999994`, 
                    198.23399999999998`}, {39.031, 197.176}}}]}}}}}}}, {{{{{{{
                    
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{37.843999999999994`, 
                    198.23399999999998`}, {39.031, 197.176}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{37.050999999999995`, 
                    198.23399999999998`}, {38.23800000000001, 
                    197.176}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{37.050999999999995`, 
                    198.23399999999998`}, {38.23800000000001, 197.176}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{36.258, 
                    198.23399999999998`}, {37.445, 197.176}}}]}}}}}}}, {{{{{{{
                    
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{36.258, 
                    198.23399999999998`}, {37.445, 197.176}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{35.465, 
                    198.23399999999998`}, {36.652, 197.176}}}]}}}}}}}, {{{{{{{
                    
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{35.465, 
                    198.23399999999998`}, {36.652, 197.176}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{34.672000000000004`, 
                    198.23399999999998`}, {35.858999999999995`, 
                    197.176}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{34.672000000000004`, 
                    198.23399999999998`}, {35.858999999999995`, 197.176}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{33.879, 
                    198.23399999999998`}, {35.066, 197.176}}}]}}}}}}}, {{{{{{{
                    
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{33.879, 
                    198.23399999999998`}, {35.066, 197.176}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{33.086, 
                    198.23399999999998`}, {34.273, 197.176}}}]}}}}}}}, {{{{{{{
                    
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{33.086, 
                    198.23399999999998`}, {34.273, 197.176}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{32.289, 
                    198.23399999999998`}, {33.48, 197.176}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{32.289, 
                    198.23399999999998`}, {33.48, 197.176}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{31.496, 
                    198.23399999999998`}, {32.688, 197.176}}}]}}}}}}}, {{{{{{{
                    
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{31.496, 
                    198.23399999999998`}, {32.688, 197.176}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{30.703, 
                    198.23399999999998`}, {31.895, 197.176}}}]}}}}}}}, {{{{{{{
                    
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{30.703, 
                    198.23399999999998`}, {31.895, 197.176}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{33.879, 
                    198.23399999999998`}, {35.066, 197.176}}}]}}}}}}}, {{{{{{{
                    
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{33.879, 
                    198.23399999999998`}, {35.066, 197.176}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{29.91, 
                    198.23399999999998`}, {31.102, 197.176}}}]}}}}}}}, {{{{{{{
                    
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{29.91, 
                    198.23399999999998`}, {31.102, 197.176}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{29.117000000000004`, 
                    198.23399999999998`}, {30.309, 197.176}}}]}}}}}}}, {{{{{{{
                    
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{29.117000000000004`, 
                    198.23399999999998`}, {30.309, 197.176}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{28.324, 
                    198.23399999999998`}, {29.516000000000002`, 
                    197.176}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{28.324, 
                    198.23399999999998`}, {29.516000000000002`, 197.176}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{27.531000000000002`, 
                    198.23399999999998`}, {28.723, 197.176}}}]}}}}}}}, {{{{{{{
                    
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{27.531000000000002`, 
                    198.23399999999998`}, {28.723, 197.176}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{28.723, 192.227}, {
                    27.531000000000002`, 191.164}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{28.723, 192.227}, {
                    27.531000000000002`, 191.164}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{29.516000000000002`, 
                    192.227}, {28.324, 191.164}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{29.516000000000002`, 
                    192.227}, {28.324, 191.164}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{30.309, 192.227}, {
                    29.117000000000004`, 191.164}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{30.309, 192.227}, {
                    29.117000000000004`, 191.164}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{31.102, 192.227}, {29.91,
                     191.164}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{31.102, 192.227}, {29.91,
                     191.164}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{31.895, 192.227}, {
                    30.703, 191.164}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{31.895, 192.227}, {
                    30.703, 191.164}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{32.688, 192.227}, {
                    31.496, 191.164}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{32.688, 192.227}, {
                    31.496, 191.164}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{33.48, 192.227}, {32.289,
                     191.164}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{33.48, 192.227}, {32.289,
                     191.164}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{34.273, 192.227}, {
                    33.086, 191.164}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{34.273, 192.227}, {
                    33.086, 191.164}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{35.066, 192.227}, {
                    33.879, 191.164}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{35.066, 192.227}, {
                    33.879, 191.164}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{35.858999999999995`, 
                    192.227}, {34.672000000000004`, 191.164}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{35.858999999999995`, 
                    192.227}, {34.672000000000004`, 191.164}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{36.652, 192.227}, {
                    35.465, 191.164}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{36.652, 192.227}, {
                    35.465, 191.164}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{37.445, 192.227}, {
                    36.258, 191.164}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{37.445, 192.227}, {
                    36.258, 191.164}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{34.273, 192.227}, {
                    33.086, 191.164}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{34.273, 192.227}, {
                    33.086, 191.164}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{38.23800000000001, 
                    192.227}, {37.050999999999995`, 191.164}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{38.23800000000001, 
                    192.227}, {37.050999999999995`, 191.164}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{39.031, 192.227}, {
                    37.843999999999994`, 191.164}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{39.031, 192.227}, {
                    37.843999999999994`, 191.164}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{39.828, 192.227}, {
                    38.637, 191.164}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{39.828, 192.227}, {
                    38.637, 191.164}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{40.621, 192.227}, {39.43,
                     191.164}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{40.621, 192.227}, {39.43,
                     191.164}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{39.43, 192.227}, {40.621,
                     191.164}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{39.43, 192.227}, {40.621,
                     191.164}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{38.637, 192.227}, {
                    39.828, 191.164}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{38.637, 192.227}, {
                    39.828, 191.164}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{37.843999999999994`, 
                    192.227}, {39.031, 191.164}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{37.843999999999994`, 
                    192.227}, {39.031, 191.164}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{37.050999999999995`, 
                    192.227}, {38.23800000000001, 191.164}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{37.050999999999995`, 
                    192.227}, {38.23800000000001, 191.164}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{36.258, 192.227}, {
                    37.445, 191.164}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{36.258, 192.227}, {
                    37.445, 191.164}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{35.465, 192.227}, {
                    36.652, 191.164}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{35.465, 192.227}, {
                    36.652, 191.164}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{34.672000000000004`, 
                    192.227}, {35.858999999999995`, 191.164}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{34.672000000000004`, 
                    192.227}, {35.858999999999995`, 191.164}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{33.879, 192.227}, {
                    35.066, 191.164}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{33.879, 192.227}, {
                    35.066, 191.164}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{33.086, 192.227}, {
                    34.273, 191.164}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{33.086, 192.227}, {
                    34.273, 191.164}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{32.289, 192.227}, {33.48,
                     191.164}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{32.289, 192.227}, {33.48,
                     191.164}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{31.496, 192.227}, {
                    32.688, 191.164}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{31.496, 192.227}, {
                    32.688, 191.164}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{30.703, 192.227}, {
                    31.895, 191.164}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{30.703, 192.227}, {
                    31.895, 191.164}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{33.879, 192.227}, {
                    35.066, 191.164}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{33.879, 192.227}, {
                    35.066, 191.164}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{29.91, 192.227}, {31.102,
                     191.164}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{29.91, 192.227}, {31.102,
                     191.164}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{29.117000000000004`, 
                    192.227}, {30.309, 191.164}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{29.117000000000004`, 
                    192.227}, {30.309, 191.164}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{28.324, 192.227}, {
                    29.516000000000002`, 191.164}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{28.324, 192.227}, {
                    29.516000000000002`, 191.164}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{27.531000000000002`, 
                    192.227}, {28.723, 191.164}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{27.531000000000002`, 
                    192.227}, {28.723, 191.164}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    92.371, 198.945}, {79.477, 198.945}, {78.766, 198.945}, {
                    78.191, 198.406}, {78.191, 197.738}, {78.191, 191.664}, {
                    78.191, 190.996}, {78.766, 190.45700000000002`}, {79.477, 
                    190.45700000000002`}, {92.371, 190.45700000000002`}, {
                    93.086, 190.45700000000002`}, {93.66, 190.996}, {93.66, 
                    191.664}, {93.66, 197.738}, {93.66, 198.406}, {93.086, 
                    198.945}, {92.371, 198.945}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002951354166666667], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    92.371, 198.945}, {79.477, 198.945}, {78.766, 198.945}, {
                    78.191, 198.406}, {78.191, 197.738}, {78.191, 191.664}, {
                    78.191, 190.996}, {78.766, 190.457}, {79.477, 190.457}, {
                    92.371, 190.457}, {93.086, 190.457}, {93.66, 190.996}, {
                    93.66, 191.664}, {93.66, 197.738}, {93.66, 198.406}, {
                    93.086, 198.945}, {92.371, 198.945}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    92.043, 198.594}, {79.809, 198.594}, {79.133, 198.594}, {
                    78.586, 198.098}, {78.586, 197.48800000000003`}, {78.586, 
                    191.918}, {78.586, 191.305}, {79.133, 190.812}, {79.809, 
                    190.812}, {92.043, 190.812}, {92.71900000000001, 
                    190.812}, {93.262, 191.305}, {93.262, 191.918}, {93.262, 
                    197.48800000000003`}, {93.262, 198.098}, {
                    92.71900000000001, 198.594}, {92.043, 
                    198.594}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752291666666667], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    92.043, 198.594}, {79.809, 198.594}, {79.133, 198.594}, {
                    78.586, 198.098}, {78.586, 197.488}, {78.586, 191.918}, {
                    78.586, 191.305}, {79.133, 190.812}, {79.809, 190.812}, {
                    92.043, 190.812}, {92.71900000000001, 190.812}, {93.262, 
                    191.305}, {93.262, 191.918}, {93.262, 197.488}, {93.262, 
                    198.098}, {92.71900000000001, 198.594}, {92.043, 
                    198.594}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIFIGYC4sqXaoYcc0Id4nZ58jD1ZziIrHN/WJUT6sB1
fXGBbV+Gw0Wl2z/rskIdijImvq1pznDYNPf98mPOoQ7CzQdOLazMcNC/q8LW
qBrqcPPc9+DHrRkOIY+Xzj7CEOrAAAI1GQ6qbI1TnZVDHUDa7QszHGbkCTUf
kAp1APJM45IyHIpBEu9DIOqSEfwJh75qxPhnOLh05zz/LRjqcNzbvNMxAGGe
bFSK9X3nDAdRkHv/hDh804jpP2SKMJ8b5H6tDIi/rEMdtpwo2zffDOEfsPsN
MxyOgczNCIXYK5/hAAsPsH9koeoXhULs1c+A2HM21GHVx0u+SRZQ/z+Fukc7
w8EZ5F7OMIdFrts+/zWBhueXUAenhKcXlIDuBVnryhfmAAomBZ8Mh3iQ+4wR
fHA4mYZB7EnNcOidDvSQAFQ+JcNBrvV14I5v0PgqznAA+WaPSBjEnXUZDntL
JkuwvAt1sAJ5uBsafhdDIe5pQPgH7O+WDAcAOIfkoA==
                    
                    "]]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.00017376208333333334`], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIFIGYC4sqXaoYcc0Id4nZ58jD1ZziIrHN/WJUT6sB1
fXGBbV+Gw0Wl2z/rskIdijMmvq1pznDYNPf98mPOoQ5CzQdOLazMcNC/q8LW
qBrqcPPc9+DHrRkOIY+Xzj7CEOrAAAI1GQ6qbI1TnZVDHUDa7QszHGbkAXVK
hTq8q7E3jUvKgJj7PgSiLhnB7z/0VSPGP8PBpTvn+W/BUIdj3uadjgEI82Sj
UqzvO2c4iILc+yfE4ZtGTP8hU4T5YPdrZUD8ZR3qsOVE2b75Zgj/gN1vmAEx
NwPqP/kMB1h4gP0jC1W/KBRir34GxJ6zoQ6rPl7yTbKA+v9pqIMMyD3aGQ7O
IPdyhjksct32+a8JNDy/hDo4JTy9oAR0L8haV74wB1AwKfhkOMSD3GeM4IPD
yTQMYk9qhkPvdKCHBMIcnoDkUzIc5FpfB+74Bo2v4gwHkG/2iIRB3FmX4bC3
ZLIEy7tQB0uQh7uh4XcxFOKeBoR/joP83ZLhAAA0r+Sd
                    "], 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{85.398, 194.79299999999998`}, {85.398, 
                    194.406}, {85.766, 194.094}, {86.215, 194.094}, {86.664, 
                    194.094}, {87.027, 194.406}, {87.027, 
                    194.79299999999998`}, {87.027, 195.176}, {86.664, 
                    195.48800000000003`}, {86.215, 195.48800000000003`}, {
                    85.766, 195.48800000000003`}, {85.398, 195.176}, {85.398, 
                    194.79299999999998`}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.00018712128065294733`], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{85.398, 194.79308092799997`}, {85.398, 
                    194.40591648}, {85.766, 194.093901888}, {86.215, 
                    194.093901888}, {86.664, 194.093901888}, {87.027, 
                    194.40591648}, {87.027, 194.79308092799997`}, {87.027, 
                    195.175489056}, {86.664, 195.488454912}, {86.215, 
                    195.488454912}, {85.766, 195.488454912}, {85.398, 
                    195.175489056}, {85.398, 194.79308092799997`}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{91.277, 
                    198.23399999999998`}, {92.46900000000001, 
                    197.176}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{91.277, 
                    198.23399999999998`}, {92.46900000000001, 197.176}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{90.48400000000001, 
                    198.23399999999998`}, {91.67599999999999, 
                    197.176}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{90.48400000000001, 
                    198.23399999999998`}, {91.67599999999999, 197.176}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{89.691, 
                    198.23399999999998`}, {90.883, 197.176}}}]}}}}}}}, {{{{{{{
                    
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{89.691, 
                    198.23399999999998`}, {90.883, 197.176}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{88.898, 
                    198.23399999999998`}, {90.09, 197.176}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{88.898, 
                    198.23399999999998`}, {90.09, 197.176}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{88.10499999999999, 
                    198.23399999999998`}, {89.29700000000001, 
                    197.176}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{88.10499999999999, 
                    198.23399999999998`}, {89.29700000000001, 197.176}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{87.312, 
                    198.23399999999998`}, {88.504, 197.176}}}]}}}}}}}, {{{{{{{
                    
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{87.312, 
                    198.23399999999998`}, {88.504, 197.176}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{86.52, 
                    198.23399999999998`}, {87.71100000000001, 
                    197.176}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{86.52, 
                    198.23399999999998`}, {87.71100000000001, 197.176}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{85.727, 
                    198.23399999999998`}, {86.91400000000002, 
                    197.176}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{85.727, 
                    198.23399999999998`}, {86.91400000000002, 197.176}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{84.93400000000001, 
                    198.23399999999998`}, {86.121, 197.176}}}]}}}}}}}, {{{{{{{
                    
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{84.93400000000001, 
                    198.23399999999998`}, {86.121, 197.176}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{84.141, 
                    198.23399999999998`}, {85.32799999999999, 
                    197.176}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{84.141, 
                    198.23399999999998`}, {85.32799999999999, 197.176}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{83.348, 
                    198.23399999999998`}, {84.535, 197.176}}}]}}}}}}}, {{{{{{{
                    
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{83.348, 
                    198.23399999999998`}, {84.535, 197.176}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{82.55499999999999, 
                    198.23399999999998`}, {83.742, 197.176}}}]}}}}}}}, {{{{{{{
                    
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{82.55499999999999, 
                    198.23399999999998`}, {83.742, 197.176}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{85.727, 
                    198.23399999999998`}, {86.91400000000002, 
                    197.176}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{85.727, 
                    198.23399999999998`}, {86.91400000000002, 197.176}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{81.762, 
                    198.23399999999998`}, {82.94900000000001, 
                    197.176}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{81.762, 
                    198.23399999999998`}, {82.94900000000001, 197.176}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{80.96900000000001, 
                    198.23399999999998`}, {82.15599999999999, 
                    197.176}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{80.96900000000001, 
                    198.23399999999998`}, {82.15599999999999, 197.176}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{80.17199999999998, 
                    198.23399999999998`}, {81.363, 197.176}}}]}}}}}}}, {{{{{{{
                    
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{80.17199999999998, 
                    198.23399999999998`}, {81.363, 197.176}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{79.37899999999999, 
                    198.23399999999998`}, {80.57, 197.176}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{79.37899999999999, 
                    198.23399999999998`}, {80.57, 197.176}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{80.57, 
                    198.23399999999998`}, {79.37899999999999, 
                    197.176}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{80.57, 
                    198.23399999999998`}, {79.37899999999999, 197.176}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{81.363, 
                    198.23399999999998`}, {80.17199999999998, 
                    197.176}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{81.363, 
                    198.23399999999998`}, {80.17199999999998, 197.176}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{82.15599999999999, 
                    198.23399999999998`}, {80.96900000000001, 
                    197.176}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{82.15599999999999, 
                    198.23399999999998`}, {80.96900000000001, 197.176}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{82.94900000000001, 
                    198.23399999999998`}, {81.762, 197.176}}}]}}}}}}}, {{{{{{{
                    
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{82.94900000000001, 
                    198.23399999999998`}, {81.762, 197.176}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{83.742, 
                    198.23399999999998`}, {82.55499999999999, 
                    197.176}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{83.742, 
                    198.23399999999998`}, {82.55499999999999, 197.176}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{84.535, 
                    198.23399999999998`}, {83.348, 197.176}}}]}}}}}}}, {{{{{{{
                    
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{84.535, 
                    198.23399999999998`}, {83.348, 197.176}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{85.32799999999999, 
                    198.23399999999998`}, {84.141, 197.176}}}]}}}}}}}, {{{{{{{
                    
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{85.32799999999999, 
                    198.23399999999998`}, {84.141, 197.176}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{86.121, 
                    198.23399999999998`}, {84.93400000000001, 
                    197.176}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{86.121, 
                    198.23399999999998`}, {84.93400000000001, 197.176}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{86.91400000000002, 
                    198.23399999999998`}, {85.727, 197.176}}}]}}}}}}}, {{{{{{{
                    
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{86.91400000000002, 
                    198.23399999999998`}, {85.727, 197.176}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{87.71100000000001, 
                    198.23399999999998`}, {86.52, 197.176}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{87.71100000000001, 
                    198.23399999999998`}, {86.52, 197.176}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{88.504, 
                    198.23399999999998`}, {87.312, 197.176}}}]}}}}}}}, {{{{{{{
                    
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{88.504, 
                    198.23399999999998`}, {87.312, 197.176}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{89.29700000000001, 
                    198.23399999999998`}, {88.10499999999999, 
                    197.176}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{89.29700000000001, 
                    198.23399999999998`}, {88.10499999999999, 197.176}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{86.121, 
                    198.23399999999998`}, {84.93400000000001, 
                    197.176}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{86.121, 
                    198.23399999999998`}, {84.93400000000001, 197.176}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{90.09, 
                    198.23399999999998`}, {88.898, 197.176}}}]}}}}}}}, {{{{{{{
                    
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{90.09, 
                    198.23399999999998`}, {88.898, 197.176}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{90.883, 
                    198.23399999999998`}, {89.691, 197.176}}}]}}}}}}}, {{{{{{{
                    
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{90.883, 
                    198.23399999999998`}, {89.691, 197.176}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{91.67599999999999, 
                    198.23399999999998`}, {90.48400000000001, 
                    197.176}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{91.67599999999999, 
                    198.23399999999998`}, {90.48400000000001, 197.176}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{92.46900000000001, 
                    198.23399999999998`}, {91.277, 197.176}}}]}}}}}}}, {{{{{{{
                    
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{92.46900000000001, 
                    198.23399999999998`}, {91.277, 197.176}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{91.277, 192.227}, {
                    92.46900000000001, 191.164}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{91.277, 192.227}, {
                    92.46900000000001, 191.164}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{90.48400000000001, 
                    192.227}, {91.67599999999999, 191.164}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{90.48400000000001, 
                    192.227}, {91.67599999999999, 191.164}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{89.691, 192.227}, {
                    90.883, 191.164}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{89.691, 192.227}, {
                    90.883, 191.164}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{88.898, 192.227}, {90.09,
                     191.164}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{88.898, 192.227}, {90.09,
                     191.164}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{88.10499999999999, 
                    192.227}, {89.29700000000001, 191.164}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{88.10499999999999, 
                    192.227}, {89.29700000000001, 191.164}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{87.312, 192.227}, {
                    88.504, 191.164}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{87.312, 192.227}, {
                    88.504, 191.164}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{86.52, 192.227}, {
                    87.71100000000001, 191.164}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{86.52, 192.227}, {
                    87.71100000000001, 191.164}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{85.727, 192.227}, {
                    86.91400000000002, 191.164}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{85.727, 192.227}, {
                    86.91400000000002, 191.164}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{84.93400000000001, 
                    192.227}, {86.121, 191.164}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{84.93400000000001, 
                    192.227}, {86.121, 191.164}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{84.141, 192.227}, {
                    85.32799999999999, 191.164}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{84.141, 192.227}, {
                    85.32799999999999, 191.164}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{83.348, 192.227}, {
                    84.535, 191.164}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{83.348, 192.227}, {
                    84.535, 191.164}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{82.55499999999999, 
                    192.227}, {83.742, 191.164}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{82.55499999999999, 
                    192.227}, {83.742, 191.164}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{85.727, 192.227}, {
                    86.91400000000002, 191.164}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{85.727, 192.227}, {
                    86.91400000000002, 191.164}}}, CurveClosed -> {0}]}}}}}}},
                     {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{81.762, 192.227}, {
                    82.94900000000001, 191.164}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{81.762, 192.227}, {
                    82.94900000000001, 191.164}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{80.96900000000001, 
                    192.227}, {82.15599999999999, 191.164}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{80.96900000000001, 
                    192.227}, {82.15599999999999, 191.164}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{80.17199999999998, 
                    192.227}, {81.363, 191.164}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{80.17199999999998, 
                    192.227}, {81.363, 191.164}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{79.37899999999999, 
                    192.227}, {80.57, 191.164}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{79.37899999999999, 
                    192.227}, {80.57, 191.164}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{80.57, 192.227}, {
                    79.37899999999999, 191.164}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{80.57, 192.227}, {
                    79.37899999999999, 191.164}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{81.363, 192.227}, {
                    80.17199999999998, 191.164}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{81.363, 192.227}, {
                    80.17199999999998, 191.164}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{82.15599999999999, 
                    192.227}, {80.96900000000001, 191.164}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{82.15599999999999, 
                    192.227}, {80.96900000000001, 191.164}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{82.94900000000001, 
                    192.227}, {81.762, 191.164}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{82.94900000000001, 
                    192.227}, {81.762, 191.164}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{83.742, 192.227}, {
                    82.55499999999999, 191.164}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{83.742, 192.227}, {
                    82.55499999999999, 191.164}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{84.535, 192.227}, {
                    83.348, 191.164}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{84.535, 192.227}, {
                    83.348, 191.164}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{85.32799999999999, 
                    192.227}, {84.141, 191.164}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{85.32799999999999, 
                    192.227}, {84.141, 191.164}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{86.121, 192.227}, {
                    84.93400000000001, 191.164}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{86.121, 192.227}, {
                    84.93400000000001, 191.164}}}, CurveClosed -> {0}]}}}}}}},
                     {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{86.91400000000002, 
                    192.227}, {85.727, 191.164}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{86.91400000000002, 
                    192.227}, {85.727, 191.164}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{87.71100000000001, 
                    192.227}, {86.52, 191.164}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{87.71100000000001, 
                    192.227}, {86.52, 191.164}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{88.504, 192.227}, {
                    87.312, 191.164}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{88.504, 192.227}, {
                    87.312, 191.164}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{89.29700000000001, 
                    192.227}, {88.10499999999999, 191.164}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{89.29700000000001, 
                    192.227}, {88.10499999999999, 191.164}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{86.121, 192.227}, {
                    84.93400000000001, 191.164}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{86.121, 192.227}, {
                    84.93400000000001, 191.164}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{90.09, 192.227}, {88.898,
                     191.164}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{90.09, 192.227}, {88.898,
                     191.164}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{90.883, 192.227}, {
                    89.691, 191.164}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{90.883, 192.227}, {
                    89.691, 191.164}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{91.67599999999999, 
                    192.227}, {90.48400000000001, 191.164}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{91.67599999999999, 
                    192.227}, {90.48400000000001, 191.164}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{92.46900000000001, 
                    192.227}, {91.277, 191.164}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{92.46900000000001, 
                    192.227}, {91.277, 191.164}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{50.605000000000004`, 181.15200000000002`}, {
                    31.359, 162.33200000000002`}, {23.148, 159.953}, {27., 
                    158.43800000000002`}, {30.855, 156.92200000000003`}, {
                    43.246, 166.63299999999998`}, {56.145, 179.535}, {69.039, 
                    192.43800000000002`}, {76.938, 203.918}, {73.086, 
                    205.434}, {69.23, 206.953}, {71.07, 201.172}, {
                    50.605000000000004`, 
                    181.15200000000002`}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0004413333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{50.605000000000004`, 181.152}, {31.359, 
                    162.332}, {23.148, 159.95299999999997`}, {27., 158.438}, {
                    30.855, 156.92200000000003`}, {43.246, 
                    166.63299999999998`}, {56.145, 179.535}, {69.039, 
                    192.438}, {76.938, 203.918}, {73.086, 205.434}, {69.23, 
                    206.953}, {71.07, 201.172}, {50.605000000000004`, 
                    181.152}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    34.402, 167.477}, {41.145, 165.707}, {34.800999999999995`,
                     159.695}, {27.66, 157.21899999999997`}, {25.68, 
                    158.281}, {23.695, 159.34}, {29.246, 161.816}, {34.402, 
                    167.477}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    34.402, 167.477}, {41.145, 165.707}, {34.800999999999995`,
                     159.695}, {27.66, 157.219}, {25.68, 158.281}, {23.695, 
                    159.34}, {29.246, 161.816}, {34.402, 167.477}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    34.402, 166.76999999999998`}, {39.956999999999994`, 
                    165.35200000000003`}, {33.773, 159.57}, {27.66, 157.93}, {
                    26.078, 158.63299999999998`}, {24.487999999999996`, 
                    159.34}, {29.379, 161.32800000000003`}, {34.402, 
                    166.76999999999998`}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    34.402, 166.76999999999998`}, {39.956999999999994`, 
                    165.352}, {33.773, 159.57}, {27.66, 157.93}, {26.078, 
                    158.63299999999998`}, {24.487999999999996`, 159.34}, {
                    29.379, 161.32800000000003`}, {34.402, 
                    166.76999999999998`}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJ5IGYC4qcXlG7/7PN2UGVrnOq8P81higRLGF+vt8Nx
b/NOxz1pDtcXF9hytXs79B/6qhGzPs3BNG6XJ0+TtwMXSGIVgu+UADRpcZrD
M5B5dd4O3zRi+g/NTXOofKlmyFHj7fB46ewjCjPSHH7VZe0pKYbaNznNYaHr
ts9/S7wdZuQJNR/og6qP8XbYN19K/25PmsObwB1yrd7eDiBrmNrTHHqnAxU6
eDvo31Vha2xNc3Dpznn+WxNqf3Oaw0WQ9VJQ+xrSHHKf/175kcnbofU10KBa
qPwrL4h9VWkOK44BPXrRy2HVx0u+SRVpDmDn7/KC6K+A+meel4MPMDgSKtMc
5hxR2FDU4eUAVJW1pybNQRPoza8VXg4gYxyB9gFdqd2e5gV3jxnI4UleDkUZ
E9/WAN1/GuThWC8HdUOONTJA/27//PdKRaSXw7sae9O4SVD/JXg57CmZLMEC
lDcA+TMV6t42hPlg9wLtaxe7ee57MsJ9MPPA8VOW5mAHYvh6OSwChXNBmgMA
EdfgEA==
                    "], CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJNIGYCYoO7KmyNS70chJoPnFqYmObwqy5rT8liLweX
7pznv4H8lce8zTsXejlcVLr9sy4pzeHZBSBjnpeDU8LTC0rJaQ6nFrpu+7zW
y8Fyy4myffFpDny6m+a+X+7lkDHxbY09UL8+yPxWL4dvGjH9h1LTHGy5ri8u
yPVyKAAxMqD2BXs5qBtyrJHJgvKNvRz6D33ViMlOc3gTuEOu9bYnnL/t898r
FTsR/MNAqn+RpwPIWNssqHynJ9z8T5d8kwQqPB0KQfyUNIcpEixhfLGeDu9q
7E3jgP6J2+XJw+Tt6VAtss79YVyaQ4r1ff9ec08HmSggKzrN4SnIv3qeDr3T
84SaI9IcFgG9+1fF08EK5N9gqHuFPR1kQer90xz4Qf5n94SEn2eaw+wjChuK
fnhA7HFPc1gOCs+PHhD3OKQ55D7/vfLjIw+HffOl9O8C+VrAYPp6wwNiv3Wa
A8hbXN89IP61hrqHzxMSH1ZpDqdB4S8L9Y9ZmoMmSL8FNHyMEe7xMe90TLCE
xt8/hPlgd770gMSXLdR/TzwcZgC9e8AuzWFPyWQJlmMIPjh8V3o4AG3P2uMA
Dd8ZHhB9NmkOIOPrqhDmg9VnekDiH2i/KDCYq1I8HFpfAyMWyI8AJRw/BB8A
wZYvwA==
                    "], CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJVIGYCYmn9uypsgZ4OlltOlO2TTnNoF7t57ruzp0MY
n+6muUC+Zkz/oa8cng4ZE9/W2EumOZjG7fLk+eQBVz/niMKGohseEHlZqPoT
Hg6rPl7yTVJIc9j2+e+Vip0eDkLNB04tVE1zWH7M27xzo4eDj3mnY4ImQr5a
ZJ37QzkE/12NvWmcVJrD9cUFtlzbPRzUDTnWyAilObwO3CHXutrDwaU75/lv
wTQIPRNqH0+aQ4r1ff/edg8HoC+CH3NC/VMM1c+W5rASZH+ih8OTpbOPKLCk
OawA8QM9HBa5Am1mSHM4tRDIsPVwAHmT6X+qw2yQ/zSg8n9SHQyAwdUo6uHg
lPD0gtLvVIdnF5Ru//zn7tAKctjPVIciUEC8d4fY9y3V4SJQuu6Wu0MVyH+f
Uh3YG6c6d99xd5iRBwyRd6kOfdOBjAvukPB5mepw+KtGTP8ldweQ8IFHqRD/
XHeHhM+9VEj4vHSH2HM71aEXpPADVP5aKsQ/jB4OaiD7L6U6FIPU8UP9cz7V
IRIUcXIeDsBQvb74RKoDAwgYQOPnaCokPjk8HGSjgDYfTnXIff575cdP7g7f
gM46dBDqnudQ+w8j3A9TDwDzNBH1
                    "], 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIpIGYC4l91WXtKDrs7qBtyrJHZlerQLnbz3PfN7g7V
IuvcHwL5kyVYwvhq3R3idnnyMO1PdVjkuu3z3xR3CH0g1WEKSJ4Xwb+odPtn
3Ss3h97peULNB6DmPXZz4Lq+uMB2X6oDiOI67uZQlDHxbc3uVAeQNVVb3BxU
2RqnOm9PdeDT3TT3/XI3h1UfL/kmbUl1iLDccqKsz80BaNiphRtTHaT176qw
Nbo5AE0Nfrw21QHoKu32NKj+5akOlS/VDDlioPYtSnUQBZkfAtU/N9WhGGSv
v5uDU8LTC0rTEfzHS2cfUZiQ6gAKG4YAKL8j1WH7579XKiLdHICu2De/DWH+
hENfNWLqUx3A4Zfs5gB2ViXUvXluDiBjGEpSHUxBAdfk5jADFBx5UPe0uDns
my+lfzcH6v42qH9zEP6VjUqxvp+d6gAAl/y3aw==
                    "], 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    RGBColor[0.8588240000000001, 0.08627450000000002, 
                    0.105882], 
                    Thickness[0.0002752354166666667], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxVU2lIVUEUfmqYiFlIRYU/TErFFn1Zlpr1lTO3LMVKEgspE0+JmVsSFSJI
gYhoRYZChKhECyEhYRBPkQjbKEwMWwgJNQsSM8EWM5p5c56XfgzcM+dw5tvu
8pyifeTjcDi81IE63uoMtBYn+jdYCDrX/az5AGFR246PZ+vtOjPu3pNTdRZc
ZZeXzMkgtMiOyZnzFg49SA7wTicsi/qwwrfEwtuXP9KHUnm+0EK0uq5U9cm8
S2PlaXb9uyLfVRZjYSoi68JDVe8K8F5VFWth6PrVRyF7CCdGp29NhFp4o/ft
JdyfnOk/vdRCysbqbdn7Cc+bFYB5Fnp2q4tM3udjoatJIcki+FZeSar5IxGv
YHQdJnRq3FPSzOcSNIvAMYnGQsXwKPMZlgh3+t0Jzie8Cn3/q+KdRF2DGigg
bNBE+yQyAte0XysidGg8TyVqdb+YkKzx90iDr4Rw5kuY088lDT9Vu3m/llBb
811qPjdhMK12QELDayokKNZ3Sz9LrNTAj5O2xeH4Jo0eedz/KQ0/hf9TrwL4
V0LLuvUI4aYm5mUZvFm8fy7rkWnXHr/+66fYtUrBQOtOe7+bbxKharFydpLx
g/X9Kk0etrC/g6x3AuvZz3rEEearNeOPeT6W+XVLbM8e6Q2NYX3bmV80QT87
foP7UYTvfak5Cxolbk+oj9UEUVMwOl0t0ad9imS9y9mPCII7z8ckgg8qZuGE
uRpvit1351tI+OvBSM6v097vnguRKNW8ojiPQczHyXr4SAxrf9Z7/BEmP7Ee
fbiO9+RLGH6bCfU6fy8EtMwVSj8te3GnMP9PImFEN9qEyWc8v98ijP6bPHqI
WT31v+y4KGb1dOtdJRCm31/HeMrFLJ+Fmn+ZMPlbS/gHDmu4cA==
                    "], 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752354166666667], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}}}, CompressedData["
1:eJxFUltIlEEU/t1i28JCwkRCukhaaiE+SFSYX81EdCMqkIJlEzkDRTeziK0k
sDCrZdWIqKiIsh6KiAqpEJHYpEJBTMLoIiVma7lrubZa2EIz/wz+A+fh48zM
dzlnftmBrWKSZVlJsvJluWTxwN7w+F0OS53FArPzexa4H3FkuasusjwBX9O6
ZFc7x+X9M089zxZYn+zKq+nmqB7c8mxOlsDKae8ayns46kPxRd65AjneulB8
gOPrnaut8zIE1DeBCEfz4Qvpk9MEXshrdTHDlyJQqAgkVrRVUx18SfG5BPzf
sws88n3JjCWPr48TgqrxhaMz8+PfE6M0oaflhlT+izDrwdreY60c7zvGtvVF
CUfV+2aO5Y2vj7QMmv5tjvIiKXyAsH2ZbNSafpggVT+s8HOsLu3vzAyb914H
23ls4BiVNkL9BDu/HJOHxLnKf7pz39ZrcfSpPCRf2801T0aiDF1K/w/z/yeG
g0pPhEArPm8OvmLa70/SPpsYVMxFMUJNmnTWwHBLfpP4TXg6knjrv2LwH8I1
pf8MQ63i/UeIdW0qS/EzbFx6dlVpktB6dzM9D7fAoV3no5U7mc7DY+ZbwrS/
6QI7VD4+pvOZYvZhD5uYjz2vCqb9JwjfbMFM78MYaZ7TDIqmOO7oW1jguZ8x
RFC7aNUz3BuWQmU+7SqfoNHb6+DjqXJwHwgRSVMdYBiqLC70dRPeKLpzxk8H
YZ/c5uGTpt/mYJvvJeE/RYpP9g==
                    "], 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxdVHtoTmEc/nxmtJbksuQWso1iNrlkvvN9zznuNmS0ZmPW/NyHz8h1PsaW
2zbGhkJjYrls5pJcRnJLQojELBZCriMkrbzv+f22E3+cTr/z/t7n97zP87yn
W/rChBlNXS5XE/Wkq8etnvlv/xypyzRxM27QJrOS0FCHPDnoNyqcOrFln1P7
ThMGpF4YHarqyyUd+tao/hXvI2JaZEn/YULz7OKhW/JM9K3pEZx9gNC2YmTt
yjOCv58Qrb8/lv5SwrUfPads/WYic3bhp6wyQplurJN5xwiXluxoHxRhNfLZ
e71rZWaSxTjlhOV6foaFyJgWxzsdlfWNViOfYVsy1AksPOhe/Tug5p39Xv9o
+XkLfkN1KD5aC9d9C0frHo5N303Qx3NXW8y/kHBE86m1+Lx5hNsHhp/9fsnC
5yzfgNTNhIF6Q6mFp/d+TXyVS+hob7T4POsJHyec65KbInzWiX79nLqd1qet
02+vuwU/IHq9MRF75tbSy8sIelvIWxOdk2nIi8VOnb9rQev1swleDVwj/pD4
89xkvGRHf7tOJARrv6oEb6Kcr1zWE4RfjlPb9FaZrF8S8Vy/8Jsues+R/rmS
n3TJwyLpTxO/VxHe3FfGjDNZ/7WEpMEKyGvip4rFVaVnL/X60dOEhi9Rehfo
/a0Ev4AYt5n0Fwr+V2CR5ldE7PszsN47Cfqzv17q7ZI/t4kqnTOFp1QYn99c
+OQQ9ug8vQPrqfjpuLheApp2INCgFxr94vsAhGth10i/H6xLNqGofVBiy6lg
/I2i12Rnv52XOIjOws8SvpmCFw2+TxkEfU2+RILzP1P8bSf8UiUPnYHnvwNz
qyaJvlEyf5LopfDs9yjh7wH7C/F7CKDt8g0mbAjTSQf70J+wWC9MA+IVnbQY
4TMLqNbzohvug+BHy/nHOrXtv+Jj+xcj/49Q4T+QME8b89rH54sl7ByqBLvo
w261/YpX9NvkY/0s4Rvn43yNJBTr/j9e1ite8njKy/jjRM80p879oAwI9/L+
8bLu8uKhXh8j/O8aPG+EzDtmcL9P9Nlh/Ms/x8DrQypJvSUvqw3WM5z4v3HI
4Hx3kfk3DD5fmPhxx+D72ea//hDCCXuw4AeJnl4D29StmdJU9K/1sJ8uwknd
v9eDUkWj3iV6pnig7bjiJti/oygP3x+F9xdVCpwI
                    "], 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{72.562, 
                    198.137}, {81.10499999999999, 212.879}, {86.773, 
                    225.42600000000002`}, {85.21100000000001, 226.141}, {
                    83.65599999999999, 226.859}, {75.465, 215.477}, {66.926, 
                    200.73399999999998`}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.00034917708333333334`], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{72.562, 
                    198.137}, {81.10499999999999, 212.879}, {86.773, 
                    225.426}, {85.21100000000001, 226.141}, {
                    83.65599999999999, 226.859}, {75.465, 215.477}, {66.926, 
                    200.73399999999998`}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{72., 
                    198.395}, {80.23400000000001, 212.617}, {
                    85.91000000000001, 224.625}, {84.66799999999999, 
                    225.19899999999998`}, {83.426, 225.77299999999997`}, {
                    75.727, 214.695}, {67.488, 200.477}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.00030675208333333343`], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{72., 
                    198.39499999999998`}, {80.23400000000001, 212.617}, {
                    85.91000000000001, 224.625}, {84.66799999999999, 
                    225.199}, {83.426, 225.773}, {75.727, 214.695}, {67.488, 
                    200.477}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    70.586, 205.816}, {69.57799999999999, 
                    204.15200000000002`}, {68.52, 202.254}, {67.488, 
                    200.477}, {72., 198.395}, {73.027, 200.176}, {
                    74.15199999999999, 202.047}, {75.09400000000001, 
                    203.738}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0003481479166666667], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    70.586, 205.816}, {69.57799999999999, 204.152}, {68.52, 
                    202.254}, {67.488, 200.477}, {72., 198.39499999999998`}, {
                    73.027, 200.176}, {74.15199999999999, 202.047}, {
                    75.09400000000001, 203.738}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    70.965, 205.242}, {69.965, 203.578}, {69.266, 202.309}, {
                    68.23400000000001, 200.52700000000002`}, {71.617, 
                    198.97299999999998`}, {72.648, 200.75}, {73.406, 
                    201.99200000000002`}, {74.348, 203.684}}}]}}}}}}}, {{{{{{{
                    
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0003481479166666667], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    70.965, 205.242}, {69.965, 203.578}, {69.266, 202.309}, {
                    68.23400000000001, 200.527}, {71.617, 198.973}, {72.648, 
                    200.75}, {73.406, 201.992}, {74.348, 203.684}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    73.418, 203.316}, {71.164, 204.35500000000002`}, {69.16, 
                    200.89800000000002`}, {71.41400000000002, 
                    199.859}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002769611943733424], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    73.417948599, 203.315917393}, {71.16350044599997, 
                    204.35527949000002`}, {69.15984768300001, 
                    200.898620309}, {71.414295836, 199.859258212}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{73.422, 203.316}, {
                    69.164, 200.89800000000002`}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0003481479166666667], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{73.422, 203.316}, {
                    69.164, 200.898}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{71.41400000000002, 
                    199.859}, {71.164, 204.35500000000002`}}}]}}}}}}}, {{{{{{{
                    
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0003481479166666667], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{71.41400000000002, 
                    199.859}, {71.164, 204.355}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{83.613, 220.91}, {
                    81.35499999999999, 221.94899999999998`}}}]}}}}}}}, {{{{{{{
                    
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0003481479166666667], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{83.613, 220.91}, {
                    81.35499999999999, 221.949}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{82.836, 222.934}, {82.91400000000002, 222.625}, {
                    83.262, 222.44899999999998`}, {83.613, 222.539}, {83.965, 
                    222.625}, {84.18799999999999, 222.94899999999998`}, {
                    84.10499999999999, 223.258}, {84.027, 223.562}, {
                    83.67999999999999, 223.742}, {83.32799999999999, 
                    223.65200000000002`}, {82.977, 223.566}, {82.754, 
                    223.242}, {82.836, 222.934}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0004373646025411586], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{82.83573959999997, 222.933795676}, {
                    82.91418599999999, 222.62476281}, {83.26183340000001, 
                    222.448992254}, {83.61338199999999, 222.53949645}, {
                    83.96505909999999, 222.62536242599998`}, {
                    84.18728319999998, 222.94948530200003`}, {84.1058368, 
                    223.25776177800003`}, {84.0275189, 223.56215642400002`}, {
                    83.67974299999999, 223.7425652}, {83.32819439999999, 
                    223.65206100400002`}, {82.97651729999998, 
                    223.566195028}, {82.7542932, 223.24207215200002`}, {
                    82.83573959999997, 222.933795676}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{69.395, 181.15200000000002`}, {88.641, 
                    162.33200000000002`}, {96.85199999999999, 159.953}, {93., 
                    158.43800000000002`}, {89.145, 156.92200000000003`}, {
                    76.754, 166.63299999999998`}, {63.855, 179.535}, {50.961, 
                    192.43800000000002`}, {43.062000000000005`, 203.918}, {
                    46.913999999999994`, 205.434}, {50.77, 206.953}, {48.93, 
                    201.172}, {69.395, 181.15200000000002`}}}]}}}}}}}, {{{{{{{
                    
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0004413333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{69.395, 181.152}, {88.641, 162.332}, {
                    96.85199999999999, 159.95299999999997`}, {93., 158.438}, {
                    89.145, 156.92200000000003`}, {76.754, 
                    166.63299999999998`}, {63.855, 179.535}, {50.961, 
                    192.438}, {43.062000000000005`, 203.918}, {
                    46.913999999999994`, 205.434}, {50.77, 206.953}, {48.93, 
                    201.172}, {69.395, 181.152}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    85.598, 167.477}, {78.85499999999999, 165.707}, {85.199, 
                    159.695}, {92.34, 157.21899999999997`}, {94.32, 
                    158.281}, {96.30499999999999, 159.34}, {90.754, 
                    161.816}, {85.598, 167.477}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    85.598, 167.477}, {78.85499999999999, 165.707}, {85.199, 
                    159.695}, {92.34, 157.219}, {94.32, 158.281}, {
                    96.30499999999999, 159.34}, {90.754, 161.816}, {85.598, 
                    167.477}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    85.598, 166.76999999999998`}, {80.043, 
                    165.35200000000003`}, {86.227, 159.57}, {92.34, 157.93}, {
                    93.922, 158.63299999999998`}, {95.512, 159.34}, {90.621, 
                    161.32800000000003`}, {85.598, 
                    166.76999999999998`}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    85.598, 166.76999999999998`}, {80.043, 165.352}, {86.227, 
                    159.57}, {92.34, 157.93}, {93.922, 158.63299999999998`}, {
                    95.512, 159.34}, {90.621, 161.32800000000003`}, {85.598, 
                    166.76999999999998`}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJ5IGYC4t7peULNFgEOqmyNU533pzls+/z3SoVlgMNx
b/NOxz1pDqLr3B9W2QQ49B/6qhGzPs3h2QWl2z/tAhy4ri8usF2F4DslPL2g
tDjNAWyeQ4DDN42Y/kNz0xxcunOe/3YMcHi8dPYRhRlpDs0HTi10dYPaNznN
Qf+uCluja4DDDKC2A31Q9YEBDvvmS+nf7Ulz4AbZExXgELfLk4epPc3BasuJ
sn3xARB9rWkOsSDxbKj9zWkQc4qg9jWkOXjxMGm31wU4tL4O3CFXm+YAct6B
Lqh9VWkOa2SiUqynBzis+njJN6kCqn8RVH8F1D8bAhx8gMGRUJnmsHnu++XH
dgc43P5Zl7WnJs0BZGzr4QCHY6DwAtoHFj+DcA84fM4FOBRlTHxbA3S/NMjh
FwMc1A051sgA/QsOh8sBDu9q7E3jJkH9dz7AYU/JZAkWoHwmUJv9Wah72xDm
g90LtG8vSN05hPtg5oHjpyzN4WGVyDr3mwEOi1yBMVuQ5gAAXi7g/Q==
                    
                    "], CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    RGBColor[0.8588240000000001, 0.08627450000000002, 
                    0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJNIGYC4syJb2vs1wY4CDUfOLUwMc0BRLmuC3Bw6c55
/hvIXyMTlWK9PsDhotLtn3VJaQ690/OEmjcEODglPL2glJzmIK1/V4VtZYCD
5ZYTZfvi0xwqXqoZcqwJcMgAmQvUDzZ/b4DDN42Y/kOpaQ4Pq0TWuZ8McCiw
5bq+OANq37UAB3WgLpksKP9ZgEP/oa8aMdlpDkBVBbZCgXC+KlvjVGdlBF++
9XXgDr1AiLosqLx1INz8drGb5747BzoUgvgpaQ7bPv+9UhEY6PCuxt40Duif
SyB/RQU6VAOd9TAuzcEvSSDCMiXQAeTt+9FQ/2YEQuiINAcDoHcbcwMdrED+
DYa6tyzQQRak3j/NoRLk/5pASPh5pjlsmvt++bHmQIe4XZ48TO7Q8GyHusch
zcGLh0m7vS/QYd98Kf27QD7QN3Ktk6H2W6c5gJxV1QL1rzXUPRWBkPiwgoZ/
IdQ/ZlD9yVD1xgj3+Jh3OiZYQvU3IMyPBbmrOxASX7ZQ//UGOswAKjtgl+aw
yBUYYnMQfBVQ+K4OdADanrXHARq+mwMh6mzSIOoOIcwHqz8dCIl/oP1g+myg
Ayja5ID8kMdLZx+5geADAA+pGxs=
                    "], 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJVIGYC4uKMiW9rwgMdLLecKNsnneawt2SyBEtcoEMY
n+6muUD+m8Adcq3VgQ4gZfaSaQ5PLyjd/tmGUL9p7vvlxyZD5WWh6mcHOqz6
eMk3SSHNQZWtcarz4kAHoeYDpxaqpjmskYlKsV4e6OBj3umYoImQrxZZ5/5Q
DsF/V2NvGieV5gASrloS6KBuyLFGRijNgev64gLbVYEOLt05z38LpjnE7/Lk
YdoMtY8nzcE/SSDCck+gw81z34Mfc0L9cwyqnw1q//lAhydLZx9RYIHyrwc6
LHLd9vkvQ5qDtP5dFbaHgQ5xIHP/p0L89xoq/ycV4s+vgQ5OCcCQ+J3q0Ds9
T6iZIcih9TXQ4z9THY55Az3GEQSx71uqwwyg9AGhIIcqkEc+pTrUAr21SzAI
Iv4uFRKO4kGQ8HmZ6iAHMkgsyAFk7IFHqQ5+IP+IBEHC516qgwoofLiDHIpA
DrkN1c8Olb+WCvHP/0AHNZD9l6Du+QH1z/lUh5DHQI9/CHQosAWG5IlUh/8g
8BwaP0dTHTaD/Ps70EEWaMz9w6kOQF3a7WxBDt80YvoPHYS6hwdq/2GE+2Hq
AZ/jAt4=
                    "], CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIpIGYC4uYDpxa6ygU5qBtyrJHZleqwt2SyBItakEO1
yDr3h0D+ts9/r1Q4BjnE7fLkYdqf6mBwV4Wt0TfIYZErUOYAVL4SwZ+eJ9R8
oCvIoRfMgJrXF+TAdX1xge2+VAdRoLFVc4IcijImvq3ZnerwTSOm/9DSIAdV
tsapzttTHSpeqgFdEuSw6uMl36QtqQ4hj5fOPrIjyEEI5NCNqQ7FIH37gxxu
nvse/HhtqsPtn3VZe85A9S9PdXDpznn++yLUvkVQ869C9c9NdTjmbd7peCPI
wSnh6QWl6Qg+yBqFCakO/0HgOpTfkQox93KQw5YTZfvmtyHMn3Doq0ZMfaoD
OPzOBTnog8KlEureE0EODCBQkurw7ILS7Z/7ghxmgIIjD+qevUEO++ZL6d/N
SXW4A3L/Hqh/cxD+lY1Ksb6fneoAABBoy4o=
                    "], 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752354166666667], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxVk1tIVVEQho8XzMpCRCXyPGiUillHsyyPmb+ZlKVd9pRomNnBKTFRuyAm
dkB8EAmLiKgIEYkoQnwwuyAqFaXSQ4QEGSYhWtFDRQiFdLG19prYdGDBmT2z
Z83/zb/jfLUWB7lcrgB1oE6gOpE926ca+yxEtDx63lXC+J5YeuHJPSfeP33z
+tOHFgZOX1oWXMRImVwZ0jxooaw/PyyQGKcqL35uGrHw5sUPmi6U+lHL1Kl4
eNfGtpxxJ9Zt8z5Y5h4VT8z5qwZmLOjXYvcydoYFrm79YmFc99vHWBXSfDl3
1kKBalN+gBHjUY3mLNO3WPr9sTDUudwzWco4m72hrD+A4O0brR86zOjKuz/7
O5hMfQVDRa8aFhKu1iiFR0XPEkJCami3u4rN8wjC+SvqTzXj/csVE3PRhKKl
a3o7amWeGEK7ztcx3ur53WTmO8HYdq764884MvpUrPFkR5HRqep3+8KLMyIJ
erzOGkZvx9dbw4vJ9D3OmNe/BWR4VEo+iIw+Nb99r4tM3yOMbvfBisx5y8yr
9O/R/X8Jj2In/rev//IFTlyXtej1jR1Of1tvLmNQ7z1E5gejSfNV/Gw/bGGM
aK7hwjuTodfTHCU8MhhnPsWnhrqlPp217VyuWMLWckU2TfjGi74URoOuT5a8
h9EarZyVRrjzbazQl8xGRyZhTL3mTxLeObKPRIbt5wKCxvIuQfxQ4uTtvRwi
KLV1WUni32NOf1tHLeGkfq7uz9d+rBc9qcLDT5jR+1kv+2kR/6QLnzaJveKv
dtG3Wfx3jaBl+xW/qUY1cReZ7ydL+N8Wf3rle+gR/puEx12Hp+2XBw5Pm/cA
IV7fv070P3b02Pqfif/WMv4C+lG0GA==
                    "], 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752354166666667], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}}}, CompressedData["
1:eJxFUl1IlEEUXbfYNC0sQqIWM8kSrJaIEDfNU9sPaZE5Q/RgIcsdiIgyih5K
BBEVkTKpKIolKkLo78EiRExCw6IHSR+KDB8Wk402tTK1MLG530x+A/Nw5sy9
99xz7+rwqVI1z+PxJOgb0Ner75H2vSnehwIePusVzhxrHqlsEcjyVV8L5Sj0
Z376U3VT4MbJpTUv1ypodLzjqkBt/GBbepZC9PyyJ3uaBS53TWSXrVLg59pG
gc/3b73K8CtUFm452t4g0HH2yvL5aQrpHFhn66UqDL/TBTQODK7xVSe5+DrX
8yqEGk/EpnX8ocUbWiPThOCzN+c6mwT4W9UkzenpvL0iMPidMJld1tQVEfjY
OyWGRgg7Of6OMHFxyz8WqChY+OHeF4Ic0kLbLB8jtEbGWnq6BXaUayUxG9/n
YsePAWHyDBMc/+LWD42d/sfd/07eWQEuk6HrreRGk6TJ89XmXyJxmvV8IxwI
px7O80vT7xgZ3zMlNFtR8JPwgn3cKHF31/PxmV9k5rTZ4t+Ep6x/q8QlNvAv
oT5NOxGS2JfbsL08QRm9xdLMw6fwulgTJdL4kWjnK6Xpb5Ey/mje6WOBQh/r
LpJz83HmtVua/mcIF5mANPswRUZXvgSvVeGEq2/dpsRH/lHCLJ9ciQc/+veH
//uTZ/VGXXxBr1l0gJDMPgQlRnmx3lt/grafXkJRijenfpvl37rYqddD+AcX
9FjD
                    "], CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxdVAtMjlEY/qXFiLnPXCKTy7Bqc1lZeisKUaPvnDUjlte9UTEZ+UlaVKLc
2loqhiGtyczcNRObGWXulyXE3NaINXM55ztPfZtv+/bt/c57nvd5n+c9xzdx
zdwlHV0uVwf1JqrXQ70zvD3GZEcKuhk9aWdYFVNb3OXRkeSQSieW3cedKalm
entv2LNWFV8pHeD/QuVPzU1q+hWG/GNMm0MnJFwIEuT/YrhXRjnTj1Hzd9f4
Ab+MaXnB5/TQvsg/zOST9XHOeS9BqXrhOFPFoHk8uRPqnWI6PO3ct9+frHY+
Z0q+Hr9Zb1GAxj/NFKHr37ZoZGDnikEnmar1+kWrnc+CC6qDUxbdV7Tdqp6f
V8b+iCMWJYeoDMXnr34OWnSyuW52YhGbvELL8C8An92W6TePaaBeKLfoS7pq
NIfpndaj0qInd3/GNWYxrdV9XLVMP5lseNSBzzbo986JbX1anHwb7w/w3Uwr
tF7dBAWfvbX+ShpTn8qoho3eggYrWq/WOvGug6t7ZS5natio/vSEPwx/VGzj
zXP0t2MJv3yBF4f+RmN9LviFOLGtT7gw+sUzBWleUeC3GHpHI38l00w9PzGY
hxQ2ebHwexMb3vHC6L+VyWo8WnxjkTB1lZ5qOnyyVgnS20pzUC8N+PnQZzPy
C7CeLShF89vHVKTgrxVi3g5AnwzEhUxD9Py5BV1at7e/p8KLTewRH5QOPtsx
b7nQU/Fz6WePIG2T2w29Toh2v2y9rwszZ1swX7XC/M9gUtP8YMN94O9gWqj1
qnf2d9W8ngpK0P83gd9L8E0FXhPOUxLThg8jAjt/Emb+l8LfFvBLQL/Ngp63
uldesqDve9S3oFcT5mc6+DfAX4Lfr4XBDWK6rHV6KChf549nqtU87gmapT6L
AsHnjqBnul5A23kAfgD6f+LE9vc9/AvEPLaC/0ScFy9p+guG3j2l8XUKm3tg
sDT6hWMexkkzX1HID5NGr1k4/3HS4MdAz2VObN9H67E/Fn5vlVSn12ey6SsP
9SKh937kh7LxrVi287fP8yFJb5TsQ8ei3zJp9vnhfj0gzXz7wO989NcP95+q
Z5/P3v/ld4GfZcD3hB9VkvbUtIya3xH+1krjpwv5j6XBdUGfD5I0rWseuE++
S3N+FN4/DLG/mg==
                    "], CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{47.438, 
                    198.137}, {38.895, 212.879}, {33.227000000000004`, 
                    225.42600000000002`}, {34.789, 226.141}, {
                    36.343999999999994`, 226.859}, {44.535000000000004`, 
                    215.477}, {53.074, 200.73399999999998`}}}]}}}}}}}, {{{{{{{
                    
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.00034917708333333334`], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{47.438, 
                    198.137}, {38.895, 212.879}, {33.227000000000004`, 
                    225.426}, {34.789, 226.141}, {36.343999999999994`, 
                    226.859}, {44.535000000000004`, 215.477}, {53.074, 
                    200.73399999999998`}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{48., 
                    198.395}, {39.766000000000005`, 212.617}, {34.09, 
                    224.625}, {35.332, 225.19899999999998`}, {36.574, 
                    225.77299999999997`}, {44.273, 214.695}, {52.512, 
                    200.477}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.00030675208333333343`], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{48., 
                    198.39499999999998`}, {39.766000000000005`, 212.617}, {
                    34.09, 224.625}, {35.332, 225.199}, {36.574, 225.773}, {
                    44.273, 214.695}, {52.512, 200.477}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    49.413999999999994`, 205.816}, {50.422000000000004`, 
                    204.15200000000002`}, {51.48, 202.254}, {52.512, 
                    200.477}, {48., 198.395}, {46.973, 200.176}, {45.848, 
                    202.047}, {44.906, 203.738}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0003481479166666667], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    49.413999999999994`, 205.816}, {50.422000000000004`, 
                    204.152}, {51.48, 202.254}, {52.512, 200.477}, {48., 
                    198.39499999999998`}, {46.973, 200.176}, {45.848, 
                    202.047}, {44.906, 203.738}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    49.035000000000004`, 205.242}, {50.035000000000004`, 
                    203.578}, {50.734, 202.309}, {51.766000000000005`, 
                    200.52700000000002`}, {48.382999999999996`, 
                    198.97299999999998`}, {47.352, 200.75}, {46.594, 
                    201.99200000000002`}, {45.652, 203.684}}}]}}}}}}}, {{{{{{{
                    
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0003481479166666667], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    49.035000000000004`, 205.242}, {50.035000000000004`, 
                    203.578}, {50.734, 202.309}, {51.766000000000005`, 
                    200.527}, {48.382999999999996`, 198.973}, {47.352, 
                    200.75}, {46.594, 201.992}, {45.652, 203.684}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    46.582, 203.316}, {48.836, 204.35500000000002`}, {
                    50.839999999999996`, 200.89800000000002`}, {48.586, 
                    199.859}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002769611943733424], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    46.58167737800001, 203.316123686}, {48.83612553100003, 
                    204.355485783}, {50.839778294, 200.898826602}, {
                    48.58533014099999, 199.85946450500003`}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{46.578, 203.316}, {
                    50.836, 200.89800000000002`}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0003481479166666667], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{46.578, 203.316}, {
                    50.836, 200.898}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{48.586, 199.859}, {
                    48.836, 204.35500000000002`}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0003481479166666667], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{48.586, 199.859}, {
                    48.836, 204.355}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{36.38699999999999, 
                    220.91}, {38.645, 221.94899999999998`}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0003481479166666667], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{36.38699999999999, 
                    220.91}, {38.645, 221.949}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{37.164, 222.934}, {37.086, 222.625}, {
                    36.73800000000001, 222.44899999999998`}, {
                    36.38699999999999, 222.539}, {36.035000000000004`, 
                    222.625}, {35.812, 222.94899999999998`}, {35.895, 
                    223.258}, {35.973, 223.562}, {36.32, 223.742}, {
                    36.672000000000004`, 223.65200000000002`}, {37.023, 
                    223.566}, {37.246, 223.242}, {37.164, 
                    222.934}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0004373646025411586], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{37.16445770000001, 222.933479778}, {
                    37.08623700000002, 222.62532413000002`}, {36.7385896, 
                    222.449553574}, {36.3868153, 222.539180552}, {
                    36.03513820000002, 222.625046528}, {35.8129141, 
                    222.949169404}, {35.894360500000005`, 223.25744588}, {
                    35.9729041, 223.562717744}, {36.320454300000016`, 
                    223.74224930200003`}, {36.672228600000004`, 
                    223.652622324}, {37.02390570000001, 223.566756348}, {
                    37.24612980000001, 223.242633472}, {37.16445770000001, 
                    222.933479778}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}}}, {{{54.105000000000004`, 206.016}, {
                    54.105000000000004`, 193.641}, {54.176, 188.977}, {
                    53.266000000000005`, 188.336}, {52.398, 
                    187.65200000000002`}, {28.324, 188.336}, {28.324, 
                    184.80100000000002`}, {28.324, 181.266}, {48.156, 
                    177.727}, {54.105000000000004`, 177.727}, {
                    62.035000000000004`, 177.727}, {66.004, 181.266}, {66.004,
                     188.336}, {66.004, 206.016}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0003178145833333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}}}, {{{54.105000000000004`, 
                    206.01600000000002`}, {54.105000000000004`, 
                    193.64100000000002`}, {54.176, 188.977}, {
                    53.266000000000005`, 188.336}, {52.398, 187.652}, {28.324,
                     188.336}, {28.324, 184.801}, {28.324, 181.266}, {48.156, 
                    177.727}, {54.105000000000004`, 177.727}, {
                    62.035000000000004`, 177.727}, {66.004, 181.266}, {66.004,
                     188.336}, {66.004, 206.01600000000002`}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}}}, {{{54.105000000000004`, 202.48000000000002`}, {
                    54.105000000000004`, 200.71099999999998`}, {58.07, 
                    200.125}, {62.035000000000004`, 200.125}, {66.004, 
                    200.71099999999998`}, {66.004, 202.48000000000002`}, {
                    62.035000000000004`, 201.89100000000002`}, {58.07, 
                    201.89100000000002`}, {54.105000000000004`, 
                    202.48000000000002`}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}}}, {{{54.105000000000004`, 202.48}, {
                    54.105000000000004`, 200.711}, {58.07, 200.125}, {
                    62.035000000000004`, 200.125}, {66.004, 200.711}, {66.004,
                     202.48}, {62.035000000000004`, 201.891}, {58.07, 
                    201.891}, {54.105000000000004`, 202.48}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}}}, {{{54.105000000000004`, 206.016}, {
                    54.105000000000004`, 204.25}, {58.07, 203.66}, {
                    62.035000000000004`, 203.66}, {66.004, 204.25}, {66.004, 
                    206.016}, {62.035000000000004`, 205.42600000000002`}, {
                    58.07, 205.42600000000002`}, {54.105000000000004`, 
                    206.016}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}}}, {{{54.105000000000004`, 206.01600000000002`}, {
                    54.105000000000004`, 204.25}, {58.07, 203.66}, {
                    62.035000000000004`, 203.66}, {66.004, 204.25}, {66.004, 
                    206.01600000000002`}, {62.035000000000004`, 205.426}, {
                    58.07, 205.426}, {54.105000000000004`, 
                    206.01600000000002`}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}}}, {{{54.105000000000004`, 204.25}, {
                    54.105000000000004`, 202.48000000000002`}, {58.07, 
                    201.89100000000002`}, {62.035000000000004`, 
                    201.89100000000002`}, {66.004, 202.48000000000002`}, {
                    66.004, 204.25}, {62.035000000000004`, 203.66}, {58.07, 
                    203.66}, {54.105000000000004`, 204.25}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}}}, {{{54.105000000000004`, 204.25}, {
                    54.105000000000004`, 202.48}, {58.07, 201.891}, {
                    62.035000000000004`, 201.891}, {66.004, 202.48}, {66.004, 
                    204.25}, {62.035000000000004`, 203.66}, {58.07, 203.66}, {
                    54.105000000000004`, 204.25}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}}}, {{{54.105000000000004`, 200.71099999999998`}, {
                    54.105000000000004`, 198.945}, {58.07, 
                    198.35500000000002`}, {62.035000000000004`, 
                    198.35500000000002`}, {66.004, 198.945}, {66.004, 
                    200.71099999999998`}, {62.035000000000004`, 200.125}, {
                    58.07, 200.125}, {54.105000000000004`, 
                    200.71099999999998`}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}}}, {{{54.105000000000004`, 200.711}, {
                    54.105000000000004`, 198.945}, {58.07, 198.355}, {
                    62.035000000000004`, 198.355}, {66.004, 198.945}, {66.004,
                     200.711}, {62.035000000000004`, 200.125}, {58.07, 
                    200.125}, {54.105000000000004`, 200.711}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{55.188, 203.242}, {55.188, 203.031}, {54.945, 
                    202.863}, {54.645, 202.863}, {54.348, 202.863}, {
                    54.105000000000004`, 203.031}, {54.105000000000004`, 
                    203.242}, {54.105000000000004`, 203.453}, {54.348, 
                    203.625}, {54.645, 203.625}, {54.945, 203.625}, {55.188, 
                    203.453}, {55.188, 203.242}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.00027523230299006575`], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{55.188, 203.24234895299998`}, {55.188, 
                    203.03123184700002`}, {54.945, 202.863372589}, {54.645, 
                    202.863372589}, {54.348, 202.863372589}, {
                    54.105000000000004`, 203.03123184700002`}, {
                    54.105000000000004`, 203.24234895299998`}, {
                    54.105000000000004`, 203.45323096200002`}, {54.348, 
                    203.625086869}, {54.645, 203.625086869}, {54.945, 
                    203.625086869}, {55.188, 203.45323096200002`}, {55.188, 
                    203.24234895299998`}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{57.348, 203.055}, {57.348, 202.844}, {
                    57.105000000000004`, 202.672}, {56.809, 202.672}, {56.508,
                     202.672}, {56.266000000000005`, 202.844}, {
                    56.266000000000005`, 203.055}, {56.266000000000005`, 
                    203.262}, {56.508, 203.434}, {56.809, 203.434}, {
                    57.105000000000004`, 203.434}, {57.348, 203.262}, {57.348,
                     203.055}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.00027523230299006575`], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{57.348, 203.054741547}, {57.348, 
                    202.843859538}, {57.105000000000004`, 202.672003631}, {
                    56.809, 202.672003631}, {56.508, 202.672003631}, {
                    56.266000000000005`, 202.843859538}, {56.266000000000005`,
                     203.054741547}, {56.266000000000005`, 203.261862004}, {
                    56.508, 203.43371791100003`}, {56.809, 
                    203.43371791100003`}, {57.105000000000004`, 
                    203.43371791100003`}, {57.348, 203.261862004}, {57.348, 
                    203.054741547}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{59.512, 202.863}, {59.512, 
                    202.65200000000002`}, {59.27, 202.48000000000002`}, {
                    58.973, 202.48000000000002`}, {58.672000000000004`, 
                    202.48000000000002`}, {58.43, 202.65200000000002`}, {
                    58.43, 202.863}, {58.43, 203.07399999999998`}, {
                    58.672000000000004`, 203.242}, {58.973, 203.242}, {59.27, 
                    203.242}, {59.512, 203.07399999999998`}, {59.512, 
                    202.863}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752377784678158], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{59.512, 202.863295456}, {59.512, 
                    202.652414344}, {59.27, 202.48032407200003`}, {58.973, 
                    202.48032407200003`}, {58.672000000000004`, 
                    202.48032407200003`}, {58.43, 202.652414344}, {58.43, 
                    202.863295456}, {58.43, 203.07417656799998`}, {
                    58.672000000000004`, 203.242035112}, {58.973, 
                    203.242035112}, {59.27, 203.242035112}, {59.512, 
                    203.07417656799998`}, {59.512, 202.863295456}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{61.676, 202.863}, {61.676, 
                    202.65200000000002`}, {61.434, 202.48000000000002`}, {
                    61.137, 202.48000000000002`}, {60.836, 
                    202.48000000000002`}, {60.594, 202.65200000000002`}, {
                    60.594, 202.863}, {60.594, 203.07399999999998`}, {60.836, 
                    203.242}, {61.137, 203.242}, {61.434, 203.242}, {61.676, 
                    203.07399999999998`}, {61.676, 202.863}}}]}}}}}}}, {{{{{{{
                    
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752377784678158], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{61.676, 202.863295456}, {61.676, 
                    202.652414344}, {61.434, 202.48032407200003`}, {61.137, 
                    202.48032407200003`}, {60.836, 202.48032407200003`}, {
                    60.594, 202.652414344}, {60.594, 202.863295456}, {60.594, 
                    203.07417656799998`}, {60.836, 203.242035112}, {61.137, 
                    203.242035112}, {61.434, 203.242035112}, {61.676, 
                    203.07417656799998`}, {61.676, 202.863295456}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{63.839999999999996`, 203.055}, {
                    63.839999999999996`, 202.844}, {63.598000000000006`, 
                    202.672}, {63.297000000000004`, 202.672}, {63., 
                    202.672}, {62.758, 202.844}, {62.758, 203.055}, {62.758, 
                    203.262}, {63., 203.434}, {63.297000000000004`, 
                    203.434}, {63.598000000000006`, 203.434}, {
                    63.839999999999996`, 203.262}, {63.839999999999996`, 
                    203.055}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.00027523230299006575`], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{63.839999999999996`, 203.054741547}, {
                    63.839999999999996`, 202.843859538}, {63.598000000000006`,
                     202.672003631}, {63.297000000000004`, 202.672003631}, {
                    63., 202.672003631}, {62.758, 202.843859538}, {62.758, 
                    203.054741547}, {62.758, 203.261862004}, {63., 
                    203.43371791100003`}, {63.297000000000004`, 
                    203.43371791100003`}, {63.598000000000006`, 
                    203.43371791100003`}, {63.839999999999996`, 
                    203.261862004}, {63.839999999999996`, 203.054741547}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{66.004, 203.242}, {66.004, 203.031}, {65.762, 
                    202.863}, {65.46100000000001, 202.863}, {65.164, 
                    202.863}, {64.922, 203.031}, {64.922, 203.242}, {64.922, 
                    203.453}, {65.164, 203.625}, {65.46100000000001, 
                    203.625}, {65.762, 203.625}, {66.004, 203.453}, {66.004, 
                    203.242}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.00027523230299006575`], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{66.004, 203.24234895299998`}, {66.004, 
                    203.03123184700002`}, {65.762, 202.863372589}, {
                    65.46100000000001, 202.863372589}, {65.164, 
                    202.863372589}, {64.922, 203.03123184700002`}, {64.922, 
                    203.24234895299998`}, {64.922, 203.45323096200002`}, {
                    65.164, 203.625086869}, {65.46100000000001, 
                    203.625086869}, {65.762, 203.625086869}, {66.004, 
                    203.45323096200002`}, {66.004, 203.24234895299998`}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{54.105000000000004`, 
                    197.176}, {66.004, 187.629}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{54.105000000000004`, 
                    197.176}, {66.004, 187.62900000000002`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{55.293000000000006`, 
                    197.176}, {66.004, 188.691}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{55.293000000000006`, 
                    197.176}, {66.004, 188.691}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{56.879, 196.824}, {
                    66.004, 189.754}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{56.879, 196.824}, {
                    66.004, 189.754}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{58.07, 196.824}, {66.004,
                     190.812}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{58.07, 196.824}, {66.004,
                     190.812}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{59.26200000000001, 
                    196.824}, {66.004, 191.871}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{59.26200000000001, 
                    196.824}, {66.004, 191.87099999999998`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{60.449, 196.824}, {
                    66.004, 192.934}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{60.449, 196.824}, {
                    66.004, 192.934}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{61.641, 196.824}, {
                    66.004, 193.996}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{61.641, 196.824}, {
                    66.004, 193.996}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{62.828, 196.824}, {
                    66.004, 194.69899999999998`}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{62.828, 196.824}, {
                    66.004, 194.699}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{64.02, 196.824}, {66.004,
                     195.406}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{64.02, 196.824}, {66.004,
                     195.406}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{65.20700000000001, 
                    196.824}, {66.004, 196.117}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{65.20700000000001, 
                    196.824}, {66.004, 196.11700000000002`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{54.105000000000004`, 
                    196.117}, {66.004, 186.566}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{54.105000000000004`, 
                    196.11700000000002`}, {66.004, 186.566}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{66.004, 197.176}, {
                    52.913999999999994`, 186.566}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{66.004, 197.176}, {
                    52.913999999999994`, 186.566}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{64.812, 197.176}, {
                    53.312, 187.984}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{64.812, 197.176}, {
                    53.312, 187.984}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{63.227000000000004`, 
                    196.824}, {54.105000000000004`, 189.754}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{63.227000000000004`, 
                    196.824}, {54.105000000000004`, 189.754}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{62.035000000000004`, 
                    196.824}, {54.105000000000004`, 190.812}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{62.035000000000004`, 
                    196.824}, {54.105000000000004`, 190.812}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{60.848, 196.824}, {
                    54.105000000000004`, 191.871}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{60.848, 196.824}, {
                    54.105000000000004`, 191.87099999999998`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{59.656, 196.824}, {
                    54.105000000000004`, 192.934}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{59.656, 196.824}, {
                    54.105000000000004`, 192.934}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{58.469, 196.824}, {
                    54.105000000000004`, 193.996}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{58.469, 196.824}, {
                    54.105000000000004`, 193.996}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{57.277, 196.824}, {
                    54.105000000000004`, 
                    194.69899999999998`}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{57.277, 196.824}, {
                    54.105000000000004`, 194.699}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{56.09, 196.824}, {
                    54.105000000000004`, 195.406}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{56.09, 196.824}, {
                    54.105000000000004`, 195.406}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{54.895, 196.824}, {
                    54.105000000000004`, 196.117}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{54.895, 196.824}, {
                    54.105000000000004`, 196.11700000000002`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{66.004, 196.117}, {
                    52.913999999999994`, 185.508}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{66.004, 
                    196.11700000000002`}, {52.913999999999994`, 
                    185.50799999999998`}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{66.004, 195.055}, {
                    52.913999999999994`, 
                    184.44899999999998`}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{66.004, 195.055}, {
                    52.913999999999994`, 184.449}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{66.004, 193.996}, {
                    52.913999999999994`, 183.383}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{66.004, 193.996}, {
                    52.913999999999994`, 183.383}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{66.004, 192.934}, {
                    52.913999999999994`, 182.324}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{66.004, 192.934}, {
                    52.913999999999994`, 182.324}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{66.004, 191.871}, {
                    52.913999999999994`, 181.266}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{66.004, 
                    191.87099999999998`}, {52.913999999999994`, 181.266}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{66.004, 190.812}, {
                    52.913999999999994`, 
                    180.20299999999997`}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{66.004, 190.812}, {
                    52.913999999999994`, 180.203}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{66.004, 189.754}, {
                    52.913999999999994`, 
                    179.14499999999998`}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{66.004, 189.754}, {
                    52.913999999999994`, 179.145}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{66.004, 
                    188.68800000000002`}, {52.913999999999994`, 
                    178.078}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{66.004, 188.688}, {
                    52.913999999999994`, 178.078}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{66.004, 187.629}, {
                    53.707, 177.727}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{66.004, 
                    187.62900000000002`}, {53.707, 177.727}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{66.004, 186.566}, {
                    54.895, 177.727}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{66.004, 186.566}, {
                    54.895, 177.727}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{65.60499999999999, 
                    185.15200000000002`}, {56.879, 178.078}}}]}}}}}}}, {{{{{{{
                    
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{65.60499999999999, 
                    185.152}, {56.879, 178.078}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{65.20700000000001, 
                    183.738}, {58.07, 178.078}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{65.20700000000001, 
                    183.738}, {58.07, 178.078}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{64.41400000000002, 
                    181.97299999999998`}, {60.848, 
                    179.14499999999998`}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{64.41400000000002, 
                    181.973}, {60.848, 179.145}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{54.105000000000004`, 
                    195.055}, {65.60499999999999, 185.859}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{54.105000000000004`, 
                    195.055}, {65.60499999999999, 185.859}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{54.105000000000004`, 
                    193.996}, {65.60499999999999, 
                    184.80100000000002`}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{54.105000000000004`, 
                    193.996}, {65.60499999999999, 184.801}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{54.105000000000004`, 
                    192.934}, {65.20700000000001, 184.094}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{54.105000000000004`, 
                    192.934}, {65.20700000000001, 184.094}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{54.105000000000004`, 
                    191.871}, {65.20700000000001, 183.031}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{54.105000000000004`, 
                    191.87099999999998`}, {65.20700000000001, 183.031}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{54.105000000000004`, 
                    190.812}, {64.812, 182.324}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{54.105000000000004`, 
                    190.812}, {64.812, 182.324}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{53.707, 190.105}, {
                    64.41400000000002, 181.617}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{53.707, 190.105}, {
                    64.41400000000002, 181.61700000000002`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{53.707, 
                    189.04299999999998`}, {63.62500000000001, 
                    181.266}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{53.707, 189.043}, {
                    63.62500000000001, 181.266}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{53.312, 188.336}, {
                    63.227000000000004`, 180.555}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{53.312, 188.336}, {
                    63.227000000000004`, 180.555}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{52.913999999999994`, 
                    187.629}, {62.434, 180.20299999999997`}}}]}}}}}}}, {{{{{{{
                    
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{52.913999999999994`, 
                    187.62900000000002`}, {62.434, 180.203}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{52.913999999999994`, 
                    186.566}, {62.035000000000004`, 179.496}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{52.913999999999994`, 
                    186.566}, {62.035000000000004`, 179.496}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{52.913999999999994`, 
                    185.508}, {60.848, 179.14499999999998`}}}]}}}}}}}, {{{{{{{
                    
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{52.913999999999994`, 
                    185.50799999999998`}, {60.848, 179.145}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}}}, {{{54.105000000000004`, 198.945}, {
                    54.105000000000004`, 197.176}, {58.07, 196.59}, {
                    62.035000000000004`, 196.59}, {66.004, 197.176}, {66.004, 
                    198.945}, {62.035000000000004`, 198.35500000000002`}, {
                    58.07, 198.35500000000002`}, {54.105000000000004`, 
                    198.945}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}}}, {{{54.105000000000004`, 198.945}, {
                    54.105000000000004`, 197.176}, {58.07, 196.59}, {
                    62.035000000000004`, 196.59}, {66.004, 197.176}, {66.004, 
                    198.945}, {62.035000000000004`, 198.355}, {58.07, 
                    198.355}, {54.105000000000004`, 198.945}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{52.913999999999994`, 
                    184.44899999999998`}, {60.050999999999995`, 
                    178.789}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{52.913999999999994`, 
                    184.449}, {60.050999999999995`, 178.789}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{52.913999999999994`, 
                    183.383}, {59.26200000000001, 
                    178.43800000000002`}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{52.913999999999994`, 
                    183.383}, {59.26200000000001, 178.438}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{52.913999999999994`, 
                    182.324}, {58.469, 178.078}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{52.913999999999994`, 
                    182.324}, {58.469, 178.078}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{52.913999999999994`, 
                    181.266}, {56.879, 178.078}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{52.913999999999994`, 
                    181.266}, {56.879, 178.078}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{52.913999999999994`, 
                    180.20299999999997`}, {56.09, 177.727}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{52.913999999999994`, 
                    180.203}, {56.09, 177.727}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{52.913999999999994`, 
                    179.14499999999998`}, {54.895, 177.727}}}]}}}}}}}, {{{{{{{
                    
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{52.913999999999994`, 
                    179.145}, {54.895, 177.727}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{55.188, 197.941}, {55.188, 197.73}, {54.945, 
                    197.559}, {54.645, 197.559}, {54.348, 197.559}, {
                    54.105000000000004`, 197.73}, {54.105000000000004`, 
                    197.941}, {54.105000000000004`, 198.148}, {54.348, 
                    198.32000000000002`}, {54.645, 198.32000000000002`}, {
                    54.945, 198.32000000000002`}, {55.188, 198.148}, {55.188, 
                    197.941}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.00027523230299006575`], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{55.188, 197.941381797}, {55.188, 
                    197.730499788}, {54.945, 197.55864388100002`}, {54.645, 
                    197.55864388100002`}, {54.348, 197.55864388100002`}, {
                    54.105000000000004`, 197.730499788}, {54.105000000000004`,
                     197.941381797}, {54.105000000000004`, 198.148502254}, {
                    54.348, 198.320358161}, {54.645, 198.320358161}, {54.945, 
                    198.320358161}, {55.188, 198.148502254}, {55.188, 
                    197.941381797}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{57.348, 197.75}, {57.348, 197.539}, {
                    57.105000000000004`, 197.36700000000002`}, {56.809, 
                    197.36700000000002`}, {56.508, 197.36700000000002`}, {
                    56.266000000000005`, 197.539}, {56.266000000000005`, 
                    197.75}, {56.266000000000005`, 197.961}, {56.508, 
                    198.129}, {56.809, 198.129}, {57.105000000000004`, 
                    198.129}, {57.348, 197.961}, {57.348, 
                    197.75}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.00027523230299006575`], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{57.348, 197.750012839}, {57.348, 
                    197.53913083000003`}, {57.105000000000004`, 
                    197.367274923}, {56.809, 197.367274923}, {56.508, 
                    197.367274923}, {56.266000000000005`, 
                    197.53913083000003`}, {56.266000000000005`, 
                    197.750012839}, {56.266000000000005`, 197.960894848}, {
                    56.508, 198.12898920300003`}, {56.809, 
                    198.12898920300003`}, {57.105000000000004`, 
                    198.12898920300003`}, {57.348, 197.960894848}, {57.348, 
                    197.750012839}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{59.512, 197.559}, {59.512, 197.348}, {59.27, 
                    197.176}, {58.973, 197.176}, {58.672000000000004`, 
                    197.176}, {58.43, 197.348}, {58.43, 197.559}, {58.43, 
                    197.76999999999998`}, {58.672000000000004`, 197.941}, {
                    58.973, 197.941}, {59.27, 197.941}, {59.512, 
                    197.76999999999998`}, {59.512, 197.559}}}]}}}}}}}, {{{{{{{
                    
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752377784678158], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{59.512, 197.55858931199998`}, {59.512, 
                    197.3477082}, {59.27, 197.17561792800004`}, {58.973, 
                    197.17561792800004`}, {58.672000000000004`, 
                    197.17561792800004`}, {58.43, 197.3477082}, {58.43, 
                    197.55858931199998`}, {58.43, 197.76947042400002`}, {
                    58.672000000000004`, 197.94132560000003`}, {58.973, 
                    197.94132560000003`}, {59.27, 197.94132560000003`}, {
                    59.512, 197.76947042400002`}, {59.512, 
                    197.55858931199998`}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{61.676, 197.559}, {61.676, 197.348}, {61.434, 
                    197.176}, {61.137, 197.176}, {60.836, 197.176}, {60.594, 
                    197.348}, {60.594, 197.559}, {60.594, 
                    197.76999999999998`}, {60.836, 197.941}, {61.137, 
                    197.941}, {61.434, 197.941}, {61.676, 
                    197.76999999999998`}, {61.676, 197.559}}}]}}}}}}}, {{{{{{{
                    
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752377784678158], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{61.676, 197.55858931199998`}, {61.676, 
                    197.3477082}, {61.434, 197.17561792800004`}, {61.137, 
                    197.17561792800004`}, {60.836, 197.17561792800004`}, {
                    60.594, 197.3477082}, {60.594, 197.55858931199998`}, {
                    60.594, 197.76947042400002`}, {60.836, 
                    197.94132560000003`}, {61.137, 197.94132560000003`}, {
                    61.434, 197.94132560000003`}, {61.676, 
                    197.76947042400002`}, {61.676, 197.55858931199998`}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{63.839999999999996`, 197.75}, {
                    63.839999999999996`, 197.539}, {63.598000000000006`, 
                    197.36700000000002`}, {63.297000000000004`, 
                    197.36700000000002`}, {63., 197.36700000000002`}, {62.758,
                     197.539}, {62.758, 197.75}, {62.758, 197.961}, {63., 
                    198.129}, {63.297000000000004`, 198.129}, {
                    63.598000000000006`, 198.129}, {63.839999999999996`, 
                    197.961}, {63.839999999999996`, 197.75}}}]}}}}}}}, {{{{{{{
                    
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.00027523230299006575`], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{63.839999999999996`, 197.750012839}, {
                    63.839999999999996`, 197.53913083000003`}, {
                    63.598000000000006`, 197.367274923}, {63.297000000000004`,
                     197.367274923}, {63., 197.367274923}, {62.758, 
                    197.53913083000003`}, {62.758, 197.750012839}, {62.758, 
                    197.960894848}, {63., 198.12898920300003`}, {
                    63.297000000000004`, 198.12898920300003`}, {
                    63.598000000000006`, 198.12898920300003`}, {
                    63.839999999999996`, 197.960894848}, {63.839999999999996`,
                     197.750012839}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{66.004, 197.941}, {66.004, 197.73}, {65.762, 
                    197.559}, {65.46100000000001, 197.559}, {65.164, 
                    197.559}, {64.922, 197.73}, {64.922, 197.941}, {64.922, 
                    198.148}, {65.164, 198.32000000000002`}, {
                    65.46100000000001, 198.32000000000002`}, {65.762, 
                    198.32000000000002`}, {66.004, 198.148}, {66.004, 
                    197.941}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.00027523230299006575`], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{66.004, 197.941381797}, {66.004, 
                    197.730499788}, {65.762, 197.55864388100002`}, {
                    65.46100000000001, 197.55864388100002`}, {65.164, 
                    197.55864388100002`}, {64.922, 197.730499788}, {64.922, 
                    197.941381797}, {64.922, 198.148502254}, {65.164, 
                    198.320358161}, {65.46100000000001, 198.320358161}, {
                    65.762, 198.320358161}, {66.004, 198.148502254}, {66.004, 
                    197.941381797}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{37.050999999999995`, 
                    180.555}, {51.328, 187.984}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{37.050999999999995`, 
                    180.555}, {51.328, 187.984}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{36.258, 180.91}, {
                    49.73800000000001, 187.984}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{36.258, 180.91}, {
                    49.73800000000001, 187.984}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{35.858999999999995`, 
                    181.617}, {48.156, 187.984}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{35.858999999999995`, 
                    181.61700000000002`}, {48.156, 187.984}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{35.465, 182.324}, {
                    46.172000000000004`, 187.984}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{35.465, 182.324}, {
                    46.172000000000004`, 187.984}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{34.672000000000004`, 
                    183.031}, {44.586, 187.984}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{34.672000000000004`, 
                    183.031}, {44.586, 187.984}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{35.066, 184.094}, {
                    41.809, 187.629}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{35.066, 184.094}, {
                    41.809, 187.62900000000002`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{34.672000000000004`, 
                    184.80100000000002`}, {39.828, 187.629}}}]}}}}}}}, {{{{{{{
                    
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{34.672000000000004`, 
                    184.801}, {39.828, 187.62900000000002`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{34.672000000000004`, 
                    185.859}, {38.23800000000001, 187.629}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{34.672000000000004`, 
                    185.859}, {38.23800000000001, 187.62900000000002`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{38.23800000000001, 
                    180.20299999999997`}, {51.723000000000006`, 
                    187.277}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{38.23800000000001, 
                    180.203}, {51.723000000000006`, 187.277}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{39.43, 179.848}, {52.121,
                     186.566}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{39.43, 179.848}, {52.121,
                     186.566}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{40.621, 179.496}, {
                    52.516, 185.859}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{40.621, 179.496}, {
                    52.516, 185.859}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{41.809, 
                    179.14499999999998`}, {51.723000000000006`, 
                    184.44899999999998`}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{41.809, 179.145}, {
                    51.723000000000006`, 184.449}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{43.395, 
                    179.14499999999998`}, {52.121, 183.738}}}]}}}}}}}, {{{{{{{
                    
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{43.395, 179.145}, {
                    52.121, 183.738}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{44.586, 178.789}, {
                    52.121, 182.68}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{44.586, 178.789}, {
                    52.121, 182.68}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{45.777, 
                    178.43800000000002`}, {51.723000000000006`, 
                    181.617}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{45.777, 178.438}, {
                    51.723000000000006`, 181.61700000000002`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{47.358999999999995`, 
                    178.43800000000002`}, {52.121, 180.91}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{47.358999999999995`, 
                    178.438}, {52.121, 180.91}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{48.949, 178.078}, {
                    52.121, 179.848}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{48.949, 178.078}, {
                    52.121, 179.848}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{50.535000000000004`, 
                    178.078}, {52.516, 179.14499999999998`}}}]}}}}}}}, {{{{{{{
                    
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{50.535000000000004`, 
                    178.078}, {52.516, 179.145}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}}}, {{{53.312, 188.336}, {51.328, 188.336}, {
                    50.668000000000006`, 184.80100000000002`}, {
                    50.668000000000006`, 181.266}, {51.328, 177.727}, {53.312,
                     177.727}, {52.648, 181.266}, {52.648, 
                    184.80100000000002`}, {53.312, 188.336}}}]}}}}}}}, {{{{{{{
                    
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}}}, {{{53.312, 188.336}, {51.328, 188.336}, {
                    50.668000000000006`, 184.801}, {50.668000000000006`, 
                    181.266}, {51.328, 177.727}, {53.312, 177.727}, {52.648, 
                    181.266}, {52.648, 184.801}, {53.312, 188.336}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{29.91, 183.383}, {
                    34.672000000000004`, 
                    186.92200000000003`}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{29.91, 183.383}, {
                    34.672000000000004`, 186.922}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{29.91, 185.859}, {
                    34.672000000000004`, 181.617}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{29.91, 185.859}, {
                    34.672000000000004`, 181.61700000000002`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}}}, {{{37.050999999999995`, 187.629}, {
                    34.672000000000004`, 187.277}, {34.141, 185.035}, {34.141,
                     183.15200000000002`}, {34.672000000000004`, 180.91}, {
                    37.050999999999995`, 180.20299999999997`}, {36.52, 
                    182.445}, {36.52, 185.38700000000003`}, {
                    37.050999999999995`, 187.629}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.00019591270833333333`], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}}}, {{{37.050999999999995`, 187.62900000000002`}, {
                    34.672000000000004`, 187.277}, {34.141, 185.035}, {34.141,
                     183.152}, {34.672000000000004`, 180.91}, {
                    37.050999999999995`, 180.203}, {36.52, 182.445}, {36.52, 
                    185.387}, {37.050999999999995`, 187.62900000000002`}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {0, 1, 0}}}, {{{65.988, 205.309}, {65.988, 207.094}, {
                    64.20700000000001, 207.078}, {63.016, 208.137}, {63.016, 
                    209.21499999999997`}, {57.074, 209.19899999999998`}, {
                    57.074, 208.137}, {55.88699999999999, 207.078}, {
                    54.105000000000004`, 207.078}, {54.105000000000004`, 
                    205.309}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0003369062500000001], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {0, 1, 0}}}, {{{65.988, 205.309}, {65.988, 207.094}, {
                    64.20700000000001, 207.078}, {63.016, 208.137}, {63.016, 
                    209.215}, {57.074, 209.199}, {57.074, 208.137}, {
                    55.88699999999999, 207.078}, {54.105000000000004`, 
                    207.078}, {54.105000000000004`, 205.309}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    57.5, 211.32000000000002`}, {62.594, 
                    211.32000000000002`}, {62.594, 209.199}, {57.5, 
                    209.199}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002847395833333333], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    57.5, 211.32}, {62.594, 211.32}, {62.594, 
                    209.19899999999998`}, {57.5, 209.19899999999998`}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    57.926, 213.441}, {62.168, 213.441}, {62.168, 211.32}, {
                    57.926, 211.32}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002847395833333333], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    57.926, 213.441}, {62.168, 213.441}, {62.168, 211.32}, {
                    57.926, 211.32}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    57.926, 215.562}, {62.168, 215.562}, {62.168, 213.441}, {
                    57.926, 213.441}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002847395833333333], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    57.926, 215.562}, {62.168, 215.562}, {62.168, 213.441}, {
                    57.926, 213.441}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    58.348, 218.395}, {61.742999999999995`, 218.395}, {
                    61.742999999999995`, 215.56300000000002`}, {58.348, 
                    215.56300000000002`}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002847395833333333], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    58.348, 218.395}, {61.742999999999995`, 218.395}, {
                    61.742999999999995`, 215.56300000000002`}, {58.348, 
                    215.56300000000002`}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    58.203, 220.86700000000002`}, {61.891000000000005`, 
                    220.86700000000002`}, {61.891000000000005`, 218.394}, {
                    58.203, 218.394}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002967500000000001], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    58.203, 220.867}, {61.891000000000005`, 220.867}, {
                    61.891000000000005`, 218.394}, {58.203, 218.394}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{65.16799999999999, 223.168}, {65.16799999999999, 
                    221.312}, {62.969, 219.809}, {60.25, 219.809}, {
                    57.535000000000004`, 219.809}, {55.332, 221.312}, {55.332,
                     223.168}, {55.332, 225.023}, {57.535000000000004`, 
                    226.52700000000002`}, {60.25, 226.52700000000002`}, {
                    62.969, 226.52700000000002`}, {65.16799999999999, 
                    225.023}, {65.16799999999999, 223.168}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002797843009704614], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{65.16799999999999, 223.167931868}, {
                    65.16799999999999, 221.31284951800004`}, {62.969, 
                    219.808938571}, {60.25, 219.808938571}, {
                    57.535000000000004`, 219.808938571}, {55.332, 
                    221.31284951800004`}, {55.332, 223.167931868}, {55.332, 
                    225.023014218}, {57.535000000000004`, 
                    226.52692516500005`}, {60.25, 226.52692516500005`}, {
                    62.969, 226.52692516500005`}, {65.16799999999999, 
                    225.023014218}, {65.16799999999999, 223.167931868}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4rhdnjxM0f4OYPp1tgOM72Pe6ZhwNtth9hGF
DUU//B2stpwo2zcbk7+nZLIES5u/w6qPl3yTOrIdTi903fb5rJ/DzXPfgx9X
Zjv0Ts8TalZA8A9/1YjpL/KF8126c57/nukD4TdmO/Drbpr73t0Hbj463+Cu
ClvjUx+4+2B8mPth/AJbruuLOXLg+qtF1rk/1MPkO4Ps3+nj8LbG3jTOKQfu
vv3zpfTvBuTA3Q/jw/wH48P8D9MPCx+Y+eh8WPjC3Ice/gCXa7OX
                    
                    "]]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002797833333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4rhdnjxM0f4OYPp1tgOM72Pe6ZhwNtth9hGF
DUU//B0st5wo2zcbk7+nZLIES5u/w6qPl3yTOrIdTi903fb5rJ/DzXPfgx9X
Zjv0Ts8TalZA8A9/1YjpL/KF8126c57/nukD4TdmO/Drbpr73t0Hbj463+Cu
ClvjUx+4+2B8mPth/EJbruuLOXLg+qtF1rk/1MPkO4Ps3+nj8K7G3jTOKQfu
vn3zpfTvBuTA3Q/jw/wH48P8D9MPCx+Y+eh8WPjC3Ice/gCTM7OU
                    "], 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYCYtO4XZ48n/wcQBTT62wHGN/HvNMx4Wy2Q3HG
xLc1/f4OvdPzhJonYPLtuK4vLpD1d1jkuu3z35psh9MLgYyzfg43z30PflyZ
DVGngOAf/qoR01/kC+fnPv+98iOTr8OWE2X75pdlO0jp31Vh2+gDNx+dH2EJ
VOnnC3cfjA9zP4xfYAt0GEcOXD830Jm2Vph8sP1Kvg7CzQdOLfTNgbtv/3yg
yoAcuPthfJj/YHyY/2H6YeEDMx+dDwtfmPvQwx8ALlew6g==
                    
                    "]]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002797833333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYCYtO4XZ48n/wcQBTT62wHGN/HvNMx4Wy2Q3HG
xLc1/f4OvdPzhJonYPLtuK4vLpD1d1jkuu3z35psh9MLgYyzfg43z30PflyZ
DVGngOAf/qoR01/kC+fnPv+98iOTr8OWE2X75pdlO0jp31Vh2+gDNx+dH2EJ
VOnnC3cfjA9zP4xfaAt0GEcOXD/ImbZWmHyw/Uq+DkLNB04t9M2Bu2/ffKDK
gBy4+2F8mP9gfJj/Yfph4QMzH50PC1+Y+9DDHwArf7Dj
                    "], 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{56.562000000000005`, 222.98800000000003`}, {
                    56.562000000000005`, 222.40200000000002`}, {56.012, 
                    221.93}, {55.332, 221.93}, {54.656, 221.93}, {
                    54.105000000000004`, 222.40200000000002`}, {
                    54.105000000000004`, 222.98800000000003`}, {
                    54.105000000000004`, 223.57399999999998`}, {54.656, 
                    224.05100000000002`}, {55.332, 224.05100000000002`}, {
                    56.012, 224.05100000000002`}, {56.562000000000005`, 
                    223.57399999999998`}, {56.562000000000005`, 
                    222.98800000000003`}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002797843009704614], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{56.562000000000005`, 222.988463436}, {
                    56.562000000000005`, 222.402602545}, {56.012, 
                    221.929772253}, {55.332, 221.929772253}, {54.656, 
                    221.929772253}, {54.105000000000004`, 222.402602545}, {
                    54.105000000000004`, 222.988463436}, {54.105000000000004`,
                     223.57432432700003`}, {54.656, 224.05060593500002`}, {
                    55.332, 224.05060593500002`}, {56.012, 
                    224.05060593500002`}, {56.562000000000005`, 
                    223.57432432700003`}, {56.562000000000005`, 
                    222.988463436}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{66.398, 222.98800000000003`}, {66.398, 
                    222.40200000000002`}, {65.848, 221.93}, {
                    65.16799999999999, 221.93}, {64.488, 221.93}, {
                    63.940999999999995`, 222.40200000000002`}, {
                    63.940999999999995`, 222.98800000000003`}, {
                    63.940999999999995`, 223.57399999999998`}, {64.488, 
                    224.05100000000002`}, {65.16799999999999, 
                    224.05100000000002`}, {65.848, 224.05100000000002`}, {
                    66.398, 223.57399999999998`}, {66.398, 
                    222.98800000000003`}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002797843009704614], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{66.398, 222.988463436}, {66.398, 
                    222.402602545}, {65.848, 221.929772253}, {
                    65.16799999999999, 221.929772253}, {64.488, 
                    221.929772253}, {63.940999999999995`, 222.402602545}, {
                    63.940999999999995`, 222.988463436}, {63.940999999999995`,
                     223.57432432700003`}, {64.488, 224.05060593500002`}, {
                    65.16799999999999, 224.05060593500002`}, {65.848, 
                    224.05060593500002`}, {66.398, 223.57432432700003`}, {
                    66.398, 222.988463436}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{61.48, 222.98800000000003`}, {61.48, 
                    222.40200000000002`}, {60.93, 221.93}, {60.25, 221.93}, {
                    59.574, 221.93}, {59.023, 222.40200000000002`}, {59.023, 
                    222.98800000000003`}, {59.023, 223.57399999999998`}, {
                    59.574, 224.05100000000002`}, {60.25, 
                    224.05100000000002`}, {60.93, 224.05100000000002`}, {
                    61.48, 223.57399999999998`}, {61.48, 
                    222.98800000000003`}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002797843009704614], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{61.48, 222.988463436}, {61.48, 222.402602545}, {
                    60.93, 221.929772253}, {60.25, 221.929772253}, {59.574, 
                    221.929772253}, {59.023, 222.402602545}, {59.023, 
                    222.988463436}, {59.023, 223.57432432700003`}, {59.574, 
                    224.05060593500002`}, {60.25, 224.05060593500002`}, {
                    60.93, 224.05060593500002`}, {61.48, 
                    223.57432432700003`}, {61.48, 222.988463436}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{61.48, 226.52700000000002`}, {61.48, 225.941}, {
                    60.93, 225.465}, {60.25, 225.465}, {59.574, 225.465}, {
                    59.023, 225.941}, {59.023, 226.52700000000002`}, {59.023, 
                    227.11299999999997`}, {59.574, 227.586}, {60.25, 
                    227.586}, {60.93, 227.586}, {61.48, 
                    227.11299999999997`}, {61.48, 
                    226.52700000000002`}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002797843009704614], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{61.48, 226.52692516500005`}, {61.48, 
                    225.941064274}, {60.93, 225.464782666}, {60.25, 
                    225.464782666}, {59.574, 225.464782666}, {59.023, 
                    225.941064274}, {59.023, 226.52692516500005`}, {59.023, 
                    227.11364888500003`}, {59.574, 227.58561634800003`}, {
                    60.25, 227.58561634800003`}, {60.93, 
                    227.58561634800003`}, {61.48, 227.11364888500003`}, {
                    61.48, 226.52692516500005`}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{57.926, 206.371}, {57.926, 205.785}, {57.355, 
                    205.309}, {56.652, 205.309}, {55.949, 205.309}, {55.379, 
                    205.785}, {55.379, 206.371}, {55.379, 
                    206.95700000000002`}, {55.949, 207.43}, {56.652, 
                    207.43}, {57.355, 207.43}, {57.926, 
                    206.95700000000002`}, {57.926, 206.371}}}]}}}}}}}, {{{{{{{
                    
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002847359638519521], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{57.926, 206.37114037400002`}, {57.926, 
                    205.78548654000002`}, {57.355, 205.308965924}, {56.652, 
                    205.308965924}, {55.949, 205.308965924}, {55.379, 
                    205.78548654000002`}, {55.379, 206.37114037400002`}, {
                    55.379, 206.95679420800002`}, {55.949, 207.429982512}, {
                    56.652, 207.429982512}, {57.355, 207.429982512}, {57.926, 
                    206.95679420800002`}, {57.926, 206.37114037400002`}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{64.715, 206.371}, {64.715, 205.785}, {64.145, 
                    205.309}, {63.440999999999995`, 205.309}, {
                    62.73800000000001, 205.309}, {62.168000000000006`, 
                    205.785}, {62.168000000000006`, 206.371}, {
                    62.168000000000006`, 206.95700000000002`}, {
                    62.73800000000001, 207.43}, {63.440999999999995`, 
                    207.43}, {64.145, 207.43}, {64.715, 
                    206.95700000000002`}, {64.715, 206.371}}}]}}}}}}}, {{{{{{{
                    
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002847359638519521], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{64.715, 206.37114037400002`}, {64.715, 
                    205.78548654000002`}, {64.145, 205.308965924}, {
                    63.440999999999995`, 205.308965924}, {62.73800000000001, 
                    205.308965924}, {62.168000000000006`, 
                    205.78548654000002`}, {62.168000000000006`, 
                    206.37114037400002`}, {62.168000000000006`, 
                    206.95679420800002`}, {62.73800000000001, 
                    207.429982512}, {63.440999999999995`, 207.429982512}, {
                    64.145, 207.429982512}, {64.715, 206.95679420800002`}, {
                    64.715, 206.37114037400002`}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{57.074, 
                    209.19899999999998`}, {63.016, 209.19899999999998`}, {
                    60.047, 206.016}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.00028473541666666665`], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{57.074, 
                    209.199}, {63.016, 209.199}, {60.047, 
                    206.01600000000002`}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{61.746, 206.72299999999998`}, {61.746, 
                    205.941}, {60.983999999999995`, 205.309}, {60.047, 
                    205.309}, {59.109, 205.309}, {58.348, 205.941}, {58.348, 
                    206.72299999999998`}, {58.348, 207.504}, {59.109, 
                    208.137}, {60.047, 208.137}, {60.983999999999995`, 
                    208.137}, {61.746, 207.504}, {61.746, 
                    206.72299999999998`}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0003796485856436213], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{61.746, 206.72269929}, {61.746, 
                    205.94127212600003`}, {60.983999999999995`, 
                    205.308965924}, {60.047, 205.308965924}, {59.109, 
                    205.308965924}, {58.348, 205.94127212600003`}, {58.348, 
                    206.72269929}, {58.348, 207.50412645400004`}, {59.109, 
                    208.136432656}, {60.047, 208.136432656}, {
                    60.983999999999995`, 208.136432656}, {61.746, 
                    207.50412645400004`}, {61.746, 206.72269929}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    54.004, 196.11299999999997`}, {62.137, 
                    196.11299999999997`}, {62.41, 196.11299999999997`}, {
                    62.629000000000005`, 195.945}, {62.629000000000005`, 
                    195.738}, {62.629000000000005`, 194.36700000000002`}, {
                    62.629000000000005`, 194.156}, {62.41, 
                    193.99200000000002`}, {62.137, 193.99200000000002`}, {
                    54.004, 193.99200000000002`}, {53.730000000000004`, 
                    193.99200000000002`}, {53.508, 194.156}, {53.508, 
                    194.36700000000002`}, {53.508, 195.738}, {53.508, 
                    195.945}, {53.730000000000004`, 196.11299999999997`}, {
                    54.004, 196.11299999999997`}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    54.004, 196.113}, {62.137, 196.113}, {62.41, 196.113}, {
                    62.629000000000005`, 195.945}, {62.629000000000005`, 
                    195.738}, {62.629000000000005`, 194.367}, {
                    62.629000000000005`, 194.156}, {62.41, 193.992}, {62.137, 
                    193.992}, {54.004, 193.992}, {53.730000000000004`, 
                    193.992}, {53.508, 194.156}, {53.508, 194.367}, {53.508, 
                    195.738}, {53.508, 195.945}, {53.730000000000004`, 
                    196.113}, {54.004, 196.113}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}}, {{1, 4, 3}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgAmJ+KO3SnfP8d2SAw+Ols48o7Mlw2DT3/fJjwgi+Fw+T
dvs2f4dvGjH9hxYi+Itct33+24DgCzcfOLXQF8G/87Mua48Owry3NfamcUIZ
DjD7YPze6XlCzQsQfGn9uypsNwPg+mF8mPkwPsx+GB/mPph5MPej+w/GB2lr
XJrhYLXlRNk+fQQfbA5vgMOqj5d8kyYg+OqGHGtkytDkI9Dk7RDmtb4O3CGn
ibAPxvdLEoiwbEHwQd5yXYbQD+PDzEeRL0OTn4AwD+Z+dP8BAFDw06U=
                    
                    "]]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}}, {{1, 4, 3}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgAmJ+KO3SnfP8d2SAw+Ols48o7Mlw2DT3/fJjwgi+Fw+T
dvs2f4dvGjH9hxYi+Itct33+24DgCzUfOLXQF8G//bMua48Owrx3NfamcUIZ
DjD7YPze6XlCzQsQfGn9uypsNwPg+mF8mPkwPsx+GB/mPph5MPej+w/GB2lr
XJrhYLXlRNk+fQQfbA5vgMOqj5d8kyYg+OqGHGtkytDkI9Dk7RDmtb4O3CGn
ibAPxvdLEoiwbEHwQd5yXYbQD+PDzEeRL0OTn4AwD+Z+dP8BAE+I06Q=
                    
                    "], CurveClosed -> {1, 1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}}, {{1, 4, 3}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgAmJ+KM3eONW5u8fb4fbPuqw9GzIcPl3yTRKwQPDbxW6e
+/7Zy8Fqy4myfbMRfP27KmyNjQj+Itdtn//6IPjVIuvcHxohzPumEdN/SDbD
AWYfjC8NMughgi8K1Fal4gPXD+PDzIfxYfbD+DD3wcyDuR/dfzB+/6GvGjHH
MxyKMya+rfnvBedHWAIN6oP6Zw2Cf9zbvNOxB8FXN+RYI+OE4IOkExQR5sXu
8uRhYkfYB+NrAb35VcIHznfpznn+u9MHrh/Gh5kP48Psh/Fh7oOZB3M/uv8A
zm7Z+Q==
                    "]]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}}, {{1, 4, 3}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgAmJ+KM3eONW5u8fb4fbPuqw9GzIcPl3yTRKwQPDbxW6e
+/7Zy8Fyy4myfbMRfP27KmyNjQj+Itdtn//6IPjVIuvcHxohzPumEdN/SDbD
AWYfjC8NMughgi8K1Fal4gPXD+PDzIfxYfbD+DD3wcyDuR/dfzB+/6GvGjHH
MxyKMya+rfnvBedHgAzqg/pnDYJ/3Nu807EHwVc35Fgj44Tg+wClExQR5sXt
8uRhYkfYB+NrAb35VcIHznfpznn+u9MHrh/Gh5kP48Psh/Fh7oOZB3M/uv8A
zfbZ/A==
                    "], CurveClosed -> {1, 1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}}, {{1, 4, 3}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgAmJ+KO3Fw6Td/s3Tgfv64gLbWRkOZnG7PHkWIfh2XEBG
rKdD6+vAHXKtCH61yDr3h1kI/tYTZfvmxyH4qz5e8k1yQZinytY41Vk/wwFm
H4wPkmby9oLzIyy3nCjr84Lrh/Fh5sP4MPthfJj7YObB3I/uPxj/9s+6rD0b
Mhy2ff57pSITwZ99RGFD0Q8Ph7c19qZx0xB8oeYDpxaWIvgga/cFI/hge40R
5hXYAgNCAmEfjH/4q0ZMf5MXnN8udvPc989ecP0wPsx8GB9mP4wPcx/MPJj7
0f0HAM/n1e4=
                    "]]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}}, {{1, 4, 3}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgAmJ+KO3Fw6Td/s3Tgev64gLbWRkOZnG7PHkWIfh2IEas
p0Pr68Adcq0IfrXIOveHWQj+lhNl++bHIfirPl7yTXJBmKfK1jjVWT/DAWYf
jA+SZvL2gvMjLIEm9XnB9cP4MPNhfJj9MD7MfTDzYO5H9x+Mf/tnXdaeDRkO
2z7/vVKRieDPPqKwoeiHh8O7GnvTuGkIvlDzgVMLSxF8K5CDghF8sL3GCPMK
bIE2SiDsg/EPf9WI6W/ygvPbxW6e+/7ZC64fxoeZD+PD7IfxYe6DmQdzP7r/
AMlX1ew=
                    "], CurveClosed -> {1, 1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}}, {{1, 4, 3}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgAmJ+KL3Iddvnv1PcHfTvqrA17sxwmCzBEsb31w3Oz33+
e+XHJjeHm+e+Bz9eiOAX2HJdX9yC4Lt05zz/7YngF4LkdRDmtb4O3CEnmuEA
sw/GB8vresD51xcDTV7uAdcP48PMh/Fh9sP4MPfBzIO5H91/MH61yDr3h5cy
HD5d8k0SmOEG57M3TnXuPuPqkDHxbY39VgQf7J4JCD7YPls09ZII86y2nCjb
9zsdbh+Mbxq3y5Nnkgecbwc0tiDWE64fxoeZD+PD7EdRD3QfzDyY+9H9BwDC
Ud9Y
                    "]]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}}, {{1, 4, 3}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgAmJ+KL3Iddvnv1PcHfTvqrA17sxwmCzBEsb31w3Oz33+
e+XHJjeHm+e+Bz9eiOAX2nJdX9yC4Lt05zz/7YngF4DkdRDmtb4O3CEnmuEA
sw/GB8vresD51xcDdS73gOuH8WHmw/gw+2F8mPtg5sHcj+4/GL9aZJ37w0sZ
Dp8u+SYJzHCD89kbpzp3n3F1yJj4tsZ+K4IPtm8Cgg+2zxZNvSTCPMstJ8r2
/U6H2wfjm8bt8uSZ5AHn2wGNLYj1hOuH8WHmw/gw+1HUA90HMw/mfnT/AQDA
6d9V
                    "], CurveClosed -> {1, 1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}}, {{1, 4, 3}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgAmJ+KC26zv1hlU2QA9f1xQW26zIceqfnCTV/CITzVdka
pzpvDnS4oHT7Z900BD9j4tsa+0oEf+uJsn3z7dDkFRHmfdOI6T/EmeEAsw/G
P+Zt3unYgeDr31VhazwaBNcP48PMR5GvRPBh7oOZB3M/uv9g/P5DXzVijmdA
7N0bCOdbbgFaFB7o4NKd8/z3SgTfB2hsQiuCfxFknxGCv7dksgQLH8I8iL/T
4fbB+HG7PHmYdiP4IY+Xzj6iEAzXD+PDzIfxYfbD+DD3wcyDuR/dfwDn09cI

                    "]]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}}, {{1, 4, 3}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgAmJ+KC26zv1hlU2QA9f1xQW26zIceqfnCTV/CITzVdka
pzpvDnS4qHT7Z900BD9j4tsa+0oEf8uJsn3z7dDkFRHmfdOI6T/EmeEAsw/G
P+Zt3unYgeDr31VhazwaBNcP48PMR5GvRPBh7oOZB3M/uv9g/P5DXzVijmdA
7N0bCOdbgiwKD3Rw6c55/nslgu8DNDahFcEH22eE4O8pmSzBwocwrw/s73S4
fTB+3C5PHqbdCH7I46WzjygEw/XD+DDzYXyY/TA+zH0w82DuR/cfAOhL1wk=

                    "], CurveClosed -> {1, 1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    66.45700000000001, 196.11299999999997`}, {70.699, 
                    196.11299999999997`}, {70.84400000000001, 
                    196.11299999999997`}, {70.96100000000001, 195.945}, {
                    70.96100000000001, 195.738}, {70.96100000000001, 
                    194.36700000000002`}, {70.96100000000001, 194.156}, {
                    70.84400000000001, 193.99200000000002`}, {70.699, 
                    193.99200000000002`}, {66.45700000000001, 
                    193.99200000000002`}, {66.316, 193.99200000000002`}, {
                    66.199, 194.156}, {66.199, 194.36700000000002`}, {66.199, 
                    195.738}, {66.199, 195.945}, {66.316, 
                    196.11299999999997`}, {66.45700000000001, 
                    196.11299999999997`}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    66.45700000000001, 196.113}, {70.699, 196.113}, {
                    70.84400000000001, 196.113}, {70.96100000000001, 
                    195.945}, {70.96100000000001, 195.738}, {
                    70.96100000000001, 194.367}, {70.96100000000001, 
                    194.156}, {70.84400000000001, 193.992}, {70.699, 
                    193.992}, {66.45700000000001, 193.992}, {66.316, 
                    193.992}, {66.199, 194.156}, {66.199, 194.367}, {66.199, 
                    195.738}, {66.199, 195.945}, {66.316, 196.113}, {
                    66.45700000000001, 196.113}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    61.992000000000004`, 196.465}, {64.465, 196.465}, {64.551,
                     196.465}, {64.617, 196.242}, {64.617, 195.965}, {64.617, 
                    194.137}, {64.617, 193.859}, {64.551, 193.637}, {64.465, 
                    193.637}, {61.992000000000004`, 193.637}, {61.906, 
                    193.637}, {61.839999999999996`, 193.859}, {
                    61.839999999999996`, 194.137}, {61.839999999999996`, 
                    195.965}, {61.839999999999996`, 196.242}, {61.906, 
                    196.465}, {61.992000000000004`, 196.465}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    61.992000000000004`, 196.465}, {64.465, 196.465}, {64.551,
                     196.465}, {64.617, 196.242}, {64.617, 195.965}, {64.617, 
                    194.137}, {64.617, 193.859}, {64.551, 193.637}, {64.465, 
                    193.637}, {61.992000000000004`, 193.637}, {61.906, 
                    193.637}, {61.839999999999996`, 193.859}, {
                    61.839999999999996`, 194.137}, {61.839999999999996`, 
                    195.965}, {61.839999999999996`, 196.242}, {61.906, 
                    196.465}, {61.992000000000004`, 196.465}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    48.902, 196.465}, {51.379, 196.465}, {51.461, 196.465}, {
                    51.527, 196.242}, {51.527, 195.965}, {51.527, 194.137}, {
                    51.527, 193.859}, {51.461, 193.637}, {51.379, 193.637}, {
                    48.902, 193.637}, {48.82, 193.637}, {48.754, 193.859}, {
                    48.754, 194.137}, {48.754, 195.965}, {48.754, 196.242}, {
                    48.82, 196.465}, {48.902, 196.465}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    48.902, 196.465}, {51.379, 196.465}, {51.461, 196.465}, {
                    51.527, 196.242}, {51.527, 195.965}, {51.527, 194.137}, {
                    51.527, 193.859}, {51.461, 193.637}, {51.379, 193.637}, {
                    48.902, 193.637}, {48.82, 193.637}, {48.754, 193.859}, {
                    48.754, 194.137}, {48.754, 195.965}, {48.754, 196.242}, {
                    48.82, 196.465}, {48.902, 196.465}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    40.324, 196.82000000000002`}, {45.273, 
                    196.82000000000002`}, {45.440999999999995`, 
                    196.82000000000002`}, {45.578, 196.54299999999998`}, {
                    45.578, 196.195}, {45.578, 193.91}, {45.578, 193.562}, {
                    45.440999999999995`, 193.285}, {45.273, 193.285}, {40.324,
                     193.285}, {40.160000000000004`, 193.285}, {40.023, 
                    193.562}, {40.023, 193.91}, {40.023, 196.195}, {40.023, 
                    196.54299999999998`}, {40.160000000000004`, 
                    196.82000000000002`}, {40.324, 
                    196.82000000000002`}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    40.324, 196.82}, {45.273, 196.82}, {45.440999999999995`, 
                    196.82}, {45.578, 196.543}, {45.578, 196.195}, {45.578, 
                    193.91}, {45.578, 193.562}, {45.440999999999995`, 
                    193.285}, {45.273, 193.285}, {40.324, 193.285}, {
                    40.160000000000004`, 193.285}, {40.023, 193.562}, {40.023,
                     193.91}, {40.023, 196.195}, {40.023, 196.543}, {
                    40.160000000000004`, 196.82}, {40.324, 196.82}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    74.809, 196.465}, {79.402, 196.465}, {79.559, 196.465}, {
                    79.684, 196.184}, {79.684, 195.84}, {79.684, 193.555}, {
                    79.684, 193.207}, {79.559, 192.93}, {79.402, 192.93}, {
                    74.809, 192.93}, {74.65199999999999, 192.93}, {74.527, 
                    193.207}, {74.527, 193.555}, {74.527, 195.84}, {74.527, 
                    196.184}, {74.65199999999999, 196.465}, {74.809, 
                    196.465}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    74.809, 196.465}, {79.402, 196.465}, {79.559, 196.465}, {
                    79.684, 196.184}, {79.684, 195.84}, {79.684, 193.555}, {
                    79.684, 193.207}, {79.559, 192.93}, {79.402, 192.93}, {
                    74.809, 192.93}, {74.65199999999999, 192.93}, {74.527, 
                    193.207}, {74.527, 193.555}, {74.527, 195.84}, {74.527, 
                    196.184}, {74.65199999999999, 196.465}, {74.809, 
                    196.465}}}, CurveClosed -> {1}]}}}}}}}}}}}}}}, 
                  AspectRatio -> Automatic, ImageSize -> {{128}, {85}}, 
                  PlotRange -> {{0., 480.}, {0., 240.}}], ",", 
                 GraphicsBox[{{{{{{{
                    Thickness[0.0010416666666666667`], {{{{{{{
                    FaceForm[{
                    RGBColor[1., 0.717647, 0.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {0., 480.}, {960., 480.}, {960., 
                    0.}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 0.356863, 0.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    172., 440.}, {304., 440.}, {304., 40.}, {172., 
                    40.}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0., 0.3372549999999999, 0.254902], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    40., 440.}, {172., 440.}, {172., 40.}, {40., 
                    40.}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.5529410000000001, 0.12549000000000002`, 0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    344., 440.}, {924., 440.}, {924., 40.}, {344., 
                    40.}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 0.717647, 0.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIpIGYC4g7HhKcX1Lodtn3+e6XiZJQDOj86xfq+f1C3
w0JXoAhLhIOPeadjQlO3g1+SQITlkzAHm/v+vdNPdjv0Ts8TarYIddhyomzf
/OgehzUyUSnW4aEQ+Zk9EPUpwQ6yQOH7j3scLEEKxQMdlhTYcl2f3ONQ+VLN
kEPGx+GC0u2fdVN6HBaB7JviDdE/o8eBAQQSPDD4YPVpPQ57SyZLsIR5OBxV
2FCUEdjjsPKYt3mnooeDfOvrwB2GPQ6Hv2rE9F9yd7jsC3SIao+D/l0VtkZT
N4j/XnU75D7/vfJjkZvDNOfunOeh3Q5TgKbx8bpD+NHdDrOPgAz2h+gL7nZo
PnBqoatbsMOnS0ADfbodLoLcsSgEEn5W3Q4g6x0zwiDuNISG15FwiPs1uh28
eJi0299FYIQ3Oh8AZG64MA==
                    "]]}}}}}}}, {{{{{{{
                    Thickness[0.0017714645833333332`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIpIGYC4g7HhKcX1Lodtnz+e6XiZJQDOj86xfq+f1C3
wxLXbZ//skQ4+Jh3OiY0dTsEJAlEWD4Jc7C57987/WS3Q8/0PKFmi1CHLSfK
9s2P7nFYIxOVYh0eCpGf2QNRnxLsIAsUvv+4x8ECpFA80GFJgS3X9ck9Dg0v
1Qw5ZHwcLijd/lk3pcdhBci+Kd4Q/TN6HBhAIMEDgw9Wn9bjcKBksgRLmIfD
UYUNRRmBPQ4bjnmbdyp6OMi3vg7cYQiU/6oR03/J3eGyL9Ahqj0OBndV2BpN
3SD+e9XtkPH898qPRW4O05y7c56HdjvMAJrGx+sO4UcD+UdABvs76IP0BXc7
tBw4tdDVLdjh0yWggT7dDldA7lgUAgk/q26HE0DrHTPCIO40hIbXkXCI+zW6
HXx4mLTb30VghDc6HwB57rhI
                    "], 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 0.717647, 0.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIpIGYC4nc19qZxnyochJsPnFroW+6Azvc273RMmF3h
MD1PqPnAv3KHjIlva+ytKxxynv9e+dGtwgEo+/TCmnIH2agU6/sbKxxmgNR1
lDlcrXipZrgKKs9TBlGvVulwDGRgRanDp0u+SQK7Kh12yLW+DpQoc7igdPtn
XU2VQ+wuTx4m8TKIvb1VDh0g/XxlDgwg8AWTHwdSX1wGcdfXKofyffOl9OeW
OWi1i90897vK4dBXjZj+O2UOHg+rRNaxVjuAnOn/tQxCW1ZD7Mkuh/jXsBri
7ikVDm9B4SAH5XdUOOSC3C9U5bDIddvnvzMqHO77907P06t0kAEZtLwCYs71
Ckj4napw4NPdNPd9agXEnfeg4cVXAXH/O6j5RzDDG50PALzvvic=
                    
                    "]]}}}}}}}, {{{{{{{
                    Thickness[0.0017714645833333332`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIpIGYC4nc19qZxnyochJoPnFroW+6Azvc273RMmF3h
MCMPKPKv3CFj4tsae+sKh5znv1d+dKtwAMo+vbCm3EE2KsX6/kaouo4yh6sV
L9UMV0Hlecog6tUqHY6BDKwodfh0yTdJYFelww651teBEmUOF5Vu/6yrqXKI
3eXJwyRe5uADsre3yqEDpJ+vzIEBBL5g8uNA6ovLIO76WuVQvm++lP7cMgft
drGb535XORz6qhHTf6fMweNhlcg61moHkDP9v5ZBaMtqiP+yyyH+NayGuHtK
BSQc5KD8jgqHXJD7haocFrlu+/x3RoXDff/e6Xl6lQ4yIIOWV0Dcex2q71SF
A5/uprnvUysg7rwHDS++Coj730HVHcEMb3Q+AL5/vik=
                    "], 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 0.717647, 0.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIpIGYC4g7HhKcX1LodhJsPnFroW+6Azo9Osb7vH9Tt
MD1PqPnAv3IHH/NOx4Smboec579XfnSrcLC57987/WS3g2wUUOHGCoctJ8r2
zY/ucbha8VLNcBVUfmYPRL1aJUTd4x6HT5d8kwR2VTosKbDluj65x+GC0u2f
dTVVEHpKj4M3yJ7eKoj+GT0ODCDwBZMPVp/W45Ax8W2N/dcqh6MKG4oyAnsc
tNrFbp77XeUg3/o6cIdhj4PHwyqRdazVDpeB1kao9jiAnOFvWQ3x3yuofw2r
HaY5d+c8D+12AJpmGicH5Ud3O+SC3C9U5aB/V4WtMbjbAeSMPL1KiD98uiHu
vV4BCT+rbgc+3U1z36dWQNxpCA0vPmh4aEDNP4IZ3uh8ADOCwEA=
                    
                    "]]}}}}}}}, {{{{{{{
                    Thickness[0.0017714645833333332`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIpIGYC4g7HhKcX1LodhJoPnFroW+6Azo9Osb7vH9Tt
MCMPKPKv3MHHvNMxoanbIef575Uf3SocbO77904/2e0gGwVUuLHCYcuJsn3z
o3scrla8VDNcBZWf2QNRr1YJUfe4x+HTJd8kgV2VDksKbLmuT+5xuKh0+2dd
TZXDBRA9pQdiT28VRP+MHgcGEPiCyQerT+txyJj4tsb+a5XDUYUNRRmBPQ7a
7WI3z/2ucpBvfR24w7DHweNhlcg61mqHy0BrI1R7HEDO8LeshvjvFdS/htUO
05y7c56Hdju8q7E3jZOD8qO7HXJB7heqctC/q8LWGNztAHJGnl4lxB8+3RD3
Xq+AhJ9VtwOf7qa571MrIO40hIYXHzQ8NKDmH8EMb3Q+ADUSwEI=
                    "], 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 0.717647, 0.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIpIGYC4nc19qZxnyoctn3+e6XiZJQDOt/bvNMxYXaF
w0JXoAhLhEPGxLc19tYVDn5JAhGWT8IcgLJPL6wpd+idnifUbBHqMANIHego
c1gjE5ViHR4Kkecpg6hPCXY4BjKwotTBcsuJsn3igQ475FpfB0qUOVS+VDPk
kPFxiN3lycMkXuawCGTfFG+HDpB+vjIHBhBI8MDgx4HUF5c57C2ZLMES5uFQ
vm++lP7cMoeVIIsUPRwOfdWI6b9T5nAYRF9ydwC66r7/1zIH/bsqbI2mbhD/
ZZc75D7/vfJjkZvD1QqgQ6ZUOEwBmsbH6w7hd1Q4zD6isKEowx/irhkVDs0H
Ti10dQt2AHnz/vIKh4tKt3/WLQqBhN+pCog/M8Ig7rwHDa8j4RD3v6tw8OJh
0m5/F4ER3uh8AO3bthc=
                    "]]}}}}}}}, {{{{{{{
                    Thickness[0.0017714645833333332`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIpIGYC4nc19qZxnyoctnz+e6XiZJQDOt/bvNMxYXaF
wxLXbZ//skQ4ZEx8W2NvXeEQkCQQYfkkzAEo+/TCmnKHnul5Qs0WoQ4zgNSB
jjKHNTJRKdbhoRB5njKI+pRgh2MgAytKHSy2nCjbJx7osEOu9XWgRJlDw0s1
Qw4ZH4fYXZ48TOJlDitA9k3xdugA6ecrc2AAgQQPDH4cSH1xmcOBkskSLGEe
DuX75kvpzy1z2ACySNHD4dBXjZj+O0B5EH3J3QHoqvv+X8scDO6qsDWaukH8
l13ukPH898qPRW4OVyuADplS4TADaBofrzuE3wHkH1HYUJTh77AI5K4ZFQ4t
B04tdHULdgB58/7yCocrSrd/1i0KgYTfqQqHEyCDM8Ig7rwHDa8j4RD3v6tw
8OFh0m5/F4ER3uh8AANqti8=
                    "], 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    Thickness[0.004633204166666667], 
                    FilledCurveBox[{CompressedData["
1:eJxTTMoPSmJiYGDQZ2RgYAbSDEAOIwMjMzOQhDCIRPjVw2WJN5ZIlQSVUa6A
bPVoKqnud2JMINsNBGONoMn4FVArXkhyJIWxQKqbKYxHAMnLCKY=
                    
                    "], {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}}, {{1, 4, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}, {{0, 2, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4,
                     3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 
                    3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}}}, {CompressedData["
1:eJxdW3mcT+UaH0v2O8mSJblZwkXkhgm58wppoYT8fsxqFmMs8zu/ddDiLL/l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                    "], CompressedData["
1:eJxdVn9MlVUYvlErhsQynQNaJmSNQoP+YGry4yUqRswRtgxDrkYQrtn1O59O
r2XZPae7m2tpyIxWmXlTzDBWJkiuQQNDsVYUmBVzIv1gXQrQrOUs1znnfeRr
sbFvz33PeX887/O+35dWvXpxbZzP56vX/+Z57utF1deVKdrz+pFZ7x9x6DJe
cPDYuo5Bh1bW/7axYK6iH8yBVEE+8zdF0djGghz/3YLPT0hKmntgx/ijgsy1
naOSnhy5uO9staCuPzKWbdU4PFrePrNEUNvv/wwENbb30gU98fHahuTvJd0e
mfHdF52I1+9hnZW78ksP32Qc9UryHy5JjOt3aOHpspcaeyQN6Ucg5lDWqdlX
h7qRzxWI1ybpRPCXW+/MFtRq8tsnOU65oOGnprcUb5P0SI3xJLjO5yRNU58c
3/WQoPUdO1OzVku6yxSWJmi3k5dwslySuXZmzKHNhSt+6rvHw02Gx0IP2/o0
Plo6b3NhAvIpknS98Z8paINOK/4+SdeafMuAtb/GgD6xSpCuMjOSLzmPNYLy
E06+7SwAnxsEnTGBciQ1JF+1JGm9h20fAv+zV8JfouS+XHLolaIXV41c6WGT
5gqfhy3/F0N8P0XQjYaov0KUZ/MQNKDbWPFniDJNf5ZCD+dwXvNpeR0PMd/N
gnJNv34NcZ96BfvX56P3amYOChrf21M67+8Q8/0M/CWhXynoX5qkvvTBC88u
wf056G8Q93OgvzcE39O4xxT2jofNtfoPBdc/H/W2C+o39eRJ5kHbXzV9KIT/
FsG6KoYewuhXqWQ+dP3GvPcBSU+b/scLCpq+PS5ZV/Nx3oX+F8PfJsk6Wgt7
GPHDuL8F/qKC53QLzkehx7ckz+XzuN8sOW8X5w8jvxLMZzf4yEA/PpdUZebp
GszjCUntM7XCtH4tL99gPs467P9b2M87/Psg+jED+jiF/PPQnyHEq0E+w5J1
rOvbbvgfhr4jmLcfUd/LgqZW6E10s2L+86GnhYrjTxdc1/2K411w+HyF4vkY
cVgPldhnow73p0qRUYF/wqE5Bi9X3I9kMYltX4o8bPl9AfwuUzzPr0FvxYrz
6MS8ZcEeA993KPrK8BNDPbcorvMzQZWmnlRF3YbnKOyJiPcfbPVz3MO23hHM
82nsj4ddtvd72O7LPg/bfI+C7wKX8+uQPH+zXK6vDfqJg7/90GsM+ngXeo5h
n70pJ+s1bWn3SzKyCgRd3mN+3N/mYauXJpd/fwzzvculCZNfAPltctnfOthr
XdZPBPst3+U+NcB+G+rdj3m4JBi3Il68y/3plKzTStTbhX28Bvn1YB4iLuuw
18NWzwMetvtjCvQ2FflOU5N82fm5QbGfLkHZZu+lob9j2C8Zip/pLj+zFecx
2+V9lKvYz3nMR6FifofQj6WK+WgTdMj0Qyjeb43Qyw7obTnmr0mxHrTdvj+b
kf8h7NsDivVwDP5bMT+d2L8fKebvA9hbMC8PCvrUBN6jqNgQXQD7bnxf5KIf
2xXP/yLkG1a832qwD+uQ/1bBvNUh/yLoqw75puB9WKv4ffuzw3GqMY/92E9V
iPee931jeY56+PL3z7/RviXx
                    "], CompressedData["
1:eJxNVGtIFVEQvghJSJaZRNjLykyysJISNXO0h5SaFP2w0BRLEjG7OItdNQrP
wVRCzIJUTMxXIkRImNrLxExFKKSMKLKLRNjLTEVIQuqMMz9aWA6ze84332N2
16WeO5rmYrPZDpib1tyvftsXZiuYehWX6uGHEBtcEpkSrsBG10Wpdyr41FTd
63MN4eAil4CiXQo2Fy1/9/IRwtKEkLaBYAVvHAboC8JEc19McJiCGDr3RGqD
17mm8PuRRoT08vELETEKiiNTPg8Z/MVb79VMJCo431XrHXhK9ucrfh6EUEL7
ShUkPTSdk5F5ViogOq05CM9m/BPLbinI97obPWr4rTVtOk29THcP1tUgJJb1
zPjXKQggvg+QzzUoCHd722DvQHht4BL6Ffi0ZqeX5yLM+zGmGDdK9Jq6nwRF
Cf8fwi8NYdWJ02HOnwpC2wZyunJFz7joqUVw0PpNQf3+9um5TtHjFL9tFjTa
DZNRBZVZnrrbzYJD1G9SgTvhOIXfrPAZFPwFGpzxpRVZdxA6pueGHe6a9d9E
CKMX3pr1FiD0krCVmvNRCEQ33kdDBfUzeWQ8tq6v2KChh/ANvz3ky0YNZ8f+
tEx+QNg24utaYOr5dQbhvpFZa+r5eVhvwS/KK0pz3qMIN/ZeyRxL1KyzUfgn
az5XjxBIOGc0+/8UYTTPEM8UPUNS2zX7PCvn7cLf2+JzduG/z+I8szXjxlus
x6FZZ4TFPAs09BFBXwsayO88zX6+R0ii+cjQEEL5VUteJzXjZiG0k7+HNUQT
MZPnMPEJ1TzPHxG2mDiag6TfCDIvP83zUIXsq8ljNW04jkCPaz01z8Mx2e8q
fl6W+f6reH8Twm4yZk6+x3qZ59+K/UmW/KZkvryQ5+iF4hzjEJ5T/i0y/4WC
X6XgNulLkfqqYn9ipV+xvN+B7HexzOMmZJ6mntflgZz7JfkfLBG8//4n/wAn
LwFL
                    "], {{648.8359999999999, 326.855}, {646.438, 
                    329.01599999999996`}, {644.7850000000001, 331.074}, {
                    645.164, 331.43399999999997`}, {645.543, 
                    331.79299999999995`}, {645.9689999999999, 331.895}, {
                    646.113, 331.66}, {646.254, 331.42999999999995`}, {
                    648.215, 329.367}, {650.4649999999999, 327.082}, {
                    655.6519999999999, 321.82}, {654.586, 321.672}, {
                    648.8359999999999, 326.855}}, CompressedData["
1:eJxdVGtIVEEY3RYTMZNNIkVcsyWyB6VFYGLSMRWTCKkfISolS8JSZEvcqS2k
mLmEKISIhVGE1VaSREhtJhEWPVT6IZI9aM2sNOxBmaaklNTMnW9bcGG5fHNn
znfO+c7cJe4DOyrsNpstX/7Vs+3nzHPfS44r5x6ntH43YFO/JxzOkj1Zg06G
H82dWzM6OU583d6enM2QHf3K7+3nkKs1OV4GR3FmoPsLx+GOpsS00ww1OeUf
e8c4utT7swwbB4tONsYIfa6BYYHa7xRoSIjYGVvH0FgZZz7YLHBV9Q/h7RKY
v/rm+dEihiFF7LjQz5WEd0HgjDrnYCiMsa+qvivwTi5XRjNUL3rd86tX4FK+
VBbB0LfN7SgeEtg/8vvamD1cW/rmhmuLdxTT+oNC60llCHQf6mjqIf6FDA8n
l5fV3RK4rdalPsu/gICCK/LT+T7Sc5ChVK2PE1+QP/Gm1rOO8PaZ8NR/q9qU
QXinTGx5f3ThjUyGxcr4KlPz8JDeUlP728I0bgXhtTKorp5aE72u/uljXvL7
uqn7ric9LYSXzvBBtilwm3jh+7xsrYvwc02MP5PGJNG8XYSXQv5GUr2G4bJX
7hgQUHTKc5nW8YbmK+sjEjZqWCBtYGkkTyX8TwKS9dOL8eTHKPkp52f5PhGu
rXlPzXr/R+CR8s0eri0fpoz/tZWHoKF5+YnPpIFYlSuf0PpCeuKF9lNQHucR
Xi3Tc5zg2p8q0jvCtd8GnQ9yKJqVZaQvdJ/yyP8ujnSlP9T/L9f5vmNg7z2j
IUH2t9ZnDO2HvB9WvzjyM4nyn0LzcFBeNzComBTYyJ8S6jeH8rqbIUsRk/gq
FvXyPln9UgXak2Ww8si/FdR/2tD3L1Fo/m8NnY9owrtvQG1rHqb7321g9vfj
H3Wl+0g=
                    "], CompressedData["
1:eJxTTMoPSmViYGAQBmIQbct1fXFBSLPDTrnW14GbSh2iUqzv+3s0Q+iTpQ6d
jglPLwQ2O+Q8/73y47lSh/J986X0O5odckH8C6UOYP2nmx3076qwNV4udXhY
JbLO/UuzgyzIgJelDts+/71SodLiMD1PqPmAWplD1p6SyRLeLRD14WUOh79q
xPSHtkDU+5Y5THPuznlu0AKxX7oMop+/xSFj4tsa+7dQ991udrDacqJsH9B9
7WI3z31fAXXfvlIHm/v+vdMnNDt4gByyE+r+kmaHB0DhPKD/3i8/5m2e3Qxx
z7pSB91Nc98vT2x2APp+h9zqUocjChuKMsKh8mug/kMKHwAzJJYO
                    
                    "], CompressedData["
1:eJxdVGtIFFEU3raIkpAeIpFWJoE9FNMyk7Q9lmJlKho5s45uu+O+lDJ7kFEm
Rtw7SYlJ5QMpMzMpRCKWEPOFlmlBiAYSi4hZ9qMiI7IkpO7dc3GhgdmZs/fc
73znO9+dDeqJDJtep9MlsZs/8zvO3FhdRUDHr20yFHXVrwl3EaguWHm555UM
seNp5dUD3vWRFHW5PEkgfGzj4ks2CZrqngc91lPYd/XYpz95ErDolDOQQhpL
i4mVwTVwtqs+hMJfflXLsJ58Tm+LoHDaWfm1eFSGK/Hmj0ORFJ7+mHt7blCG
Kg60ncKX9LZ15JmId4n8Ihl8w57c/hZHwWe0sTAuUoaJ836tSQkUTO0Hlund
EvJLpzA1FOyebZUw30nhoiHK1N4gwaHosngzEfUqJeyrXOA3S5Bl3T2eViPw
t8iwQo5xDTRR6GQyLeqXIZnv76Mwsym7ojdMRhw/DdyzJfkd1zIhlJVrNmi4
f68McfwlQIMALthDBest1UDzf/fmV24OTHIBV2lwL5EhZZuAdbFVS9XgJS+0
3wy9P1khhwZcpuBuM3jmVawhnz2W+TgkYklLoOqN1/JG6izIr0iDI1yIRgvk
VDDETFHvrgXyWNuGnRqw3yjTHQvqHaohrxYLPgNFvRkLlHEiOtFfgYr96TXs
67eKfQUJPa7n4jxiNLjAxjThY0V+vqK/UisoXO8ZCt3MdmM9VvTPawqrmPsa
jDb0YSvFfkZsuF4g5jNlR37hFB59H05RnQ70o5sAY3F4kjhwfyNBvFoH3C/k
jAnmT9uRL4s9eP52OMj17yRQzjcm2HDeCylwexgmchEvg6KPUlT0i0yhhv/v
q+K5UIQ/5o7CdHN/crSJIl5pNuIkCf7DCnCbljD/e/TaoWA/m0V+kILzmiLo
3wUK1n1AIJXL+iELda8leP4Gs+A9Pw+UYJ3ELHjB9TpOoIHP+6YR8+1iPcqI
+psIJPD98TLqYxT4Lgn9rIjzfkvCeTu9sQfvpDfu434lZP48/v99+Qe+3O82

                    "], CompressedData["
1:eJxdVGtIlEEU3SKyLKWHRQ8TszJ7qohEmXmzRDPDHuqPqNhvx91ZNEsyCuyb
AemlQpmFJGlIWdFDxR5GVFZU9ISwB2RYbGbij7DSUjExmpk77RctLLuHuXPP
PefeudMd29c7h9psts3iK383ZsZ4Ut8ymB05oibwhB0iPswcXtDO4NDxbeP2
3rPDsUnDMvy7GHSacdFbflt48bUnu+7MMLz48epFRcs3GZDUmh9QN8ggdHhB
2YpsA+NiONytmhL+wTQwzwGOfEcNuN8TtqkkjUO45G01INb3bXXuZA5L5L04
B9jkJ4CDTG8vckDb2YqHwUk6vkifmxb2X3Dl5LfXHFJkfI8DlL5WDvu/rLsR
lEAwroPDKEETm0VAiHx2qk3zVRBoCmnp5806voEg7y0OGTJxHwEZVrWPw3h5
r5PASxmfz7GOMwSC63e4S7drvWkE3KVC8WYOuVKYwHMPTnz3IopDvL29KaSa
wDKpt4chz+RMzPOTwbsXfRva/JyQ0zFwoSuCw6WuV2sclU7kXcMhTyb2OPGe
wNOk0DYnlMu2hen657jQzyEc0mX9eS70Q/R3luyPD8V6+hj6MZd6+6f8i6ag
xiCQw2H5Zz6FPQF1ia1LOfo0kcID2b8sjvn6XNhP0Q91r9eF9ZVwuCjrD6Bw
I0hU9oSjvhwKDdLPYg6nE67/GPxI0a9w7fdjiv766n42Uqx/gHnPu0XaMb0M
egXt/U6Nuxnm9XWjLy8Z8ke4UV8tQ5/i3ejvVgY7JDFxoy6Bt9xcNXroP1jV
O9LCag7PU9S7luEclVHs/1TN94Zi/HcTSmSgjxt9eWTivHmoF6u+77Ow0r2Q
YlyXCY+kkcMo5Ev/l+n36q/15mv9EyjGmRo3uvB8JYMjkj/OBYlS/9/6PjsR
x2hc6MT3nK3fs82Jc0QZNO4UJ0GZ6H8UwzmsJXBO2FDvy/BdpRPkE3qVP5UE
8z03QY5h7G8CnlSxWcpN3AviPan5KTbR7xKC81pgwle5J5IJ9qdQn88j+L6v
6nyfHCCmor2pycQ5u+zA+F+mdx+ofoxlXqzqXmVhxZfIcO4iHbD7jni4flp/
s4F99Zg4T2JfKX2hDN7386zbYp8p/hQGLRLnGt75UP3ZaOFX8jfZwiqfv4F+
ntT+p9nxHdRYWPFdt7Dy86nev3l2+H9//wHKOZ9v
                    
                    "], CompressedData["
1:eJxNVWtsFFUYbRpDGi0E26YhgstDRSwh5WVMRfCIBVQkaAlo5BHS3YGZO1Mo
FUoVvDMbIg8JtBUNAsHyEBOThodKKWhaUgoFf/CQWm1lgaaxlSglUG1jGhLv
d7/LLJtsJmfn3u873znn3h1ZuLLASk1JSSlUX3o6lbfXv1wT4OO/3q6NHI9C
45YACwaN+3ZvVxSvp6eO3TQ0jkd/PVg89edYiDsO7WkckW6FWO16fknEQuOI
oyV2WhxXRv3+nyyx8MGt0RPS7gZYfEqtbLLw5HuxKTfqAxyYUdNzv2wZ3nxh
yytLPwlQPFV1+Go511sf8Lp5Nugxd02AZwbEP3/1iM31Cwy/2Q7zuOkz/wsC
3cSjTaK+6oncRKMHr6v/m7vbJY6fL62r+tLDNBrEksjccPqn/Vs8qO5/XJ4o
MYwarfVwY+62nSsikvsprPv3f8Tzl3qgtncUfnZCWvWwEo/r5ki0Xuyb1/Gc
x7wXmvoJl+fcJ/EY7c8x+zskz7vaQ21EMe+UzH+Nh4Z/xywq75awyYc8D7NJ
nx7J/bM9FNE8f5r6rS7zbZHcp9rFZdK9UaJXlWmIuzhJ9U9JqF/Fj2+5yPte
Ea6XrBtcrK1TQp2VqKDGuS7z+05i+84VGRvSXRDN4l2S/bwnmK8t2e8GgV/K
lMEzJc/9lGB+XhJrXcuTWOt9zfBrF9zvqkT+VuXUSJfnvSSxLuvwrPbpLsju
yiuGf8zl/b8ZvYpcEM3TvRJNtLHC5X3/SExXy0b1i1Af7c8xEepDMlRtFKE+
GaTnfBHqo/OTL0J9zlH9ySLUR/N8XIT6lJN+fQ7XVfqUkIFNJp9KnzbiP8a8
95JY8/40iXX9hOR8XXc4D80P9BGY1f5h1uFLhu8MEeqTm3h6QNwRoT56/SrB
ufj7Qd6NH30SKfTJEthM6ztNPtscvEb1EyYPPzgYuym79WLC5LHSwY4hjywY
1CXxIg2y0kEOve8z52WSE9bTPtTZGEjzNEl8QT7ttvG1kuOo0ns0rd9q8zxn
JK7R/J7N+ncYP1+y+Znhsx69y9n3TJ/rdSexnrN2WYj1+hqLczrEZ37vW5zX
8T6fp5kW83zDx3wSPtNiv+f47N9DWOuVn8T0SJRZ7MM6n/U9abF++5NY169O
4iV0D/b4Jt8WIppwwOfhWAyLKEj5Ad4hPsNjuDqncPC7bsD5OhjlvJUG7M+e
KE703G8uiwfMd0cUZykQ2wKjbxTanoqA+W429/lnAZ+DjVG+3w4FfG/uNvf/
Q/8H/wPhWdiy
                    "], {{484.76599999999996`, 196.805}, {
                    484.76599999999996`, 199.41}, {479.387, 202.195}, {
                    472.953, 202.918}, {467.758, 203.5}, {467.672, 203.465}, {
                    467.672, 200.871}, {467.672, 198.72299999999998`}, {
                    468.48799999999994`, 197.879}, {472.074, 196.316}, {
                    477.83599999999996`, 193.809}, {484.76599999999996`, 
                    194.07399999999998`}, {484.76599999999996`, 196.805}}, {{
                    490.66400000000004`, 197.04299999999998`}, {493.289, 
                    199.42200000000003`}, {494.53099999999995`, 202.254}, {
                    492.953, 202.254}, {491.137, 202.254}, {486.32, 197.93}, {
                    486.32, 196.30100000000002`}, {486.32, 193.758}, {487.215,
                     193.91}, {490.66400000000004`, 197.04299999999998`}}, {{
                    485.07, 204.75}, {485.29299999999995`, 
                    206.22299999999998`}, {484.383, 207.20299999999997`}, {
                    481.65200000000004`, 208.43800000000002`}, {475.77, 
                    211.094}, {468.734, 212.324}, {467.039, 
                    210.99200000000002`}, {463.91799999999995`, 208.539}, {
                    465.9959999999999, 205.24599999999998`}, {471.039, 
                    204.65200000000002`}, {473.07, 204.414}, {475.824, 
                    203.797}, {477.16, 203.277}, {481.03499999999997`, 
                    201.77299999999997`}, {484.72299999999996`, 
                    202.45700000000002`}, {485.07, 204.75}}, {{485.07, 
                    212.63299999999998`}, {485.387, 214.73}, {484.043, 
                    215.48000000000002`}, {473.08599999999996`, 219.34}, {
                    464.90599999999995`, 222.21899999999997`}, {
                    461.28499999999997`, 220.859}, {463.89799999999997`, 
                    215.895}, {464.809, 214.164}, {466.34000000000003`, 
                    213.375}, {469.76599999999996`, 212.859}, {472.316, 
                    212.477}, {475.801, 211.73}, {477.508, 
                    211.19899999999998`}, {482.074, 209.781}, {484.715, 
                    210.281}, {485.07, 212.63299999999998`}}, {{490.562, 
                    220.02}, {492.215, 221.695}, {493.566, 223.672}, {493.566,
                     224.414}, {493.566, 226.816}, {487.039, 222.562}, {
                    486.207, 219.617}, {485.207, 216.08200000000002`}, {
                    486.824, 216.23}, {490.562, 220.02}}, {{485.074, 
                    220.516}, {485.43399999999997`, 222.906}, {481.457, 
                    225.062}, {473.637, 226.72299999999998`}, {467.902, 
                    227.941}, {465.371, 227.25}, {465.801, 224.586}, {
                    466.03499999999997`, 223.129}, {467.945, 222.066}, {
                    473.367, 220.375}, {482.039, 217.668}, {484.648, 
                    217.69899999999998`}, {485.074, 220.516}}, CompressedData["
1:eJxTTMoPSmViYGCQB2IQrX9Xha3xdJ1DgS3X9cVfchy02sVunsuud+g/9FUj
pjnXweNhlci6ynoHNbbGqc6v8xwuKt3+WfeozuGbRkz/Ic98B8stJ8r2La5z
WOS67fPfgnwHd5D66joH2agU6/vRUH5ynQOQdH/Ilu+QMfFtjX0gVP/RPAfF
DUUZE2PrHCaA7PPPc5ieJ9R8oAzBB6uvR/CvVrxUM2yrc/A273RMsETwtwKd
MV8OwRduPnBq4cJcB5C3CibWQtyXkeswWYIljE+31mEGyJ5zuQ5WIPdz1kL8
9SnX4YF/7/S8XzVw+8D+E6+F88HhoYvgV4P8ZVPrcPPc9+DHa6HyhrUOQNOy
9nzIc3hXY28ap1QLCQ/vfIcLIHu+1DgUgzyWnQ8R31gDCX+PfAchkLulaxxc
unOe//6ZB4kP+RqHffOl9O/OyHUA+vrphR01DnG7PHmYmHMdjoECwqzW4fHS
2UcUOnIcQMb5e9Y5FILMa8hxQI9fAIGY6Mg=
                    "], CompressedData["
1:eJxTTMoPSmViYGBQAmIQbbnlRNm+9DqH1teBO+Q48xwmS7CE8RXWOczIE2o+
IJXnsMh12+e/OXUO3zRi+g+Z5jnYcV1fXBBb5wCibP3yHLzNOx0TrOscwOY0
5zmU75svpW9b51CUMfFtzeU8h8NfgRqToObp5TuAlM2vq3NQZWuc6lyc73C1
4qWaYRPU/Jv5DlrtYjfPddc5yEalWN//WOhwQen2z7o5dQ65z3+v/JhT6jAd
ZM49qHu5Kxw+XfJNEjCrd+DT3TT3/eoKB6Brnl6IgPJfV0Do4HqIPW8qHB4v
nX1E4VcdxJ/rKxze1tibxrXVOeyQA5qYUOFwDOQhvToHK5BDf5ZD9D2odYjd
5cnDlF4Osd+n1kEb5M7AMgeFDUCfStZCwulOCZwPdt/BQjj/Esgfv6D+l6mF
2NOSD7HfrBYSHvr5Dh0g9/vVOlwEqb+XB3FvQK0DkJe150CeQw4oHOyg5mXl
QcLLuBYSvkZ5EPfp1TqAgt/+b66D+8MqkXVAeXB4fs6F2B9S6wBUdWrh1lyI
/S51DuqGHGtkjuU6oKcHAMJ3/wg=
                    "], CompressedData["
1:eJxTTMoPSmViYGCQA2IQfVRhQ1HG1UaHY97mnY5hRQ7TnLtznl9vdODT3TT3
fWyRwxXfJIGIS40O0/OEmg+0FDl8ugQUONnocOirRkz/miIIvavRYeuJsn3z
XxU5zACp29LoUC2yzv3hlyKHrD0lkyUWIPi2XNcXF8Qj+J48TNrt3xscls4+
orBBr9gB5IyEngaHqxUv1Qz7ih0uKN3+WefXABE/WuzwGKTQsgHijkvFDvKt
rwN3GDY4MIDAkWIHgQjLLSfkGiDqFhQ7ZE58W2Nv1+AQtwtok3exQ7vYzXPf
8xog/pUrdqjYN19Kf1YDxB/fihwqgdZyCDc6aIMUHi1yiO0Hyngh+GBzsxB8
magU6/tAfu7z3ys/HipyWAbyR0Sjww45oMP6ihxA0v7ejQ7AUDm1ML3IYdvn
v1cq8hsdrLYAAyy1COKvZmj4phQ5LC4AhtC8Roi/44og9JpGB15QfIRD3Xeh
0aHDMeHpBTeofiQ+enwCAHk04P4=
                    "]}]}}}}}}}, {{{{{{{
                    Thickness[0.004633204166666667], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{CompressedData["
1:eJxTTMoPSmJiYGDQZ2RgYAbSDEAOIwMjMzOQhDCIRPjVw2WJN5ZIlQSVUa6A
bPVoKqnud2JMINsNBGONoMn4FVArXkhyJIWxQKqbKYxHAMnLCKY=
                    
                    "], {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}}, {{1, 4, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}, {{0, 2, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4,
                     3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 
                    3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}}}, {CompressedData["
1:eJxdW3mcTlUfH0v2d5IlS/LawovIGybkdWRJRQl5HmY1Zox1nvusgxbPvffZ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                    
                    "], CompressedData["
1:eJxdVn9MlVUYvlErhoxlOgdU5iVrFBr0B0uTHy9REZojbBmGohGEawy/8+nw
2i+753R3s1aGZrTKzJtihjEzQXINGhiKtbIuacWcQD9YlwI0aznLdc55H/la
bOzb+51z3vO8z/O87/38lasWVcf5fL4G/W+eZ75eWHlliaKmNw7N2HvIoYvx
7fuP1Hf0O7Sy4bcn82cr+mGn3pAqyGf+JinSb7Mr7hC8f1xS0ux9W8ceFmSO
bRuRVDt8fvfpSkFdf6Qv3ajj0Ehp+/RiQW2//9MX0LE9lybosY/XbE7+XlJG
eNp3X3TivqgXa1Tuyi+9+DqTqFdSxcHixLioQ/NOlbzY2CPJPOpiDmWenHl5
sBt4LsF9bZL6Ar/ceGuWoFaDb7fke0oFDT0+taVok6SHqkwmwXU+I+kq9cnR
7Q8IWtuxLTVzlaS5pjC/oB1ObsKJUklP6GODow5tKFjx07E7vdjyWODFtj4d
9yy4bUNBAvAUSppi8mcIWqdhxd8NvCWIdb7X6jSCWkG6yoxwnqR6g2O1oLyE
E+84c8HnOkGDBn+2pFeSL1uctNaLrQ51/1svR75EybpccOjVwhdqhy/1YgNz
hc+LLf/ng3w+RdC1hqi/gsAhqE/LWPZnkG42+iyBH85gv+bT8joWZL6bBeUY
oX4Nsk69gvPr/ZG7NDP7BY3t0kz9HWT/PYV8SdArBfr5JX2V1n/u6cU4Pwv6
BnA+G/57U/C5bPD/rhf79bGGDwXXPwf1tguKmnpyJd1reNDrVget33GTv0Ww
TkWS8YWg1wLJfOj6zfKu+6B/vKCA0e1Ryb6ag/0u/L8I+dZLet74aA3WQ7g/
hPMvSTIyDkYEmTR7dWx9F4Ef35bcl8/ifLOkRoPbxf6DwFeM/uwGH+nQ43P0
0xXox28ktU/XDtP+tbwcR3+cdjj/t1g/6/D7fugxDf44Cfy50GdA0mFzXxXw
DAGPrm+L4X8I/g6j334EHy8LmlymO+96xfznwU/zFN8/VVCuyTNf8X3nHN5f
prg/hh32Qznm2YjD+ixTNGrm17hDs0y8XLEeyWIitroUerHl9znwu1Qxf6/D
b0WK6+lEv2ViPQa+b1HMTwz13KC43s8ElZt6UhXzHMF6Iu77T2z9c9SLbb3D
6OdTmB8Purwe9WI7L495scV7GHznu4yvQ3L/zXC5vjb4Jw759sCvMfjjPfg5
hnn2lpyo18jSXiFpwMzjgMt5KnB+kxdbPppcfv8I+nu7S+MGXx3wrXc5Xz3W
q132TxjzLc/lujZj/SbUuwf9cEFw3Ir74l3Wp1PSNcZI5ai3C/N4NfD1oB/C
LvdZrxdbP/d5sZ0fk+C3ycA7RU3wZXW9WnGeLkFZZu75oe8o5ku64nvTXI6z
FD9nujyPchR1mzxn0R8FivkdgB5LFPPRJuiA0UMoMjAbGuGXrfDbcvRfE/yt
1+3vZzPwH8C83afYD0eQvxX904n5+5Fi/j7Aegvy3S/oU3PxTkX3GKLzsb4D
3xc50GML+mUh8IYUz8sqzMMa4N8omLca4C+Ev2qANwW/h9U4/7PD9VUifxTz
aRni973vG8t3xIsvfv/8C0mFJgw=
                    "], CompressedData["
1:eJxNVGtIVEEUXoQkpIeJRNjLykyysJKSNPPT3plJ0Q+LTRdLEhFbPBfxEYUz
mFqIWZCKiflKhAiJUntZmGUIhZQhRbYtFfYyUxGSkJrZOT+6cBnO3plzvtfs
stSTB9O8bDbbTvXqNe9r8PqZ2QLjLxNSfYMJ+yJKYx3RAjb9nOZ6o8DH5pqe
wIuEPbO8Qos3CYQWz3/z4h5hXtLmW88iBAZyVaMvhNGWp/ERUcKce8C16te5
pOj7gSZCesXIqZh4gXOxjs/9qv+ctTdrR+0COV11AWHHeH+BML+HE0r1vjKB
5LtqcgoZnFUC1xScthzC48kQe/lVgXz/G7vcCt9SNaZT1X7yUV99LcFe3j0Z
Ui+wWuO9Q9A02hoFtvoMNjo7CK9Uu6RegcC27PSKPIJHj2GBbt03jvmqWqEq
jY1j/D8YXxph0ZHjUa6fAkqFnK485jPCfOoIuXr9JtCwo31iupP5uFhvm4Um
Z7TPoFugMksh9rGwV88b4/4uxjfFePq4/wyJD4lllVnXCR0T0wO5syUKNP8r
hCiX+hAgDd9CQo8mtlDitfZHEDTcxECJKj1P+ZFx37q0YIU0/RU+jy4rJTKH
/7SOvSOsGwryLlR1mF4nCbcVzTpVe/Kw3MIv7VecNH67CZe3nc8ctkvjbxPj
T5HQ8tQ1kOlzQpo5DwlubVwm8+nn2imNzlN83sn4AyxE63NOxr/dMn5mM75E
y/DJlYZnjGVwFkr0av+CLDRqvfOZ71vCUZ2PDIlIDbCG/UqWJl9ZhHat736J
3RqY8nNA44mUJs/vCWuUHS3hPG+IjI/B0uShmswc5YcnJ4fJ6OAnTR4O8X5v
iU8a51nO91+BxXp/M2GL9nOa72MD5/m3MPqksH/jnC9/Mro853wnEJ5o/1v5
vhZx/2q+Pw6uLwijzz6eV8LfN5DRu4TzuIqMniWcR1+CPuY4w/3ncr///k/+
ASkHAVA=
                    "], {{648.8359999999999, 326.855}, {646.438, 
                    329.01599999999996`}, {644.7850000000001, 
                    331.07399999999996`}, {645.164, 331.43399999999997`}, {
                    645.543, 331.793}, {645.9689999999999, 331.895}, {646.113,
                     331.65999999999997`}, {646.254, 331.43}, {648.215, 
                    329.367}, {650.4649999999999, 327.082}, {
                    655.6519999999999, 321.82}, {654.586, 
                    321.67199999999997`}, {648.8359999999999, 
                    326.855}}, CompressedData["
1:eJxdVG1Ik1EUXsNETGRJNBG1JdH6oKwITMx6TMWkQupHiEoNSRgVNuLespDi
vS8hDkJEwyiij1WSREiNkoiKKBv9EMs+aGZWGvZBmaaklNS97z1r4GDcnfvx
nPM85zmbX7lvW5XdZrMVyq9ab/6cel7z0sDl0w9d7d8ZbOrzyEBa2a6c/jSO
H62dm7I6DRz7urUjPZcjN/5VwNdrQO7W5/k4HKXZwdAXAwfvnk3JPMFRn+f5
2D1C56c41vaXHG9JEFin3jVxzFb30wSak2O2JzZwtFQnmfc3CJ0/grdDIHHZ
9TPDJRwDl+TBUaHXJYR3TuCkeufgKE6wL627LaC2q+M56ua+7vrVLXChUDKL
4ejZUukoHRDYO/T7yog9Glv8ZkZjv6o7jmv+YYEDio+bIxiSv7qo/mKOB+OL
KhpuCL0v+Vn6BQUUXEmA3vcQn/0c5Wp/lOoF6eM0NZ9VhLfHhLfxW+36LMJr
NrHx/eE517I55inha02dz0t8y02tbxvXuFWE186hsnr9Jp5m9E4e8ZHeV03N
bzXxaSO8FRwfZJqiShMvaj4vXJlB+PkmRp9JYVKp3xmE5yJ9YyleznHRJ2/0
CWyW5Xjyuebxhvor40MSNm5QILNvQazhJvxPArLqJ+edpMcw6Sn7Z/loLBpb
/Z6Ydv5HaN3s0djSYYL9jy0/hBmUTJ4A1TPOtK9qhOYX4eMUWk9Bfpwl9Orn
uo9jhtanlvgOGRhUejN6HzbwTuWrIH6ReSog/R8bmn8k/19Dr7cYdt9hTclO
8vsU03rI+bDyJZGeqeR/F/XDQX5dw6FsUmQjfcoo3wzy606OHCWExFe2aJTz
ZOVzC3SkS2MVkH6LKf8k0/OXQv59y7Q/4gnvHoO61jpI8x1imP7/8Q9/zftP

                    "], CompressedData["
1:eJxTTMoPSmViYGAQBmIQbct1fXFBSLPDDrnW14GbSh2iUqzv+3s0Q+iTpQ6d
jglPLwQ2O+Q8/73y47lSh/J986X0O6D8C6UOYP2nmx3076qwNV4udXhYJbLO
/UuzgwzIgJelDts+/71SodLiMCNPqPmAWplD1p6SyRLeLRD14WUOh79qxPSH
tjjIgtT7ljlMc+7OeW7QArFfugyin7/FIWPi2xr7t1D33W52sNxyomwf0H3t
YjfPfV8Bdc++Ugeb+/690yc0O3iAHLIT6v6SZgeQcB7Qf++XH/M2z26GuGdd
qYPuprnvlyc2OwB9v0NudanDEYUNRRnhUPk1UP8hhQ8AMHyWCw==
                    
                    "], CompressedData["
1:eJxdVAlIVFEUnUzCQqRFJGookyArRbNVyjyaYpuZBv4/M2ozozNOUrYgGSFh
xHsvyaiozIhSM5NAJGIIsU3asIIIC6JMxLQF2ozIkgh61zso9OHz/+Xf5Zxz
z/tz3DtzPEEWiyVD3/QsuVl2cnqNgIWueBPlt+tmxPkFakunHup4bGJVb9bR
M51j359nuieb/QLxPXMnHPQYaDp3P/JqkASObP/wZ5sBHe3xWSU26rTEVSb8
nXtv182TXF9rYrb4lN22SKLMd+JLxUsTh1Oc754lSPh//H2x75GJmjW60WKJ
z9lts8SNQLwikF9uIiz22vlvSRKhLxt3JSWY6Nsf3pqRJuFsXxca1G0wvmyJ
j8+iuodbDc73SVQmLy1obzCwcXlVilNItNG8EwbjOhro32zAXrSyN6tWIoT6
LzAxxUz0dzZJdGiZgh+a2ED19yR+R+cduxtr4jr1CVd4M3yg5GZ1LmL0uOZk
xfhSTSRN0i8zFabHacGuOHjeRIXqiFdPfxXmo58EnKZQn6475RVAs1ioNik8
pEFrnbj7Uw8qVkjVMkXdcWJkXxUK9Ahe7RqNoxeFtFjdY7GViJxzMb5yhVwS
otGF/GO6Y67CRZpX78I2TTt5mcLXCi3QBRfrHaMwQLhaXIzPGpg35EIV7cui
QLSSSt3ML0gxr99uKOIVGdDjeCHvI1GB1tQ3qYjxhSl0Er/KIjhI7yGtr7Zd
T0cR++eJBLmvwebBGfJhq2Q+zz38vVTy/Pdexhcn0fK9K9PtK2Y/dgu8fvpr
S78o5vpGwf3OFuPSLkIsOH/Qy3h1PNIvwov1pP8tgWoqTPPwvsdLlJBOfYXc
L0eyjzLd7BdT8nkJc4PWfNAR8MffrRhs1psskDhOhZV5IJslZwT82+UA2fSA
9v+IXksczGd+ID/Swft6L9i/4xw897LAZpJ1wM66nxV8/h7Z8ZaElgLbaU66
HQ9Irx2C/XXKxvlewTiW2lj/AoE0qk8xWR+b4PPrN9jPDoEY4nXa4H37xuKR
frvH4nvkVyFGz+P//5d/+0nqVw==
                    "], CompressedData["
1:eJxdVH9MlVUYvjmWxYT1A10qMqPGCDVwzjUl4MlyoMHUQv5wwu53D/eeO0xg
6Wqj75zNhSauImtOlzpnVrOGTk2YU2CMGqFtDq1N+8FuhMw/GBoUMHO6znve
4/1ad7v7vmfn/d73eZ73fc/TkYbXojNCoVC1+dNzU21hYt01hZylj7RlfhpG
weCzD+8YUfhwf/0T7/aE8clTKVXp4wq3/JLlNfcDvPJs/1vdz3hJ3PfqCy0v
bfZQNtSUcfKegsmy7+UtHlZQXKFGz5F5+YO+hzHKs0sjl+p97KF3Mndza6Xm
ukMeilKvHWucqzl/SQQh+mVolJv04ZYIhr84+N3CMhff4s79AKcvOXP49o8u
fjICq29Io3l0w7ms1QL5FHdTg8oU1QkYkZeODrt6BwUGsn+9o6+7+HYBkhW+
oFFFiacFKOxIs+bvxgSuUHyTZh6fCyw89WZ8b4NGN+mtFIjvNYqrNRpJmMF5
7835+fIyjVXhkYHsYwLFRGRSMd+5tZznb4VfLk+/PpwWxdabd78aL9D4evxq
ReRQFE9S3QqN7ZQ4EWV+BmeS0OEoDlDbcjV2Ef/nYuznQ47/thj7YfqbQ/2Z
KZnPtGI/8mSyf5bPcgk7Bpka79PLYol3Mk6WDr2ocZV0z5H4lvpXpznfdIz7
afpheUzFmF+r458hcS5r5+iGfs36tkq0k597ND5b3fHXvd8l+5Xv+H4v2d9U
188uyfzvquT5hEn72JTClCnbO+bwhOI+pcaxgD64otBG9QvirO+EYn6r4uzv
G4r9FHHuv8Hh82tmzfgPtnwfDfANmsPjkvWuVzwP+yT3f75ivT9Jjv/Tx0cU
ODPOfvb5PG8JmcS2780Btt89Lzlu3Of9SpFoIv+L3b6mO71NTv9syXG+w10x
Pn9Fcf2SGEpJ/wN+N6KMC50/u6O8z1sU+ilPKIqdNEdSoXO7OcmqZf+XOb0n
BL40NpxKVbx/GwXXM3qtP4cE5/vB5/m6L5BY98H++gNOv9knOz97fPa7VfC8
7vD5vlkruD+7fdTQ+SLB+/2Nj1mU748IzFSMDAz4PB+nIxz/j5+8D2w/HldJ
bPdnTYBtvVKFOpq7pRG8TYub5u6z6x7rTPjooHky95XVl2Pm4Y6u6zT3ma1f
rvAb4UYvOR+2P5sCbJ9rA2znM91jPw+7flSGeQ/aAmzrdQTY+nnR3b/bwvj/
/f0vArCfhA==
                    "], CompressedData["
1:eJxNVX9sTWcYbmSRZulkaxuRza4fE7qKYJuI0Xm2VW1+xBCyjIj03sM53zmo
ooruO+cGpTO0bLMRis6SJY2xTVe2VFO1sj8wjLUUTbd2C2rWaSONxPd+77dz
3eTekzfn/fG8z/N83x2Uu2yW1SspKSlXfenplN0tmlgVYMPtmdWRY1Ho+EqA
uX1GfLu3PYp3U3oN3/RCHClXK/KyLsbC+I9De+oHplhh3FE0ccyCiIX6gUfy
7eQ4Lg6+9lDmW1jz99DRyfcDLDyhMhssvPhBbPzNkwEOTqrqfFS4CNPGlry5
8KMAeVlPX634cjH3KwrQn/Jm26DHjFUBhvaOf/r2Nzb3n2XwTXXQSjhu+Sgm
/GcF42iSqCl/fmRzvQevvefr+9skjp0pqCnf5+ENNSbPkkhbX/vLgRIPavqf
F16RjGu1h5sztu5aGpE8T8V6fs+HoLKsAg809p6Kh41Oruyf73HfTInGc92z
W1/2uM88iVTq3+zynvsl12ea+lbJ+670UB3ZeHtmm8RGwr/KQ92DjPnbOyTr
MM7DVOKn09T39bCE9vnL9G90Ge8VyXMqXVwg3uslulSburiL49T/hMT1h1L8
9J6Lcd8rwCcl2og3uFhNRJ2WKKXBI13G953Ex7uWpq5PcUEw876QrOe/gvHa
Ev8Qz3UCvxUqgXMk6/WSYHxeItbP7YlY833d4GsRPO+SRM4WpdQgl/c9L1GU
fnhyy1suSO6yXyWaCH/M5frfJeu9xAXBrO2SOEOFpS7WUd1/ElBpg3tEyE8T
6XNUhPxUkW7FIuRH8zlHhPxo/2SLkJ+fqf9rIuRH+/Y5EfKj+et2QOXlip+V
thKwwfgzx/CfYd57ibiB+u5IxLp/s/If+euGw364/D8/ApNb1qYfPm/wThIh
P6Oah/SOOyLkR+cvF+yLOya/xOjRLZFEn3SBzZTfZvzV5OAd6q/mb6PBPzoY
vqlv4zkVC/JjmYOd/Z6a26dd4nVaZJmDTHrfbc7Lq07YT+tXY+MZ2qdB4jPS
abeNrxQdRxTfQyh/i837nDL6ejbz32r4nmAzP6k+89G1mM9Jmo/PqV9HItZ7
Vi8KY51fZeEu+bSfz/hWWOzXUT7vm2OxX6b4fJ+kWaz3dJ/1eyLWfGUn4lry
R6HFvK7z+XncYv4OJGLdvzIRL6B7sNM3/rYQ0YADPg9HY1C/DzKyzf02IIZL
03Offd8N2F8VUfZbQcD67Inih85HlwvjAePdGcVpMsTWwPAbhZanNGC8m819
/knA57k4yvfboYDvzd3m/n/i/+AxP5jYyg==
                    "], {{
                    484.76599999999996`, 196.805}, {484.76599999999996`, 
                    199.41000000000003`}, {479.387, 202.195}, {472.953, 
                    202.918}, {467.758, 203.5}, {467.672, 
                    203.46500000000003`}, {467.672, 200.87099999999998`}, {
                    467.672, 198.723}, {468.48799999999994`, 
                    197.87900000000002`}, {472.074, 196.31599999999997`}, {
                    477.83599999999996`, 193.80900000000003`}, {
                    484.76599999999996`, 194.07400000000007`}, {
                    484.76599999999996`, 196.805}}, {{490.66400000000004`, 
                    197.043}, {493.289, 199.42200000000003`}, {
                    494.53099999999995`, 202.25400000000002`}, {492.953, 
                    202.25400000000002`}, {491.137, 202.25400000000002`}, {
                    486.32, 197.93}, {486.32, 196.301}, {486.32, 
                    193.75799999999998`}, {487.215, 193.91000000000003`}, {
                    490.66400000000004`, 197.043}}, {{485.07, 204.75}, {
                    485.29299999999995`, 206.223}, {484.383, 
                    207.20300000000003`}, {481.65200000000004`, 208.438}, {
                    475.77, 211.09400000000005`}, {468.734, 212.324}, {
                    467.039, 210.99200000000002`}, {463.91799999999995`, 
                    208.53900000000004`}, {465.9959999999999, 
                    205.24599999999998`}, {471.039, 204.652}, {473.07, 
                    204.41400000000004`}, {475.824, 203.79700000000003`}, {
                    477.16, 203.27700000000004`}, {481.03499999999997`, 
                    201.77300000000002`}, {484.72299999999996`, 202.457}, {
                    485.07, 204.75}}, {{485.07, 212.63299999999998`}, {
                    485.387, 214.73000000000002`}, {484.043, 
                    215.48000000000002`}, {473.08599999999996`, 
                    219.33999999999997`}, {464.90599999999995`, 
                    222.21900000000005`}, {461.28499999999997`, 
                    220.85899999999998`}, {463.89799999999997`, 
                    215.89499999999998`}, {464.809, 214.16400000000004`}, {
                    466.34000000000003`, 213.375}, {469.76599999999996`, 
                    212.85899999999998`}, {472.316, 212.47700000000003`}, {
                    475.801, 211.73000000000002`}, {477.508, 211.199}, {
                    482.074, 209.781}, {484.715, 210.281}, {485.07, 
                    212.63299999999998`}}, {{490.562, 220.02000000000004`}, {
                    492.215, 221.695}, {493.566, 223.67200000000003`}, {
                    493.566, 224.414}, {493.566, 226.816}, {487.039, 
                    222.56200000000007`}, {486.207, 219.61700000000002`}, {
                    485.207, 216.08200000000005`}, {486.824, 
                    216.23000000000002`}, {490.562, 220.02000000000004`}}, {{
                    485.074, 220.51600000000002`}, {485.43399999999997`, 
                    222.906}, {481.457, 225.06199999999998`}, {473.637, 
                    226.723}, {467.902, 227.941}, {465.371, 227.25}, {465.801,
                     224.586}, {466.03499999999997`, 223.12900000000002`}, {
                    467.945, 222.06600000000003`}, {473.367, 220.375}, {
                    482.039, 217.668}, {484.648, 217.699}, {485.074, 
                    220.51600000000002`}}, CompressedData["
1:eJxTTMoPSmViYGCQB2IQrX9Xha3xdJ1DgS3X9cVfchy02sVunsuud+g/9FUj
pjnXweNhlci6ynoHVbbGqc6v8xwuKt3+WfeozuGbRkz/Ic98B8stJ8r2La5z
WOS67fPfgnwHd5D66joH2agU6/vRUH5ynUO1yDr3h2z5DhkT39bYB9Y5fAXp
P5rnoLihKGNibB3EPv88h+l5Qs0HyhB8sPp6BP9qxUs1w7Y6Bx/zTscESwR/
K9AZ8+UQfOHmA6cWLsx1AHmrYGKtw2KQ+zJyHSZLsITx6dY6zADZcy7XwQrk
fs5ahwsgf33KdXjg3zs971cN3D6w/8Rr4XxweOgi+GB/2dQ63Dz3PfjxWqi8
Ya0D0LSsPR/yHN7V2JvGKdVCwsM7H2LPlxqHYpDHsvMh4htrHApBDvXIdxAC
uVu6xsG5O+f57595kPiQr3HYP19K/+6MXAegr59e2FHjELfLk4eJOdfhmDcw
IMxqHZ4snX1EoSPHAWScvyc0PhtyHNDjFwB7QOjD
                    
                    "], CompressedData["
1:eJxTTMoPSmViYGBQAmIQbbnlRNm+9DqHtteBO+Q48xwmS7CE8RXWOczIE2o+
IJXnsMh12+e/OXUOXzVi+g+Z5jnYcV1fXBBb5wCibP3yHLzNOx0TrOscwOY0
5zmU75svpW9b51CUMfFtzeU8h8MgjUlQ8/TyHUDK5tfVOaiwNU51Ls53uFrx
Us2wqc7hG8j8m/kOWu1iN8911znIRKVY3/9Y6HBB6fbPujl1DjnPf6/8mFPq
MB1kzr06h1aQe7krHD5d8k0SMKt34NPdNPf96goHoGueXoiA8l9XQOjgeog9
byocHi+dfUThV53DFJA/11c4vK2xN41rq3PYIQc0MaHC4RjIQ3pQ//wsh+h7
UOsQt8uThym9HGK/T62DNsidgWUOChuAPpWshYTTnRI4H+y+g4Vw/kWQP35B
/S9TC7GnJR9iv1mtgyooPPTzHTpA7veDqr+XB3FvQK0DkJe150AeJBzsoPJZ
eZDwMq6FhK9RHsR9erUOoOC3/5vr4P6wSmQdUF4WFJ6fcyH2h9Q6AFWdWrg1
F2K/S52DuiHHGpljuQ7o6QEAve//BQ==
                    "], CompressedData["
1:eJxTTMoPSmViYGCQA2IQfVRhQ1HG1UaH497mnY5hRQ7TnLtznl9vdODT3TT3
fWyRwxXfJIGIS40OM/KEmg+0FDl8ugQUONnocPirRkz/miKHQyB6V6PDlhNl
++a/KoKo29LoUC2yzv3hlyKHrD0lkyUWIPi2XNcXF8Qj+J48TNrt3xscls0+
orBBr9gB5IyEngaHaxUv1Qz7ih0uKN3+WefX4OADEj9a7PB4KVChZQPEHZeK
HeRbXwfuMGxwYACBI8UOAhGWW07INUDULSh2yJz4tsbersEhbhfQJu9ih3ax
m+e+5zVA/CtX7FCxb76U/qwGiD++FTlUAq3lEG500AYpPFrkENsPlPFC8MHm
ZiH4MlEp1veB/Jznv1d+PFQE8UdEo8MOOaDD+oocQNL+3o0OwFA5tTC9yGHb
579XKvIbHaxAAZZaBPFvMzR8U4ocFhcAQ2heo8NFkL/jiiD+XwONj3Co+y40
OnQ5Jjy94AbVj8RHj08AglzhCw==
                    "]}, 
                    CurveClosed -> {1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 
                    1, 1, 1, 1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 0.717647, 0.], 
                    Opacity[1.]}], 
                    FilledCurveBox[{CompressedData["
1:eJxTTMoPSmJiYGDQZ2RgYAbSDEAOIwMjMzOQhDCIRPjVw2WJN5ZIlQSVUa6A
bPVoKqnud2JMINsNBGONoMn4FVArXkhyJIWxQKqbKYxHAMnLCKY=
                    
                    "], {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}}, {{1, 4, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}, {{0, 2, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4,
                     3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 
                    3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}}}, {CompressedData["
1:eJxdW3mcT+UaH0v2O8mSJblZwkXkhgm58wppoYT8fsxqFmMs8zu/ddDiLL/l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                    "], CompressedData["
1:eJxdVn9MlVUYvlErhsQynQNaJmSNQoP+YGry4yUqRswRtgxDrkYQrtn1O59O
r2XZPae7m2tpyIxWmXlTzDBWJkiuQQNDsVYUmBVzIv1gXQrQrOUs1znnfeRr
sbFvz33PeX887/O+35dWvXpxbZzP56vX/+Z57utF1deVKdrz+pFZ7x9x6DJe
cPDYuo5Bh1bW/7axYK6iH8yBVEE+8zdF0djGghz/3YLPT0hKmntgx/ijgsy1
naOSnhy5uO9staCuPzKWbdU4PFrePrNEUNvv/wwENbb30gU98fHahuTvJd0e
mfHdF52I1+9hnZW78ksP32Qc9UryHy5JjOt3aOHpspcaeyQN6Ucg5lDWqdlX
h7qRzxWI1ybpRPCXW+/MFtRq8tsnOU65oOGnprcUb5P0SI3xJLjO5yRNU58c
3/WQoPUdO1OzVku6yxSWJmi3k5dwslySuXZmzKHNhSt+6rvHw02Gx0IP2/o0
Plo6b3NhAvIpknS98Z8paINOK/4+SdeafMuAtb/GgD6xSpCuMjOSLzmPNYLy
E06+7SwAnxsEnTGBciQ1JF+1JGm9h20fAv+zV8JfouS+XHLolaIXV41c6WGT
5gqfhy3/F0N8P0XQjYaov0KUZ/MQNKDbWPFniDJNf5ZCD+dwXvNpeR0PMd/N
gnJNv34NcZ96BfvX56P3amYOChrf21M67+8Q8/0M/CWhXynoX5qkvvTBC88u
wf056G8Q93OgvzcE39O4xxT2jofNtfoPBdc/H/W2C+o39eRJ5kHbXzV9KIT/
FsG6KoYewuhXqWQ+dP3GvPcBSU+b/scLCpq+PS5ZV/Nx3oX+F8PfJsk6Wgt7
GPHDuL8F/qKC53QLzkehx7ckz+XzuN8sOW8X5w8jvxLMZzf4yEA/PpdUZebp
GszjCUntM7XCtH4tL99gPs467P9b2M87/Psg+jED+jiF/PPQnyHEq0E+w5J1
rOvbbvgfhr4jmLcfUd/LgqZW6E10s2L+86GnhYrjTxdc1/2K411w+HyF4vkY
cVgPldhnow73p0qRUYF/wqE5Bi9X3I9kMYltX4o8bPl9AfwuUzzPr0FvxYrz
6MS8ZcEeA993KPrK8BNDPbcorvMzQZWmnlRF3YbnKOyJiPcfbPVz3MO23hHM
82nsj4ddtvd72O7LPg/bfI+C7wKX8+uQPH+zXK6vDfqJg7/90GsM+ngXeo5h
n70pJ+s1bWn3SzKyCgRd3mN+3N/mYauXJpd/fwzzvculCZNfAPltctnfOthr
XdZPBPst3+U+NcB+G+rdj3m4JBi3Il68y/3plKzTStTbhX28Bvn1YB4iLuuw
18NWzwMetvtjCvQ2FflOU5N82fm5QbGfLkHZZu+lob9j2C8Zip/pLj+zFecx
2+V9lKvYz3nMR6FifofQj6WK+WgTdMj0Qyjeb43Qyw7obTnmr0mxHrTdvj+b
kf8h7NsDivVwDP5bMT+d2L8fKebvA9hbMC8PCvrUBN6jqNgQXQD7bnxf5KIf
2xXP/yLkG1a832qwD+uQ/1bBvNUh/yLoqw75puB9WKv4ffuzw3GqMY/92E9V
iPee931jeY56+PL3z7/RviXx
                    "], CompressedData["
1:eJxNVGtIFVEQvghJSJaZRNjLykyysJISNXO0h5SaFP2w0BRLEjG7OItdNQrP
wVRCzIJUTMxXIkRImNrLxExFKKSMKLKLRNjLTEVIQuqMMz9aWA6ze84332N2
16WeO5rmYrPZDpib1tyvftsXZiuYehWX6uGHEBtcEpkSrsBG10Wpdyr41FTd
63MN4eAil4CiXQo2Fy1/9/IRwtKEkLaBYAVvHAboC8JEc19McJiCGDr3RGqD
17mm8PuRRoT08vELETEKiiNTPg8Z/MVb79VMJCo431XrHXhK9ucrfh6EUEL7
ShUkPTSdk5F5ViogOq05CM9m/BPLbinI97obPWr4rTVtOk29THcP1tUgJJb1
zPjXKQggvg+QzzUoCHd722DvQHht4BL6Ffi0ZqeX5yLM+zGmGDdK9Jq6nwRF
Cf8fwi8NYdWJ02HOnwpC2wZyunJFz7joqUVw0PpNQf3+9um5TtHjFL9tFjTa
DZNRBZVZnrrbzYJD1G9SgTvhOIXfrPAZFPwFGpzxpRVZdxA6pueGHe6a9d9E
CKMX3pr1FiD0krCVmvNRCEQ33kdDBfUzeWQ8tq6v2KChh/ANvz3ky0YNZ8f+
tEx+QNg24utaYOr5dQbhvpFZa+r5eVhvwS/KK0pz3qMIN/ZeyRxL1KyzUfgn
az5XjxBIOGc0+/8UYTTPEM8UPUNS2zX7PCvn7cLf2+JzduG/z+I8szXjxlus
x6FZZ4TFPAs09BFBXwsayO88zX6+R0ii+cjQEEL5VUteJzXjZiG0k7+HNUQT
MZPnMPEJ1TzPHxG2mDiag6TfCDIvP83zUIXsq8ljNW04jkCPaz01z8Mx2e8q
fl6W+f6reH8Twm4yZk6+x3qZ59+K/UmW/KZkvryQ5+iF4hzjEJ5T/i0y/4WC
X6XgNulLkfqqYn9ipV+xvN+B7HexzOMmZJ6mntflgZz7JfkfLBG8//4n/wAn
LwFL
                    "], {{648.8359999999999, 326.855}, {646.438, 
                    329.01599999999996`}, {644.7850000000001, 331.074}, {
                    645.164, 331.43399999999997`}, {645.543, 
                    331.79299999999995`}, {645.9689999999999, 331.895}, {
                    646.113, 331.66}, {646.254, 331.42999999999995`}, {
                    648.215, 329.367}, {650.4649999999999, 327.082}, {
                    655.6519999999999, 321.82}, {654.586, 321.672}, {
                    648.8359999999999, 326.855}}, CompressedData["
1:eJxdVGtIVEEY3RYTMZNNIkVcsyWyB6VFYGLSMRWTCKkfISolS8JSZEvcqS2k
mLmEKISIhVGE1VaSREhtJhEWPVT6IZI9aM2sNOxBmaaklNTMnW9bcGG5fHNn
znfO+c7cJe4DOyrsNpstX/7Vs+3nzHPfS44r5x6ntH43YFO/JxzOkj1Zg06G
H82dWzM6OU583d6enM2QHf3K7+3nkKs1OV4GR3FmoPsLx+GOpsS00ww1OeUf
e8c4utT7swwbB4tONsYIfa6BYYHa7xRoSIjYGVvH0FgZZz7YLHBV9Q/h7RKY
v/rm+dEihiFF7LjQz5WEd0HgjDrnYCiMsa+qvivwTi5XRjNUL3rd86tX4FK+
VBbB0LfN7SgeEtg/8vvamD1cW/rmhmuLdxTT+oNC60llCHQf6mjqIf6FDA8n
l5fV3RK4rdalPsu/gICCK/LT+T7Sc5ChVK2PE1+QP/Gm1rOO8PaZ8NR/q9qU
QXinTGx5f3ThjUyGxcr4KlPz8JDeUlP728I0bgXhtTKorp5aE72u/uljXvL7
uqn7ric9LYSXzvBBtilwm3jh+7xsrYvwc02MP5PGJNG8XYSXQv5GUr2G4bJX
7hgQUHTKc5nW8YbmK+sjEjZqWCBtYGkkTyX8TwKS9dOL8eTHKPkp52f5PhGu
rXlPzXr/R+CR8s0eri0fpoz/tZWHoKF5+YnPpIFYlSuf0PpCeuKF9lNQHucR
Xi3Tc5zg2p8q0jvCtd8GnQ9yKJqVZaQvdJ/yyP8ujnSlP9T/L9f5vmNg7z2j
IUH2t9ZnDO2HvB9WvzjyM4nyn0LzcFBeNzComBTYyJ8S6jeH8rqbIUsRk/gq
FvXyPln9UgXak2Ww8si/FdR/2tD3L1Fo/m8NnY9owrtvQG1rHqb7321g9vfj
H3Wl+0g=
                    "], CompressedData["
1:eJxTTMoPSmViYGAQBmIQbct1fXFBSLPDTrnW14GbSh2iUqzv+3s0Q+iTpQ6d
jglPLwQ2O+Q8/73y47lSh/J986X0O5odckH8C6UOYP2nmx3076qwNV4udXhY
JbLO/UuzgyzIgJelDts+/71SodLiMD1PqPmAWplD1p6SyRLeLRD14WUOh79q
xPSHtkDU+5Y5THPuznlu0AKxX7oMop+/xSFj4tsa+7dQ991udrDacqJsH9B9
7WI3z31fAXXfvlIHm/v+vdMnNDt4gByyE+r+kmaHB0DhPKD/3i8/5m2e3Qxx
z7pSB91Nc98vT2x2APp+h9zqUocjChuKMsKh8mug/kMKHwAzJJYO
                    
                    "], CompressedData["
1:eJxdVGtIFFEU3raIkpAeIpFWJoE9FNMyk7Q9lmJlKho5s45uu+O+lDJ7kFEm
Rtw7SYlJ5QMpMzMpRCKWEPOFlmlBiAYSi4hZ9qMiI7IkpO7dc3GhgdmZs/fc
73znO9+dDeqJDJtep9MlsZs/8zvO3FhdRUDHr20yFHXVrwl3EaguWHm555UM
seNp5dUD3vWRFHW5PEkgfGzj4ks2CZrqngc91lPYd/XYpz95ErDolDOQQhpL
i4mVwTVwtqs+hMJfflXLsJ58Tm+LoHDaWfm1eFSGK/Hmj0ORFJ7+mHt7blCG
Kg60ncKX9LZ15JmId4n8Ihl8w57c/hZHwWe0sTAuUoaJ836tSQkUTO0Hlund
EvJLpzA1FOyebZUw30nhoiHK1N4gwaHosngzEfUqJeyrXOA3S5Bl3T2eViPw
t8iwQo5xDTRR6GQyLeqXIZnv76Mwsym7ojdMRhw/DdyzJfkd1zIhlJVrNmi4
f68McfwlQIMALthDBest1UDzf/fmV24OTHIBV2lwL5EhZZuAdbFVS9XgJS+0
3wy9P1khhwZcpuBuM3jmVawhnz2W+TgkYklLoOqN1/JG6izIr0iDI1yIRgvk
VDDETFHvrgXyWNuGnRqw3yjTHQvqHaohrxYLPgNFvRkLlHEiOtFfgYr96TXs
67eKfQUJPa7n4jxiNLjAxjThY0V+vqK/UisoXO8ZCt3MdmM9VvTPawqrmPsa
jDb0YSvFfkZsuF4g5jNlR37hFB59H05RnQ70o5sAY3F4kjhwfyNBvFoH3C/k
jAnmT9uRL4s9eP52OMj17yRQzjcm2HDeCylwexgmchEvg6KPUlT0i0yhhv/v
q+K5UIQ/5o7CdHN/crSJIl5pNuIkCf7DCnCbljD/e/TaoWA/m0V+kILzmiLo
3wUK1n1AIJXL+iELda8leP4Gs+A9Pw+UYJ3ELHjB9TpOoIHP+6YR8+1iPcqI
+psIJPD98TLqYxT4Lgn9rIjzfkvCeTu9sQfvpDfu434lZP48/v99+Qe+3O82

                    "], CompressedData["
1:eJxdVGtIlEEU3SKyLKWHRQ8TszJ7qohEmXmzRDPDHuqPqNhvx91ZNEsyCuyb
AemlQpmFJGlIWdFDxR5GVFZU9ISwB2RYbGbij7DSUjExmpk77RctLLuHuXPP
PefeudMd29c7h9psts3iK383ZsZ4Ut8ymB05oibwhB0iPswcXtDO4NDxbeP2
3rPDsUnDMvy7GHSacdFbflt48bUnu+7MMLz48epFRcs3GZDUmh9QN8ggdHhB
2YpsA+NiONytmhL+wTQwzwGOfEcNuN8TtqkkjUO45G01INb3bXXuZA5L5L04
B9jkJ4CDTG8vckDb2YqHwUk6vkifmxb2X3Dl5LfXHFJkfI8DlL5WDvu/rLsR
lEAwroPDKEETm0VAiHx2qk3zVRBoCmnp5806voEg7y0OGTJxHwEZVrWPw3h5
r5PASxmfz7GOMwSC63e4S7drvWkE3KVC8WYOuVKYwHMPTnz3IopDvL29KaSa
wDKpt4chz+RMzPOTwbsXfRva/JyQ0zFwoSuCw6WuV2sclU7kXcMhTyb2OPGe
wNOk0DYnlMu2hen657jQzyEc0mX9eS70Q/R3luyPD8V6+hj6MZd6+6f8i6ag
xiCQw2H5Zz6FPQF1ia1LOfo0kcID2b8sjvn6XNhP0Q91r9eF9ZVwuCjrD6Bw
I0hU9oSjvhwKDdLPYg6nE67/GPxI0a9w7fdjiv766n42Uqx/gHnPu0XaMb0M
egXt/U6Nuxnm9XWjLy8Z8ke4UV8tQ5/i3ejvVgY7JDFxoy6Bt9xcNXroP1jV
O9LCag7PU9S7luEclVHs/1TN94Zi/HcTSmSgjxt9eWTivHmoF6u+77Ow0r2Q
YlyXCY+kkcMo5Ev/l+n36q/15mv9EyjGmRo3uvB8JYMjkj/OBYlS/9/6PjsR
x2hc6MT3nK3fs82Jc0QZNO4UJ0GZ6H8UwzmsJXBO2FDvy/BdpRPkE3qVP5UE
8z03QY5h7G8CnlSxWcpN3AviPan5KTbR7xKC81pgwle5J5IJ9qdQn88j+L6v
6nyfHCCmor2pycQ5u+zA+F+mdx+ofoxlXqzqXmVhxZfIcO4iHbD7jni4flp/
s4F99Zg4T2JfKX2hDN7386zbYp8p/hQGLRLnGt75UP3ZaOFX8jfZwiqfv4F+
ntT+p9nxHdRYWPFdt7Dy86nev3l2+H9//wHKOZ9v
                    
                    "], CompressedData["
1:eJxNVWtsFFUYbRpDGi0E26YhgstDRSwh5WVMRfCIBVQkaAlo5BHS3YGZO1Mo
FUoVvDMbIg8JtBUNAsHyEBOThodKKWhaUgoFf/CQWm1lgaaxlSglUG1jGhLv
d7/LLJtsJmfn3u873znn3h1ZuLLASk1JSSlUX3o6lbfXv1wT4OO/3q6NHI9C
45YACwaN+3ZvVxSvp6eO3TQ0jkd/PVg89edYiDsO7WkckW6FWO16fknEQuOI
oyV2WhxXRv3+nyyx8MGt0RPS7gZYfEqtbLLw5HuxKTfqAxyYUdNzv2wZ3nxh
yytLPwlQPFV1+Go511sf8Lp5Nugxd02AZwbEP3/1iM31Cwy/2Q7zuOkz/wsC
3cSjTaK+6oncRKMHr6v/m7vbJY6fL62r+tLDNBrEksjccPqn/Vs8qO5/XJ4o
MYwarfVwY+62nSsikvsprPv3f8Tzl3qgtncUfnZCWvWwEo/r5ki0Xuyb1/Gc
x7wXmvoJl+fcJ/EY7c8x+zskz7vaQ21EMe+UzH+Nh4Z/xywq75awyYc8D7NJ
nx7J/bM9FNE8f5r6rS7zbZHcp9rFZdK9UaJXlWmIuzhJ9U9JqF/Fj2+5yPte
Ea6XrBtcrK1TQp2VqKDGuS7z+05i+84VGRvSXRDN4l2S/bwnmK8t2e8GgV/K
lMEzJc/9lGB+XhJrXcuTWOt9zfBrF9zvqkT+VuXUSJfnvSSxLuvwrPbpLsju
yiuGf8zl/b8ZvYpcEM3TvRJNtLHC5X3/SExXy0b1i1Af7c8xEepDMlRtFKE+
GaTnfBHqo/OTL0J9zlH9ySLUR/N8XIT6lJN+fQ7XVfqUkIFNJp9KnzbiP8a8
95JY8/40iXX9hOR8XXc4D80P9BGY1f5h1uFLhu8MEeqTm3h6QNwRoT56/SrB
ufj7Qd6NH30SKfTJEthM6ztNPtscvEb1EyYPPzgYuym79WLC5LHSwY4hjywY
1CXxIg2y0kEOve8z52WSE9bTPtTZGEjzNEl8QT7ttvG1kuOo0ns0rd9q8zxn
JK7R/J7N+ncYP1+y+Znhsx69y9n3TJ/rdSexnrN2WYj1+hqLczrEZ37vW5zX
8T6fp5kW83zDx3wSPtNiv+f47N9DWOuVn8T0SJRZ7MM6n/U9abF++5NY169O
4iV0D/b4Jt8WIppwwOfhWAyLKEj5Ad4hPsNjuDqncPC7bsD5OhjlvJUG7M+e
KE703G8uiwfMd0cUZykQ2wKjbxTanoqA+W429/lnAZ+DjVG+3w4FfG/uNvf/
Q/8H/wPhWdiy
                    "], {{484.76599999999996`, 196.805}, {
                    484.76599999999996`, 199.41}, {479.387, 202.195}, {
                    472.953, 202.918}, {467.758, 203.5}, {467.672, 203.465}, {
                    467.672, 200.871}, {467.672, 198.72299999999998`}, {
                    468.48799999999994`, 197.879}, {472.074, 196.316}, {
                    477.83599999999996`, 193.809}, {484.76599999999996`, 
                    194.07399999999998`}, {484.76599999999996`, 196.805}}, {{
                    490.66400000000004`, 197.04299999999998`}, {493.289, 
                    199.42200000000003`}, {494.53099999999995`, 202.254}, {
                    492.953, 202.254}, {491.137, 202.254}, {486.32, 197.93}, {
                    486.32, 196.30100000000002`}, {486.32, 193.758}, {487.215,
                     193.91}, {490.66400000000004`, 197.04299999999998`}}, {{
                    485.07, 204.75}, {485.29299999999995`, 
                    206.22299999999998`}, {484.383, 207.20299999999997`}, {
                    481.65200000000004`, 208.43800000000002`}, {475.77, 
                    211.094}, {468.734, 212.324}, {467.039, 
                    210.99200000000002`}, {463.91799999999995`, 208.539}, {
                    465.9959999999999, 205.24599999999998`}, {471.039, 
                    204.65200000000002`}, {473.07, 204.414}, {475.824, 
                    203.797}, {477.16, 203.277}, {481.03499999999997`, 
                    201.77299999999997`}, {484.72299999999996`, 
                    202.45700000000002`}, {485.07, 204.75}}, {{485.07, 
                    212.63299999999998`}, {485.387, 214.73}, {484.043, 
                    215.48000000000002`}, {473.08599999999996`, 219.34}, {
                    464.90599999999995`, 222.21899999999997`}, {
                    461.28499999999997`, 220.859}, {463.89799999999997`, 
                    215.895}, {464.809, 214.164}, {466.34000000000003`, 
                    213.375}, {469.76599999999996`, 212.859}, {472.316, 
                    212.477}, {475.801, 211.73}, {477.508, 
                    211.19899999999998`}, {482.074, 209.781}, {484.715, 
                    210.281}, {485.07, 212.63299999999998`}}, {{490.562, 
                    220.02}, {492.215, 221.695}, {493.566, 223.672}, {493.566,
                     224.414}, {493.566, 226.816}, {487.039, 222.562}, {
                    486.207, 219.617}, {485.207, 216.08200000000002`}, {
                    486.824, 216.23}, {490.562, 220.02}}, {{485.074, 
                    220.516}, {485.43399999999997`, 222.906}, {481.457, 
                    225.062}, {473.637, 226.72299999999998`}, {467.902, 
                    227.941}, {465.371, 227.25}, {465.801, 224.586}, {
                    466.03499999999997`, 223.129}, {467.945, 222.066}, {
                    473.367, 220.375}, {482.039, 217.668}, {484.648, 
                    217.69899999999998`}, {485.074, 220.516}}, CompressedData["
1:eJxTTMoPSmViYGCQB2IQrX9Xha3xdJ1DgS3X9cVfchy02sVunsuud+g/9FUj
pjnXweNhlci6ynoHNbbGqc6v8xwuKt3+WfeozuGbRkz/Ic98B8stJ8r2La5z
WOS67fPfgnwHd5D66joH2agU6/vRUH5ynQOQdH/Ilu+QMfFtjX0gVP/RPAfF
DUUZE2PrHCaA7PPPc5ieJ9R8oAzBB6uvR/CvVrxUM2yrc/A273RMsETwtwKd
MV8OwRduPnBq4cJcB5C3CibWQtyXkeswWYIljE+31mEGyJ5zuQ5WIPdz1kL8
9SnX4YF/7/S8XzVw+8D+E6+F88HhoYvgV4P8ZVPrcPPc9+DHa6HyhrUOQNOy
9nzIc3hXY28ap1QLCQ/vfIcLIHu+1DgUgzyWnQ8R31gDCX+PfAchkLulaxxc
unOe//6ZB4kP+RqHffOl9O/OyHUA+vrphR01DnG7PHmYmHMdjoECwqzW4fHS
2UcUOnIcQMb5e9Y5FILMa8hxQI9fAIGY6Mg=
                    "], CompressedData["
1:eJxTTMoPSmViYGBQAmIQbbnlRNm+9DqH1teBO+Q48xwmS7CE8RXWOczIE2o+
IJXnsMh12+e/OXUO3zRi+g+Z5jnYcV1fXBBb5wCibP3yHLzNOx0TrOscwOY0
5zmU75svpW9b51CUMfFtzeU8h8NfgRqToObp5TuAlM2vq3NQZWuc6lyc73C1
4qWaYRPU/Jv5DlrtYjfPddc5yEalWN//WOhwQen2z7o5dQ65z3+v/JhT6jAd
ZM49qHu5Kxw+XfJNEjCrd+DT3TT3/eoKB6Brnl6IgPJfV0Do4HqIPW8qHB4v
nX1E4VcdxJ/rKxze1tibxrXVOeyQA5qYUOFwDOQhvToHK5BDf5ZD9D2odYjd
5cnDlF4Osd+n1kEb5M7AMgeFDUCfStZCwulOCZwPdt/BQjj/Esgfv6D+l6mF
2NOSD7HfrBYSHvr5Dh0g9/vVOlwEqb+XB3FvQK0DkJe150CeQw4oHOyg5mXl
QcLLuBYSvkZ5EPfp1TqAgt/+b66D+8MqkXVAeXB4fs6F2B9S6wBUdWrh1lyI
/S51DuqGHGtkjuU6oKcHAMJ3/wg=
                    "], CompressedData["
1:eJxTTMoPSmViYGCQA2IQfVRhQ1HG1UaHY97mnY5hRQ7TnLtznl9vdODT3TT3
fWyRwxXfJIGIS40O0/OEmg+0FDl8ugQUONnocOirRkz/miIIvavRYeuJsn3z
XxU5zACp29LoUC2yzv3hlyKHrD0lkyUWIPi2XNcXF8Qj+J48TNrt3xscls4+
orBBr9gB5IyEngaHqxUv1Qz7ih0uKN3+WefXABE/WuzwGKTQsgHijkvFDvKt
rwN3GDY4MIDAkWIHgQjLLSfkGiDqFhQ7ZE58W2Nv1+AQtwtok3exQ7vYzXPf
8xog/pUrdqjYN19Kf1YDxB/fihwqgdZyCDc6aIMUHi1yiO0Hyngh+GBzsxB8
magU6/tAfu7z3ys/HipyWAbyR0Sjww45oMP6ihxA0v7ejQ7AUDm1ML3IYdvn
v1cq8hsdrLYAAyy1COKvZmj4phQ5LC4AhtC8Roi/44og9JpGB15QfIRD3Xeh
0aHDMeHpBTeofiQ+enwCAHk04P4=
                    "]}]}}}}}}}}}}}}}}, 
                  AspectRatio -> Automatic, ImageSize -> {{128}, {85}}, 
                  PlotRange -> {{0., 960.}, {0., 480.}}], ",", 
                 GraphicsBox[{{{{{{{{
                    Thickness[0.0010416666666666667`], {{{{{{{
                    FaceForm[{
                    RGBColor[0.890196, 0.0392157, 0.09019610000000002], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {0., 640.}, {960., 640.}, {960., 
                    0.}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{500., 320.}, {500., 231.63299999999998`}, {
                    428.367, 160.}, {340., 160.}, {251.63299999999998`, 
                    160.}, {180., 231.63299999999998`}, {180., 320.}, {180., 
                    408.367}, {251.63299999999998`, 480.}, {340., 480.}, {
                    428.367, 480.}, {500., 408.367}, {500., 
                    320.}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0.890196, 0.0392157, 0.09019610000000002], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{508., 320.}, {508., 249.309}, {450.691, 192.}, {
                    380., 192.}, {309.309, 192.}, {252., 249.309}, {252., 
                    320.}, {252., 390.691}, {309.309, 448.}, {380., 448.}, {
                    450.691, 448.}, {508., 390.691}, {508., 
                    320.}}}]}}}}}}}}}}}}}}, {{{{{{{
                    RGBColor[1., 1., 1.], 
                    
                    PolygonBox[{{521.9449999999999, 302.03905243264535`}, {
                    521.9449999999999, 243.914}, {556.1093226919377, 
                    290.9381676425142}, {611.387, 272.977}, {
                    577.2235256317572, 320.}, {611.387, 
                    367.02299999999997`}, {556.1093226919377, 
                    349.06183235748574`}, {521.9449999999999, 
                    396.08599999999996`}, {521.9449999999999, 
                    337.96094756735465`}, {466.668, 320.}}]}}}}}}}}, 
                  AspectRatio -> Automatic, ImageSize -> {{128}, {85}}, 
                  PlotRange -> {{0., 960.}, {0., 640.}}], ",", 
                 GraphicsBox[{{{{{{{
                    Thickness[0.0010416666666666667`], {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.854902, 0.14509800000000003`, 0.11372500000000002`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {0., 720.}, {960., 720.}, {960., 
                    0.}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 0.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{480., 504.}, {
                    435.5, 367.047}, {526.805, 337.383}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{480., 504.}, {
                    524.5, 367.047}, {433.195, 337.383}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{616.953, 
                    404.5}, {472.953, 404.5}, {472.953, 308.5}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{616.953, 
                    404.5}, {500.453, 319.855}, {444.027, 
                    397.52299999999997`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{564.641, 
                    243.5}, {520.145, 380.453}, {428.84000000000003`, 
                    350.789}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{564.641, 
                    243.5}, {448.14500000000004`, 328.14500000000004`}, {
                    504.57, 405.809}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{343.047, 
                    404.5}, {487.047, 404.5}, {487.047, 308.5}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{343.047, 
                    404.5}, {459.547, 319.855}, {515.9730000000001, 
                    397.52299999999997`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    395.35900000000004`, 243.5}, {439.855, 380.453}, {531.16, 
                    350.789}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    395.35900000000004`, 243.5}, {511.855, 
                    328.14500000000004`}, {455.42999999999995`, 
                    405.809}}}]}}}}}}}}}}}}}}, AspectRatio -> Automatic, 
                  ImageSize -> {{128}, {85}}, 
                  PlotRange -> {{0., 960.}, {0., 720.}}], ",", 
                 GraphicsBox[{{{{{{{
                    Thickness[0.00078125], {{{{{{{
                    FaceForm[{
                    RGBColor[0.007843139999999998, 0.309804, 0.635294], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {0., 640.}, {1280., 640.}, {1280., 
                    0.}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     533.3319999999999}, {1280., 533.3319999999999}, {1280., 
                    106.66799999999984`}, {0., 
                    106.66799999999984`}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.9294119999999999, 0.109804, 0.15294100000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     515.555}, {1280., 515.555}, {1280., 
                    124.44599999999991`}, {0., 
                    124.44599999999991`}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{568.891, 320.}, {568.891, 241.453}, {505.215, 
                    177.777}, {426.668, 177.777}, {348.121, 177.777}, {
                    284.445, 241.453}, {284.445, 320.}, {284.445, 398.547}, {
                    348.121, 462.22299999999996`}, {426.668, 
                    462.22299999999996`}, {505.215, 462.22299999999996`}, {
                    568.891, 398.547}, {568.891, 320.}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.9294119999999999, 0.109804, 0.15294100000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{426.668, 
                    457.777}, {384.09, 326.742}, {449.60900000000004`, 
                    305.457}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{426.668, 
                    457.777}, {469.242, 326.742}, {403.727, 305.457}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    557.6990000000001, 362.574}, {419.92199999999997`, 
                    362.574}, {419.92199999999997`, 293.688}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    557.6990000000001, 362.574}, {446.23799999999994`, 
                    281.594}, {405.746, 337.324}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{295.633, 
                    362.574}, {407.09799999999996`, 281.594}, {447.59, 
                    337.324}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{295.633, 
                    362.574}, {433.40999999999997`, 362.574}, {
                    433.40999999999997`, 293.688}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    507.65200000000004`, 208.535}, {465.074, 339.57}, {
                    399.559, 318.28099999999995`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    507.65200000000004`, 208.535}, {396.188, 289.52}, {
                    436.676, 345.25}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{345.684, 
                    208.535}, {457.148, 289.52}, {416.656, 345.25}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{345.684, 
                    208.535}, {388.258, 339.57}, {453.777, 
                    318.28099999999995`}}}]}}}}}}}}}}}}}}, AspectRatio -> 
                  Automatic, ImageSize -> {{128}, {85}}, 
                  PlotRange -> {{0., 1280.}, {0., 640.}}]}], "}"}], ",", 
             RowBox[{"{", 
               RowBox[{
                 GraphicsBox[{{{{{{{
                    Thickness[0.0011111111111111111`], {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {900., 0.}, {900., 600.}, {0., 
                    600.}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0.91, 0.067, 0.17600000000000002`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{389.99969999999996`, 
                    600.0003}, {389.99969999999996`, 
                    360.00030000000004`}, {-0.0003000000000383807, 
                    360.00030000000004`}, {-0.0003000000000383807, 
                    240.00030000000004`}, {389.99969999999996`, 
                    240.00030000000004`}, {389.99969999999996`, 
                    0.0003000000000383807}, {510.00069999999994`, 
                    0.0003000000000383807}, {510.00069999999994`, 
                    240.00030000000004`}, {899.9997, 240.00030000000004`}, {
                    899.9997, 360.00030000000004`}, {510.00069999999994`, 
                    360.00030000000004`}, {510.00069999999994`, 600.0003}}}], 
                    
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{172.9215, 539.9021999999999}, {180.2365, 
                    501.41219999999987`}, {180.2365, 461.88819999999987`}, {
                    172.9215, 423.39819999999986`}, {186.4875, 
                    425.09019999999987`}, {200.2125, 425.09019999999987`}, {
                    213.7785, 423.39819999999986`}, {206.4635, 
                    461.88819999999987`}, {206.4635, 501.41219999999987`}, {
                    213.7785, 539.9021999999999}, {200.2125, 
                    538.2091999999999}, {186.4875, 538.2091999999999}, {
                    172.9215, 539.9021999999999}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{251.6022, 502.07849999999996`}, {213.1122, 
                    494.76349999999996`}, {173.5882, 494.76349999999996`}, {
                    135.09820000000002`, 502.07849999999996`}, {
                    136.79020000000003`, 488.5125}, {136.79020000000003`, 
                    474.78749999999997`}, {135.09820000000002`, 461.2215}, {
                    173.5882, 468.53649999999993`}, {213.1122, 
                    468.53649999999993`}, {251.6022, 461.2215}, {249.9092, 
                    474.78749999999997`}, {249.9092, 488.5125}, {251.6022, 
                    502.07849999999996`}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{686.2215, 176.6022}, {693.5365, 138.1122}, {
                    693.5365, 98.5882}, {686.2215, 60.098200000000006`}, {
                    699.7875, 61.79020000000001}, {713.5125, 
                    61.79020000000001}, {727.0785, 60.098200000000006`}, {
                    719.7635, 98.5882}, {719.7635, 138.1122}, {727.0785, 
                    176.6022}, {713.5125, 174.9092}, {699.7875, 174.9092}, {
                    686.2215, 176.6022}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{764.9021999999999, 138.77849999999998`}, {
                    726.4121999999999, 131.46349999999998`}, {
                    686.8881999999999, 131.46349999999998`}, {
                    648.3981999999999, 138.77849999999998`}, {
                    650.0901999999999, 125.21249999999998`}, {
                    650.0901999999999, 111.48749999999998`}, {
                    648.3981999999999, 97.92149999999998}, {686.8881999999999,
                     105.23649999999998`}, {726.4121999999999, 
                    105.23649999999998`}, {764.9021999999999, 
                    97.92149999999998}, {763.2091999999999, 
                    111.48749999999998`}, {763.2091999999999, 
                    125.21249999999998`}, {764.9021999999999, 
                    138.77849999999998`}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{686.2215, 539.9021999999999}, {693.5365, 
                    501.41219999999987`}, {693.5365, 461.88819999999987`}, {
                    686.2215, 423.39819999999986`}, {699.7875, 
                    425.09019999999987`}, {713.5125, 425.09019999999987`}, {
                    727.0785, 423.39819999999986`}, {719.7635, 
                    461.88819999999987`}, {719.7635, 501.41219999999987`}, {
                    727.0785, 539.9021999999999}, {713.5125, 
                    538.2091999999999}, {699.7875, 538.2091999999999}, {
                    686.2215, 539.9021999999999}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{764.9021999999999, 502.07849999999996`}, {
                    726.4121999999999, 494.76349999999996`}, {
                    686.8881999999999, 494.76349999999996`}, {
                    648.3981999999999, 502.07849999999996`}, {
                    650.0901999999999, 488.5125}, {650.0901999999999, 
                    474.78749999999997`}, {648.3981999999999, 461.2215}, {
                    686.8881999999999, 468.53649999999993`}, {
                    726.4121999999999, 468.53649999999993`}, {
                    764.9021999999999, 461.2215}, {763.2091999999999, 
                    474.78749999999997`}, {763.2091999999999, 488.5125}, {
                    764.9021999999999, 502.07849999999996`}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{172.9215, 176.6022}, {180.2365, 138.1122}, {
                    180.2365, 98.5882}, {172.9215, 60.098200000000006`}, {
                    186.4875, 61.79020000000001}, {200.2125, 
                    61.79020000000001}, {213.7785, 60.098200000000006`}, {
                    206.4635, 98.5882}, {206.4635, 138.1122}, {213.7785, 
                    176.6022}, {200.2125, 174.9092}, {186.4875, 174.9092}, {
                    172.9215, 176.6022}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{251.6022, 138.77849999999998`}, {213.1122, 
                    131.46349999999998`}, {173.5882, 131.46349999999998`}, {
                    135.09820000000002`, 138.77849999999998`}, {
                    136.79020000000003`, 125.21249999999998`}, {
                    136.79020000000003`, 111.48749999999998`}, {
                    135.09820000000002`, 97.92149999999998}, {173.5882, 
                    105.23649999999998`}, {213.1122, 105.23649999999998`}, {
                    251.6022, 97.92149999999998}, {249.9092, 
                    111.48749999999998`}, {249.9092, 125.21249999999998`}, {
                    251.6022, 138.77849999999998`}}}]}}}}}}}}}}}}}}, 
                  AspectRatio -> Automatic, ImageSize -> {{128}, {85}}, 
                  PlotRange -> {{0., 900.}, {0., 600.}}], ",", 
                 GraphicsBox[{{{{{{{
                    Thickness[0.001388888888888889], {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     480.}, {720., 480.}, {720., 240.}, {0., 
                    240.}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0.8352940000000001, 0.168627, 0.117647], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     240.}, {720., 240.}, {720., 0.}, {0., 
                    0.}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0., 0.223529, 0.65098], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     320.}, {720., 320.}, {720., 160.}, {0., 
                    160.}}}]}}}}}}}}}}}}}}, AspectRatio -> Automatic, 
                  ImageSize -> {{128}, {85}}, 
                  PlotRange -> {{0., 720.}, {0., 480.}}], ",", 
                 GraphicsBox[{{{{{{{
                    Thickness[0.001893939393939394], {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {0., 384.}, {528., 384.}, {528., 
                    0.}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0., 0.21960800000000003`, 0.7215689999999999], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     348.}, {528., 348.}, {528., 288.}, {0., 288.}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     96.}, {528., 96.}, {528., 36.}, {0., 
                    36.}}}]}}}}}}}, {{{{{{{
                    RGBColor[0., 0.21960800000000003`, 0.7215689999999999], 
                    Thickness[0.024999999999999998`], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{264., 
                    261.938}, {203.43, 157.031}, {324.57, 157.031}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    RGBColor[0., 0.21960800000000003`, 0.7215689999999999], 
                    Thickness[0.024999999999999998`], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    264.00000000000006`, 122.06200000000018`}, {
                    324.56999999999994`, 226.96900000000002`}, {
                    203.43000000000004`, 226.96900000000002`}}}, 
                    CurveClosed -> {1}]}}}}}}}}}}}}}}, 
                  ImageSize -> {{128}, {85}}, 
                  PlotRange -> {{0, 528}, {36, 348}}], ",", 
                 GraphicsBox[{{{{{{{
                    Thickness[0.0008333333333333334], {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {0., 720.}, {1200., 720.}, {1200., 
                    0.}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.8078430000000001, 0.06666670000000002, 0.14902], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{1200., 720.}, {
                    296., 720.}, {480., 648.}, {296., 576.}, {480., 504.}, {
                    296., 432.}, {480., 360.}, {296., 288.}, {480., 216.}, {
                    296., 144.}, {480., 72.}, {296., 0.}, {1200., 
                    0.}}}]}}}}}}}}}}}}}}, AspectRatio -> Automatic, 
                  ImageSize -> {{128}, {85}}, 
                  PlotRange -> {{0., 1200.}, {0., 720.}}], ",", 
                 GraphicsBox[{{{{{{{
                    Thickness[0.0015625], {{{{{{{
                    FaceForm[{
                    RGBColor[0.8784310000000001, 0., 0.14509800000000003`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     308.202}, {640., 308.202}, {640., 103.40099999999998`}, {
                    0., 103.40099999999998`}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0.011764699999999998`, 0.180392, 0.631373], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     410.6}, {640., 410.6}, {640., 308.202}, {0., 308.202}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     103.40100000000001`}, {640., 103.40100000000001`}, {640.,
                     0.9990000000000094}, {0., 
                    0.9990000000000094}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{317.59, 
                    285.811}, {317.59, 285.811}, {317.441, 290.022}, {319.895,
                     290.069}, {322.348, 290.022}, {322.199, 285.811}, {
                    322.199, 285.811}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{317.59, 
                    285.811006}, {317.59, 285.811006}, {317.441, 
                    290.02200600000003`}, {319.895, 290.069006}, {322.348, 
                    290.02200600000003`}, {322.199, 285.811006}, {322.199, 
                    285.811006}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}}}, {{{418.93399999999997`, 
                    175.721}, {418.93399999999997`, 196.73299999999998`}, {
                    419.617, 199.39700000000002`}, {421.879, 201.756}, {
                    423.582, 202.225}, {423.582, 221.93200000000002`}, {
                    421.012, 221.93200000000002`}, {419.75, 218.58}, {419.75, 
                    218.58}, {415.375, 199.319}, {415.375, 
                    175.88100000000003`}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}}}, {{{418.93399999999997`, 
                    175.72100600000002`}, {418.93399999999997`, 196.733006}, {
                    419.617, 199.39700600000003`}, {421.879, 201.756006}, {
                    423.582, 202.225006}, {423.582, 221.932006}, {421.012, 
                    221.932006}, {419.75, 218.580006}, {419.75, 218.580006}, {
                    415.375, 199.319006}, {415.375, 175.88100600000004`}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    374.449, 217.545}, {380.75800000000004`, 217.545}, {
                    380.75800000000004`, 204.178}, {374.449, 
                    204.178}}}]}}}}}}}, {{{{{{{
                    Thickness[0.001292146875], 
                    CapForm["Round"], 
                    JoinForm["Round"], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    374.449, 217.545006}, {380.75800000000004`, 217.545006}, {
                    380.75800000000004`, 204.178006}, {374.449, 204.178006}}},
                     CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    262.316, 217.545}, {378.847, 217.545}, {378.847, 
                    172.70499999999998`}, {262.316, 
                    172.70499999999998`}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm["Round"], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    262.316, 217.545006}, {378.847, 217.545006}, {378.847, 
                    172.705006}, {262.316, 172.705006}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{221.262, 
                    175.79899999999998`}, {221.262, 196.73299999999998`}, {
                    220.578, 199.39700000000002`}, {218.316, 201.756}, {
                    216.61299999999997`, 202.225}, {216.61299999999997`, 
                    220.651}, {220.445, 218.58}, {224.82000000000002`, 
                    199.319}, {224.82000000000002`, 
                    175.79899999999998`}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{221.262, 175.799006}, {
                    221.262, 196.733006}, {220.578, 199.39700600000003`}, {
                    218.316, 201.756006}, {216.61299999999997`, 202.225006}, {
                    216.61299999999997`, 220.65100600000002`}, {220.445, 
                    218.580006}, {224.82000000000002`, 199.319006}, {
                    224.82000000000002`, 175.799006}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}}}, {{{221.262, 175.721}, {
                    221.262, 196.73299999999998`}, {220.578, 
                    199.39700000000002`}, {218.316, 201.756}, {
                    216.61299999999997`, 202.225}, {216.61299999999997`, 
                    221.93200000000002`}, {219.18800000000002`, 
                    221.93200000000002`}, {220.445, 218.58}, {220.445, 
                    218.58}, {224.82000000000002`, 199.319}, {
                    224.82000000000002`, 
                    175.88100000000003`}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}}}, {{{221.262, 
                    175.72100600000002`}, {221.262, 196.733006}, {220.578, 
                    199.39700600000003`}, {218.316, 201.756006}, {
                    216.61299999999997`, 202.225006}, {216.61299999999997`, 
                    221.932006}, {219.18800000000002`, 221.932006}, {220.445, 
                    218.580006}, {220.445, 218.580006}, {224.82000000000002`, 
                    199.319006}, {224.82000000000002`, 175.88100600000004`}}},
                     CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    216.73, 170.354}, {218.535, 171.272}, {220.59, 173.409}, {
                    221.262, 175.79899999999998`}, {418.97299999999996`, 
                    175.79899999999998`}, {419.64500000000004`, 173.409}, {
                    421.699, 171.272}, {423.504, 170.354}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    216.73, 170.35400600000003`}, {218.535, 
                    171.27200599999998`}, {220.59, 173.409006}, {221.262, 
                    175.799006}, {418.97299999999996`, 175.799006}, {
                    419.64500000000004`, 173.409006}, {421.699, 
                    171.27200599999998`}, {423.504, 170.35400600000003`}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    372.828, 192.791}, {376.5, 192.791}, {376.5, 175.9}, {
                    372.828, 175.9}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Round"], 
                    JoinForm["Round"], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    372.828, 192.791006}, {376.5, 192.791006}, {376.5, 
                    175.90000600000002`}, {372.828, 175.90000600000002`}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    262.316, 201.135}, {378.847, 201.135}, {378.847, 
                    195.92399999999998`}, {262.316, 
                    195.92399999999998`}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm["Round"], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    262.316, 201.135006}, {378.847, 201.135006}, {378.847, 
                    195.924006}, {262.316, 195.924006}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    262.316, 208.202}, {378.847, 208.202}, {378.847, 
                    203.60399999999998`}, {262.316, 
                    203.60399999999998`}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm["Round"], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    262.316, 208.20200599999998`}, {378.847, 
                    208.20200599999998`}, {378.847, 203.60400599999997`}, {
                    262.316, 203.60400599999997`}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    262.316, 215.256}, {378.847, 215.256}, {378.847, 
                    210.799}, {262.316, 210.799}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0011818156249999998`], 
                    CapForm["Butt"], 
                    JoinForm["Round"], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    262.316, 215.256006}, {378.847, 215.256006}, {378.847, 
                    210.79900600000002`}, {262.316, 210.79900600000002`}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    374.449, 217.545}, {380.75800000000004`, 217.545}, {
                    380.75800000000004`, 204.178}, {374.449, 
                    204.178}}}]}}}}}}}, {{{{{{{
                    Thickness[0.001292146875], 
                    CapForm["Round"], 
                    JoinForm["Round"], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    374.449, 217.545006}, {380.75800000000004`, 217.545006}, {
                    380.75800000000004`, 204.178006}, {374.449, 204.178006}}},
                     CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}}}, {{{421.484, 
                    170.354}, {419.715, 171.155}, {417.137, 173.342}, {
                    417.137, 175.545}, {417.137, 201.70499999999998`}, {
                    418.348, 203.866}, {373.78099999999995`, 203.866}, {
                    375.52, 201.70499999999998`}, {375.52, 175.545}, {375.52, 
                    173.342}, {373.75, 171.155}, {371.97999999999996`, 
                    170.354}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}}}, {{{421.484, 
                    170.35400600000003`}, {419.715, 171.15500600000001`}, {
                    417.137, 173.342006}, {417.137, 175.545006}, {417.137, 
                    201.705006}, {418.348, 203.86600600000003`}, {
                    373.78099999999995`, 203.86600600000003`}, {375.52, 
                    201.705006}, {375.52, 175.545006}, {375.52, 173.342006}, {
                    373.75, 171.15500600000001`}, {371.97999999999996`, 
                    170.35400600000003`}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    292.98799999999994`, 192.791}, {296.65999999999997`, 
                    192.791}, {296.65999999999997`, 175.9}, {
                    292.98799999999994`, 175.9}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Round"], 
                    JoinForm["Round"], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    292.98799999999994`, 192.791006}, {296.65999999999997`, 
                    192.791006}, {296.65999999999997`, 175.90000600000002`}, {
                    292.98799999999994`, 175.90000600000002`}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    343.156, 192.791}, {346.82800000000003`, 192.791}, {
                    346.82800000000003`, 175.9}, {343.156, 
                    175.9}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Round"], 
                    JoinForm["Round"], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    343.156, 192.791006}, {346.82800000000003`, 192.791006}, {
                    346.82800000000003`, 175.90000600000002`}, {343.156, 
                    175.90000600000002`}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}}}, {{{349.301, 
                    170.354}, {347.22299999999996`, 171.155}, {344.203, 
                    173.342}, {344.203, 175.545}, {344.203, 
                    200.42800000000003`}, {346.90599999999995`, 203.866}, {
                    292.863, 203.866}, {295.453, 200.42800000000003`}, {
                    295.453, 175.545}, {295.453, 173.342}, {293.379, 
                    171.155}, {291.301, 170.354}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}}}, {{{349.301, 
                    170.35400600000003`}, {347.22299999999996`, 
                    171.15500600000001`}, {344.203, 173.342006}, {344.203, 
                    175.545006}, {344.203, 200.428006}, {346.90599999999995`, 
                    203.86600600000003`}, {292.863, 203.86600600000003`}, {
                    295.453, 200.428006}, {295.453, 175.545006}, {295.453, 
                    173.342006}, {293.379, 171.15500600000001`}, {291.301, 
                    170.35400600000003`}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    302.47299999999996`, 192.791}, {306.145, 192.791}, {
                    306.145, 175.9}, {302.47299999999996`, 
                    175.9}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Round"], 
                    JoinForm["Round"], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    302.47299999999996`, 192.791006}, {306.145, 192.791006}, {
                    306.145, 175.90000600000002`}, {302.47299999999996`, 
                    175.90000600000002`}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    333.51599999999996`, 192.791}, {337.188, 192.791}, {
                    337.188, 175.9}, {333.51599999999996`, 
                    175.9}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Round"], 
                    JoinForm["Round"], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    333.51599999999996`, 192.791006}, {337.188, 192.791006}, {
                    337.188, 175.90000600000002`}, {333.51599999999996`, 
                    175.90000600000002`}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}}}, {{{291.895, 232.178}, {291.895, 
                    203.86200000000002`}, {347.215, 203.86200000000002`}, {
                    347.215, 209.959}, {347.29299999999995`, 232.178}, {
                    345.03099999999995`, 231.291}, {344.633, 
                    229.24099999999999`}, {344.633, 229.24099999999999`}, {
                    344.633, 217.178}, {294.715, 217.178}, {294.715, 
                    229.24099999999999`}, {294.715, 229.24099999999999`}, {
                    294.156, 231.291}, {291.895, 232.178}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}}}, {{{291.895, 232.17800599999998`}, {291.895, 
                    203.862006}, {347.215, 203.862006}, {347.215, 
                    209.95900600000002`}, {347.29299999999995`, 
                    232.17800599999998`}, {345.03099999999995`, 231.291006}, {
                    344.633, 229.241006}, {344.633, 229.241006}, {344.633, 
                    217.17800599999998`}, {294.715, 217.17800599999998`}, {
                    294.715, 229.241006}, {294.715, 229.241006}, {294.156, 
                    231.291006}, {291.895, 232.17800599999998`}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 
                    0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{339.707, 
                    170.354}, {337.89799999999997`, 171.155}, {
                    333.96099999999996`, 173.342}, {333.96099999999996`, 
                    175.545}, {333.96099999999996`, 203.389}, {334.348, 
                    204.944}, {336.457, 205.86200000000002`}, {337.812, 
                    206.83}, {301.129, 206.83}, {302.875, 205.905}, {304.82, 
                    205.13899999999998`}, {305.52, 203.389}, {305.52, 
                    175.545}, {305.52, 173.342}, {302.402, 171.155}, {
                    300.59799999999996`, 170.354}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 
                    0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{339.707, 
                    170.35400600000003`}, {337.89799999999997`, 
                    171.15500600000001`}, {333.96099999999996`, 173.342006}, {
                    333.96099999999996`, 175.545006}, {333.96099999999996`, 
                    203.38900600000002`}, {334.348, 204.944006}, {336.457, 
                    205.862006}, {337.812, 206.83000600000003`}, {301.129, 
                    206.83000600000003`}, {302.875, 205.90500600000001`}, {
                    304.82, 205.139006}, {305.52, 203.38900600000002`}, {
                    305.52, 175.545006}, {305.52, 173.342006}, {302.402, 
                    171.15500600000001`}, {300.59799999999996`, 
                    170.35400600000003`}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{344.629, 
                    206.53}, {344.629, 226.58800000000002`}, {
                    339.60200000000003`, 226.58800000000002`}, {
                    339.60200000000003`, 228.541}, {299.828, 228.541}, {
                    299.828, 226.58800000000002`}, {294.801, 
                    226.58800000000002`}, {294.801, 206.53}}}]}}}}}}}, {{{{{{{
                    
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{344.629, 
                    206.53000600000001`}, {344.629, 226.588006}, {
                    339.60200000000003`, 226.588006}, {339.60200000000003`, 
                    228.541006}, {299.828, 228.541006}, {299.828, 
                    226.588006}, {294.801, 226.588006}, {294.801, 
                    206.53000600000001`}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    263.234, 192.791}, {266.90999999999997`, 192.791}, {
                    266.90999999999997`, 175.9}, {263.234, 
                    175.9}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Round"], 
                    JoinForm["Round"], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    263.234, 192.791006}, {266.90999999999997`, 192.791006}, {
                    266.90999999999997`, 175.90000600000002`}, {263.234, 
                    175.90000600000002`}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}}}, {{{218.539, 
                    170.354}, {220.312, 171.155}, {222.89100000000002`, 
                    173.342}, {222.89100000000002`, 175.545}, {
                    222.89100000000002`, 201.70499999999998`}, {221.676, 
                    203.866}, {266.246, 203.866}, {264.504, 
                    201.70499999999998`}, {264.504, 175.545}, {264.504, 
                    173.342}, {266.277, 171.155}, {268.047, 
                    170.354}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}}}, {{{218.539, 
                    170.35400600000003`}, {220.312, 171.15500600000001`}, {
                    222.89100000000002`, 173.342006}, {222.89100000000002`, 
                    175.545006}, {222.89100000000002`, 201.705006}, {221.676, 
                    203.86600600000003`}, {266.246, 203.86600600000003`}, {
                    264.504, 201.705006}, {264.504, 175.545006}, {264.504, 
                    173.342006}, {266.277, 171.15500600000001`}, {268.047, 
                    170.35400600000003`}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    223.312, 221.27599999999998`}, {227.429, 
                    221.27599999999998`}, {227.429, 206.01799999999997`}, {
                    223.312, 206.01799999999997`}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Round"], 
                    JoinForm["Round"], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    223.312, 221.276006}, {227.429, 221.276006}, {227.429, 
                    206.01800599999999`}, {223.312, 206.01800599999999`}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    223.289, 224.538}, {227.402, 224.538}, {227.402, 
                    221.323}, {223.289, 221.323}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Round"], 
                    JoinForm["Round"], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    223.289, 224.538006}, {227.402, 224.538006}, {227.402, 
                    221.323006}, {223.289, 221.323006}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}}}, {{{259.051, 
                    170.354}, {257.28099999999995`, 171.155}, {
                    254.69899999999998`, 173.342}, {254.69899999999998`, 
                    175.545}, {254.69899999999998`, 200.424}, {
                    258.40599999999995`, 203.866}, {228.10899999999998`, 
                    203.866}, {231.812, 200.424}, {231.812, 175.545}, {
                    231.812, 173.342}, {229.23399999999998`, 171.155}, {
                    227.465, 170.354}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}}}, {{{259.051, 
                    170.35400600000003`}, {257.28099999999995`, 
                    171.15500600000001`}, {254.69899999999998`, 173.342006}, {
                    254.69899999999998`, 175.545006}, {254.69899999999998`, 
                    200.42400600000002`}, {258.40599999999995`, 
                    203.86600600000003`}, {228.10899999999998`, 
                    203.86600600000003`}, {231.812, 200.42400600000002`}, {
                    231.812, 175.545006}, {231.812, 173.342006}, {
                    229.23399999999998`, 171.15500600000001`}, {227.465, 
                    170.35400600000003`}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}}}, {{{254.809, 
                    170.354}, {253.035, 171.155}, {250.45700000000002`, 
                    173.342}, {250.45700000000002`, 175.545}, {
                    250.45700000000002`, 198.038}, {252.883, 
                    201.47899999999998`}, {233.63299999999998`, 
                    201.47899999999998`}, {236.059, 198.038}, {236.059, 
                    175.545}, {236.059, 173.342}, {233.48000000000002`, 
                    171.155}, {231.707, 170.354}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}}}, {{{254.809, 
                    170.35400600000003`}, {253.035, 171.15500600000001`}, {
                    250.45700000000002`, 173.342006}, {250.45700000000002`, 
                    175.545006}, {250.45700000000002`, 198.038006}, {252.883, 
                    201.479006}, {233.63299999999998`, 201.479006}, {236.059, 
                    198.038006}, {236.059, 175.545006}, {236.059, 
                    173.342006}, {233.48000000000002`, 171.15500600000001`}, {
                    231.707, 170.35400600000003`}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    412.42199999999997`, 170.354}, {410.65200000000004`, 
                    171.155}, {408.074, 173.342}, {408.074, 175.545}, {
                    408.074, 200.424}, {411.777, 203.866}, {
                    381.47999999999996`, 203.866}, {385.188, 200.424}, {
                    385.188, 175.545}, {385.188, 173.342}, {382.605, 
                    171.155}, {380.83599999999996`, 170.354}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    412.42199999999997`, 170.35400600000003`}, {
                    410.65200000000004`, 171.15500600000001`}, {408.074, 
                    173.342006}, {408.074, 175.545006}, {408.074, 
                    200.42400600000002`}, {411.777, 203.86600600000003`}, {
                    381.47999999999996`, 203.86600600000003`}, {385.188, 
                    200.42400600000002`}, {385.188, 175.545006}, {385.188, 
                    173.342006}, {382.605, 171.15500600000001`}, {
                    380.83599999999996`, 170.35400600000003`}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}}}, {{{408.18, 
                    170.354}, {406.40599999999995`, 171.155}, {403.828, 
                    173.342}, {403.828, 175.545}, {403.828, 198.038}, {
                    406.254, 201.47899999999998`}, {387.004, 
                    201.47899999999998`}, {389.42999999999995`, 198.038}, {
                    389.42999999999995`, 175.545}, {389.42999999999995`, 
                    173.342}, {386.85200000000003`, 171.155}, {385.078, 
                    170.354}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}}}, {{{408.18, 
                    170.35400600000003`}, {406.40599999999995`, 
                    171.15500600000001`}, {403.828, 173.342006}, {403.828, 
                    175.545006}, {403.828, 198.038006}, {406.254, 
                    201.479006}, {387.004, 201.479006}, {389.42999999999995`, 
                    198.038006}, {389.42999999999995`, 175.545006}, {
                    389.42999999999995`, 173.342006}, {386.85200000000003`, 
                    171.15500600000001`}, {385.078, 170.35400600000003`}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    238.66, 201.47899999999998`}, {247.855, 
                    201.47899999999998`}, {247.855, 170.35399999999998`}, {
                    238.66, 170.35399999999998`}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    238.66, 201.479006}, {247.855, 201.479006}, {247.855, 
                    170.354006}, {238.66, 170.354006}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    331.78099999999995`, 170.354}, {330.012, 171.155}, {
                    327.42999999999995`, 173.342}, {327.42999999999995`, 
                    175.545}, {327.42999999999995`, 199.319}, {328.887, 
                    201.47899999999998`}, {310.77, 201.47899999999998`}, {
                    312.227, 199.319}, {312.227, 175.545}, {312.227, 
                    173.342}, {309.64500000000004`, 171.155}, {307.875, 
                    170.354}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    331.78099999999995`, 170.35400600000003`}, {330.012, 
                    171.15500600000001`}, {327.42999999999995`, 173.342006}, {
                    327.42999999999995`, 175.545006}, {327.42999999999995`, 
                    199.319006}, {328.887, 201.479006}, {310.77, 
                    201.479006}, {312.227, 199.319006}, {312.227, 
                    175.545006}, {312.227, 173.342006}, {309.64500000000004`, 
                    171.15500600000001`}, {307.875, 170.35400600000003`}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    315.23799999999994`, 201.467}, {324.41799999999995`, 
                    201.467}, {324.41799999999995`, 170.36200000000002`}, {
                    315.23799999999994`, 
                    170.36200000000002`}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0012262218749999998`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    315.23799999999994`, 201.46700600000003`}, {
                    324.41799999999995`, 201.46700600000003`}, {
                    324.41799999999995`, 170.36200600000004`}, {
                    315.23799999999994`, 170.36200600000004`}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    392.03099999999995`, 201.47899999999998`}, {
                    401.22599999999994`, 201.47899999999998`}, {
                    401.22599999999994`, 170.35399999999998`}, {
                    392.03099999999995`, 
                    170.35399999999998`}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    392.03099999999995`, 201.479006}, {401.22599999999994`, 
                    201.479006}, {401.22599999999994`, 170.354006}, {
                    392.03099999999995`, 170.354006}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    310.617, 213.29899999999998`}, {329.043, 
                    213.29899999999998`}, {329.043, 206.51}, {310.617, 
                    206.51}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm["Round"], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    310.617, 213.299006}, {329.043, 213.299006}, {329.043, 
                    206.510006}, {310.617, 206.510006}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}}}, {{{329.242, 208.315}, {
                    329.26599999999996`, 210.36200000000002`}, {335.219, 
                    210.455}, {338.28499999999997`, 212.202}, {301.469, 
                    212.202}, {304.53499999999997`, 210.455}, {310.355, 
                    210.311}, {310.355, 208.315}, {311.60200000000003`, 
                    204.33800000000002`}, {326.84000000000003`, 
                    203.72899999999998`}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm["Round"], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}}}, {{{329.242, 208.315006}, {
                    329.26599999999996`, 210.362006}, {335.219, 
                    210.45500600000003`}, {338.28499999999997`, 
                    212.20200599999998`}, {301.469, 212.20200599999998`}, {
                    304.53499999999997`, 210.45500600000003`}, {310.355, 
                    210.31100600000002`}, {310.355, 208.315006}, {
                    311.60200000000003`, 204.338006}, {326.84000000000003`, 
                    203.729006}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 
                    0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    336.43799999999993`, 229.959}, {336.43799999999993`, 
                    234.975}, {336.648, 236.909}, {338.191, 236.909}, {
                    338.191, 220.955}, {334.40999999999997`, 219.584}, {
                    331.715, 214.76}, {331.715, 214.76}, {307.945, 214.76}, {
                    307.945, 214.76}, {305.246, 219.584}, {301.469, 
                    220.955}, {301.469, 236.909}, {303.367, 236.909}, {
                    303.379, 234.889}, {303.379, 229.959}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 
                    0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    336.43799999999993`, 229.95900600000002`}, {
                    336.43799999999993`, 234.975006}, {336.648, 236.909006}, {
                    338.191, 236.909006}, {338.191, 220.95500600000003`}, {
                    334.40999999999997`, 219.58400600000002`}, {331.715, 
                    214.760006}, {331.715, 214.760006}, {307.945, 
                    214.760006}, {307.945, 214.760006}, {305.246, 
                    219.58400600000002`}, {301.469, 220.95500600000003`}, {
                    301.469, 236.909006}, {303.367, 236.909006}, {303.379, 
                    234.88900600000002`}, {303.379, 229.95900600000002`}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    308.29699999999997`, 226.98700000000002`}, {
                    311.35900000000004`, 223.311}, {311.074, 217.077}, {
                    311.039, 213.401}, {328.801, 213.401}, {
                    328.76599999999996`, 217.077}, {328.47999999999996`, 
                    223.311}, {331.543, 226.98700000000002`}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    308.29699999999997`, 226.98700600000004`}, {
                    311.35900000000004`, 223.31100600000002`}, {311.074, 
                    217.077006}, {311.039, 213.40100600000002`}, {328.801, 
                    213.40100600000002`}, {328.76599999999996`, 217.077006}, {
                    328.47999999999996`, 223.31100600000002`}, {331.543, 
                    226.98700600000004`}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    226.14499999999998`, 192.791}, {229.81699999999998`, 
                    192.791}, {229.81699999999998`, 175.9}, {
                    226.14499999999998`, 175.9}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Round"], 
                    JoinForm["Round"], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    226.14499999999998`, 192.791006}, {229.81699999999998`, 
                    192.791006}, {229.81699999999998`, 175.90000600000002`}, {
                    226.14499999999998`, 175.90000600000002`}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    412.719, 221.27599999999998`}, {416.832, 
                    221.27599999999998`}, {416.832, 206.01799999999997`}, {
                    412.719, 206.01799999999997`}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Round"], 
                    JoinForm["Round"], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    412.719, 221.276006}, {416.832, 221.276006}, {416.832, 
                    206.01800599999999`}, {412.719, 206.01800599999999`}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    216.73, 170.35400600000003`}, {218.535, 
                    171.27200599999998`}, {220.59, 173.409006}, {221.262, 
                    175.799006}, {418.97299999999996`, 175.799006}, {
                    419.64500000000004`, 173.409006}, {421.699, 
                    171.27200599999998`}, {423.504, 170.35400600000003`}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    257.633, 192.791}, {261.305, 192.791}, {261.305, 175.9}, {
                    257.633, 175.9}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Round"], 
                    JoinForm["Round"], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    257.633, 192.791006}, {261.305, 192.791006}, {261.305, 
                    175.90000600000002`}, {257.633, 175.90000600000002`}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}}}, {{{220.434, 226.475}, {220.434, 203.866}, {223.004, 
                    203.866}, {223.004, 226.53}, {222.078, 
                    226.99800000000002`}, {221.207, 227.07299999999998`}, {
                    220.434, 226.475}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}}}, {{{220.434, 226.475006}, {220.434, 
                    203.86600600000003`}, {223.004, 203.86600600000003`}, {
                    223.004, 226.53000600000001`}, {222.078, 226.998006}, {
                    221.207, 227.073006}, {220.434, 226.475006}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}}}, {{{220.516, 
                    211.846}, {223.70299999999997`, 210.21699999999998`}, {
                    226.859, 208.33}, {227.656, 203.866}, {220.516, 
                    203.866}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}}}, {{{220.516, 
                    211.84600600000002`}, {223.70299999999997`, 210.217006}, {
                    226.859, 208.33000600000003`}, {227.656, 
                    203.86600600000003`}, {220.516, 203.86600600000003`}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    259.39099999999996`, 217.545}, {265.7, 217.545}, {265.7, 
                    204.178}, {259.39099999999996`, 204.178}}}]}}}}}}}, {{{{{{{
                    Thickness[0.001292146875], 
                    CapForm["Round"], 
                    JoinForm["Round"], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    259.39099999999996`, 217.545006}, {265.7, 217.545006}, {
                    265.7, 204.178006}, {259.39099999999996`, 204.178006}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}}}, {{{264.719, 218.62}, {264.719, 203.866}, {266.801, 
                    203.866}, {266.801, 218.655}, {266.15200000000004`, 
                    218.959}, {265.262, 219.006}, {264.719, 
                    218.62}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}}}, {{{264.719, 218.620006}, {264.719, 
                    203.86600600000003`}, {266.801, 203.86600600000003`}, {
                    266.801, 218.65500600000001`}, {266.15200000000004`, 
                    218.95900600000002`}, {265.262, 219.006006}, {264.719, 
                    218.620006}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}}}, CompressedData["
1:eJxlVWtIFFEU3t20l2WmoRK2aoVFFhIUsUl1/BEmZQ8LiwoRKYtyZ69z75Rp
SiEhEWFSUBARS5nUD1nEFokISwnzx6KlVIpJpPQyou2xWATdx8wZ1gbmx8e9
c875vvOdM5llvqLD0xwOh5O/5fx18feqlljfOYfCnevdGYFHFWDh8PPCsgTm
hQ2zX94icRTO55WO94W8kBHQjzaN6rD/UO7ojkEvPN267nzeGx0m6449ZCna
f/jJz+UHG1/pKn61Bkn1nb3+cR3iV7Xd+NqiqfgRHZJfhyK7l2iQ/7Z6QWsK
hce9/s3BXBs3fTm9aa1u4w9/7n577tdgo/g+lkKrOAhpkCYK4/XFFPMMeT5Y
JPALXdVR7lN1D+tgXE6NKR7ywbtmXtiEDpzd4mEngfs9Jx7dDOuw8yJX4qZ5
/lsH73ueUPOp/PMo4poFPHOajRMFv2Wmfmds3CXyt03BYZ/SYT6F4Pe/A1Wz
CBwVRGdQWCnkySJKd54//dznXR1bCAh5S6dR6BaNOE5UnlQKCfs87T11RNWR
QeFBwRxXdiGBDjf/0G3e95h4jY1l/FIzfz4BIXMJPxc26G0git8KCqc+Zq2e
eY3AXFFvOgUh1+Q9ovzgoaq+vv+x1Cvf5HObwGAVD7SNwjMu80I/Uf0/YNbb
TEDIHdAowNqSBwX3zPsVFJzZDcmvnxLlzz0UigSREaL020xBlFk9QSBnZOn0
szzfwUbecVel0msvhRZhzCQTH6GwScT/QWAFDxuqobC9jCv4i4BIE6o1659Z
qfQkJt5Zqfp3gSGWfq5lik+ciU8xxSdCQMhUd4WBSwQOEzjJr+U0M6xHhHHf
Z1iv5B9kyEf6uYUhX9mfSwz1kPwvMtRLxvMz1FPeDzDUW/JpZ9gPMQbxXQz7
NRVLfw0xGBNEggTWt/MB6WfoBznvPQz9IvW8ztBP1nmU/97YWPpjmKFf5ZyO
MfSznIdJhn6X/XEa0fPwk+G8yD3zieE8Sb4DDOctCrfZ2JpXj+A3yqLne8LG
/aKfLgOx1H+WgftC9jvBwH0i902mgftG1rfcwH0k/Zxm4L6S/ogw3GcyP9fD
2ncWtvahha19Kb+PNXCfVog6kw3ctw7xLDVwH0t/uA3c11Ox9MMiA/e99Nc3
hv8D6c+vDP8XFrb+J/8ApYz8HQ==
                    "]]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}}}, CompressedData["
1:eJxlVWtIFFEUVrPSnrZKRW2mFWb2kCCz7XkMYnsYVpQ9MelhRu7sde6dMrei
shKJMC0qiLKlzDIqWUokSKRCRdBWS3osKdI7DVMysaKae2fmLNrA/PiYmXvO
953vfBO+zb5mZz8fHx9f9U5Rbz/1Pi+ZsiqGUNjauHF6SXkaGPjWkLdSELPB
gkEvrpLBFBY7ujrcdTYIK5FT85plCL7sbk1otEHliticuCYZXGV/q9ko6T/8
qCtyS+5LWTs/U4LgrIoa53sZKlOsxe1FknZ+twxPTTv8106UwNqSGXJnFIVM
/9g1pfO8ePlkU3yM7MXOmEV/GpwSLOTf96ew68je7JA6CcybdsxrVvt7mHvV
4oqzwziOn8ngiC5PzU2xA4cJHhlm1N4OSnxth7eFF5+Etckw/+jYKR5fAver
95YXdMoQWDXNYSrQn/+UISI8r7RDsmv1h1PEjpA71hazF5s4v8kUirl+h71Y
1Hf1wZ12GDbddal9BIX800s9GYEEUvO+Hlg0kMKghE9dRREEcuKS37vV+r/C
Z28oW0qAy5vcj8KVhz8zUvcQ6GxYuS1oNIWv37MeVB8iYPv462ZHGIXzHxID
pq4kUBZ6vHV1qKoXf9+i41leLM5PpnCG17cSUKvHJKnP4+/WVtZkE41fFIV1
J9JjAy4QGMr7HU/hkc3W0lNMND9YqNaf+38s9LLqfK4RaMz4HDEznkJhcOD1
MU6izX+z3m8hAS53iUTB3HCjYlmx/n4ahaaqevOrSqL5cy2FGet2n2x9QzT9
llD4tjz/Y2Ybgeg3kwYcUevNmTb0d6RfuqbXegrHtp9bkBOs4136+d8JRGWP
fFXnoBD1d1OS5QeBqRwf1PsPSNf0JDpela7N7yRDLPx8kGl8But4P4NznE83
AfcET8+hs0zrv5PAvvKCMdGFDPtRp1EWep9hv4J/KUM+ws9FDPmK+ZxmqIfg
f4qhXuI8J0M9xfslDPUWfO4xnMeZ0f6Jwx4znFdfLPz1mmnzLiUw9566IPUM
/SD2vZqhX4SeFxn6yXjey39NXiz84WHoV5EX7xj6WexDD0O/i/n4Kr33oYvh
vlzn+n1huE+C73OG+9YLu7zY2FcL59fMeu93mxfX83n6KYiF/oEK5oWYd5CC
eSLyJlzBvBH9RSqYR8LPZgXzSvijm2GeifqqHkbeGdjIQwMbeSm+769gnqZx
fiMVzFsffk1SMI+FP0IVzOu+WPhhnIJ5L/zVwfB/IPzZzvB/YWDjf/IPab3x
Fw==
                    "], CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    Thickness[0.001], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{311.277, 271.655006}, {
                    328.816, 271.655006}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    318.28099999999995`, 269.10400000000004`}, {315.848, 
                    270.358}, {315.848, 273.94}, {316.84400000000005`, 
                    273.639}, {317.96099999999996`, 273.518}, {318.066, 
                    271.93199999999996`}, {318.414, 274.194}, {319.039, 
                    274.084}, {320.02, 274.967}, {321., 274.084}, {321.625, 
                    274.194}, {321.97299999999996`, 271.93199999999996`}, {
                    322.082, 273.518}, {323.199, 273.639}, {324.191, 
                    273.94}, {324.191, 270.358}, {321.758, 
                    269.10400000000004`}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    318.28099999999995`, 269.104006}, {315.848, 
                    270.35800600000005`}, {315.848, 273.94000600000004`}, {
                    316.84400000000005`, 273.639006}, {317.96099999999996`, 
                    273.518006}, {318.066, 271.932006}, {318.414, 
                    274.194006}, {319.039, 274.08400600000004`}, {320.02, 
                    274.967006}, {321., 274.08400600000004`}, {321.625, 
                    274.194006}, {321.97299999999996`, 271.932006}, {322.082, 
                    273.518006}, {323.199, 273.639006}, {324.191, 
                    273.94000600000004`}, {324.191, 270.35800600000005`}, {
                    321.758, 269.104006}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    Thickness[0.001], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{309.195, 266.178006}, {
                    330.621, 266.178006}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    318.117, 263.22499999999997`}, {314.078, 266.002}, {
                    314.078, 269.303}, {315.4959999999999, 
                    268.97499999999997`}, {317.08599999999996`, 
                    268.84200000000004`}, {317.242, 267.10400000000004`}, {
                    317.734, 269.584}, {318.625, 270.87}, {320.02, 271.834}, {
                    321.41799999999995`, 270.87}, {322.309, 269.584}, {
                    322.801, 267.10400000000004`}, {322.957, 
                    268.84200000000004`}, {324.547, 268.97499999999997`}, {
                    325.965, 269.303}, {325.965, 266.002}, {
                    321.92199999999997`, 
                    263.22499999999997`}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    318.117, 263.225006}, {314.078, 266.002006}, {314.078, 
                    269.303006}, {315.4959999999999, 268.975006}, {
                    317.08599999999996`, 268.84200599999997`}, {317.242, 
                    267.104006}, {317.734, 269.58400600000004`}, {318.625, 
                    270.870006}, {320.02, 271.83400600000004`}, {
                    321.41799999999995`, 270.870006}, {322.309, 
                    269.58400600000004`}, {322.801, 267.104006}, {322.957, 
                    268.84200599999997`}, {324.547, 268.975006}, {325.965, 
                    269.303006}, {325.965, 266.002006}, {321.92199999999997`, 
                    263.225006}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    Thickness[0.001], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{307.121, 259.534006}, {
                    332.625, 259.534006}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    317.832, 254.069}, {313.188, 258.14700000000005`}, {
                    313.188, 262.99799999999993`}, {314.816, 262.514}, {
                    316.64500000000004`, 262.319}, {316.824, 259.764}, {
                    317.39099999999996`, 263.409}, {318.414, 
                    265.29499999999996`}, {320.02, 266.71299999999997`}, {
                    321.629, 265.29499999999996`}, {322.648, 263.409}, {
                    323.219, 259.764}, {323.395, 262.319}, {325.227, 
                    262.514}, {326.855, 262.99799999999993`}, {326.855, 
                    258.14700000000005`}, {322.207, 254.069}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    317.832, 254.069006}, {313.188, 258.14700600000003`}, {
                    313.188, 262.99800600000003`}, {314.816, 262.514006}, {
                    316.64500000000004`, 262.319006}, {316.824, 259.764006}, {
                    317.39099999999996`, 263.409006}, {318.414, 265.295006}, {
                    320.02, 266.71300599999995`}, {321.629, 265.295006}, {
                    322.648, 263.409006}, {323.219, 259.764006}, {323.395, 
                    262.319006}, {325.227, 262.514006}, {326.855, 
                    262.99800600000003`}, {326.855, 258.14700600000003`}, {
                    322.207, 254.069006}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    326.39799999999997`, 248.647}, {322.199, 242.834}, {
                    317.441, 242.834}, {313.23799999999994`, 
                    248.647}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    326.39799999999997`, 248.647006}, {322.199, 
                    242.83400600000002`}, {317.441, 242.83400600000002`}, {
                    313.23799999999994`, 248.647006}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    310.82, 238.893}, {312.92199999999997`, 
                    237.74499999999998`}, {313.699, 235.455}, {
                    313.92199999999997`, 231.159}, {325.75, 231.159}, {
                    325.97299999999996`, 235.455}, {326.75, 
                    237.74499999999998`}, {328.85200000000003`, 
                    238.893}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    310.82, 238.893006}, {312.92199999999997`, 237.745006}, {
                    313.699, 235.45500600000003`}, {313.92199999999997`, 
                    231.159006}, {325.75, 231.159006}, {325.97299999999996`, 
                    235.45500600000003`}, {326.75, 237.745006}, {
                    328.85200000000003`, 238.893006}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    Thickness[0.001], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{304.945, 251.412006}, {
                    335.191, 251.412006}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.001], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{304.25, 242.159006}, {
                    335.40599999999995`, 242.159006}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}}}, {{{329.027, 248.647}, {
                    329.027, 254.48700000000002`}, {327.03099999999995`, 
                    253.936}, {325.73799999999994`, 252.752}, {325.16, 
                    251.151}, {325.16, 253.08800000000002`}, {
                    322.60900000000004`, 257.557}, {319.828, 259.78}, {
                    317.039, 257.29099999999994`}, {314.445, 253.248}, {
                    314.4959999999999, 251.151}, {314.02299999999997`, 
                    252.678}, {312.629, 253.936}, {310.629, 
                    254.48700000000002`}, {310.629, 248.647}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm["Round"], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}}}, {{{329.027, 248.647006}, {
                    329.027, 254.48700600000004`}, {327.03099999999995`, 
                    253.93600600000002`}, {325.73799999999994`, 252.752006}, {
                    325.16, 251.15100600000002`}, {325.16, 253.088006}, {
                    322.60900000000004`, 257.557006}, {319.828, 
                    259.78000599999996`}, {317.039, 257.29100600000004`}, {
                    314.445, 253.24800599999998`}, {314.4959999999999, 
                    251.15100600000002`}, {314.02299999999997`, 
                    252.67800599999998`}, {312.629, 253.93600600000002`}, {
                    310.629, 254.48700600000004`}, {310.629, 248.647006}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}}}, {{{329.90999999999997`, 
                    238.893}, {329.90999999999997`, 244.72899999999998`}, {
                    327.72299999999996`, 244.18200000000002`}, {326.305, 
                    242.99800000000002`}, {325.672, 241.393}, {325.672, 
                    243.334}, {322.879, 247.803}, {319.828, 250.026}, {316.77,
                     247.538}, {313.92599999999993`, 243.495}, {313.984, 
                    241.393}, {313.465, 242.924}, {311.93399999999997`, 
                    244.18200000000002`}, {309.746, 244.72899999999998`}, {
                    309.746, 238.893}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm["Round"], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}}}, {{{329.90999999999997`, 
                    238.893006}, {329.90999999999997`, 244.729006}, {
                    327.72299999999996`, 244.182006}, {326.305, 242.998006}, {
                    325.672, 241.393006}, {325.672, 243.33400600000002`}, {
                    322.879, 247.803006}, {319.828, 250.02600600000002`}, {
                    316.77, 247.538006}, {313.92599999999993`, 
                    243.49500600000002`}, {313.984, 241.393006}, {313.465, 
                    242.92400600000002`}, {311.93399999999997`, 244.182006}, {
                    309.746, 244.729006}, {309.746, 238.893006}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}}}, {{{332.371, 226.909}, {
                    332.371, 233.64299999999997`}, {329.648, 232.944}, {
                    327.957, 230.92800000000003`}, {327.10200000000003`, 
                    229.752}, {327.10200000000003`, 233.401}, {322.984, 
                    238.959}, {319.828, 240.78}, {316.594, 
                    238.91299999999998`}, {312.559, 233.166}, {312.559, 
                    229.752}, {311.676, 230.92000000000002`}, {310.008, 
                    232.944}, {307.28499999999997`, 233.64299999999997`}, {
                    307.28499999999997`, 226.909}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm["Round"], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}}}, {{{332.371, 226.909006}, {
                    332.371, 233.64300599999999`}, {329.648, 232.944006}, {
                    327.957, 230.928006}, {327.10200000000003`, 229.752006}, {
                    327.10200000000003`, 233.40100600000002`}, {322.984, 
                    238.95900600000002`}, {319.828, 240.780006}, {316.594, 
                    238.912006}, {312.559, 233.166006}, {312.559, 
                    229.752006}, {311.676, 230.920006}, {310.008, 
                    232.944006}, {307.28499999999997`, 233.64300599999999`}, {
                    307.28499999999997`, 226.909006}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}}}, {{{330.89799999999997`, 
                    211.959}, {330.89799999999997`, 218.88500000000002`}, {
                    328.4959999999999, 217.944}, {327.777, 215.627}, {327.02, 
                    214.053}, {327.316, 221.077}, {323.066, 228.627}, {
                    319.828, 230.541}, {316.59, 228.627}, {312.258, 
                    220.916}, {312.637, 214.053}, {311.85900000000004`, 
                    215.61599999999999`}, {311.16, 217.944}, {308.758, 
                    218.88500000000002`}, {308.758, 211.959}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm["Round"], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}}}, {{{330.89799999999997`, 
                    211.95900600000002`}, {330.89799999999997`, 
                    218.88500600000003`}, {328.4959999999999, 217.944006}, {
                    327.777, 215.62700600000002`}, {327.02, 214.053006}, {
                    327.316, 221.077006}, {323.066, 228.62700600000002`}, {
                    319.828, 230.541006}, {316.59, 228.62700600000002`}, {
                    312.258, 220.916006}, {312.637, 214.053006}, {
                    311.85900000000004`, 215.616006}, {311.16, 217.944006}, {
                    308.758, 218.88500600000003`}, {308.758, 
                    211.95900600000002`}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    412.746, 224.538}, {416.859, 224.538}, {416.859, 
                    221.323}, {412.746, 221.323}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Round"], 
                    JoinForm["Round"], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    412.746, 224.538006}, {416.859, 224.538006}, {416.859, 
                    221.323006}, {412.746, 221.323006}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    378.777, 192.791}, {382.449, 192.791}, {382.449, 175.9}, {
                    378.777, 175.9}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Round"], 
                    JoinForm["Round"], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    378.777, 192.791006}, {382.449, 192.791006}, {382.449, 
                    175.90000600000002`}, {378.777, 175.90000600000002`}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    410.262, 192.791}, {413.934, 192.791}, {413.934, 175.9}, {
                    410.262, 175.9}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Round"], 
                    JoinForm["Round"], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    410.262, 192.791006}, {413.934, 192.791006}, {413.934, 
                    175.90000600000002`}, {410.262, 175.90000600000002`}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{294.801, 
                    211.95900600000002`}, {344.629, 211.95900600000002`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    310.617, 211.952006}, {329.086, 211.952006}, {329.086, 
                    205.16700600000001`}, {310.617, 205.16700600000001`}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}}}, {{{329.215, 
                    201.47899999999998`}, {329.215, 208.401}, {326.695, 
                    207.803}, {326.543, 206.873}, {325.742, 205.323}, {
                    326.039, 209.518}, {323.066, 214.303}, {319.828, 
                    216.21699999999998`}, {316.59, 214.303}, {313.621, 
                    209.518}, {313.91799999999995`, 205.323}, {313.117, 
                    206.873}, {313.01599999999996`, 207.803}, {310.441, 
                    208.401}, {310.441, 201.47899999999998`}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}}}, {{{329.215, 201.479006}, {
                    329.215, 208.40100600000002`}, {326.695, 207.803006}, {
                    326.543, 206.873006}, {325.742, 205.32300600000002`}, {
                    326.039, 209.51800599999999`}, {323.066, 214.303006}, {
                    319.828, 216.217006}, {316.59, 214.303006}, {313.621, 
                    209.51800599999999`}, {313.91799999999995`, 
                    205.32300600000002`}, {313.117, 206.873006}, {
                    313.01599999999996`, 207.803006}, {310.441, 
                    208.40100600000002`}, {310.441, 201.479006}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}}}, {{{266.801, 
                    211.846}, {263.613, 210.21699999999998`}, {260.457, 
                    208.33}, {259.66, 203.866}, {266.801, 
                    203.866}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}}}, {{{266.801, 
                    211.84600600000002`}, {263.613, 210.217006}, {260.457, 
                    208.33000600000003`}, {259.66, 203.86600600000003`}, {
                    266.801, 203.86600600000003`}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    223.004, 221.27599999999998`}, {227.42999999999998`, 
                    221.27599999999998`}, {227.42999999999998`, 
                    203.95999999999998`}, {223.004, 
                    203.95999999999998`}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Round"], 
                    JoinForm["Round"], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    223.004, 221.276006}, {227.42999999999998`, 221.276006}, {
                    227.42999999999998`, 203.960006}, {223.004, 203.960006}}},
                     CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    223.004, 224.538}, {227.402, 224.538}, {227.402, 
                    221.323}, {223.004, 221.323}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Round"], 
                    JoinForm["Round"], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    223.004, 224.538006}, {227.402, 224.538006}, {227.402, 
                    221.323006}, {223.004, 221.323006}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    259.39099999999996`, 217.545}, {265.7, 217.545}, {265.7, 
                    204.178}, {259.39099999999996`, 204.178}}}]}}}}}}}, {{{{{{{
                    Thickness[0.001292146875], 
                    CapForm["Round"], 
                    JoinForm["Round"], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    259.39099999999996`, 217.545006}, {265.7, 217.545006}, {
                    265.7, 204.178006}, {259.39099999999996`, 204.178006}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJ7IGYCYqstJ8r2Zec45D7/vfJjU6YDjC9289z3YPNc
h8dLZx9RmILgc19fXGA7K8dhp1zr68A1OQ5VIuvcH35D8B0Tnl5QUs+F8126
c57/Vsx1OL3QddvnpzkOsbs8eZjYcx3ctn3+e0Uk1yEOxH+f41A6WYIlzC7X
IWPi2xr7izkOB04BNZTnOgg3A1k/cxwOf9WI6X8ElReF6p+Q6xDOp7tpbnyu
QwfI4rJcB5AzHwfmOgBdVSWyCupeq1wHkDZTpjwHLhAf6N5kgQjLLQJ5EPM0
cx1sQRIz8yDusc6F+Fc9D+L/Fqh/dPIcQMbEFeU6LAMKb8iD8uNyHaJSrO/7
78xzWAT05l+TXAeQs95fz3NgAIEMqLxjvkMByCKgeSxhQBUn8xzU2BqnOq/O
hbjnAoIPjg+pfDi/PmtPyeSOfEj4Lc916AT5918+1L48B6BrijJECzD4QFfv
kLPNcwBFw0r3AodVHy/5JhUg+EWgAFiM4IPjfzVCPzofHB+W+XD79e+qsDWa
5sPdB+PD3A/jw/wHDs+YfLj/b/2sy9pTkQ8PH4h9+fDwA4dvUz48fMH8vHx4
+BeCwhNoHix+vgGTyaGl+fD4A/tvez48fi8p3f5Z9yofHv8XQPxl+fD0UQ1K
z3358PQDDr/GfHj6KgaZdzofnv7A6f15Pjx9grStYy+Ap1+wez7mw9M3mH8z
H57+Z+QJNR/Ylw/PH+Dw3ZkPzz9g9S8R/PJ986X0lQvg/B0gWq0Anj8vgvxj
hcmH5W8Ajzbb3g==
                    "]]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJ7IGYCYqstJ8r2Zec4qCpO3PaxKdMBxj8vlMISYp7r
8Hjp7CMKUxB87uuLC2xn5TgURUj9CFyT41Alss794TcE3zHh6QUl9Vw436U7
5/lvxVyHltu3Dn1+muMQu8uTh4k91+H/+w6uqyK5DnEg/vscB92zawXC7HId
Mia+rbG/mONQyWIetK0810G4+cCphT9zHKr192X0P4LKi0L1T8h1COfT3TQ3
PtfBsfrrxwtluQ43z30PfhyY65DeWNYusgrqXqtcBy91IR9TpjwHLhAf6F5p
r7euWwTyIOZp5jp8c87ZUDAzD+Ie61yIf9XzIP5vgfpHJ88BqNo0rijXIf5q
pO6GPCg/DujOeRde++/Mc1jkuu3zX5Nch2Np7qveX89zYACBDKi8Y75DgS3Q
BUDz9vYvttx0Ms9Bja1xqvPqXIh7LiD44PiQyofzzZcENk7uyIeE3/JcByeQ
f//lQ+3Lc1i491dFhmgBBr/1deAOOVugPzmNmFa5Fzis+njJN6kAwS8CBcBi
BB8c/6sR+tH54PiwzIfbr39Xha3RNB/uPhgf5n4YH+Y/cHjG5MP9f+tnXdae
inx4+EDsy4eHHzh8m/Lh4Qvm5+XDw78QFJ5A82Dx800jpv/Q0nx4/IH9tz0f
Hr+XlG7/rHuVD4//CyD+snx4+qgGpee+fHj6AYdfYz48fRWDzDudD09/4PT+
PB+ePt0fAnMEewE8/YLd8zEfnr7B/Jv58PQ/I0+o+cC+fHj+AIfvznx4/gGr
f4ngl++bL6WvXADn75ADulCtAJ4/L4L8Y4XJh+VvAFeLyus=
                    "], 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    245.73, 246.42000000000002`}, {247.59, 
                    247.97899999999998`}, {247.59, 249.97899999999998`}, {
                    246.91, 249.91299999999998`}, {246.539, 249.678}, {
                    246.035, 249.02200000000002`}, {245.60899999999998`, 
                    250.346}, {244.672, 251.38100000000003`}, {243.414, 
                    252.026}, {242.15200000000002`, 251.38100000000003`}, {
                    241.21499999999997`, 250.393}, {240.789, 249.069}, {
                    240.285, 249.725}, {239.914, 249.91299999999998`}, {
                    239.23399999999998`, 249.97899999999998`}, {
                    239.23399999999998`, 247.97899999999998`}, {241.094, 
                    246.42000000000002`}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    245.73, 246.420006}, {247.59, 247.979006}, {247.59, 
                    249.979006}, {246.91, 249.912006}, {246.539, 
                    249.67800599999998`}, {246.035, 249.022006}, {
                    245.60899999999998`, 250.34600600000002`}, {244.672, 
                    251.38100600000004`}, {243.414, 252.02600600000002`}, {
                    242.15200000000002`, 251.38100600000004`}, {
                    241.21499999999997`, 250.393006}, {240.789, 249.069006}, {
                    240.285, 249.725006}, {239.914, 249.912006}, {
                    239.23399999999998`, 249.979006}, {239.23399999999998`, 
                    247.979006}, {241.094, 246.420006}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    246.727, 241.405}, {247.59, 243.27599999999998`}, {247.59,
                     245.873}, {246.91, 245.80700000000002`}, {246.539, 
                    245.569}, {246.035, 244.901}, {245.60899999999998`, 
                    246.248}, {244.672, 247.295}, {243.414, 247.948}, {
                    242.15200000000002`, 247.295}, {241.21499999999997`, 
                    246.295}, {240.789, 244.95200000000003`}, {240.285, 
                    245.61599999999999`}, {239.914, 245.80700000000002`}, {
                    239.23399999999998`, 245.873}, {239.23399999999998`, 
                    243.27599999999998`}, {240.098, 241.405}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    246.727, 241.40500600000001`}, {247.59, 243.276006}, {
                    247.59, 245.873006}, {246.91, 245.80700600000003`}, {
                    246.539, 245.569006}, {246.035, 244.90100600000002`}, {
                    245.60899999999998`, 246.24800599999998`}, {244.672, 
                    247.295006}, {243.414, 247.948006}, {242.15200000000002`, 
                    247.295006}, {241.21499999999997`, 246.295006}, {240.789, 
                    244.952006}, {240.285, 245.616006}, {239.914, 
                    245.80700600000003`}, {239.23399999999998`, 245.873006}, {
                    239.23399999999998`, 243.276006}, {240.098, 
                    241.40500600000001`}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    246.85500000000002`, 234.623}, {249.617, 237.991}, {
                    249.617, 241.311}, {248.605, 241.198}, {248.055, 
                    240.795}, {247.309, 239.666}, {246.676, 241.94}, {245.281,
                     242.44}, {243.414, 243.541}, {241.54299999999998`, 
                    242.44}, {240.148, 242.02200000000002`}, {239.516, 
                    239.74499999999998`}, {238.76999999999998`, 240.877}, {
                    238.21899999999997`, 241.198}, {237.207, 241.311}, {
                    237.207, 237.991}, {239.969, 234.623}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    246.85500000000002`, 234.623006}, {249.617, 
                    237.99100600000003`}, {249.617, 241.31100600000002`}, {
                    248.605, 241.198006}, {248.055, 240.795006}, {247.309, 
                    239.666006}, {246.676, 241.940006}, {245.281, 
                    242.440006}, {243.414, 243.541006}, {241.54299999999998`, 
                    242.440006}, {240.148, 242.022006}, {239.516, 
                    239.745006}, {238.76999999999998`, 240.87700600000002`}, {
                    238.21899999999997`, 241.198006}, {237.207, 
                    241.31100600000002`}, {237.207, 237.99100600000003`}, {
                    239.969, 234.623006}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJRIGYC4oyJb2vsv+Y5HP6qEdNfl+OAzn+8dPYRhZh8
hx1yra8Db+Q4cF1fXGCblO+gsKEoYyJnLpxvYgwE1bkO72rsTeOs8h0OgfSX
5ToU2AJViOQ7XKt4qWaYk+ugytY41fl7noMdWGOug7ohxxqZe3kO91SAErNz
HWJ3efIwbc9zePF75cdLW3Mh7snNcxC7ee578ONch36QwcoI+ePe5p2Of3Lh
+p0Snl5QAqqDmf8N6IxDR3Ph9jOAwIJcuPvA/qvIhbsfxof5D+hroNdz4f4H
85/mwsMHnQ8ABFCbJg==
                    "]]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJRIGYC4oyJb2vsv+Y51Ojvy+ivy3FA5z9eOvuIQky+
Q2GE1I/AGzkOXNcXF9gm5TvcfMleOpEzF85/k3PC3rg61+Fdjb1pnFW+QzVI
f1muQ4EtUIVIvkP/pjpjw5xcB1W2xqnO3/McvjnnbCiwzXVQN+RYI3Mvz2Fa
3OzeqbNzHWJ3efIwbc9zWGBq/+/S1lyIe3LzHM4LpbCEPM516D/0VSNGGSF/
3Nu80/FPLly/U8LTC0pAdTDzv2nE9B86mgu3nwEEFuTC3Qf2X0Uu3P0wPsx/
ra8Dd8i15sL9D+Y/zYWHDzofANFqmVA=
                    "], 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJRIGYC4tbXgTvkFPMd6rL2lEz+kuWAzlc35Fgjsy7f
IVkgwnLLhGwHb/NOx4SN+Q52XNcXF5xF8A9/1Yjpr8txKLQFStTkO4jdPPc9
uDzHYeuJsn3zvfIdcp//XvkxKMfBcgtQQDnfYeLbGntTLqg8U76D27bPf6/M
yXGoFlnn/vBcnkNA7/Q8IeZchwyQwtw8iHqvXIdikAA3Qh5s3vVcuH4Qd/62
XLj5ViCB/ly4/SBnPY7NhbsP7F/NXLj7YXyY/1TZGqc6G+fC/Q92z85cePig
8wGGoKCb
                    "]]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJRIGYC4tbXgTvkFPMdzJcENk7+kuWAzlc35Fgjsy7f
QdrrreuWCdkO3uadjgkb8x2+OedsKDiL4Nfo78vor8txKLTlur64Jt/hvFAK
S0h5jsPWE2X75nvlO6gqTtz2MSjHwXILUEA538FLXcjHlAsqz5Tv8P99B9fV
OTkO1SLr3B+ey3PgPK5TLcSc65Ax8W2NfW4eRL1XrkMxSIAbIQ8273ouXD+I
O39bLtx8K5BAfy7c/pvnvgc/js2Fuw/sX81cuPthfJj/VNkapzob58L9D3bP
zlx4+KDzAeAhlNE=
                    "], CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJRIGYC4tbXgTvkFPMdlhTYcl3nznJA5ws3Hzi1cGa+
Q4TllhNlbVkO3uadjgkb8x3uqbA1Tt2N4Ltt+/z3Sk62QyFQ2+KafAcQVZCa
7bD1RNm++V75Dh+WH/M2d8x2ABmzTznfYfYRhQ1FP7Ig8kz5DgG90/OEurMd
qkXWuT88l+eQ+/z3yo/3sh0yJr6tsc/NcwCKVomo5TgUgwS4EfJg867nwvWD
uPO35cLNtwIJ9OfC7b957nvw49hcuPvA/tXMhbsfxof5L4xPd9Nc91y4/8Hu
2ZkLDx90PgCrxZ/i
                    "]]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJRIGYC4tbXgTvkFPMdYlddErvOneWAzhduPnBq4cx8
B4Fiz6tlbVkO3uadjgkb8x2mxc3unbobwf//voPrak62Q6Et1/XFNfkO35xz
NhSkZjtsPVG2b75XvsOKh9ER5o7ZDpZbgALK+Q4h/7buKfqRBZFnynfgPK5T
LdSd7VAtss794bk8BzXFids+3st2yJj4tsY+N88hvbGsXUQtx6EYJMCNkAeb
dz0Xrh/Enb8tF26+FUigPxdu/81z34Mfx+bC3Qf2r2Yu3P0wPsx/YXy6m+a6
58L9D3bPzlx4+KDzASGmnw0=
                    "], 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{250.555, 
                    204.131}, {249.45700000000002`, 208.91299999999998`}, {
                    248.512, 212.455}, {243.21899999999997`, 216.053}, {
                    237.93, 212.455}, {236.984, 208.91299999999998`}, {
                    235.88700000000003`, 204.131}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{250.555, 
                    204.131006}, {249.45700000000002`, 208.912006}, {248.512, 
                    212.45500600000003`}, {243.21899999999997`, 216.053006}, {
                    237.93, 212.45500600000003`}, {236.984, 208.912006}, {
                    235.88700000000003`, 204.131006}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}}}, {{{253.277, 
                    201.47899999999998`}, {253.277, 208.401}, {250.875, 
                    207.459}, {248.70299999999997`, 206.065}, {
                    247.90200000000002`, 204.51399999999998`}, {247.008, 
                    208.35800000000003`}, {245.285, 210.053}, {243.137, 
                    212.377}, {240.99200000000002`, 210.053}, {239.555, 
                    208.35800000000003`}, {238.66, 204.51399999999998`}, {
                    237.859, 206.065}, {235.68800000000002`, 207.459}, {
                    233.285, 208.401}, {233.285, 
                    201.47899999999998`}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}}}, {{{253.277, 201.479006}, {
                    253.277, 208.40100600000002`}, {250.875, 
                    207.45900600000002`}, {248.70299999999997`, 206.065006}, {
                    247.90200000000002`, 204.514006}, {247.008, 
                    208.35800600000002`}, {245.285, 210.053006}, {243.137, 
                    212.37700600000002`}, {240.99200000000002`, 210.053006}, {
                    239.555, 208.35800600000002`}, {238.66, 204.514006}, {
                    237.859, 206.065006}, {235.68800000000002`, 
                    207.45900600000002`}, {233.285, 208.40100600000002`}, {
                    233.285, 201.479006}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}}}, {{{220.434, 226.475}, {220.434, 203.866}, {223.004, 
                    203.866}, {223.004, 226.53}, {222.078, 
                    226.99800000000002`}, {221.207, 227.07299999999998`}, {
                    220.434, 226.475}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}}}, {{{220.434, 226.475006}, {220.434, 
                    203.86600600000003`}, {223.004, 203.86600600000003`}, {
                    223.004, 226.53000600000001`}, {222.078, 226.998006}, {
                    221.207, 227.073006}, {220.434, 226.475006}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}}}, {{{220.516, 
                    211.846}, {223.70299999999997`, 210.21699999999998`}, {
                    226.859, 208.33}, {227.656, 203.866}, {220.516, 
                    203.866}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}}}, {{{220.516, 
                    211.84600600000002`}, {223.70299999999997`, 210.217006}, {
                    226.859, 208.33000600000003`}, {227.656, 
                    203.86600600000003`}, {220.516, 203.86600600000003`}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}}}, {{{264.719, 218.62}, {264.719, 203.866}, {266.801, 
                    203.866}, {266.801, 218.655}, {266.15200000000004`, 
                    218.959}, {265.262, 219.006}, {264.719, 
                    218.62}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}}}, {{{264.719, 218.620006}, {264.719, 
                    203.86600600000003`}, {266.801, 203.86600600000003`}, {
                    266.801, 218.65500600000001`}, {266.15200000000004`, 
                    218.95900600000002`}, {265.262, 219.006006}, {264.719, 
                    218.620006}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}}}, {{{266.801, 
                    211.959}, {263.613, 210.33}, {260.457, 208.444}, {259.66, 
                    203.97899999999998`}, {266.801, 
                    203.97899999999998`}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}}}, {{{266.801, 
                    211.95900600000002`}, {263.613, 210.33000600000003`}, {
                    260.457, 208.444006}, {259.66, 203.979006}, {266.801, 
                    203.979006}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}}}, {{{419.715, 226.475}, {419.715, 203.866}, {417.141, 
                    203.866}, {417.141, 226.53}, {418.07, 
                    226.99800000000002`}, {418.93799999999993`, 
                    227.07299999999998`}, {419.715, 226.475}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}}}, {{{419.715, 226.475006}, {419.715, 
                    203.86600600000003`}, {417.141, 203.86600600000003`}, {
                    417.141, 226.53000600000001`}, {418.07, 226.998006}, {
                    418.93799999999993`, 227.073006}, {419.715, 226.475006}}},
                     CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJ7IGYC4uPe5p2Op8odcp//XvmxKdMBxhe7ee57sHmu
w33/3ul59xB8hQ1FGRMfljvslGt9Hbgmx0EmKsX6Pn8FnM8AAhoIvh3X9cUF
qhUOpxe6bvv8FKpevMLBbdvnv1dEch34dDfNfc9d4VA6WYIlzC7XAUTx/S13
OHAKqKE81yFj4tsae8EKh8NfNWL6H0Hl5aH6J+Q6HAO516XCocMx4emFslwH
EDfBtsJhnfvDKpFVUPcaVjiAjDFlyoPwge5NFoiw3CKQBzFPs8LBFuTOmXkQ
9wDVg/2rnudwQen2z7owqH908hyEm4Eu861wWDb7iMKGvDwHIRDfucIB5C3/
nXkOOaBw1KuAmHM9DxJ+HlB5x3yH6XlAHUDzgLbqbjqZ5/Dpkm+SQBbUPRcQ
fHB8SOXD+fVZe0omd+Q78ILMTa9w6AT5918+xL51FQ5HQB4TLcDgx+3y5GHa
XOHQDZJwL3DYcqJs3/wzCP7Vipdqhs8QfLA/XyH0o/PB8WFYCbe/fN98KX39
Srj7YHyY+2F8mP8ugsLTqRLu/xmg8AiohIcP2L6sSnj4gcM7tBIevuDw9q6E
hz9YP9A8WPyA1aVXwuMP7L+CSnj8gs3rrITHPyiZrAOqh6UPWZAB0ZXw9LMI
mGz/hlTC0xfYvKpKePoDp/eOSnj6fLwU6LA5lfD0C3ZPbyU8fYP5jZXw9G8J
ipDiSnj+AIdXYSU8/4DVdyL4YP9vR/DB/t9VCc+f4Pg/h8mH5W8A2B3VVg==

                    "]]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJ7IGYC4uPe5p2Op8odVBUnbvvYlOkA458XSmEJMc91
uO/fOz3vHoKvsKEoY+LDcoeiCKkfgWtyHGSiUqzv81fA+QwgoIHg23FdX1yg
WuHQcvvWoc9PoerFKxz+v+/guiqS68Cnu2nue+4KB92zawXC7HIdJkuwhPH9
LXeoZDEP2lae65Ax8W2NvWCFQ7X+voz+R1B5eaj+CbkOx0DudalwcKz++vFC
Wa4DiJtgW+GQ3ljWLrIK6l7DCgcvdSEfU6Y8CB/oXmmvt65bBPIg5mlWOHxz
ztlQMDMP4h6gerB/1fMcLijd/lkXBvWPTp6DcPOBUwt9Kxzir0bqbsjLcxAC
8Z0rHITnXXjtvzPPIef575Uf9SocjqW5r3p/PQ8Sfh5Qecd8h+l5QB1A8/b2
L7bcdDLP4dMl3ySBLKh7LiD44PiQyofzzZcENk7uyHfgBbkvvcLBCeTff/kQ
+9ZVOCzc+6siQ7QAgx+3y5OHaXOFQwanEdMq9wKHLSfK9s0/g+BfrXipZvgM
wd8p1/o68BVCPzofHB+GlXD7y/fNl9LXr4S7D8aHuR/Gh/nvIig8nSrh/p8B
Co+ASnj4gO3LqoSHHzi8Qyvh4QsOb+9KePiD9QPNg8UPKHn5p1fC4w/sv4JK
ePyCzeushMe/+8MqkXVA9bD0IQsyILoSnn4WuW77/DekEp6+wOZVVcLTHzi9
d1TC0+fjpbOPKMyphKdfsHt6K+HpG8xvrISnf0tQhBRXwvMHOLwKK+H5B6y+
E8EH+387gg/2/65KeP4Ex/85TD4sfwMAoHLEYw==
                    "], 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    399.008, 246.42000000000002`}, {400.867, 
                    247.97899999999998`}, {400.867, 249.97899999999998`}, {
                    400.188, 249.91299999999998`}, {399.816, 249.678}, {
                    399.312, 249.02200000000002`}, {398.887, 250.346}, {
                    397.949, 251.38100000000003`}, {396.688, 252.026}, {
                    395.42999999999995`, 251.38100000000003`}, {
                    394.49199999999996`, 250.393}, {394.066, 249.069}, {
                    393.562, 249.725}, {393.191, 249.91299999999998`}, {
                    392.512, 249.97899999999998`}, {392.512, 
                    247.97899999999998`}, {394.371, 
                    246.42000000000002`}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    399.008, 246.420006}, {400.867, 247.979006}, {400.867, 
                    249.979006}, {400.188, 249.912006}, {399.816, 
                    249.67800599999998`}, {399.312, 249.022006}, {398.887, 
                    250.34600600000002`}, {397.949, 251.38100600000004`}, {
                    396.688, 252.02600600000002`}, {395.42999999999995`, 
                    251.38100600000004`}, {394.49199999999996`, 250.393006}, {
                    394.066, 249.069006}, {393.562, 249.725006}, {393.191, 
                    249.912006}, {392.512, 249.979006}, {392.512, 
                    247.979006}, {394.371, 246.420006}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}}}, {{{400.,
                     241.405}, {400.867, 243.27599999999998`}, {400.867, 
                    245.873}, {400.188, 245.80700000000002`}, {399.816, 
                    245.569}, {399.312, 244.901}, {398.887, 246.248}, {
                    397.949, 247.295}, {396.688, 247.948}, {
                    395.42999999999995`, 247.295}, {394.49199999999996`, 
                    246.295}, {394.066, 244.95200000000003`}, {393.562, 
                    245.61599999999999`}, {393.191, 245.80700000000002`}, {
                    392.512, 245.873}, {392.512, 243.27599999999998`}, {
                    393.375, 241.405}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}}}, {{{400.,
                     241.40500600000001`}, {400.867, 243.276006}, {400.867, 
                    245.873006}, {400.188, 245.80700600000003`}, {399.816, 
                    245.569006}, {399.312, 244.90100600000002`}, {398.887, 
                    246.24800599999998`}, {397.949, 247.295006}, {396.688, 
                    247.948006}, {395.42999999999995`, 247.295006}, {
                    394.49199999999996`, 246.295006}, {394.066, 244.952006}, {
                    393.562, 245.616006}, {393.191, 245.80700600000003`}, {
                    392.512, 245.873006}, {392.512, 243.276006}, {393.375, 
                    241.40500600000001`}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    400.133, 234.623}, {402.895, 237.991}, {402.895, 
                    241.311}, {401.883, 241.198}, {401.332, 240.795}, {
                    400.58599999999996`, 239.666}, {399.953, 241.94}, {
                    398.559, 242.44}, {396.688, 243.541}, {394.82, 242.44}, {
                    393.42599999999993`, 242.02200000000002`}, {
                    392.79299999999995`, 239.74499999999998`}, {392.047, 
                    240.877}, {391.4959999999999, 241.198}, {390.484, 
                    241.311}, {390.484, 237.991}, {393.246, 
                    234.623}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    400.133, 234.623006}, {402.895, 237.99100600000003`}, {
                    402.895, 241.31100600000002`}, {401.883, 241.198006}, {
                    401.332, 240.795006}, {400.58599999999996`, 239.666006}, {
                    399.953, 241.940006}, {398.559, 242.440006}, {396.688, 
                    243.541006}, {394.82, 242.440006}, {393.42599999999993`, 
                    242.022006}, {392.79299999999995`, 239.745006}, {392.047, 
                    240.87700600000002`}, {391.4959999999999, 241.198006}, {
                    390.484, 241.31100600000002`}, {390.484, 
                    237.99100600000003`}, {393.246, 234.623006}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJRIGYC4skSLGF8/JUOh79qxPTX5Tig8y8q3f5Z51Tp
sEOu9XXgjRwHxQ1FGRNdKx0UQDRnLpxvYgwE1bkOws0HTi00rHQ4BNJflusw
PU+o+YBcpcO1ipdqhjm5DgwgIFDpYMd1fXGBba6D/l0VtkbmSod7QGrq7FwH
Xt1Nc9+/r3B48Xvlx0tbcx3idnnyMJ2ucBC7ee578ONch8dLZx9RWIaQB7tz
UgVcP9j8tgq4+VEp1vf9yyvg9t/3752el1IBd98FkP8CKuDuh/Fh/osF2R9e
Afc/mN9eAQ8fdD4AYnmREg==
                    "]]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJRIGYC4skSLGF8/JUONfr7MvrrchzQ+ReVbv+sc6p0
KIyQ+hF4I8dBcUNRxkTXSoebL9lLJ3Lmwvlvck7YG1fnOgg3Hzi10LDSoRqk
vyzXYXqeUPMBuUqH/k11xoY5uQ4MICBQ6fDNOWdDgW2ug/5dFbZG5kqHaXGz
e6fOznXg1d009/37CocFpvb/Lm3NdYjb5cnDdLrC4bxQCkvI41yHx0tnH1FY
hpA//FUjpn9SBVw/2Py2Crj5USnW9/3LK+D23/fvnZ6XUgF33wWQ/wIq4O6H
8WH+iwXZH14B9z+Y314BDx90PgAvoo88
                    "], 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJRIGYC4kWu2z7/Val0qMvaUzL5S5YDOt+W6/riguxK
h2SBCMstE7IdJkuwhPHlVjrYgcTPIviHv2rE9NflOCybfURhQ1Clg9jNc9+D
y3McrLacKNtnWemQ+/z3yo9BOQ475FpfB6pVOkx8W2NvygWVF610cANae2VO
joNsVIr1/d8VDgG90/OEmHMd4nZ58jCdroCo98p1uFrxUs1wFkIebF5DBVy/
Jci8/Aq4+WD5mAq4/SDj/Z0r4O4Di2tUwN0P48P8xwACehWo/i+sgIcPOh8A
E0eazg==
                    "]]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJRIGYC4kWu2z7/Val0MF8S2Dj5S5YDOt+W6/riguxK
B2mvt65bJmQ7TJZgCePLrXT45pyzoeAsgl+jvy+jvy7HYdnsIwobgiodzgul
sISU5zhYbTlRts+y0kFVceK2j0E5DjvkWl8HqlU6eKkL+ZhyQeVFKx3+v+/g
ujonx0E2KsX6/u8KB87jOtVCzLkOcbs8eZhOV0DUe+U6XK14qWY4CyEPNq+h
Aq7fEmRefgXcfLB8TAXcfpDx/s4VcPflPv+98qNGBdz9MD7MfwwgoFeB6v/C
Cnj4oPMBbMiPBA==
                    "], CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJRIGYC4kWu2z7/Val0WFJgy3WdO8sBnZ8x8W2NfWKl
Q4TllhNlbVkOkyVYwvhyKx3uqbA1Tt2N4LsBtV3JyXZYNvuIwoagSgeg7sUF
qdkOVkBt+ywrHT4sP+Zt7pjtsEOu9XWgWqUDSFnRjyyIvGilQ0Dv9Dyh7mwH
2agU6/u/Kxxyn/9e+fFetkPcLk8eptMVDuvcH1aJqOU4XK14qWY4CyEPNq+h
Aq4f5Mx9+RVw88HyMRVw+0HG+ztXwN0HNkejAu5+GB/mP6CuTkeLClT/F1bA
wwedDwA3dZqj
                    "]]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJRIGYC4kWu2z7/Val0iF11Sew6d5YDOj9j4tsa+8RK
B4Fiz6tlbVkOkyVYwvhyKx2mxc3unbobwf//voPrak62w7LZRxQ2BFU6fHPO
2VCQmu1gteVE2T7LSocVD6MjzB2zHXbItb4OVKt0CPm3dU/RjyyIvGilA+dx
nWqh7mwH2agU6/u/KxzUFCdu+3gv2yFulycP0+kKh/TGsnYRtRyHqxUv1Qxn
IeTB5jVUwPVbgszLr4CbD5aPqYDbDzLe37kC7r7c579XftSogLsfxof575i3
eaejRQWq/wsr4OGDzgcArUeZzg==
                    "], 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{403.832, 
                    204.131}, {402.734, 208.91299999999998`}, {401.789, 
                    212.455}, {396.4959999999999, 216.053}, {391.207, 
                    212.455}, {390.262, 208.91299999999998`}, {
                    389.16400000000004`, 204.131}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{403.832, 
                    204.131006}, {402.734, 208.912006}, {401.789, 
                    212.45500600000003`}, {396.4959999999999, 216.053006}, {
                    391.207, 212.45500600000003`}, {390.262, 208.912006}, {
                    389.16400000000004`, 204.131006}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}}}, {{{419.633, 
                    211.846}, {416.445, 210.21699999999998`}, {413.633, 
                    208.33}, {412.832, 203.866}, {419.633, 
                    203.866}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}}}, {{{419.633, 
                    211.84600600000002`}, {416.445, 210.217006}, {413.633, 
                    208.33000600000003`}, {412.832, 203.86600600000003`}, {
                    419.633, 203.86600600000003`}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}}}, {{{375.42999999999995`, 218.62}, {
                    375.42999999999995`, 203.866}, {373.34400000000005`, 
                    203.866}, {373.34400000000005`, 218.655}, {
                    373.9959999999999, 218.959}, {374.887, 219.006}, {
                    375.42999999999995`, 218.62}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}}}, {{{375.42999999999995`, 218.620006}, {
                    375.42999999999995`, 203.86600600000003`}, {
                    373.34400000000005`, 203.86600600000003`}, {
                    373.34400000000005`, 218.65500600000001`}, {
                    373.9959999999999, 218.95900600000002`}, {374.887, 
                    219.006006}, {375.42999999999995`, 218.620006}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}}}, {{{
                    373.34400000000005`, 211.846}, {376.53099999999995`, 
                    210.21699999999998`}, {379.688, 208.33}, {
                    380.48799999999994`, 203.866}, {373.34400000000005`, 
                    203.866}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}}}, {{{
                    373.34400000000005`, 211.84600600000002`}, {
                    376.53099999999995`, 210.217006}, {379.688, 
                    208.33000600000003`}, {380.48799999999994`, 
                    203.86600600000003`}, {373.34400000000005`, 
                    203.86600600000003`}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}}}, {{{375.42999999999995`, 218.62}, {
                    375.42999999999995`, 203.866}, {373.34400000000005`, 
                    203.866}, {373.34400000000005`, 218.655}, {
                    373.9959999999999, 218.959}, {374.887, 219.006}, {
                    375.42999999999995`, 218.62}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}}}, {{{375.42999999999995`, 218.620006}, {
                    375.42999999999995`, 203.86600600000003`}, {
                    373.34400000000005`, 203.86600600000003`}, {
                    373.34400000000005`, 218.65500600000001`}, {
                    373.9959999999999, 218.95900600000002`}, {374.887, 
                    219.006006}, {375.42999999999995`, 218.620006}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}}}, {{{
                    373.34400000000005`, 211.846}, {376.53099999999995`, 
                    210.21699999999998`}, {379.688, 208.33}, {
                    380.48799999999994`, 203.866}, {373.34400000000005`, 
                    203.866}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}}}, {{{
                    373.34400000000005`, 211.84600600000002`}, {
                    376.53099999999995`, 210.217006}, {379.688, 
                    208.33000600000003`}, {380.48799999999994`, 
                    203.86600600000003`}, {373.34400000000005`, 
                    203.86600600000003`}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}}}, {{{338.191, 
                    232.01399999999998`}, {338.191, 237.768}, {343.156, 
                    238.416}, {343.156, 238.416}, {343.156, 233.295}, {
                    341.26599999999996`, 233.377}, {340.355, 231.678}, {
                    340.355, 229.155}, {340.355, 226.627}, {341.879, 
                    226.58800000000002`}, {341.879, 226.58800000000002`}, {
                    341.879, 212.05700000000002`}, {338.191, 
                    212.05700000000002`}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}}}, {{{338.191, 232.014006}, {
                    338.191, 237.76800599999999`}, {343.156, 238.416006}, {
                    343.156, 238.416006}, {343.156, 233.295006}, {
                    341.26599999999996`, 233.37700600000002`}, {340.355, 
                    231.67800599999998`}, {340.355, 229.15500600000001`}, {
                    340.355, 226.62700600000002`}, {341.879, 226.588006}, {
                    341.879, 226.588006}, {341.879, 212.05700600000003`}, {
                    338.191, 212.05700600000003`}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}}}, {{{301.48799999999994`, 
                    232.01399999999998`}, {301.48799999999994`, 237.768}, {
                    296.52299999999997`, 238.416}, {296.52299999999997`, 
                    238.416}, {296.52299999999997`, 233.295}, {298.414, 
                    233.377}, {299.324, 231.678}, {299.324, 229.155}, {
                    299.324, 226.627}, {297.801, 226.58800000000002`}, {
                    297.801, 226.58800000000002`}, {297.801, 
                    212.05700000000002`}, {301.48799999999994`, 
                    212.05700000000002`}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}}}, {{{301.48799999999994`, 
                    232.014006}, {301.48799999999994`, 237.76800599999999`}, {
                    296.52299999999997`, 238.416006}, {296.52299999999997`, 
                    238.416006}, {296.52299999999997`, 233.295006}, {298.414, 
                    233.37700600000002`}, {299.324, 231.67800599999998`}, {
                    299.324, 229.15500600000001`}, {299.324, 
                    226.62700600000002`}, {297.801, 226.588006}, {297.801, 
                    226.588006}, {297.801, 212.05700600000003`}, {
                    301.48799999999994`, 212.05700600000003`}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}}}, {{{406.637, 
                    201.55700000000002`}, {406.637, 208.483}, {404.234, 
                    207.541}, {402.062, 206.147}, {401.262, 204.596}, {
                    400.367, 208.44}, {398.64500000000004`, 210.135}, {
                    396.4959999999999, 212.459}, {394.348, 210.135}, {
                    392.90999999999997`, 208.44}, {392.01599999999996`, 
                    204.596}, {391.215, 206.147}, {389.043, 207.541}, {
                    386.641, 208.483}, {386.641, 
                    201.55700000000002`}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}}}, {{{406.637, 
                    201.55700600000003`}, {406.637, 208.48300600000002`}, {
                    404.234, 207.541006}, {402.062, 206.147006}, {401.262, 
                    204.59600600000002`}, {400.367, 208.440006}, {
                    398.64500000000004`, 210.135006}, {396.4959999999999, 
                    212.45900600000002`}, {394.348, 210.135006}, {
                    392.90999999999997`, 208.440006}, {392.01599999999996`, 
                    204.59600600000002`}, {391.215, 206.147006}, {389.043, 
                    207.541006}, {386.641, 208.48300600000002`}, {386.641, 
                    201.55700600000003`}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    194.39100000000002`, 145.05700000000002`}, {445.605, 
                    145.05700000000002`}, {445.60900000000004`, 132.225}, {
                    194.395, 132.225}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    194.39100000000002`, 145.057006}, {445.605, 145.057006}, {
                    445.60900000000004`, 132.225006}, {194.395, 132.225006}}},
                     CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    187.76999999999998`, 132.24499999999998`}, {452.227, 
                    132.24499999999998`}, {452.22999999999996`, 119.432}, {
                    187.77299999999997`, 119.432}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    187.76999999999998`, 132.245006}, {452.227, 132.245006}, {
                    452.22999999999996`, 119.432006}, {187.77299999999997`, 
                    119.432006}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    207.586, 164.248}, {432.41400000000004`, 164.248}, {
                    432.41400000000004`, 155.947}, {207.586, 
                    155.947}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    207.586, 164.24800599999998`}, {432.41400000000004`, 
                    164.24800599999998`}, {432.41400000000004`, 155.947006}, {
                    207.586, 155.947006}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    201.012, 156.002}, {438.98900000000003`, 156.002}, {
                    438.98900000000003`, 145.127}, {201.01200000000003`, 
                    145.127}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    201.012, 156.002006}, {438.98900000000003`, 156.002006}, {
                    438.98900000000003`, 145.127006}, {201.01200000000003`, 
                    145.127006}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    211.512, 170.635}, {428.48900000000003`, 170.635}, {
                    428.48900000000003`, 164.31099999999998`}, {
                    211.51200000000003`, 
                    164.31099999999998`}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    211.512, 170.635006}, {428.48900000000003`, 170.635006}, {
                    428.48900000000003`, 164.311006}, {211.51200000000003`, 
                    164.311006}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    235.062, 170.6}, {251.453, 170.6}, {251.453, 
                    119.46699999999998`}, {235.062, 
                    119.46699999999998`}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0013056953125000002`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    235.062, 170.600006}, {251.453, 170.600006}, {251.453, 
                    119.46700600000003`}, {235.062, 119.46700600000003`}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    238.691, 170.6}, {247.824, 170.6}, {247.824, 
                    119.46699999999998`}, {238.691, 
                    119.46699999999998`}}}]}}}}}}}, {{{{{{{
                    Thickness[0.001303675], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    238.691, 170.600006}, {247.824, 170.600006}, {247.824, 
                    119.46700600000003`}, {238.691, 119.46700600000003`}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{238.523, 164.291006}, {
                    247.98800000000003`, 164.291006}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{238.523, 157.893006}, {
                    247.98800000000003`, 157.893006}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{238.523, 
                    151.49100599999997`}, {247.98800000000003`, 
                    151.49100599999997`}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{238.523, 
                    145.09200600000003`}, {247.98800000000003`, 
                    145.09200600000003`}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{238.523, 
                    138.69400600000006`}, {247.98800000000003`, 
                    138.69400600000006`}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{238.523, 
                    132.29100599999998`}, {247.98800000000003`, 
                    132.29100599999998`}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{238.523, 
                    125.89300600000001`}, {247.98800000000003`, 
                    125.89300600000001`}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    311.52, 170.6}, {327.911, 170.6}, {327.911, 
                    119.46699999999998`}, {311.52, 
                    119.46699999999998`}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0013056953125000002`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    311.52, 170.600006}, {327.911, 170.600006}, {327.911, 
                    119.46700600000003`}, {311.52, 119.46700600000003`}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    315.262, 170.6}, {324.395, 170.6}, {324.395, 
                    119.46699999999998`}, {315.262, 
                    119.46699999999998`}}}]}}}}}}}, {{{{{{{
                    Thickness[0.001303675], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    315.262, 170.600006}, {324.395, 170.600006}, {324.395, 
                    119.46700600000003`}, {315.262, 119.46700600000003`}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{315.309, 164.303006}, {
                    324.121, 164.303006}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{315.309, 
                    157.89700600000003`}, {324.121, 157.89700600000003`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{315.309, 151.495006}, {
                    324.121, 151.495006}}}, CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{315.309, 
                    145.09200600000003`}, {324.121, 145.09200600000003`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{315.309, 
                    138.69000600000004`}, {324.121, 138.69000600000004`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{315.309, 
                    132.28400600000003`}, {324.121, 132.28400600000003`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{315.309, 
                    125.88100600000001`}, {324.121, 125.88100600000001`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    388.43399999999997`, 170.6}, {404.825, 170.6}, {404.825, 
                    119.46699999999998`}, {388.43399999999997`, 
                    119.46699999999998`}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0013056953125000002`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    388.43399999999997`, 170.600006}, {404.825, 170.600006}, {
                    404.825, 119.46700600000003`}, {388.43399999999997`, 
                    119.46700600000003`}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    392.062, 170.6}, {401.195, 170.6}, {401.195, 
                    119.46699999999998`}, {392.062, 
                    119.46699999999998`}}}]}}}}}}}, {{{{{{{
                    Thickness[0.001303675], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    392.062, 170.600006}, {401.195, 170.600006}, {401.195, 
                    119.46700600000003`}, {392.062, 119.46700600000003`}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{391.89799999999997`, 
                    164.291006}, {401.363, 164.291006}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{391.89799999999997`, 
                    157.893006}, {401.363, 157.893006}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{391.89799999999997`, 
                    151.49100599999997`}, {401.363, 151.49100599999997`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{391.89799999999997`, 
                    145.09200600000003`}, {401.363, 145.09200600000003`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{391.89799999999997`, 
                    138.69400600000006`}, {401.363, 138.69400600000006`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{391.89799999999997`, 
                    132.29100599999998`}, {401.363, 132.29100599999998`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{391.89799999999997`, 
                    125.89300600000001`}, {401.363, 125.89300600000001`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    270.42999999999995`, 192.791}, {274.10599999999994`, 
                    192.791}, {274.10599999999994`, 175.9}, {
                    270.42999999999995`, 175.9}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Round"], 
                    JoinForm["Round"], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    270.42999999999995`, 192.791006}, {274.10599999999994`, 
                    192.791006}, {274.10599999999994`, 175.90000600000002`}, {
                    270.42999999999995`, 175.90000600000002`}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    278.10900000000004`, 192.791}, {281.785, 192.791}, {
                    281.785, 175.9}, {278.10900000000004`, 
                    175.9}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Round"], 
                    JoinForm["Round"], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    278.10900000000004`, 192.791006}, {281.785, 192.791006}, {
                    281.785, 175.90000600000002`}, {278.10900000000004`, 
                    175.90000600000002`}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    285.79299999999995`, 192.791}, {289.465, 192.791}, {
                    289.465, 175.9}, {285.79299999999995`, 
                    175.9}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Round"], 
                    JoinForm["Round"], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    285.79299999999995`, 192.791006}, {289.465, 192.791006}, {
                    289.465, 175.90000600000002`}, {285.79299999999995`, 
                    175.90000600000002`}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    350.113, 192.791}, {353.785, 192.791}, {353.785, 175.9}, {
                    350.113, 175.9}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Round"], 
                    JoinForm["Round"], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    350.113, 192.791006}, {353.785, 192.791006}, {353.785, 
                    175.90000600000002`}, {350.113, 175.90000600000002`}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    357.79299999999995`, 192.791}, {361.46899999999994`, 
                    192.791}, {361.46899999999994`, 175.9}, {
                    357.79299999999995`, 175.9}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Round"], 
                    JoinForm["Round"], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    357.79299999999995`, 192.791006}, {361.46899999999994`, 
                    192.791006}, {361.46899999999994`, 175.90000600000002`}, {
                    357.79299999999995`, 175.90000600000002`}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    365.47299999999996`, 192.791}, {369.14899999999994`, 
                    192.791}, {369.14899999999994`, 175.9}, {
                    365.47299999999996`, 175.9}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Round"], 
                    JoinForm["Round"], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    365.47299999999996`, 192.791006}, {369.14899999999994`, 
                    192.791006}, {369.14899999999994`, 175.90000600000002`}, {
                    365.47299999999996`, 175.90000600000002`}}}, 
                    CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    312.191, 277.08799999999997`}, {311.78499999999997`, 
                    280.28799999999995`}, {328.004, 280.28799999999995`}, {
                    327.59799999999996`, 
                    277.08799999999997`}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    312.191, 277.088006}, {311.78499999999997`, 280.288006}, {
                    328.004, 280.288006}, {327.59799999999996`, 277.088006}}},
                     CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    313.277, 280.35}, {312.92999999999995`, 282.979}, {
                    326.85900000000004`, 282.979}, {326.512, 
                    280.35}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    313.277, 280.350006}, {312.92999999999995`, 282.979006}, {
                    326.85900000000004`, 282.979006}, {326.512, 280.350006}}},
                     CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    315.48799999999994`, 283.077}, {315.258, 285.709}, {
                    324.53099999999995`, 285.709}, {324.301, 
                    283.077}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    315.48799999999994`, 283.077006}, {315.258, 285.709006}, {
                    324.53099999999995`, 285.709006}, {324.301, 283.077006}}},
                     CurveClosed -> {1}]}}}}}}}}}}}}}}, AspectRatio -> 
                  Automatic, ImageSize -> {{128}, {85}}, 
                  PlotRange -> {{0., 640.}, {0., 411.}}], ",", 
                 GraphicsBox[{{{{{{{
                    Thickness[0.0010416666666666667`], {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.8078430000000001, 0.06666670000000002, 0.14902], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {0., 640.}, {960., 640.}, {960., 
                    0.}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     320.}, {960., 320.}, {960., 0.}, {0., 
                    0.}}}]}}}}}}}}}}}}}}, AspectRatio -> Automatic, 
                  ImageSize -> {{128}, {85}}, 
                  PlotRange -> {{0., 960.}, {0., 640.}}], ",", 
                 GraphicsBox[{{{{{{{
                    Thickness[0.001388888888888889], {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {0., 480.}, {720., 480.}, {720., 
                    0.}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0.737255, 0., 0.17647100000000002`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{504., 240.}, {504., 160.47299999999998`}, {
                    439.527, 96.}, {360., 96.}, {280.47299999999996`, 96.}, {
                    216., 160.47299999999998`}, {216., 240.}, {216., 
                    319.527}, {280.47299999999996`, 384.}, {360., 384.}, {
                    439.527, 384.}, {504., 319.527}, {504., 
                    240.}}}]}}}}}}}}}}}}}}, AspectRatio -> Automatic, 
                  ImageSize -> {{128}, {85}}, 
                  PlotRange -> {{0., 720.}, {0., 480.}}], ",", 
                 GraphicsBox[{{{{{{{
                    Thickness[0.0016666666666666668`], {{{{{{{
                    FaceForm[{
                    RGBColor[0.9294119999999999, 0.109804, 0.141176], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {0., 400.}, {600., 400.}, {600., 
                    0.}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     300.}, {600., 300.}, {600., 100.}, {0., 
                    100.}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0., 0.65098, 0.31764699999999996`], 
                    Opacity[1.]}], 
                    FilledCurveBox[{CompressedData["
1:eJxTTMoPSmJiYGDYBMTMQMzAxMDIzAxEDIwMQARhD29Ef29SYiNV4oWgIWgK
AO1qBvs=
                    "], {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {0, 1, 
                    0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4,
                     3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {CompressedData["
1:eJx9WWmUVNURHhYFhYMIAwjCBBUGjQtwYgRB5cKgaARRUfRNdw9098z0Mr28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                    "], CompressedData["
1:eJxTTMoPSmViYGAwAWIQPVmCJYzPsNABTCcWONhyXV9cYFzo0Po6cIcckM8A
AmYI+S0nyvbNt0Dwl84+orDBB8GPSrG+7x9d6PAYJBFT4OBt3umYkFjocOir
Rkx/SIGD/l0VtkYg/22NvWlcCNT8pEIHPt1Nc98HF0D0AfmWIIuA/OMgA4B8
hQ1FGROB/HcgfUlQ+4D8i0q3f9YB+dUi69wfBhU4lO+bL6WfXOhgBdIfWAAx
JxlqXwDUvhSo//wLHD5d8k0SAPKrQPr9CiDqgPyrFS/VDJH4siCP+RY43Pfv
nZ4H5BuA/OGLkIeEA4J/DORuJD7Yf94I/eBw8kbIx+3y5GFC4j8AqfOChgeQ
Dw43T4T7c5//XvnRowBibjI0fD0Q/gWrA/KFmg+cWgjkuz8E+RAav/HQ8LEs
cADGztMLHoUQdykUOKCkB/4CSLjIQdUzQsNLpNBhkeu2z3+/5EPs5y10iAW5
/3s+JFyAfJCxSkA+2HyeQgdg7L2tAfLB9vBA4xfIB4cTD9S9P/Ih4cxd6LDq
I9AiIB/sbiC/AORwIB8cbtzQ+PsJNZ+r0OESKB38ync4DAoHIN8JZP9vqH1s
hRBxpgIHYVB4sELTpwCCD7ZfA8HXahe7eQ6YvjxA9vNC3RuPFj7A9A4ADNBT
Sg==
                    "], CompressedData["
1:eJxTTMoPSmViYGAQBmIQHbvLk4fJvtgh9/nvlR+1Chz076qwNSLx3R9WiaxD
4j9eOvuIggOC3+GY8PRCHIJvy3V9cUFxscOhrxox/TIFDkLNB04tLC922HKi
bN98lgKHTpD6mmKHvSWTJVjO5TtcULr9s66g2MEAZO/efLj5MD7YXBUEv3zf
fCl90WIHJ6AxSofzHRQ3FGVM5C12eFtjbxp3Kd9BJirF+j57sYO6IccamXv5
EPexFTtYgRzwPt9hkeu2z385EO5pfR24Qw6o/2rFSzVDGShfsdjhIshdQP+g
hw8AONOPXA==
                    "], CompressedData["
1:eJxTTMoPSmViYGAQA2IQnfv898qPS4ocGEBArsBBqPnAqYX7ixweL519REGh
wGGnXOvrwFNFDjtAtACCDyR3yN3Nh/Nlo1Ks73fnO3Q6Jjy9sKvI4aLS7Z91
RfkOwiDzCqHqffMdbLmuLy5wLnLQv6vC1miaDxGXLHLYeqJs33ytfIerFS/V
DAWKHFTZGqc6G+dD3AXkF2VMfFsD5IPdxw+1zxhqHj/UvSb5Dt7mQBcA+cdA
DBOo+UD+/vlS+neB/MkSLGF8QP4i122f/wL5VluAFn8thMjn5Dvw6W6a+567
yKF3ep5Q8xaofu8ih9hdnjxM3/MdLEHqi4sg/gSGR7XIOveHE4oc7vsDdcgU
OKCHJwB+5Zh8
                    "], {{320.469, 257.85200000000003`}, {
                    322.90999999999997`, 257.92999999999995`}, {323.219, 
                    256.777}, {322.027, 253.35200000000003`}, {321.617, 
                    252.172}, {319.914, 251.21499999999997`}, {318.25, 
                    251.21499999999997`}, {315.812, 251.21499999999997`}, {
                    315.29299999999995`, 251.805}, {315.605, 254.262}, {
                    315.887, 256.445}, {316.96099999999996`, 257.441}, {
                    319.383, 257.746}, {319.78499999999997`, 
                    257.79699999999997`}, {320.14500000000004`, 
                    257.84000000000003`}, {320.469, 
                    257.85200000000003`}}, CompressedData["
1:eJxTTMoPSmViYGBQBWIQbct1fXHBxkKHKpF17g/T8h1m5Ak1H9hU6OCY8PSC
Unq+ww651teBWxDyihuKMiZuRfBzn/9e+fEJgg8273ihw+Ols48obMlzOPxV
I6a/q9DhbY29aVxSHsS8kEIH/bsqbI2SeQ7LgMo2SBU6qBtyrJH5lQtRz1Xo
cEHp9s86sTyHB/690/OA/OkgdwH5x73NOx2BfFW2xqnO4nkOVyteqhkC+f2H
gBqBfKDpO+Q4EeaD3cFRCNEnkwcRZy90qAa5Vy4P4l52qHnyeQ7l++ZL6bND
3a8ANQ/I7wU5AMifLMESxgfkg8UV8yD+Zit0uAhyr1IexJ1AftwuTx4m5TwH
kDEbgHxgqL2tAfLvg/wD5B8DuUclDxIuQD5Qd9YeFWj4APk+QOkEVYT6LSfK
9s1XQ6gHu1cdoR7sP408BwYQAPK5gd6y1ULwJ4DCRxvBD+PT3TQXiQ+mdRB8
sHlAflSK9X1/oH9vnvse/LgXGl6VhQ4g79jHQuMbKf0AAGv56A4=
                    
                    "], CompressedData["
1:eJxTTMoPSmViYGCQB2IQfeirRkx/XrFD6+vAHXIncx3K982X0m8tdth6omzf
/HO5Dvp3VdgaJ0Pl5+Y6CDUfOLWwu9iB6/riAlunXIeoFOv7/u3FDlZbgBr4
cx1m5AFVFBQ73PlZl7XnTY5Dlcg694d+xQ6Pl84+ovAkx2GR67bPf02KHYRB
5tyF8lWKHWRBBt3Pcch5/nvlR7liB3VDjjUy76D65aD2Aflg9wL51SBxJH7c
Lk8epvc5Dse8zTsd5aDuAfIZQADIvw1yz4cciLhsMcRfH3McPB4CbQDyvwGN
OQTkG4DEZaHmf8pxABmXAOQ7JTy9oPQZwe8HWQzkT5ZgCeOThbr/M9Q/MsUQ
e7/kQMwB8vcDg/UukD8dFD5A/tsae9O4bzkOIOfMl4Ga9z0HEi6SxQ7FGRPf
1gDD89Ml3yQBtWKHQltgCNjkQuQdoe5thfIDofZtgMZXYrHD3hKgy47lOqDH
LwAEcN+m
                    "], CompressedData["
1:eJxTTMoPSmViYGCQAGIQbXBXha1xb5FD6+vAHXJbcx22nCjbN39fkYOPeadj
ApCvsKEoY+J+hPwFpds/6w4g+LJRKdb33yL45fvmS+l/LXLImPi2xj411+GY
N9CgM0UO+4HCd01yHUDK/XcWOWwF2SOX65Dz/PfKj8uKHPaWTJZg4ct1ANr6
9MKCIofHS2cfUeCBugeJDzYPyFdja5zqzJ3r8OmSb5IAEl8GZMH8IocJh75q
xAD5tlzXFxfMR+gH24/EB7t/dpHDRZC/YPY3Idyn1S5281x6kQNQNmuPQa4D
SNsGsyIHdUOONTJBuQ5XK16qGeYVOTCAQEuuw4w8oeYDXUUO4HCdm+sA9FUY
31qoeZtyHdDDGwDyRK63
                    "], {{323.703, 234.539}, {325.039, 
                    234.60899999999998`}, {326.49199999999996`, 
                    234.35200000000003`}, {327.902, 233.758}, {330.465, 
                    232.684}, {330.96099999999996`, 231.754}, {
                    330.47299999999996`, 228.945}, {329.812, 225.129}, {
                    327.72999999999996`, 224.70299999999997`}, {
                    320.60900000000004`, 226.969}, {317.113, 
                    228.08200000000002`}, {316.754, 228.61299999999997`}, {
                    317.871, 230.92200000000003`}, {318.941, 233.125}, {
                    321.14500000000004`, 234.40200000000002`}, {323.703, 
                    234.539}}, CompressedData["
1:eJxTTMoPSmViYGAQBmIQfczbvNPxXYGDKlvjVGfjXAf9uypsje8R/GWzjyhs
+IDgM4DAJwS/WmSd+0OXQjh/h1zr68CAQocLSrd/1olB1WsUOqz+eMk3aU2O
wwP/3ul5UoUO++ZL6d/tyHGYkSfUfIChEEIH5ThsOVG2bz7QPUBVQs0mOQ6d
jglPL1wqcHhbY28ax5bjsBNk/qkCBzWQfdxQ9TsKHB4vBTo0JMdBYUNRxsTF
BRB3rcpxWOS67fPfOQUQdzzJcciYCDRpeYED1/XFBbZsUP9tKICoU4G690SB
w0WQ+41yHdDDBwASMn/g
                    "], CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQYiBQ4u3TnPf7/McYhKsb7vb17gIAtivM5xaH0d
uEPOt8DhktLtn3WnoPKZBQ7fNGL6D2XmOOQ+/73y44QCh4yJb2vsH2Y7eDys
ElkXWuBQBBLYnO2gsAHIki9wuHnue/DjzmyHCyBzxKD6J2Y79B/6qhFzOR9i
H3+OQ9wuTx6m2fkOE0Di8TkOPuadjgmt+Q6Pl84+ojAlxwGoO2vPlHwH/bsq
bI1bcxzUDTnWyEzLd+idnifUvCPHAeyfGfkQek8OxF8z8x1mAKUP7MuB+GMW
1Pz9OQ5WW06U7QPaV2jLdX3xgRyH495AC+fkQ/xzMMdh/3wp/btAPtj9QD6Y
npvv4JTw9ILS4RyHiyDz5uU7WILMAfLB9myC2n8jx6EYZNDtfIi/Huc4AH3z
9AJPgcOqj5d8k15Aw5O/wOEWyF9AvnDzgVMLBaHh9RLqH6T4AQB+fMn0
                    
                    "], {{338.85200000000003`, 218.539}, {341.305, 
                    218.73399999999998`}, {343.812, 217.008}, {343.453, 
                    214.21899999999997`}, {342.9959999999999, 210.676}, {
                    339.129, 209.65200000000002`}, {335.949, 
                    212.21499999999997`}, {334.051, 213.74599999999998`}, {
                    333.97999999999996`, 214.312}, {335.453, 216.535}, {
                    336.29699999999997`, 217.805}, {337.566, 218.434}, {
                    338.85200000000003`, 218.539}}, CompressedData["
1:eJxTTMoPSmViYGCQB2IQfd+/d3qeR5HD/vlS+ndrshxko1Ks73sWObS+Dtwh
V5vloH9Xha3RGyG/yHXb578+CP4OOaDKAATf27zTMSG4yKE4Y+Lbmuosh0+X
fJMEwoochJsPnFpYmeXg/rBKZF14kcNxkMKKLAeFDUUZEyOLHLacKNs3vyzL
Iff575Ufo4ocCmy5ri8ugZoXXeTAAAIlUPNiihxm5Ak1HyjKcgC7H8hXN+RY
IwPkg80B8r9pxPQfKsxymCzBEsYXW+Rw+2dd1p6CLAeQs+yB/FUfgQYVQM2P
hZoP5Gu3i908B+Q7Jjy9oJSfBRGPg9qXl+XweOnsIwpAPtAU0zgg/9BXoEVA
vgEonHKzHKaD1MVBww/GT4H6PzbLoQNkcFqRgxPIfOcsiDlA+WqRde4P5RDu
d+nOAYZEpgOf7qa5702LHCxBEu2ZDqDo8Vctcojd5cnD9DwTYr9YEcRdNlkQ
c1Sg/quAhg9S/AIATUjYeQ==
                    "], CompressedData["
1:eJxTTMoPSmViYGDQA2IQPSNPqPlAQKFD3C5PHiblLAdbruuLCxILHYoyJr6t
Uc9ymA6Sryl08DbvdEwQzHJ4vHT2EYUZhQ6WW06U7Xuc6QDWv6rQoQCk8Uim
wwP/3ul5mwodLijd/lm3LNPhasVLNUMgvxdk0IRMiH4g/22NvWlcX6YDAwgA
+VYg87ozHbTbxW6e21jo8E0jpv9QZ6aDx8MqkXUboeZ3ZDoINx84tRDIB7ur
LRPiXiBfCCTemukAcrY9kA+0PWtPS6ZDtcg694cbCh2cEp5eUGrOdFgGtH4D
kA/SZtuUCXEHkL/Iddvnvw2ZDjJRKdb31xc6TDj0VSOmPtNBYQMwJIB8dUOO
NTJ1UPvWQ91Xm+kAUu4P5O+fL6V/tybToXwfkAHk94EcCOTHgsIVyAf7G8gH
Gdu/Duqeaqj9QD44HKsyIeGwthDij8pMh9znv1d+XFPooMrWONW5HBp+a6D2
l2Y68Olumvt+daGD/l0VtsZSqHuB/FUfL/kmlWRC4m011P4SaHgvKHS4CIqf
JKh/26HhmZbpsEOu9XVgDtT+iZkOiiDzQqHxtyXTYSvQefOdoPofQd3nUOjA
DQrPX9DwBvLB6n4h5ItBBv5G8GVB9v5GqD8OcugfhDzQFTvk/iL4BiD/IfHB
/hGBpk83qH6FLAf09AwAlTtZfA==
                    "], {{301.66, 
                    208.57399999999998`}, {302.141, 208.61299999999997`}, {
                    302.641, 208.14499999999998`}, {303.477, 
                    207.21899999999997`}, {304.53099999999995`, 206.059}, {
                    305.76599999999996`, 203.84}, {306.215, 202.277}, {
                    307.29699999999997`, 198.523}, {305.59, 
                    196.95700000000002`}, {302.25, 198.66}, {298.668, 
                    200.48800000000003`}, {297.79699999999997`, 
                    203.38700000000003`}, {299.867, 206.648}, {300.66, 
                    207.89100000000002`}, {301.148, 208.52700000000002`}, {
                    301.66, 208.57399999999998`}}, CompressedData["
1:eJxTTMoPSmViYGBQBWIQDQYpxQ6OCU8vKOVnOhz+qhHTX1Ts4ATiF2c6vK2x
N41rK3Yoypj4tsY90wFE2XcXO9w89z348d8Mh8dLZx9R6Ct2iNvlycN0OcOh
fN98KX2gPFjfugyHC0q3f9a1QM1bnOFw3793eh4S/2rFSzXDFqj6RVDzkPh8
upvmvm8udnDpznn+e2GGg8IGoEuA/G9AZx4C8r3NOx0TgHz9uypsjUD+ZAmW
MD4gH+xOIP8iyP6mYof9QGfdXQC1D8gvtOW6vngB1D4kPti+xmIH2agU6/vz
Mxy028VunkPiW205UbYPyAfTQD7YXiR5kDEFSHwQ5Y+kvlpknfvDBoT8MqD1
G5D4YGVIfHA4IPF3yLW+DkTiHwMFABIfHJ9IfF6Qf+oRfDCdjOBbgiwMLoaE
0yUEv296nlCzTiacHwYKmPBMh9znv1d+jIKGV06mA3r6AQC7qQgE
                    
                    "], CompressedData["
1:eJxTTMoPSmViYGDQA2IQXS2yzv0hS4GDS3fO898HMxy028VunlNE8Mv3zZfS
ty5wAKvbl+EgG5Vifd+7wIEBBHZkONhyXV9ckF7gUAhirMlwsNpyomxfZYHD
fqC2u3MyHLYCufObChy4gcpsuzIcLijd/lnXUuCgbsixRqYtw+FqxUs1w7YC
h4yJb2vsGzMcWl8H7pBrh+qvyXAQaj5waiGQDzanKgNib0eBQxif7qa55RkO
x7zNOx2BfB8glVCa4TAjD6gDyAfakrWnIMNh2ewjChuAfDW2xqnO2Qj1QNtM
49IyHBa5bvv8F+ieApD7XTIcpoP05xQ4TDj0VSNGOsNBCxQe9lD/vkl3uAhy
vxTU/CPpDlWgcNmW79APUj893QHk/flp+Q6PlwIt7kh30L+rwtb4MA/irrx0
B1WQO87nQeQr0h0sQRqm50HMfQc1rywP4h6TDIi6mDyI+UD/gt0Vneew6uMl
36QWBL8X5HAkPsRfCD44fFsRfLC7gHxwuAD54HhpQ8iD3YHEj93lycPUDg1/
oHuKQAa2I9wH9geQfxwUvkA+JJ4yIOkiBuoeIB8cr0A+SFlCJzT8Y6DuAfIN
QHRsHiT9AfnCoPgH8mHpB6yvEuqe5VD3JOQ7fNOI6T8ETK/o6RkA8GtGnw==

                    "], {{339.984, 185.88700000000003`}, {344.828, 186.098}, {
                    347.445, 182.824}, {342.18, 178.758}, {
                    338.79299999999995`, 176.141}, {333.816, 176.035}, {
                    330.734, 178.523}, {328.51599999999996`, 180.312}, {
                    328.629, 180.566}, {332.668, 183.285}, {
                    335.22299999999996`, 185.}, {337.82, 185.789}, {339.984, 
                    185.88700000000003`}}, CompressedData["
1:eJxTTMoPSmViYGBQBWIQfbXipZphVJmDS3fO898H0xwUNhRlTIwuc+C6vrjA
9lCaw2QJljC+2DKHm+e+Bz8Gyu+Qa30dGIdQb7XlRNm+TAT/mLd5p2NLmUPs
Lk8epuVpDhkT39bYzyxzAOoCak1zACmfv6/MYd98Kf27HmkOF5Ru/6wD8veD
+C5pDlrtYjfP9Zc5OCY8vaB0PdVBqPnAqYXlZQ5AU0zj5qU6AG1Z+TEO6p7C
VIh4GNS9eakQ9yHxP13yTRJA4jOAABKfT3fT3PehCL7HwyqRdUh8YZD9SHxF
UPgg8aNSrO/7I/HB/kXil4M8isTPBbk/BMGvFlnn/hCJDw4fvzIHdUOONTJF
qQ6HvmrE9OuUOdz5WZe1pybVARS8CZzQ8GhLdTgOEnhUCgnfiamQ+DtZ6lBo
CzRxA4IPC08YHxz+N1Ih8QfkO4Hkb0PDA8hf5Lrt8987qQ6Pl84+onChFBLe
smkQcYMyBxmQx7enOaCnHwBpDxOs
                    "], {{268.883, 176.648}, {
                    269.10900000000004`, 176.66}, {269.375, 176.648}, {269.66,
                     176.648}, {272.99199999999996`, 176.648}, {274.828, 
                    173.906}, {274.828, 168.92200000000003`}, {274.828, 
                    162.22299999999998`}, {270.746, 162.762}, {
                    268.85900000000004`, 169.70299999999997`}, {267.219, 
                    175.74599999999998`}, {267.055, 176.547}, {268.883, 
                    176.648}}, CompressedData["
1:eJxNk21IVFEQhhcRifwgLCJExRZTCUL8EWGx7KhFREQUsfdai4XsgUVEt1NY
lEiiYRFSErHaJkuK/ogQiRLpw0Skwh+6H9ZmKRIRIWFRUSAhNHPuwDkXLofn
zpwz55137vb65uMizeVyefGlVT0BCWp9L+DzUGS6qFPC/huNX/8tCMjZ9aj/
R1xCacWGh/ljAn4ljtRvWpTwt8x/c6qf85E3d0zO3EdePtodbkIeODD2e/2e
5pfRvPIl5Jj741ob8uJaW8Nz5OtVZ77EkNU5Bqv7IF/eMnLwE3LBycC+5YiO
35r6U+Y3uCSj/U5NROdX42c38oUJKiwhQXXvav7e6t1dhxzsWW31ImemBkMe
I6709GkuXyrOaO/T+Yf3YGUjrpZezR9In8Ehz8bUYK/er/QZ8XzSFxbw9uJK
SQXefwfp6RJOndcSKh+/aZmoEbBK9x6R8OAnGuESMF549duxKxJeUWJnwNkf
5H4WC+e7n/t3jvtzQoKPjH3G/vgkvDh/e1v6rGblt8FPsHzUYHWOwWSDe05A
uCm3Y9LH/iBfowCyRfUM3kt6jHylJ6bj3RRAvkR1kM9S/5BR7XihJZ01zv2z
2I8499div5BpW8jieUYuGpXBHov1JQTkks/IlOZBVj5YrA85m+Yfue7poay0
pHB8s3m+ktxfW+crP2ydr/wy8kl21GY/kYfRplGb/UnyPNs8H/Osp5b7Mc96
anmekHd2bV2YPSWd/+od6zvN56f4vsb//R8cH8Yx
                    
                    "], CompressedData["
1:eJxTTMoPSmViYGDQAGIQfeirRkz/vEKHjIlva+wnpjoASdO4JYUQelKqg8Fd
FbbGtYUOE8AKUx0eL519RGEXlN+d6mDLdX1xweVChyKQAc2pDsuA0hteFTp4
m3c6JkSmOoC1vSt06JueJ9Ssk+oQlWJ93/9zocPekskSLN9SIOo/FDrIgiTO
pzh8uuSbJADUD7ZnT4qDwgagyS8LHbaeKNs3f1eKwwygMQdeFDqs+ghUuCPF
4WrFSzVDIN8x4ekFpe0pDvog9z4vdACqOrVwa4rDFpC+Z1DztqQ48Olumvv+
aaFDtcg694ebUhyEQeqA/ItKt3/WAflAV4XxAflg8Y0pDiBnH3gCDR8gH+zf
x4UOxSCB9SkOViALHhY63Dz3Pfjx2hSHYyCPPyh0aH0duEMOyAe7436hw52f
dVl71kDdc6/QYTXI/UA+AwgA+cdB+oB8sLvuFELEgXxwON5G8MH+vYVQD3bv
2UKHcJDH1kPDbw/UvxdSIO6GxR9/KkT/HKh8BDS+p0DDtyoVYt/0Qod986X0
73akQtw/Heq/Tmj8z0DE/wVQuM2Auqcn1UG7XezmuZmFkHjqS3XQAvFnFzoU
ggJuAjQ9IKU3ADaTNHQ=
                    "]}]}}}}}}}}}}}}}}, AspectRatio -> 
                  Automatic, ImageSize -> {{128}, {85}}, 
                  PlotRange -> {{0., 600.}, {0., 400.}}], ",", 
                 GraphicsBox[{{{{{{{{
                    Thickness[0.0017211703958691911`], {{{{{{{
                    RGBColor[0., 0.21960800000000003`, 0.5764710000000001], 
                    Thickness[0.07213642512908776], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}}}, {{{21.047, 365.337471}, {507.949, 
                    365.337471}, {21.047, 670.247471}, {21.047, 
                    21.04847099999995}, {507.949, 21.04847099999995}, {21.047,
                     507.946471}}}, CurveClosed -> {1}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{159.875, 
                    129.36100000000002`}, {142.77299999999997`, 
                    88.99700000000001}, {125.66799999999999`, 
                    129.36100000000002`}}}]}}}}}}}}}}}}}}, {{{{{{{{
                    RGBColor[
                    0.8627450000000002, 0.07843140000000001, 
                    0.23529400000000003`], 
                    
                    PolygonBox[{{{21.047, 365.337}, {507.949, 365.337}, {
                    21.047, 670.247}}}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8627450000000002, 0.07843140000000001, 
                    0.23529400000000003`], 
                    
                    PolygonBox[{{21.047, 21.048}, {507.949, 21.048}, {21.047, 
                    507.947}}]}}}}}}}}, {{{{{{{
                    Thickness[0.0017211703958691911`], {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4r0lkyVYnrk5uG37/PfKr1qH4oyJb2vq/RwW
SOnfVZlQ7dB84NRCV79Ih9eBO+Rab1Y63PpZl7XnRiKc/67G3jSOKx3OFwZp
EMyB62cAgR+5cPNh/AJbruuLU2ocgKrYGlfmOGjG9B/6eqHKIW6XJw9TdpbD
QaC12zZWOhSC1OlkOERabjlRNqnCoRVkEWuqgypb41Tn1+Vw98D4vdPzhJoj
YuF8kPN2cYbD9d8Gqe8JgpsPdo+CD9x+WHjA3IcePgAXt4qb
                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{187.90200000000002`, 434.552}, {
                    187.90200000000002`, 409.626}, {167.695, 
                    389.42299999999994`}, {142.77299999999997`, 
                    389.42299999999994`}, {117.848, 389.42299999999994`}, {
                    97.645, 409.626}, {97.645, 434.552}, {97.645, 459.474}, {
                    117.848, 479.677}, {142.77299999999997`, 479.677}, {
                    167.695, 479.677}, {187.90200000000002`, 459.474}, {
                    187.90200000000002`, 434.552}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    160.04299999999998`, 476.243}, {155., 
                    496.02099999999996`}, {142.77299999999997`, 479.677}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{174.684, 
                    466.462}, {177.594, 486.661}, {160.04299999999998`, 
                    476.243}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{184.465, 
                    451.822}, {194.883, 469.368}, {174.684, 466.462}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    187.90200000000002`, 434.552}, {204.242, 446.779}, {
                    184.465, 451.822}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{184.465, 
                    417.282}, {204.242, 422.325}, {187.90200000000002`, 
                    434.552}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{174.684, 
                    402.64200000000005`}, {194.883, 399.73199999999997`}, {
                    184.465, 417.282}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{125.504, 
                    476.243}, {130.547, 496.02099999999996`}, {
                    142.77299999999997`, 479.677}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{110.863, 
                    466.462}, {107.953, 486.661}, {125.504, 476.243}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{101.082, 
                    451.822}, {90.664, 469.368}, {110.863, 466.462}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{97.645, 
                    434.552}, {81.30499999999999, 446.779}, {101.082, 
                    451.822}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{101.082, 
                    417.282}, {81.30499999999999, 422.325}, {97.645, 
                    434.552}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{110.863, 
                    402.64200000000005`}, {90.664, 399.73199999999997`}, {
                    101.082, 417.282}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{208.85500000000002`, 193.19299999999998`}, {
                    208.85500000000002`, 156.697}, {179.26999999999998`, 
                    127.111}, {142.77299999999997`, 127.111}, {106.277, 
                    127.111}, {76.691, 156.697}, {76.691, 
                    193.19299999999998`}, {76.691, 229.689}, {106.277, 
                    259.279}, {142.77299999999997`, 259.279}, {
                    179.26999999999998`, 259.279}, {208.85500000000002`, 
                    229.689}, {208.85500000000002`, 193.19299999999998`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{159.875, 
                    129.36100000000002`}, {142.77299999999997`, 
                    88.99700000000001}, {125.66799999999999`, 
                    129.36100000000002`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    125.66799999999999`, 257.025}, {142.77299999999997`, 
                    297.392}, {159.875, 257.025}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    78.94100000000002, 176.091}, {38.574, 
                    193.19299999999998`}, {78.94100000000002, 210.298}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{206.605, 
                    210.298}, {246.969, 193.19299999999998`}, {206.605, 
                    176.091}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    125.66799999999999`, 129.36100000000002`}, {
                    90.67599999999999, 102.95400000000001`}, {96.043, 
                    146.466}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{159.875, 
                    257.025}, {194.871, 283.4309999999999}, {189.5, 
                    239.923}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    78.94100000000002, 210.298}, {52.535000000000004`, 
                    245.29}, {96.043, 239.923}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{206.605, 
                    176.091}, {233.012, 141.095}, {189.5, 146.466}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{96.043, 
                    146.466}, {52.535000000000004`, 141.095}, {
                    78.94100000000002, 176.091}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{189.5, 
                    239.923}, {233.012, 245.29}, {206.605, 210.298}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{96.043, 
                    239.923}, {90.67599999999999, 283.4309999999999}, {
                    125.66799999999999`, 257.025}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{189.5, 
                    146.466}, {194.871, 102.95400000000001`}, {159.875, 
                    129.36100000000002`}}}]}}}}}}}}}, AspectRatio -> 
                  Automatic, ImageSize -> {{128}, {85}}, 
                  PlotRange -> {{0., 581.}, {0., 709.}}], ",", 
                 GraphicsBox[{{{{{{{{
                    Thickness[0.001388888888888889], {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {0., 480.}, {720., 480.}, {720., 
                    0.}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0.003921569999999999, 0.254902, 0.109804], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    180., 480.}, {720., 480.}, {720., 0.}, {180., 
                    0.}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{594., 240.}, {594., 160.47299999999998`}, {
                    529.5269999999999, 96.}, {450., 96.}, {
                    370.47299999999996`, 96.}, {306., 160.47299999999998`}, {
                    306., 240.}, {306., 319.527}, {370.47299999999996`, 
                    384.}, {450., 384.}, {529.5269999999999, 384.}, {594., 
                    319.527}, {594., 240.}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0.003921569999999999, 0.254902, 0.109804], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{585.4649999999999, 360.414}, {633.898, 
                    305.92599999999993`}, {628.992, 222.49200000000002`}, {
                    574.504, 174.059}, {520.016, 125.62899999999999`}, {
                    436.582, 130.535}, {388.148, 185.023}, {339.719, 
                    239.512}, {344.625, 322.941}, {399.113, 371.375}, {
                    453.59799999999996`, 419.809}, {537.031, 414.902}, {
                    585.4649999999999, 360.414}}}]}}}}}}}}}}}}}}, {{{{{{{
                    RGBColor[1., 1., 1.], 
                    
                    PolygonBox[{{473.984, 299.066}, {508.04896572377527`, 
                    291.59710042426104`}, {511.47299999999996`, 256.895}, {
                    529.1002640300983, 286.9815069648755}, {563.168, 
                    279.512}, {539.9966282021564, 305.5796022787413}, {
                    539.9966282021563, 305.5796022787413}, {557.625, 
                    335.668}, {525.6781375521971, 321.6877862374376}, {
                    502.508, 347.754}, {505.9325235671064, 
                    313.0469406822399}}]}}}}}}}}, AspectRatio -> Automatic, 
                  ImageSize -> {{128}, {85}}, 
                  PlotRange -> {{0., 720.}, {0., 480.}}], ",", 
                 GraphicsBox[{{{{{{{
                    Thickness[0.001388888888888889], {{{{{{{
                    FaceForm[{
                    RGBColor[0., 0.21960800000000003`, 0.6588240000000001], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {0., 360.}, {720., 360.}, {720., 
                    0.}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.8078430000000001, 0.06666670000000002, 0.14902], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     180.}, {720., 180.}, {720., 0.}, {0., 
                    0.}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{311.77, 
                    180.}, {0., 0.}, {0., 360.}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.988235, 0.8196080000000001, 0.08627450000000002], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{148., 180.}, {148., 160.117}, {131.883, 144.}, {
                    112., 144.}, {92.117, 144.}, {76., 160.117}, {76., 
                    180.}, {76., 199.883}, {92.117, 216.}, {112., 216.}, {
                    131.883, 216.}, {148., 199.883}, {148., 180.}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    36., 180.}, {40.676, 175.324}, {112., 180.}, {40.676, 
                    184.676}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{44., 
                    171.047}, {47.815999999999995`, 167.23399999999998`}, {
                    112., 180.}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{44., 
                    188.953}, {47.815999999999995`, 192.766}, {112., 180.}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    58.26200000000001, 233.738}, {58.26200000000001, 
                    227.129}, {112., 180.}, {64.871, 233.738}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{57.586, 
                    221.754}, {57.586, 216.359}, {112., 180.}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    70.24600000000001, 234.414}, {75.641, 234.414}, {112., 
                    180.}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    112., 256.}, {107.324, 251.324}, {112., 180.}, {
                    116.67599999999999`, 251.324}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    103.04700000000001`, 248.}, {99.23400000000001, 
                    244.184}, {112., 180.}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{120.953, 
                    248.}, {124.766, 244.184}, {112., 180.}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    165.738, 233.738}, {159.129, 233.738}, {112., 180.}, {
                    165.738, 227.129}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{153.754, 
                    234.414}, {148.359, 234.414}, {112., 180.}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{166.414, 
                    221.754}, {166.414, 216.359}, {112., 180.}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    188., 180.}, {183.324, 184.676}, {112., 180.}, {183.324, 
                    175.324}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{180., 
                    188.953}, {176.184, 192.766}, {112., 180.}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{180., 
                    171.047}, {176.184, 167.23399999999998`}, {112., 180.}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    165.738, 126.262}, {165.738, 132.871}, {112., 180.}, {
                    159.129, 126.262}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{166.414, 
                    138.24599999999998`}, {166.414, 143.641}, {112., 180.}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{153.754, 
                    125.586}, {148.359, 125.586}, {112., 180.}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    112., 104.}, {116.67599999999999`, 108.67599999999999`}, {
                    112., 180.}, {107.324, 108.67599999999999`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{120.953, 
                    112.}, {124.766, 115.816}, {112., 180.}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    103.04700000000001`, 112.}, {99.23400000000001, 
                    115.816}, {112., 180.}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    58.26200000000001, 126.262}, {64.871, 126.262}, {112., 
                    180.}, {58.26200000000001, 132.871}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    70.24600000000001, 125.586}, {75.641, 125.586}, {112., 
                    180.}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{57.586, 
                    138.24599999999998`}, {57.586, 143.641}, {112., 180.}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}}}, {{{275.77, 180.}, {262.242, 175.297}, {
                    261.949, 160.98000000000002`}, {253.297, 
                    172.39100000000002`}, {239.59, 168.24599999999998`}, {
                    247.76999999999998`, 180.}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}}}, {{{275.77, 180.}, {262.242, 
                    184.70299999999997`}, {261.949, 199.02}, {253.297, 
                    187.60899999999998`}, {239.59, 191.754}, {
                    247.76999999999998`, 180.}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}}}, {{{18., 31.176000000000002`}, {
                    20.691000000000003`, 45.242000000000004`}, {
                    8.437999999999999, 52.656}, {22.648, 
                    54.440999999999995`}, {25.91, 68.387}, {32., 55.426}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}}}, {{{18., 31.176000000000002`}, {
                    28.836000000000002`, 40.543}, {41.382999999999996`, 
                    33.633}, {35.824, 46.836}, {46.27, 56.633}, {32., 
                    55.426}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}}}, {{{18., 328.824}, {28.836000000000002`, 
                    319.457}, {41.382999999999996`, 326.367}, {35.824, 
                    313.16400000000004`}, {46.27, 303.367}, {32., 304.574}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}}}, {{{18., 328.824}, {20.691000000000003`, 
                    314.758}, {8.437999999999999, 307.34400000000005`}, {
                    22.648, 305.559}, {25.91, 291.613}, {32., 
                    304.574}}}]}}}}}}}}}}}}}}, AspectRatio -> Automatic, 
                  ImageSize -> {{128}, {85}}, 
                  PlotRange -> {{0., 720.}, {0., 360.}}], ",", 
                 GraphicsBox[{{{{{{{
                    Thickness[0.001639344262295082], {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.5529410000000001, 0.105882, 0.23921600000000004`], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     240.}, {609.602, 240.}, {609.602, 0.}, {0., 
                    0.}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJRIGZiQAd5DhhCYJABF7/1sy5rj0Sew81z34MfL9Vy
gMlPkWAJ41tr5QCTh4i7wOW3ff57pWKlF1xeha1xqvPqAAdU80Pg8rdBdEg4
XB6iPgrN/Di4/Lsae9O4VQlweaHmA6cWhiahmZ8Cl4eoT4XLQ9Sno5mfiWZ+
Fpr5OWjm5zkAADWeXto=
                    "]]}}}}}}}}}}}}}}, AspectRatio -> 
                  Automatic, ImageSize -> {{128}, {85}}, 
                  PlotRange -> {{0., 610.}, {0., 240.}}], ",", 
                 GraphicsBox[{{{{{{{
                    Thickness[0.00028935185185185184`], {{{{{{{
                    FaceForm[{
                    RGBColor[0.9294119999999999, 0.160784, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     2304.}, {3456., 2304.}, {3456., 1152.}, {0., 
                    1152.}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     1152.}, {3456., 1152.}, {3456., 0.}, {0., 0.}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJDIGYCYm/zTseE1kkODGAw2wHGf6lmyKEjO8tBla1x
qnPEJAc+3U1z861mOrSL3TxXzjjJgWONTNSTjBlgdWtWTXQACn8Pnj7d4fbP
uiwbrYkOP4IfL5W+Ps3hsm+SwI3OCQ5yra8Dd5hNc5jq3J3z/FI/WDxi2lSH
bZ//XqkI6nM4qrCh6IXoVIj963sg+vdPcciY+LbGnqfbYe775ce8M6Y4CERY
bjnh1ukA1G1pYj3F4fHS2UcUGtvhfP27KmyNu1vh/EqQA781w/WD7Q9qgpsP
tO3phfUNcPun5wk1H4irg7uvfN98Kf271XD3A2VPLYyuhPtPNirF+n5kOdz/
IOds+FcKDx+wexaXwMNvsgRLGN/7Ynj4wviw8IfxxYHmXX40G67/4yXfpAlH
58DNB9s/fS7cfnA8ZMyDuw9sv8Z8uPsfVomscz85H+4/sPkmC+D+nwcMH+7S
BfDwAbpCt2jBAnj4AU2XuXV6ATx8z38Pfpz6aAE8/GF8WPzA+LD4g+mHxS/M
fFj8o9gPTB8w98HSD8z9sPQF8x8s/cH8D0ufsPCBpV9Y+MHSNyx80dM/AJyY
ZBE=
                    "]]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0.9294119999999999, 0.160784, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJDIGYCYh/zTscHS6c4MIDBbAcYv9CW6/pizVkOGRPf
1thXT3HwBoonBM90kG99HWihOcXhsm+SQETvDIdls48oGFyf7DD3/fJj3sen
O0SlWN8/HzsZol9wOkT/sUkO69wfVolUTXN4qWbIsUZvEti+hkdTHfaUTJZg
qZzosOVE2T75zKkOLt05z39vmuBgfd+/V1x8qsM0Z6DAzX6HT5eAFh6F2qvb
53Bqoeu24llTHLYC9c1v6IHz+XQ3zX1/uQvOB7tbvROuH+Q+/9ntcPPB7uNv
g9sP1r+4Be4+wQjLLSdKmuHuB0kvd22C+28qyH1BjXD/Ly4ASqxrgIePAEg/
VwM8/IC+DePLroeHL4wPC38Yv//QV42Ya7Ph+kHum79mDtx8HZA7iubC7U8C
KbSYB3cfWP+7eXD3B+2Qa33dOh/uP1AaOMC3AO5/UDwWeC+Ahw/IvJKSBfDw
axe7ea587gJ4+Err31U5tmkBPPxhfFj8wPiw+IPph8UvzHxY/MPsh6UPFPcB
0w/M/bD0BfMfLP3B/A9Ln7DwgaVfWPjB0jcsfNHTPwCAp1ta
                    
                    "]]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{805.758, 1717.547}, {746.906, 
                    1762.6909999999998`}, {688.0740000000001, 1717.527}, {
                    710.727, 1790.3239999999998`}, {651.6880000000001, 
                    1835.195}, {724.535, 1835.043}, {746.883, 1907.941}, {
                    769.254, 1835.051}, {842.102, 1835.23}, {783.082, 
                    1790.336}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{1267.508, 1717.547}, {1208.6599999999999`, 
                    1762.6909999999998`}, {1149.8239999999998`, 1717.527}, {
                    1172.477, 1790.3239999999998`}, {1113.441, 1835.195}, {
                    1186.289, 1835.043}, {1208.6329999999998`, 1907.941}, {
                    1231.008, 1835.051}, {1303.8519999999999`, 1835.23}, {
                    1244.8319999999999`, 1790.336}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{1036.867, 1888.9180000000001`}, {978.02, 
                    1934.062}, {919.1840000000001, 1888.895}, {
                    941.8359999999999, 1961.6909999999998`}, {
                    882.8009999999999, 2006.566}, {955.648, 2006.41}, {
                    977.996, 2079.309}, {1000.3669999999998`, 
                    2006.4180000000001`}, {1073.2150000000001`, 2006.598}, {
                    1014.191, 1961.703}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{892.156, 1443.348}, {833.309, 1488.492}, {
                    774.4730000000001, 1443.328}, {797.125, 1516.125}, {
                    738.09, 1560.996}, {810.938, 1560.8439999999998`}, {
                    833.2850000000001, 1633.742}, {855.656, 
                    1560.8519999999999`}, {928.504, 1561.031}, {869.48, 
                    1516.137}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{1181.105, 1443.348}, {1122.258, 1488.492}, {
                    1063.4260000000002`, 1443.328}, {1086.0739999999998`, 
                    1516.125}, {1027.039, 1560.996}, {1099.887, 
                    1560.8439999999998`}, {1122.234, 1633.742}, {1144.605, 
                    1560.8519999999999`}, {1217.453, 1561.031}, {1158.434, 
                    1516.137}}}]}}}}}}}}}}}}}}, AspectRatio -> Automatic, 
                  ImageSize -> {{128}, {85}}, 
                  PlotRange -> {{0., 3456.}, {0., 2304.}}], ",", 
                 GraphicsBox[{{{{{{{
                    Thickness[0.001388888888888889], {{{{{{{
                    FaceForm[{
                    RGBColor[0.9294119999999999, 0.109804, 0.141176], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {0., 480.}, {720., 480.}, {720., 
                    0.}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     400.}, {720., 400.}, {720., 80.}, {0., 
                    80.}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0.141176, 0.11372500000000002`, 0.309804], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     320.}, {720., 320.}, {720., 160.}, {0., 
                    160.}}}]}}}}}}}}}}}}}}, AspectRatio -> Automatic, 
                  ImageSize -> {{128}, {85}}, 
                  PlotRange -> {{0., 720.}, {0., 480.}}], ",", 
                 GraphicsBox[{{{{{{{
                    Thickness[0.001388888888888889], {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {0., 480.}, {720., 480.}, {720., 
                    0.}}}]}}}}}}}, {{{{{{{
                    Thickness[0.001388888888888889], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    110.387, 334.301}, {176.94899999999998`, 
                    434.14500000000004`}, {243.512, 389.77}, {
                    176.94899999999998`, 
                    289.92199999999997`}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    121.48, 314.883}, {199.137, 431.371}, {
                    207.45700000000002`, 425.824}, {129.80100000000002`, 
                    309.33599999999996`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    146.441, 298.242}, {224.098, 414.72999999999996`}, {
                    232.418, 409.184}, {154.762, 292.695}}}]}}}}}}}, {{{{{{{
                    Thickness[0.001388888888888889], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    476.48799999999994`, 90.23}, {543.0509999999999, 
                    190.078}, {609.613, 145.69899999999998`}, {
                    543.0509999999999, 45.855}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    487.582, 70.816}, {565.238, 187.305}, {573.559, 
                    181.758}, {495.902, 65.27}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    512.543, 54.176}, {590.1990000000001, 170.664}, {598.52, 
                    165.117}, {520.8629999999999, 48.629000000000005`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    498.676, 141.539}, {504.22299999999996`, 149.859}, {
                    587.4259999999999, 94.391}, {581.879, 
                    86.07}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0.776471, 0.047058800000000005`, 0.188235], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{426.562, 339.848}, {481.707, 303.082}, {
                    496.60900000000004`, 228.578}, {459.848, 
                    173.43800000000002`}, {423.082, 118.293}, {348.578, 
                    103.391}, {293.43799999999993`, 140.15200000000002`}, {
                    238.29299999999998`, 176.918}, {223.39100000000002`, 
                    251.42200000000003`}, {260.15200000000004`, 306.562}, {
                    296.91799999999995`, 361.707}, {371.42199999999997`, 
                    376.60900000000004`}, {426.562, 339.848}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0., 0.20392200000000002`, 0.47058800000000006`], 
                    
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4gf+vdPznAocFrlu+/xXo9hBla1xqnN4nkOH
Y8LTC22FEPGQfIfW14E75CTzHKbnCTUf8Cl0KM6Y+LbmdbZDzvPfKz++K3K4
ee578OO9mQ7l++ZL6WeWQuR3ZzkwgEBDGYRmgJo7rdzhuLd5p+OiAofJEixh
fIJVEFqx0AGkzX5zNUSeq8DB4K4KW2NorUOVyDr3h89yHYCypnFXaiH0pwwH
xQ1FGRP31jjsLQGasC7VYensIwobllU76IP0ZSY52HFdX1zwtNLBasuJsn38
CQ6HvmrE9P8oh9gzNc4B6JtTC7nLIP7iioW4/2exgxcPk3b7ujiH2F2ePEzh
RQ77gcJ3WxIh6rYUOGwFGjd/UzLUXGj4mKZDxL3yHKpB7uXLdvABeiOhNdfh
1s+6rD0v8jDCFz38ASyVsr0=
                    "]]}}}}}}}, {{{{{{{
                    Thickness[0.001388888888888889], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    176.94899999999998`, 45.855}, {110.387, 
                    145.69899999999998`}, {176.94899999999998`, 190.078}, {
                    243.512, 90.23}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    199.137, 48.629000000000005`}, {121.48, 165.117}, {
                    129.80100000000002`, 170.664}, {207.45700000000002`, 
                    54.176}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    224.098, 65.27}, {146.441, 181.758}, {154.762, 187.305}, {
                    232.418, 70.816}}}]}}}}}}}, {{{{{{{
                    Thickness[0.001388888888888889], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    543.0509999999999, 289.92199999999997`}, {
                    476.48799999999994`, 389.77}, {543.0509999999999, 
                    434.14500000000004`}, {609.613, 334.301}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    565.238, 292.695}, {487.582, 409.184}, {495.902, 
                    414.72999999999996`}, {573.559, 298.242}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    590.1990000000001, 309.33599999999996`}, {512.543, 
                    425.824}, {520.8629999999999, 431.371}, {598.52, 
                    314.883}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    504.22299999999996`, 330.141}, {498.676, 
                    338.46099999999996`}, {581.879, 393.92999999999995`}, {
                    587.4259999999999, 385.60900000000004`}}}]}}}}}}}, {{{{{{{
                    
                    Thickness[0.001388888888888889], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    540.277, 348.168}, {529.1840000000001, 364.809}, {545.824,
                     375.902}, {556.918, 359.262}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    163.08200000000002`, 102.71100000000001`}, {157.535, 
                    111.031}, {190.816, 133.21899999999997`}, {196.363, 
                    124.898}}}]}}}}}}}}}}}}}}, AspectRatio -> Automatic, 
                  ImageSize -> {{128}, {85}}, 
                  PlotRange -> {{0., 720.}, {0., 480.}}]}], "}"}], ",", 
             RowBox[{"{", 
               RowBox[{
                 GraphicsBox[{{{{{{{
                    Thickness[0.000925925925925926], {{{{{{{
                    FaceForm[{
                    RGBColor[1., 0.6, 0.2], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {0., 720.}, {1080., 720.}, {1080., 
                    0.}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     480.}, {1080., 480.}, {1080., 240.}, {0., 
                    240.}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0.0705882, 0.533333, 0.027451000000000003`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     240.}, {1080., 240.}, {1080., 0.}, {0., 
                    0.}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0., 0., 0.533333], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{636., 360.}, {636., 306.97999999999996`}, {
                    593.02, 264.}, {540., 264.}, {486.97999999999996`, 
                    264.}, {444., 306.97999999999996`}, {444., 360.}, {444., 
                    413.02}, {486.97999999999996`, 456.}, {540., 456.}, {
                    593.02, 456.}, {636., 413.02}, {636., 
                    360.}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{624., 360.}, {624., 313.60900000000004`}, {
                    586.391, 276.}, {540., 276.}, {493.60900000000004`, 
                    276.}, {456., 313.60900000000004`}, {456., 360.}, {456., 
                    406.39099999999996`}, {493.60900000000004`, 444.}, {540., 
                    444.}, {586.391, 444.}, {624., 406.39099999999996`}, {
                    624., 360.}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0., 0., 0.533333], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{556.8009999999999, 360.}, {556.8009999999999, 
                    350.72299999999996`}, {549.277, 343.199}, {540., 
                    343.199}, {530.7230000000001, 343.199}, {
                    523.1990000000001, 350.72299999999996`}, {
                    523.1990000000001, 360.}, {523.1990000000001, 369.277}, {
                    530.7230000000001, 376.801}, {540., 376.801}, {549.277, 
                    376.801}, {556.8009999999999, 369.277}, {
                    556.8009999999999, 360.}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{627.4449999999999, 348.48799999999994`}, {
                    627.145, 346.188}, {625.031, 344.57}, {622.734, 
                    344.871}, {620.434, 345.176}, {618.8159999999999, 
                    347.28499999999997`}, {619.117, 349.58599999999996`}, {
                    619.4219999999999, 351.883}, {621.531, 353.504}, {623.828,
                     353.199}, {626.129, 352.89799999999997`}, {627.75, 
                    350.789}, {627.4449999999999, 348.48799999999994`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    540., 276.}, {542.879, 326.39799999999997`}, {540., 
                    350.39799999999997`}, {537.121, 326.39799999999997`}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{621.484, 326.246}, {620.5980000000001, 
                    324.105}, {618.141, 323.08599999999996`}, {616., 
                    323.97299999999996`}, {613.8549999999999, 324.863}, {
                    612.8399999999999, 327.32}, {613.727, 
                    329.46099999999996`}, {614.613, 331.605}, {617.07, 
                    332.621}, {619.215, 331.734}, {621.3549999999999, 
                    330.848}, {622.375, 328.39099999999996`}, {621.484, 
                    326.246}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    518.258, 278.863}, {534.086, 326.801}, {537.516, 
                    350.727}, {528.523, 328.289}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{609.9730000000001, 306.309}, {608.5619999999999, 
                    304.469}, {605.9259999999999, 304.121}, {604.086, 
                    305.53099999999995`}, {602.246, 306.945}, {601.898, 
                    309.582}, {603.309, 311.42199999999997`}, {
                    604.7230000000001, 313.262}, {607.3589999999999, 
                    313.60900000000004`}, {609.1990000000001, 312.195}, {
                    611.039, 310.78499999999997`}, {611.387, 308.148}, {
                    609.9730000000001, 306.309}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    498., 287.254}, {525.695, 329.46099999999996`}, {
                    535.1990000000001, 351.688}, {520.707, 
                    332.34000000000003`}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{593.691, 290.027}, {591.8519999999999, 
                    288.613}, {589.215, 288.96099999999996`}, {587.805, 
                    290.801}, {586.391, 292.641}, {586.738, 295.277}, {
                    588.5780000000001, 296.691}, {590.418, 
                    298.10200000000003`}, {593.055, 297.754}, {
                    594.4689999999999, 295.914}, {595.879, 294.074}, {595.531,
                     291.43799999999993`}, {593.691, 290.027}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    480.60200000000003`, 300.60200000000003`}, {518.277, 
                    334.203}, {533.211, 353.21099999999996`}, {
                    514.2030000000001, 338.277}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{573.754, 278.51599999999996`}, {571.609, 
                    277.625}, {569.1519999999999, 278.64500000000004`}, {
                    568.266, 280.78499999999997`}, {567.379, 
                    282.92999999999995`}, {568.395, 285.387}, {570.539, 
                    286.27299999999997`}, {572.6800000000001, 287.16}, {
                    575.137, 286.14500000000004`}, {576.0269999999999, 
                    284.}, {576.914, 281.85900000000004`}, {575.895, 
                    279.402}, {573.754, 278.51599999999996`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    467.254, 318.}, {512.3399999999999, 340.707}, {
                    531.6880000000001, 355.199}, {509.46099999999996`, 
                    345.695}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{551.512, 272.555}, {549.211, 272.25}, {547.102, 
                    273.871}, {546.8009999999999, 276.172}, {546.496, 
                    278.469}, {548.117, 280.578}, {550.414, 280.883}, {
                    552.715, 281.184}, {554.824, 279.566}, {555.129, 
                    277.26599999999996`}, {555.43, 274.969}, {
                    553.8119999999999, 272.855}, {551.512, 272.555}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    458.863, 338.258}, {508.289, 348.52299999999997`}, {
                    530.727, 357.51599999999996`}, {506.801, 
                    354.08599999999996`}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{528.488, 272.555}, {526.1880000000001, 
                    272.855}, {524.57, 274.969}, {524.871, 
                    277.26599999999996`}, {525.176, 279.566}, {
                    527.2850000000001, 281.184}, {529.586, 280.883}, {531.883,
                     280.578}, {533.504, 278.469}, {533.1990000000001, 
                    276.172}, {532.898, 273.871}, {530.7890000000001, 
                    272.25}, {528.488, 272.555}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    456., 360.}, {506.39799999999997`, 357.121}, {530.398, 
                    360.}, {506.39799999999997`, 362.879}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{506.246, 278.51599999999996`}, {504.105, 
                    279.402}, {503.08599999999996`, 281.85900000000004`}, {
                    503.97299999999996`, 284.}, {504.863, 
                    286.14500000000004`}, {507.32, 287.16}, {
                    509.46099999999996`, 286.27299999999997`}, {511.605, 
                    285.387}, {512.621, 282.92999999999995`}, {511.734, 
                    280.78499999999997`}, {510.848, 278.64500000000004`}, {
                    508.39099999999996`, 277.625}, {506.246, 
                    278.51599999999996`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    458.863, 381.742}, {506.801, 365.914}, {530.727, 
                    362.484}, {508.289, 371.477}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{486.309, 290.027}, {484.469, 
                    291.43799999999993`}, {484.121, 294.074}, {
                    485.53099999999995`, 295.914}, {486.945, 297.754}, {
                    489.582, 298.10200000000003`}, {491.42199999999997`, 
                    296.691}, {493.262, 295.277}, {493.60900000000004`, 
                    292.641}, {492.195, 290.801}, {490.78499999999997`, 
                    288.96099999999996`}, {488.148, 288.613}, {486.309, 
                    290.027}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    467.254, 402.}, {509.46099999999996`, 374.305}, {
                    531.6880000000001, 364.801}, {512.3399999999999, 
                    379.29299999999995`}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{470.027, 306.309}, {468.613, 308.148}, {
                    468.96099999999996`, 310.78499999999997`}, {470.801, 
                    312.195}, {472.641, 313.60900000000004`}, {475.277, 
                    313.262}, {476.691, 311.42199999999997`}, {
                    478.10200000000003`, 309.582}, {477.754, 306.945}, {
                    475.914, 305.53099999999995`}, {474.074, 304.121}, {
                    471.43799999999993`, 304.469}, {470.027, 306.309}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    480.60200000000003`, 419.39799999999997`}, {
                    514.2030000000001, 381.72299999999996`}, {533.211, 
                    366.789}, {518.277, 385.79699999999997`}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{458.51599999999996`, 326.246}, {457.625, 
                    328.39099999999996`}, {458.64500000000004`, 330.848}, {
                    460.78499999999997`, 331.734}, {462.92999999999995`, 
                    332.621}, {465.387, 331.605}, {466.27299999999997`, 
                    329.46099999999996`}, {467.16, 327.32}, {
                    466.14500000000004`, 324.863}, {464., 
                    323.97299999999996`}, {461.85900000000004`, 
                    323.08599999999996`}, {459.402, 324.105}, {
                    458.51599999999996`, 326.246}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    498., 432.746}, {520.707, 387.66}, {535.1990000000001, 
                    368.312}, {525.695, 390.539}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{452.555, 348.48799999999994`}, {452.25, 
                    350.789}, {453.871, 352.89799999999997`}, {456.172, 
                    353.199}, {458.469, 353.504}, {460.578, 351.883}, {
                    460.883, 349.58599999999996`}, {461.184, 
                    347.28499999999997`}, {459.566, 345.176}, {
                    457.26599999999996`, 344.871}, {454.969, 344.57}, {
                    452.855, 346.188}, {452.555, 348.48799999999994`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    518.258, 441.137}, {528.523, 391.71099999999996`}, {
                    537.516, 369.27299999999997`}, {534.086, 393.199}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{452.555, 371.512}, {452.855, 373.812}, {454.969, 
                    375.42999999999995`}, {457.26599999999996`, 375.129}, {
                    459.566, 374.824}, {461.184, 372.715}, {460.883, 
                    370.414}, {460.578, 368.117}, {458.469, 
                    366.4959999999999}, {456.172, 366.801}, {453.871, 
                    367.10200000000003`}, {452.25, 369.21099999999996`}, {
                    452.555, 371.512}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    540., 444.}, {537.121, 393.60200000000003`}, {540., 
                    369.60200000000003`}, {542.879, 393.60200000000003`}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{458.51599999999996`, 393.754}, {459.402, 
                    395.895}, {461.85900000000004`, 396.914}, {464., 
                    396.027}, {466.14500000000004`, 395.137}, {467.16, 
                    392.68}, {466.27299999999997`, 390.539}, {465.387, 
                    388.395}, {462.92999999999995`, 387.379}, {
                    460.78499999999997`, 388.26599999999996`}, {
                    458.64500000000004`, 389.15200000000004`}, {457.625, 
                    391.60900000000004`}, {458.51599999999996`, 393.754}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    561.742, 441.137}, {545.914, 393.199}, {542.484, 
                    369.27299999999997`}, {551.477, 391.71099999999996`}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{470.027, 413.691}, {471.43799999999993`, 
                    415.53099999999995`}, {474.074, 415.879}, {475.914, 
                    414.469}, {477.754, 413.055}, {478.10200000000003`, 
                    410.41799999999995`}, {476.691, 408.578}, {475.277, 
                    406.73799999999994`}, {472.641, 406.39099999999996`}, {
                    470.801, 407.805}, {468.96099999999996`, 409.215}, {
                    468.613, 411.85200000000003`}, {470.027, 413.691}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    582., 432.746}, {554.305, 390.539}, {544.8009999999999, 
                    368.312}, {559.2930000000001, 387.66}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{486.309, 429.97299999999996`}, {488.148, 
                    431.387}, {490.78499999999997`, 431.039}, {492.195, 
                    429.199}, {493.60900000000004`, 427.35900000000004`}, {
                    493.262, 424.72299999999996`}, {491.42199999999997`, 
                    423.309}, {489.582, 421.89799999999997`}, {486.945, 
                    422.246}, {485.53099999999995`, 424.08599999999996`}, {
                    484.121, 425.92599999999993`}, {484.469, 428.562}, {
                    486.309, 429.97299999999996`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    599.398, 419.39799999999997`}, {561.7230000000001, 
                    385.79699999999997`}, {546.7890000000001, 366.789}, {
                    565.797, 381.72299999999996`}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{506.246, 441.484}, {508.39099999999996`, 
                    442.375}, {510.848, 441.355}, {511.734, 439.215}, {
                    512.621, 437.07}, {511.605, 434.613}, {
                    509.46099999999996`, 433.727}, {507.32, 
                    432.84000000000003`}, {504.863, 433.855}, {
                    503.97299999999996`, 436.}, {503.08599999999996`, 
                    438.141}, {504.105, 440.59799999999996`}, {506.246, 
                    441.484}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    612.746, 402.}, {567.66, 379.29299999999995`}, {
                    548.3119999999999, 364.801}, {570.539, 374.305}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{528.488, 447.445}, {530.7890000000001, 447.75}, {
                    532.898, 446.129}, {533.1990000000001, 443.828}, {533.504,
                     441.53099999999995`}, {531.883, 439.42199999999997`}, {
                    529.586, 439.117}, {527.2850000000001, 438.816}, {525.176,
                     440.43399999999997`}, {524.871, 442.734}, {524.57, 
                    445.03099999999995`}, {526.1880000000001, 
                    447.14500000000004`}, {528.488, 447.445}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    621.137, 381.742}, {571.711, 371.477}, {549.2730000000001,
                     362.484}, {573.1990000000001, 365.914}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{551.512, 447.445}, {553.8119999999999, 
                    447.14500000000004`}, {555.43, 445.03099999999995`}, {
                    555.129, 442.734}, {554.824, 440.43399999999997`}, {
                    552.715, 438.816}, {550.414, 439.117}, {548.117, 
                    439.42199999999997`}, {546.496, 441.53099999999995`}, {
                    546.8009999999999, 443.828}, {547.102, 446.129}, {549.211,
                     447.75}, {551.512, 447.445}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    624., 360.}, {573.602, 362.879}, {549.602, 360.}, {
                    573.602, 357.121}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{573.754, 441.484}, {575.895, 
                    440.59799999999996`}, {576.914, 438.141}, {
                    576.0269999999999, 436.}, {575.137, 433.855}, {
                    572.6800000000001, 432.84000000000003`}, {570.539, 
                    433.727}, {568.395, 434.613}, {567.379, 437.07}, {568.266,
                     439.215}, {569.1519999999999, 441.355}, {571.609, 
                    442.375}, {573.754, 441.484}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    621.137, 338.258}, {573.1990000000001, 
                    354.08599999999996`}, {549.2730000000001, 
                    357.51599999999996`}, {571.711, 348.52299999999997`}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{593.691, 429.97299999999996`}, {595.531, 
                    428.562}, {595.879, 425.92599999999993`}, {
                    594.4689999999999, 424.08599999999996`}, {593.055, 
                    422.246}, {590.418, 421.89799999999997`}, {
                    588.5780000000001, 423.309}, {586.738, 
                    424.72299999999996`}, {586.391, 427.35900000000004`}, {
                    587.805, 429.199}, {589.215, 431.039}, {591.8519999999999,
                     431.387}, {593.691, 429.97299999999996`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    612.746, 318.}, {570.539, 345.695}, {548.3119999999999, 
                    355.199}, {567.66, 340.707}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{609.9730000000001, 413.691}, {611.387, 
                    411.85200000000003`}, {611.039, 409.215}, {
                    609.1990000000001, 407.805}, {607.3589999999999, 
                    406.39099999999996`}, {604.7230000000001, 
                    406.73799999999994`}, {603.309, 408.578}, {601.898, 
                    410.41799999999995`}, {602.246, 413.055}, {604.086, 
                    414.469}, {605.9259999999999, 415.879}, {
                    608.5619999999999, 415.53099999999995`}, {
                    609.9730000000001, 413.691}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    599.398, 300.60200000000003`}, {565.797, 338.277}, {
                    546.7890000000001, 353.21099999999996`}, {
                    561.7230000000001, 334.203}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{621.484, 393.754}, {622.375, 
                    391.60900000000004`}, {621.3549999999999, 
                    389.15200000000004`}, {619.215, 388.26599999999996`}, {
                    617.07, 387.379}, {614.613, 388.395}, {613.727, 
                    390.539}, {612.8399999999999, 392.68}, {613.8549999999999,
                     395.137}, {616., 396.027}, {618.141, 396.914}, {
                    620.5980000000001, 395.895}, {621.484, 393.754}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    582., 287.254}, {559.2930000000001, 
                    332.34000000000003`}, {544.8009999999999, 351.688}, {
                    554.305, 329.46099999999996`}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{627.4449999999999, 371.512}, {627.75, 
                    369.21099999999996`}, {626.129, 367.10200000000003`}, {
                    623.828, 366.801}, {621.531, 366.4959999999999}, {
                    619.4219999999999, 368.117}, {619.117, 370.414}, {
                    618.8159999999999, 372.715}, {620.434, 374.824}, {622.734,
                     375.129}, {625.031, 375.42999999999995`}, {627.145, 
                    373.812}, {627.4449999999999, 371.512}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    561.742, 278.863}, {551.477, 328.289}, {542.484, 
                    350.727}, {545.914, 326.801}}}]}}}}}}}}}}}}}}, 
                  AspectRatio -> Automatic, ImageSize -> {{128}, {85}}, 
                  PlotRange -> {{0., 1080.}, {0., 720.}}], ",", 
                 GraphicsBox[{{{{{{{
                    Thickness[0.0007936507936507937], {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.13725500000000002`, 0.623529, 0.25098000000000004`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {0., 720.}, {1260., 720.}, {1260., 
                    0.}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     480.}, {1260., 480.}, {1260., 240.}, {0., 
                    240.}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0.854902, 0., 0.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     240.}, {1260., 240.}, {1260., 0.}, {0., 
                    0.}}}]}}}}}}}, {{{{{{{
                    RGBColor[1., 1., 1.], 
                    Thickness[0.0044444444444444444`], 
                    Opacity[1.], 
                    CapForm["Round"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 
                    0}}, {{0, 2, 0}}, {{0, 2, 0}}}, {{{579.602, 516.398}, {
                    646.8009999999999, 516.398}}, {{579.602, 494.}, {579.602, 
                    505.19899999999996`}, {602., 505.19899999999996`}, {602., 
                    494.}, {624.398, 494.}, {624.398, 505.19899999999996`}, {
                    613.1990000000001, 505.19899999999996`}}, {{
                    646.8009999999999, 494.}, {635.602, 494.}, {635.602, 
                    505.19899999999996`}, {658., 505.19899999999996`}, {658., 
                    516.398}}, {{658., 505.19899999999996`}, {658., 494.}, {
                    680.398, 494.}, {680.398, 516.398}}, {{669.1990000000001, 
                    516.398}, {669.1990000000001, 494.}}, {{590.8009999999999,
                     494.}, {590.805, 494.}}}, 
                    CurveClosed -> {0, 0, 0, 0, 0, 0}]}}}}}}}, {{{{{{{
                    RGBColor[1., 1., 1.], 
                    Thickness[0.005312127152597305], 
                    Opacity[1.], 
                    CapForm["Round"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}}}, {{{
                    579.6013999999999, 481.602}, {624.3986, 481.602}}, {{
                    635.6013999999999, 481.602}, {680.3986, 481.602}}}, 
                    CurveClosed -> {0, 0}]}}}}}}}, {{{{{{{
                    RGBColor[1., 1., 1.], 
                    Thickness[0.0044444444444444444`], 
                    Opacity[1.], 
                    CapForm["Round"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 
                    0}}, {{0, 2, 0}}, {{0, 2, 0}}}, {{{579.602, 226.}, {
                    646.8009999999999, 226.}}, {{579.602, 
                    203.60199999999998`}, {579.602, 214.801}, {602., 
                    214.801}, {602., 203.60199999999998`}, {624.398, 
                    203.60199999999998`}, {624.398, 214.801}, {
                    613.1990000000001, 214.801}}, {{646.8009999999999, 
                    203.60199999999998`}, {635.602, 203.60199999999998`}, {
                    635.602, 214.801}, {658., 214.801}, {658., 226.}}, {{658.,
                     214.801}, {658., 203.60199999999998`}, {680.398, 
                    203.60199999999998`}, {680.398, 226.}}, {{
                    669.1990000000001, 226.}, {669.1990000000001, 
                    203.60199999999998`}}, {{590.8009999999999, 
                    203.60199999999998`}, {590.805, 203.60199999999998`}}}, 
                    CurveClosed -> {0, 0, 0, 0, 0, 0}]}}}}}}}, {{{{{{{
                    RGBColor[1., 1., 1.], 
                    Thickness[0.005312127152597305], 
                    Opacity[1.], 
                    CapForm["Round"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}}}, {{{
                    579.6013999999999, 238.39799999999997`}, {624.3986, 
                    238.39799999999997`}}, {{635.6013999999999, 
                    238.39799999999997`}, {680.3986, 238.39799999999997`}}}, 
                    CurveClosed -> {0, 0}]}}}}}}}, {{{{{{{
                    RGBColor[1., 1., 1.], 
                    Thickness[0.0044444444444444444`], 
                    Opacity[1.], 
                    CapForm["Round"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 
                    0}}, {{0, 2, 0}}, {{0, 2, 0}}}, {{{691.602, 516.398}, {
                    758.8009999999999, 516.398}}, {{691.602, 494.}, {691.602, 
                    505.19899999999996`}, {714., 505.19899999999996`}, {714., 
                    494.}, {736.398, 494.}, {736.398, 505.19899999999996`}, {
                    725.1990000000001, 505.19899999999996`}}, {{
                    758.8009999999999, 494.}, {747.602, 494.}, {747.602, 
                    505.19899999999996`}, {770., 505.19899999999996`}, {770., 
                    516.398}}, {{770., 505.19899999999996`}, {770., 494.}, {
                    792.398, 494.}, {792.398, 516.398}}, {{781.1990000000001, 
                    516.398}, {781.1990000000001, 494.}}, {{702.8009999999999,
                     494.}, {702.805, 494.}}}, 
                    CurveClosed -> {0, 0, 0, 0, 0, 0}]}}}}}}}, {{{{{{{
                    RGBColor[1., 1., 1.], 
                    Thickness[0.005312127152597305], 
                    Opacity[1.], 
                    CapForm["Round"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}}}, {{{
                    691.6013999999999, 481.602}, {736.3986, 481.602}}, {{
                    747.6013999999999, 481.602}, {792.3986, 481.602}}}, 
                    CurveClosed -> {0, 0}]}}}}}}}, {{{{{{{
                    RGBColor[1., 1., 1.], 
                    Thickness[0.0044444444444444444`], 
                    Opacity[1.], 
                    CapForm["Round"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 
                    0}}, {{0, 2, 0}}, {{0, 2, 0}}}, {{{691.602, 226.}, {
                    758.8009999999999, 226.}}, {{691.602, 
                    203.60199999999998`}, {691.602, 214.801}, {714., 
                    214.801}, {714., 203.60199999999998`}, {736.398, 
                    203.60199999999998`}, {736.398, 214.801}, {
                    725.1990000000001, 214.801}}, {{758.8009999999999, 
                    203.60199999999998`}, {747.602, 203.60199999999998`}, {
                    747.602, 214.801}, {770., 214.801}, {770., 226.}}, {{770.,
                     214.801}, {770., 203.60199999999998`}, {792.398, 
                    203.60199999999998`}, {792.398, 226.}}, {{
                    781.1990000000001, 226.}, {781.1990000000001, 
                    203.60199999999998`}}, {{702.8009999999999, 
                    203.60199999999998`}, {702.805, 203.60199999999998`}}}, 
                    CurveClosed -> {0, 0, 0, 0, 0, 0}]}}}}}}}, {{{{{{{
                    RGBColor[1., 1., 1.], 
                    Thickness[0.005312127152597305], 
                    Opacity[1.], 
                    CapForm["Round"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}}}, {{{
                    691.6013999999999, 238.39799999999997`}, {736.3986, 
                    238.39799999999997`}}, {{747.6013999999999, 
                    238.39799999999997`}, {792.3986, 238.39799999999997`}}}, 
                    CurveClosed -> {0, 0}]}}}}}}}, {{{{{{{
                    RGBColor[1., 1., 1.], 
                    Thickness[0.0044444444444444444`], 
                    Opacity[1.], 
                    CapForm["Round"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 
                    0}}, {{0, 2, 0}}, {{0, 2, 0}}}, {{{355.60200000000003`, 
                    516.398}, {422.801, 516.398}}, {{355.60200000000003`, 
                    494.}, {355.60200000000003`, 505.19899999999996`}, {378., 
                    505.19899999999996`}, {378., 494.}, {400.39799999999997`, 
                    494.}, {400.39799999999997`, 505.19899999999996`}, {
                    389.199, 505.19899999999996`}}, {{422.801, 494.}, {
                    411.60200000000003`, 494.}, {411.60200000000003`, 
                    505.19899999999996`}, {434., 505.19899999999996`}, {434., 
                    516.398}}, {{434., 505.19899999999996`}, {434., 494.}, {
                    456.39799999999997`, 494.}, {456.39799999999997`, 
                    516.398}}, {{445.199, 516.398}, {445.199, 494.}}, {{
                    366.801, 494.}, {366.805, 494.}}}, 
                    CurveClosed -> {0, 0, 0, 0, 0, 0}]}}}}}}}, {{{{{{{
                    RGBColor[1., 1., 1.], 
                    Thickness[0.005312127152597305], 
                    Opacity[1.], 
                    CapForm["Round"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}}}, {{{355.6014, 
                    481.602}, {400.3986, 481.602}}, {{411.60139999999996`, 
                    481.602}, {456.3986, 481.602}}}, 
                    CurveClosed -> {0, 0}]}}}}}}}, {{{{{{{
                    RGBColor[1., 1., 1.], 
                    Thickness[0.0044444444444444444`], 
                    Opacity[1.], 
                    CapForm["Round"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 
                    0}}, {{0, 2, 0}}, {{0, 2, 0}}}, {{{355.60200000000003`, 
                    226.}, {422.801, 226.}}, {{355.60200000000003`, 
                    203.60199999999998`}, {355.60200000000003`, 214.801}, {
                    378., 214.801}, {378., 203.60199999999998`}, {
                    400.39799999999997`, 203.60199999999998`}, {
                    400.39799999999997`, 214.801}, {389.199, 214.801}}, {{
                    422.801, 203.60199999999998`}, {411.60200000000003`, 
                    203.60199999999998`}, {411.60200000000003`, 214.801}, {
                    434., 214.801}, {434., 226.}}, {{434., 214.801}, {434., 
                    203.60199999999998`}, {456.39799999999997`, 
                    203.60199999999998`}, {456.39799999999997`, 226.}}, {{
                    445.199, 226.}, {445.199, 203.60199999999998`}}, {{
                    366.801, 203.60199999999998`}, {366.805, 
                    203.60199999999998`}}}, 
                    CurveClosed -> {0, 0, 0, 0, 0, 0}]}}}}}}}, {{{{{{{
                    RGBColor[1., 1., 1.], 
                    Thickness[0.005312127152597305], 
                    Opacity[1.], 
                    CapForm["Round"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}}}, {{{355.6014, 
                    238.39799999999997`}, {400.3986, 238.39799999999997`}}, {{
                    411.60139999999996`, 238.39799999999997`}, {456.3986, 
                    238.39799999999997`}}}, 
                    CurveClosed -> {0, 0}]}}}}}}}, {{{{{{{
                    RGBColor[1., 1., 1.], 
                    Thickness[0.0044444444444444444`], 
                    Opacity[1.], 
                    CapForm["Round"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 
                    0}}, {{0, 2, 0}}, {{0, 2, 0}}}, {{{467.60200000000003`, 
                    516.398}, {534.8009999999999, 516.398}}, {{
                    467.60200000000003`, 494.}, {467.60200000000003`, 
                    505.19899999999996`}, {490., 505.19899999999996`}, {490., 
                    494.}, {512.398, 494.}, {512.398, 505.19899999999996`}, {
                    501.199, 505.19899999999996`}}, {{534.8009999999999, 
                    494.}, {523.602, 494.}, {523.602, 505.19899999999996`}, {
                    546., 505.19899999999996`}, {546., 516.398}}, {{546., 
                    505.19899999999996`}, {546., 494.}, {568.398, 494.}, {
                    568.398, 516.398}}, {{557.1990000000001, 516.398}, {
                    557.1990000000001, 494.}}, {{478.801, 494.}, {478.805, 
                    494.}}}, CurveClosed -> {0, 0, 0, 0, 0, 0}]}}}}}}}, {{{{{{{
                    RGBColor[1., 1., 1.], 
                    Thickness[0.005312127152597305], 
                    Opacity[1.], 
                    CapForm["Round"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}}}, {{{
                    467.60139999999996`, 481.602}, {512.3986, 481.602}}, {{
                    523.6013999999999, 481.602}, {568.3986, 481.602}}}, 
                    CurveClosed -> {0, 0}]}}}}}}}, {{{{{{{
                    RGBColor[1., 1., 1.], 
                    Thickness[0.0044444444444444444`], 
                    Opacity[1.], 
                    CapForm["Round"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 
                    0}}, {{0, 2, 0}}, {{0, 2, 0}}}, {{{467.60200000000003`, 
                    226.}, {534.8009999999999, 226.}}, {{467.60200000000003`, 
                    203.60199999999998`}, {467.60200000000003`, 214.801}, {
                    490., 214.801}, {490., 203.60199999999998`}, {512.398, 
                    203.60199999999998`}, {512.398, 214.801}, {501.199, 
                    214.801}}, {{534.8009999999999, 203.60199999999998`}, {
                    523.602, 203.60199999999998`}, {523.602, 214.801}, {546., 
                    214.801}, {546., 226.}}, {{546., 214.801}, {546., 
                    203.60199999999998`}, {568.398, 203.60199999999998`}, {
                    568.398, 226.}}, {{557.1990000000001, 226.}, {
                    557.1990000000001, 203.60199999999998`}}, {{478.801, 
                    203.60199999999998`}, {478.805, 203.60199999999998`}}}, 
                    CurveClosed -> {0, 0, 0, 0, 0, 0}]}}}}}}}, {{{{{{{
                    RGBColor[1., 1., 1.], 
                    Thickness[0.005312127152597305], 
                    Opacity[1.], 
                    CapForm["Round"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}}}, {{{
                    467.60139999999996`, 238.39799999999997`}, {512.3986, 
                    238.39799999999997`}}, {{523.6013999999999, 
                    238.39799999999997`}, {568.3986, 238.39799999999997`}}}, 
                    CurveClosed -> {0, 0}]}}}}}}}, {{{{{{{
                    RGBColor[1., 1., 1.], 
                    Thickness[0.0044444444444444444`], 
                    Opacity[1.], 
                    CapForm["Round"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 
                    0}}, {{0, 2, 0}}, {{0, 2, 0}}}, {{{1027.6019999999999`, 
                    516.398}, {1094.801, 516.398}}, {{1027.6019999999999`, 
                    494.}, {1027.6019999999999`, 505.19899999999996`}, {1050.,
                     505.19899999999996`}, {1050., 494.}, {1072.398, 494.}, {
                    1072.398, 505.19899999999996`}, {1061.1989999999998`, 
                    505.19899999999996`}}, {{1094.801, 494.}, {
                    1083.6019999999999`, 494.}, {1083.6019999999999`, 
                    505.19899999999996`}, {1106., 505.19899999999996`}, {
                    1106., 516.398}}, {{1106., 505.19899999999996`}, {1106., 
                    494.}, {1128.398, 494.}, {1128.398, 516.398}}, {{
                    1117.1989999999998`, 516.398}, {1117.1989999999998`, 
                    494.}}, {{1038.801, 494.}, {1038.805, 494.}}}, 
                    CurveClosed -> {0, 0, 0, 0, 0, 0}]}}}}}}}, {{{{{{{
                    RGBColor[1., 1., 1.], 
                    Thickness[0.005312127152597305], 
                    Opacity[1.], 
                    CapForm["Round"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}}}, {{{1027.6014, 
                    481.602}, {1072.3986, 481.602}}, {{1083.6013999999998`, 
                    481.602}, {1128.3986, 481.602}}}, 
                    CurveClosed -> {0, 0}]}}}}}}}, {{{{{{{
                    RGBColor[1., 1., 1.], 
                    Thickness[0.0044444444444444444`], 
                    Opacity[1.], 
                    CapForm["Round"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 
                    0}}, {{0, 2, 0}}, {{0, 2, 0}}}, {{{1027.6019999999999`, 
                    226.}, {1094.801, 226.}}, {{1027.6019999999999`, 
                    203.60199999999998`}, {1027.6019999999999`, 214.801}, {
                    1050., 214.801}, {1050., 203.60199999999998`}, {1072.398, 
                    203.60199999999998`}, {1072.398, 214.801}, {
                    1061.1989999999998`, 214.801}}, {{1094.801, 
                    203.60199999999998`}, {1083.6019999999999`, 
                    203.60199999999998`}, {1083.6019999999999`, 214.801}, {
                    1106., 214.801}, {1106., 226.}}, {{1106., 214.801}, {
                    1106., 203.60199999999998`}, {1128.398, 
                    203.60199999999998`}, {1128.398, 226.}}, {{
                    1117.1989999999998`, 226.}, {1117.1989999999998`, 
                    203.60199999999998`}}, {{1038.801, 203.60199999999998`}, {
                    1038.805, 203.60199999999998`}}}, 
                    CurveClosed -> {0, 0, 0, 0, 0, 0}]}}}}}}}, {{{{{{{
                    RGBColor[1., 1., 1.], 
                    Thickness[0.005312127152597305], 
                    Opacity[1.], 
                    CapForm["Round"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}}}, {{{1027.6014, 
                    238.39799999999997`}, {1072.3986, 
                    238.39799999999997`}}, {{1083.6013999999998`, 
                    238.39799999999997`}, {1128.3986, 238.39799999999997`}}}, 
                    CurveClosed -> {0, 0}]}}}}}}}, {{{{{{{
                    RGBColor[1., 1., 1.], 
                    Thickness[0.0044444444444444444`], 
                    Opacity[1.], 
                    CapForm["Round"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 
                    0}}, {{0, 2, 0}}, {{0, 2, 0}}}, {{{1139.6019999999999`, 
                    516.398}, {1206.801, 516.398}}, {{1139.6019999999999`, 
                    494.}, {1139.6019999999999`, 505.19899999999996`}, {1162.,
                     505.19899999999996`}, {1162., 494.}, {1184.398, 494.}, {
                    1184.398, 505.19899999999996`}, {1173.1989999999998`, 
                    505.19899999999996`}}, {{1206.801, 494.}, {
                    1195.6019999999999`, 494.}, {1195.6019999999999`, 
                    505.19899999999996`}, {1218., 505.19899999999996`}, {
                    1218., 516.398}}, {{1218., 505.19899999999996`}, {1218., 
                    494.}, {1240.398, 494.}, {1240.398, 516.398}}, {{
                    1229.1989999999998`, 516.398}, {1229.1989999999998`, 
                    494.}}, {{1150.801, 494.}, {1150.805, 494.}}}, 
                    CurveClosed -> {0, 0, 0, 0, 0, 0}]}}}}}}}, {{{{{{{
                    RGBColor[1., 1., 1.], 
                    Thickness[0.005312127152597305], 
                    Opacity[1.], 
                    CapForm["Round"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}}}, {{{
                    1139.6013999999998`, 481.602}, {1184.3986, 481.602}}, {{
                    1195.6013999999998`, 481.602}, {1240.3986, 481.602}}}, 
                    CurveClosed -> {0, 0}]}}}}}}}, {{{{{{{
                    RGBColor[1., 1., 1.], 
                    Thickness[0.0044444444444444444`], 
                    Opacity[1.], 
                    CapForm["Round"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 
                    0}}, {{0, 2, 0}}, {{0, 2, 0}}}, {{{1139.6019999999999`, 
                    226.}, {1206.801, 226.}}, {{1139.6019999999999`, 
                    203.60199999999998`}, {1139.6019999999999`, 214.801}, {
                    1162., 214.801}, {1162., 203.60199999999998`}, {1184.398, 
                    203.60199999999998`}, {1184.398, 214.801}, {
                    1173.1989999999998`, 214.801}}, {{1206.801, 
                    203.60199999999998`}, {1195.6019999999999`, 
                    203.60199999999998`}, {1195.6019999999999`, 214.801}, {
                    1218., 214.801}, {1218., 226.}}, {{1218., 214.801}, {
                    1218., 203.60199999999998`}, {1240.398, 
                    203.60199999999998`}, {1240.398, 226.}}, {{
                    1229.1989999999998`, 226.}, {1229.1989999999998`, 
                    203.60199999999998`}}, {{1150.801, 203.60199999999998`}, {
                    1150.805, 203.60199999999998`}}}, 
                    CurveClosed -> {0, 0, 0, 0, 0, 0}]}}}}}}}, {{{{{{{
                    RGBColor[1., 1., 1.], 
                    Thickness[0.005312127152597305], 
                    Opacity[1.], 
                    CapForm["Round"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}}}, {{{
                    1139.6013999999998`, 238.39799999999997`}, {1184.3986, 
                    238.39799999999997`}}, {{1195.6013999999998`, 
                    238.39799999999997`}, {1240.3986, 238.39799999999997`}}}, 
                    CurveClosed -> {0, 0}]}}}}}}}, {{{{{{{
                    RGBColor[1., 1., 1.], 
                    Thickness[0.0044444444444444444`], 
                    Opacity[1.], 
                    CapForm["Round"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 
                    0}}, {{0, 2, 0}}, {{0, 2, 0}}}, {{{803.602, 516.398}, {
                    870.8009999999999, 516.398}}, {{803.602, 494.}, {803.602, 
                    505.19899999999996`}, {826., 505.19899999999996`}, {826., 
                    494.}, {848.398, 494.}, {848.398, 505.19899999999996`}, {
                    837.1990000000001, 505.19899999999996`}}, {{
                    870.8009999999999, 494.}, {859.602, 494.}, {859.602, 
                    505.19899999999996`}, {882., 505.19899999999996`}, {882., 
                    516.398}}, {{882., 505.19899999999996`}, {882., 494.}, {
                    904.398, 494.}, {904.398, 516.398}}, {{893.1990000000001, 
                    516.398}, {893.1990000000001, 494.}}, {{814.8009999999999,
                     494.}, {814.805, 494.}}}, 
                    CurveClosed -> {0, 0, 0, 0, 0, 0}]}}}}}}}, {{{{{{{
                    RGBColor[1., 1., 1.], 
                    Thickness[0.005312127152597305], 
                    Opacity[1.], 
                    CapForm["Round"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}}}, {{{
                    803.6013999999999, 481.602}, {848.3986, 481.602}}, {{
                    859.6013999999999, 481.602}, {904.3986, 481.602}}}, 
                    CurveClosed -> {0, 0}]}}}}}}}, {{{{{{{
                    RGBColor[1., 1., 1.], 
                    Thickness[0.0044444444444444444`], 
                    Opacity[1.], 
                    CapForm["Round"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 
                    0}}, {{0, 2, 0}}, {{0, 2, 0}}}, {{{803.602, 226.}, {
                    870.8009999999999, 226.}}, {{803.602, 
                    203.60199999999998`}, {803.602, 214.801}, {826., 
                    214.801}, {826., 203.60199999999998`}, {848.398, 
                    203.60199999999998`}, {848.398, 214.801}, {
                    837.1990000000001, 214.801}}, {{870.8009999999999, 
                    203.60199999999998`}, {859.602, 203.60199999999998`}, {
                    859.602, 214.801}, {882., 214.801}, {882., 226.}}, {{882.,
                     214.801}, {882., 203.60199999999998`}, {904.398, 
                    203.60199999999998`}, {904.398, 226.}}, {{
                    893.1990000000001, 226.}, {893.1990000000001, 
                    203.60199999999998`}}, {{814.8009999999999, 
                    203.60199999999998`}, {814.805, 203.60199999999998`}}}, 
                    CurveClosed -> {0, 0, 0, 0, 0, 0}]}}}}}}}, {{{{{{{
                    RGBColor[1., 1., 1.], 
                    Thickness[0.005312127152597305], 
                    Opacity[1.], 
                    CapForm["Round"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}}}, {{{
                    803.6013999999999, 238.39799999999997`}, {848.3986, 
                    238.39799999999997`}}, {{859.6013999999999, 
                    238.39799999999997`}, {904.3986, 238.39799999999997`}}}, 
                    CurveClosed -> {0, 0}]}}}}}}}, {{{{{{{
                    RGBColor[1., 1., 1.], 
                    Thickness[0.0044444444444444444`], 
                    Opacity[1.], 
                    CapForm["Round"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 
                    0}}, {{0, 2, 0}}, {{0, 2, 0}}}, {{{915.602, 516.398}, {
                    982.8009999999999, 516.398}}, {{915.602, 494.}, {915.602, 
                    505.19899999999996`}, {938., 505.19899999999996`}, {938., 
                    494.}, {960.398, 494.}, {960.398, 505.19899999999996`}, {
                    949.1990000000001, 505.19899999999996`}}, {{
                    982.8009999999999, 494.}, {971.602, 494.}, {971.602, 
                    505.19899999999996`}, {994., 505.19899999999996`}, {994., 
                    516.398}}, {{994., 505.19899999999996`}, {994., 494.}, {
                    1016.398, 494.}, {1016.398, 516.398}}, {{
                    1005.1990000000001`, 516.398}, {1005.1990000000001`, 
                    494.}}, {{926.8009999999999, 494.}, {926.805, 494.}}}, 
                    CurveClosed -> {0, 0, 0, 0, 0, 0}]}}}}}}}, {{{{{{{
                    RGBColor[1., 1., 1.], 
                    Thickness[0.005312127152597305], 
                    Opacity[1.], 
                    CapForm["Round"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}}}, {{{
                    915.6013999999999, 481.602}, {960.3986, 481.602}}, {{
                    971.6013999999999, 481.602}, {1016.3986, 481.602}}}, 
                    CurveClosed -> {0, 0}]}}}}}}}, {{{{{{{
                    RGBColor[1., 1., 1.], 
                    Thickness[0.0044444444444444444`], 
                    Opacity[1.], 
                    CapForm["Round"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 
                    0}}, {{0, 2, 0}}, {{0, 2, 0}}}, {{{915.602, 226.}, {
                    982.8009999999999, 226.}}, {{915.602, 
                    203.60199999999998`}, {915.602, 214.801}, {938., 
                    214.801}, {938., 203.60199999999998`}, {960.398, 
                    203.60199999999998`}, {960.398, 214.801}, {
                    949.1990000000001, 214.801}}, {{982.8009999999999, 
                    203.60199999999998`}, {971.602, 203.60199999999998`}, {
                    971.602, 214.801}, {994., 214.801}, {994., 226.}}, {{994.,
                     214.801}, {994., 203.60199999999998`}, {1016.398, 
                    203.60199999999998`}, {1016.398, 226.}}, {{
                    1005.1990000000001`, 226.}, {1005.1990000000001`, 
                    203.60199999999998`}}, {{926.8009999999999, 
                    203.60199999999998`}, {926.805, 203.60199999999998`}}}, 
                    CurveClosed -> {0, 0, 0, 0, 0, 0}]}}}}}}}, {{{{{{{
                    RGBColor[1., 1., 1.], 
                    Thickness[0.005312127152597305], 
                    Opacity[1.], 
                    CapForm["Round"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}}}, {{{
                    915.6013999999999, 238.39799999999997`}, {960.3986, 
                    238.39799999999997`}}, {{971.6013999999999, 
                    238.39799999999997`}, {1016.3986, 238.39799999999997`}}}, 
                    CurveClosed -> {0, 0}]}}}}}}}, {{{{{{{
                    RGBColor[1., 1., 1.], 
                    Thickness[0.0044444444444444444`], 
                    Opacity[1.], 
                    CapForm["Round"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 
                    0}}, {{0, 2, 0}}, {{0, 2, 0}}}, {{{243.602, 516.398}, {
                    310.801, 516.398}}, {{243.602, 494.}, {243.602, 
                    505.19899999999996`}, {266., 505.19899999999996`}, {266., 
                    494.}, {288.39799999999997`, 494.}, {288.39799999999997`, 
                    505.19899999999996`}, {277.199, 505.19899999999996`}}, {{
                    310.801, 494.}, {299.60200000000003`, 494.}, {
                    299.60200000000003`, 505.19899999999996`}, {322., 
                    505.19899999999996`}, {322., 516.398}}, {{322., 
                    505.19899999999996`}, {322., 494.}, {344.39799999999997`, 
                    494.}, {344.39799999999997`, 516.398}}, {{333.199, 
                    516.398}, {333.199, 494.}}, {{254.80100000000002`, 
                    494.}, {254.805, 494.}}}, 
                    CurveClosed -> {0, 0, 0, 0, 0, 0}]}}}}}}}, {{{{{{{
                    RGBColor[1., 1., 1.], 
                    Thickness[0.005312127152597305], 
                    Opacity[1.], 
                    CapForm["Round"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}}}, {{{
                    243.60139999999998`, 481.602}, {288.39859999999993`, 
                    481.602}}, {{299.6014, 481.602}, {344.39859999999993`, 
                    481.602}}}, CurveClosed -> {0, 0}]}}}}}}}, {{{{{{{
                    RGBColor[1., 1., 1.], 
                    Thickness[0.0044444444444444444`], 
                    Opacity[1.], 
                    CapForm["Round"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 
                    0}}, {{0, 2, 0}}, {{0, 2, 0}}}, {{{243.602, 226.}, {
                    310.801, 226.}}, {{243.602, 203.60199999999998`}, {
                    243.602, 214.801}, {266., 214.801}, {266., 
                    203.60199999999998`}, {288.39799999999997`, 
                    203.60199999999998`}, {288.39799999999997`, 214.801}, {
                    277.199, 214.801}}, {{310.801, 203.60199999999998`}, {
                    299.60200000000003`, 203.60199999999998`}, {
                    299.60200000000003`, 214.801}, {322., 214.801}, {322., 
                    226.}}, {{322., 214.801}, {322., 203.60199999999998`}, {
                    344.39799999999997`, 203.60199999999998`}, {
                    344.39799999999997`, 226.}}, {{333.199, 226.}, {333.199, 
                    203.60199999999998`}}, {{254.80100000000002`, 
                    203.60199999999998`}, {254.805, 203.60199999999998`}}}, 
                    CurveClosed -> {0, 0, 0, 0, 0, 0}]}}}}}}}, {{{{{{{
                    RGBColor[1., 1., 1.], 
                    Thickness[0.005312127152597305], 
                    Opacity[1.], 
                    CapForm["Round"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}}}, {{{
                    243.60139999999998`, 238.39799999999997`}, {
                    288.39859999999993`, 238.39799999999997`}}, {{299.6014, 
                    238.39799999999997`}, {344.39859999999993`, 
                    238.39799999999997`}}}, 
                    CurveClosed -> {0, 0}]}}}}}}}, {{{{{{{
                    RGBColor[1., 1., 1.], 
                    Thickness[0.0044444444444444444`], 
                    Opacity[1.], 
                    CapForm["Round"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 
                    0}}, {{0, 2, 0}}, {{0, 2, 0}}}, {{{19.602, 516.398}, {
                    86.801, 516.398}}, {{19.602, 494.}, {19.602, 
                    505.19899999999996`}, {42., 505.19899999999996`}, {42., 
                    494.}, {64.398, 494.}, {64.398, 505.19899999999996`}, {
                    53.199000000000005`, 505.19899999999996`}}, {{86.801, 
                    494.}, {75.60199999999999, 494.}, {75.60199999999999, 
                    505.19899999999996`}, {98., 505.19899999999996`}, {98., 
                    516.398}}, {{98., 505.19899999999996`}, {98., 494.}, {
                    120.398, 494.}, {120.398, 516.398}}, {{109.199, 
                    516.398}, {109.199, 494.}}, {{30.801000000000002`, 
                    494.}, {30.805, 494.}}}, 
                    CurveClosed -> {0, 0, 0, 0, 0, 0}]}}}}}}}, {{{{{{{
                    RGBColor[1., 1., 1.], 
                    Thickness[0.005312127152597305], 
                    Opacity[1.], 
                    CapForm["Round"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}}}, {{{
                    19.601399999999998`, 481.602}, {64.3986, 481.602}}, {{
                    75.6014, 481.602}, {120.3986, 481.602}}}, 
                    CurveClosed -> {0, 0}]}}}}}}}, {{{{{{{
                    RGBColor[1., 1., 1.], 
                    Thickness[0.0044444444444444444`], 
                    Opacity[1.], 
                    CapForm["Round"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 
                    0}}, {{0, 2, 0}}, {{0, 2, 0}}}, {{{19.602, 226.}, {86.801,
                     226.}}, {{19.602, 203.60199999999998`}, {19.602, 
                    214.801}, {42., 214.801}, {42., 203.60199999999998`}, {
                    64.398, 203.60199999999998`}, {64.398, 214.801}, {
                    53.199000000000005`, 214.801}}, {{86.801, 
                    203.60199999999998`}, {75.60199999999999, 
                    203.60199999999998`}, {75.60199999999999, 214.801}, {98., 
                    214.801}, {98., 226.}}, {{98., 214.801}, {98., 
                    203.60199999999998`}, {120.398, 203.60199999999998`}, {
                    120.398, 226.}}, {{109.199, 226.}, {109.199, 
                    203.60199999999998`}}, {{30.801000000000002`, 
                    203.60199999999998`}, {30.805, 203.60199999999998`}}}, 
                    CurveClosed -> {0, 0, 0, 0, 0, 0}]}}}}}}}, {{{{{{{
                    RGBColor[1., 1., 1.], 
                    Thickness[0.005312127152597305], 
                    Opacity[1.], 
                    CapForm["Round"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}}}, {{{
                    19.601399999999998`, 238.39799999999997`}, {64.3986, 
                    238.39799999999997`}}, {{75.6014, 238.39799999999997`}, {
                    120.3986, 238.39799999999997`}}}, 
                    CurveClosed -> {0, 0}]}}}}}}}, {{{{{{{
                    RGBColor[1., 1., 1.], 
                    Thickness[0.0044444444444444444`], 
                    Opacity[1.], 
                    CapForm["Round"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 
                    0}}, {{0, 2, 0}}, {{0, 2, 0}}}, {{{131.602, 516.398}, {
                    198.80100000000002`, 516.398}}, {{131.602, 494.}, {
                    131.602, 505.19899999999996`}, {154., 
                    505.19899999999996`}, {154., 494.}, {176.39800000000002`, 
                    494.}, {176.39800000000002`, 505.19899999999996`}, {
                    165.19899999999998`, 505.19899999999996`}}, {{
                    198.80100000000002`, 494.}, {187.602, 494.}, {187.602, 
                    505.19899999999996`}, {210., 505.19899999999996`}, {210., 
                    516.398}}, {{210., 505.19899999999996`}, {210., 494.}, {
                    232.39800000000002`, 494.}, {232.39800000000002`, 
                    516.398}}, {{221.19899999999998`, 516.398}, {
                    221.19899999999998`, 494.}}, {{142.80100000000002`, 
                    494.}, {142.805, 494.}}}, 
                    CurveClosed -> {0, 0, 0, 0, 0, 0}]}}}}}}}, {{{{{{{
                    RGBColor[1., 1., 1.], 
                    Thickness[0.005312127152597305], 
                    Opacity[1.], 
                    CapForm["Round"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}}}, {{{131.6014, 
                    481.602}, {176.39860000000002`, 481.602}}, {{
                    187.60139999999998`, 481.602}, {232.39859999999993`, 
                    481.602}}}, CurveClosed -> {0, 0}]}}}}}}}, {{{{{{{
                    RGBColor[1., 1., 1.], 
                    Thickness[0.0044444444444444444`], 
                    Opacity[1.], 
                    CapForm["Round"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 
                    0}}, {{0, 2, 0}}, {{0, 2, 0}}}, {{{131.602, 226.}, {
                    198.80100000000002`, 226.}}, {{131.602, 
                    203.60199999999998`}, {131.602, 214.801}, {154., 
                    214.801}, {154., 203.60199999999998`}, {
                    176.39800000000002`, 203.60199999999998`}, {
                    176.39800000000002`, 214.801}, {165.19899999999998`, 
                    214.801}}, {{198.80100000000002`, 203.60199999999998`}, {
                    187.602, 203.60199999999998`}, {187.602, 214.801}, {210., 
                    214.801}, {210., 226.}}, {{210., 214.801}, {210., 
                    203.60199999999998`}, {232.39800000000002`, 
                    203.60199999999998`}, {232.39800000000002`, 226.}}, {{
                    221.19899999999998`, 226.}, {221.19899999999998`, 
                    203.60199999999998`}}, {{142.80100000000002`, 
                    203.60199999999998`}, {142.805, 203.60199999999998`}}}, 
                    CurveClosed -> {0, 0, 0, 0, 0, 0}]}}}}}}}, {{{{{{{
                    RGBColor[1., 1., 1.], 
                    Thickness[0.005312127152597305], 
                    Opacity[1.], 
                    CapForm["Round"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}}}, {{{131.6014, 
                    238.39799999999997`}, {176.39860000000002`, 
                    238.39799999999997`}}, {{187.60139999999998`, 
                    238.39799999999997`}, {232.39859999999993`, 
                    238.39799999999997`}}}, 
                    CurveClosed -> {0, 0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0.854902, 0., 0.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{666.664, 
                    424.33599999999996`}, {666.664, 424.33599999999996`}, {
                    731.7850000000001, 373.40999999999997`}, {683.918, 
                    300.22299999999996`}, {729., 327.77299999999997`}, {
                    732.895, 403.53499999999997`}, {666.664, 
                    424.33599999999996`}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{630., 431.57}, {619.637, 419.883}, {601.824, 
                    431.504}, {607.9449999999999, 444.234}, {618.66, 
                    425.03099999999995`}, {630., 440.547}, {630., 440.547}, {
                    630., 440.547}, {641.3399999999999, 
                    425.03099999999995`}, {652.055, 444.234}, {
                    658.1800000000001, 431.504}, {640.3669999999998, 
                    419.883}, {630., 431.57}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJtIGZigIINzQ6trwN3yPEXOmz7/PdKRUmzQ+7z3ys/
rsLkv19+zNv8RZODHdf1xQW+hQ5HFDYUZeg3ORz6qhHTf67QocMx4emFYwg+
WF662QFsD0sRRNyq2aF833wpfWVMvhzIIY8bHabnCTUfmFLs4GPe6ZjwqtEh
Y+LbGvvWMgdbkL3/Gh22nCjbN7+u0qHypZohx8kmh6sVQEZaFUG+N8i8hEYI
7V3m8AHknyKo/+8WOSwuANoQ1ewAcvZE6XI43wpkoWWVwzTn7pznFc0Q8zyq
HGDhN1mCJYzvOGF+1p6SyRLPEfpj+oEhwNoCNx/Gh9kvGGG55cRbhPvA/v7f
Cnd/u9jNc9+ntTgcAwkA/UeIfxgU3omtkPAFhp/Nff/e6aWtDlEp1vf9geH7
sEpknXtNq0MnKB6B4X8U5BDVFkj4A+MHnQ82z6XF4dMl3yQBYPyC43FmC8Sd
wPgHyxu0wvlg/5S3OBjcVWFrBKYfTx4m7fbXzQ5xu4Cs1Zh8sPvXQ9MHMH0C
AGVtMXs=
                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    593.3399999999999, 424.33599999999996`}, {
                    593.3399999999999, 424.33599999999996`}, {528.219, 
                    373.40999999999997`}, {576.086, 300.22299999999996`}, {
                    531., 327.77299999999997`}, {527.102, 
                    403.53499999999997`}, {593.3399999999999, 
                    424.33599999999996`}}}]}}}}}}}}}}}}}}, AspectRatio -> 
                  Automatic, ImageSize -> {{128}, {85}}, 
                  PlotRange -> {{0., 1260.}, {0., 720.}}], ",", 
                 GraphicsBox[{{{{{{{
                    Thickness[0.001388888888888889], {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.8078430000000001, 0.06666670000000002, 0.14902], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     480.}, {720., 480.}, {720., 320.}, {0., 
                    320.}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     320.}, {720., 320.}, {720., 160.}, {0., 
                    160.}}}]}}}}}}}, {{{{{{{
                    Thickness[0.001388888888888889], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     160.}, {720., 160.}, {720., 0.}, {0., 
                    0.}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0., 0.478431, 0.23921600000000004`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{218.918, 
                    180.562}, {214.781, 185.102}, {223.13299999999998`, 
                    194.102}, {227.26999999999998`, 189.562}, {231.406, 
                    185.02}, {223.055, 176.02}, {218.92200000000003`, 
                    180.57}}, CompressedData["
1:eJxlVQ1olVUYvpqOMce1plmm2UxbUsawJWEiveXC9pOmwzVMxIbd7+d8937n
O99Wq9lIRpmV3o2MnCZOLxs1NYeVmKitFWUqNoRh+7mpSNiQFhplIkHnnOd0
L9SFy8fznfe873Oe5z3vN7PWX/Hi2Egk0ij/6tl19ewztX0WFeVseH/xUIyG
bjS5R9stun9e7r7pozESduuv66ss2vJBoqB5rkVf7rqrOF1oEV+Udy5lW1Tx
6KYn1n4VownnUnzRoEXV0YcO7twbo/tUvok2PfbZiZeOX4lR6Tve5ZsjFrX0
/jFndYVFeSr+oEWDql6ujXpbLPpOJay0qe9eyaTT1Ct1wCtiU6Wq95pDf85Z
nex1HHp18idLLh6yaZuk17PUpbtXrVt4PmmDR6NLEfXjNt4fyGId35vFOl+/
i/O02fTGleWHZ9ww66dtvL+NUaOqV+BAlxJGxenZORvmO9CjxqzXOjj/pwz8
Wwye6NECpUfK4FkeDZy5XnXpi+y6zjfggN81Rpc6dnxTWOoiLu1msPbtoyzW
z3dd7HNdOlb33p3j3nRJ0Xx8KstgrftoFu956tDvf59mNKz0HTb7jzD4nc8o
UOf60KxXMvj0NqNQJWaGn8fgy04GvTwT18ng71sm31FGZ5Wv2xn65aTRr59R
UvXFdQafJnjwu9AD3yc9xJd74Ftn3jd54Lfeo80q/1YPvJIe/D/lgdf4OOq6
cfT5tCzW/sz+D54bB4+vvQzWffkXy+B/9Ts8Q3bKifB/WOvYlUDfpEKcfzhB
0o35a5pCPKM++qUmhI59Jr4kxH1pzWLNZ4fpr3FBBuu+SfkZrOvsi8OH9izW
/dyRxbov9jPo9qNPk5p7Tu5OJ6i/YaRoXpTDlwU+4m7n0LnSJxXeU2Tw6z78
eIQj/34Tv5jjPg349ODGKQNnlnN6+qK8qWM41ldycw5O8nQ/99Vwuibb+dZc
Ti8flwJbZn06x/nrTf4Sw6uZkyrPy8y+rRxz5gWDt5s8Doeu7ZzU8i5u6kn9
dN5bjI6vBKQeyw4EmCejAXg+L7B/haBv1YZfBJ1fJhWrFtQpX3dLrH1eJUi6
Xx0dEci/VtCaI2X5Y4cEfFgnqLBbTozvBc1Uz3qz3zZxzYIuqLwPC4pfvvnx
1RYBvpNN3B6BeSh56f7aZvhcMLwdQYpm908BeFQJUu3/WzrAvLlHQLe2ALoV
B1Sg/F5odGzluBd7E6SuYVL6/7mq/0AcPPI5+qQwjvd5HP07JY56bRz3PWr6
rCzIYO3DJpHBWneJtc45CdSX+DlFOJlAvs2CRlX+PB/naxWYt3f42N8hUGel
6b+GEHEVHOfdGCLPEm70DOFbKTc+hOj3qRx+jK9DH/zg43yizsyJLNbrkxzU
rXczWPv7rIu4JhtzbJaLfjxlYa4MOlgvN9/NBvP9GmO+l9MczPdjMcSX24jv
ihleFuaa/D7/A9PgVSI=
                    "], CompressedData["
1:eJxTTMoPSmViYGCQB2IQrbChKGPi8xIHoeYDpxYezXWA8atE1rk/bCtwmCzB
Esb3usThbY29aZxdIYT/ucRBq13s5jnnQgdbruuLC36WODxeOvuIgkehQ+7z
3ys/ipRC+EaFDse8zTsdDUod4nZ58jAJF0LM9y51kI1Ksb7/ucDhasVLNcMa
KP9ggcN9/97peXNKHfh0N819v7jAIWMi0ObzpQ5bTpTtm19S4HDoq0ZM/xWo
+uwCh2qQO4+UOujfVWFrTCxwuKB0+2fdhFKHHJA77AoctEHunFgKoT0R/EWu
2z7/LcmF88Hmt2VBwuE7gv/pkm+SQFAZnD8jD6giqczBB+ithN4siHt6yiDi
h7Ig9h8oc9g/X0r/Lks2xB+HyyDh8SfL4TgoPFZB+RVZEHMXlEHC2y0L4q+p
ZRB/P82EqJ9U5qDK1jjVeX6mgyVIQ3eZAwMIKGQ6CIPcu7MUQktmwuOvH+Qw
YQQfHH/Hch0AiJroxA==
                    "]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}, {{0, 2, 0}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, {CompressedData["
1:eJxlUltIFGEUXiQ2iDCpzSTMVrsQUW0iS1lsHukhTGGxy4bW6hJGtc7O/DNF
NZc1TCyFIsJiBdFNwqCHZDMDidzEwi6QuA9hEmUiIV0WKaiQemjOnHHmwYfh
55v//Od83/m+/OPCgRMZDocD9A/P4v6X55JFMgQyt/Z1loehum73pL9YhsGz
bTmLuuqhfEdraahMhvdzDeEnWRx88l+L8Zdk+L3p2PXhKAdprcRb0yvDiqah
190pDs4n46s9aZnezXGAbWe9CpSGPo8VzHIwie85BaRTN9LaDAf7phRXr6DA
xOifg9NiBDZfyZ4YPaMAXpfk8zD8Sx+k169BYrU87EK+lQqkCnRGEg/uhN6p
UAHmWzJ+p4WH6Z6O5+6dCs1P8dD8rXIgr1YB/Zb5nAK8vfBlY6GkwAsscAsQ
mfl778dtc74sAId4RCE9b8z77wq088ubhrIY8VumQs3jsqUZRYz0u2xs1OfY
GOkkclXSu0qw8CNdRrwhYuENzsZbe2Nh4te3EBu6bkYsPJCnK8tmaKPDkVBp
7n5GurtVaMWFVzOqbzdxHaM+V1XQ3Q1kRkx+l20cQ528jQ1/Lqq05w4Gng/r
nY1xlXx+wOAZ+jPPL8no3ZQKd7HvVwYtONepwQgSc4kwhr5t0chPn0h8/Rr1
C4pUd0ij3FSJ1K9KI54BEwc1MHJbzyx8BB/EeQvP78/g93MhNvpxIuQij3Fz
XrNIPF5p5HObiQc12I66e2xs5PO+jY3994uUh48a5fydCEHMweIo7eefSHv0
RKn/WonyeTRK/lRI9P+kWR+SyOeuKGC82UMJ9uDZGSXeT21s9FkpWPgwClp3
mva/TbawkWuvTLmpCMN/ybjHEQ==
                    "], {{423.09799999999996`, 
                    217.445}, {423.09799999999996`, 222.164}, {
                    420.47999999999996`, 222.164}, {416.965, 222.164}, {
                    413.754, 218.848}, {413.754, 215.21099999999998`}, {
                    413.754, 212.727}, {423.09799999999996`, 212.727}, {
                    423.09799999999996`, 217.441}}, CompressedData["
1:eJxTTMoPSmViYGBQBGIQHbfLk4dJuM7hm0ZM/6GbuQ4w/kWl2z/rJhU4XADR
YnUOM/KEmg94FToc+gpUKFfncLXipZphQKFD7vPfKz+q1EHUhRQ6bDlRtm++
Q53Dff/e6Xl2hQ4MIBBT51C+b76Uvnyhg7d5p2NCeZ0Dr+6mue//F0DMWVHn
YAXSeBZq34k6B/eHVSLr1hc4KGwoypj4G2pfQ4FDtcg694cM9Q62XNcXF5QX
OLS+Dtwh97HOYZHrts9/cwog7ttT53AcZJFXgYNsVIr1/b11EHWhCH4ByICO
XDhfla1xqvP0LIg9avVwPtC1Ty+0IPhgcyfVO+wHeufunCyIv7bXOwBd+bbm
cpaDIsi9Z+sdgL4Xav6SBQnHR/UON899D37MmQ3x59N6iD+YsiHh96Ie4o7f
WRB3Pq6HhNPJLIi6G/XQ+MiC+O9cvUMYHzAAo6HqD9c7+IDUf8100L+rwta4
v94B5Gyl9ZkQ9++Aul8/E2KfEDQ+lRB8dUOONTK3ch0AX6j2uw==
                    
                    "], CompressedData["
1:eJxTTMoPSmViYGBQBGIQ/Xjp7CMKp6ocqkXWuT9MKXSISrG+77+9yuFtjb1p
XE6hg3DzgVMLF1Y5eDysEllXWejw6ZJvksCsKod3IPmmQof7/r3T8/qqHNxB
8v2FDse8zTsdp1Q5LHLd9vnvBKj8viqHByC6qxCij6vaAWTthrpCh9znv1d+
tIDyewodMiYCbU6udgC7aw9Uf0e1g3a72M1zTwsdrla8VDPcA+VfLHRYBtJ3
o9qhCuT+Y4UQd3+rdjj0VSOm/0Chww651teB/6odZEEeO1wI8adQjcMFpds/
685A/WNRA1HPUwRRb1IDcb9CkYMWyB79Goh+yyKHTseEpxdcaiD6zIog7gis
gfhfugji/uwaB17dTXPfPy90YACBsBpIuCyDhq9qjcNxEH9SoYMd1/XFBbw1
UH8i3A/2J5BvueVE2b7z1Q5AV+2Qmwj1z4JqiHlzCiHunlHtMFmCJYxvNlR9
M9S/rdDwDK2GmBsG1c9XDYlPT2h4AuN/ep5Q8wFg/AMAyiz3BA==
                    
                    "], {{436.72299999999996`, 290.289}, {435.117, 291.484}, {
                    431.72299999999996`, 297.59799999999996`}, {431.594, 
                    299.543}, {431.47999999999996`, 301.21099999999996`}, {
                    431.754, 301.72299999999996`}, {432.84400000000005`, 
                    301.895}, {434.754, 302.191}, {435.633, 300.809}, {
                    437.10200000000003`, 295.22299999999996`}, {438.305, 
                    290.64500000000004`}, {438.18, 289.199}, {436.727, 
                    290.289}}}]}}}}}}}}}}}}}}, AspectRatio -> Automatic, 
                  ImageSize -> {{128}, {85}}, 
                  PlotRange -> {{0., 720.}, {0., 480.}}], ",", 
                 GraphicsBox[{{{{{{{
                    Thickness[0.001388888888888889], {{{{{{{
                    Thickness[0.001388888888888889], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {0., 480.}, {720., 480.}, {720., 
                    0.}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     480.}, {720., 480.}, {720., 160.}, {0., 
                    160.}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.8078430000000001, 0.06666670000000002, 0.14902], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     480.}, {720., 480.}, {720., 320.}, {0., 
                    320.}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0., 0.478431, 0.23921600000000004`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{216., 292.}, {
                    199.93, 242.547}, {230.363, 232.656}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{216., 292.}, {
                    232.07, 242.547}, {201.637, 232.656}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{265.453, 
                    256.07}, {213.453, 256.07}, {213.453, 224.07}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{265.453, 
                    256.07}, {223.38700000000003`, 225.504}, {204.578, 
                    251.395}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{166.547, 
                    256.07}, {208.61299999999997`, 225.504}, {
                    227.42200000000003`, 251.395}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{166.547, 
                    256.07}, {218.547, 256.07}, {218.547, 224.07}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{246.566, 
                    197.93}, {230.496, 247.38700000000003`}, {200.062, 
                    237.496}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{246.566, 
                    197.93}, {204.496, 228.496}, {223.305, 254.383}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{185.434, 
                    197.93}, {227.504, 228.496}, {208.695, 254.383}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{185.434, 
                    197.93}, {201.504, 247.38700000000003`}, {
                    231.93800000000002`, 237.496}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{504., 292.}, {
                    487.92999999999995`, 242.547}, {518.3629999999999, 
                    232.656}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{504., 292.}, {
                    520.07, 242.547}, {489.637, 232.656}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{553.453, 
                    256.07}, {501.453, 256.07}, {501.453, 224.07}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{553.453, 
                    256.07}, {511.387, 225.504}, {492.578, 251.395}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{454.547, 
                    256.07}, {496.613, 225.504}, {515.4219999999999, 
                    251.395}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{454.547, 
                    256.07}, {506.547, 256.07}, {506.547, 224.07}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    534.5659999999999, 197.93}, {518.496, 
                    247.38700000000003`}, {488.062, 237.496}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    534.5659999999999, 197.93}, {492.4959999999999, 
                    228.496}, {511.305, 254.383}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    473.43399999999997`, 197.93}, {515.504, 228.496}, {
                    496.695, 254.383}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    473.43399999999997`, 197.93}, {489.504, 
                    247.38700000000003`}, {519.938, 237.496}}}]}}}}}}}}}}}}}},
                   AspectRatio -> Automatic, ImageSize -> {{128}, {85}}, 
                  PlotRange -> {{0., 720.}, {0., 480.}}], ",", 
                 GraphicsBox[{{{{{{{
                    Thickness[0.0010416666666666667`], {{{{{{{
                    FaceForm[{
                    RGBColor[0., 0.4, 0.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {0., 480.}, {960., 480.}, {960., 
                    0.}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     480.}, {960., 480.}, {960., 137.14499999999998`}, {0., 
                    137.14499999999998`}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0.8, 0., 0.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     480.}, {960., 480.}, {960., 342.855}, {0., 
                    342.855}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0.972549, 0.764706, 0.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIZIGYC4k7HhKcXztQ4PF46+4jCmTyHi0q3f9a9qnHg
ur64wNYo38Fyy4myfdq1Dq2vA3fIZeY7LHLd9vlvSi1EvU++wzFv807HebUO
IGOU9PMdtgKVzz9V61BoCzThQJ7Dff/e6XlnaiHiXgi+/l0VtkbGLAeFDUUZ
E43rMPgw9SDjE0zr4OZZgdyTWAe3L26XJw/T7DpU91ypg7vXAGSuaD3cP+X7
5kvpG9fD/RuVYn3fP7je4ZtGTP+h3nyIuFO9A4jaYFYAcS9bPcQdnQUOy0Di
p+ocPl3yTRK4U+DAAAJpdRB38xdC+Axo/Fm1cD7YPtNauH6w+M8auPmyIAV7
a+D2g+k1NXD3occXAG2yx5Q=
                    "]]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4h1yra8DxWod3tXYm8a9ynfIff575UenWodC
W67ri//kOzzw752eV1TrAOQV2H7Kd2AAgTm1DvvnS+nfPZPvINx84NTCo7UO
YXy6m+Yuz3cAmrZD7mWtg+WWE2X70qHqGeoc9oHUS+Q7VImsc38oVgeXB9tr
VQfXD1aeUgc3X3FDUcbE3jq4/ZMlWML49tbB3efxEGjiyzq4+8H6H9VB1OkW
QPQfrXPQbhe7eS6xACI+uw7ijrYCh0NfNWL6C+ocQNa/X13g8BZkjkWdwyLX
bZ//HiiAux/GFwL593gtnA9yRkF/LVw/OPxSauHmg8PPqhZuP9g4uVq4+9DD
HwAHcqwN
                    "]]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0.972549, 0.764706, 0.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4vv+vdPzztQ6WG45UbZve7aDwV0VtsajtQ6t
rwN3yMlmO4DlV9Q6gKTnt2U5KGwoyphYWetQLbLO/SFXlsOy2UcUNnjVOjgm
PL2g1J/p8HgpUICr1uFtjb1pnF4mRP3BGoj89wyHRa7bPv+tqHGQjUqxvr8/
A6Jfo8aB6/riAttNGQ4XlG7/rLtT7XDc27zT8UKGww45oEsmVEPk32U4HPqq
EdPvUe0gA9JvnunAq7tp7nv+agd1Q441MosyHWxBCu9XOWwFuXddhsP0PKHm
AyVVDoUgiTfpDrG7PHmYvlc6xIHoxekO5fvmS+lXVjrog/wdme4wWYIljO91
hYNLd87z353pEH83VED8q5QB4a+ocAjlA1rMnOrg/rBKZN3/Kog9y1Ih7tWp
dmAAgQ1Q976odnAC+V86DRIubbUOqz5e8k26kQZx7/9ah5vnvgc/ZsxyAADR
07hx
                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYCYoUNRRkTjescLLecKNu3PdvhotLtn3VWdQ6t
rwN3yMlmO4Dlw+scQNLz27Ic7vv3Ts9rq3OoFlnn/pAryyEqxfq+/9Y6B8eE
pxeU+jMdZEECX+sc3tbYm8bpZULU29VD5L9nOMTu8uRhaq+HqNufAdF/vd6B
6/riAttNGQ4z8oSaDwg2OBz3Nu90vJDhsKTAluu6eQNE/l2GgxzIYdENDjIg
jeaZDpUv1Qw5Khoc1A051sgsynR4WAV02IQGh60g967LgNBHGxwKgcYsfpPu
cAHkP5ZGhziQOxanOxwBedC50UH/rgpbY2S6w7bPf69UdDU6uHTnPP/dme6w
dDZQxf5GiH+VMiD81Y0OoXy6m+YypzrE9B/6qtHQ4DAd5O5lqRD3ZjY4MIDA
Bqh7uRscnED+l05zEG4+cGphZZ3Dqo+XfJNupDkAdcf0M9Q53Dz3PfgxY5YD
AAodtds=
                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, {{{451.777, 177.38700000000003`}, {
                    446.551, 166.10899999999998`}, {436.10900000000004`, 
                    164.172}, {426.977, 173.277}, {426.977, 173.277}, {
                    430.648, 175.871}, {434.578, 176.586}, {
                    433.84400000000005`, 179.72299999999998`}, {435.355, 
                    184.062}, {437.484, 186.406}, {439.719, 184.883}, {
                    442.83599999999996`, 181.82000000000002`}, {443.629, 
                    178.266}, {449.133, 178.977}, {451.777, 
                    177.38700000000003`}, {451.777, 177.38700000000003`}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, {{{492.64500000000004`, 178.664}, {
                    485.65200000000004`, 168.38700000000003`}, {
                    475.03499999999997`, 168.176}, {467.508, 
                    178.64499999999998`}, {467.508, 178.64499999999998`}, {
                    471.551, 180.605}, {475.547, 180.672}, {475.328, 
                    183.88700000000003`}, {477.527, 187.92200000000003`}, {
                    480.012, 189.89100000000002`}, {481.965, 188.02}, {
                    484.543, 184.496}, {484.746, 180.85500000000002`}, {
                    490.29699999999997`, 180.664}, {492.64500000000004`, 
                    178.664}, {492.64500000000004`, 178.664}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, {{{533.172, 173.26999999999998`}, {
                    524.605, 164.26999999999998`}, {514.094, 165.789}, {
                    508.371, 177.344}, {508.371, 177.344}, {512.6800000000001,
                     178.621}, {516.633, 178.035}, {516.9409999999999, 
                    181.242}, {519.766, 184.86700000000002`}, {522.539, 
                    186.40200000000002`}, {524.164, 184.242}, {526.133, 
                    180.344}, {525.738, 176.71899999999997`}, {
                    531.1840000000001, 175.625}, {533.172, 
                    173.26999999999998`}, {533.172, 
                    173.26999999999998`}}}]}}}}}}}, {{{{{{{
                    RGBColor[0.972549, 0.764706, 0.], 
                    Thickness[0.011428571875], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{413.484, 
                    152.23000000000002`}, {456.58599999999996`, 
                    165.05900000000003`}, {503.414, 165.05900000000003`}, {
                    546.516, 152.23000000000002`}}}, 
                    CurveClosed -> {0}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[0.972549, 0.764706, 0.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{480., 332.57}, {490.078, 301.559}, {463.695, 
                    320.727}, {496.305, 320.727}, {469.92199999999997`, 
                    301.559}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{432., 319.71099999999996`}, {442.078, 288.699}, {
                    415.695, 307.863}, {448.305, 307.863}, {
                    421.92199999999997`, 288.699}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{396.863, 284.57}, {406.93799999999993`, 
                    253.559}, {380.559, 272.727}, {413.16400000000004`, 
                    272.727}, {386.78499999999997`, 253.559}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{384., 236.57}, {394.078, 205.559}, {367.695, 
                    224.727}, {400.305, 224.727}, {373.92199999999997`, 
                    205.559}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{528., 319.71099999999996`}, {517.9219999999999, 
                    288.699}, {544.305, 307.863}, {511.695, 307.863}, {
                    538.0780000000001, 288.699}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{563.137, 284.57}, {553.0619999999999, 253.559}, {
                    579.4409999999999, 272.727}, {546.8359999999999, 
                    272.727}, {573.215, 253.559}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{576., 236.57}, {565.9219999999999, 205.559}, {
                    592.305, 224.727}, {559.695, 224.727}, {586.0780000000001,
                     205.559}}}]}}}}}}}}}}}}}}, AspectRatio -> Automatic, 
                  ImageSize -> {{128}, {85}}, 
                  PlotRange -> {{0., 960.}, {0., 480.}}], ",", 
                 GraphicsBox[{{{{{{{
                    Thickness[0.0010416666666666667`], {{{{{{{
                    FaceForm[{
                    RGBColor[0., 0.619608, 0.286275], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     480.}, {960., 480.}, {960., 320.}, {0., 
                    320.}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     320.}, {960., 320.}, {960., 160.}, {0., 
                    160.}}}]}}}}}}}, {{{{{{{
                    Thickness[0.0010416666666666667`], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     160.}, {960., 160.}, {960., 0.}, {0., 
                    0.}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.8078430000000001, 0.06666670000000002, 0.14902], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     480.}, {240., 480.}, {240., 0.}, {0., 
                    0.}}}]}}}}}}}}}}}}}}, AspectRatio -> Automatic, 
                  ImageSize -> {{128}, {85}}, 
                  PlotRange -> {{0., 960.}, {0., 480.}}], ",", 
                 GraphicsBox[{{{{{{{
                    Thickness[0.001388888888888889], {{{{{{{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {0., 480.}, {720., 480.}, {720., 
                    0.}}}]}}}}}}}, {{{{{{{
                    FaceForm[{
                    RGBColor[
                    0.8078430000000001, 0.06666670000000002, 0.14902], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     480.}, {720., 480.}, {720., 320.}, {0., 
                    320.}}}]}}}}}}}, {{{{{{{
                    Thickness[0.001388888888888889], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     160.}, {720., 160.}, {720., 0.}, {0., 
                    0.}}}]}}}}}}}}}}}}}}, AspectRatio -> Automatic, 
                  ImageSize -> {{128}, {85}}, 
                  PlotRange -> {{0., 720.}, {0., 480.}}]}], "}"}]}], "}"}]], 
        "ExerciseOutput", Selectable -> False, Copyable -> False, Editable -> 
        False, ShowCellBracket -> False]]], " "}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Center}}},
   GridBoxBackground->{"Columns" -> {{
        RGBColor[1, 1, 1]}}},
   GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{1}}}],
  FrameMargins->0]], "ExerciseOutput",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellFrame->{{1, 1}, {1, 1}},
 ShowCellBracket->False,
 CellFrameColor->RGBColor[0.85, 0.85, 0.85],
 LineBreakWithin->
  Automatic,ExpressionUUID->"75de5721-e697-483c-90bd-bc145d970409"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Make raster images of the letters of the alphabet at size 20, then make a \
graph of the 2 nearest neighbors of each one.",
 StyleBox[ButtonBox["\[NonBreakingSpace]\[RightGuillemet]",
  Appearance->None,
  Evaluator->Automatic,
  Method->"Preemptive",
  ButtonFunction:>(SelectionMove[
     ButtonNotebook[], All, ButtonCell, AutoScroll -> False]; 
   FrontEndExecute[
     FrontEndToken[
      ButtonNotebook[], "OpenCloseGroup"]])],
  FontColor->RGBColor[1, 0.501961, 0]]
}], "Exercise",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellDingbat->Cell[
  "22.13", "ExerciseNumber", FontColor -> 
   RGBColor[0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]],
 ShowCellBracket->
  False,ExpressionUUID->"1e08a798-a622-4a19-8a63-70661e9e2624"],

Cell[BoxData[
 PaneBox[GridBox[{
    {" ", 
     StyleBox[
      RowBox[{"Expected", " ", 
       RowBox[{"output", ":"}]}],
      Editable->False,
      Selectable->False,
      StripOnInput->False,
      FontColor->RGBColor[0.45, 0.45, 0.45]], " "},
    {" ", 
     InterpretationBox[Cell[BoxData[
       GraphicsBox[
        NamespaceBox["NetworkGraphics",
         DynamicModuleBox[{Typeset`graph = HoldComplete[
           Graph[{
             Graphics[
              Raster[CompressedData["
1:eJztUCEOwyAUJZnbEeZ2gd5hJyCZrqrArhZbVzlXh0JVVaFqUJgaDAaLQVRg
KhCMlqZt1gtM7CU/4fH+f4/PvXg9iwsA4BbrGms+h5/GZE2Edf4kaAbBhgfp
+XvmSE5RtHWW7iGuMMy2NihcCF6VC+lMcnK8QUkdDipR05rkZb6pIfRVsssq
wpRxfhTwoEa3vsF74DF3g3da8pY0NUZLZ77OejsItS+q6bJZMybWLo+EJWVc
MLLujlnqH2WHvlNzbo+/5o0eWNdSSmjHzRT+OOMDUFN0aA==
               "], {{0, 0}, {
               10, 26}}, {0, 255}, ColorFunction -> RGBColor], 
              ImageSize -> {10, 26}, PlotRange -> {{0, 10}, {0, 26}}], 
             Graphics[
              Raster[CompressedData["
1:eJzVkK0OwyAUhUkm9wZzewHegSdoMo2qwO4d6pB1OBRqClWFqZrBYGYmMDMI
xExFRUf/abNmmdtOchO4+bj3HI7p+ZTuAACHUPtQ7bn5P1XuEeSqZffGSYhD
siwBkxBTdgIMw2MfYkISOFzyq18AmNlhtBekgyB1EZAwM2/1JeoIaesZyHXk
68k7Q7n2XwDxisZRtAYg4X56b3gfVrllTIiZVIWgQ1AsqvU/xCJ6nNgDmJu6
skpehBBFaXw9G3qXYqGPgGZtZrQN3CVFENHCbgG/rxcTMKJ1
               "], {{0, 0}, {
               11, 26}}, {0, 255}, ColorFunction -> RGBColor], 
              ImageSize -> {11, 26}, PlotRange -> {{0, 11}, {0, 26}}], 
             Graphics[
              Raster[CompressedData["
1:eJxTTMoPSmJmYGCQAmJOIAax/w8+8Ondq6dPn7569wlZ8N2l1TF6DAjgX7n3
zjuQ4uvzYUKOBZWVMY5gpt6M//9fTYSw/Sc++A4x4/uh+RO33/n+/9MJf7Ci
jU9/o1n9HWKa44x3GK76fmcp2LQZnzCk/r87BLbK/wSm3O87BRDHNe1FKH8F
Nf7V3iao09M6tx86tLQzDchu2vsUIntpaSUDKmja/gBh8LsHh7ZvXLp06eqN
e++8+k44WIcjAAC1RVCo
               "], {{0, 0}, {9, 26}}, {0, 255}, 
               ColorFunction -> RGBColor], ImageSize -> {9, 26}, 
              PlotRange -> {{0, 9}, {0, 26}}], 
             Graphics[
              Raster[CompressedData["
1:eJxTTMoPSmJmYGCQAmJuIAax/w8t8P3d0wdPnz599R2b5KXVTQwIkLZ043x/
Bgb/GWchsg+2V0Jl9GIKCmLg6vwnQhQ8bdIDSxasfgfR8O5Skz+Sgk9nwTzH
Q++QnHNpBlzB9+tLwfITkeT/f0JS8PvBapANep24FPz/dAJi4YlP2K34//sO
xA+OTXvhCh5sb0Lyxf+nMG86FszYe2j7jMoYVG+CTDk0A+F9jHCAOezBpe2r
Vy9dunrvpafvLs3HVICiGNmRtFHw/c5qfz29yqXXcSkYbAAALCuqpQ==
               "], {{
               0, 0}, {11, 26}}, {0, 255}, ColorFunction -> RGBColor], 
              ImageSize -> {11, 26}, PlotRange -> {{0, 11}, {0, 26}}], 
             Graphics[
              Raster[CompressedData["
1:eJztj68OgzAQxpvM7RHm9gK8w56AZI+AwK4Wi0PicKgqVBWqZgpTU4OpwNRU
nKipQLD+gSyQzU/sl1xyvfvuvt41e9yzE0Lo4uLswufLz2NAK4eG+VCXDN/Q
myStKTehZWW3VW9FVRV5GvJi8k1dh6kEt2rbaNUopjBqhiBN+cEsykYSnRra
93Sld2lHhbZWEvSFaoAFnsEWC7AGPMYaVvpazWGZJQ7KkqnNDeI/ibTuoVgZ
V+GGCjHUeRKOa2AVz7zFe8+Uqd0NRo2MdoSQnnH96bo/LxRCezk=
               "], {{0, 
               0}, {10, 26}}, {0, 255}, ColorFunction -> RGBColor], 
              ImageSize -> {10, 26}, PlotRange -> {{0, 10}, {0, 26}}], 
             Graphics[
              Raster[CompressedData["
1:eJxTTMoPSmJmYGCQAmI2IAax/9MXfL++FGgpQ8zSTzCRT5dmgEQcZ7zDEMFU
Q54I3OTf1+eDRPznfwdzX53dWBmjBxJh0GuaOHHG6rNnOyFcOOj8/endpY1N
YHbBiTsPHjwFGfYdYjLMHLC/5kPUXAcJ/QaLPSiAGqKnBwvnT9c3xsBsQAmW
799/UxKsqAAAAhZjvA==
               "], {{0, 0}, {6, 26}}, {0, 255}, 
               ColorFunction -> RGBColor], ImageSize -> {6, 26}, 
              PlotRange -> {{0, 6}, {0, 26}}], 
             Graphics[
              Raster[CompressedData["
1:eJzlUKFuxDAMjTS2TxjbD/Qf/AWVhosOlK609FhhWVlRUFBRUEhQSEhISUBI
SUFASEHBLU66m069SeN7kqU4z8/P9vvl8+PyQgh5i/EaA9+3P2APi1GSI4TS
8xr2O2VoQ06oex6iyk0pK5qeGesWZwXtivQFndwsw3c1PTgtPBXUNy8Bpa1e
Qwg+YZ3FkNgyFjpWnX0TOUZW9WW2ruo7mp6KFQcPI5Ig/PNlHW9RCWUJUADU
7TD7n313S0+WlTpa5c5xO5EEntY4L/Q6swOypQpHq20eMX9gCbWHl5cdth7n
bMvbtDo03DirWHXc8ToJk8fq4Ok5uu/BN6slo5RNXBt7wP1ygv+KL3qCMuA=

               "], {{0, 0}, {10, 26}}, {0, 255}, ColorFunction -> RGBColor], 
              ImageSize -> {10, 26}, PlotRange -> {{0, 10}, {0, 26}}], 
             Graphics[
              Raster[CompressedData["
1:eJxTTMoPSmJmYGCQAmJuIAax/w8XcH1+GtA7aUuvw0U+XZoBFImZcQnCvTQj
Bsj1n3gWTQFcZEAUfL80H4sCmJuB4M7qAkwFDI5N1z9BFZyd6A8SQFMAVjRx
9fbVMwognMrtD5AVOBZUwtWBgF7Tg9//Mdzw6tD21UuXLl298cS733AXYfEF
GiCo4OwMFDdjgjsbOx31HDthbh6KAABYzr7r
               "], {{0, 0}, {11, 26}}, {
               0, 255}, ColorFunction -> RGBColor], ImageSize -> {11, 26}, 
              PlotRange -> {{0, 11}, {0, 26}}], 
             Graphics[
              Raster[CompressedData["
1:eJxTTMoPSmJmYGCQAmJWIAax/9MSXJ+fBrQibel1CPfSjBgg13/iWTpzz050
BHL1YNzfn17duXPn1aff/+H8V3De96UgrQwMMUu/g7ifZjiCuY4zPkGkX905
tPfQnXcwvVQCAEeBPoI=
               "], {{0, 0}, {5, 26}}, {0, 255}, 
               ColorFunction -> RGBColor], ImageSize -> {5, 26}, 
              PlotRange -> {{0, 5}, {0, 26}}], 
             Graphics[
              Raster[CompressedData["
1:eJxTTMoPSmJmYGCQAmI2IAax/2OAd08fXL906dL1B79hIjEMMBAz/x1Y5NCM
pqbOSj2w2IxLn+B6z070B6u6BBe5NAOk23/i2SEkcnaiI1BErxMh8vvTqzt3
7rz6BA8SsNArZIHvSyHBFLP0O1Tk0wxHsIjjDHgA/X5359DeQ3feIZlDAwAA
n1xr8A==
               "], {{0, 0}, {6, 26}}, {0, 255}, ColorFunction -> 
               RGBColor], ImageSize -> {6, 26}, 
              PlotRange -> {{0, 6}, {0, 26}}], 
             Graphics[
              Raster[CompressedData["
1:eJxTTMoPSmJmYGCQAmIuIAax/w9NcH1+GtDxaUuvw0UugUUY/OeD2DNiQMyJ
Z6FyT7frgeQYJp54B5d17DwBlvu0FMRj0CvY/htiDlgWKLD0zu9PJzrB7Jiz
n2C2QGURoHL7U4Qb0GTTln5HcjNENm3G9qUFIOfopS39hCHrPwPoozsFYN2O
nYfQZcE++g3zTuXGO5iyQPDqEMTZDPMvfcISGkAFD+5cv37n6affWGWRAX7Z
szP8Qe7EIXtnY6ejnmPn9gdYZQchAADMKmsX
               "], {{0, 0}, {10, 26}}, {
               0, 255}, ColorFunction -> RGBColor], ImageSize -> {10, 26}, 
              PlotRange -> {{0, 10}, {0, 26}}], 
             Graphics[
              Raster[CompressedData["
1:eJxTTMoPSmJmYGCQAmJWIAax/1Mb/P706sGDp+++/wax76xmAAPHiWeB3Evz
YyC8jXe+g7gzQFz/GZcgGqFcsMrBwz07wx/ufiC4s7HTUc+xc/sD6gYaAAHv
MDA=
               "], {{0, 0}, {5, 26}}, {0, 255}, ColorFunction -> 
               RGBColor], ImageSize -> {5, 26}, 
              PlotRange -> {{0, 5}, {0, 26}}], 
             Graphics[
              Raster[CompressedData["
1:eJztkaEOgzAQhi/ZE8zO7QV4hz4ByTQKgR12dg5ZV3eqClWFws9gamoqZjCI
iRoEgrUNFNTC3LLwJ5f0vv5/L23P6fWSHgDgZOtoy63HXd9LYWafLuMqEImJ
JUyaGRjuAKCaiGSuj2mzRDyhzStEWAxrsiWCPxLBbREmZ8Mg8si/WP85AqTQ
k8VQ4kCUYTdFdO4AlLNjioAfVQp2iyEoSlCIIot8k4SxjT+U5DlZrEDulazp
CkCCy2UH0yql3b+aZy1Kznn10IPf6jtVWYC8btpx19/pDWR9XYk=
               "], {{0, 
               0}, {17, 26}}, {0, 255}, ColorFunction -> RGBColor], 
              ImageSize -> {17, 26}, PlotRange -> {{0, 17}, {0, 26}}], 
             Graphics[
              Raster[CompressedData["
1:eJxTTMoPSmJmYGCQAmJuIAax/w8XcH1+GtA7aUuvw0U+XZoBFImZcQnCvTQj
Bsj1n3gWTQFcZEAUfL80H4sCmJuB4M7qAkwFDI5N1z9BFZyd6A8SQFMAVjRx
9fbVMwognMrtD2DqHUEGVjb5MyABvaYHv6EG/v709Pr1O+9Ajnt6YvvqpUuX
rt544t3v/6OAJAAA/yPYVg==
               "], {{0, 0}, {11, 26}}, {0, 255}, 
               ColorFunction -> RGBColor], ImageSize -> {11, 26}, 
              PlotRange -> {{0, 11}, {0, 26}}], 
             Graphics[
              Raster[CompressedData["
1:eJztkKEOwyAURUkm9wdz+wH+oV9AMo2qqB22tq6yrq4KVVWFqqnC1NTUVMxg
EAgMoqJjsNJtqZlcspuQAOfe9x6c4+slPgAATnYd7Xrsl1+TVlIIIZXZQSNL
IAiCKONyDtRM9UoQSYMRceW5KpG7wJV8BsbUmWDauurc8YjJraMZSpdJBmPt
1PFCvc5kBuy7aDuAM8B819BrO0IXrdU2iQYGwzwRP2PZr3huiOOY+pBgqX8Y
zqqua4sk8sdq0CHCKwLelbPp4zONnNqmppQ2jN/0vPz1pe6vbsT7
               "], {{0, 
               0}, {11, 26}}, {0, 255}, ColorFunction -> RGBColor], 
              ImageSize -> {11, 26}, PlotRange -> {{0, 11}, {0, 26}}], 
             Graphics[
              Raster[CompressedData["
1:eJxTTMoPSmJmYGCQAmJuIAax/xMFfn///v03bulLM2KARvnPuERAwcSzFCqI
mX8d6JhXT4Hg1XdsChgYHP0dGWDAccbeBxgKgEAvJi3NXw/KmXjiHbICvZgZ
D6BGv1uaBlak1/kKlzffHQLbprfxwW8cvvg03x9sy9l3JChACclXnY7oCoAB
8Qqu/9J8iGf3vkLzZsz8jXu3L+2EejRmKcRbZyc6QoIAEU4gkAYLhv+/Pz29
fv3OJyDj3Z29G1cvXbp0+6Gz7/BE/yjABgAnJqWw
               "], {{0, 0}, {11, 
               26}}, {0, 255}, ColorFunction -> RGBColor], 
              ImageSize -> {11, 26}, PlotRange -> {{0, 11}, {0, 26}}], 
             Graphics[
              Raster[CompressedData["
1:eJxTTMoPSmJmYGCQAmJuIAax/5MJfn8Hgt84pT9dmgE03HHiWfwK/ElV8P3d
0wdPnz59BbT59/X5aAourW5igAO9tM5Kf2QFD7ZXwqRiCgpi4AphCp426YEl
C1a/g2h4d6nJXw+h4NNZkHEMjofeITkHyZHfry8Fy09Ekkfxxe8Hq0HG6XXi
UvD/0wmwFf4nPmG34v/vOxA/ODbthSt4sL0J2ZtPYd50LJix99D2GZUxqN4E
mXJoBsL7iADrPIES/g8ubV+9eunS1XvP3vn+//vTO9cfvPqOK7JGASYAAA9L
rNM=
               "], {{0, 0}, {11, 26}}, {0, 255}, ColorFunction -> 
               RGBColor], ImageSize -> {11, 26}, 
              PlotRange -> {{0, 11}, {0, 26}}], 
             Graphics[
              Raster[CompressedData["
1:eJxTTMoPSmJmYGCQAmJ2IAax/w80uD4/DeiMtKXXkQUvzYgBCvpPPEsfQcfO
E5iCQOGND35jCAKBXtOMGRMnbgQKnp3oCOTHNDU5wqSAgr8/Pb1+/c4nIOPV
9Y2rly5dvZeMYBk8AADIm9Yh
               "], {{0, 0}, {7, 26}}, {0, 255}, 
               ColorFunction -> RGBColor], ImageSize -> {7, 26}, 
              PlotRange -> {{0, 7}, {0, 26}}], 
             Graphics[
              Raster[CompressedData["
1:eJxTTMoPSmJmYGCQAmIOIAax/w8s+P391VMQePfpO1Tk+9ONEwsYkIBj2vwH
v/9fmugI4cYUNE2cWAnlVG7//+lSU1rTiacw7a/2gqQcJ6JZc3ZpJQOy+PdX
h1bPiNGDWdF5CCj27uxSPSRrO1efBRn6/VIMRMC/cuPZO9/hRn466w92wQOY
wHeIF75fAoszFMzYfv362dWdaUD2xBOvgDLXV1cyoIKm7VDdn55e37tx9dKl
SzduP/Hg02+qB/PgAQC7PPiW
               "], {{0, 0}, {8, 26}}, {0, 255}, 
               ColorFunction -> RGBColor], ImageSize -> {8, 26}, 
              PlotRange -> {{0, 8}, {0, 26}}], 
             Graphics[
              Raster[CompressedData["
1:eJxTTMoPSmJmYGCQAmJ2IAax/9Md/P707unTp6/effoNE7m+sYkBBhwnngUr
uhQD4funFcQ4Fqy+DhT7fmc1SESv6SmSaZ8uzQArm/EJU9CRBMF3yC68Ph9s
5vzvcBduX1oZo8cAsX7ijImdEw89/d7JgA6aTrz79OrVg0sbHUG8ghMPHty5
fucVxJTvYB+huvP/97P+QMGY+SiCgwwAAFKhuT4=
               "], {{0, 0}, {7, 
               26}}, {0, 255}, ColorFunction -> RGBColor], 
              ImageSize -> {7, 26}, PlotRange -> {{0, 7}, {0, 26}}], 
             Graphics[
              Raster[CompressedData["
1:eJxTTMoPSmJmYGCQAmJuIAax/w8p8OnV0wdPn7569x2r5MYmfwYY8G/aeP3E
fCBjxtlPEOlXhzqhco4xMf56cJUTz76DKDg7EaRdr2AjxPTrG5vQFFyaEQPk
Vm5/CrfyRKc/pgK4jXARNAVw7oAoODvREcjtPIFQgCby/dWD69fvIIfx93dP
gSKvPv3GFuyjADsAAOt53ho=
               "], {{0, 0}, {11, 26}}, {0, 255}, 
               ColorFunction -> RGBColor], ImageSize -> {11, 26}, 
              PlotRange -> {{0, 11}, {0, 26}}], 
             Graphics[
              Raster[CompressedData["
1:eJxTTMoPSmJmYGCQAmJOIAax/w8dcKLTnwEE0i59R5X4faeAAQqaDr1Clnl3
diIDHKStRtL3e3uBHlBs4qETnY5A2v/EJ5jM97MxINUxl37/PwuWK9j4ACLz
dHsTxJzf//9/ujQDxPafD9b3aSlYT9Pep0jucdwLdMurvY5g087CzD/UBBJI
W3r9ztI0uGkQADXTceJEkNMYKvci++UOWDXDqwd3rl9/8On3f2TwDixIZrAO
ZQAAtf1PUg==
               "], {{0, 0}, {9, 26}}, {0, 255}, ColorFunction -> 
               RGBColor], ImageSize -> {9, 26}, 
              PlotRange -> {{0, 9}, {0, 26}}], 
             Graphics[
              Raster[CompressedData["
1:eJztUaGShDAM7cz6+4Bz+wP8A1/AzGrUitqrXYtD4upQqCoUCnOqpgaDqajB
IBCYigouCWWX/YFTm5nOpC8vb16S6/3ndr8wxr7hfcHDfPvE8psyjKKfIuIH
TkhW6TNx6guCWfLoAiHrIFmEyvlFDJ1IDvzhCDIyjwhL+yc1WIGcvCqw2jpQ
XSS4Sbgs+dmStw225o0bMRHttHmNtrmaxnq3tDPHmpPzAVIUFd1kJLXaLQwZ
quyW1po+lVlBvgFqInYbjfVQlVRVYGnVlGZIBNGGH4MIG16jcWUXXRJRrnE4
FXcg2rd1caUL3E9amecedlEwe5zA0FEyP7txtLM/ncvZdyTMgNjT+j/xv/EH
JeF/Zw==
               "], {{0, 0}, {14, 26}}, {0, 255}, ColorFunction -> 
               RGBColor], ImageSize -> {14, 26}, 
              PlotRange -> {{0, 14}, {0, 26}}], 
             Graphics[
              Raster[CompressedData["
1:eJxTTMoPSmJmYGCQAmJOIAax/w96MN8f6EyGgtV34CKHOsFCaavfnZ0IYjD4
n/gEEv9+fSmYy7D0+vf//39vL9ADsvWaDv3//64TxGRw7DwBNeLTCbARjgUF
MWAdlXeQbHywvZIBBmZc+oTimu+XYqAyeie+o8icgLgKDByb9iJ0QF3luP36
iQKE84DgKcRV/hNBrnqwGizpOPHV//93lkIsKbjzG2LG0yYwP2bpne+vHly/
fv3BK4TdEJGn71BdMzIAAB4dQJ4=
               "], {{0, 0}, {9, 26}}, {0, 255}, 
               ColorFunction -> RGBColor], ImageSize -> {9, 26}, 
              PlotRange -> {{0, 9}, {0, 26}}], 
             Graphics[
              Raster[CompressedData["
1:eJzlUKEOgzAQbTK1X5jbD/AP/YIm01WI2WFnccg6HAqFmkJhpmYwmBpEDaai
AlNRsXFXWGia7Af2kkuu967v3t05vV3SAyHktMRxCcjfP+CsMdoYGzNDyQgi
YYUM+XmoKWXU06ya489WZgmQojcxqZ8FcNcmnurG2ou+ItEuXwfeWxXO6jnZ
wAMz6nGHmmhK6KCd/jJGoFitloEcvYyrmDeQ5BrMNJDT0uwM8GrA15TDgkk7
uc0A5oheMOyU3sD+RFaiPi0E3idrp73fDJfQapRynF2wpYFiuPh/4ANLGjIw

               "], {{0, 0}, {9, 26}}, {0, 255}, ColorFunction -> RGBColor], 
              ImageSize -> {9, 26}, PlotRange -> {{0, 9}, {0, 26}}], 
             Graphics[
              Raster[CompressedData["
1:eJxTTMoPSmJmYGCQAmJOIAax/w96cGl+DAMI6OkxIIOYs5/+31mdBuPq+Ts6
6oEBA0MaUOr//1cTHcESlXuxGPp0O8S0zkOvMCXvrC6AW4EBPs33B0umrf6O
KfnuENhOhsrtTzElXx3qBEv6H3oHFdg4YyIYzJg/owDmrfkgOz+dQPUs1I+H
QHK/Xz24gwGe/iY+QIcRAAA9XkVU
               "], {{0, 0}, {9, 26}}, {0, 255}, 
               ColorFunction -> RGBColor], ImageSize -> {9, 26}, 
              PlotRange -> {{0, 9}, {0, 26}}]}, {Null, 
             SparseArray[
             Automatic, {26, 26}, 0, {
              1, {{0, 5, 7, 10, 12, 15, 17, 19, 22, 25, 27, 29, 32, 35, 39, 
                49, 52, 55, 58, 60, 62, 64, 66, 69, 73, 75, 78}, {{5}, {15}, {
                19}, {24}, {26}, {8}, {16}, {5}, {15}, {18}, {15}, {17}, {
                1}, {3}, {15}, {9}, {12}, {16}, {17}, {2}, {11}, {14}, {6}, {
                10}, {12}, {9}, {12}, {8}, {24}, {6}, {9}, {10}, {14}, {15}, {
                18}, {8}, {13}, {15}, {21}, {1}, {3}, {4}, {5}, {13}, {14}, {
                16}, {17}, {19}, {21}, {2}, {7}, {15}, {4}, {7}, {15}, {3}, {
                13}, {20}, {1}, {15}, {18}, {26}, {14}, {15}, {23}, {25}, {
                22}, {24}, {25}, {1}, {11}, {23}, {26}, {22}, {23}, {1}, {
                20}, {24}}}, Pattern}]}, {VertexLabels -> {All}}]]}, 
          TagBox[GraphicsGroupBox[{
             {Hue[0.6, 0.7, 0.5], Opacity[0.7], 
              {Arrowheads[0.], 
               ArrowBox[{{4.480586225893454, -2.1799474327571104`}, {
                5.24106218708406, -1.7053517372530047`}}, 
                0.052478423386308704`]}, 
              {Arrowheads[0.], 
               ArrowBox[{{4.480586225893454, -2.1799474327571104`}, {
                5.965103790399207, -2.322804916942334}}, 
                0.052478423386308704`]}, 
              {Arrowheads[0.], 
               ArrowBox[{{4.480586225893454, -2.1799474327571104`}, {
                5.0936340590684415`, -2.420075315170594}}, 
                0.052478423386308704`]}, 
              {Arrowheads[0.], 
               ArrowBox[{{4.480586225893454, -2.1799474327571104`}, {
                3.188711043481997, -2.607258064208528}}, 
                0.052478423386308704`]}, 
              {Arrowheads[0.], 
               ArrowBox[{{4.480586225893454, -2.1799474327571104`}, {
                3.6377999851433134`, -1.7113080955758058`}}, 
                0.052478423386308704`]}, 
              {Arrowheads[0.], 
               ArrowBox[{{5.9670411273594635`, -4.1970993673568024`}, {
                4.986842693816599, -3.8493818994661746`}}, 
                0.052478423386308704`]}, 
              {Arrowheads[0.], 
               ArrowBox[{{5.9670411273594635`, -4.1970993673568024`}, {
                6.688016643036104, -3.4306867425232745`}}, 
                0.052478423386308704`]}, 
              {Arrowheads[0.], 
               ArrowBox[{{5.765111935171046, -1.2491283642487643`}, {
                5.24106218708406, -1.7053517372530047`}}, 
                0.052478423386308704`]}, 
              {Arrowheads[0.], 
               ArrowBox[{{5.765111935171046, -1.2491283642487643`}, {
                5.965103790399207, -2.322804916942334}}, 
                0.052478423386308704`]}, 
              {Arrowheads[0.], 
               ArrowBox[{{5.765111935171046, -1.2491283642487643`}, {
                5.104055270980713, -0.873614448207543}}, 
                0.052478423386308704`]}, 
              {Arrowheads[0.], 
               ArrowBox[{{6.993329162302756, -1.9673148421060902`}, {
                5.965103790399207, -2.322804916942334}}, 
                0.052478423386308704`]}, 
              {Arrowheads[0.], 
               ArrowBox[{{6.993329162302756, -1.9673148421060902`}, {
                7.159884817394166, -2.5216057257948923`}}, 
                0.052478423386308704`]}, 
              {Arrowheads[0.], 
               ArrowBox[{{5.24106218708406, -1.7053517372530047`}, {
                5.965103790399207, -2.322804916942334}}, 
                0.052478423386308704`]}, 
              {Arrowheads[0.], 
               ArrowBox[{{2.6759265588555055`, -6.249358300161733}, {
                1.7418955435258285`, -6.683451809207677}}, 
                0.052478423386308704`]}, 
              {Arrowheads[0.], 
               ArrowBox[{{2.6759265588555055`, -6.249358300161733}, {
                1.7432975798106856`, -5.813881410030349}}, 
                0.052478423386308704`]}, 
              {Arrowheads[0.], 
               ArrowBox[{{7.6166730800090585`, -3.214984670662907}, {
                6.688016643036104, -3.4306867425232745`}}, 
                0.052478423386308704`]}, 
              {Arrowheads[0.], 
               ArrowBox[{{7.6166730800090585`, -3.214984670662907}, {
                7.159884817394166, -2.5216057257948923`}}, 
                0.052478423386308704`]}, 
              {Arrowheads[0.], 
               ArrowBox[{{4.986842693816599, -3.8493818994661746`}, {
                3.8469892110659623`, -3.53684531368041}}, 
                0.052478423386308704`]}, 
              {Arrowheads[0.], 
               ArrowBox[{{4.986842693816599, -3.8493818994661746`}, {
                5.58583296100195, -2.9515506391145854`}}, 
                0.052478423386308704`]}, 
              {Arrowheads[0.], 
               ArrowBox[{{1.7418955435258285`, -6.683451809207677}, {
                0.8083910213367735, -6.248705306432721}}, 
                0.052478423386308704`]}, 
              {Arrowheads[0.], 
               ArrowBox[{{1.7418955435258285`, -6.683451809207677}, {
                1.7432975798106856`, -5.813881410030349}}, 
                0.052478423386308704`]}, 
              {Arrowheads[0.], 
               ArrowBox[{{0.8083910213367735, -6.248705306432721}, {
                1.7432975798106856`, -5.813881410030349}}, 
                0.052478423386308704`]}, 
              {Arrowheads[0.], 
               ArrowBox[{{3.8469892110659623`, -3.53684531368041}, {
                3.188711043481997, -2.607258064208528}}, 
                0.052478423386308704`]}, 
              {Arrowheads[0.], 
               ArrowBox[{{5.6639631469428835`, -1.8248221865674927`}, {
                5.58583296100195, -2.9515506391145854`}}, 
                0.052478423386308704`]}, 
              {Arrowheads[0.], 
               ArrowBox[{{5.6639631469428835`, -1.8248221865674927`}, {
                5.965103790399207, -2.322804916942334}}, 
                0.052478423386308704`]}, 
              {Arrowheads[0.], 
               ArrowBox[{{5.6639631469428835`, -1.8248221865674927`}, {
                5.104055270980713, -0.873614448207543}}, 
                0.052478423386308704`]}, 
              {Arrowheads[0.], 
               ArrowBox[{{5.58583296100195, -2.9515506391145854`}, {
                5.965103790399207, -2.322804916942334}}, 
                0.052478423386308704`]}, 
              {Arrowheads[0.], 
               ArrowBox[{{5.58583296100195, -2.9515506391145854`}, {
                6.215695355594371, -2.9999022913880706`}}, 
                0.052478423386308704`]}, 
              {Arrowheads[0.], 
               ArrowBox[{{5.965103790399207, -2.322804916942334}, {
                6.688016643036104, -3.4306867425232745`}}, 
                0.052478423386308704`]}, 
              {Arrowheads[0.], 
               ArrowBox[{{5.965103790399207, -2.322804916942334}, {
                7.159884817394166, -2.5216057257948923`}}, 
                0.052478423386308704`]}, 
              {Arrowheads[0.], 
               ArrowBox[{{5.965103790399207, -2.322804916942334}, {
                5.0936340590684415`, -2.420075315170594}}, 
                0.052478423386308704`]}, 
              {Arrowheads[0.], 
               ArrowBox[{{5.965103790399207, -2.322804916942334}, {
                6.215695355594371, -2.9999022913880706`}}, 
                0.052478423386308704`]}, 
              {Arrowheads[0.], 
               ArrowBox[{{5.104055270980713, -0.873614448207543}, {
                4.0893098597948505`, -0.8083910213367735}}, 
                0.052478423386308704`]}, 
              {Arrowheads[0.], 
               ArrowBox[{{4.0893098597948505`, -0.8083910213367735}, {
                3.6377999851433134`, -1.7113080955758058`}}, 
                0.052478423386308704`]}, 
              {Arrowheads[0.], 
               ArrowBox[{{0.8717601828076917, -3.141020808670527}, {
                1.7291396205785987`, -2.7951101292059013`}}, 
                0.052478423386308704`]}, 
              {Arrowheads[0.], 
               ArrowBox[{{0.8717601828076917, -3.141020808670527}, {
                0.8083910213367735, -2.6803280265469525`}}, 
                0.052478423386308704`]}, 
              {Arrowheads[0.], 
               ArrowBox[{{1.7291396205785987`, -2.7951101292059013`}, {
                3.188711043481997, -2.607258064208528}}, 
                0.052478423386308704`]}, 
              {Arrowheads[0.], 
               ArrowBox[{{1.7291396205785987`, -2.7951101292059013`}, {
                0.8083910213367735, -2.6803280265469525`}}, 
                0.052478423386308704`]}, 
              {Arrowheads[0.], 
               ArrowBox[{{3.188711043481997, -2.607258064208528}, {
                3.6377999851433134`, -1.7113080955758058`}}, 
                0.052478423386308704`]}}, 
             {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
              0.7]}], {
               DiskBox[{4.480586225893454, -2.1799474327571104}, 
                0.052478423386308704], InsetBox[
                FormBox[
                 GraphicsBox[RasterBox[CompressedData["
1:eJztUCEOwyAUJZnbEeZ2gd5hJyCZrqrArhZbVzlXh0JVVaFqUJgaDAaLQVRg
KhCMlqZt1gtM7CU/4fH+f4/PvXg9iwsA4BbrGms+h5/GZE2Edf4kaAbBhgfp
+XvmSE5RtHWW7iGuMMy2NihcCF6VC+lMcnK8QUkdDipR05rkZb6pIfRVsssq
wpRxfhTwoEa3vsF74DF3g3da8pY0NUZLZ77OejsItS+q6bJZMybWLo+EJWVc
MLLujlnqH2WHvlNzbo+/5o0eWNdSSmjHzRT+OOMDUFN0aA==
                   "], {{0, 
                   0}, {10, 26}}, {0, 255},
                   ColorFunction->RGBColor],
                  ImageSize->{10, 26},
                  PlotRange->{{0, 10}, {0, 26}}],
                 TraditionalForm], 
                Offset[{2, 2}, {4.533064649279763, -2.1274690093708015}], 
                ImageScaled[{0, 0}],
                BaseStyle->"Graphics"]}, {
               DiskBox[{5.9670411273594635, -4.1970993673568024}, 
                0.052478423386308704], InsetBox[
                FormBox[
                 GraphicsBox[RasterBox[CompressedData["
1:eJzVkK0OwyAUhUkm9wZzewHegSdoMo2qwO4d6pB1OBRqClWFqZrBYGYmMDMI
xExFRUf/abNmmdtOchO4+bj3HI7p+ZTuAACHUPtQ7bn5P1XuEeSqZffGSYhD
siwBkxBTdgIMw2MfYkISOFzyq18AmNlhtBekgyB1EZAwM2/1JeoIaesZyHXk
68k7Q7n2XwDxisZRtAYg4X56b3gfVrllTIiZVIWgQ1AsqvU/xCJ6nNgDmJu6
skpehBBFaXw9G3qXYqGPgGZtZrQN3CVFENHCbgG/rxcTMKJ1
                   "], {{0, 
                   0}, {11, 26}}, {0, 255},
                   ColorFunction->RGBColor],
                  ImageSize->{11, 26},
                  PlotRange->{{0, 11}, {0, 26}}],
                 TraditionalForm], 
                Offset[{2, 2}, {6.019519550745772, -4.1446209439704935}], 
                ImageScaled[{0, 0}],
                BaseStyle->"Graphics"]}, {
               DiskBox[{5.765111935171046, -1.2491283642487643}, 
                0.052478423386308704], InsetBox[
                FormBox[
                 GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGCQAmJOIAax/w8+8Ondq6dPn7569wlZ8N2l1TF6DAjgX7n3
zjuQ4uvzYUKOBZWVMY5gpt6M//9fTYSw/Sc++A4x4/uh+RO33/n+/9MJf7Ci
jU9/o1n9HWKa44x3GK76fmcp2LQZnzCk/r87BLbK/wSm3O87BRDHNe1FKH8F
Nf7V3iao09M6tx86tLQzDchu2vsUIntpaSUDKmja/gBh8LsHh7ZvXLp06eqN
e++8+k44WIcjAAC1RVCo
                   "], {{0, 0}, {9, 26}}, {0, 255},
                   ColorFunction->RGBColor],
                  ImageSize->{9, 26},
                  PlotRange->{{0, 9}, {0, 26}}],
                 TraditionalForm], 
                Offset[{2, 2}, {5.8175903585573545, -1.1966499408624556}], 
                ImageScaled[{0, 0}],
                BaseStyle->"Graphics"]}, {
               DiskBox[{6.993329162302756, -1.9673148421060902}, 
                0.052478423386308704], InsetBox[
                FormBox[
                 GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGCQAmJuIAax/w8t8P3d0wdPnz599R2b5KXVTQwIkLZ043x/
Bgb/GWchsg+2V0Jl9GIKCmLg6vwnQhQ8bdIDSxasfgfR8O5Skz+Sgk9nwTzH
Q++QnHNpBlzB9+tLwfITkeT/f0JS8PvBapANep24FPz/dAJi4YlP2K34//sO
xA+OTXvhCh5sb0Lyxf+nMG86FszYe2j7jMoYVG+CTDk0A+F9jHCAOezBpe2r
Vy9dunrvpafvLs3HVICiGNmRtFHw/c5qfz29yqXXcSkYbAAALCuqpQ==
                   
                   "], {{0, 0}, {11, 26}}, {0, 255},
                   ColorFunction->RGBColor],
                  ImageSize->{11, 26},
                  PlotRange->{{0, 11}, {0, 26}}],
                 TraditionalForm], 
                Offset[{2, 2}, {7.045807585689065, -1.9148364187197815}], 
                ImageScaled[{0, 0}],
                BaseStyle->"Graphics"]}, {
               DiskBox[{5.24106218708406, -1.7053517372530047}, 
                0.052478423386308704], InsetBox[
                FormBox[
                 GraphicsBox[RasterBox[CompressedData["
1:eJztj68OgzAQxpvM7RHm9gK8w56AZI+AwK4Wi0PicKgqVBWqZgpTU4OpwNRU
nKipQLD+gSyQzU/sl1xyvfvuvt41e9yzE0Lo4uLswufLz2NAK4eG+VCXDN/Q
myStKTehZWW3VW9FVRV5GvJi8k1dh6kEt2rbaNUopjBqhiBN+cEsykYSnRra
93Sld2lHhbZWEvSFaoAFnsEWC7AGPMYaVvpazWGZJQ7KkqnNDeI/ibTuoVgZ
V+GGCjHUeRKOa2AVz7zFe8+Uqd0NRo2MdoSQnnH96bo/LxRCezk=
                   "], {{
                   0, 0}, {10, 26}}, {0, 255},
                   ColorFunction->RGBColor],
                  ImageSize->{10, 26},
                  PlotRange->{{0, 10}, {0, 26}}],
                 TraditionalForm], 
                Offset[{2, 2}, {5.293540610470369, -1.652873313866696}], 
                ImageScaled[{0, 0}],
                BaseStyle->"Graphics"]}, {
               DiskBox[{2.6759265588555055, -6.249358300161733}, 
                0.052478423386308704], InsetBox[
                FormBox[
                 GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGCQAmI2IAax/9MXfL++FGgpQ8zSTzCRT5dmgEQcZ7zDEMFU
Q54I3OTf1+eDRPznfwdzX53dWBmjBxJh0GuaOHHG6rNnOyFcOOj8/endpY1N
YHbBiTsPHjwFGfYdYjLMHLC/5kPUXAcJ/QaLPSiAGqKnBwvnT9c3xsBsQAmW
799/UxKsqAAAAhZjvA==
                   "], {{0, 0}, {6, 26}}, {0, 255},
                   ColorFunction->RGBColor],
                  ImageSize->{6, 26},
                  PlotRange->{{0, 6}, {0, 26}}],
                 TraditionalForm], 
                Offset[{2, 2}, {2.7284049822418144, -6.196879876775424}], 
                ImageScaled[{0, 0}],
                BaseStyle->"Graphics"]}, {
               DiskBox[{7.6166730800090585, -3.214984670662907}, 
                0.052478423386308704], InsetBox[
                FormBox[
                 GraphicsBox[RasterBox[CompressedData["
1:eJzlUKFuxDAMjTS2TxjbD/Qf/AWVhosOlK609FhhWVlRUFBRUEhQSEhISUBI
SUFASEHBLU66m069SeN7kqU4z8/P9vvl8+PyQgh5i/EaA9+3P2APi1GSI4TS
8xr2O2VoQ06oex6iyk0pK5qeGesWZwXtivQFndwsw3c1PTgtPBXUNy8Bpa1e
Qwg+YZ3FkNgyFjpWnX0TOUZW9WW2ruo7mp6KFQcPI5Ig/PNlHW9RCWUJUADU
7TD7n313S0+WlTpa5c5xO5EEntY4L/Q6swOypQpHq20eMX9gCbWHl5cdth7n
bMvbtDo03DirWHXc8ToJk8fq4Ok5uu/BN6slo5RNXBt7wP1ygv+KL3qCMuA=

                   "], {{0, 0}, {10, 26}}, {0, 255},
                   ColorFunction->RGBColor],
                  ImageSize->{10, 26},
                  PlotRange->{{0, 10}, {0, 26}}],
                 TraditionalForm], 
                Offset[{2, 2}, {7.669151503395367, -3.162506247276598}], 
                ImageScaled[{0, 0}],
                BaseStyle->"Graphics"]}, {
               DiskBox[{4.986842693816599, -3.8493818994661746}, 
                0.052478423386308704], InsetBox[
                FormBox[
                 GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGCQAmJuIAax/w8XcH1+GtA7aUuvw0U+XZoBFImZcQnCvTQj
Bsj1n3gWTQFcZEAUfL80H4sCmJuB4M7qAkwFDI5N1z9BFZyd6A8SQFMAVjRx
9fbVMwognMrtD5AVOBZUwtWBgF7Tg9//Mdzw6tD21UuXLl298cS733AXYfEF
GiCo4OwMFDdjgjsbOx31HDthbh6KAABYzr7r
                   "], {{0, 0}, {11, 
                   26}}, {0, 255},
                   ColorFunction->RGBColor],
                  ImageSize->{11, 26},
                  PlotRange->{{0, 11}, {0, 26}}],
                 TraditionalForm], 
                Offset[{2, 2}, {5.039321117202908, -3.7969034760798657}], 
                ImageScaled[{0, 0}],
                BaseStyle->"Graphics"]}, {
               DiskBox[{1.7418955435258285, -6.683451809207677}, 
                0.052478423386308704], InsetBox[
                FormBox[
                 GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGCQAmJWIAax/9MSXJ+fBrQibel1CPfSjBgg13/iWTpzz050
BHL1YNzfn17duXPn1aff/+H8V3De96UgrQwMMUu/g7ifZjiCuY4zPkGkX905
tPfQnXcwvVQCAEeBPoI=
                   "], {{0, 0}, {5, 26}}, {0, 255},
                   ColorFunction->RGBColor],
                  ImageSize->{5, 26},
                  PlotRange->{{0, 5}, {0, 26}}],
                 TraditionalForm], 
                Offset[{2, 2}, {1.7943739669121372, -6.630973385821368}], 
                ImageScaled[{0, 0}],
                BaseStyle->"Graphics"]}, {
               DiskBox[{0.8083910213367735, -6.248705306432721}, 
                0.052478423386308704], InsetBox[
                FormBox[
                 GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGCQAmI2IAax/2OAd08fXL906dL1B79hIjEMMBAz/x1Y5NCM
pqbOSj2w2IxLn+B6z070B6u6BBe5NAOk23/i2SEkcnaiI1BErxMh8vvTqzt3
7rz6BA8SsNArZIHvSyHBFLP0O1Tk0wxHsIjjDHgA/X5359DeQ3feIZlDAwAA
n1xr8A==
                   "], {{0, 0}, {6, 26}}, {0, 255},
                   ColorFunction->RGBColor],
                  ImageSize->{6, 26},
                  PlotRange->{{0, 6}, {0, 26}}],
                 TraditionalForm], 
                Offset[{2, 2}, {0.8608694447230822, -6.196226883046412}], 
                ImageScaled[{0, 0}],
                BaseStyle->"Graphics"]}, {
               DiskBox[{3.8469892110659623, -3.53684531368041}, 
                0.052478423386308704], InsetBox[
                FormBox[
                 GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGCQAmIuIAax/w9NcH1+GtDxaUuvw0UugUUY/OeD2DNiQMyJ
Z6FyT7frgeQYJp54B5d17DwBlvu0FMRj0CvY/htiDlgWKLD0zu9PJzrB7Jiz
n2C2QGURoHL7U4Qb0GTTln5HcjNENm3G9qUFIOfopS39hCHrPwPoozsFYN2O
nYfQZcE++g3zTuXGO5iyQPDqEMTZDPMvfcISGkAFD+5cv37n6affWGWRAX7Z
szP8Qe7EIXtnY6ejnmPn9gdYZQchAADMKmsX
                   "], {{0, 0}, {10, 
                   26}}, {0, 255},
                   ColorFunction->RGBColor],
                  ImageSize->{10, 26},
                  PlotRange->{{0, 10}, {0, 26}}],
                 TraditionalForm], 
                Offset[{2, 2}, {3.8994676344522707, -3.484366890294101}], 
                ImageScaled[{0, 0}],
                BaseStyle->"Graphics"]}, {
               DiskBox[{1.7432975798106856, -5.813881410030349}, 
                0.052478423386308704], InsetBox[
                FormBox[
                 GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGCQAmJWIAax/1Mb/P706sGDp+++/wax76xmAAPHiWeB3Evz
YyC8jXe+g7gzQFz/GZcgGqFcsMrBwz07wx/ufiC4s7HTUc+xc/sD6gYaAAHv
MDA=
                   "], {{0, 0}, {5, 26}}, {0, 255},
                   ColorFunction->RGBColor],
                  ImageSize->{5, 26},
                  PlotRange->{{0, 5}, {0, 26}}],
                 TraditionalForm], 
                Offset[{2, 2}, {1.7957760031969943, -5.76140298664404}], 
                ImageScaled[{0, 0}],
                BaseStyle->"Graphics"]}, {
               DiskBox[{5.6639631469428835, -1.8248221865674927}, 
                0.052478423386308704], InsetBox[
                FormBox[
                 GraphicsBox[RasterBox[CompressedData["
1:eJztkaEOgzAQhi/ZE8zO7QV4hz4ByTQKgR12dg5ZV3eqClWFws9gamoqZjCI
iRoEgrUNFNTC3LLwJ5f0vv5/L23P6fWSHgDgZOtoy63HXd9LYWafLuMqEImJ
JUyaGRjuAKCaiGSuj2mzRDyhzStEWAxrsiWCPxLBbREmZ8Mg8si/WP85AqTQ
k8VQ4kCUYTdFdO4AlLNjioAfVQp2iyEoSlCIIot8k4SxjT+U5DlZrEDulazp
CkCCy2UH0yql3b+aZy1Kznn10IPf6jtVWYC8btpx19/pDWR9XYk=
                   "], {{
                   0, 0}, {17, 26}}, {0, 255},
                   ColorFunction->RGBColor],
                  ImageSize->{17, 26},
                  PlotRange->{{0, 17}, {0, 26}}],
                 TraditionalForm], 
                Offset[{2, 2}, {5.716441570329192, -1.772343763181184}], 
                ImageScaled[{0, 0}],
                BaseStyle->"Graphics"]}, {
               DiskBox[{5.58583296100195, -2.9515506391145854}, 
                0.052478423386308704], InsetBox[
                FormBox[
                 GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGCQAmJuIAax/w8XcH1+GtA7aUuvw0U+XZoBFImZcQnCvTQj
Bsj1n3gWTQFcZEAUfL80H4sCmJuB4M7qAkwFDI5N1z9BFZyd6A8SQFMAVjRx
9fbVMwognMrtD2DqHUEGVjb5MyABvaYHv6EG/v709Pr1O+9Ajnt6YvvqpUuX
rt544t3v/6OAJAAA/yPYVg==
                   "], {{0, 0}, {11, 26}}, {0, 255},
                   ColorFunction->RGBColor],
                  ImageSize->{11, 26},
                  PlotRange->{{0, 11}, {0, 26}}],
                 TraditionalForm], 
                Offset[{2, 2}, {5.638311384388259, -2.8990722157282764}], 
                ImageScaled[{0, 0}],
                BaseStyle->"Graphics"]}, {
               DiskBox[{5.965103790399207, -2.322804916942334}, 
                0.052478423386308704], InsetBox[
                FormBox[
                 GraphicsBox[RasterBox[CompressedData["
1:eJztkKEOwyAURUkm9wdz+wH+oV9AMo2qqB22tq6yrq4KVVWFqqnC1NTUVMxg
EAgMoqJjsNJtqZlcspuQAOfe9x6c4+slPgAATnYd7Xrsl1+TVlIIIZXZQSNL
IAiCKONyDtRM9UoQSYMRceW5KpG7wJV8BsbUmWDauurc8YjJraMZSpdJBmPt
1PFCvc5kBuy7aDuAM8B819BrO0IXrdU2iQYGwzwRP2PZr3huiOOY+pBgqX8Y
zqqua4sk8sdq0CHCKwLelbPp4zONnNqmppQ2jN/0vPz1pe6vbsT7
                   "], {{
                   0, 0}, {11, 26}}, {0, 255},
                   ColorFunction->RGBColor],
                  ImageSize->{11, 26},
                  PlotRange->{{0, 11}, {0, 26}}],
                 TraditionalForm], 
                Offset[{2, 2}, {6.0175822137855155, -2.2703264935560252}], 
                ImageScaled[{0, 0}],
                BaseStyle->"Graphics"]}, {
               DiskBox[{6.688016643036104, -3.4306867425232745}, 
                0.052478423386308704], InsetBox[
                FormBox[
                 GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGCQAmJuIAax/xMFfn///v03bulLM2KARvnPuERAwcSzFCqI
mX8d6JhXT4Hg1XdsChgYHP0dGWDAccbeBxgKgEAvJi3NXw/KmXjiHbICvZgZ
D6BGv1uaBlak1/kKlzffHQLbprfxwW8cvvg03x9sy9l3JChACclXnY7oCoAB
8Qqu/9J8iGf3vkLzZsz8jXu3L+2EejRmKcRbZyc6QoIAEU4gkAYLhv+/Pz29
fv3OJyDj3Z29G1cvXbp0+6Gz7/BE/yjABgAnJqWw
                   "], {{0, 0}, {11, 
                   26}}, {0, 255},
                   ColorFunction->RGBColor],
                  ImageSize->{11, 26},
                  PlotRange->{{0, 11}, {0, 26}}],
                 TraditionalForm], 
                Offset[{2, 2}, {6.740495066422413, -3.3782083191369656}], 
                ImageScaled[{0, 0}],
                BaseStyle->"Graphics"]}, {
               DiskBox[{7.159884817394166, -2.5216057257948923}, 
                0.052478423386308704], InsetBox[
                FormBox[
                 GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGCQAmJuIAax/5MJfn8Hgt84pT9dmgE03HHiWfwK/ElV8P3d
0wdPnz59BbT59/X5aAourW5igAO9tM5Kf2QFD7ZXwqRiCgpi4AphCp426YEl
C1a/g2h4d6nJXw+h4NNZkHEMjofeITkHyZHfry8Fy09Ekkfxxe8Hq0HG6XXi
UvD/0wmwFf4nPmG34v/vOxA/ODbthSt4sL0J2ZtPYd50LJix99D2GZUxqN4E
mXJoBsL7iADrPIES/g8ubV+9eunS1XvP3vn+//vTO9cfvPqOK7JGASYAAA9L
rNM=
                   "], {{0, 0}, {11, 26}}, {0, 255},
                   ColorFunction->RGBColor],
                  ImageSize->{11, 26},
                  PlotRange->{{0, 11}, {0, 26}}],
                 TraditionalForm], 
                Offset[{2, 2}, {7.2123632407804745, -2.469127302408584}], 
                ImageScaled[{0, 0}],
                BaseStyle->"Graphics"]}, {
               DiskBox[{5.104055270980713, -0.873614448207543}, 
                0.052478423386308704], InsetBox[
                FormBox[
                 GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGCQAmJ2IAax/w80uD4/DeiMtKXXkQUvzYgBCvpPPEsfQcfO
E5iCQOGND35jCAKBXtOMGRMnbgQKnp3oCOTHNDU5wqSAgr8/Pb1+/c4nIOPV
9Y2rly5dvZeMYBk8AADIm9Yh
                   "], {{0, 0}, {7, 26}}, {0, 255},
                   ColorFunction->RGBColor],
                  ImageSize->{7, 26},
                  PlotRange->{{0, 7}, {0, 26}}],
                 TraditionalForm], 
                Offset[{2, 2}, {5.156533694367022, -0.8211360248212343}], 
                ImageScaled[{0, 0}],
                BaseStyle->"Graphics"]}, {
               DiskBox[{5.0936340590684415, -2.420075315170594}, 
                0.052478423386308704], InsetBox[
                FormBox[
                 GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGCQAmIOIAax/w8s+P391VMQePfpO1Tk+9ONEwsYkIBj2vwH
v/9fmugI4cYUNE2cWAnlVG7//+lSU1rTiacw7a/2gqQcJ6JZc3ZpJQOy+PdX
h1bPiNGDWdF5CCj27uxSPSRrO1efBRn6/VIMRMC/cuPZO9/hRn466w92wQOY
wHeIF75fAoszFMzYfv362dWdaUD2xBOvgDLXV1cyoIKm7VDdn55e37tx9dKl
SzduP/Hg02+qB/PgAQC7PPiW
                   "], {{0, 0}, {8, 26}}, {0, 255},
                   ColorFunction->RGBColor],
                  ImageSize->{8, 26},
                  PlotRange->{{0, 8}, {0, 26}}],
                 TraditionalForm], 
                Offset[{2, 2}, {5.14611248245475, -2.3675968917842853}], 
                ImageScaled[{0, 0}],
                BaseStyle->"Graphics"]}, {
               DiskBox[{4.0893098597948505, -0.8083910213367735}, 
                0.052478423386308704], InsetBox[
                FormBox[
                 GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGCQAmJ2IAax/9Md/P707unTp6/effoNE7m+sYkBBhwnngUr
uhQD4funFcQ4Fqy+DhT7fmc1SESv6SmSaZ8uzQArm/EJU9CRBMF3yC68Ph9s
5vzvcBduX1oZo8cAsX7ijImdEw89/d7JgA6aTrz79OrVg0sbHUG8ghMPHty5
fucVxJTvYB+huvP/97P+QMGY+SiCgwwAAFKhuT4=
                   "], {{0, 0}, {7, 
                   26}}, {0, 255},
                   ColorFunction->RGBColor],
                  ImageSize->{7, 26},
                  PlotRange->{{0, 7}, {0, 26}}],
                 TraditionalForm], 
                Offset[{2, 2}, {4.141788283181159, -0.7559125979504648}], 
                ImageScaled[{0, 0}],
                BaseStyle->"Graphics"]}, {
               DiskBox[{6.215695355594371, -2.9999022913880706}, 
                0.052478423386308704], InsetBox[
                FormBox[
                 GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGCQAmJuIAax/w8p8OnV0wdPn7569x2r5MYmfwYY8G/aeP3E
fCBjxtlPEOlXhzqhco4xMf56cJUTz76DKDg7EaRdr2AjxPTrG5vQFFyaEQPk
Vm5/CrfyRKc/pgK4jXARNAVw7oAoODvREcjtPIFQgCby/dWD69fvIIfx93dP
gSKvPv3GFuyjADsAAOt53ho=
                   "], {{0, 0}, {11, 26}}, {0, 255},
                   ColorFunction->RGBColor],
                  ImageSize->{11, 26},
                  PlotRange->{{0, 11}, {0, 26}}],
                 TraditionalForm], 
                Offset[{2, 2}, {6.26817377898068, -2.9474238680017617}], 
                ImageScaled[{0, 0}],
                BaseStyle->"Graphics"]}, {
               DiskBox[{0.8717601828076917, -3.141020808670527}, 
                0.052478423386308704], InsetBox[
                FormBox[
                 GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGCQAmJOIAax/w8dcKLTnwEE0i59R5X4faeAAQqaDr1Clnl3
diIDHKStRtL3e3uBHlBs4qETnY5A2v/EJ5jM97MxINUxl37/PwuWK9j4ACLz
dHsTxJzf//9/ujQDxPafD9b3aSlYT9Pep0jucdwLdMurvY5g087CzD/UBBJI
W3r9ztI0uGkQADXTceJEkNMYKvci++UOWDXDqwd3rl9/8On3f2TwDixIZrAO
ZQAAtf1PUg==
                   "], {{0, 0}, {9, 26}}, {0, 255},
                   ColorFunction->RGBColor],
                  ImageSize->{9, 26},
                  PlotRange->{{0, 9}, {0, 26}}],
                 TraditionalForm], 
                Offset[{2, 2}, {0.9242386061940004, -3.088542385284218}], 
                ImageScaled[{0, 0}],
                BaseStyle->"Graphics"]}, {
               DiskBox[{1.7291396205785987, -2.7951101292059013}, 
                0.052478423386308704], InsetBox[
                FormBox[
                 GraphicsBox[RasterBox[CompressedData["
1:eJztUaGShDAM7cz6+4Bz+wP8A1/AzGrUitqrXYtD4upQqCoUCnOqpgaDqajB
IBCYigouCWWX/YFTm5nOpC8vb16S6/3ndr8wxr7hfcHDfPvE8psyjKKfIuIH
TkhW6TNx6guCWfLoAiHrIFmEyvlFDJ1IDvzhCDIyjwhL+yc1WIGcvCqw2jpQ
XSS4Sbgs+dmStw225o0bMRHttHmNtrmaxnq3tDPHmpPzAVIUFd1kJLXaLQwZ
quyW1po+lVlBvgFqInYbjfVQlVRVYGnVlGZIBNGGH4MIG16jcWUXXRJRrnE4
FXcg2rd1caUL3E9amecedlEwe5zA0FEyP7txtLM/ncvZdyTMgNjT+j/xv/EH
JeF/Zw==
                   "], {{0, 0}, {14, 26}}, {0, 255},
                   ColorFunction->RGBColor],
                  ImageSize->{14, 26},
                  PlotRange->{{0, 14}, {0, 26}}],
                 TraditionalForm], 
                Offset[{2, 2}, {1.7816180439649074, -2.7426317058195924}], 
                ImageScaled[{0, 0}],
                BaseStyle->"Graphics"]}, {
               DiskBox[{3.188711043481997, -2.607258064208528}, 
                0.052478423386308704], InsetBox[
                FormBox[
                 GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGCQAmJOIAax/w96MN8f6EyGgtV34CKHOsFCaavfnZ0IYjD4
n/gEEv9+fSmYy7D0+vf//39vL9ADsvWaDv3//64TxGRw7DwBNeLTCbARjgUF
MWAdlXeQbHywvZIBBmZc+oTimu+XYqAyeie+o8icgLgKDByb9iJ0QF3luP36
iQKE84DgKcRV/hNBrnqwGizpOPHV//93lkIsKbjzG2LG0yYwP2bpne+vHly/
fv3BK4TdEJGn71BdMzIAAB4dQJ4=
                   "], {{0, 0}, {9, 26}}, {0, 
                   255},
                   ColorFunction->RGBColor],
                  ImageSize->{9, 26},
                  PlotRange->{{0, 9}, {0, 26}}],
                 TraditionalForm], 
                Offset[{2, 2}, {3.241189466868306, -2.554779640822219}], 
                ImageScaled[{0, 0}],
                BaseStyle->"Graphics"]}, {
               DiskBox[{0.8083910213367735, -2.6803280265469525}, 
                0.052478423386308704], InsetBox[
                FormBox[
                 GraphicsBox[RasterBox[CompressedData["
1:eJzlUKEOgzAQbTK1X5jbD/AP/YIm01WI2WFnccg6HAqFmkJhpmYwmBpEDaai
AlNRsXFXWGia7Af2kkuu967v3t05vV3SAyHktMRxCcjfP+CsMdoYGzNDyQgi
YYUM+XmoKWXU06ya489WZgmQojcxqZ8FcNcmnurG2ou+ItEuXwfeWxXO6jnZ
wAMz6nGHmmhK6KCd/jJGoFitloEcvYyrmDeQ5BrMNJDT0uwM8GrA15TDgkk7
uc0A5oheMOyU3sD+RFaiPi0E3idrp73fDJfQapRynF2wpYFiuPh/4ANLGjIw

                   "], {{0, 0}, {9, 26}}, {0, 255},
                   ColorFunction->RGBColor],
                  ImageSize->{9, 26},
                  PlotRange->{{0, 9}, {0, 26}}],
                 TraditionalForm], 
                Offset[{2, 2}, {0.8608694447230822, -2.6278496031606435}], 
                ImageScaled[{0, 0}],
                BaseStyle->"Graphics"]}, {
               DiskBox[{3.6377999851433134, -1.7113080955758058}, 
                0.052478423386308704], InsetBox[
                FormBox[
                 GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGCQAmJOIAax/w96cGl+DAMI6OkxIIOYs5/+31mdBuPq+Ts6
6oEBA0MaUOr//1cTHcESlXuxGPp0O8S0zkOvMCXvrC6AW4EBPs33B0umrf6O
KfnuENhOhsrtTzElXx3qBEv6H3oHFdg4YyIYzJg/owDmrfkgOz+dQPUs1I+H
QHK/Xz24gwGe/iY+QIcRAAA9XkVU
                   "], {{0, 0}, {9, 26}}, {0, 
                   255},
                   ColorFunction->RGBColor],
                  ImageSize->{9, 26},
                  PlotRange->{{0, 9}, {0, 26}}],
                 TraditionalForm], 
                Offset[{2, 2}, {3.690278408529622, -1.658829672189497}], 
                ImageScaled[{0, 0}],
                BaseStyle->"Graphics"]}}}],
           MouseAppearanceTag["NetworkGraphics"]],
          AllowKernelInitialization->False]],
        DefaultBaseStyle->{
         "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
          Hue[0.8, 1., 0.6]},
        FormatType->TraditionalForm,
        FrameTicks->None,
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]]]], "ExerciseOutput",ExpressionUUID->
       "054bb684-2a7b-4f2a-b655-add1a8894107"],
      Apply[TextCell, 
       Cell[
        BoxData[
         GraphicsBox[
          NamespaceBox["NetworkGraphics", 
           DynamicModuleBox[{Typeset`graph = HoldComplete[
               Graph[{
                 Graphics[
                  Raster[CompressedData["
1:eJztUCEOwyAUJZnbEeZ2gd5hJyCZrqrArhZbVzlXh0JVVaFqUJgaDAaLQVRg
KhCMlqZt1gtM7CU/4fH+f4/PvXg9iwsA4BbrGms+h5/GZE2Edf4kaAbBhgfp
+XvmSE5RtHWW7iGuMMy2NihcCF6VC+lMcnK8QUkdDipR05rkZb6pIfRVsssq
wpRxfhTwoEa3vsF74DF3g3da8pY0NUZLZ77OejsItS+q6bJZMybWLo+EJWVc
MLLujlnqH2WHvlNzbo+/5o0eWNdSSmjHzRT+OOMDUFN0aA==
                   "], {{0, 
                   0}, {10, 26}}, {0, 255}, ColorFunction -> RGBColor], 
                  ImageSize -> {10, 26}, PlotRange -> {{0, 10}, {0, 26}}], 
                 Graphics[
                  Raster[CompressedData["
1:eJzVkK0OwyAUhUkm9wZzewHegSdoMo2qwO4d6pB1OBRqClWFqZrBYGYmMDMI
xExFRUf/abNmmdtOchO4+bj3HI7p+ZTuAACHUPtQ7bn5P1XuEeSqZffGSYhD
siwBkxBTdgIMw2MfYkISOFzyq18AmNlhtBekgyB1EZAwM2/1JeoIaesZyHXk
68k7Q7n2XwDxisZRtAYg4X56b3gfVrllTIiZVIWgQ1AsqvU/xCJ6nNgDmJu6
skpehBBFaXw9G3qXYqGPgGZtZrQN3CVFENHCbgG/rxcTMKJ1
                   "], {{0, 
                   0}, {11, 26}}, {0, 255}, ColorFunction -> RGBColor], 
                  ImageSize -> {11, 26}, PlotRange -> {{0, 11}, {0, 26}}], 
                 Graphics[
                  Raster[CompressedData["
1:eJxTTMoPSmJmYGCQAmJOIAax/w8+8Ondq6dPn7569wlZ8N2l1TF6DAjgX7n3
zjuQ4uvzYUKOBZWVMY5gpt6M//9fTYSw/Sc++A4x4/uh+RO33/n+/9MJf7Ci
jU9/o1n9HWKa44x3GK76fmcp2LQZnzCk/r87BLbK/wSm3O87BRDHNe1FKH8F
Nf7V3iao09M6tx86tLQzDchu2vsUIntpaSUDKmja/gBh8LsHh7ZvXLp06eqN
e++8+k44WIcjAAC1RVCo
                   "], {{0, 0}, {9, 26}}, {0, 255}, 
                   ColorFunction -> RGBColor], ImageSize -> {9, 26}, 
                  PlotRange -> {{0, 9}, {0, 26}}], 
                 Graphics[
                  Raster[CompressedData["
1:eJxTTMoPSmJmYGCQAmJuIAax/w8t8P3d0wdPnz599R2b5KXVTQwIkLZ043x/
Bgb/GWchsg+2V0Jl9GIKCmLg6vwnQhQ8bdIDSxasfgfR8O5Skz+Sgk9nwTzH
Q++QnHNpBlzB9+tLwfITkeT/f0JS8PvBapANep24FPz/dAJi4YlP2K34//sO
xA+OTXvhCh5sb0Lyxf+nMG86FszYe2j7jMoYVG+CTDk0A+F9jHCAOezBpe2r
Vy9dunrvpafvLs3HVICiGNmRtFHw/c5qfz29yqXXcSkYbAAALCuqpQ==
                   
                   "], {{0, 0}, {11, 26}}, {0, 255}, ColorFunction -> 
                   RGBColor], ImageSize -> {11, 26}, 
                  PlotRange -> {{0, 11}, {0, 26}}], 
                 Graphics[
                  Raster[CompressedData["
1:eJztj68OgzAQxpvM7RHm9gK8w56AZI+AwK4Wi0PicKgqVBWqZgpTU4OpwNRU
nKipQLD+gSyQzU/sl1xyvfvuvt41e9yzE0Lo4uLswufLz2NAK4eG+VCXDN/Q
myStKTehZWW3VW9FVRV5GvJi8k1dh6kEt2rbaNUopjBqhiBN+cEsykYSnRra
93Sld2lHhbZWEvSFaoAFnsEWC7AGPMYaVvpazWGZJQ7KkqnNDeI/ibTuoVgZ
V+GGCjHUeRKOa2AVz7zFe8+Uqd0NRo2MdoSQnnH96bo/LxRCezk=
                   "], {{
                   0, 0}, {10, 26}}, {0, 255}, ColorFunction -> RGBColor], 
                  ImageSize -> {10, 26}, PlotRange -> {{0, 10}, {0, 26}}], 
                 Graphics[
                  Raster[CompressedData["
1:eJxTTMoPSmJmYGCQAmI2IAax/9MXfL++FGgpQ8zSTzCRT5dmgEQcZ7zDEMFU
Q54I3OTf1+eDRPznfwdzX53dWBmjBxJh0GuaOHHG6rNnOyFcOOj8/endpY1N
YHbBiTsPHjwFGfYdYjLMHLC/5kPUXAcJ/QaLPSiAGqKnBwvnT9c3xsBsQAmW
799/UxKsqAAAAhZjvA==
                   "], {{0, 0}, {6, 26}}, {0, 255}, 
                   ColorFunction -> RGBColor], ImageSize -> {6, 26}, 
                  PlotRange -> {{0, 6}, {0, 26}}], 
                 Graphics[
                  Raster[CompressedData["
1:eJzlUKFuxDAMjTS2TxjbD/Qf/AWVhosOlK609FhhWVlRUFBRUEhQSEhISUBI
SUFASEHBLU66m069SeN7kqU4z8/P9vvl8+PyQgh5i/EaA9+3P2APi1GSI4TS
8xr2O2VoQ06oex6iyk0pK5qeGesWZwXtivQFndwsw3c1PTgtPBXUNy8Bpa1e
Qwg+YZ3FkNgyFjpWnX0TOUZW9WW2ruo7mp6KFQcPI5Ig/PNlHW9RCWUJUADU
7TD7n313S0+WlTpa5c5xO5EEntY4L/Q6swOypQpHq20eMX9gCbWHl5cdth7n
bMvbtDo03DirWHXc8ToJk8fq4Ok5uu/BN6slo5RNXBt7wP1ygv+KL3qCMuA=

                   "], {{0, 0}, {10, 26}}, {0, 255}, ColorFunction -> 
                   RGBColor], ImageSize -> {10, 26}, 
                  PlotRange -> {{0, 10}, {0, 26}}], 
                 Graphics[
                  Raster[CompressedData["
1:eJxTTMoPSmJmYGCQAmJuIAax/w8XcH1+GtA7aUuvw0U+XZoBFImZcQnCvTQj
Bsj1n3gWTQFcZEAUfL80H4sCmJuB4M7qAkwFDI5N1z9BFZyd6A8SQFMAVjRx
9fbVMwognMrtD5AVOBZUwtWBgF7Tg9//Mdzw6tD21UuXLl298cS733AXYfEF
GiCo4OwMFDdjgjsbOx31HDthbh6KAABYzr7r
                   "], {{0, 0}, {11, 
                   26}}, {0, 255}, ColorFunction -> RGBColor], 
                  ImageSize -> {11, 26}, PlotRange -> {{0, 11}, {0, 26}}], 
                 Graphics[
                  Raster[CompressedData["
1:eJxTTMoPSmJmYGCQAmJWIAax/9MSXJ+fBrQibel1CPfSjBgg13/iWTpzz050
BHL1YNzfn17duXPn1aff/+H8V3De96UgrQwMMUu/g7ifZjiCuY4zPkGkX905
tPfQnXcwvVQCAEeBPoI=
                   "], {{0, 0}, {5, 26}}, {0, 255}, 
                   ColorFunction -> RGBColor], ImageSize -> {5, 26}, 
                  PlotRange -> {{0, 5}, {0, 26}}], 
                 Graphics[
                  Raster[CompressedData["
1:eJxTTMoPSmJmYGCQAmI2IAax/2OAd08fXL906dL1B79hIjEMMBAz/x1Y5NCM
pqbOSj2w2IxLn+B6z070B6u6BBe5NAOk23/i2SEkcnaiI1BErxMh8vvTqzt3
7rz6BA8SsNArZIHvSyHBFLP0O1Tk0wxHsIjjDHgA/X5359DeQ3feIZlDAwAA
n1xr8A==
                   "], {{0, 0}, {6, 26}}, {0, 255}, ColorFunction -> 
                   RGBColor], ImageSize -> {6, 26}, 
                  PlotRange -> {{0, 6}, {0, 26}}], 
                 Graphics[
                  Raster[CompressedData["
1:eJxTTMoPSmJmYGCQAmIuIAax/w9NcH1+GtDxaUuvw0UugUUY/OeD2DNiQMyJ
Z6FyT7frgeQYJp54B5d17DwBlvu0FMRj0CvY/htiDlgWKLD0zu9PJzrB7Jiz
n2C2QGURoHL7U4Qb0GTTln5HcjNENm3G9qUFIOfopS39hCHrPwPoozsFYN2O
nYfQZcE++g3zTuXGO5iyQPDqEMTZDPMvfcISGkAFD+5cv37n6affWGWRAX7Z
szP8Qe7EIXtnY6ejnmPn9gdYZQchAADMKmsX
                   "], {{0, 0}, {10, 
                   26}}, {0, 255}, ColorFunction -> RGBColor], 
                  ImageSize -> {10, 26}, PlotRange -> {{0, 10}, {0, 26}}], 
                 Graphics[
                  Raster[CompressedData["
1:eJxTTMoPSmJmYGCQAmJWIAax/1Mb/P706sGDp+++/wax76xmAAPHiWeB3Evz
YyC8jXe+g7gzQFz/GZcgGqFcsMrBwz07wx/ufiC4s7HTUc+xc/sD6gYaAAHv
MDA=
                   "], {{0, 0}, {5, 26}}, {0, 255}, ColorFunction -> 
                   RGBColor], ImageSize -> {5, 26}, 
                  PlotRange -> {{0, 5}, {0, 26}}], 
                 Graphics[
                  Raster[CompressedData["
1:eJztkaEOgzAQhi/ZE8zO7QV4hz4ByTQKgR12dg5ZV3eqClWFws9gamoqZjCI
iRoEgrUNFNTC3LLwJ5f0vv5/L23P6fWSHgDgZOtoy63HXd9LYWafLuMqEImJ
JUyaGRjuAKCaiGSuj2mzRDyhzStEWAxrsiWCPxLBbREmZ8Mg8si/WP85AqTQ
k8VQ4kCUYTdFdO4AlLNjioAfVQp2iyEoSlCIIot8k4SxjT+U5DlZrEDulazp
CkCCy2UH0yql3b+aZy1Kznn10IPf6jtVWYC8btpx19/pDWR9XYk=
                   "], {{
                   0, 0}, {17, 26}}, {0, 255}, ColorFunction -> RGBColor], 
                  ImageSize -> {17, 26}, PlotRange -> {{0, 17}, {0, 26}}], 
                 Graphics[
                  Raster[CompressedData["
1:eJxTTMoPSmJmYGCQAmJuIAax/w8XcH1+GtA7aUuvw0U+XZoBFImZcQnCvTQj
Bsj1n3gWTQFcZEAUfL80H4sCmJuB4M7qAkwFDI5N1z9BFZyd6A8SQFMAVjRx
9fbVMwognMrtD2DqHUEGVjb5MyABvaYHv6EG/v709Pr1O+9Ajnt6YvvqpUuX
rt544t3v/6OAJAAA/yPYVg==
                   "], {{0, 0}, {11, 26}}, {0, 255}, 
                   ColorFunction -> RGBColor], ImageSize -> {11, 26}, 
                  PlotRange -> {{0, 11}, {0, 26}}], 
                 Graphics[
                  Raster[CompressedData["
1:eJztkKEOwyAURUkm9wdz+wH+oV9AMo2qqB22tq6yrq4KVVWFqqnC1NTUVMxg
EAgMoqJjsNJtqZlcspuQAOfe9x6c4+slPgAATnYd7Xrsl1+TVlIIIZXZQSNL
IAiCKONyDtRM9UoQSYMRceW5KpG7wJV8BsbUmWDauurc8YjJraMZSpdJBmPt
1PFCvc5kBuy7aDuAM8B819BrO0IXrdU2iQYGwzwRP2PZr3huiOOY+pBgqX8Y
zqqua4sk8sdq0CHCKwLelbPp4zONnNqmppQ2jN/0vPz1pe6vbsT7
                   "], {{
                   0, 0}, {11, 26}}, {0, 255}, ColorFunction -> RGBColor], 
                  ImageSize -> {11, 26}, PlotRange -> {{0, 11}, {0, 26}}], 
                 Graphics[
                  Raster[CompressedData["
1:eJxTTMoPSmJmYGCQAmJuIAax/xMFfn///v03bulLM2KARvnPuERAwcSzFCqI
mX8d6JhXT4Hg1XdsChgYHP0dGWDAccbeBxgKgEAvJi3NXw/KmXjiHbICvZgZ
D6BGv1uaBlak1/kKlzffHQLbprfxwW8cvvg03x9sy9l3JChACclXnY7oCoAB
8Qqu/9J8iGf3vkLzZsz8jXu3L+2EejRmKcRbZyc6QoIAEU4gkAYLhv+/Pz29
fv3OJyDj3Z29G1cvXbp0+6Gz7/BE/yjABgAnJqWw
                   "], {{0, 0}, {11, 
                   26}}, {0, 255}, ColorFunction -> RGBColor], 
                  ImageSize -> {11, 26}, PlotRange -> {{0, 11}, {0, 26}}], 
                 Graphics[
                  Raster[CompressedData["
1:eJxTTMoPSmJmYGCQAmJuIAax/5MJfn8Hgt84pT9dmgE03HHiWfwK/ElV8P3d
0wdPnz59BbT59/X5aAourW5igAO9tM5Kf2QFD7ZXwqRiCgpi4AphCp426YEl
C1a/g2h4d6nJXw+h4NNZkHEMjofeITkHyZHfry8Fy09Ekkfxxe8Hq0HG6XXi
UvD/0wmwFf4nPmG34v/vOxA/ODbthSt4sL0J2ZtPYd50LJix99D2GZUxqN4E
mXJoBsL7iADrPIES/g8ubV+9eunS1XvP3vn+//vTO9cfvPqOK7JGASYAAA9L
rNM=
                   "], {{0, 0}, {11, 26}}, {0, 255}, ColorFunction -> 
                   RGBColor], ImageSize -> {11, 26}, 
                  PlotRange -> {{0, 11}, {0, 26}}], 
                 Graphics[
                  Raster[CompressedData["
1:eJxTTMoPSmJmYGCQAmJ2IAax/w80uD4/DeiMtKXXkQUvzYgBCvpPPEsfQcfO
E5iCQOGND35jCAKBXtOMGRMnbgQKnp3oCOTHNDU5wqSAgr8/Pb1+/c4nIOPV
9Y2rly5dvZeMYBk8AADIm9Yh
                   "], {{0, 0}, {7, 26}}, {0, 255}, 
                   ColorFunction -> RGBColor], ImageSize -> {7, 26}, 
                  PlotRange -> {{0, 7}, {0, 26}}], 
                 Graphics[
                  Raster[CompressedData["
1:eJxTTMoPSmJmYGCQAmIOIAax/w8s+P391VMQePfpO1Tk+9ONEwsYkIBj2vwH
v/9fmugI4cYUNE2cWAnlVG7//+lSU1rTiacw7a/2gqQcJ6JZc3ZpJQOy+PdX
h1bPiNGDWdF5CCj27uxSPSRrO1efBRn6/VIMRMC/cuPZO9/hRn466w92wQOY
wHeIF75fAoszFMzYfv362dWdaUD2xBOvgDLXV1cyoIKm7VDdn55e37tx9dKl
SzduP/Hg02+qB/PgAQC7PPiW
                   "], {{0, 0}, {8, 26}}, {0, 255}, 
                   ColorFunction -> RGBColor], ImageSize -> {8, 26}, 
                  PlotRange -> {{0, 8}, {0, 26}}], 
                 Graphics[
                  Raster[CompressedData["
1:eJxTTMoPSmJmYGCQAmJ2IAax/9Md/P707unTp6/effoNE7m+sYkBBhwnngUr
uhQD4funFcQ4Fqy+DhT7fmc1SESv6SmSaZ8uzQArm/EJU9CRBMF3yC68Ph9s
5vzvcBduX1oZo8cAsX7ijImdEw89/d7JgA6aTrz79OrVg0sbHUG8ghMPHty5
fucVxJTvYB+huvP/97P+QMGY+SiCgwwAAFKhuT4=
                   "], {{0, 0}, {7, 
                   26}}, {0, 255}, ColorFunction -> RGBColor], 
                  ImageSize -> {7, 26}, PlotRange -> {{0, 7}, {0, 26}}], 
                 Graphics[
                  Raster[CompressedData["
1:eJxTTMoPSmJmYGCQAmJuIAax/w8p8OnV0wdPn7569x2r5MYmfwYY8G/aeP3E
fCBjxtlPEOlXhzqhco4xMf56cJUTz76DKDg7EaRdr2AjxPTrG5vQFFyaEQPk
Vm5/CrfyRKc/pgK4jXARNAVw7oAoODvREcjtPIFQgCby/dWD69fvIIfx93dP
gSKvPv3GFuyjADsAAOt53ho=
                   "], {{0, 0}, {11, 26}}, {0, 255}, 
                   ColorFunction -> RGBColor], ImageSize -> {11, 26}, 
                  PlotRange -> {{0, 11}, {0, 26}}], 
                 Graphics[
                  Raster[CompressedData["
1:eJxTTMoPSmJmYGCQAmJOIAax/w8dcKLTnwEE0i59R5X4faeAAQqaDr1Clnl3
diIDHKStRtL3e3uBHlBs4qETnY5A2v/EJ5jM97MxINUxl37/PwuWK9j4ACLz
dHsTxJzf//9/ujQDxPafD9b3aSlYT9Pep0jucdwLdMurvY5g087CzD/UBBJI
W3r9ztI0uGkQADXTceJEkNMYKvci++UOWDXDqwd3rl9/8On3f2TwDixIZrAO
ZQAAtf1PUg==
                   "], {{0, 0}, {9, 26}}, {0, 255}, 
                   ColorFunction -> RGBColor], ImageSize -> {9, 26}, 
                  PlotRange -> {{0, 9}, {0, 26}}], 
                 Graphics[
                  Raster[CompressedData["
1:eJztUaGShDAM7cz6+4Bz+wP8A1/AzGrUitqrXYtD4upQqCoUCnOqpgaDqajB
IBCYigouCWWX/YFTm5nOpC8vb16S6/3ndr8wxr7hfcHDfPvE8psyjKKfIuIH
TkhW6TNx6guCWfLoAiHrIFmEyvlFDJ1IDvzhCDIyjwhL+yc1WIGcvCqw2jpQ
XSS4Sbgs+dmStw225o0bMRHttHmNtrmaxnq3tDPHmpPzAVIUFd1kJLXaLQwZ
quyW1po+lVlBvgFqInYbjfVQlVRVYGnVlGZIBNGGH4MIG16jcWUXXRJRrnE4
FXcg2rd1caUL3E9amecedlEwe5zA0FEyP7txtLM/ncvZdyTMgNjT+j/xv/EH
JeF/Zw==
                   "], {{0, 0}, {14, 26}}, {0, 255}, ColorFunction -> 
                   RGBColor], ImageSize -> {14, 26}, 
                  PlotRange -> {{0, 14}, {0, 26}}], 
                 Graphics[
                  Raster[CompressedData["
1:eJxTTMoPSmJmYGCQAmJOIAax/w96MN8f6EyGgtV34CKHOsFCaavfnZ0IYjD4
n/gEEv9+fSmYy7D0+vf//39vL9ADsvWaDv3//64TxGRw7DwBNeLTCbARjgUF
MWAdlXeQbHywvZIBBmZc+oTimu+XYqAyeie+o8icgLgKDByb9iJ0QF3luP36
iQKE84DgKcRV/hNBrnqwGizpOPHV//93lkIsKbjzG2LG0yYwP2bpne+vHly/
fv3BK4TdEJGn71BdMzIAAB4dQJ4=
                   "], {{0, 0}, {9, 26}}, {0, 
                   255}, ColorFunction -> RGBColor], ImageSize -> {9, 26}, 
                  PlotRange -> {{0, 9}, {0, 26}}], 
                 Graphics[
                  Raster[CompressedData["
1:eJzlUKEOgzAQbTK1X5jbD/AP/YIm01WI2WFnccg6HAqFmkJhpmYwmBpEDaai
AlNRsXFXWGia7Af2kkuu967v3t05vV3SAyHktMRxCcjfP+CsMdoYGzNDyQgi
YYUM+XmoKWXU06ya489WZgmQojcxqZ8FcNcmnurG2ou+ItEuXwfeWxXO6jnZ
wAMz6nGHmmhK6KCd/jJGoFitloEcvYyrmDeQ5BrMNJDT0uwM8GrA15TDgkk7
uc0A5oheMOyU3sD+RFaiPi0E3idrp73fDJfQapRynF2wpYFiuPh/4ANLGjIw

                   "], {{0, 0}, {9, 26}}, {0, 255}, ColorFunction -> 
                   RGBColor], ImageSize -> {9, 26}, 
                  PlotRange -> {{0, 9}, {0, 26}}], 
                 Graphics[
                  Raster[CompressedData["
1:eJxTTMoPSmJmYGCQAmJOIAax/w96cGl+DAMI6OkxIIOYs5/+31mdBuPq+Ts6
6oEBA0MaUOr//1cTHcESlXuxGPp0O8S0zkOvMCXvrC6AW4EBPs33B0umrf6O
KfnuENhOhsrtTzElXx3qBEv6H3oHFdg4YyIYzJg/owDmrfkgOz+dQPUs1I+H
QHK/Xz24gwGe/iY+QIcRAAA9XkVU
                   "], {{0, 0}, {9, 26}}, {0, 
                   255}, ColorFunction -> RGBColor], ImageSize -> {9, 26}, 
                  PlotRange -> {{0, 9}, {0, 26}}]}, {Null, 
                 SparseArray[
                 Automatic, {26, 26}, 0, {
                  1, {{0, 5, 7, 10, 12, 15, 17, 19, 22, 25, 27, 29, 32, 35, 
                    39, 49, 52, 55, 58, 60, 62, 64, 66, 69, 73, 75, 78}, {{
                    5}, {15}, {19}, {24}, {26}, {8}, {16}, {5}, {15}, {18}, {
                    15}, {17}, {1}, {3}, {15}, {9}, {12}, {16}, {17}, {2}, {
                    11}, {14}, {6}, {10}, {12}, {9}, {12}, {8}, {24}, {6}, {
                    9}, {10}, {14}, {15}, {18}, {8}, {13}, {15}, {21}, {1}, {
                    3}, {4}, {5}, {13}, {14}, {16}, {17}, {19}, {21}, {2}, {
                    7}, {15}, {4}, {7}, {15}, {3}, {13}, {20}, {1}, {15}, {
                    18}, {26}, {14}, {15}, {23}, {25}, {22}, {24}, {25}, {
                    1}, {11}, {23}, {26}, {22}, {23}, {1}, {20}, {24}}}, 
                   Pattern}]}, {VertexLabels -> {All}}]]}, 
            TagBox[
             GraphicsGroupBox[{{{{{{{
                    Hue[0.6, 0.7, 0.5], 
                    Opacity[0.7], {{{{{{
                    Arrowheads[0.], 
                    
                    ArrowBox[{{4.480586225893454, -2.1799474327571104`}, {
                    5.24106218708406, -1.7053517372530047`}}, 
                    0.052478423386308704`]}}}}}}, {{{{{{
                    Arrowheads[0.], 
                    
                    ArrowBox[{{4.480586225893454, -2.1799474327571104`}, {
                    5.965103790399207, -2.322804916942334}}, 
                    0.052478423386308704`]}}}}}}, {{{{{{
                    Arrowheads[0.], 
                    
                    ArrowBox[{{4.480586225893454, -2.1799474327571104`}, {
                    5.0936340590684415`, -2.420075315170594}}, 
                    0.052478423386308704`]}}}}}}, {{{{{{
                    Arrowheads[0.], 
                    
                    ArrowBox[{{4.480586225893454, -2.1799474327571104`}, {
                    3.188711043481997, -2.607258064208528}}, 
                    0.052478423386308704`]}}}}}}, {{{{{{
                    Arrowheads[0.], 
                    
                    ArrowBox[{{4.480586225893454, -2.1799474327571104`}, {
                    3.6377999851433134`, -1.7113080955758058`}}, 
                    0.052478423386308704`]}}}}}}, {{{{{{
                    Arrowheads[0.], 
                    
                    ArrowBox[{{5.9670411273594635`, -4.1970993673568024`}, {
                    4.986842693816599, -3.8493818994661746`}}, 
                    0.052478423386308704`]}}}}}}, {{{{{{
                    Arrowheads[0.], 
                    
                    ArrowBox[{{5.9670411273594635`, -4.1970993673568024`}, {
                    6.688016643036104, -3.4306867425232745`}}, 
                    0.052478423386308704`]}}}}}}, {{{{{{
                    Arrowheads[0.], 
                    
                    ArrowBox[{{5.765111935171046, -1.2491283642487643`}, {
                    5.24106218708406, -1.7053517372530047`}}, 
                    0.052478423386308704`]}}}}}}, {{{{{{
                    Arrowheads[0.], 
                    
                    ArrowBox[{{5.765111935171046, -1.2491283642487643`}, {
                    5.965103790399207, -2.322804916942334}}, 
                    0.052478423386308704`]}}}}}}, {{{{{{
                    Arrowheads[0.], 
                    
                    ArrowBox[{{5.765111935171046, -1.2491283642487643`}, {
                    5.104055270980713, -0.873614448207543}}, 
                    0.052478423386308704`]}}}}}}, {{{{{{
                    Arrowheads[0.], 
                    
                    ArrowBox[{{6.993329162302756, -1.9673148421060902`}, {
                    5.965103790399207, -2.322804916942334}}, 
                    0.052478423386308704`]}}}}}}, {{{{{{
                    Arrowheads[0.], 
                    ArrowBox[{{6.993329162302756, -1.9673148421060902`}, {
                    7.159884817394166, -2.5216057257948923`}}, 
                    0.052478423386308704`]}}}}}}, {{{{{{
                    Arrowheads[0.], 
                    
                    ArrowBox[{{5.24106218708406, -1.7053517372530047`}, {
                    5.965103790399207, -2.322804916942334}}, 
                    0.052478423386308704`]}}}}}}, {{{{{{
                    Arrowheads[0.], 
                    
                    ArrowBox[{{2.6759265588555055`, -6.249358300161733}, {
                    1.7418955435258285`, -6.683451809207677}}, 
                    0.052478423386308704`]}}}}}}, {{{{{{
                    Arrowheads[0.], 
                    
                    ArrowBox[{{2.6759265588555055`, -6.249358300161733}, {
                    1.7432975798106856`, -5.813881410030349}}, 
                    0.052478423386308704`]}}}}}}, {{{{{{
                    Arrowheads[0.], 
                    
                    ArrowBox[{{7.6166730800090585`, -3.214984670662907}, {
                    6.688016643036104, -3.4306867425232745`}}, 
                    0.052478423386308704`]}}}}}}, {{{{{{
                    Arrowheads[0.], 
                    
                    ArrowBox[{{7.6166730800090585`, -3.214984670662907}, {
                    7.159884817394166, -2.5216057257948923`}}, 
                    0.052478423386308704`]}}}}}}, {{{{{{
                    Arrowheads[0.], 
                    
                    ArrowBox[{{4.986842693816599, -3.8493818994661746`}, {
                    3.8469892110659623`, -3.53684531368041}}, 
                    0.052478423386308704`]}}}}}}, {{{{{{
                    Arrowheads[0.], 
                    
                    ArrowBox[{{4.986842693816599, -3.8493818994661746`}, {
                    5.58583296100195, -2.9515506391145854`}}, 
                    0.052478423386308704`]}}}}}}, {{{{{{
                    Arrowheads[0.], 
                    
                    ArrowBox[{{1.7418955435258285`, -6.683451809207677}, {
                    0.8083910213367735, -6.248705306432721}}, 
                    0.052478423386308704`]}}}}}}, {{{{{{
                    Arrowheads[0.], 
                    
                    ArrowBox[{{1.7418955435258285`, -6.683451809207677}, {
                    1.7432975798106856`, -5.813881410030349}}, 
                    0.052478423386308704`]}}}}}}, {{{{{{
                    Arrowheads[0.], 
                    
                    ArrowBox[{{0.8083910213367735, -6.248705306432721}, {
                    1.7432975798106856`, -5.813881410030349}}, 
                    0.052478423386308704`]}}}}}}, {{{{{{
                    Arrowheads[0.], 
                    
                    ArrowBox[{{3.8469892110659623`, -3.53684531368041}, {
                    3.188711043481997, -2.607258064208528}}, 
                    0.052478423386308704`]}}}}}}, {{{{{{
                    Arrowheads[0.], 
                    
                    ArrowBox[{{5.6639631469428835`, -1.8248221865674927`}, {
                    5.58583296100195, -2.9515506391145854`}}, 
                    0.052478423386308704`]}}}}}}, {{{{{{
                    Arrowheads[0.], 
                    
                    ArrowBox[{{5.6639631469428835`, -1.8248221865674927`}, {
                    5.965103790399207, -2.322804916942334}}, 
                    0.052478423386308704`]}}}}}}, {{{{{{
                    Arrowheads[0.], 
                    
                    ArrowBox[{{5.6639631469428835`, -1.8248221865674927`}, {
                    5.104055270980713, -0.873614448207543}}, 
                    0.052478423386308704`]}}}}}}, {{{{{{
                    Arrowheads[0.], 
                    
                    ArrowBox[{{5.58583296100195, -2.9515506391145854`}, {
                    5.965103790399207, -2.322804916942334}}, 
                    0.052478423386308704`]}}}}}}, {{{{{{
                    Arrowheads[0.], 
                    
                    ArrowBox[{{5.58583296100195, -2.9515506391145854`}, {
                    6.215695355594371, -2.9999022913880706`}}, 
                    0.052478423386308704`]}}}}}}, {{{{{{
                    Arrowheads[0.], 
                    
                    ArrowBox[{{5.965103790399207, -2.322804916942334}, {
                    6.688016643036104, -3.4306867425232745`}}, 
                    0.052478423386308704`]}}}}}}, {{{{{{
                    Arrowheads[0.], 
                    
                    ArrowBox[{{5.965103790399207, -2.322804916942334}, {
                    7.159884817394166, -2.5216057257948923`}}, 
                    0.052478423386308704`]}}}}}}, {{{{{{
                    Arrowheads[0.], 
                    
                    ArrowBox[{{5.965103790399207, -2.322804916942334}, {
                    5.0936340590684415`, -2.420075315170594}}, 
                    0.052478423386308704`]}}}}}}, {{{{{{
                    Arrowheads[0.], 
                    
                    ArrowBox[{{5.965103790399207, -2.322804916942334}, {
                    6.215695355594371, -2.9999022913880706`}}, 
                    0.052478423386308704`]}}}}}}, {{{{{{
                    Arrowheads[0.], 
                    
                    ArrowBox[{{5.104055270980713, -0.873614448207543}, {
                    4.0893098597948505`, -0.8083910213367735}}, 
                    0.052478423386308704`]}}}}}}, {{{{{{
                    Arrowheads[0.], 
                    
                    ArrowBox[{{4.0893098597948505`, -0.8083910213367735}, {
                    3.6377999851433134`, -1.7113080955758058`}}, 
                    0.052478423386308704`]}}}}}}, {{{{{{
                    Arrowheads[0.], 
                    
                    ArrowBox[{{0.8717601828076917, -3.141020808670527}, {
                    1.7291396205785987`, -2.7951101292059013`}}, 
                    0.052478423386308704`]}}}}}}, {{{{{{
                    Arrowheads[0.], 
                    
                    ArrowBox[{{0.8717601828076917, -3.141020808670527}, {
                    0.8083910213367735, -2.6803280265469525`}}, 
                    0.052478423386308704`]}}}}}}, {{{{{{
                    Arrowheads[0.], 
                    
                    ArrowBox[{{1.7291396205785987`, -2.7951101292059013`}, {
                    3.188711043481997, -2.607258064208528}}, 
                    0.052478423386308704`]}}}}}}, {{{{{{
                    Arrowheads[0.], 
                    
                    ArrowBox[{{1.7291396205785987`, -2.7951101292059013`}, {
                    0.8083910213367735, -2.6803280265469525`}}, 
                    0.052478423386308704`]}}}}}}, {{{{{{
                    Arrowheads[0.], 
                    
                    ArrowBox[{{3.188711043481997, -2.607258064208528}, {
                    3.6377999851433134`, -1.7113080955758058`}}, 
                    0.052478423386308704`]}}}}}}}}}}}}, {{{{{{
                    Hue[0.6, 0.2, 0.8], 
                    EdgeForm[{
                    GrayLevel[0], 
                    Opacity[0.7]}], {
                    
                    DiskBox[{4.480586225893454, -2.1799474327571104`}, 
                    0.052478423386308704`], 
                    InsetBox[
                    FormBox[
                    GraphicsBox[
                    RasterBox[CompressedData["
1:eJztUCEOwyAUJZnbEeZ2gd5hJyCZrqrArhZbVzlXh0JVVaFqUJgaDAaLQVRg
KhCMlqZt1gtM7CU/4fH+f4/PvXg9iwsA4BbrGms+h5/GZE2Edf4kaAbBhgfp
+XvmSE5RtHWW7iGuMMy2NihcCF6VC+lMcnK8QUkdDipR05rkZb6pIfRVsssq
wpRxfhTwoEa3vsF74DF3g3da8pY0NUZLZ77OejsItS+q6bJZMybWLo+EJWVc
MLLujlnqH2WHvlNzbo+/5o0eWNdSSmjHzRT+OOMDUFN0aA==
                    "], {{0, 
                    0}, {10, 26}}, {0, 255}, ColorFunction -> RGBColor], 
                    ImageSize -> {10, 26}, PlotRange -> {{0, 10}, {0, 26}}], 
                    TraditionalForm], 
                    Offset[{2, 2}, {4.533064649279763, -2.1274690093708015`}], 
                    ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                    
                    DiskBox[{5.9670411273594635`, -4.1970993673568024`}, 
                    0.052478423386308704`], 
                    InsetBox[
                    FormBox[
                    GraphicsBox[
                    RasterBox[CompressedData["
1:eJzVkK0OwyAUhUkm9wZzewHegSdoMo2qwO4d6pB1OBRqClWFqZrBYGYmMDMI
xExFRUf/abNmmdtOchO4+bj3HI7p+ZTuAACHUPtQ7bn5P1XuEeSqZffGSYhD
siwBkxBTdgIMw2MfYkISOFzyq18AmNlhtBekgyB1EZAwM2/1JeoIaesZyHXk
68k7Q7n2XwDxisZRtAYg4X56b3gfVrllTIiZVIWgQ1AsqvU/xCJ6nNgDmJu6
skpehBBFaXw9G3qXYqGPgGZtZrQN3CVFENHCbgG/rxcTMKJ1
                    "], {{0, 
                    0}, {11, 26}}, {0, 255}, ColorFunction -> RGBColor], 
                    ImageSize -> {11, 26}, PlotRange -> {{0, 11}, {0, 26}}], 
                    TraditionalForm], 
                    Offset[{2, 2}, {6.019519550745772, -4.1446209439704935`}], 
                    ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                    
                    DiskBox[{5.765111935171046, -1.2491283642487643`}, 
                    0.052478423386308704`], 
                    InsetBox[
                    FormBox[
                    GraphicsBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmJmYGCQAmJOIAax/w8+8Ondq6dPn7569wlZ8N2l1TF6DAjgX7n3
zjuQ4uvzYUKOBZWVMY5gpt6M//9fTYSw/Sc++A4x4/uh+RO33/n+/9MJf7Ci
jU9/o1n9HWKa44x3GK76fmcp2LQZnzCk/r87BLbK/wSm3O87BRDHNe1FKH8F
Nf7V3iao09M6tx86tLQzDchu2vsUIntpaSUDKmja/gBh8LsHh7ZvXLp06eqN
e++8+k44WIcjAAC1RVCo
                    "], {{0, 0}, {9, 26}}, {0, 255}, 
                    ColorFunction -> RGBColor], ImageSize -> {9, 26}, 
                    PlotRange -> {{0, 9}, {0, 26}}], TraditionalForm], 
                    
                    Offset[{2, 2}, {
                    5.8175903585573545`, -1.1966499408624556`}], 
                    ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                    
                    DiskBox[{6.993329162302756, -1.9673148421060902`}, 
                    0.052478423386308704`], 
                    InsetBox[
                    FormBox[
                    GraphicsBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmJmYGCQAmJuIAax/w8t8P3d0wdPnz599R2b5KXVTQwIkLZ043x/
Bgb/GWchsg+2V0Jl9GIKCmLg6vwnQhQ8bdIDSxasfgfR8O5Skz+Sgk9nwTzH
Q++QnHNpBlzB9+tLwfITkeT/f0JS8PvBapANep24FPz/dAJi4YlP2K34//sO
xA+OTXvhCh5sb0Lyxf+nMG86FszYe2j7jMoYVG+CTDk0A+F9jHCAOezBpe2r
Vy9dunrvpafvLs3HVICiGNmRtFHw/c5qfz29yqXXcSkYbAAALCuqpQ==
                    
                    "], {{0, 0}, {11, 26}}, {0, 255}, ColorFunction -> 
                    RGBColor], ImageSize -> {11, 26}, 
                    PlotRange -> {{0, 11}, {0, 26}}], TraditionalForm], 
                    Offset[{2, 2}, {7.045807585689065, -1.9148364187197815`}], 
                    ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                    
                    DiskBox[{5.24106218708406, -1.7053517372530047`}, 
                    0.052478423386308704`], 
                    InsetBox[
                    FormBox[
                    GraphicsBox[
                    RasterBox[CompressedData["
1:eJztj68OgzAQxpvM7RHm9gK8w56AZI+AwK4Wi0PicKgqVBWqZgpTU4OpwNRU
nKipQLD+gSyQzU/sl1xyvfvuvt41e9yzE0Lo4uLswufLz2NAK4eG+VCXDN/Q
myStKTehZWW3VW9FVRV5GvJi8k1dh6kEt2rbaNUopjBqhiBN+cEsykYSnRra
93Sld2lHhbZWEvSFaoAFnsEWC7AGPMYaVvpazWGZJQ7KkqnNDeI/ibTuoVgZ
V+GGCjHUeRKOa2AVz7zFe8+Uqd0NRo2MdoSQnnH96bo/LxRCezk=
                    
                    "], {{0, 0}, {10, 26}}, {0, 255}, ColorFunction -> 
                    RGBColor], ImageSize -> {10, 26}, 
                    PlotRange -> {{0, 10}, {0, 26}}], TraditionalForm], 
                    Offset[{2, 2}, {5.293540610470369, -1.652873313866696}], 
                    ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                    
                    DiskBox[{2.6759265588555055`, -6.249358300161733}, 
                    0.052478423386308704`], 
                    InsetBox[
                    FormBox[
                    GraphicsBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmJmYGCQAmI2IAax/9MXfL++FGgpQ8zSTzCRT5dmgEQcZ7zDEMFU
Q54I3OTf1+eDRPznfwdzX53dWBmjBxJh0GuaOHHG6rNnOyFcOOj8/endpY1N
YHbBiTsPHjwFGfYdYjLMHLC/5kPUXAcJ/QaLPSiAGqKnBwvnT9c3xsBsQAmW
799/UxKsqAAAAhZjvA==
                    "], {{0, 0}, {6, 26}}, {0, 255}, 
                    ColorFunction -> RGBColor], ImageSize -> {6, 26}, 
                    PlotRange -> {{0, 6}, {0, 26}}], TraditionalForm], 
                    Offset[{2, 2}, {2.7284049822418144`, -6.196879876775424}], 
                    ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                    
                    DiskBox[{7.6166730800090585`, -3.214984670662907}, 
                    0.052478423386308704`], 
                    InsetBox[
                    FormBox[
                    GraphicsBox[
                    RasterBox[CompressedData["
1:eJzlUKFuxDAMjTS2TxjbD/Qf/AWVhosOlK609FhhWVlRUFBRUEhQSEhISUBI
SUFASEHBLU66m069SeN7kqU4z8/P9vvl8+PyQgh5i/EaA9+3P2APi1GSI4TS
8xr2O2VoQ06oex6iyk0pK5qeGesWZwXtivQFndwsw3c1PTgtPBXUNy8Bpa1e
Qwg+YZ3FkNgyFjpWnX0TOUZW9WW2ruo7mp6KFQcPI5Ig/PNlHW9RCWUJUADU
7TD7n313S0+WlTpa5c5xO5EEntY4L/Q6swOypQpHq20eMX9gCbWHl5cdth7n
bMvbtDo03DirWHXc8ToJk8fq4Ok5uu/BN6slo5RNXBt7wP1ygv+KL3qCMuA=

                    "], {{0, 0}, {10, 26}}, {0, 255}, ColorFunction -> 
                    RGBColor], ImageSize -> {10, 26}, 
                    PlotRange -> {{0, 10}, {0, 26}}], TraditionalForm], 
                    Offset[{2, 2}, {7.669151503395367, -3.162506247276598}], 
                    ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                    DiskBox[{4.986842693816599, -3.8493818994661746`}, 
                    0.052478423386308704`], 
                    InsetBox[
                    FormBox[
                    GraphicsBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmJmYGCQAmJuIAax/w8XcH1+GtA7aUuvw0U+XZoBFImZcQnCvTQj
Bsj1n3gWTQFcZEAUfL80H4sCmJuB4M7qAkwFDI5N1z9BFZyd6A8SQFMAVjRx
9fbVMwognMrtD5AVOBZUwtWBgF7Tg9//Mdzw6tD21UuXLl298cS733AXYfEF
GiCo4OwMFDdjgjsbOx31HDthbh6KAABYzr7r
                    "], {{0, 0}, {11, 
                    26}}, {0, 255}, ColorFunction -> RGBColor], 
                    ImageSize -> {11, 26}, PlotRange -> {{0, 11}, {0, 26}}], 
                    TraditionalForm], 
                    Offset[{2, 2}, {5.039321117202908, -3.7969034760798657`}], 
                    ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                    
                    DiskBox[{1.7418955435258285`, -6.683451809207677}, 
                    0.052478423386308704`], 
                    InsetBox[
                    FormBox[
                    GraphicsBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmJmYGCQAmJWIAax/9MSXJ+fBrQibel1CPfSjBgg13/iWTpzz050
BHL1YNzfn17duXPn1aff/+H8V3De96UgrQwMMUu/g7ifZjiCuY4zPkGkX905
tPfQnXcwvVQCAEeBPoI=
                    "], {{0, 0}, {5, 26}}, {0, 255}, 
                    ColorFunction -> RGBColor], ImageSize -> {5, 26}, 
                    PlotRange -> {{0, 5}, {0, 26}}], TraditionalForm], 
                    Offset[{2, 2}, {1.7943739669121372`, -6.630973385821368}], 
                    ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                    
                    DiskBox[{0.8083910213367735, -6.248705306432721}, 
                    0.052478423386308704`], 
                    InsetBox[
                    FormBox[
                    GraphicsBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmJmYGCQAmI2IAax/2OAd08fXL906dL1B79hIjEMMBAz/x1Y5NCM
pqbOSj2w2IxLn+B6z070B6u6BBe5NAOk23/i2SEkcnaiI1BErxMh8vvTqzt3
7rz6BA8SsNArZIHvSyHBFLP0O1Tk0wxHsIjjDHgA/X5359DeQ3feIZlDAwAA
n1xr8A==
                    "], {{0, 0}, {6, 26}}, {0, 255}, ColorFunction -> 
                    RGBColor], ImageSize -> {6, 26}, 
                    PlotRange -> {{0, 6}, {0, 26}}], TraditionalForm], 
                    Offset[{2, 2}, {0.8608694447230822, -6.196226883046412}], 
                    
                    ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                    
                    DiskBox[{3.8469892110659623`, -3.53684531368041}, 
                    0.052478423386308704`], 
                    InsetBox[
                    FormBox[
                    GraphicsBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmJmYGCQAmIuIAax/w9NcH1+GtDxaUuvw0UugUUY/OeD2DNiQMyJ
Z6FyT7frgeQYJp54B5d17DwBlvu0FMRj0CvY/htiDlgWKLD0zu9PJzrB7Jiz
n2C2QGURoHL7U4Qb0GTTln5HcjNENm3G9qUFIOfopS39hCHrPwPoozsFYN2O
nYfQZcE++g3zTuXGO5iyQPDqEMTZDPMvfcISGkAFD+5cv37n6affWGWRAX7Z
szP8Qe7EIXtnY6ejnmPn9gdYZQchAADMKmsX
                    "], {{0, 0}, {10, 
                    26}}, {0, 255}, ColorFunction -> RGBColor], 
                    ImageSize -> {10, 26}, PlotRange -> {{0, 10}, {0, 26}}], 
                    TraditionalForm], 
                    Offset[{2, 2}, {3.8994676344522707`, -3.484366890294101}], 
                    ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                    
                    DiskBox[{1.7432975798106856`, -5.813881410030349}, 
                    0.052478423386308704`], 
                    InsetBox[
                    FormBox[
                    GraphicsBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmJmYGCQAmJWIAax/1Mb/P706sGDp+++/wax76xmAAPHiWeB3Evz
YyC8jXe+g7gzQFz/GZcgGqFcsMrBwz07wx/ufiC4s7HTUc+xc/sD6gYaAAHv
MDA=
                    "], {{0, 0}, {5, 26}}, {0, 255}, ColorFunction -> 
                    RGBColor], ImageSize -> {5, 26}, 
                    PlotRange -> {{0, 5}, {0, 26}}], TraditionalForm], 
                    Offset[{2, 2}, {1.7957760031969943`, -5.76140298664404}], 
                    
                    ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                    
                    DiskBox[{5.6639631469428835`, -1.8248221865674927`}, 
                    0.052478423386308704`], 
                    InsetBox[
                    FormBox[
                    GraphicsBox[
                    RasterBox[CompressedData["
1:eJztkaEOgzAQhi/ZE8zO7QV4hz4ByTQKgR12dg5ZV3eqClWFws9gamoqZjCI
iRoEgrUNFNTC3LLwJ5f0vv5/L23P6fWSHgDgZOtoy63HXd9LYWafLuMqEImJ
JUyaGRjuAKCaiGSuj2mzRDyhzStEWAxrsiWCPxLBbREmZ8Mg8si/WP85AqTQ
k8VQ4kCUYTdFdO4AlLNjioAfVQp2iyEoSlCIIot8k4SxjT+U5DlZrEDulazp
CkCCy2UH0yql3b+aZy1Kznn10IPf6jtVWYC8btpx19/pDWR9XYk=
                    
                    "], {{0, 0}, {17, 26}}, {0, 255}, ColorFunction -> 
                    RGBColor], ImageSize -> {17, 26}, 
                    PlotRange -> {{0, 17}, {0, 26}}], TraditionalForm], 
                    Offset[{2, 2}, {5.716441570329192, -1.772343763181184}], 
                    ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                    
                    DiskBox[{5.58583296100195, -2.9515506391145854`}, 
                    0.052478423386308704`], 
                    InsetBox[
                    FormBox[
                    GraphicsBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmJmYGCQAmJuIAax/w8XcH1+GtA7aUuvw0U+XZoBFImZcQnCvTQj
Bsj1n3gWTQFcZEAUfL80H4sCmJuB4M7qAkwFDI5N1z9BFZyd6A8SQFMAVjRx
9fbVMwognMrtD2DqHUEGVjb5MyABvaYHv6EG/v709Pr1O+9Ajnt6YvvqpUuX
rt544t3v/6OAJAAA/yPYVg==
                    "], {{0, 0}, {11, 26}}, {0, 255},
                     ColorFunction -> RGBColor], ImageSize -> {11, 26}, 
                    PlotRange -> {{0, 11}, {0, 26}}], TraditionalForm], 
                    Offset[{2, 2}, {5.638311384388259, -2.8990722157282764`}], 
                    ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                    
                    DiskBox[{5.965103790399207, -2.322804916942334}, 
                    0.052478423386308704`], 
                    InsetBox[
                    FormBox[
                    GraphicsBox[
                    RasterBox[CompressedData["
1:eJztkKEOwyAURUkm9wdz+wH+oV9AMo2qqB22tq6yrq4KVVWFqqnC1NTUVMxg
EAgMoqJjsNJtqZlcspuQAOfe9x6c4+slPgAATnYd7Xrsl1+TVlIIIZXZQSNL
IAiCKONyDtRM9UoQSYMRceW5KpG7wJV8BsbUmWDauurc8YjJraMZSpdJBmPt
1PFCvc5kBuy7aDuAM8B819BrO0IXrdU2iQYGwzwRP2PZr3huiOOY+pBgqX8Y
zqqua4sk8sdq0CHCKwLelbPp4zONnNqmppQ2jN/0vPz1pe6vbsT7
                    
                    "], {{0, 0}, {11, 26}}, {0, 255}, ColorFunction -> 
                    RGBColor], ImageSize -> {11, 26}, 
                    PlotRange -> {{0, 11}, {0, 26}}], TraditionalForm], 
                    
                    Offset[{2, 2}, {
                    6.0175822137855155`, -2.2703264935560252`}], 
                    ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                    
                    DiskBox[{6.688016643036104, -3.4306867425232745`}, 
                    0.052478423386308704`], 
                    InsetBox[
                    FormBox[
                    GraphicsBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmJmYGCQAmJuIAax/xMFfn///v03bulLM2KARvnPuERAwcSzFCqI
mX8d6JhXT4Hg1XdsChgYHP0dGWDAccbeBxgKgEAvJi3NXw/KmXjiHbICvZgZ
D6BGv1uaBlak1/kKlzffHQLbprfxwW8cvvg03x9sy9l3JChACclXnY7oCoAB
8Qqu/9J8iGf3vkLzZsz8jXu3L+2EejRmKcRbZyc6QoIAEU4gkAYLhv+/Pz29
fv3OJyDj3Z29G1cvXbp0+6Gz7/BE/yjABgAnJqWw
                    "], {{0, 0}, {11,
                     26}}, {0, 255}, ColorFunction -> RGBColor], 
                    ImageSize -> {11, 26}, PlotRange -> {{0, 11}, {0, 26}}], 
                    TraditionalForm], 
                    Offset[{2, 2}, {6.740495066422413, -3.3782083191369656`}], 
                    ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                    
                    DiskBox[{7.159884817394166, -2.5216057257948923`}, 
                    0.052478423386308704`], 
                    InsetBox[
                    FormBox[
                    GraphicsBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmJmYGCQAmJuIAax/5MJfn8Hgt84pT9dmgE03HHiWfwK/ElV8P3d
0wdPnz59BbT59/X5aAourW5igAO9tM5Kf2QFD7ZXwqRiCgpi4AphCp426YEl
C1a/g2h4d6nJXw+h4NNZkHEMjofeITkHyZHfry8Fy09Ekkfxxe8Hq0HG6XXi
UvD/0wmwFf4nPmG34v/vOxA/ODbthSt4sL0J2ZtPYd50LJix99D2GZUxqN4E
mXJoBsL7iADrPIES/g8ubV+9eunS1XvP3vn+//vTO9cfvPqOK7JGASYAAA9L
rNM=
                    "], {{0, 0}, {11, 26}}, {0, 255}, ColorFunction -> 
                    RGBColor], ImageSize -> {11, 26}, 
                    PlotRange -> {{0, 11}, {0, 26}}], TraditionalForm], 
                    Offset[{2, 2}, {7.2123632407804745`, -2.469127302408584}], 
                    ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                    
                    DiskBox[{5.104055270980713, -0.873614448207543}, 
                    0.052478423386308704`], 
                    InsetBox[
                    FormBox[
                    GraphicsBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmJmYGCQAmJ2IAax/w80uD4/DeiMtKXXkQUvzYgBCvpPPEsfQcfO
E5iCQOGND35jCAKBXtOMGRMnbgQKnp3oCOTHNDU5wqSAgr8/Pb1+/c4nIOPV
9Y2rly5dvZeMYBk8AADIm9Yh
                    "], {{0, 0}, {7, 26}}, {0, 255}, 
                    ColorFunction -> RGBColor], ImageSize -> {7, 26}, 
                    PlotRange -> {{0, 7}, {0, 26}}], TraditionalForm], 
                    Offset[{2, 2}, {5.156533694367022, -0.8211360248212343}], 
                    
                    ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                    
                    DiskBox[{5.0936340590684415`, -2.420075315170594}, 
                    0.052478423386308704`], 
                    InsetBox[
                    FormBox[
                    GraphicsBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmJmYGCQAmIOIAax/w8s+P391VMQePfpO1Tk+9ONEwsYkIBj2vwH
v/9fmugI4cYUNE2cWAnlVG7//+lSU1rTiacw7a/2gqQcJ6JZc3ZpJQOy+PdX
h1bPiNGDWdF5CCj27uxSPSRrO1efBRn6/VIMRMC/cuPZO9/hRn466w92wQOY
wHeIF75fAoszFMzYfv362dWdaUD2xBOvgDLXV1cyoIKm7VDdn55e37tx9dKl
SzduP/Hg02+qB/PgAQC7PPiW
                    "], {{0, 0}, {8, 26}}, {0, 255}, 
                    ColorFunction -> RGBColor], ImageSize -> {8, 26}, 
                    PlotRange -> {{0, 8}, {0, 26}}], TraditionalForm], 
                    Offset[{2, 2}, {5.14611248245475, -2.3675968917842853`}], 
                    
                    ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                    
                    DiskBox[{4.0893098597948505`, -0.8083910213367735}, 
                    0.052478423386308704`], 
                    InsetBox[
                    FormBox[
                    GraphicsBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmJmYGCQAmJ2IAax/9Md/P707unTp6/effoNE7m+sYkBBhwnngUr
uhQD4funFcQ4Fqy+DhT7fmc1SESv6SmSaZ8uzQArm/EJU9CRBMF3yC68Ph9s
5vzvcBduX1oZo8cAsX7ijImdEw89/d7JgA6aTrz79OrVg0sbHUG8ghMPHty5
fucVxJTvYB+huvP/97P+QMGY+SiCgwwAAFKhuT4=
                    "], {{0, 0}, {7, 
                    26}}, {0, 255}, ColorFunction -> RGBColor], 
                    ImageSize -> {7, 26}, PlotRange -> {{0, 7}, {0, 26}}], 
                    TraditionalForm], 
                    Offset[{2, 2}, {4.141788283181159, -0.7559125979504648}], 
                    
                    ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                    
                    DiskBox[{6.215695355594371, -2.9999022913880706`}, 
                    0.052478423386308704`], 
                    InsetBox[
                    FormBox[
                    GraphicsBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmJmYGCQAmJuIAax/w8p8OnV0wdPn7569x2r5MYmfwYY8G/aeP3E
fCBjxtlPEOlXhzqhco4xMf56cJUTz76DKDg7EaRdr2AjxPTrG5vQFFyaEQPk
Vm5/CrfyRKc/pgK4jXARNAVw7oAoODvREcjtPIFQgCby/dWD69fvIIfx93dP
gSKvPv3GFuyjADsAAOt53ho=
                    "], {{0, 0}, {11, 26}}, {0, 255},
                     ColorFunction -> RGBColor], ImageSize -> {11, 26}, 
                    PlotRange -> {{0, 11}, {0, 26}}], TraditionalForm], 
                    Offset[{2, 2}, {6.26817377898068, -2.9474238680017617`}], 
                    
                    ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                    
                    DiskBox[{0.8717601828076917, -3.141020808670527}, 
                    0.052478423386308704`], 
                    InsetBox[
                    FormBox[
                    GraphicsBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmJmYGCQAmJOIAax/w8dcKLTnwEE0i59R5X4faeAAQqaDr1Clnl3
diIDHKStRtL3e3uBHlBs4qETnY5A2v/EJ5jM97MxINUxl37/PwuWK9j4ACLz
dHsTxJzf//9/ujQDxPafD9b3aSlYT9Pep0jucdwLdMurvY5g087CzD/UBBJI
W3r9ztI0uGkQADXTceJEkNMYKvci++UOWDXDqwd3rl9/8On3f2TwDixIZrAO
ZQAAtf1PUg==
                    "], {{0, 0}, {9, 26}}, {0, 255}, 
                    ColorFunction -> RGBColor], ImageSize -> {9, 26}, 
                    PlotRange -> {{0, 9}, {0, 26}}], TraditionalForm], 
                    Offset[{2, 2}, {0.9242386061940004, -3.088542385284218}], 
                    
                    ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                    
                    DiskBox[{1.7291396205785987`, -2.7951101292059013`}, 
                    0.052478423386308704`], 
                    InsetBox[
                    FormBox[
                    GraphicsBox[
                    RasterBox[CompressedData["
1:eJztUaGShDAM7cz6+4Bz+wP8A1/AzGrUitqrXYtD4upQqCoUCnOqpgaDqajB
IBCYigouCWWX/YFTm5nOpC8vb16S6/3ndr8wxr7hfcHDfPvE8psyjKKfIuIH
TkhW6TNx6guCWfLoAiHrIFmEyvlFDJ1IDvzhCDIyjwhL+yc1WIGcvCqw2jpQ
XSS4Sbgs+dmStw225o0bMRHttHmNtrmaxnq3tDPHmpPzAVIUFd1kJLXaLQwZ
quyW1po+lVlBvgFqInYbjfVQlVRVYGnVlGZIBNGGH4MIG16jcWUXXRJRrnE4
FXcg2rd1caUL3E9amecedlEwe5zA0FEyP7txtLM/ncvZdyTMgNjT+j/xv/EH
JeF/Zw==
                    "], {{0, 0}, {14, 26}}, {0, 255}, ColorFunction -> 
                    RGBColor], ImageSize -> {14, 26}, 
                    PlotRange -> {{0, 14}, {0, 26}}], TraditionalForm], 
                    
                    Offset[{2, 2}, {
                    1.7816180439649074`, -2.7426317058195924`}], 
                    ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                    
                    DiskBox[{3.188711043481997, -2.607258064208528}, 
                    0.052478423386308704`], 
                    InsetBox[
                    FormBox[
                    GraphicsBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmJmYGCQAmJOIAax/w96MN8f6EyGgtV34CKHOsFCaavfnZ0IYjD4
n/gEEv9+fSmYy7D0+vf//39vL9ADsvWaDv3//64TxGRw7DwBNeLTCbARjgUF
MWAdlXeQbHywvZIBBmZc+oTimu+XYqAyeie+o8icgLgKDByb9iJ0QF3luP36
iQKE84DgKcRV/hNBrnqwGizpOPHV//93lkIsKbjzG2LG0yYwP2bpne+vHly/
fv3BK4TdEJGn71BdMzIAAB4dQJ4=
                    "], {{0, 0}, {9, 26}}, {0, 
                    255}, ColorFunction -> RGBColor], ImageSize -> {9, 26}, 
                    PlotRange -> {{0, 9}, {0, 26}}], TraditionalForm], 
                    Offset[{2, 2}, {3.241189466868306, -2.554779640822219}], 
                    ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                    
                    DiskBox[{0.8083910213367735, -2.6803280265469525`}, 
                    0.052478423386308704`], 
                    InsetBox[
                    FormBox[
                    GraphicsBox[
                    RasterBox[CompressedData["
1:eJzlUKEOgzAQbTK1X5jbD/AP/YIm01WI2WFnccg6HAqFmkJhpmYwmBpEDaai
AlNRsXFXWGia7Af2kkuu967v3t05vV3SAyHktMRxCcjfP+CsMdoYGzNDyQgi
YYUM+XmoKWXU06ya489WZgmQojcxqZ8FcNcmnurG2ou+ItEuXwfeWxXO6jnZ
wAMz6nGHmmhK6KCd/jJGoFitloEcvYyrmDeQ5BrMNJDT0uwM8GrA15TDgkk7
uc0A5oheMOyU3sD+RFaiPi0E3idrp73fDJfQapRynF2wpYFiuPh/4ANLGjIw

                    "], {{0, 0}, {9, 26}}, {0, 255}, ColorFunction -> 
                    RGBColor], ImageSize -> {9, 26}, 
                    PlotRange -> {{0, 9}, {0, 26}}], TraditionalForm], 
                    
                    Offset[{2, 2}, {
                    0.8608694447230822, -2.6278496031606435`}], 
                    ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                    
                    DiskBox[{3.6377999851433134`, -1.7113080955758058`}, 
                    0.052478423386308704`], 
                    InsetBox[
                    FormBox[
                    GraphicsBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmJmYGCQAmJOIAax/w96cGl+DAMI6OkxIIOYs5/+31mdBuPq+Ts6
6oEBA0MaUOr//1cTHcESlXuxGPp0O8S0zkOvMCXvrC6AW4EBPs33B0umrf6O
KfnuENhOhsrtTzElXx3qBEv6H3oHFdg4YyIYzJg/owDmrfkgOz+dQPUs1I+H
QHK/Xz24gwGe/iY+QIcRAAA9XkVU
                    "], {{0, 0}, {9, 26}}, {0, 
                    255}, ColorFunction -> RGBColor], ImageSize -> {9, 26}, 
                    PlotRange -> {{0, 9}, {0, 26}}], TraditionalForm], 
                    Offset[{2, 2}, {3.690278408529622, -1.658829672189497}], 
                    ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}}}}}}}}], 
             MouseAppearanceTag["NetworkGraphics"]], 
            AllowKernelInitialization -> False]], 
          DefaultBaseStyle -> {
           "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
            Hue[0.8, 1., 0.6]}, FormatType -> TraditionalForm, FrameTicks -> 
          None, GridLinesStyle -> Directive[
            GrayLevel[0.5, 0.4]]]], "ExerciseOutput", Selectable -> False, 
        Copyable -> False, Editable -> False, ShowCellBracket -> False]]], " "}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Center}}},
   GridBoxBackground->{"Columns" -> {{
        RGBColor[1, 1, 1]}}},
   GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{1}}}],
  FrameMargins->0]], "ExerciseOutput",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellFrame->{{1, 1}, {1, 1}},
 ShowCellBracket->False,
 CellFrameColor->RGBColor[0.85, 0.85, 0.85],
 LineBreakWithin->
  Automatic,ExpressionUUID->"6433f86c-2e4d-4a39-ac55-a48ee69401d6"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Generate a table of the results of using ",
 ButtonBox["TextRecognize",
  BaseStyle->"Link"],
 " on \[OpenCurlyDoubleQuote]hello\[CloseCurlyDoubleQuote] rasterized at size \
50 and then blurred by between 1 and 10.",
 StyleBox[ButtonBox["\[NonBreakingSpace]\[RightGuillemet]",
  Appearance->None,
  Evaluator->Automatic,
  Method->"Preemptive",
  ButtonFunction:>(SelectionMove[
     ButtonNotebook[], All, ButtonCell, AutoScroll -> False]; 
   FrontEndExecute[
     FrontEndToken[
      ButtonNotebook[], "OpenCloseGroup"]])],
  FontColor->RGBColor[1, 0.501961, 0]]
}], "Exercise",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellDingbat->Cell[
  "22.14", "ExerciseNumber", FontColor -> 
   RGBColor[0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]],
 ShowCellBracket->
  False,ExpressionUUID->"54d781eb-9c41-4a78-89a9-f7ae2bc22039"],

Cell[BoxData[
 PaneBox[GridBox[{
    {" ", 
     StyleBox[
      RowBox[{"Expected", " ", 
       RowBox[{"output", ":"}]}],
      Editable->False,
      Selectable->False,
      StripOnInput->False,
      FontColor->RGBColor[0.45, 0.45, 0.45]], " "},
    {" ", 
     InterpretationBox[Cell[BoxData[
       RowBox[{"{", 
        RowBox[{"\<\"hello\"\>", ",", "\<\"hello\"\>", ",", "\<\"hello\"\>", 
         ",", "\<\"hello\"\>", ",", "\<\"hello\"\>", ",", "\<\"hello\"\>", 
         ",", "\<\"hllo\"\>", ",", "\<\"\"\>", ",", "\<\"\"\>", 
         ",", "\<\"\"\>"}], "}"}]], "ExerciseOutput",ExpressionUUID->
       "4a50b126-4cbd-4f54-859c-9094e9f39bdf"],
      Apply[TextCell, 
       Cell[
        BoxData[
         RowBox[{"{", 
           
           RowBox[{"\"hello\"", ",", "\"hello\"", ",", "\"hello\"", ",", 
             "\"hello\"", ",", "\"hello\"", ",", "\"hello\"", ",", "\"hllo\"",
              ",", "\"\"", ",", "\"\"", ",", "\"\""}], "}"}]], 
        "ExerciseOutput", Selectable -> False, Copyable -> False, Editable -> 
        False, ShowCellBracket -> False]]], " "}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Center}}},
   GridBoxBackground->{"Columns" -> {{
        RGBColor[1, 1, 1]}}},
   GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{1}}}],
  FrameMargins->0]], "ExerciseOutput",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellFrame->{{1, 1}, {1, 1}},
 ShowCellBracket->False,
 CellFrameColor->RGBColor[0.85, 0.85, 0.85],
 LineBreakWithin->
  Automatic,ExpressionUUID->"e37ac0c6-4af1-4453-b852-55c815038b19"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Make a dendrogram for images of the first 10 letters of the alphabet.",
 StyleBox[ButtonBox["\[NonBreakingSpace]\[RightGuillemet]",
  Appearance->None,
  Evaluator->Automatic,
  Method->"Preemptive",
  ButtonFunction:>(SelectionMove[
     ButtonNotebook[], All, ButtonCell, AutoScroll -> False]; 
   FrontEndExecute[
     FrontEndToken[
      ButtonNotebook[], "OpenCloseGroup"]])],
  FontColor->RGBColor[1, 0.501961, 0]]
}], "Exercise",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellDingbat->Cell[
  "22.15", "ExerciseNumber", FontColor -> 
   RGBColor[0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]],
 ShowCellBracket->
  False,ExpressionUUID->"add4548d-4996-4940-90e5-7e7787706248"],

Cell[BoxData[
 PaneBox[GridBox[{
    {" ", 
     StyleBox[
      RowBox[{"Expected", " ", 
       RowBox[{"output", ":"}]}],
      Editable->False,
      Selectable->False,
      StripOnInput->False,
      FontColor->RGBColor[0.45, 0.45, 0.45]], " "},
    {" ", 
     InterpretationBox[Cell[BoxData[
       GraphicsBox[{
         {GrayLevel[0.65], 
          LineBox[{{{49.6875, 55.979950789261906`}, {49.6875, 
            64.76639411696317}}, {{95., 58.74734182225931}, {95., 
            64.76639411696317}}, {{49.6875, 64.76639411696317}, {95., 
            64.76639411696317}}, {{24.375, 47.616920746650024`}, {24.375, 
            55.979950789261906`}}, {{75., 52.768529573571044`}, {75., 
            55.979950789261906`}}, {{24.375, 55.979950789261906`}, {75., 
            55.979950789261906`}}, {{10, 0}, {10., 47.616920746650024`}}, {{
            38.75, 42.54789039833263}, {38.75, 47.616920746650024`}}, {{10., 
            47.616920746650024`}, {38.75, 47.616920746650024`}}, {{25., 
            24.624907760325}, {25., 42.54789039833263}}, {{52.5, 
            42.534559923165226`}, {52.5, 42.54789039833263}}, {{25., 
            42.54789039833263}, {52.5, 
            42.54789039833263}}, {{20, 0}, {20., 24.624907760325}}, {{30, 
             0}, {30., 24.624907760325}}, {{20., 24.624907760325}, {30., 
            24.624907760325}}, {{45., 23.859342456805184`}, {45., 
            42.534559923165226`}}, {{60, 0}, {60., 42.534559923165226`}}, {{
            45., 42.534559923165226`}, {60., 
            42.534559923165226`}}, {{40, 0}, {40., 23.859342456805184`}}, {{
             50, 0}, {50., 23.859342456805184`}}, {{40., 
            23.859342456805184`}, {50., 
            23.859342456805184`}}, {{70, 0}, {70., 52.768529573571044`}}, {{
             80, 0}, {80., 52.768529573571044`}}, {{70., 
            52.768529573571044`}, {80., 
            52.768529573571044`}}, {{90, 0}, {90., 58.74734182225931}}, {{100,
              0}, {100., 58.74734182225931}}, {{90., 58.74734182225931}, {
            100., 58.74734182225931}}}]}, InsetBox[
          FrameBox[
           TagBox[
            GraphicsBox[
             TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UFAYiEEqQez/Qwe8u36os8CfAQxiOje+gwp/mqgHEpixeuOMSpBszNLrEInv
7179hqp5WsnAoNd5Am7SodUTYxz1IEYxOM4AG/W00xHEK5i4+tKds016IPFP
////frARKJi2/RXEyPn+UPH/T7eD7Jq4/cHT60ub/JHMebe0wJEB5sqJBXoM
/vM/wSwGOunVOziPmgAAFIx/gw==
               "], {{0, 19}, {8, 0}}, {0, 255},
               ColorFunction->RGBColor],
              BoxForm`ImageTag[
              "Byte", ColorSpace -> "RGB", Interleaving -> True, 
               Magnification -> Automatic],
              Selectable->False],
             DefaultBaseStyle->"ImageGraphics",
             ImageSize->{
               Rational[67, 10], 19},
             ImageSizeRaw->{8, 19},
             PlotRange->{{0, 8}, {0, 19}}],
            Short],
           Background->GrayLevel[1],
           FrameMargins->{{0, 0}, {0, 0}},
           FrameStyle->GrayLevel[1],
           RoundingRadius->2,
           StripOnInput->False], {10, 0}, Scaled[{0.5, 1}]], InsetBox[
          FrameBox[
           TagBox[
            GraphicsBox[
             TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UFAYiEEqQez/1APfP336/htT+NNEPQa9zrOY4jMcGRwn4hK/hFWcoWDG/KYY
oLMZ9Pwnbr8DEZ/vDxJg8K9cunp+mh6IOf/6J5j6jd8hul/tBfLA1qHZC9bu
Px9THKQ9Zim6e17tBdrgP+MSzF69ztWHrl/aWwC2d/WD7yD1/gyOaRCHgBVA
3QkDv7+/e/UOW0BRBADqRHM1
               "], {{0, 19}, {8, 0}}, {0, 255},
               ColorFunction->RGBColor],
              BoxForm`ImageTag[
              "Byte", ColorSpace -> "RGB", Interleaving -> True, 
               Magnification -> Automatic],
              Selectable->False],
             DefaultBaseStyle->"ImageGraphics",
             ImageSize->{
               Rational[67, 10], 19},
             ImageSizeRaw->{8, 19},
             PlotRange->{{0, 8}, {0, 19}}],
            Short],
           Background->GrayLevel[1],
           FrameMargins->{{0, 0}, {0, 0}},
           FrameStyle->GrayLevel[1],
           RoundingRadius->2,
           StripOnInput->False], {20, 0}, Scaled[{0.5, 1}]], InsetBox[
          FrameBox[
           TagBox[
            GraphicsBox[
             TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UFAYiEEqQez/1APfP336/htT+NNEPQa9zrOY4jMcGRwn4hK/hFVcr2n1xolp
DCDgOHHvA4j4/BiwgF7B/KUT/UEs/7PfoeoZ0ua/Ayt6d6ITqOXEJ5j5M6Dm
f7o0Ayh+Fi4Ocw/1xOeD3POJqACkBAAApDmCLw==
               "], {{0, 19}, {8, 
               0}}, {0, 255},
               ColorFunction->RGBColor],
              BoxForm`ImageTag[
              "Byte", ColorSpace -> "RGB", Interleaving -> True, 
               Magnification -> Automatic],
              Selectable->False],
             DefaultBaseStyle->"ImageGraphics",
             ImageSize->{
               Rational[67, 10], 19},
             ImageSizeRaw->{8, 19},
             PlotRange->{{0, 8}, {0, 19}}],
            Short],
           Background->GrayLevel[1],
           FrameMargins->{{0, 0}, {0, 0}},
           FrameStyle->GrayLevel[1],
           RoundingRadius->2,
           StripOnInput->False], {30, 0}, Scaled[{0.5, 1}]], InsetBox[
          FrameBox[
           TagBox[
            GraphicsBox[
             TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UFAYiNmBGMT+P0jBu+0TCxwZQMC/YMb1d7////++Og3MrZyxdH6nHgND06FX
36/PB4o4Nh2CavoNVPb/06UZQMHVD34jGwcW1Nv76j+GIEPa0juoVj9oAtmj
N3H72Tt3TnT6M1RufAAy+9UJqIPArlh9CWHWp3fvXr379Ps/FQAAlctd6A==

               "], {{0, 19}, {7, 0}}, {0, 255},
               ColorFunction->RGBColor],
              BoxForm`ImageTag[
              "Byte", ColorSpace -> "RGB", Interleaving -> True, 
               Magnification -> Automatic],
              Selectable->False],
             DefaultBaseStyle->"ImageGraphics",
             ImageSize->{
               Rational[67, 10], 19},
             ImageSizeRaw->{7, 19},
             PlotRange->{{0, 7}, {0, 19}}],
            Short],
           Background->GrayLevel[1],
           FrameMargins->{{0, 0}, {0, 0}},
           FrameStyle->GrayLevel[1],
           RoundingRadius->2,
           StripOnInput->False], {40, 0}, Scaled[{0.5, 1}]], InsetBox[
          FrameBox[
           TagBox[
            GraphicsBox[
             TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UFAYiNmBGMT+P0jBq9WdaXoMIJDWufEdSOT76jQQt2DG6o3zm4AMx4lnv1+f
D2RUbn8K0XNnvj8DQ+enSzNAsgVNnU1A0FkQA+TpQQRjmibOAIKJYHLGaojg
xLOfUK1+2gSyWG/G9rMPHlzfOLGgafV1kPC7s03+DHBQufQsXMP3T+9evXr3
/TcVvA0AsaNMNg==
               "], {{0, 19}, {7, 0}}, {0, 255},
               ColorFunction->RGBColor],
              BoxForm`ImageTag[
              "Byte", ColorSpace -> "RGB", Interleaving -> True, 
               Magnification -> Automatic],
              Selectable->False],
             DefaultBaseStyle->"ImageGraphics",
             ImageSize->{
               Rational[67, 10], 19},
             ImageSizeRaw->{7, 19},
             PlotRange->{{0, 7}, {0, 19}}],
            Short],
           Background->GrayLevel[1],
           FrameMargins->{{0, 0}, {0, 0}},
           FrameStyle->GrayLevel[1],
           RoundingRadius->2,
           StripOnInput->False], {50, 0}, Scaled[{0.5, 1}]], InsetBox[
          FrameBox[
           TagBox[
            GraphicsBox[
             TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UFAYiEEqQez/tAK/P3369BtD9NOlGUBLJ579hEP8Hbop1+cjxH8/XdoUowfk
6/mn+QMphhkg8e9L00Bs/8oZS2c0MYABUP3360uBDMfOvVDzz0LNh1i09M53
NHvBDL3tT39jE2foPPQOZs5EqHu+X4dYu/TE9esnlvrD7AWqeXdpNYQLBJWd
TUAHz78E9+/3d69effqOGTCUAgBRm2wL
               "], {{0, 19}, {8, 0}}, {0, 
               255},
               ColorFunction->RGBColor],
              BoxForm`ImageTag[
              "Byte", ColorSpace -> "RGB", Interleaving -> True, 
               Magnification -> Automatic],
              Selectable->False],
             DefaultBaseStyle->"ImageGraphics",
             ImageSize->{
               Rational[67, 10], 19},
             ImageSizeRaw->{8, 19},
             PlotRange->{{0, 8}, {0, 19}}],
            Short],
           Background->GrayLevel[1],
           FrameMargins->{{0, 0}, {0, 0}},
           FrameStyle->GrayLevel[1],
           RoundingRadius->2,
           StripOnInput->False], {60, 0}, Scaled[{0.5, 1}]], InsetBox[
          FrameBox[
           TagBox[
            GraphicsBox[
             
             TagBox[RasterBox[
               RawArray["UnsignedInteger8",{{{255, 255, 255}, {255, 255, 
                255}, {255, 255, 255}, {255, 255, 255}, {255, 255, 255}}, {{
                255, 255, 255}, {255, 255, 255}, {255, 255, 255}, {255, 255, 
                255}, {255, 255, 255}}, {{255, 255, 255}, {255, 255, 255}, {
                255, 255, 255}, {255, 255, 255}, {255, 255, 255}}, {{255, 255,
                 255}, {255, 255, 255}, {251, 242, 229}, {220, 215, 220}, {
                229, 238, 242}}, {{255, 255, 255}, {242, 210, 165}, {0, 0, 
                0}, {0, 0, 0}, {0, 0, 137}}, {{255, 255, 255}, {205, 145, 
                65}, {0, 0, 102}, {194, 220, 229}, {229, 229, 238}}, {{255, 
                255, 255}, {215, 159, 79}, {0, 65, 159}, {251, 255, 255}, {
                255, 255, 255}}, {{220, 177, 130}, {46, 0, 0}, {0, 0, 0}, {65,
                 65, 79}, {165, 215, 242}}, {{224, 189, 159}, {92, 65, 0}, {0,
                 0, 65}, {112, 130, 137}, {189, 224, 247}}, {{255, 255, 
                255}, {215, 159, 79}, {0, 46, 152}, {247, 255, 255}, {255, 
                255, 255}}, {{255, 255, 255}, {210, 152, 65}, {0, 46, 152}, {
                242, 255, 255}, {255, 255, 255}}, {{255, 255, 255}, {210, 152,
                 65}, {0, 46, 152}, {242, 255, 255}, {255, 255, 255}}, {{255, 
                255, 255}, {210, 152, 65}, {0, 46, 152}, {242, 255, 255}, {
                255, 255, 255}}, {{255, 255, 255}, {210, 152, 65}, {0, 46, 
                152}, {242, 255, 255}, {255, 255, 255}}, {{255, 255, 255}, {
                210, 152, 79}, {0, 65, 152}, {242, 255, 255}, {255, 255, 
                255}}, {{255, 255, 255}, {255, 255, 255}, {255, 255, 255}, {
                255, 255, 255}, {255, 255, 255}}, {{255, 255, 255}, {255, 255,
                 255}, {255, 255, 255}, {255, 255, 255}, {255, 255, 255}}, {{
                255, 255, 255}, {255, 255, 255}, {255, 255, 255}, {255, 255, 
                255}, {255, 255, 255}}, {{255, 255, 255}, {255, 255, 255}, {
                255, 255, 255}, {255, 255, 255}, {255, 255, 255}}}], {{0, 
               19}, {5, 0}}, {0, 255},
               ColorFunction->RGBColor],
              BoxForm`ImageTag[
              "Byte", ColorSpace -> "RGB", Interleaving -> True, 
               Magnification -> Automatic],
              Selectable->False],
             DefaultBaseStyle->"ImageGraphics",
             ImageSize->{
               Rational[67, 10], 19},
             ImageSizeRaw->{5, 19},
             PlotRange->{{0, 5}, {0, 19}}],
            Short],
           Background->GrayLevel[1],
           FrameMargins->{{0, 0}, {0, 0}},
           FrameStyle->GrayLevel[1],
           RoundingRadius->2,
           StripOnInput->False], {70, 0}, Scaled[{0.5, 1}]], InsetBox[
          FrameBox[
           TagBox[
            GraphicsBox[
             
             TagBox[RasterBox[
               RawArray["UnsignedInteger8",{{{255, 255, 255}, {255, 255, 
                255}, {255, 255, 255}, {255, 255, 255}}, {{255, 255, 255}, {
                255, 255, 255}, {255, 255, 255}, {255, 255, 255}}, {{255, 255,
                 255}, {255, 255, 255}, {255, 255, 255}, {255, 255, 255}}, {{
                255, 255, 255}, {255, 255, 255}, {255, 255, 255}, {255, 255, 
                255}}, {{255, 251, 224}, {145, 102, 79}, {102, 145, 189}, {
                251, 255, 255}}, {{255, 247, 205}, {65, 0, 0}, {0, 46, 145}, {
                242, 255, 255}}, {{255, 255, 255}, {251, 247, 247}, {251, 251,
                 255}, {255, 255, 255}}, {{255, 255, 242}, {177, 121, 79}, {
                121, 171, 215}, {255, 255, 255}}, {{255, 255, 242}, {152, 46, 
                0}, {46, 145, 205}, {255, 255, 255}}, {{255, 255, 242}, {152, 
                65, 0}, {65, 145, 205}, {255, 255, 255}}, {{255, 255, 242}, {
                152, 65, 0}, {65, 145, 205}, {255, 255, 255}}, {{255, 255, 
                242}, {152, 65, 0}, {65, 145, 205}, {255, 255, 255}}, {{255, 
                255, 242}, {152, 65, 0}, {65, 145, 205}, {255, 255, 255}}, {{
                255, 255, 242}, {152, 65, 0}, {65, 145, 205}, {255, 255, 
                255}}, {{255, 255, 242}, {152, 65, 0}, {65, 145, 205}, {255, 
                255, 255}}, {{255, 255, 255}, {255, 255, 255}, {255, 255, 
                255}, {255, 255, 255}}, {{255, 255, 255}, {255, 255, 255}, {
                255, 255, 255}, {255, 255, 255}}, {{255, 255, 255}, {255, 255,
                 255}, {255, 255, 255}, {255, 255, 255}}, {{255, 255, 255}, {
                255, 255, 255}, {255, 255, 255}, {255, 255, 255}}}], {{0, 
               19}, {4, 0}}, {0, 255},
               ColorFunction->RGBColor],
              BoxForm`ImageTag[
              "Byte", ColorSpace -> "RGB", Interleaving -> True, 
               Magnification -> Automatic],
              Selectable->False],
             DefaultBaseStyle->"ImageGraphics",
             ImageSize->{
               Rational[67, 10], 19},
             ImageSizeRaw->{4, 19},
             PlotRange->{{0, 4}, {0, 19}}],
            Short],
           Background->GrayLevel[1],
           FrameMargins->{{0, 0}, {0, 0}},
           FrameStyle->GrayLevel[1],
           RoundingRadius->2,
           StripOnInput->False], {80, 0}, Scaled[{0.5, 1}]], InsetBox[
          FrameBox[
           TagBox[
            GraphicsBox[
             
             TagBox[RasterBox[
               RawArray["UnsignedInteger8",{{{255, 255, 255}, {255, 255, 
                255}, {255, 255, 255}, {255, 255, 255}}, {{255, 255, 255}, {
                255, 255, 255}, {255, 255, 255}, {255, 255, 255}}, {{255, 255,
                 255}, {255, 255, 255}, {255, 255, 255}, {255, 255, 255}}, {{
                255, 255, 255}, {255, 255, 255}, {255, 255, 255}, {255, 255, 
                255}}, {{255, 255, 255}, {255, 251, 224}, {152, 102, 79}, {
                102, 145, 189}}, {{255, 255, 255}, {255, 247, 205}, {65, 0, 
                0}, {0, 46, 145}}, {{255, 255, 255}, {255, 255, 255}, {251, 
                247, 247}, {251, 251, 255}}, {{255, 255, 255}, {255, 255, 
                242}, {177, 121, 79}, {121, 171, 215}}, {{255, 255, 255}, {
                255, 255, 242}, {152, 46, 0}, {46, 145, 205}}, {{255, 255, 
                255}, {255, 255, 242}, {152, 65, 0}, {65, 145, 205}}, {{255, 
                255, 255}, {255, 255, 242}, {152, 65, 0}, {65, 145, 205}}, {{
                255, 255, 255}, {255, 255, 242}, {152, 65, 0}, {65, 145, 
                205}}, {{255, 255, 255}, {255, 255, 242}, {152, 65, 0}, {65, 
                145, 205}}, {{255, 255, 255}, {255, 255, 242}, {152, 65, 0}, {
                65, 145, 205}}, {{255, 255, 255}, {255, 255, 242}, {152, 65, 
                0}, {65, 145, 205}}, {{255, 255, 255}, {255, 255, 242}, {159, 
                65, 0}, {65, 145, 205}}, {{247, 238, 234}, {224, 210, 177}, {
                65, 0, 0}, {79, 145, 205}}, {{177, 92, 0}, {0, 0, 0}, {0, 0, 
                46}, {177, 224, 247}}, {{247, 242, 234}, {224, 224, 224}, {
                234, 242, 255}, {255, 255, 255}}}], {{0, 19}, {4, 0}}, {0, 
               255},
               ColorFunction->RGBColor],
              BoxForm`ImageTag[
              "Byte", ColorSpace -> "RGB", Interleaving -> True, 
               Magnification -> Automatic],
              Selectable->False],
             DefaultBaseStyle->"ImageGraphics",
             ImageSize->{
               Rational[67, 10], 19},
             ImageSizeRaw->{4, 19},
             PlotRange->{{0, 4}, {0, 19}}],
            Short],
           Background->GrayLevel[1],
           FrameMargins->{{0, 0}, {0, 0}},
           FrameStyle->GrayLevel[1],
           RoundingRadius->2,
           StripOnInput->False], {90, 0}, Scaled[{0.5, 1}]], InsetBox[
          FrameBox[
           TagBox[
            GraphicsBox[
             TagBox[RasterBox[CompressedData["
1:eJzVkKFuwzAQhq2NFE7aE+wFgkcNhyJ1GgtptbgayaJ00lQaFmiWFwgKCgoq
KTIxMQkxMDEJCDhiEOCdE3XS9gY9ydbnu//uP/lp/7lld4SQ4wav7e6bFsXu
9PqAj7fs+HHI0veX7Cs9pMXz/h6Tj3iCMrC/nZitKBOKO5MoZozFNG4UeG9O
IcU6IZoyCZhUwjoPEqWVhKVVYyHvbUAQmM9bHXi6ILOVvevyCLtx9OIRi2m1
tZwSmvOa87rpDVy3ARmjFe+1MXqJEealMFXkX0SdmUHVATTMDsA5MD26UC4n
gfKoHVYzp9oSG8rL6N1Q0j9TGD+760+MVg9KquHX1P8AAj5dUg==
               "], {{0, 
               19}, {8, 0}}, {0, 255},
               ColorFunction->RGBColor],
              BoxForm`ImageTag[
              "Byte", ColorSpace -> "RGB", Interleaving -> True, 
               Magnification -> Automatic],
              Selectable->False],
             DefaultBaseStyle->"ImageGraphics",
             ImageSize->{
               Rational[67, 10], 19},
             ImageSizeRaw->{8, 19},
             PlotRange->{{0, 8}, {0, 19}}],
            Short],
           Background->GrayLevel[1],
           FrameMargins->{{0, 0}, {0, 0}},
           FrameStyle->GrayLevel[1],
           RoundingRadius->2,
           StripOnInput->False], {100, 0}, Scaled[{0.5, 1}]]},
        AlignmentPoint->Center,
        AspectRatio->NCache[2^Rational[-1, 2], 0.7071067811865475],
        Axes->False,
        AxesLabel->None,
        AxesOrigin->Automatic,
        AxesStyle->{},
        Background->None,
        BaseStyle->{},
        BaselinePosition->Automatic,
        ColorOutput->Automatic,
        ContentSelectable->Automatic,
        CoordinatesToolOptions:>Automatic,
        DisplayFunction:>$DisplayFunction,
        Epilog->{},
        FormatType:>TraditionalForm,
        Frame->False,
        FrameLabel->None,
        FrameStyle->{},
        FrameTicks->Automatic,
        FrameTicksStyle->{},
        GridLines->None,
        GridLinesStyle->{},
        ImageMargins->0.,
        ImagePadding->All,
        ImageSize->Automatic,
        ImageSizeRaw->Automatic,
        LabelStyle->{},
        Method->Automatic,
        PlotLabel->None,
        PlotRange->All,
        PlotRangeClipping->False,
        PlotRangePadding->Automatic,
        PlotRegion->Automatic,
        PreserveImageOptions->Automatic,
        Prolog->{},
        RotateLabel->True,
        Ticks->Automatic,
        TicksStyle->{}]], "ExerciseOutput",ExpressionUUID->
       "743247ea-277d-460d-a75f-2ff508225816"],
      Apply[TextCell, 
       Cell[
        BoxData[
         GraphicsBox[{{{{{{
                GrayLevel[0.65], 
                
                LineBox[{{{49.6875, 55.979950789261906`}, {49.6875, 
                  64.76639411696317}}, {{95., 58.74734182225931}, {95., 
                  64.76639411696317}}, {{49.6875, 64.76639411696317}, {95., 
                  64.76639411696317}}, {{24.375, 47.616920746650024`}, {
                  24.375, 55.979950789261906`}}, {{75., 
                  52.768529573571044`}, {75., 55.979950789261906`}}, {{24.375,
                   55.979950789261906`}, {75., 
                  55.979950789261906`}}, {{10, 0}, {10., 
                   47.616920746650024`}}, {{38.75, 42.54789039833263}, {38.75,
                   47.616920746650024`}}, {{10., 47.616920746650024`}, {38.75,
                   47.616920746650024`}}, {{25., 24.624907760325}, {25., 
                  42.54789039833263}}, {{52.5, 42.534559923165226`}, {52.5, 
                  42.54789039833263}}, {{25., 42.54789039833263}, {52.5, 
                  42.54789039833263}}, {{20, 0}, {20., 24.624907760325}}, {{
                   30, 0}, {30., 24.624907760325}}, {{20., 24.624907760325}, {
                  30., 24.624907760325}}, {{45., 23.859342456805184`}, {45., 
                  42.534559923165226`}}, {{60, 0}, {60., 
                   42.534559923165226`}}, {{45., 42.534559923165226`}, {60., 
                  42.534559923165226`}}, {{40, 0}, {40., 
                   23.859342456805184`}}, {{50, 0}, {50., 
                   23.859342456805184`}}, {{40., 23.859342456805184`}, {50., 
                  23.859342456805184`}}, {{70, 0}, {70., 
                   52.768529573571044`}}, {{80, 0}, {80., 
                   52.768529573571044`}}, {{70., 52.768529573571044`}, {80., 
                  52.768529573571044`}}, {{90, 0}, {90., 
                   58.74734182225931}}, {{100, 0}, {100., 
                   58.74734182225931}}, {{90., 58.74734182225931}, {100., 
                  58.74734182225931}}}]}}}}}, 
           InsetBox[
            FrameBox[
             TagBox[
              GraphicsBox[
               TagBox[
                RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UFAYiEEqQez/Qwe8u36os8CfAQxiOje+gwp/mqgHEpixeuOMSpBszNLrEInv
7179hqp5WsnAoNd5Am7SodUTYxz1IEYxOM4AG/W00xHEK5i4+tKds016IPFP
////frARKJi2/RXEyPn+UPH/T7eD7Jq4/cHT60ub/JHMebe0wJEB5sqJBXoM
/vM/wSwGOunVOziPmgAAFIx/gw==
                 "], {{0, 19}, {8, 0}}, {0, 255},
                  ColorFunction -> RGBColor], 
                BoxForm`ImageTag[
                "Byte", ColorSpace -> "RGB", Interleaving -> True, 
                 Magnification -> Automatic], Selectable -> False], 
               DefaultBaseStyle -> "ImageGraphics", ImageSize -> {
                 Rational[67, 10], 19}, ImageSizeRaw -> {8, 19}, 
               PlotRange -> {{0, 8}, {0, 19}}], Short], Background -> 
             GrayLevel[1], FrameMargins -> {{0, 0}, {0, 0}}, FrameStyle -> 
             GrayLevel[1], RoundingRadius -> 2, StripOnInput -> False], {10, 
            0}, 
            Scaled[{0.5, 1}]], 
           InsetBox[
            FrameBox[
             TagBox[
              GraphicsBox[
               TagBox[
                RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UFAYiEEqQez/1APfP336/htT+NNEPQa9zrOY4jMcGRwn4hK/hFWcoWDG/KYY
oLMZ9Pwnbr8DEZ/vDxJg8K9cunp+mh6IOf/6J5j6jd8hul/tBfLA1qHZC9bu
Px9THKQ9Zim6e17tBdrgP+MSzF69ztWHrl/aWwC2d/WD7yD1/gyOaRCHgBVA
3QkDv7+/e/UOW0BRBADqRHM1
                 "], {{0, 19}, {8, 0}}, {0, 255}, 
                 ColorFunction -> RGBColor], 
                BoxForm`ImageTag[
                "Byte", ColorSpace -> "RGB", Interleaving -> True, 
                 Magnification -> Automatic], Selectable -> False], 
               DefaultBaseStyle -> "ImageGraphics", ImageSize -> {
                 Rational[67, 10], 19}, ImageSizeRaw -> {8, 19}, 
               PlotRange -> {{0, 8}, {0, 19}}], Short], Background -> 
             GrayLevel[1], FrameMargins -> {{0, 0}, {0, 0}}, FrameStyle -> 
             GrayLevel[1], RoundingRadius -> 2, StripOnInput -> False], {20, 
            0}, 
            Scaled[{0.5, 1}]], 
           InsetBox[
            FrameBox[
             TagBox[
              GraphicsBox[
               TagBox[
                RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UFAYiEEqQez/1APfP336/htT+NNEPQa9zrOY4jMcGRwn4hK/hFVcr2n1xolp
DCDgOHHvA4j4/BiwgF7B/KUT/UEs/7PfoeoZ0ua/Ayt6d6ITqOXEJ5j5M6Dm
f7o0Ayh+Fi4Ocw/1xOeD3POJqACkBAAApDmCLw==
                 "], {{0, 19}, {8, 
                 0}}, {0, 255}, ColorFunction -> RGBColor], 
                BoxForm`ImageTag[
                "Byte", ColorSpace -> "RGB", Interleaving -> True, 
                 Magnification -> Automatic], Selectable -> False], 
               DefaultBaseStyle -> "ImageGraphics", ImageSize -> {
                 Rational[67, 10], 19}, ImageSizeRaw -> {8, 19}, 
               PlotRange -> {{0, 8}, {0, 19}}], Short], Background -> 
             GrayLevel[1], FrameMargins -> {{0, 0}, {0, 0}}, FrameStyle -> 
             GrayLevel[1], RoundingRadius -> 2, StripOnInput -> False], {30, 
            0}, 
            Scaled[{0.5, 1}]], 
           InsetBox[
            FrameBox[
             TagBox[
              GraphicsBox[
               TagBox[
                RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UFAYiNmBGMT+P0jBu+0TCxwZQMC/YMb1d7////++Og3MrZyxdH6nHgND06FX
36/PB4o4Nh2CavoNVPb/06UZQMHVD34jGwcW1Nv76j+GIEPa0juoVj9oAtmj
N3H72Tt3TnT6M1RufAAy+9UJqIPArlh9CWHWp3fvXr379Ps/FQAAlctd6A==

                 "], {{0, 19}, {7, 0}}, {0, 255}, ColorFunction -> RGBColor], 
                
                BoxForm`ImageTag[
                "Byte", ColorSpace -> "RGB", Interleaving -> True, 
                 Magnification -> Automatic], Selectable -> False], 
               DefaultBaseStyle -> "ImageGraphics", ImageSize -> {
                 Rational[67, 10], 19}, ImageSizeRaw -> {7, 19}, 
               PlotRange -> {{0, 7}, {0, 19}}], Short], Background -> 
             GrayLevel[1], FrameMargins -> {{0, 0}, {0, 0}}, FrameStyle -> 
             GrayLevel[1], RoundingRadius -> 2, StripOnInput -> False], {40, 
            0}, 
            Scaled[{0.5, 1}]], 
           InsetBox[
            FrameBox[
             TagBox[
              GraphicsBox[
               TagBox[
                RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UFAYiNmBGMT+P0jBq9WdaXoMIJDWufEdSOT76jQQt2DG6o3zm4AMx4lnv1+f
D2RUbn8K0XNnvj8DQ+enSzNAsgVNnU1A0FkQA+TpQQRjmibOAIKJYHLGaojg
xLOfUK1+2gSyWG/G9rMPHlzfOLGgafV1kPC7s03+DHBQufQsXMP3T+9evXr3
/TcVvA0AsaNMNg==
                 "], {{0, 19}, {7, 0}}, {0, 255}, 
                 ColorFunction -> RGBColor], 
                BoxForm`ImageTag[
                "Byte", ColorSpace -> "RGB", Interleaving -> True, 
                 Magnification -> Automatic], Selectable -> False], 
               DefaultBaseStyle -> "ImageGraphics", ImageSize -> {
                 Rational[67, 10], 19}, ImageSizeRaw -> {7, 19}, 
               PlotRange -> {{0, 7}, {0, 19}}], Short], Background -> 
             GrayLevel[1], FrameMargins -> {{0, 0}, {0, 0}}, FrameStyle -> 
             GrayLevel[1], RoundingRadius -> 2, StripOnInput -> False], {50, 
            0}, 
            Scaled[{0.5, 1}]], 
           InsetBox[
            FrameBox[
             TagBox[
              GraphicsBox[
               TagBox[
                RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UFAYiEEqQez/tAK/P3369BtD9NOlGUBLJ579hEP8Hbop1+cjxH8/XdoUowfk
6/mn+QMphhkg8e9L00Bs/8oZS2c0MYABUP3360uBDMfOvVDzz0LNh1i09M53
NHvBDL3tT39jE2foPPQOZs5EqHu+X4dYu/TE9esnlvrD7AWqeXdpNYQLBJWd
TUAHz78E9+/3d69effqOGTCUAgBRm2wL
                 "], {{0, 19}, {8, 0}}, {0, 
                 255}, ColorFunction -> RGBColor], 
                BoxForm`ImageTag[
                "Byte", ColorSpace -> "RGB", Interleaving -> True, 
                 Magnification -> Automatic], Selectable -> False], 
               DefaultBaseStyle -> "ImageGraphics", ImageSize -> {
                 Rational[67, 10], 19}, ImageSizeRaw -> {8, 19}, 
               PlotRange -> {{0, 8}, {0, 19}}], Short], Background -> 
             GrayLevel[1], FrameMargins -> {{0, 0}, {0, 0}}, FrameStyle -> 
             GrayLevel[1], RoundingRadius -> 2, StripOnInput -> False], {60, 
            0}, 
            Scaled[{0.5, 1}]], 
           InsetBox[
            FrameBox[
             TagBox[
              GraphicsBox[
               TagBox[
                RasterBox[
                RawArray["UnsignedInteger8",{{{255, 255, 255}, {255, 255, 
                  255}, {255, 255, 255}, {255, 255, 255}, {255, 255, 255}}, {{
                  255, 255, 255}, {255, 255, 255}, {255, 255, 255}, {255, 255,
                   255}, {255, 255, 255}}, {{255, 255, 255}, {255, 255, 
                  255}, {255, 255, 255}, {255, 255, 255}, {255, 255, 255}}, {{
                  255, 255, 255}, {255, 255, 255}, {251, 242, 229}, {220, 215,
                   220}, {229, 238, 242}}, {{255, 255, 255}, {242, 210, 
                  165}, {0, 0, 0}, {0, 0, 0}, {0, 0, 137}}, {{255, 255, 
                  255}, {205, 145, 65}, {0, 0, 102}, {194, 220, 229}, {229, 
                  229, 238}}, {{255, 255, 255}, {215, 159, 79}, {0, 65, 
                  159}, {251, 255, 255}, {255, 255, 255}}, {{220, 177, 130}, {
                  46, 0, 0}, {0, 0, 0}, {65, 65, 79}, {165, 215, 242}}, {{224,
                   189, 159}, {92, 65, 0}, {0, 0, 65}, {112, 130, 137}, {189, 
                  224, 247}}, {{255, 255, 255}, {215, 159, 79}, {0, 46, 
                  152}, {247, 255, 255}, {255, 255, 255}}, {{255, 255, 255}, {
                  210, 152, 65}, {0, 46, 152}, {242, 255, 255}, {255, 255, 
                  255}}, {{255, 255, 255}, {210, 152, 65}, {0, 46, 152}, {242,
                   255, 255}, {255, 255, 255}}, {{255, 255, 255}, {210, 152, 
                  65}, {0, 46, 152}, {242, 255, 255}, {255, 255, 255}}, {{255,
                   255, 255}, {210, 152, 65}, {0, 46, 152}, {242, 255, 255}, {
                  255, 255, 255}}, {{255, 255, 255}, {210, 152, 79}, {0, 65, 
                  152}, {242, 255, 255}, {255, 255, 255}}, {{255, 255, 255}, {
                  255, 255, 255}, {255, 255, 255}, {255, 255, 255}, {255, 255,
                   255}}, {{255, 255, 255}, {255, 255, 255}, {255, 255, 
                  255}, {255, 255, 255}, {255, 255, 255}}, {{255, 255, 255}, {
                  255, 255, 255}, {255, 255, 255}, {255, 255, 255}, {255, 255,
                   255}}, {{255, 255, 255}, {255, 255, 255}, {255, 255, 
                  255}, {255, 255, 255}, {255, 255, 255}}}], {{0, 19}, {5, 
                 0}}, {0, 255}, ColorFunction -> RGBColor], 
                BoxForm`ImageTag[
                "Byte", ColorSpace -> "RGB", Interleaving -> True, 
                 Magnification -> Automatic], Selectable -> False], 
               DefaultBaseStyle -> "ImageGraphics", ImageSize -> {
                 Rational[67, 10], 19}, ImageSizeRaw -> {5, 19}, 
               PlotRange -> {{0, 5}, {0, 19}}], Short], Background -> 
             GrayLevel[1], FrameMargins -> {{0, 0}, {0, 0}}, FrameStyle -> 
             GrayLevel[1], RoundingRadius -> 2, StripOnInput -> False], {70, 
            0}, 
            Scaled[{0.5, 1}]], 
           InsetBox[
            FrameBox[
             TagBox[
              GraphicsBox[
               TagBox[
                RasterBox[
                RawArray["UnsignedInteger8",{{{255, 255, 255}, {255, 255, 
                  255}, {255, 255, 255}, {255, 255, 255}}, {{255, 255, 255}, {
                  255, 255, 255}, {255, 255, 255}, {255, 255, 255}}, {{255, 
                  255, 255}, {255, 255, 255}, {255, 255, 255}, {255, 255, 
                  255}}, {{255, 255, 255}, {255, 255, 255}, {255, 255, 255}, {
                  255, 255, 255}}, {{255, 251, 224}, {145, 102, 79}, {102, 
                  145, 189}, {251, 255, 255}}, {{255, 247, 205}, {65, 0, 0}, {
                  0, 46, 145}, {242, 255, 255}}, {{255, 255, 255}, {251, 247, 
                  247}, {251, 251, 255}, {255, 255, 255}}, {{255, 255, 242}, {
                  177, 121, 79}, {121, 171, 215}, {255, 255, 255}}, {{255, 
                  255, 242}, {152, 46, 0}, {46, 145, 205}, {255, 255, 
                  255}}, {{255, 255, 242}, {152, 65, 0}, {65, 145, 205}, {255,
                   255, 255}}, {{255, 255, 242}, {152, 65, 0}, {65, 145, 
                  205}, {255, 255, 255}}, {{255, 255, 242}, {152, 65, 0}, {65,
                   145, 205}, {255, 255, 255}}, {{255, 255, 242}, {152, 65, 
                  0}, {65, 145, 205}, {255, 255, 255}}, {{255, 255, 242}, {
                  152, 65, 0}, {65, 145, 205}, {255, 255, 255}}, {{255, 255, 
                  242}, {152, 65, 0}, {65, 145, 205}, {255, 255, 255}}, {{255,
                   255, 255}, {255, 255, 255}, {255, 255, 255}, {255, 255, 
                  255}}, {{255, 255, 255}, {255, 255, 255}, {255, 255, 255}, {
                  255, 255, 255}}, {{255, 255, 255}, {255, 255, 255}, {255, 
                  255, 255}, {255, 255, 255}}, {{255, 255, 255}, {255, 255, 
                  255}, {255, 255, 255}, {255, 255, 255}}}], {{0, 19}, {4, 
                 0}}, {0, 255}, ColorFunction -> RGBColor], 
                BoxForm`ImageTag[
                "Byte", ColorSpace -> "RGB", Interleaving -> True, 
                 Magnification -> Automatic], Selectable -> False], 
               DefaultBaseStyle -> "ImageGraphics", ImageSize -> {
                 Rational[67, 10], 19}, ImageSizeRaw -> {4, 19}, 
               PlotRange -> {{0, 4}, {0, 19}}], Short], Background -> 
             GrayLevel[1], FrameMargins -> {{0, 0}, {0, 0}}, FrameStyle -> 
             GrayLevel[1], RoundingRadius -> 2, StripOnInput -> False], {80, 
            0}, 
            Scaled[{0.5, 1}]], 
           InsetBox[
            FrameBox[
             TagBox[
              GraphicsBox[
               TagBox[
                RasterBox[
                RawArray["UnsignedInteger8",{{{255, 255, 255}, {255, 255, 
                  255}, {255, 255, 255}, {255, 255, 255}}, {{255, 255, 255}, {
                  255, 255, 255}, {255, 255, 255}, {255, 255, 255}}, {{255, 
                  255, 255}, {255, 255, 255}, {255, 255, 255}, {255, 255, 
                  255}}, {{255, 255, 255}, {255, 255, 255}, {255, 255, 255}, {
                  255, 255, 255}}, {{255, 255, 255}, {255, 251, 224}, {152, 
                  102, 79}, {102, 145, 189}}, {{255, 255, 255}, {255, 247, 
                  205}, {65, 0, 0}, {0, 46, 145}}, {{255, 255, 255}, {255, 
                  255, 255}, {251, 247, 247}, {251, 251, 255}}, {{255, 255, 
                  255}, {255, 255, 242}, {177, 121, 79}, {121, 171, 215}}, {{
                  255, 255, 255}, {255, 255, 242}, {152, 46, 0}, {46, 145, 
                  205}}, {{255, 255, 255}, {255, 255, 242}, {152, 65, 0}, {65,
                   145, 205}}, {{255, 255, 255}, {255, 255, 242}, {152, 65, 
                  0}, {65, 145, 205}}, {{255, 255, 255}, {255, 255, 242}, {
                  152, 65, 0}, {65, 145, 205}}, {{255, 255, 255}, {255, 255, 
                  242}, {152, 65, 0}, {65, 145, 205}}, {{255, 255, 255}, {255,
                   255, 242}, {152, 65, 0}, {65, 145, 205}}, {{255, 255, 
                  255}, {255, 255, 242}, {152, 65, 0}, {65, 145, 205}}, {{255,
                   255, 255}, {255, 255, 242}, {159, 65, 0}, {65, 145, 
                  205}}, {{247, 238, 234}, {224, 210, 177}, {65, 0, 0}, {79, 
                  145, 205}}, {{177, 92, 0}, {0, 0, 0}, {0, 0, 46}, {177, 224,
                   247}}, {{247, 242, 234}, {224, 224, 224}, {234, 242, 
                  255}, {255, 255, 255}}}], {{0, 19}, {4, 0}}, {0, 255}, 
                 ColorFunction -> RGBColor], 
                BoxForm`ImageTag[
                "Byte", ColorSpace -> "RGB", Interleaving -> True, 
                 Magnification -> Automatic], Selectable -> False], 
               DefaultBaseStyle -> "ImageGraphics", ImageSize -> {
                 Rational[67, 10], 19}, ImageSizeRaw -> {4, 19}, 
               PlotRange -> {{0, 4}, {0, 19}}], Short], Background -> 
             GrayLevel[1], FrameMargins -> {{0, 0}, {0, 0}}, FrameStyle -> 
             GrayLevel[1], RoundingRadius -> 2, StripOnInput -> False], {90, 
            0}, 
            Scaled[{0.5, 1}]], 
           InsetBox[
            FrameBox[
             TagBox[
              GraphicsBox[
               TagBox[
                RasterBox[CompressedData["
1:eJzVkKFuwzAQhq2NFE7aE+wFgkcNhyJ1GgtptbgayaJ00lQaFmiWFwgKCgoq
KTIxMQkxMDEJCDhiEOCdE3XS9gY9ydbnu//uP/lp/7lld4SQ4wav7e6bFsXu
9PqAj7fs+HHI0veX7Cs9pMXz/h6Tj3iCMrC/nZitKBOKO5MoZozFNG4UeG9O
IcU6IZoyCZhUwjoPEqWVhKVVYyHvbUAQmM9bHXi6ILOVvevyCLtx9OIRi2m1
tZwSmvOa87rpDVy3ARmjFe+1MXqJEealMFXkX0SdmUHVATTMDsA5MD26UC4n
gfKoHVYzp9oSG8rL6N1Q0j9TGD+760+MVg9KquHX1P8AAj5dUg==
                 "], {{0,
                  19}, {8, 0}}, {0, 255}, ColorFunction -> RGBColor], 
                BoxForm`ImageTag[
                "Byte", ColorSpace -> "RGB", Interleaving -> True, 
                 Magnification -> Automatic], Selectable -> False], 
               DefaultBaseStyle -> "ImageGraphics", ImageSize -> {
                 Rational[67, 10], 19}, ImageSizeRaw -> {8, 19}, 
               PlotRange -> {{0, 8}, {0, 19}}], Short], Background -> 
             GrayLevel[1], FrameMargins -> {{0, 0}, {0, 0}}, FrameStyle -> 
             GrayLevel[1], RoundingRadius -> 2, StripOnInput -> False], {100, 
            0}, 
            Scaled[{0.5, 1}]]}, AlignmentPoint -> Center, AspectRatio -> 
          NCache[2^Rational[-1, 2], 0.7071067811865475], Axes -> False, 
          AxesLabel -> None, AxesOrigin -> Automatic, AxesStyle -> {}, 
          Background -> None, BaseStyle -> {}, BaselinePosition -> Automatic, 
          ColorOutput -> Automatic, ContentSelectable -> Automatic, 
          CoordinatesToolOptions :> Automatic, 
          DisplayFunction :> $DisplayFunction, Epilog -> {}, FormatType :> 
          TraditionalForm, Frame -> False, FrameLabel -> None, 
          FrameStyle -> {}, FrameTicks -> Automatic, FrameTicksStyle -> {}, 
          GridLines -> None, GridLinesStyle -> {}, ImageMargins -> 0., 
          ImagePadding -> All, ImageSize -> Automatic, ImageSizeRaw -> 
          Automatic, LabelStyle -> {}, Method -> Automatic, PlotLabel -> None,
           PlotRange -> All, PlotRangeClipping -> False, PlotRangePadding -> 
          Automatic, PlotRegion -> Automatic, PreserveImageOptions -> 
          Automatic, Prolog -> {}, RotateLabel -> True, Ticks -> Automatic, 
          TicksStyle -> {}]], "ExerciseOutput", Selectable -> False, Copyable -> 
        False, Editable -> False, ShowCellBracket -> False]]], " "}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Center}}},
   GridBoxBackground->{"Columns" -> {{
        RGBColor[1, 1, 1]}}},
   GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{1}}}],
  FrameMargins->0]], "ExerciseOutput",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellFrame->{{1, 1}, {1, 1}},
 ShowCellBracket->False,
 CellFrameColor->RGBColor[0.85, 0.85, 0.85],
 LineBreakWithin->
  Automatic,ExpressionUUID->"68e438ae-4a11-4f9c-b198-24be83e1f39e"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Make a feature space plot for the uppercase letters of the alphabet.",
 StyleBox[ButtonBox["\[NonBreakingSpace]\[RightGuillemet]",
  Appearance->None,
  Evaluator->Automatic,
  Method->"Preemptive",
  ButtonFunction:>(SelectionMove[
     ButtonNotebook[], All, ButtonCell, AutoScroll -> False]; 
   FrontEndExecute[
     FrontEndToken[
      ButtonNotebook[], "OpenCloseGroup"]])],
  FontColor->RGBColor[1, 0.501961, 0]]
}], "Exercise",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellDingbat->Cell[
  "22.16", "ExerciseNumber", FontColor -> 
   RGBColor[0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]],
 ShowCellBracket->False,
 CellTags->
  "LastCellOfAPage",ExpressionUUID->"738c2071-5e8b-4de8-a233-3bd0ba9cea5a"],

Cell[BoxData[
 PaneBox[GridBox[{
    {" ", 
     StyleBox[
      RowBox[{"Expected", " ", 
       RowBox[{"output", ":"}]}],
      Editable->False,
      Selectable->False,
      StripOnInput->False,
      FontColor->RGBColor[0.45, 0.45, 0.45]], " "},
    {" ", 
     InterpretationBox[Cell[BoxData[
       GraphicsBox[{{}, {{}, 
          {Hue[0.67, 0.6, 0.6], PointBox[CompressedData["
1:eJwBsQFO/iFib1JlAgAAABoAAAACAAAAEYznZaVCOEBU+mpYexcbQO3sO/Ei
pCXAzBuEAkWeCUB2kbs+Htk6wHSJOJ89IR1ApazL5CEvJsDUSEtFLesnQEDS
tiG2ly/A6jvUMs9WGsCGWuNlz/o0wP1ICTqJ5yXAMAyQ/IpLN8ABSD6JWNMl
QBab2GfRbBxA2WjzzBJUBEC9PCbHvkxAQKWuJGLfhRfAocJHyy2O8T8m+7DC
VeYxQBSaTRH+bSdAn6XyLqJTHsCefGF7v2c6wA2VF7IbkhLApAoj+iX2LkAv
6N+jTckFQMukgeC9JCNAwE73bgrmHUCj+OI2i0wtwF3tfuY9uDBA/fMrADM0
BsD9A/nQuhcRwDk9hmqD7TDAWDZxYOOeNUCRezGe5QoBQDptNvKiwAzAfsgz
XtxHMcAdQ1PbO7P/P+cdKfCEIUBAWIrrnd6BJcCPJ+mDA3XxP1BOUMAuhSVA
YleDdAMzCED6m9oVghs0wOLQ1t9z+jJALXqt4KUPF8CJjUrNWI0rQOXNkG2K
hCnA14q9YDevOECvycjQp2svwE5asExx0CXA57lDm6d9KsDdNcY2
            
            "]]}, {}}, {}, {}, {{}, {}}, {{}, {InsetBox[
            PaneBox[
             FrameBox[
              StyleBox[
               TagBox[
                GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmIOIAax/9MYpDEwOHaeQBa5s7qAgUFvI5BgaHqKEP40
3x8o3PnuUCdQYun171Dhd4ccGRj8Z1z6//1SDAM6WP3g9///v7dX6gHZMzbu
3bt3NUiNXucriNYTQKMcD30C2Ql0hv/8S1AzwUYVbH/6/foMoPKNIEMg4Pd2
oKvS5m/sdGTQm/gOyc3vTkyE2Jg2/zqK935fh7hq49Pf/1HBu6d37jzAEKUZ
AAAubmtE
                  "], {{0, 0}, {8, 19}}, {0, 255},
                  ColorFunction->RGBColor],
                 ImageSize->{8, 19},
                 PlotRange->{{0, 8}, {0, 19}}],
                HoldForm],
               StripOnInput->False,
               Opacity->1,
               FontOpacity->1,
               $CellContext`LineOpacity -> 1,
               $CellContext`FrontFaceOpacity -> 1,
               $CellContext`BackFaceOpacity -> 1],
              LabelStyle -> {},
              Frame -> True,
              Background->Directive[
                GrayLevel[1]],
              ContentPadding->False,
              FrameMargins->2,
              FrameStyle->None,
              RoundingRadius->4,
              StripOnInput->False],
             
             FrameMargins->
              0], {24.260336274175703, 6.772931462792787}, {0, 0}], InsetBox[
            PaneBox[
             FrameBox[
              StyleBox[
               TagBox[
                GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmJOIAax/9MVfJofw4AE9GIqZ1x69Rsq5Q8Uidl44sSJ
Q3uXTiwAK0i79B0m5T//O8yUdycmAuU6T7yDSjnO+AS34elGoNTEszAphspL
T189ffrg0qGNBY5Arv+JT3C7UFxyCNkZek0Pvv/+/undpe0z9IBumn8JIYWw
6/dSMPcdkq47n4CaXl0/BJJhSFsNNvHTRD00q9Jgdv3/9PTBnTt3gPjBg6ev
3n36TdOwxwEAOkaHZg==
                  "], {{0, 0}, {9, 19}}, {0, 255},
                  ColorFunction->RGBColor],
                 ImageSize->{9, 19},
                 PlotRange->{{0, 9}, {0, 19}}],
                HoldForm],
               StripOnInput->False,
               Opacity->1,
               FontOpacity->1,
               $CellContext`LineOpacity -> 1,
               $CellContext`FrontFaceOpacity -> 1,
               $CellContext`BackFaceOpacity -> 1],
              LabelStyle -> {},
              Frame -> True,
              Background->Directive[
                GrayLevel[1]],
              ContentPadding->False,
              FrameMargins->2,
              FrameStyle->None,
              RoundingRadius->4,
              StripOnInput->False],
             
             FrameMargins->
              0], {-10.820579088750003, 3.202280063301691}, {0, 0}], 
           InsetBox[
            PaneBox[
             FrameBox[
              StyleBox[
               TagBox[
                GraphicsBox[RasterBox[CompressedData["
1:eJy1j6EOwyAQhkmmpvcEe4G+A0+wZBpVUbvZ2bnKOhwKVbUHOIOqmTmNwMwg
TmAQFQyyrOkybP/kwvF/3A8c28u53THGDrn2uUqfNtQciDzR/Os6o05sEZdg
P743fTEaoWHCCXpRdqOLKb3uTW47jEtGQHR5iVYXoO3/3QFlRhJDDamMhmcV
lane+MpvIpYXCVUZSwlVgfymLYU5epAdv47fkxEGwVbitwetg72dDAAYdFTL
3lZv0BSv+g==
                  "], {{0, 0}, {9, 19}}, {0, 255},
                  ColorFunction->RGBColor],
                 ImageSize->{9, 19},
                 PlotRange->{{0, 9}, {0, 19}}],
                HoldForm],
               StripOnInput->False,
               Opacity->1,
               FontOpacity->1,
               $CellContext`LineOpacity -> 1,
               $CellContext`FrontFaceOpacity -> 1,
               $CellContext`BackFaceOpacity -> 1],
              LabelStyle -> {},
              Frame -> True,
              Background->Directive[
                GrayLevel[1]],
              ContentPadding->False,
              FrameMargins->2,
              FrameStyle->None,
              RoundingRadius->4,
              StripOnInput->False],
             
             FrameMargins->
              0], {-26.848117752831477, 7.282461631608715}, {0, 0}], 
           InsetBox[
            PaneBox[
             FrameBox[
              StyleBox[
               TagBox[
                GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmJOIAax/9MVfJofwwAHjv4FSw/dQUj5A8ViVh86sXf1
DH+wgpj5ZxFS/vO/Q1U+nQiS1tv7CiblOOMTzJTfd5YC5dJW38GU+v/9EtBy
x4lnsUmd9ccl9emEIw6pS2DPzLj0CSql13Tn06d3T6+v7gR70n/GO7D+iXoM
yCCmafWr3zCznz64c+fOAzDx6tPv/wMBAFbNk4I=
                  "], {{0, 0}, {9, 
                  19}}, {0, 255},
                  ColorFunction->RGBColor],
                 ImageSize->{9, 19},
                 PlotRange->{{0, 9}, {0, 19}}],
                HoldForm],
               StripOnInput->False,
               Opacity->1,
               FontOpacity->1,
               $CellContext`LineOpacity -> 1,
               $CellContext`FrontFaceOpacity -> 1,
               $CellContext`BackFaceOpacity -> 1],
              LabelStyle -> {},
              Frame -> True,
              Background->Directive[
                GrayLevel[1]],
              ContentPadding->False,
              FrameMargins->2,
              FrameStyle->None,
              RoundingRadius->4,
              StripOnInput->False],
             
             FrameMargins->
              0], {-11.092055463659856, 11.959329762878419}, {0, 0}], InsetBox[
            PaneBox[
             FrameBox[
              StyleBox[
               TagBox[
                GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmIOIAax/9McfJofw4AGJp59BxL3BzL952/cvhECVm+8
/u43VNx//ndMc4DijjOwizMUHLp+5zoQXLr+AGQIXBwJdJ5AEm+6/u7dKzD4
9B3JHFz26iHUv3r1Dqzm00Q9dH8d+gSWePrgzp07D6AAxPxEvdDEBQCIi2wv

                  "], {{0, 0}, {8, 19}}, {0, 255},
                  ColorFunction->RGBColor],
                 ImageSize->{8, 19},
                 PlotRange->{{0, 8}, {0, 19}}],
                HoldForm],
               StripOnInput->False,
               Opacity->1,
               FontOpacity->1,
               $CellContext`LineOpacity -> 1,
               $CellContext`FrontFaceOpacity -> 1,
               $CellContext`BackFaceOpacity -> 1],
              LabelStyle -> {},
              Frame -> True,
              Background->Directive[
                GrayLevel[1]],
              ContentPadding->False,
              FrameMargins->2,
              FrameStyle->None,
              RoundingRadius->4,
              StripOnInput->False],
             
             FrameMargins->
              0], {-15.796311429564525, -6.584774774745691}, {0, 0}], InsetBox[
            PaneBox[
             FrameBox[
              StyleBox[
               TagBox[
                GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmJ2IAax/9MEfJofw8DgP/8TquAMfwYGxxnv0FSCBT9h
CvrP/44pyOA/Y/Xq1UuXLp0/f++ldzBBBIiZfwlm5kRiLdJruv7u3SsoAJk5
UY8BDYCUPn1w586dB1AAYlIYRlgBAIEXRQ0=
                  "], {{0, 0}, {7, 
                  19}}, {0, 255},
                  ColorFunction->RGBColor],
                 ImageSize->{7, 19},
                 PlotRange->{{0, 7}, {0, 19}}],
                HoldForm],
               StripOnInput->False,
               Opacity->1,
               FontOpacity->1,
               $CellContext`LineOpacity -> 1,
               $CellContext`FrontFaceOpacity -> 1,
               $CellContext`BackFaceOpacity -> 1],
              LabelStyle -> {},
              Frame -> True,
              Background->Directive[
                GrayLevel[1]],
              ContentPadding->False,
              FrameMargins->2,
              FrameStyle->None,
              RoundingRadius->4,
              StripOnInput->False],
             
             FrameMargins->
              0], {-20.979727142339947, -10.952218831666409}, {0, 0}], 
           InsetBox[
            PaneBox[
             FrameBox[
              StyleBox[
               TagBox[
                GraphicsBox[RasterBox[CompressedData["
1:eJy1jyESwyAQRZmpqu4JeoHcISfITDUqIrY9Q1xk3DoUqqoHqEFhMJiYiJgY
xAoMAkGBNm06E5s/szPLf+xnOdfXS30ghJxiHWOlPuwpi2gMWv9nzpLTgnxF
Wz675KPss1HBQyglWEvjoZMYgunS/UbZJcLripBeoRt5Anz8pTtVZmQ1RAQ6
zzhNl+cyYrnJyM93iGLQg5jce6oTZuMzfmjydnaDhYEnWN7YYKz3bhRQFjeF
n0kBDVmrbDWuVsZJiWeU1JPfCt9VL6yXmfQ=
                  "], {{0, 0}, {9, 
                  19}}, {0, 255},
                  ColorFunction->RGBColor],
                 ImageSize->{9, 19},
                 PlotRange->{{0, 9}, {0, 19}}],
                HoldForm],
               StripOnInput->False,
               Opacity->1,
               FontOpacity->1,
               $CellContext`LineOpacity -> 1,
               $CellContext`FrontFaceOpacity -> 1,
               $CellContext`BackFaceOpacity -> 1],
              LabelStyle -> {},
              Frame -> True,
              Background->Directive[
                GrayLevel[1]],
              ContentPadding->False,
              FrameMargins->2,
              FrameStyle->None,
              RoundingRadius->4,
              StripOnInput->False],
             
             FrameMargins->
              0], {-23.295089516799806, 10.91278485188741}, {0, 0}], 
           InsetBox[
            PaneBox[
             FrameBox[
              StyleBox[
               TagBox[
                GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmIuIAax/w8Y+DQ/hoHBf/4nuMD3S2lAgRmXILIz/BkY
HGe8Qyg/CxKYeBaqFyyLpBeL7He47O9LMWiyDAWHrt+5DgJ3rp+YD+T7o8ii
AxRZvabr7969AoF3r+5s1EOTRXHVJYJuhuudCDRIb+I7JFlHoEDnCajvn955
8BShFeilVw/uPH33/f/AAQC6adIj
                  "], {{0, 0}, {10, 19}}, {0, 
                  255},
                  ColorFunction->RGBColor],
                 ImageSize->{10, 19},
                 PlotRange->{{0, 10}, {0, 19}}],
                HoldForm],
               StripOnInput->False,
               Opacity->1,
               FontOpacity->1,
               $CellContext`LineOpacity -> 1,
               $CellContext`FrontFaceOpacity -> 1,
               $CellContext`BackFaceOpacity -> 1],
              LabelStyle -> {},
              Frame -> True,
              Background->Directive[
                GrayLevel[1]],
              ContentPadding->False,
              FrameMargins->2,
              FrameStyle->None,
              RoundingRadius->4,
              StripOnInput->False],
             
             FrameMargins->
              0], {7.106267569156236, 2.541051484277983}, {0, 0}], InsetBox[
            PaneBox[
             FrameBox[
              StyleBox[
               TagBox[
                
                GraphicsBox[
                 RasterBox[{{{255, 255, 255}, {255, 255, 255}, {255, 255, 
                  255}, {255, 255, 255}}, {{255, 255, 255}, {255, 255, 255}, {
                  255, 255, 255}, {255, 255, 255}}, {{255, 255, 255}, {255, 
                  255, 255}, {255, 255, 255}, {255, 255, 255}}, {{255, 255, 
                  255}, {255, 255, 255}, {255, 255, 255}, {255, 255, 255}}, {{
                  255, 255, 242}, {159, 92, 0}, {0, 79, 159}, {242, 255, 
                  255}}, {{255, 255, 242}, {152, 79, 0}, {0, 65, 152}, {238, 
                  255, 255}}, {{255, 255, 242}, {159, 79, 0}, {0, 65, 152}, {
                  242, 255, 255}}, {{255, 255, 242}, {159, 79, 0}, {0, 65, 
                  152}, {242, 255, 255}}, {{255, 255, 242}, {159, 79, 0}, {0, 
                  65, 152}, {242, 255, 255}}, {{255, 255, 242}, {159, 79, 
                  0}, {0, 65, 152}, {242, 255, 255}}, {{255, 255, 242}, {159, 
                  79, 0}, {0, 65, 152}, {242, 255, 255}}, {{255, 255, 242}, {
                  159, 79, 0}, {0, 65, 152}, {242, 255, 255}}, {{255, 255, 
                  242}, {159, 79, 0}, {0, 65, 152}, {242, 255, 255}}, {{255, 
                  255, 242}, {145, 46, 0}, {0, 46, 145}, {238, 255, 255}}, {{
                  255, 255, 255}, {242, 229, 220}, {224, 229, 242}, {255, 255,
                   255}}, {{255, 255, 255}, {255, 255, 255}, {255, 255, 
                  255}, {255, 255, 255}}, {{255, 255, 255}, {255, 255, 255}, {
                  255, 255, 255}, {255, 255, 255}}, {{255, 255, 255}, {255, 
                  255, 255}, {255, 255, 255}, {255, 255, 255}}, {{255, 255, 
                  255}, {255, 255, 255}, {255, 255, 255}, {255, 255, 
                  255}}}, {{0, 0}, {4, 19}}, {0, 255},
                  ColorFunction->RGBColor],
                 ImageSize->{4, 19},
                 PlotRange->{{0, 4}, {0, 19}}],
                HoldForm],
               StripOnInput->False,
               Opacity->1,
               FontOpacity->1,
               $CellContext`LineOpacity -> 1,
               $CellContext`FrontFaceOpacity -> 1,
               $CellContext`BackFaceOpacity -> 1],
              LabelStyle -> {},
              Frame -> True,
              Background->Directive[
                GrayLevel[1]],
              ContentPadding->False,
              FrameMargins->2,
              FrameStyle->None,
              RoundingRadius->4,
              StripOnInput->False],
             
             FrameMargins->
              0], {32.59957208029798, -5.880734952439217}, {0, 0}], InsetBox[
            PaneBox[
             FrameBox[
              StyleBox[
               TagBox[
                GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmJ2IAax/1MDvHsFBO9+w/m/n85I02OAgpi9D74DxS7N
cARyOlcfOrsXzPJfChL9/vTspacQTZdm+DMwpF3/jmIyWND/xCcsgmdpL3h2
ItClemi2//709M6dp7//0wQAAJQIVgs=
                  "], {{0, 0}, {7, 19}}, {0, 
                  255},
                  ColorFunction->RGBColor],
                 ImageSize->{7, 19},
                 PlotRange->{{0, 7}, {0, 19}}],
                HoldForm],
               StripOnInput->False,
               Opacity->1,
               FontOpacity->1,
               $CellContext`LineOpacity -> 1,
               $CellContext`FrontFaceOpacity -> 1,
               $CellContext`BackFaceOpacity -> 1],
              LabelStyle -> {},
              Frame -> True,
              Background->Directive[
                GrayLevel[1]],
              ContentPadding->False,
              FrameMargins->2,
              FrameStyle->None,
              RoundingRadius->4,
              StripOnInput->False],
             
             FrameMargins->
              0], {1.0972116413724182, 17.89974610157801}, {0, 0}], InsetBox[
            PaneBox[
             FrameBox[
              StyleBox[
               TagBox[
                GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmJOIAax/9MVfJofw8DgP/8TXODpdkcGBr2mQ0CpGf4M
DI4z3kElvq9OA7rOce+r3yBdICmork9nZwAl/GechRoIlGJIOwuSe9WpB2QX
XP/9H0mKgSFm4vallUC6cvtTFGfAQcz8d3D3QHTFzNi7tAAsc+k/mpTjjO//
/28sANk08cQ7NCkw/+lER5DLtz+FuOPTRKBavYlQpZ8upYGtvAT2zKendx48
RQTG73dP71y/8+43JSFMMgAABnOZsw==
                  "], {{0, 0}, {9, 19}}, {0, 
                  255},
                  ColorFunction->RGBColor],
                 ImageSize->{9, 19},
                 PlotRange->{{0, 9}, {0, 19}}],
                HoldForm],
               StripOnInput->False,
               Opacity->1,
               FontOpacity->1,
               $CellContext`LineOpacity -> 1,
               $CellContext`FrontFaceOpacity -> 1,
               $CellContext`BackFaceOpacity -> 1],
              LabelStyle -> {},
              Frame -> True,
              Background->Directive[
                GrayLevel[1]],
              ContentPadding->False,
              FrameMargins->2,
              FrameStyle->None,
              RoundingRadius->4,
              StripOnInput->False],
             
             FrameMargins->
              0], {11.714829006884464, -7.581673368034358}, {0, 0}], 
           InsetBox[
            PaneBox[
             FrameBox[
              StyleBox[
               TagBox[
                GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmJ2IAax/9MEfJofw4AK/EGC/iDG/I3bN4LB6o2HoIL+
87+jaQcKOs74NECCE/UYGPQmvkPz0tM7D56iKqQBAAD4rFL4
                  "], {{0, 
                  0}, {7, 19}}, {0, 255},
                  ColorFunction->RGBColor],
                 ImageSize->{7, 19},
                 PlotRange->{{0, 7}, {0, 19}}],
                HoldForm],
               StripOnInput->False,
               Opacity->1,
               FontOpacity->1,
               $CellContext`LineOpacity -> 1,
               $CellContext`FrontFaceOpacity -> 1,
               $CellContext`BackFaceOpacity -> 1],
              LabelStyle -> {},
              Frame -> True,
              Background->Directive[
                GrayLevel[1]],
              ContentPadding->False,
              FrameMargins->2,
              FrameStyle->None,
              RoundingRadius->4,
              StripOnInput->False],
             
             FrameMargins->
              0], {-26.405265532780156, -4.642683775605531}, {0, 0}], InsetBox[
            PaneBox[
             FrameBox[
              StyleBox[
               TagBox[
                GraphicsBox[RasterBox[CompressedData["
1:eJzNUKEOwyAQvWRycl+wH+g/8AUk06iK2dXW1lXicKiqfkBVzVQNpmYGgcEg
JmoQFQxYl5Yt09sll9x794573DG/nPIdABx87n2G2v1FTBwDouI7OTG01LNq
AdD1npDbWlDs/3VulXP2QzA6pwuIgZh1lr8J2M1KBkBGNSCAzpgm9YD50FcA
ReeN+BbmPSfpC2Xt11MR/JkgxSRbBRw/d5dyjoQdScSYvQQRZ5tT9GUWzS4C
GhA00q5nEiyM1MMCtZJSr+24RkupTMr9Lh7V3PPK
                  "], {{0, 0}, {11, 
                  19}}, {0, 255},
                  ColorFunction->RGBColor],
                 ImageSize->{11, 19},
                 PlotRange->{{0, 11}, {0, 19}}],
                HoldForm],
               StripOnInput->False,
               Opacity->1,
               FontOpacity->1,
               $CellContext`LineOpacity -> 1,
               $CellContext`FrontFaceOpacity -> 1,
               $CellContext`BackFaceOpacity -> 1],
              LabelStyle -> {},
              Frame -> True,
              Background->Directive[
                GrayLevel[1]],
              ContentPadding->False,
              FrameMargins->2,
              FrameStyle->None,
              RoundingRadius->4,
              StripOnInput->False],
             
             FrameMargins->
              0], {15.480758492257628, 2.7232926180559143}, {0, 0}], 
           InsetBox[
            PaneBox[
             FrameBox[
              StyleBox[
               TagBox[
                GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmIuIAax/w8Y+DTfn8Fx4lk4/93ZGUD3xMy/BJGd4Ygs
+7RJDyjJ4A8VQZG9s7qAAQz8Z2DIfj8bw8Dg2Ll6RgxcPUL2UKcjUNOJV3ea
GFBlZ1z//2472DHX//+/5I9qr//8vasrgZIFd8Dm+yPpBfoIApoOvfqPKRsD
louZ/wnibrAs3OSJYA+uvvP7P0wW6Di9TqgfPz19cOfBO6TQ+/3qwZ2nn37/
HzgAADmbx5k=
                  "], {{0, 0}, {10, 19}}, {0, 255},
                  ColorFunction->RGBColor],
                 ImageSize->{10, 19},
                 PlotRange->{{0, 10}, {0, 19}}],
                HoldForm],
               StripOnInput->False,
               Opacity->1,
               FontOpacity->1,
               $CellContext`LineOpacity -> 1,
               $CellContext`FrontFaceOpacity -> 1,
               $CellContext`BackFaceOpacity -> 1],
              LabelStyle -> {},
              Frame -> True,
              Background->Directive[
                GrayLevel[1]],
              ContentPadding->False,
              FrameMargins->2,
              FrameStyle->None,
              RoundingRadius->4,
              StripOnInput->False],
             
             FrameMargins->
              0], {9.571761146379137, 7.4746491754955855}, {0, 0}], InsetBox[
            PaneBox[
             FrameBox[
              StyleBox[
               TagBox[
                GraphicsBox[RasterBox[CompressedData["
1:eJzFkKEOgzAQhknmZvcEewHeYU9AMo1CYIedxVXi6qZQVX2AmipMTU0NogaD
qKipQLC7LpCS+e1Pmvz3f3fXptfqca9OWZZd4JzhoF9/ocU7D1q+gBX0lu26
UWl3NEuCWd4wIaVgdY4VkXOEU4tlY8LWHXSNzQRwGHuwNRvTi0yPnNvFKwqG
ap/SoF8Qdsp5TaM50C10n1kyuJS6+E4KI14V8eKQLO5LiEodo6FDXhI++RC8
5S2WRaf2TaxJPgO+48kP74AOa6QASTO59d96A6IhyfA=
                  "], {{0, 0}, {
                  10, 19}}, {0, 255},
                  ColorFunction->RGBColor],
                 ImageSize->{10, 19},
                 PlotRange->{{0, 10}, {0, 19}}],
                HoldForm],
               StripOnInput->False,
               Opacity->1,
               FontOpacity->1,
               $CellContext`LineOpacity -> 1,
               $CellContext`FrontFaceOpacity -> 1,
               $CellContext`BackFaceOpacity -> 1],
              LabelStyle -> {},
              Frame -> True,
              Background->Directive[
                GrayLevel[1]],
              ContentPadding->False,
              FrameMargins->2,
              FrameStyle->None,
              RoundingRadius->4,
              StripOnInput->False],
             
             FrameMargins->
              0], {-14.649499621588182, 16.719694524753653}, {0, 0}], InsetBox[
            PaneBox[
             FrameBox[
              StyleBox[
               TagBox[
                GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmJOIAax/9MVfJofw8DgP/8TNqkZ/gwMjjPeYdUFlsKq
CySl1/n0///f33//xpRCAjGVSx98R5aK2X7i7NkTh5Z2poGk/ee/g0v5z/8O
M+XSDKCLHU98wuKMTyc6UaT0mu58+vTp3bs7ZzeCTUy7DjLl00Q9BlTguPQS
1Jefnj64c+cOED948ODVq3eo7qcTAADeHKSZ
                  "], {{0, 0}, {9, 
                  19}}, {0, 255},
                  ColorFunction->RGBColor],
                 ImageSize->{9, 19},
                 PlotRange->{{0, 9}, {0, 19}}],
                HoldForm],
               StripOnInput->False,
               Opacity->1,
               FontOpacity->1,
               $CellContext`LineOpacity -> 1,
               $CellContext`FrontFaceOpacity -> 1,
               $CellContext`BackFaceOpacity -> 1],
              LabelStyle -> {},
              Frame -> True,
              Background->Directive[
                GrayLevel[1]],
              ContentPadding->False,
              FrameMargins->2,
              FrameStyle->None,
              RoundingRadius->4,
              StripOnInput->False],
             
             FrameMargins->
              0], {-2.7754879010594764, -4.273173585127549}, {0, 0}], InsetBox[
            PaneBox[
             FrameBox[
              StyleBox[
               TagBox[
                GraphicsBox[RasterBox[CompressedData["
1:eJzFUCESgzAQZKauti/oB/oHXsBMNQqBbSwWh8TFoVAoVFVMFCYmJiYCg0FE
xERE0EtaaMBV9WZuZm83t7m7a/a4Z6coii6QZ0iHlx9DjZwSQuggJn1QWhRH
aySNCCQ74BTIFFNtF2u0sR9BEvztuaUNHbeemVaOjAvChGDPwr+r6OzFqXRV
Ie32g0DOoQTZiBYg6mQ4nGxzIDtpNMcAarYb3vDGk+qtIjKH6tqiNPNgULu1
/ZwYDDVLAOWdCYxbvzf31FA7Pa36SRujx750ZVKzzakLDuhX748nHoU7PqFi
Usu/4wUE+7cr
                  "], {{0, 0}, {10, 19}}, {0, 255},
                  ColorFunction->RGBColor],
                 ImageSize->{10, 19},
                 PlotRange->{{0, 10}, {0, 19}}],
                HoldForm],
               StripOnInput->False,
               Opacity->1,
               FontOpacity->1,
               $CellContext`LineOpacity -> 1,
               $CellContext`FrontFaceOpacity -> 1,
               $CellContext`BackFaceOpacity -> 1],
              LabelStyle -> {},
              Frame -> True,
              Background->Directive[
                GrayLevel[1]],
              ContentPadding->False,
              FrameMargins->2,
              FrameStyle->None,
              RoundingRadius->4,
              StripOnInput->False],
             
             FrameMargins->
              0], {-16.92778650071452, 21.620656993522374}, {0, 0}], 
           InsetBox[
            PaneBox[
             FrameBox[
              StyleBox[
               TagBox[
                GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmJOIAax/9MVfJofw8DgP/8TjH+o05+BQW/jg99AqRlA
puOMd2Dx3w9WA92mV7n9N0QXQgpsAoPjoXcwA8FS34GsExOBEgVLryPsAkoB
Jf399UA0Q9P2O6hSegVNnZ1NlRBp/4knkAyc/x2q8h3Yus5XSHbBHX8dJOd4
4hNMSq/pzqdPn969un5iNUiT3kSIgydCrEcA/43XoWZ8evrgzp07Dx6A8NNX
735TN7CJAwAqBZCP
                  "], {{0, 0}, {9, 19}}, {0, 255},
                  ColorFunction->RGBColor],
                 ImageSize->{9, 19},
                 PlotRange->{{0, 9}, {0, 19}}],
                HoldForm],
               StripOnInput->False,
               Opacity->1,
               FontOpacity->1,
               $CellContext`LineOpacity -> 1,
               $CellContext`FrontFaceOpacity -> 1,
               $CellContext`BackFaceOpacity -> 1],
              LabelStyle -> {},
              Frame -> True,
              Background->Directive[
                GrayLevel[1]],
              ContentPadding->False,
              FrameMargins->2,
              FrameStyle->None,
              RoundingRadius->4,
              StripOnInput->False],
             
             FrameMargins->
              0], {2.130320773968784, -3.5940607951030445}, {0, 0}], 
           InsetBox[
            PaneBox[
             FrameBox[
              StyleBox[
               TagBox[
                GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmIOIAax/1MZ/P707t2rd+++I0S+n13d6cgAB3qdG68D
Re+sTgPx/CtXHzp76ezezhg9IG/GpU//fz/dvvEEQvvvS/4MDI6dJ9CseXpo
IlB9zPxLCJFLezvTIPY4HnoFFvp0qckfaqtjWufZVxBTP80HC/o3Lb3+CsmZ
n04ANTs2HcLw0dNKkP6ms08//f7+6dL2iXp6BUBnAsGrszMYkIF/E0QcHApP
zx7aCwRnrz/9TX5gkgAAmoFq1w==
                  "], {{0, 0}, {8, 19}}, {0, 255},
                  ColorFunction->RGBColor],
                 ImageSize->{8, 19},
                 PlotRange->{{0, 8}, {0, 19}}],
                HoldForm],
               StripOnInput->False,
               Opacity->1,
               FontOpacity->1,
               $CellContext`LineOpacity -> 1,
               $CellContext`FrontFaceOpacity -> 1,
               $CellContext`BackFaceOpacity -> 1],
              LabelStyle -> {},
              Frame -> True,
              Background->Directive[
                GrayLevel[1]],
              ContentPadding->False,
              FrameMargins->2,
              FrameStyle->None,
              RoundingRadius->4,
              StripOnInput->False],
             
             FrameMargins->
              0], {-17.28070629848707, 1.9812582557098672}, {0, 0}], 
           InsetBox[
            PaneBox[
             FrameBox[
              StyleBox[
               TagBox[
                GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmIOIAax/9MJfFoaw8DgP/8ThvgMfwYGxxnvMMTng8Ux
1dNZ/Pund69evfr07nqTHgODXtP1dyDuq3ffJzJgBZ2fXj24c+fOAyC4g6Af
PMWwh9oAAL/Hhh0=
                  "], {{0, 0}, {8, 19}}, {0, 255},
                  ColorFunction->RGBColor],
                 ImageSize->{8, 19},
                 PlotRange->{{0, 8}, {0, 19}}],
                HoldForm],
               StripOnInput->False,
               Opacity->1,
               FontOpacity->1,
               $CellContext`LineOpacity -> 1,
               $CellContext`FrontFaceOpacity -> 1,
               $CellContext`BackFaceOpacity -> 1],
              LabelStyle -> {},
              Frame -> True,
              Background->Directive[
                GrayLevel[1]],
              ContentPadding->False,
              FrameMargins->2,
              FrameStyle->None,
              RoundingRadius->4,
              StripOnInput->False],
             
             FrameMargins->
              0], {32.2618694496885, -10.753651556971064}, {0, 0}], InsetBox[
            PaneBox[
             FrameBox[
              StyleBox[
               TagBox[
                GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmIuIAax/9MB/P7+7t2rd+8+YcpcWt3EAAd6MdvvINR8
ujQfJOhYufHQiUMbZziCOAV3fkNN3F6px8AQcxam/NOJiUDpGZcg/E8g1Y4z
EGZ9v+TPwJC29DpcVq/zEMIR388CZR0nnoXLwtj0kPWHyYI80HkCWRboCT2Y
yLundx68+o4cpq8e3Hn66TdmkNINAAB5At0y
                  "], {{0, 0}, {10, 
                  19}}, {0, 255},
                  ColorFunction->RGBColor],
                 ImageSize->{10, 19},
                 PlotRange->{{0, 10}, {0, 19}}],
                HoldForm],
               StripOnInput->False,
               Opacity->1,
               FontOpacity->1,
               $CellContext`LineOpacity -> 1,
               $CellContext`FrontFaceOpacity -> 1,
               $CellContext`BackFaceOpacity -> 1],
              LabelStyle -> {},
              Frame -> True,
              Background->Directive[
                GrayLevel[1]],
              ContentPadding->False,
              FrameMargins->2,
              FrameStyle->None,
              RoundingRadius->4,
              StripOnInput->False],
             
             FrameMargins->
              0], {1.0910678055538232, 10.760122308543174}, {0, 0}], 
           InsetBox[
            PaneBox[
             FrameBox[
              StyleBox[
               TagBox[
                GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmIOIAax/9MHvDvkD7TMsfMVqvCDjZUMYLDxwW8k4e9L
Y4CKYxwZGGLmX0IIfzoBFKncfv1Qpx6D3sR3MOFXe5uAJmx/9f/ToU4Q4ynE
qN8b04C8plcwjWmr74DNvgQye+IJiInzgc7yn/8J6MATIL0zLn2CmHlnKVCz
46F3/7cXAIXTrsNc9/vBRgaQG56CvJO2EcnRT0GOcJz/4M6dB+++o3j9KUiI
grAjCgAAqK92FQ==
                  "], {{0, 0}, {8, 19}}, {0, 255},
                  ColorFunction->RGBColor],
                 ImageSize->{8, 19},
                 PlotRange->{{0, 8}, {0, 19}}],
                HoldForm],
               StripOnInput->False,
               Opacity->1,
               FontOpacity->1,
               $CellContext`LineOpacity -> 1,
               $CellContext`FrontFaceOpacity -> 1,
               $CellContext`BackFaceOpacity -> 1],
              LabelStyle -> {},
              Frame -> True,
              Background->Directive[
                GrayLevel[1]],
              ContentPadding->False,
              FrameMargins->2,
              FrameStyle->None,
              RoundingRadius->4,
              StripOnInput->False],
             
             FrameMargins->
              0], {3.0249089338857837, -20.107453695174605}, {0, 0}], InsetBox[
            PaneBox[
             FrameBox[
              StyleBox[
               TagBox[
                GraphicsBox[RasterBox[CompressedData["
1:eJzNUSFyhTAUzExtXU/QC+QOOUFmqlFf1BaLxSHjcFEoFOorTFVMDAaDiMEg
ImIiEPn7Ap8eoNOZvpkw2cdmd/Pyfvv6uL0wxt6wXrFon/5jBV0gmhi3/cDe
KmCpzA9lnz8ZVT2uR8MoSVi0/qK4nmcOr8dDRomMWTHFk7PeK8BOl1DayNmA
0nQaXz2fpO+aM96uboDS6FOkMNKuEwKUgzuV4VTeU3JoNnabWsG4CimSUJXd
o5XkNCNXXzChhrZgvKEbmQb6DdzjrBGunQKaS18eWZXxz5zCBvThIHKPLpgp
0oTssHTHcaKw6pxLWghxdY4lWiSSegqbW9w1quSBtnBNDj9Xv//qDf+gHv7V
Goo=
                  "], {{0, 0}, {12, 19}}, {0, 255},
                  ColorFunction->RGBColor],
                 ImageSize->{12, 19},
                 PlotRange->{{0, 12}, {0, 19}}],
                HoldForm],
               StripOnInput->False,
               Opacity->1,
               FontOpacity->1,
               $CellContext`LineOpacity -> 1,
               $CellContext`FrontFaceOpacity -> 1,
               $CellContext`BackFaceOpacity -> 1],
              LabelStyle -> {},
              Frame -> True,
              Background->Directive[
                GrayLevel[1]],
              ContentPadding->False,
              FrameMargins->2,
              FrameStyle->None,
              RoundingRadius->4,
              StripOnInput->False],
             
             FrameMargins->
              0], {18.978330602593708, -5.76528121050664}, {0, 0}], InsetBox[
            PaneBox[
             FrameBox[
              StyleBox[
               TagBox[
                GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmIOIAax/9MYzI8BWtL0AMb9dGk+kJ+29PqnSzNAjNV3
wMLvZjiCeNe/A9nfV6eB2UDRQ51AVuVGmO6n20ES81d3AhXrdb5CsuXERH8G
MJh/6ROy7d+vzwcLF9z5jSz8aT5UOUPM/Etw0VcQ6/beOTsDKO146B1E+EEl
UFSv6SlI3wmQzZV7gczrYCM6T0AVXQJpYVh65/unVw+u33n6HW7o709A/qtP
KNbTAgAAGKFtWA==
                  "], {{0, 0}, {8, 19}}, {0, 255},
                  ColorFunction->RGBColor],
                 ImageSize->{8, 19},
                 PlotRange->{{0, 8}, {0, 19}}],
                HoldForm],
               StripOnInput->False,
               Opacity->1,
               FontOpacity->1,
               $CellContext`LineOpacity -> 1,
               $CellContext`FrontFaceOpacity -> 1,
               $CellContext`BackFaceOpacity -> 1],
              LabelStyle -> {},
              Frame -> True,
              Background->Directive[
                GrayLevel[1]],
              ContentPadding->False,
              FrameMargins->2,
              FrameStyle->None,
              RoundingRadius->4,
              StripOnInput->False],
             
             FrameMargins->
              0], {13.776068129873936, -12.758868621755889}, {0, 0}], InsetBox[
            PaneBox[
             FrameBox[
              StyleBox[
               TagBox[
                GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmJ2IAax/9MOfD/rz8Aw8ewnNEFHkOA7bCpRBT+BVV5C
0X5naRrQzY5NexFCv6+DhEDAce8rmLLVQDG97dfPFgCppkNgZXeAbIaYpb//
/780A2ibHlDxg9UgsfkQK96dAFqn13koBmTSDLith5r0gAIP7tx58O47koPf
3bn+gNxwwQcALj1NGg==
                  "], {{0, 0}, {7, 19}}, {0, 255},
                  ColorFunction->RGBColor],
                 ImageSize->{7, 19},
                 PlotRange->{{0, 7}, {0, 19}}],
                HoldForm],
               StripOnInput->False,
               Opacity->1,
               FontOpacity->1,
               $CellContext`LineOpacity -> 1,
               $CellContext`FrontFaceOpacity -> 1,
               $CellContext`BackFaceOpacity -> 1],
              LabelStyle -> {},
              Frame -> True,
              Background->Directive[
                GrayLevel[1]],
              ContentPadding->False,
              FrameMargins->2,
              FrameStyle->None,
              RoundingRadius->4,
              StripOnInput->False],
             
             FrameMargins->
              0], {24.6844387495756, -15.710264706144555}, {0, 0}], InsetBox[
            PaneBox[
             FrameBox[
              StyleBox[
               TagBox[
                GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmIOIAax/9MYXJofw4ABHCee/XR9KZjpv3rv3o1QsHrv
pVdALScm+jMw6K2+8xvDsDuVIC1NDzAkPp2dATJrxllMB+yt1ANKrX6AYdr3
S2lgp7zC0PLuUCdQJm3pdajhr6Dg06cHnSDDHLc//f3/+wk9TI81nfj///er
B3fu3HkAB0DO03ffSQ850gAA3T9u/Q==
                  "], {{0, 0}, {8, 19}}, {0, 
                  255},
                  ColorFunction->RGBColor],
                 ImageSize->{8, 19},
                 PlotRange->{{0, 8}, {0, 19}}],
                HoldForm],
               StripOnInput->False,
               Opacity->1,
               FontOpacity->1,
               $CellContext`LineOpacity -> 1,
               $CellContext`FrontFaceOpacity -> 1,
               $CellContext`BackFaceOpacity -> 1],
              LabelStyle -> {},
              Frame -> True,
              Background->Directive[
                GrayLevel[1]],
              ContentPadding->False,
              FrameMargins->2,
              FrameStyle->None,
              RoundingRadius->4,
              StripOnInput->False],
             
             FrameMargins->
              0], {-10.907114407088695, -13.245419361131054}, {0, 0}]}}},
        AspectRatio->1,
        Axes->{False, False},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{False, False}, {False, False}},
        FrameLabel->{{None, None}, {None, None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        ImagePadding->All,
        Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              (Identity[#]& )[
               Part[#, 1]], 
              (Identity[#]& )[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              (Identity[#]& )[
               Part[#, 1]], 
              (Identity[#]& )[
               Part[#, 2]]}& )}},
        PlotRange->All,
        PlotRangeClipping->False,
        PlotRangePadding->{{
           Scaled[0.05], 
           Scaled[0.05]}, {
           Scaled[0.05], 
           Scaled[0.05]}},
        Ticks->{Automatic, Automatic}]], "ExerciseOutput",ExpressionUUID->
       "3d983761-bbc9-467b-ae88-398518c7ab8e"],
      Apply[TextCell, 
       Cell[
        BoxData[
         GraphicsBox[{{}, {{{}, {{{{{
                  Hue[0.67, 0.6, 0.6], 
                  PointBox[CompressedData["
1:eJwBsQFO/iFib1JlAgAAABoAAAACAAAAEYznZaVCOEBU+mpYexcbQO3sO/Ei
pCXAzBuEAkWeCUB2kbs+Htk6wHSJOJ89IR1ApazL5CEvJsDUSEtFLesnQEDS
tiG2ly/A6jvUMs9WGsCGWuNlz/o0wP1ICTqJ5yXAMAyQ/IpLN8ABSD6JWNMl
QBab2GfRbBxA2WjzzBJUBEC9PCbHvkxAQKWuJGLfhRfAocJHyy2O8T8m+7DC
VeYxQBSaTRH+bSdAn6XyLqJTHsCefGF7v2c6wA2VF7IbkhLApAoj+iX2LkAv
6N+jTckFQMukgeC9JCNAwE73bgrmHUCj+OI2i0wtwF3tfuY9uDBA/fMrADM0
BsD9A/nQuhcRwDk9hmqD7TDAWDZxYOOeNUCRezGe5QoBQDptNvKiwAzAfsgz
XtxHMcAdQ1PbO7P/P+cdKfCEIUBAWIrrnd6BJcCPJ+mDA3XxP1BOUMAuhSVA
YleDdAMzCED6m9oVghs0wOLQ1t9z+jJALXqt4KUPF8CJjUrNWI0rQOXNkG2K
hCnA14q9YDevOECvycjQp2svwE5asExx0CXA57lDm6d9KsDdNcY2
                   
                   "]]}}}}}, {}}}, {}, {}, {{{{}}}, {{{}}}}, {{{{}}}, {{{
               InsetBox[
                PaneBox[
                 FrameBox[
                  StyleBox[
                   TagBox[
                    GraphicsBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmIOIAax/9MYpDEwOHaeQBa5s7qAgUFvI5BgaHqKEP40
3x8o3PnuUCdQYun171Dhd4ccGRj8Z1z6//1SDAM6WP3g9///v7dX6gHZMzbu
3bt3NUiNXucriNYTQKMcD30C2Ql0hv/8S1AzwUYVbH/6/foMoPKNIEMg4Pd2
oKvS5m/sdGTQm/gOyc3vTkyE2Jg2/zqK935fh7hq49Pf/1HBu6d37jzAEKUZ
AAAubmtE
                    "], {{0, 0}, {8, 19}}, {0, 255}, ColorFunction -> 
                    RGBColor], ImageSize -> {8, 19}, 
                    PlotRange -> {{0, 8}, {0, 19}}], HoldForm], StripOnInput -> 
                   False, $CellContext`LineOpacity -> 
                   1, $CellContext`FrontFaceOpacity -> 
                   1, $CellContext`BackFaceOpacity -> 1, Opacity -> 1, 
                   FontOpacity -> 1], LabelStyle -> {}, Frame -> True, 
                  Background -> Directive[
                    GrayLevel[1]], ContentPadding -> False, FrameMargins -> 2,
                   FrameStyle -> None, RoundingRadius -> 4, StripOnInput -> 
                  False], FrameMargins -> 0], {24.260336274175703`, 
                6.772931462792787}, {0, 0}], 
               InsetBox[
                PaneBox[
                 FrameBox[
                  StyleBox[
                   TagBox[
                    GraphicsBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmJOIAax/9MVfJofw4AE9GIqZ1x69Rsq5Q8Uidl44sSJ
Q3uXTiwAK0i79B0m5T//O8yUdycmAuU6T7yDSjnO+AS34elGoNTEszAphspL
T189ffrg0qGNBY5Arv+JT3C7UFxyCNkZek0Pvv/+/undpe0z9IBumn8JIYWw
6/dSMPcdkq47n4CaXl0/BJJhSFsNNvHTRD00q9Jgdv3/9PTBnTt3gPjBg6ev
3n36TdOwxwEAOkaHZg==
                    "], {{0, 0}, {9, 19}}, {0, 255}, 
                    ColorFunction -> RGBColor], ImageSize -> {9, 19}, 
                    PlotRange -> {{0, 9}, {0, 19}}], HoldForm], StripOnInput -> 
                   False, $CellContext`LineOpacity -> 
                   1, $CellContext`FrontFaceOpacity -> 
                   1, $CellContext`BackFaceOpacity -> 1, Opacity -> 1, 
                   FontOpacity -> 1], LabelStyle -> {}, Frame -> True, 
                  Background -> Directive[
                    GrayLevel[1]], ContentPadding -> False, FrameMargins -> 2,
                   FrameStyle -> None, RoundingRadius -> 4, StripOnInput -> 
                  False], FrameMargins -> 0], {-10.820579088750003`, 
                3.202280063301691}, {0, 0}], 
               InsetBox[
                PaneBox[
                 FrameBox[
                  StyleBox[
                   TagBox[
                    GraphicsBox[
                    RasterBox[CompressedData["
1:eJy1j6EOwyAQhkmmpvcEe4G+A0+wZBpVUbvZ2bnKOhwKVbUHOIOqmTmNwMwg
TmAQFQyyrOkybP/kwvF/3A8c28u53THGDrn2uUqfNtQciDzR/Os6o05sEZdg
P743fTEaoWHCCXpRdqOLKb3uTW47jEtGQHR5iVYXoO3/3QFlRhJDDamMhmcV
lane+MpvIpYXCVUZSwlVgfymLYU5epAdv47fkxEGwVbitwetg72dDAAYdFTL
3lZv0BSv+g==
                    "], {{0, 0}, {9, 19}}, {0, 255}, 
                    ColorFunction -> RGBColor], ImageSize -> {9, 19}, 
                    PlotRange -> {{0, 9}, {0, 19}}], HoldForm], StripOnInput -> 
                   False, $CellContext`LineOpacity -> 
                   1, $CellContext`FrontFaceOpacity -> 
                   1, $CellContext`BackFaceOpacity -> 1, Opacity -> 1, 
                   FontOpacity -> 1], LabelStyle -> {}, Frame -> True, 
                  Background -> Directive[
                    GrayLevel[1]], ContentPadding -> False, FrameMargins -> 2,
                   FrameStyle -> None, RoundingRadius -> 4, StripOnInput -> 
                  False], FrameMargins -> 0], {-26.848117752831477`, 
                7.282461631608715}, {0, 0}], 
               InsetBox[
                PaneBox[
                 FrameBox[
                  StyleBox[
                   TagBox[
                    GraphicsBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmJOIAax/9MVfJofwwAHjv4FSw/dQUj5A8ViVh86sXf1
DH+wgpj5ZxFS/vO/Q1U+nQiS1tv7CiblOOMTzJTfd5YC5dJW38GU+v/9EtBy
x4lnsUmd9ccl9emEIw6pS2DPzLj0CSql13Tn06d3T6+v7gR70n/GO7D+iXoM
yCCmafWr3zCznz64c+fOAzDx6tPv/wMBAFbNk4I=
                    "], {{0, 0}, {9, 
                    19}}, {0, 255}, ColorFunction -> RGBColor], 
                    ImageSize -> {9, 19}, PlotRange -> {{0, 9}, {0, 19}}], 
                    HoldForm], StripOnInput -> 
                   False, $CellContext`LineOpacity -> 
                   1, $CellContext`FrontFaceOpacity -> 
                   1, $CellContext`BackFaceOpacity -> 1, Opacity -> 1, 
                   FontOpacity -> 1], LabelStyle -> {}, Frame -> True, 
                  Background -> Directive[
                    GrayLevel[1]], ContentPadding -> False, FrameMargins -> 2,
                   FrameStyle -> None, RoundingRadius -> 4, StripOnInput -> 
                  False], FrameMargins -> 0], {-11.092055463659856`, 
                11.959329762878419`}, {0, 0}], 
               InsetBox[
                PaneBox[
                 FrameBox[
                  StyleBox[
                   TagBox[
                    GraphicsBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmIOIAax/9McfJofw4AGJp59BxL3BzL952/cvhECVm+8
/u43VNx//ndMc4DijjOwizMUHLp+5zoQXLr+AGQIXBwJdJ5AEm+6/u7dKzD4
9B3JHFz26iHUv3r1Dqzm00Q9dH8d+gSWePrgzp07D6AAxPxEvdDEBQCIi2wv

                    "], {{0, 0}, {8, 19}}, {0, 255}, ColorFunction -> 
                    RGBColor], ImageSize -> {8, 19}, 
                    PlotRange -> {{0, 8}, {0, 19}}], HoldForm], StripOnInput -> 
                   False, $CellContext`LineOpacity -> 
                   1, $CellContext`FrontFaceOpacity -> 
                   1, $CellContext`BackFaceOpacity -> 1, Opacity -> 1, 
                   FontOpacity -> 1], LabelStyle -> {}, Frame -> True, 
                  Background -> Directive[
                    GrayLevel[1]], ContentPadding -> False, FrameMargins -> 2,
                   FrameStyle -> None, RoundingRadius -> 4, StripOnInput -> 
                  False], FrameMargins -> 
                 0], {-15.796311429564525`, -6.584774774745691}, {0, 0}], 
               InsetBox[
                PaneBox[
                 FrameBox[
                  StyleBox[
                   TagBox[
                    GraphicsBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmJ2IAax/9MEfJofw8DgP/8TquAMfwYGxxnv0FSCBT9h
CvrP/44pyOA/Y/Xq1UuXLp0/f++ldzBBBIiZfwlm5kRiLdJruv7u3SsoAJk5
UY8BDYCUPn1w586dB1AAYlIYRlgBAIEXRQ0=
                    "], {{0, 0}, {7, 
                    19}}, {0, 255}, ColorFunction -> RGBColor], 
                    ImageSize -> {7, 19}, PlotRange -> {{0, 7}, {0, 19}}], 
                    HoldForm], StripOnInput -> 
                   False, $CellContext`LineOpacity -> 
                   1, $CellContext`FrontFaceOpacity -> 
                   1, $CellContext`BackFaceOpacity -> 1, Opacity -> 1, 
                   FontOpacity -> 1], LabelStyle -> {}, Frame -> True, 
                  Background -> Directive[
                    GrayLevel[1]], ContentPadding -> False, FrameMargins -> 2,
                   FrameStyle -> None, RoundingRadius -> 4, StripOnInput -> 
                  False], FrameMargins -> 
                 0], {-20.979727142339947`, -10.952218831666409`}, {0, 0}], 
               InsetBox[
                PaneBox[
                 FrameBox[
                  StyleBox[
                   TagBox[
                    GraphicsBox[
                    RasterBox[CompressedData["
1:eJy1jyESwyAQRZmpqu4JeoHcISfITDUqIrY9Q1xk3DoUqqoHqEFhMJiYiJgY
xAoMAkGBNm06E5s/szPLf+xnOdfXS30ghJxiHWOlPuwpi2gMWv9nzpLTgnxF
Wz675KPss1HBQyglWEvjoZMYgunS/UbZJcLripBeoRt5Anz8pTtVZmQ1RAQ6
zzhNl+cyYrnJyM93iGLQg5jce6oTZuMzfmjydnaDhYEnWN7YYKz3bhRQFjeF
n0kBDVmrbDWuVsZJiWeU1JPfCt9VL6yXmfQ=
                    "], {{0, 0}, {9, 
                    19}}, {0, 255}, ColorFunction -> RGBColor], 
                    ImageSize -> {9, 19}, PlotRange -> {{0, 9}, {0, 19}}], 
                    HoldForm], StripOnInput -> 
                   False, $CellContext`LineOpacity -> 
                   1, $CellContext`FrontFaceOpacity -> 
                   1, $CellContext`BackFaceOpacity -> 1, Opacity -> 1, 
                   FontOpacity -> 1], LabelStyle -> {}, Frame -> True, 
                  Background -> Directive[
                    GrayLevel[1]], ContentPadding -> False, FrameMargins -> 2,
                   FrameStyle -> None, RoundingRadius -> 4, StripOnInput -> 
                  False], FrameMargins -> 0], {-23.295089516799806`, 
                10.91278485188741}, {0, 0}], 
               InsetBox[
                PaneBox[
                 FrameBox[
                  StyleBox[
                   TagBox[
                    GraphicsBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmIuIAax/w8Y+DQ/hoHBf/4nuMD3S2lAgRmXILIz/BkY
HGe8Qyg/CxKYeBaqFyyLpBeL7He47O9LMWiyDAWHrt+5DgJ3rp+YD+T7o8ii
AxRZvabr7969AoF3r+5s1EOTRXHVJYJuhuudCDRIb+I7JFlHoEDnCajvn955
8BShFeilVw/uPH33/f/AAQC6adIj
                    "], {{0, 0}, {10, 19}}, {0, 
                    255}, ColorFunction -> RGBColor], ImageSize -> {10, 19}, 
                    PlotRange -> {{0, 10}, {0, 19}}], HoldForm], StripOnInput -> 
                   False, $CellContext`LineOpacity -> 
                   1, $CellContext`FrontFaceOpacity -> 
                   1, $CellContext`BackFaceOpacity -> 1, Opacity -> 1, 
                   FontOpacity -> 1], LabelStyle -> {}, Frame -> True, 
                  Background -> Directive[
                    GrayLevel[1]], ContentPadding -> False, FrameMargins -> 2,
                   FrameStyle -> None, RoundingRadius -> 4, StripOnInput -> 
                  False], FrameMargins -> 0], {7.106267569156236, 
                2.541051484277983}, {0, 0}], 
               InsetBox[
                PaneBox[
                 FrameBox[
                  StyleBox[
                   TagBox[
                    GraphicsBox[
                    
                    RasterBox[{{{255, 255, 255}, {255, 255, 255}, {255, 255, 
                    255}, {255, 255, 255}}, {{255, 255, 255}, {255, 255, 
                    255}, {255, 255, 255}, {255, 255, 255}}, {{255, 255, 
                    255}, {255, 255, 255}, {255, 255, 255}, {255, 255, 
                    255}}, {{255, 255, 255}, {255, 255, 255}, {255, 255, 
                    255}, {255, 255, 255}}, {{255, 255, 242}, {159, 92, 0}, {
                    0, 79, 159}, {242, 255, 255}}, {{255, 255, 242}, {152, 79,
                     0}, {0, 65, 152}, {238, 255, 255}}, {{255, 255, 242}, {
                    159, 79, 0}, {0, 65, 152}, {242, 255, 255}}, {{255, 255, 
                    242}, {159, 79, 0}, {0, 65, 152}, {242, 255, 255}}, {{255,
                     255, 242}, {159, 79, 0}, {0, 65, 152}, {242, 255, 
                    255}}, {{255, 255, 242}, {159, 79, 0}, {0, 65, 152}, {242,
                     255, 255}}, {{255, 255, 242}, {159, 79, 0}, {0, 65, 
                    152}, {242, 255, 255}}, {{255, 255, 242}, {159, 79, 0}, {
                    0, 65, 152}, {242, 255, 255}}, {{255, 255, 242}, {159, 79,
                     0}, {0, 65, 152}, {242, 255, 255}}, {{255, 255, 242}, {
                    145, 46, 0}, {0, 46, 145}, {238, 255, 255}}, {{255, 255, 
                    255}, {242, 229, 220}, {224, 229, 242}, {255, 255, 
                    255}}, {{255, 255, 255}, {255, 255, 255}, {255, 255, 
                    255}, {255, 255, 255}}, {{255, 255, 255}, {255, 255, 
                    255}, {255, 255, 255}, {255, 255, 255}}, {{255, 255, 
                    255}, {255, 255, 255}, {255, 255, 255}, {255, 255, 
                    255}}, {{255, 255, 255}, {255, 255, 255}, {255, 255, 
                    255}, {255, 255, 255}}}, {{0, 0}, {4, 19}}, {0, 255}, 
                    ColorFunction -> RGBColor], ImageSize -> {4, 19}, 
                    PlotRange -> {{0, 4}, {0, 19}}], HoldForm], StripOnInput -> 
                   False, $CellContext`LineOpacity -> 
                   1, $CellContext`FrontFaceOpacity -> 
                   1, $CellContext`BackFaceOpacity -> 1, Opacity -> 1, 
                   FontOpacity -> 1], LabelStyle -> {}, Frame -> True, 
                  Background -> Directive[
                    GrayLevel[1]], ContentPadding -> False, FrameMargins -> 2,
                   FrameStyle -> None, RoundingRadius -> 4, StripOnInput -> 
                  False], FrameMargins -> 0], {
                32.59957208029798, -5.880734952439217}, {0, 0}], 
               InsetBox[
                PaneBox[
                 FrameBox[
                  StyleBox[
                   TagBox[
                    GraphicsBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmJ2IAax/1MDvHsFBO9+w/m/n85I02OAgpi9D74DxS7N
cARyOlcfOrsXzPJfChL9/vTspacQTZdm+DMwpF3/jmIyWND/xCcsgmdpL3h2
ItClemi2//709M6dp7//0wQAAJQIVgs=
                    "], {{0, 0}, {7, 19}}, {
                    0, 255}, ColorFunction -> RGBColor], ImageSize -> {7, 19},
                     PlotRange -> {{0, 7}, {0, 19}}], HoldForm], StripOnInput -> 
                   False, $CellContext`LineOpacity -> 
                   1, $CellContext`FrontFaceOpacity -> 
                   1, $CellContext`BackFaceOpacity -> 1, Opacity -> 1, 
                   FontOpacity -> 1], LabelStyle -> {}, Frame -> True, 
                  Background -> Directive[
                    GrayLevel[1]], ContentPadding -> False, FrameMargins -> 2,
                   FrameStyle -> None, RoundingRadius -> 4, StripOnInput -> 
                  False], FrameMargins -> 0], {1.0972116413724182`, 
                17.89974610157801}, {0, 0}], 
               InsetBox[
                PaneBox[
                 FrameBox[
                  StyleBox[
                   TagBox[
                    GraphicsBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmJOIAax/9MVfJofw8DgP/8TXODpdkcGBr2mQ0CpGf4M
DI4z3kElvq9OA7rOce+r3yBdICmork9nZwAl/GechRoIlGJIOwuSe9WpB2QX
XP/9H0mKgSFm4vallUC6cvtTFGfAQcz8d3D3QHTFzNi7tAAsc+k/mpTjjO//
/28sANk08cQ7NCkw/+lER5DLtz+FuOPTRKBavYlQpZ8upYGtvAT2zKendx48
RQTG73dP71y/8+43JSFMMgAABnOZsw==
                    "], {{0, 0}, {9, 19}}, {
                    0, 255}, ColorFunction -> RGBColor], ImageSize -> {9, 19},
                     PlotRange -> {{0, 9}, {0, 19}}], HoldForm], StripOnInput -> 
                   False, $CellContext`LineOpacity -> 
                   1, $CellContext`FrontFaceOpacity -> 
                   1, $CellContext`BackFaceOpacity -> 1, Opacity -> 1, 
                   FontOpacity -> 1], LabelStyle -> {}, Frame -> True, 
                  Background -> Directive[
                    GrayLevel[1]], ContentPadding -> False, FrameMargins -> 2,
                   FrameStyle -> None, RoundingRadius -> 4, StripOnInput -> 
                  False], FrameMargins -> 0], {
                11.714829006884464`, -7.581673368034358}, {0, 0}], 
               InsetBox[
                PaneBox[
                 FrameBox[
                  StyleBox[
                   TagBox[
                    GraphicsBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmJ2IAax/9MEfJofw4AK/EGC/iDG/I3bN4LB6o2HoIL+
87+jaQcKOs74NECCE/UYGPQmvkPz0tM7D56iKqQBAAD4rFL4
                    "], {{0, 
                    0}, {7, 19}}, {0, 255}, ColorFunction -> RGBColor], 
                    ImageSize -> {7, 19}, PlotRange -> {{0, 7}, {0, 19}}], 
                    HoldForm], StripOnInput -> 
                   False, $CellContext`LineOpacity -> 
                   1, $CellContext`FrontFaceOpacity -> 
                   1, $CellContext`BackFaceOpacity -> 1, Opacity -> 1, 
                   FontOpacity -> 1], LabelStyle -> {}, Frame -> True, 
                  Background -> Directive[
                    GrayLevel[1]], ContentPadding -> False, FrameMargins -> 2,
                   FrameStyle -> None, RoundingRadius -> 4, StripOnInput -> 
                  False], FrameMargins -> 
                 0], {-26.405265532780156`, -4.642683775605531}, {0, 0}], 
               InsetBox[
                PaneBox[
                 FrameBox[
                  StyleBox[
                   TagBox[
                    GraphicsBox[
                    RasterBox[CompressedData["
1:eJzNUKEOwyAQvWRycl+wH+g/8AUk06iK2dXW1lXicKiqfkBVzVQNpmYGgcEg
JmoQFQxYl5Yt09sll9x794573DG/nPIdABx87n2G2v1FTBwDouI7OTG01LNq
AdD1npDbWlDs/3VulXP2QzA6pwuIgZh1lr8J2M1KBkBGNSCAzpgm9YD50FcA
ReeN+BbmPSfpC2Xt11MR/JkgxSRbBRw/d5dyjoQdScSYvQQRZ5tT9GUWzS4C
GhA00q5nEiyM1MMCtZJSr+24RkupTMr9Lh7V3PPK
                    "], {{0, 0}, {11,
                     19}}, {0, 255}, ColorFunction -> RGBColor], 
                    ImageSize -> {11, 19}, PlotRange -> {{0, 11}, {0, 19}}], 
                    HoldForm], StripOnInput -> 
                   False, $CellContext`LineOpacity -> 
                   1, $CellContext`FrontFaceOpacity -> 
                   1, $CellContext`BackFaceOpacity -> 1, Opacity -> 1, 
                   FontOpacity -> 1], LabelStyle -> {}, Frame -> True, 
                  Background -> Directive[
                    GrayLevel[1]], ContentPadding -> False, FrameMargins -> 2,
                   FrameStyle -> None, RoundingRadius -> 4, StripOnInput -> 
                  False], FrameMargins -> 0], {15.480758492257628`, 
                2.7232926180559143`}, {0, 0}], 
               InsetBox[
                PaneBox[
                 FrameBox[
                  StyleBox[
                   TagBox[
                    GraphicsBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmIuIAax/w8Y+DTfn8Fx4lk4/93ZGUD3xMy/BJGd4Ygs
+7RJDyjJ4A8VQZG9s7qAAQz8Z2DIfj8bw8Dg2Ll6RgxcPUL2UKcjUNOJV3ea
GFBlZ1z//2472DHX//+/5I9qr//8vasrgZIFd8Dm+yPpBfoIApoOvfqPKRsD
louZ/wnibrAs3OSJYA+uvvP7P0wW6Di9TqgfPz19cOfBO6TQ+/3qwZ2nn37/
HzgAADmbx5k=
                    "], {{0, 0}, {10, 19}}, {0, 255}, 
                    ColorFunction -> RGBColor], ImageSize -> {10, 19}, 
                    PlotRange -> {{0, 10}, {0, 19}}], HoldForm], StripOnInput -> 
                   False, $CellContext`LineOpacity -> 
                   1, $CellContext`FrontFaceOpacity -> 
                   1, $CellContext`BackFaceOpacity -> 1, Opacity -> 1, 
                   FontOpacity -> 1], LabelStyle -> {}, Frame -> True, 
                  Background -> Directive[
                    GrayLevel[1]], ContentPadding -> False, FrameMargins -> 2,
                   FrameStyle -> None, RoundingRadius -> 4, StripOnInput -> 
                  False], FrameMargins -> 0], {9.571761146379137, 
                7.4746491754955855`}, {0, 0}], 
               InsetBox[
                PaneBox[
                 FrameBox[
                  StyleBox[
                   TagBox[
                    GraphicsBox[
                    RasterBox[CompressedData["
1:eJzFkKEOgzAQhknmZvcEewHeYU9AMo1CYIedxVXi6qZQVX2AmipMTU0NogaD
qKipQLC7LpCS+e1Pmvz3f3fXptfqca9OWZZd4JzhoF9/ocU7D1q+gBX0lu26
UWl3NEuCWd4wIaVgdY4VkXOEU4tlY8LWHXSNzQRwGHuwNRvTi0yPnNvFKwqG
ap/SoF8Qdsp5TaM50C10n1kyuJS6+E4KI14V8eKQLO5LiEodo6FDXhI++RC8
5S2WRaf2TaxJPgO+48kP74AOa6QASTO59d96A6IhyfA=
                    "], {{0, 
                    0}, {10, 19}}, {0, 255}, ColorFunction -> RGBColor], 
                    ImageSize -> {10, 19}, PlotRange -> {{0, 10}, {0, 19}}], 
                    HoldForm], StripOnInput -> 
                   False, $CellContext`LineOpacity -> 
                   1, $CellContext`FrontFaceOpacity -> 
                   1, $CellContext`BackFaceOpacity -> 1, Opacity -> 1, 
                   FontOpacity -> 1], LabelStyle -> {}, Frame -> True, 
                  Background -> Directive[
                    GrayLevel[1]], ContentPadding -> False, FrameMargins -> 2,
                   FrameStyle -> None, RoundingRadius -> 4, StripOnInput -> 
                  False], FrameMargins -> 0], {-14.649499621588182`, 
                16.719694524753653`}, {0, 0}], 
               InsetBox[
                PaneBox[
                 FrameBox[
                  StyleBox[
                   TagBox[
                    GraphicsBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmJOIAax/9MVfJofw8DgP/8TNqkZ/gwMjjPeYdUFlsKq
CySl1/n0///f33//xpRCAjGVSx98R5aK2X7i7NkTh5Z2poGk/ee/g0v5z/8O
M+XSDKCLHU98wuKMTyc6UaT0mu58+vTp3bs7ZzeCTUy7DjLl00Q9BlTguPQS
1Jefnj64c+cOED948ODVq3eo7qcTAADeHKSZ
                    "], {{0, 0}, {9, 
                    19}}, {0, 255}, ColorFunction -> RGBColor], 
                    ImageSize -> {9, 19}, PlotRange -> {{0, 9}, {0, 19}}], 
                    HoldForm], StripOnInput -> 
                   False, $CellContext`LineOpacity -> 
                   1, $CellContext`FrontFaceOpacity -> 
                   1, $CellContext`BackFaceOpacity -> 1, Opacity -> 1, 
                   FontOpacity -> 1], LabelStyle -> {}, Frame -> True, 
                  Background -> Directive[
                    GrayLevel[1]], ContentPadding -> False, FrameMargins -> 2,
                   FrameStyle -> None, RoundingRadius -> 4, StripOnInput -> 
                  False], FrameMargins -> 
                 0], {-2.7754879010594764`, -4.273173585127549}, {0, 0}], 
               InsetBox[
                PaneBox[
                 FrameBox[
                  StyleBox[
                   TagBox[
                    GraphicsBox[
                    RasterBox[CompressedData["
1:eJzFUCESgzAQZKauti/oB/oHXsBMNQqBbSwWh8TFoVAoVFVMFCYmJiYCg0FE
xERE0EtaaMBV9WZuZm83t7m7a/a4Z6coii6QZ0iHlx9DjZwSQuggJn1QWhRH
aySNCCQ74BTIFFNtF2u0sR9BEvztuaUNHbeemVaOjAvChGDPwr+r6OzFqXRV
Ie32g0DOoQTZiBYg6mQ4nGxzIDtpNMcAarYb3vDGk+qtIjKH6tqiNPNgULu1
/ZwYDDVLAOWdCYxbvzf31FA7Pa36SRujx750ZVKzzakLDuhX748nHoU7PqFi
Usu/4wUE+7cr
                    "], {{0, 0}, {10, 19}}, {0, 255}, 
                    ColorFunction -> RGBColor], ImageSize -> {10, 19}, 
                    PlotRange -> {{0, 10}, {0, 19}}], HoldForm], StripOnInput -> 
                   False, $CellContext`LineOpacity -> 
                   1, $CellContext`FrontFaceOpacity -> 
                   1, $CellContext`BackFaceOpacity -> 1, Opacity -> 1, 
                   FontOpacity -> 1], LabelStyle -> {}, Frame -> True, 
                  Background -> Directive[
                    GrayLevel[1]], ContentPadding -> False, FrameMargins -> 2,
                   FrameStyle -> None, RoundingRadius -> 4, StripOnInput -> 
                  False], FrameMargins -> 0], {-16.92778650071452, 
                21.620656993522374`}, {0, 0}], 
               InsetBox[
                PaneBox[
                 FrameBox[
                  StyleBox[
                   TagBox[
                    GraphicsBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmJOIAax/9MVfJofw8DgP/8TjH+o05+BQW/jg99AqRlA
puOMd2Dx3w9WA92mV7n9N0QXQgpsAoPjoXcwA8FS34GsExOBEgVLryPsAkoB
Jf399UA0Q9P2O6hSegVNnZ1NlRBp/4knkAyc/x2q8h3Yus5XSHbBHX8dJOd4
4hNMSq/pzqdPn969un5iNUiT3kSIgydCrEcA/43XoWZ8evrgzp07Dx6A8NNX
735TN7CJAwAqBZCP
                    "], {{0, 0}, {9, 19}}, {0, 255}, 
                    ColorFunction -> RGBColor], ImageSize -> {9, 19}, 
                    PlotRange -> {{0, 9}, {0, 19}}], HoldForm], StripOnInput -> 
                   False, $CellContext`LineOpacity -> 
                   1, $CellContext`FrontFaceOpacity -> 
                   1, $CellContext`BackFaceOpacity -> 1, Opacity -> 1, 
                   FontOpacity -> 1], LabelStyle -> {}, Frame -> True, 
                  Background -> Directive[
                    GrayLevel[1]], ContentPadding -> False, FrameMargins -> 2,
                   FrameStyle -> None, RoundingRadius -> 4, StripOnInput -> 
                  False], FrameMargins -> 0], {
                2.130320773968784, -3.5940607951030445`}, {0, 0}], 
               InsetBox[
                PaneBox[
                 FrameBox[
                  StyleBox[
                   TagBox[
                    GraphicsBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmIOIAax/1MZ/P707t2rd+++I0S+n13d6cgAB3qdG68D
Re+sTgPx/CtXHzp76ezezhg9IG/GpU//fz/dvvEEQvvvS/4MDI6dJ9CseXpo
IlB9zPxLCJFLezvTIPY4HnoFFvp0qckfaqtjWufZVxBTP80HC/o3Lb3+CsmZ
n04ANTs2HcLw0dNKkP6ms08//f7+6dL2iXp6BUBnAsGrszMYkIF/E0QcHApP
zx7aCwRnrz/9TX5gkgAAmoFq1w==
                    "], {{0, 0}, {8, 19}}, {0, 
                    255}, ColorFunction -> RGBColor], ImageSize -> {8, 19}, 
                    PlotRange -> {{0, 8}, {0, 19}}], HoldForm], StripOnInput -> 
                   False, $CellContext`LineOpacity -> 
                   1, $CellContext`FrontFaceOpacity -> 
                   1, $CellContext`BackFaceOpacity -> 1, Opacity -> 1, 
                   FontOpacity -> 1], LabelStyle -> {}, Frame -> True, 
                  Background -> Directive[
                    GrayLevel[1]], ContentPadding -> False, FrameMargins -> 2,
                   FrameStyle -> None, RoundingRadius -> 4, StripOnInput -> 
                  False], FrameMargins -> 0], {-17.28070629848707, 
                1.9812582557098672`}, {0, 0}], 
               InsetBox[
                PaneBox[
                 FrameBox[
                  StyleBox[
                   TagBox[
                    GraphicsBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmIOIAax/9MJfFoaw8DgP/8ThvgMfwYGxxnvMMTng8Ux
1dNZ/Pund69evfr07nqTHgODXtP1dyDuq3ffJzJgBZ2fXj24c+fOAyC4g6Af
PMWwh9oAAL/Hhh0=
                    "], {{0, 0}, {8, 19}}, {0, 255}, 
                    ColorFunction -> RGBColor], ImageSize -> {8, 19}, 
                    PlotRange -> {{0, 8}, {0, 19}}], HoldForm], StripOnInput -> 
                   False, $CellContext`LineOpacity -> 
                   1, $CellContext`FrontFaceOpacity -> 
                   1, $CellContext`BackFaceOpacity -> 1, Opacity -> 1, 
                   FontOpacity -> 1], LabelStyle -> {}, Frame -> True, 
                  Background -> Directive[
                    GrayLevel[1]], ContentPadding -> False, FrameMargins -> 2,
                   FrameStyle -> None, RoundingRadius -> 4, StripOnInput -> 
                  False], FrameMargins -> 0], {
                32.2618694496885, -10.753651556971064`}, {0, 0}], 
               InsetBox[
                PaneBox[
                 FrameBox[
                  StyleBox[
                   TagBox[
                    GraphicsBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmIuIAax/9MB/P7+7t2rd+8+YcpcWt3EAAd6MdvvINR8
ujQfJOhYufHQiUMbZziCOAV3fkNN3F6px8AQcxam/NOJiUDpGZcg/E8g1Y4z
EGZ9v+TPwJC29DpcVq/zEMIR388CZR0nnoXLwtj0kPWHyYI80HkCWRboCT2Y
yLundx68+o4cpq8e3Hn66TdmkNINAAB5At0y
                    "], {{0, 0}, {10, 
                    19}}, {0, 255}, ColorFunction -> RGBColor], 
                    ImageSize -> {10, 19}, PlotRange -> {{0, 10}, {0, 19}}], 
                    HoldForm], StripOnInput -> 
                   False, $CellContext`LineOpacity -> 
                   1, $CellContext`FrontFaceOpacity -> 
                   1, $CellContext`BackFaceOpacity -> 1, Opacity -> 1, 
                   FontOpacity -> 1], LabelStyle -> {}, Frame -> True, 
                  Background -> Directive[
                    GrayLevel[1]], ContentPadding -> False, FrameMargins -> 2,
                   FrameStyle -> None, RoundingRadius -> 4, StripOnInput -> 
                  False], FrameMargins -> 0], {1.0910678055538232`, 
                10.760122308543174`}, {0, 0}], 
               InsetBox[
                PaneBox[
                 FrameBox[
                  StyleBox[
                   TagBox[
                    GraphicsBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmIOIAax/9MHvDvkD7TMsfMVqvCDjZUMYLDxwW8k4e9L
Y4CKYxwZGGLmX0IIfzoBFKncfv1Qpx6D3sR3MOFXe5uAJmx/9f/ToU4Q4ynE
qN8b04C8plcwjWmr74DNvgQye+IJiInzgc7yn/8J6MATIL0zLn2CmHlnKVCz
46F3/7cXAIXTrsNc9/vBRgaQG56CvJO2EcnRT0GOcJz/4M6dB+++o3j9KUiI
grAjCgAAqK92FQ==
                    "], {{0, 0}, {8, 19}}, {0, 255}, 
                    ColorFunction -> RGBColor], ImageSize -> {8, 19}, 
                    PlotRange -> {{0, 8}, {0, 19}}], HoldForm], StripOnInput -> 
                   False, $CellContext`LineOpacity -> 
                   1, $CellContext`FrontFaceOpacity -> 
                   1, $CellContext`BackFaceOpacity -> 1, Opacity -> 1, 
                   FontOpacity -> 1], LabelStyle -> {}, Frame -> True, 
                  Background -> Directive[
                    GrayLevel[1]], ContentPadding -> False, FrameMargins -> 2,
                   FrameStyle -> None, RoundingRadius -> 4, StripOnInput -> 
                  False], FrameMargins -> 0], {
                3.0249089338857837`, -20.107453695174605`}, {0, 0}], 
               InsetBox[
                PaneBox[
                 FrameBox[
                  StyleBox[
                   TagBox[
                    GraphicsBox[
                    RasterBox[CompressedData["
1:eJzNUSFyhTAUzExtXU/QC+QOOUFmqlFf1BaLxSHjcFEoFOorTFVMDAaDiMEg
ImIiEPn7Ap8eoNOZvpkw2cdmd/Pyfvv6uL0wxt6wXrFon/5jBV0gmhi3/cDe
KmCpzA9lnz8ZVT2uR8MoSVi0/qK4nmcOr8dDRomMWTHFk7PeK8BOl1DayNmA
0nQaXz2fpO+aM96uboDS6FOkMNKuEwKUgzuV4VTeU3JoNnabWsG4CimSUJXd
o5XkNCNXXzChhrZgvKEbmQb6DdzjrBGunQKaS18eWZXxz5zCBvThIHKPLpgp
0oTssHTHcaKw6pxLWghxdY4lWiSSegqbW9w1quSBtnBNDj9Xv//qDf+gHv7V
Goo=
                    "], {{0, 0}, {12, 19}}, {0, 255}, ColorFunction -> 
                    RGBColor], ImageSize -> {12, 19}, 
                    PlotRange -> {{0, 12}, {0, 19}}], HoldForm], StripOnInput -> 
                   False, $CellContext`LineOpacity -> 
                   1, $CellContext`FrontFaceOpacity -> 
                   1, $CellContext`BackFaceOpacity -> 1, Opacity -> 1, 
                   FontOpacity -> 1], LabelStyle -> {}, Frame -> True, 
                  Background -> Directive[
                    GrayLevel[1]], ContentPadding -> False, FrameMargins -> 2,
                   FrameStyle -> None, RoundingRadius -> 4, StripOnInput -> 
                  False], FrameMargins -> 0], {
                18.978330602593708`, -5.76528121050664}, {0, 0}], 
               InsetBox[
                PaneBox[
                 FrameBox[
                  StyleBox[
                   TagBox[
                    GraphicsBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmIOIAax/9MYzI8BWtL0AMb9dGk+kJ+29PqnSzNAjNV3
wMLvZjiCeNe/A9nfV6eB2UDRQ51AVuVGmO6n20ES81d3AhXrdb5CsuXERH8G
MJh/6ROy7d+vzwcLF9z5jSz8aT5UOUPM/Etw0VcQ6/beOTsDKO146B1E+EEl
UFSv6SlI3wmQzZV7gczrYCM6T0AVXQJpYVh65/unVw+u33n6HW7o709A/qtP
KNbTAgAAGKFtWA==
                    "], {{0, 0}, {8, 19}}, {0, 255}, 
                    ColorFunction -> RGBColor], ImageSize -> {8, 19}, 
                    PlotRange -> {{0, 8}, {0, 19}}], HoldForm], StripOnInput -> 
                   False, $CellContext`LineOpacity -> 
                   1, $CellContext`FrontFaceOpacity -> 
                   1, $CellContext`BackFaceOpacity -> 1, Opacity -> 1, 
                   FontOpacity -> 1], LabelStyle -> {}, Frame -> True, 
                  Background -> Directive[
                    GrayLevel[1]], ContentPadding -> False, FrameMargins -> 2,
                   FrameStyle -> None, RoundingRadius -> 4, StripOnInput -> 
                  False], FrameMargins -> 0], {
                13.776068129873936`, -12.758868621755889`}, {0, 0}], 
               InsetBox[
                PaneBox[
                 FrameBox[
                  StyleBox[
                   TagBox[
                    GraphicsBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmJ2IAax/9MOfD/rz8Aw8ewnNEFHkOA7bCpRBT+BVV5C
0X5naRrQzY5NexFCv6+DhEDAce8rmLLVQDG97dfPFgCppkNgZXeAbIaYpb//
/780A2ibHlDxg9UgsfkQK96dAFqn13koBmTSDLith5r0gAIP7tx58O47koPf
3bn+gNxwwQcALj1NGg==
                    "], {{0, 0}, {7, 19}}, {0, 255}, 
                    ColorFunction -> RGBColor], ImageSize -> {7, 19}, 
                    PlotRange -> {{0, 7}, {0, 19}}], HoldForm], StripOnInput -> 
                   False, $CellContext`LineOpacity -> 
                   1, $CellContext`FrontFaceOpacity -> 
                   1, $CellContext`BackFaceOpacity -> 1, Opacity -> 1, 
                   FontOpacity -> 1], LabelStyle -> {}, Frame -> True, 
                  Background -> Directive[
                    GrayLevel[1]], ContentPadding -> False, FrameMargins -> 2,
                   FrameStyle -> None, RoundingRadius -> 4, StripOnInput -> 
                  False], FrameMargins -> 0], {
                24.6844387495756, -15.710264706144555`}, {0, 0}], 
               InsetBox[
                PaneBox[
                 FrameBox[
                  StyleBox[
                   TagBox[
                    GraphicsBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmIOIAax/9MYXJofw4ABHCee/XR9KZjpv3rv3o1QsHrv
pVdALScm+jMw6K2+8xvDsDuVIC1NDzAkPp2dATJrxllMB+yt1ANKrX6AYdr3
S2lgp7zC0PLuUCdQJm3pdajhr6Dg06cHnSDDHLc//f3/+wk9TI81nfj///er
B3fu3HkAB0DO03ffSQ850gAA3T9u/Q==
                    "], {{0, 0}, {8, 19}}, {
                    0, 255}, ColorFunction -> RGBColor], ImageSize -> {8, 19},
                     PlotRange -> {{0, 8}, {0, 19}}], HoldForm], StripOnInput -> 
                   False, $CellContext`LineOpacity -> 
                   1, $CellContext`FrontFaceOpacity -> 
                   1, $CellContext`BackFaceOpacity -> 1, Opacity -> 1, 
                   FontOpacity -> 1], LabelStyle -> {}, Frame -> True, 
                  Background -> Directive[
                    GrayLevel[1]], ContentPadding -> False, FrameMargins -> 2,
                   FrameStyle -> None, RoundingRadius -> 4, StripOnInput -> 
                  False], FrameMargins -> 
                 0], {-10.907114407088695`, -13.245419361131054`}, {0, 
                0}]}}}}}, AspectRatio -> 1, Axes -> {False, False}, 
          AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, DisplayFunction -> 
          Identity, Frame -> {{False, False}, {False, False}}, 
          FrameLabel -> {{None, None}, {None, None}}, 
          FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
          GridLines -> {None, None}, GridLinesStyle -> Directive[
            GrayLevel[0.5, 0.4]], ImagePadding -> All, 
          Method -> {"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                (Identity[#]& )[
                 Part[#, 1]], 
                (Identity[#]& )[
                 Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                (Identity[#]& )[
                 Part[#, 1]], 
                (Identity[#]& )[
                 Part[#, 2]]}& )}}, PlotRange -> All, PlotRangeClipping -> 
          False, PlotRangePadding -> {{
             Scaled[0.05], 
             Scaled[0.05]}, {
             Scaled[0.05], 
             Scaled[0.05]}}, Ticks -> {Automatic, Automatic}]], 
        "ExerciseOutput", Selectable -> False, Copyable -> False, Editable -> 
        False, ShowCellBracket -> False]]], " "}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Center}}},
   GridBoxBackground->{"Columns" -> {{
        RGBColor[1, 1, 1]}}},
   GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{1}}}],
  FrameMargins->0]], "ExerciseOutput",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellFrame->{{1, 1}, {1, 1}},
 ShowCellBracket->False,
 CellFrameColor->RGBColor[0.85, 0.85, 0.85],
 LineBreakWithin->
  Automatic,ExpressionUUID->"b208f6b0-9f35-40c6-9e94-f371ca873c25"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Make a table of image identifications for a picture of the Eiffel Tower, \
blurred by an amount from 1 to 5.",
 StyleBox[ButtonBox["\[NonBreakingSpace]\[RightGuillemet]",
  Appearance->None,
  Evaluator->Automatic,
  Method->"Preemptive",
  ButtonFunction:>(SelectionMove[
     ButtonNotebook[], All, ButtonCell, AutoScroll -> False]; 
   FrontEndExecute[
     FrontEndToken[
      ButtonNotebook[], "OpenCloseGroup"]])],
  FontColor->RGBColor[1, 0.501961, 0]]
}], "Exercise",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellDingbat->Cell[
  "+22.1", "ExerciseNumber", FontColor -> 
   RGBColor[0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]],
 ShowCellBracket->
  False,ExpressionUUID->"08c7e264-4b4d-4788-a56d-c651bdba0a27"],

Cell[BoxData[
 PaneBox[GridBox[{
    {" ", 
     StyleBox[
      RowBox[{"Expected", " ", 
       RowBox[{"output", ":"}]}],
      Editable->False,
      Selectable->False,
      StripOnInput->False,
      FontColor->RGBColor[0.45, 0.45, 0.45]], " "},
    {" ", 
     InterpretationBox[Cell[BoxData[
       RowBox[{"{", 
        RowBox[{
         TemplateBox[{"\"Eiffel Tower\"",RowBox[{"Entity", "[", 
             RowBox[{"\"Building\"", ",", "\"EiffelTower::5h9w8\""}], "]"}],
           "\"Entity[\\\"Building\\\", \\\"EiffelTower::5h9w8\\\"]\"",
           "\"building\""},
          "Entity"], ",", 
         TemplateBox[{"\"tower\"",RowBox[{"Entity", "[", 
             RowBox[{"\"Concept\"", ",", "\"Tower::72xxm\""}], "]"}],
           "\"Entity[\\\"Concept\\\", \\\"Tower::72xxm\\\"]\"","\"concept\""},
          
          "Entity"], ",", 
         TemplateBox[{"\"tower\"",RowBox[{"Entity", "[", 
             RowBox[{"\"Concept\"", ",", "\"Tower::72xxm\""}], "]"}],
           "\"Entity[\\\"Concept\\\", \\\"Tower::72xxm\\\"]\"","\"concept\""},
          
          "Entity"], ",", 
         TemplateBox[{"\"tower\"",RowBox[{"Entity", "[", 
             RowBox[{"\"Concept\"", ",", "\"Tower::72xxm\""}], "]"}],
           "\"Entity[\\\"Concept\\\", \\\"Tower::72xxm\\\"]\"","\"concept\""},
          
          "Entity"], ",", 
         TemplateBox[{"\"device\"",RowBox[{"Entity", "[", 
             RowBox[{"\"Concept\"", ",", "\"Device::f2cw8\""}], "]"}],
           "\"Entity[\\\"Concept\\\", \\\"Device::f2cw8\\\"]\"","\"concept\""},
          "Entity"]}], "}"}]], "ExerciseOutput",ExpressionUUID->
       "2f6fad28-6df3-4230-84d8-64b44038e6b1"],
      Apply[TextCell, 
       Cell[
        BoxData[
         RowBox[{"{", 
           RowBox[{
             TemplateBox[{"\"Eiffel Tower\"", 
               RowBox[{"Entity", "[", 
                 RowBox[{"\"Building\"", ",", "\"EiffelTower::5h9w8\""}], 
                 "]"}], "\"Entity[\\\"Building\\\", \
\\\"EiffelTower::5h9w8\\\"]\"", "\"building\""}, "Entity"], ",", 
             TemplateBox[{"\"tower\"", 
               RowBox[{"Entity", "[", 
                 RowBox[{"\"Concept\"", ",", "\"Tower::72xxm\""}], "]"}], 
               "\"Entity[\\\"Concept\\\", \\\"Tower::72xxm\\\"]\"", 
               "\"concept\""}, "Entity"], ",", 
             TemplateBox[{"\"tower\"", 
               RowBox[{"Entity", "[", 
                 RowBox[{"\"Concept\"", ",", "\"Tower::72xxm\""}], "]"}], 
               "\"Entity[\\\"Concept\\\", \\\"Tower::72xxm\\\"]\"", 
               "\"concept\""}, "Entity"], ",", 
             TemplateBox[{"\"tower\"", 
               RowBox[{"Entity", "[", 
                 RowBox[{"\"Concept\"", ",", "\"Tower::72xxm\""}], "]"}], 
               "\"Entity[\\\"Concept\\\", \\\"Tower::72xxm\\\"]\"", 
               "\"concept\""}, "Entity"], ",", 
             TemplateBox[{"\"device\"", 
               RowBox[{"Entity", "[", 
                 RowBox[{"\"Concept\"", ",", "\"Device::f2cw8\""}], "]"}], 
               "\"Entity[\\\"Concept\\\", \\\"Device::f2cw8\\\"]\"", 
               "\"concept\""}, "Entity"]}], "}"}]], "ExerciseOutput", 
        Selectable -> False, Copyable -> False, Editable -> False, 
        ShowCellBracket -> False]]], " "}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Center}}},
   GridBoxBackground->{"Columns" -> {{
        RGBColor[1, 1, 1]}}},
   GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{1}}}],
  FrameMargins->0]], "ExerciseOutput",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellFrame->{{1, 1}, {1, 1}},
 ShowCellBracket->False,
 CellFrameColor->RGBColor[0.85, 0.85, 0.85],
 LineBreakWithin->
  Automatic,ExpressionUUID->"f6cd4f12-e8f4-4266-b045-073b65dda894"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Classify the sentiment of the Wikipedia article on \
\[OpenCurlyDoubleQuote]happiness\[CloseCurlyDoubleQuote].",
 StyleBox[ButtonBox["\[NonBreakingSpace]\[RightGuillemet]",
  Appearance->None,
  Evaluator->Automatic,
  Method->"Preemptive",
  ButtonFunction:>(SelectionMove[
     ButtonNotebook[], All, ButtonCell, AutoScroll -> False]; 
   FrontEndExecute[
     FrontEndToken[
      ButtonNotebook[], "OpenCloseGroup"]])],
  FontColor->RGBColor[1, 0.501961, 0]]
}], "Exercise",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellDingbat->Cell[
  "+22.2", "ExerciseNumber", FontColor -> 
   RGBColor[0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]],
 ShowCellBracket->
  False,ExpressionUUID->"b3821203-b4e0-4b24-aefd-6aaec906c008"],

Cell[BoxData[
 PaneBox[GridBox[{
    {" ", 
     StyleBox[
      RowBox[{"Expected", " ", 
       RowBox[{"output", ":"}]}],
      Editable->False,
      Selectable->False,
      StripOnInput->False,
      FontColor->RGBColor[0.45, 0.45, 0.45]], " "},
    {" ", 
     InterpretationBox[Cell[
      BoxData["\<\"Neutral\"\>"], "ExerciseOutput",ExpressionUUID->
       "d909ad75-dd75-4bee-970f-bdaf4266c642"],
      Apply[TextCell, 
       Cell[
        BoxData["\"Neutral\""], "ExerciseOutput", Selectable -> False, 
        Copyable -> False, Editable -> False, ShowCellBracket -> False]]], " "}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Center}}},
   GridBoxBackground->{"Columns" -> {{
        RGBColor[1, 1, 1]}}},
   GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{1}}}],
  FrameMargins->0]], "ExerciseOutput",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellFrame->{{1, 1}, {1, 1}},
 ShowCellBracket->False,
 CellFrameColor->RGBColor[0.85, 0.85, 0.85],
 LineBreakWithin->
  Automatic,ExpressionUUID->"02579f6d-b8c3-4d4a-8c20-5b51a6129152"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Of colors in the list ",
 Cell[BoxData[
  RowBox[{
   ButtonBox["Table",
    BaseStyle->"CodeLink"], "[", 
   RowBox[{
    RowBox[{
     ButtonBox["Hue",
      BaseStyle->"CodeLink"], "[", "h", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"h", ",", "0", ",", "1", ",", ".05"}], "}"}]}], "]"}]], 
  "InlineCode",ExpressionUUID->"39a93e6b-3235-4c99-bfab-c3504501fa94"],
 ", find which are the 3 nearest to ",
 ButtonBox["Pink",
  BaseStyle->"Link"],
 ".",
 StyleBox[ButtonBox["\[NonBreakingSpace]\[RightGuillemet]",
  Appearance->None,
  Evaluator->Automatic,
  Method->"Preemptive",
  ButtonFunction:>(SelectionMove[
     ButtonNotebook[], All, ButtonCell, AutoScroll -> False]; 
   FrontEndExecute[
     FrontEndToken[
      ButtonNotebook[], "OpenCloseGroup"]])],
  FontColor->RGBColor[1, 0.501961, 0]]
}], "Exercise",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellDingbat->Cell[
  "+22.3", "ExerciseNumber", FontColor -> 
   RGBColor[0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]],
 ShowCellBracket->
  False,ExpressionUUID->"ae8fb412-c572-4309-898e-196ad228b62b"],

Cell[BoxData[
 PaneBox[GridBox[{
    {" ", 
     StyleBox[
      RowBox[{"Expected", " ", 
       RowBox[{"output", ":"}]}],
      Editable->False,
      Selectable->False,
      StripOnInput->False,
      FontColor->RGBColor[0.45, 0.45, 0.45]], " "},
    {" ", 
     InterpretationBox[Cell[BoxData[
       RowBox[{"{", 
        RowBox[{
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {Hue[0.9500000000000001], RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             FrameStyle->Hue[0.9500000000000001, 1., 0.6666666666666667],
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            "Hue[0.9500000000000001]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               Hue[0.9500000000000001, 0.5, 0.5]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["HueColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          Hue[0.9500000000000001],
          Editable->False,
          Selectable->False], ",", 
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {Hue[0.9], RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             FrameStyle->Hue[0.9, 1., 0.6666666666666667],
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            "Hue[0.9]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               Hue[0.9, 0.5, 0.5]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["HueColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          Hue[0.9],
          Editable->False,
          Selectable->False], ",", 
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {Hue[0.05], RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             FrameStyle->Hue[0.05000000000000001, 1., 0.6666666666666667],
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            "Hue[0.05]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               Hue[0.05, 0.5, 0.5]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["HueColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          Hue[0.05],
          Editable->False,
          Selectable->False]}], "}"}]], "ExerciseOutput",ExpressionUUID->
       "6574a5e4-890d-4f1d-a373-5932f4ef56c8"],
      Apply[TextCell, 
       Cell[
        BoxData[
         RowBox[{"{", 
           RowBox[{
             InterpretationBox[
              ButtonBox[
               TooltipBox[
                GraphicsBox[{{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}}, {{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}}, {{{{{{{
                    Hue[0.9500000000000001], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}}, AspectRatio -> 1, 
                 Frame -> True, FrameStyle -> 
                 Hue[0.9500000000000001, 1., 0.6666666666666667], FrameTicks -> 
                 None, ImageSize -> 
                 Dynamic[{
                   Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                "Hue[0.9500000000000001]"], Appearance -> None, 
               BaseStyle -> {}, BaselinePosition -> Baseline, ButtonFunction :> 
               With[{Typeset`box$ = EvaluationBox[]}, 
                 If[
                  Not[
                   AbsoluteCurrentValue["Deployed"]], 
                  SelectionMove[Typeset`box$, All, Expression]; 
                  FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                  FrontEnd`Private`$ColorSelectorInitialColor = 
                   Hue[0.9500000000000001, 0.5, 0.5]; 
                  FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                  MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
               Automatic, Method -> "Preemptive"], 
              Hue[0.9500000000000001], Editable -> False, Selectable -> 
              False], ",", 
             InterpretationBox[
              ButtonBox[
               TooltipBox[
                GraphicsBox[{{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}}, {{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}}, {{{{{{{
                    Hue[0.9], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}}, AspectRatio -> 1, 
                 Frame -> True, FrameStyle -> 
                 Hue[0.9, 1., 0.6666666666666667], FrameTicks -> None, 
                 ImageSize -> 
                 Dynamic[{
                   Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], "Hue[0.9]"],
                Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
               Baseline, ButtonFunction :> 
               With[{Typeset`box$ = EvaluationBox[]}, 
                 If[
                  Not[
                   AbsoluteCurrentValue["Deployed"]], 
                  SelectionMove[Typeset`box$, All, Expression]; 
                  FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                  FrontEnd`Private`$ColorSelectorInitialColor = 
                   Hue[0.9, 0.5, 0.5]; 
                  FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                  MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
               Automatic, Method -> "Preemptive"], 
              Hue[0.9], Editable -> False, Selectable -> False], ",", 
             InterpretationBox[
              ButtonBox[
               TooltipBox[
                GraphicsBox[{{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}}, {{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}}, {{{{{{{
                    Hue[0.05], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}}, AspectRatio -> 1, 
                 Frame -> True, FrameStyle -> 
                 Hue[0.05000000000000001, 1., 0.6666666666666667], FrameTicks -> 
                 None, ImageSize -> 
                 Dynamic[{
                   Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                "Hue[0.05]"], Appearance -> None, BaseStyle -> {}, 
               BaselinePosition -> Baseline, ButtonFunction :> 
               With[{Typeset`box$ = EvaluationBox[]}, 
                 If[
                  Not[
                   AbsoluteCurrentValue["Deployed"]], 
                  SelectionMove[Typeset`box$, All, Expression]; 
                  FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                  FrontEnd`Private`$ColorSelectorInitialColor = 
                   Hue[0.05, 0.5, 0.5]; 
                  FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                  MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
               Automatic, Method -> "Preemptive"], 
              Hue[0.05], Editable -> False, Selectable -> False]}], "}"}]], 
        "ExerciseOutput", Selectable -> False, Copyable -> False, Editable -> 
        False, ShowCellBracket -> False]]], " "}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Center}}},
   GridBoxBackground->{"Columns" -> {{
        RGBColor[1, 1, 1]}}},
   GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{1}}}],
  FrameMargins->0]], "ExerciseOutput",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellFrame->{{1, 1}, {1, 1}},
 ShowCellBracket->False,
 CellFrameColor->RGBColor[0.85, 0.85, 0.85],
 LineBreakWithin->
  Automatic,ExpressionUUID->"3b7ec25b-11ef-4eaf-b2ed-fbb226479dce"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Compute all fractions ",
 Cell[BoxData[
  RowBox[{"i", "/", "j"}]], "InlineCode",ExpressionUUID->
  "38f59556-0419-49c7-b841-8d4991d004b2"],
 " for ",
 Cell[BoxData[
 "i"], "InlineCode",ExpressionUUID->"24fde331-4cc8-4053-8d95-7aa188bc8013"],
 " and ",
 Cell[BoxData[
 "j"], "InlineCode",ExpressionUUID->"84174f76-6862-4eca-ae84-c09c56be271e"],
 " up to 500, and find the 10 fractions closest to pi.",
 StyleBox[ButtonBox["\[NonBreakingSpace]\[RightGuillemet]",
  Appearance->None,
  Evaluator->Automatic,
  Method->"Preemptive",
  ButtonFunction:>(SelectionMove[
     ButtonNotebook[], All, ButtonCell, AutoScroll -> False]; 
   FrontEndExecute[
     FrontEndToken[
      ButtonNotebook[], "OpenCloseGroup"]])],
  FontColor->RGBColor[1, 0.501961, 0]]
}], "Exercise",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellDingbat->Cell[
  "+22.4", "ExerciseNumber", FontColor -> 
   RGBColor[0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]],
 ShowCellBracket->
  False,ExpressionUUID->"90dc848e-df55-46ce-bd47-2763b110454b"],

Cell[BoxData[
 PaneBox[GridBox[{
    {" ", 
     StyleBox[
      RowBox[{"Expected", " ", 
       RowBox[{"output", ":"}]}],
      Editable->False,
      Selectable->False,
      StripOnInput->False,
      FontColor->RGBColor[0.45, 0.45, 0.45]], " "},
    {" ", 
     InterpretationBox[Cell[BoxData[
       RowBox[{"{", 
        RowBox[{
         FractionBox["355", "113"], ",", 
         FractionBox["377", "120"], ",", 
         FractionBox["333", "106"], ",", 
         FractionBox["399", "127"], ",", 
         FractionBox["311", "99"], ",", 
         FractionBox["421", "134"], ",", 
         FractionBox["443", "141"], ",", 
         FractionBox["289", "92"], ",", 
         FractionBox["465", "148"], ",", 
         FractionBox["487", "155"]}], "}"}]], "ExerciseOutput",
       ExpressionUUID->"2593c00e-39fd-416c-8c21-b2252c819cdd"],
      Apply[TextCell, 
       Cell[
        BoxData[
         RowBox[{"{", 
           RowBox[{
             FractionBox["355", "113"], ",", 
             FractionBox["377", "120"], ",", 
             FractionBox["333", "106"], ",", 
             FractionBox["399", "127"], ",", 
             FractionBox["311", "99"], ",", 
             FractionBox["421", "134"], ",", 
             FractionBox["443", "141"], ",", 
             FractionBox["289", "92"], ",", 
             FractionBox["465", "148"], ",", 
             FractionBox["487", "155"]}], "}"}]], "ExerciseOutput", 
        Selectable -> False, Copyable -> False, Editable -> False, 
        ShowCellBracket -> False]]], " "}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Center}}},
   GridBoxBackground->{"Columns" -> {{
        RGBColor[1, 1, 1]}}},
   GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{1}}}],
  FrameMargins->0]], "ExerciseOutput",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellFrame->{{1, 1}, {1, 1}},
 ShowCellBracket->False,
 CellFrameColor->RGBColor[0.85, 0.85, 0.85],
 LineBreakWithin->
  Automatic,ExpressionUUID->"06583770-2523-4653-8035-2249e8e4df02"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Generate a list of 10 random numbers from 0 to 10, and make a graph of the \
3 nearest neighbors of each one.",
 StyleBox[ButtonBox["\[NonBreakingSpace]\[RightGuillemet]",
  Appearance->None,
  Evaluator->Automatic,
  Method->"Preemptive",
  ButtonFunction:>(SelectionMove[
     ButtonNotebook[], All, ButtonCell, AutoScroll -> False]; 
   FrontEndExecute[
     FrontEndToken[
      ButtonNotebook[], "OpenCloseGroup"]])],
  FontColor->RGBColor[1, 0.501961, 0]]
}], "Exercise",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellDingbat->Cell[
  "+22.5", "ExerciseNumber", FontColor -> 
   RGBColor[0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]],
 ShowCellBracket->
  False,ExpressionUUID->"1fc2d00c-96ce-4fc3-8258-0d69cde6c752"],

Cell[BoxData[
 PaneBox[GridBox[{
    {" ", 
     StyleBox[
      RowBox[{"Expected", " ", 
       RowBox[{"output", ":"}]}],
      Editable->False,
      Selectable->False,
      StripOnInput->False,
      FontColor->RGBColor[0.45, 0.45, 0.45]], " "},
    {" ", 
     InterpretationBox[Cell[BoxData[
       GraphicsBox[
        NamespaceBox["NetworkGraphics",
         DynamicModuleBox[{Typeset`graph = HoldComplete[
           Graph[{8, 9, 6, 2, 5, 7, 0, 10}, {Null, 
             SparseArray[
             Automatic, {8, 8}, 0, {
              1, {{0, 5, 8, 13, 16, 21, 26, 29, 32}, {{2}, {3}, {5}, {6}, {
                8}, {1}, {6}, {8}, {1}, {4}, {5}, {6}, {7}, {3}, {5}, {7}, {
                1}, {3}, {4}, {6}, {7}, {1}, {2}, {3}, {5}, {8}, {3}, {4}, {
                5}, {1}, {2}, {6}}}, Pattern}]}, {
            GraphLayout -> "LinearEmbedding", 
             VertexCoordinates -> {{8, 0}, {9, 0}, {6, 0}, {2, 0}, {5, 0}, {7,
               0}, {0, 0}, {10, 0}}, VertexLabels -> {All}}]]}, 
          TagBox[GraphicsGroupBox[{
             {Hue[0.6, 0.7, 0.5], Opacity[0.7], 
              BezierCurveBox[{{8., 0.}, {8.5, 0.5}, {9., 0.}}], 
              BezierCurveBox[{{8., 0.}, {7., 1.}, {6., 0.}}], 
              BezierCurveBox[{{8., 0.}, {6.5, 1.5}, {5., 0.}}], 
              BezierCurveBox[{{8., 0.}, {7.5, 0.5}, {7., 0.}}], 
              BezierCurveBox[{{8., 0.}, {9., 1.}, {10., 0.}}], 
              BezierCurveBox[{{9., 0.}, {8., 1.}, {7., 0.}}], 
              BezierCurveBox[{{9., 0.}, {9.5, 0.5}, {10., 0.}}], 
              BezierCurveBox[{{6., 0.}, {4., 2.}, {2., 0.}}], 
              BezierCurveBox[{{6., 0.}, {5.5, 0.5}, {5., 0.}}], 
              BezierCurveBox[{{6., 0.}, {6.5, 0.5}, {7., 0.}}], 
              BezierCurveBox[{{6., 0.}, {3., 3.}, {0., 0.}}], 
              BezierCurveBox[{{2., 0.}, {3.5, 1.5}, {5., 0.}}], 
              BezierCurveBox[{{2., 0.}, {1., 1.}, {0., 0.}}], 
              BezierCurveBox[{{5., 0.}, {6., 1.}, {7., 0.}}], 
              BezierCurveBox[{{5., 0.}, {2.5, 2.5}, {0., 0.}}], 
              BezierCurveBox[{{7., 0.}, {8.5, 1.5}, {10., 0.}}]}, 
             {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
              0.7]}], {DiskBox[{8., 0.}, 0.06561181434599156], 
               InsetBox["8", 
                Offset[{2, 2}, {8.065611814345992, 0.06561181434599156}], 
                ImageScaled[{0, 0}],
                BaseStyle->"Graphics"]}, {
               DiskBox[{9., 0.}, 0.06561181434599156], 
               InsetBox["9", 
                Offset[{2, 2}, {9.065611814345992, 0.06561181434599156}], 
                ImageScaled[{0, 0}],
                BaseStyle->"Graphics"]}, {
               DiskBox[{6., 0.}, 0.06561181434599156], 
               InsetBox["6", 
                Offset[{2, 2}, {6.065611814345991, 0.06561181434599156}], 
                ImageScaled[{0, 0}],
                BaseStyle->"Graphics"]}, {
               DiskBox[{2., 0.}, 0.06561181434599156], 
               InsetBox["2", 
                Offset[{2, 2}, {2.0656118143459916, 0.06561181434599156}], 
                ImageScaled[{0, 0}],
                BaseStyle->"Graphics"]}, {
               DiskBox[{5., 0.}, 0.06561181434599156], 
               InsetBox["5", 
                Offset[{2, 2}, {5.065611814345991, 0.06561181434599156}], 
                ImageScaled[{0, 0}],
                BaseStyle->"Graphics"]}, {
               DiskBox[{7., 0.}, 0.06561181434599156], 
               InsetBox["7", 
                Offset[{2, 2}, {7.065611814345991, 0.06561181434599156}], 
                ImageScaled[{0, 0}],
                BaseStyle->"Graphics"]}, {
               DiskBox[{0., 0.}, 0.06561181434599156], 
               InsetBox["0", 
                Offset[{2, 2}, {0.06561181434599156, 0.06561181434599156}], 
                ImageScaled[{0, 0}],
                BaseStyle->"Graphics"]}, {
               DiskBox[{10., 0.}, 0.06561181434599156], 
               InsetBox["10", 
                Offset[{2, 2}, {10.065611814345992, 0.06561181434599156}], 
                ImageScaled[{0, 0}],
                BaseStyle->"Graphics"]}}}],
           MouseAppearanceTag["NetworkGraphics"]],
          AllowKernelInitialization->False]],
        DefaultBaseStyle->{
         "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
          Hue[0.8, 1., 0.6]},
        FrameTicks->None,
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]]]], "ExerciseOutput",ExpressionUUID->
       "17a622f2-4496-4595-8785-3cb27ef4c631"],
      Apply[TextCell, 
       Cell[
        BoxData[
         GraphicsBox[
          NamespaceBox["NetworkGraphics", 
           DynamicModuleBox[{Typeset`graph = HoldComplete[
               Graph[{8, 9, 6, 2, 5, 7, 0, 10}, {Null, 
                 SparseArray[
                 Automatic, {8, 8}, 0, {
                  1, {{0, 5, 8, 13, 16, 21, 26, 29, 32}, {{2}, {3}, {5}, {
                    6}, {8}, {1}, {6}, {8}, {1}, {4}, {5}, {6}, {7}, {3}, {
                    5}, {7}, {1}, {3}, {4}, {6}, {7}, {1}, {2}, {3}, {5}, {
                    8}, {3}, {4}, {5}, {1}, {2}, {6}}}, Pattern}]}, {
                GraphLayout -> "LinearEmbedding", 
                 VertexCoordinates -> {{8, 0}, {9, 0}, {6, 0}, {2, 0}, {5, 
                  0}, {7, 0}, {0, 0}, {10, 0}}, VertexLabels -> {All}}]]}, 
            TagBox[
             GraphicsGroupBox[{{{{{{{{
                    Hue[0.6, 0.7, 0.5], 
                    Opacity[0.7], 
                    BezierCurveBox[{{8., 0.}, {8.5, 0.5}, {9., 0.}}], 
                    BezierCurveBox[{{8., 0.}, {7., 1.}, {6., 0.}}], 
                    BezierCurveBox[{{8., 0.}, {6.5, 1.5}, {5., 0.}}], 
                    BezierCurveBox[{{8., 0.}, {7.5, 0.5}, {7., 0.}}], 
                    BezierCurveBox[{{8., 0.}, {9., 1.}, {10., 0.}}], 
                    BezierCurveBox[{{9., 0.}, {8., 1.}, {7., 0.}}], 
                    BezierCurveBox[{{9., 0.}, {9.5, 0.5}, {10., 0.}}], 
                    BezierCurveBox[{{6., 0.}, {4., 2.}, {2., 0.}}], 
                    BezierCurveBox[{{6., 0.}, {5.5, 0.5}, {5., 0.}}], 
                    BezierCurveBox[{{6., 0.}, {6.5, 0.5}, {7., 0.}}], 
                    BezierCurveBox[{{6., 0.}, {3., 3.}, {0., 0.}}], 
                    BezierCurveBox[{{2., 0.}, {3.5, 1.5}, {5., 0.}}], 
                    BezierCurveBox[{{2., 0.}, {1., 1.}, {0., 0.}}], 
                    BezierCurveBox[{{5., 0.}, {6., 1.}, {7., 0.}}], 
                    BezierCurveBox[{{5., 0.}, {2.5, 2.5}, {0., 0.}}], 
                    
                    BezierCurveBox[{{7., 0.}, {8.5, 1.5}, {10., 
                    0.}}]}}}}}}}, {{{{{{{
                    Hue[0.6, 0.2, 0.8], 
                    EdgeForm[{
                    GrayLevel[0], 
                    Opacity[0.7]}], {
                    DiskBox[{8., 0.}, 0.06561181434599156], 
                    InsetBox["8", 
                    Offset[{2, 2}, {8.065611814345992, 0.06561181434599156}], 
                    
                    ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                    DiskBox[{9., 0.}, 0.06561181434599156], 
                    InsetBox["9", 
                    Offset[{2, 2}, {9.065611814345992, 0.06561181434599156}], 
                    
                    ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                    DiskBox[{6., 0.}, 0.06561181434599156], 
                    InsetBox["6", 
                    Offset[{2, 2}, {6.065611814345991, 0.06561181434599156}], 
                    
                    ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                    DiskBox[{2., 0.}, 0.06561181434599156], 
                    InsetBox["2", 
                    
                    Offset[{2, 2}, {2.0656118143459916`, 
                    0.06561181434599156}], 
                    ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                    DiskBox[{5., 0.}, 0.06561181434599156], 
                    InsetBox["5", 
                    Offset[{2, 2}, {5.065611814345991, 0.06561181434599156}], 
                    
                    ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                    DiskBox[{7., 0.}, 0.06561181434599156], 
                    InsetBox["7", 
                    Offset[{2, 2}, {7.065611814345991, 0.06561181434599156}], 
                    
                    ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                    DiskBox[{0., 0.}, 0.06561181434599156], 
                    InsetBox["0", 
                    
                    Offset[{2, 2}, {0.06561181434599156, 
                    0.06561181434599156}], 
                    ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                    DiskBox[{10., 0.}, 0.06561181434599156], 
                    InsetBox["10", 
                    
                    Offset[{2, 2}, {10.065611814345992`, 
                    0.06561181434599156}], 
                    ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}}}}}}}}}], 
             MouseAppearanceTag["NetworkGraphics"]], 
            AllowKernelInitialization -> False]], 
          DefaultBaseStyle -> {
           "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
            Hue[0.8, 1., 0.6]}, FrameTicks -> None, GridLinesStyle -> 
          Directive[
            GrayLevel[0.5, 0.4]]]], "ExerciseOutput", Selectable -> False, 
        Copyable -> False, Editable -> False, ShowCellBracket -> False]]], " "}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Center}}},
   GridBoxBackground->{"Columns" -> {{
        RGBColor[1, 1, 1]}}},
   GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{1}}}],
  FrameMargins->0]], "ExerciseOutput",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellFrame->{{1, 1}, {1, 1}},
 ShowCellBracket->False,
 CellFrameColor->RGBColor[0.85, 0.85, 0.85],
 LineBreakWithin->
  Automatic,ExpressionUUID->"8e506c4c-d78b-47f3-9e78-f4482301fda5"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Find clusters of similar colors in a list of 100 random colors.",
 StyleBox[ButtonBox["\[NonBreakingSpace]\[RightGuillemet]",
  Appearance->None,
  Evaluator->Automatic,
  Method->"Preemptive",
  ButtonFunction:>(SelectionMove[
     ButtonNotebook[], All, ButtonCell, AutoScroll -> False]; 
   FrontEndExecute[
     FrontEndToken[
      ButtonNotebook[], "OpenCloseGroup"]])],
  FontColor->RGBColor[1, 0.501961, 0]]
}], "Exercise",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellDingbat->Cell[
  "+22.6", "ExerciseNumber", FontColor -> 
   RGBColor[0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]],
 ShowCellBracket->
  False,ExpressionUUID->"b30441eb-a999-49ec-9bac-3fccc1c77f86"],

Cell[BoxData[
 PaneBox[GridBox[{
    {" ", 
     StyleBox[
      RowBox[{"Expected", " ", 
       RowBox[{"output", ":"}]}],
      Editable->False,
      Selectable->False,
      StripOnInput->False,
      FontColor->RGBColor[0.45, 0.45, 0.45]], " "},
    {" ", 
     InterpretationBox[Cell[BoxData[
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{
                {GrayLevel[0], RectangleBox[{0, 0}]}, 
                {GrayLevel[0], RectangleBox[{1, -1}]}, 
                {RGBColor[
                 0.8116438051434329, 0.8547919864863347, 0.7807710853793401], 
                 RectangleBox[{0, -1}, {2, 1}]}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.541095870095622, 0.5698613243242232, 0.5205140569195601],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.8116438051434329, 0.8547919864863347, \
0.7807710853793401]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.8116438051434329, 0.8547919864863347, 0.7807710853793401]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.8116438051434329, 0.8547919864863347, 0.7807710853793401],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{
                {GrayLevel[0], RectangleBox[{0, 0}]}, 
                {GrayLevel[0], RectangleBox[{1, -1}]}, 
                {RGBColor[
                 0.2983278570382957, 0.9907444932950316, 0.9284043344039434], 
                 RectangleBox[{0, -1}, {2, 1}]}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.19888523802553046`, 0.6604963288633544, 0.6189362229359623],
               
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.2983278570382957, 0.9907444932950316, \
0.9284043344039434]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.2983278570382957, 0.9907444932950316, 0.9284043344039434]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.2983278570382957, 0.9907444932950316, 0.9284043344039434],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{
                {GrayLevel[0], RectangleBox[{0, 0}]}, 
                {GrayLevel[0], RectangleBox[{1, -1}]}, 
                {RGBColor[
                 0.18676117011450066`, 0.5486089602170863, 
                  0.04303247680226141], RectangleBox[{0, -1}, {2, 1}]}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.12450744674300045`, 0.3657393068113909, 
                 0.028688317868174273`],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.18676117011450066, 0.5486089602170863, \
0.04303247680226141]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.18676117011450066`, 0.5486089602170863, 
                   0.04303247680226141]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.18676117011450066`, 0.5486089602170863, 0.04303247680226141],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{
                {GrayLevel[0], RectangleBox[{0, 0}]}, 
                {GrayLevel[0], RectangleBox[{1, -1}]}, 
                {RGBColor[
                 0.4044608902823441, 0.9788998961090443, 0.8108975624714536], 
                 RectangleBox[{0, -1}, {2, 1}]}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.2696405935215628, 0.6525999307393628, 0.5405983749809691],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.4044608902823441, 0.9788998961090443, \
0.8108975624714536]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.4044608902823441, 0.9788998961090443, 0.8108975624714536]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.4044608902823441, 0.9788998961090443, 0.8108975624714536],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{
                {GrayLevel[0], RectangleBox[{0, 0}]}, 
                {GrayLevel[0], RectangleBox[{1, -1}]}, 
                {RGBColor[
                 0.5308001574813235, 0.9503472359039511, 0.8646083755834806], 
                 RectangleBox[{0, -1}, {2, 1}]}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.35386677165421565`, 0.6335648239359675, 0.5764055837223204],
               
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.5308001574813235, 0.9503472359039511, \
0.8646083755834806]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.5308001574813235, 0.9503472359039511, 0.8646083755834806]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.5308001574813235, 0.9503472359039511, 0.8646083755834806],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{
                {GrayLevel[0], RectangleBox[{0, 0}]}, 
                {GrayLevel[0], RectangleBox[{1, -1}]}, 
                {RGBColor[
                 0.5926608241659339, 0.4671421812435703, 
                  0.027570072930602985`], RectangleBox[{0, -1}, {2, 1}]}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.3951072161106226, 0.3114281208290469, 0.01838004862040199],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.5926608241659339, 0.4671421812435703, \
0.027570072930602985]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.5926608241659339, 0.4671421812435703, 
                   0.027570072930602985`]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.5926608241659339, 0.4671421812435703, 0.027570072930602985`],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{
                {GrayLevel[0], RectangleBox[{0, 0}]}, 
                {GrayLevel[0], RectangleBox[{1, -1}]}, 
                {RGBColor[
                 0.49843743964638865`, 0.7588128836239783, 
                  0.6588996785867525], RectangleBox[{0, -1}, {2, 1}]}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.3322916264309258, 0.5058752557493189, 0.43926645239116835`],
               
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.49843743964638865, 0.7588128836239783, \
0.6588996785867525]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.49843743964638865`, 0.7588128836239783, 
                   0.6588996785867525]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.49843743964638865`, 0.7588128836239783, 0.6588996785867525],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{
                {GrayLevel[0], RectangleBox[{0, 0}]}, 
                {GrayLevel[0], RectangleBox[{1, -1}]}, 
                {RGBColor[
                 0.6788691428209239, 0.8865118691450595, 0.06859340947663295],
                  RectangleBox[{0, -1}, {2, 1}]}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.4525794285472826, 0.5910079127633731, 0.04572893965108864],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.6788691428209239, 0.8865118691450595, \
0.06859340947663295]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.6788691428209239, 0.8865118691450595, 
                   0.06859340947663295]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.6788691428209239, 0.8865118691450595, 0.06859340947663295],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{
                {GrayLevel[0], RectangleBox[{0, 0}]}, 
                {GrayLevel[0], RectangleBox[{1, -1}]}, 
                {RGBColor[
                 0.3966954095359472, 0.9303983446364068, 
                  0.27133513969525125`], RectangleBox[{0, -1}, {2, 1}]}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.26446360635729815`, 0.6202655630909379, 
                 0.18089009313016752`],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.3966954095359472, 0.9303983446364068, \
0.27133513969525125]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.3966954095359472, 0.9303983446364068, 
                   0.27133513969525125`]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.3966954095359472, 0.9303983446364068, 0.27133513969525125`],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{
                {GrayLevel[0], RectangleBox[{0, 0}]}, 
                {GrayLevel[0], RectangleBox[{1, -1}]}, 
                {RGBColor[
                 0.7496777159050012, 0.8414031368083361, 
                  0.29000881481349006`], RectangleBox[{0, -1}, {2, 1}]}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.4997851439366675, 0.5609354245388908, 0.19333920987566006`],
               
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.7496777159050012, 0.8414031368083361, \
0.29000881481349006]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.7496777159050012, 0.8414031368083361, 
                   0.29000881481349006`]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.7496777159050012, 0.8414031368083361, 0.29000881481349006`],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{
                {GrayLevel[0], RectangleBox[{0, 0}]}, 
                {GrayLevel[0], RectangleBox[{1, -1}]}, 
                {RGBColor[
                 0.1722869702422274, 0.42066881136044554`, 
                  0.18877704427888808`], RectangleBox[{0, -1}, {2, 1}]}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.11485798016148493`, 0.28044587424029704`, 
                 0.12585136285259207`],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.1722869702422274, 0.42066881136044554, \
0.18877704427888808]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.1722869702422274, 0.42066881136044554`, 
                   0.18877704427888808`]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.1722869702422274, 0.42066881136044554`, 0.18877704427888808`],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{
                {GrayLevel[0], RectangleBox[{0, 0}]}, 
                {GrayLevel[0], RectangleBox[{1, -1}]}, 
                {RGBColor[
                 0.020568097401979735`, 0.32843933224376776`, 
                  0.2578912775452169], RectangleBox[{0, -1}, {2, 1}]}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.013712064934653156`, 0.2189595548291785, 
                 0.17192751836347794`],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.020568097401979735, 0.32843933224376776, \
0.2578912775452169]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.020568097401979735`, 0.32843933224376776`, 
                   0.2578912775452169]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.020568097401979735`, 0.32843933224376776`, 0.2578912775452169],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{
                {GrayLevel[0], RectangleBox[{0, 0}]}, 
                {GrayLevel[0], RectangleBox[{1, -1}]}, 
                {RGBColor[
                 0.4276762158276948, 0.9445301871184215, 0.6339408432442302], 
                 RectangleBox[{0, -1}, {2, 1}]}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.2851174772184632, 0.629686791412281, 0.4226272288294868],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.4276762158276948, 0.9445301871184215, \
0.6339408432442302]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.4276762158276948, 0.9445301871184215, 0.6339408432442302]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.4276762158276948, 0.9445301871184215, 0.6339408432442302],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{
                {GrayLevel[0], RectangleBox[{0, 0}]}, 
                {GrayLevel[0], RectangleBox[{1, -1}]}, 
                {RGBColor[
                 0.3449333805776824, 0.8214093187031501, 0.00535396147946221],
                  RectangleBox[{0, -1}, {2, 1}]}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.22995558705178828`, 0.5476062124687668, 
                 0.003569307652974807],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.3449333805776824, 0.8214093187031501, \
0.00535396147946221]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.3449333805776824, 0.8214093187031501, 
                   0.00535396147946221]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.3449333805776824, 0.8214093187031501, 0.00535396147946221],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{
                {GrayLevel[0], RectangleBox[{0, 0}]}, 
                {GrayLevel[0], RectangleBox[{1, -1}]}, 
                {RGBColor[
                 0.9595114792486563, 0.9614567195621035, 0.09956803288245264],
                  RectangleBox[{0, -1}, {2, 1}]}},
               AspectRatio->1,
               Frame->True,
               FrameStyle->RGBColor[
                0.6396743194991042, 0.6409711463747357, 0.06637868858830176],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.9595114792486563, 0.9614567195621035, \
0.09956803288245264]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.9595114792486563, 0.9614567195621035, 
                   0.09956803288245264]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.9595114792486563, 0.9614567195621035, 0.09956803288245264],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{
                {GrayLevel[0], RectangleBox[{0, 0}]}, 
                {GrayLevel[0], RectangleBox[{1, -1}]}, 
                {RGBColor[
                 0.13927723404143122`, 0.9837658758454813, 
                  0.6275322853052734], RectangleBox[{0, -1}, {2, 1}]}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.09285148936095415, 0.6558439172303209, 0.41835485687018226`],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.13927723404143122, 0.9837658758454813, \
0.6275322853052734]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.13927723404143122`, 0.9837658758454813, 
                   0.6275322853052734]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.13927723404143122`, 0.9837658758454813, 0.6275322853052734],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{
                {GrayLevel[0], RectangleBox[{0, 0}]}, 
                {GrayLevel[0], RectangleBox[{1, -1}]}, 
                {RGBColor[
                 0.4129872979782936, 0.599123151026224, 0.5563798982651478], 
                 RectangleBox[{0, -1}, {2, 1}]}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.2753248653188624, 0.3994154340174827, 0.3709199321767652],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.4129872979782936, 0.599123151026224, \
0.5563798982651478]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.4129872979782936, 0.599123151026224, 0.5563798982651478]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.4129872979782936, 0.599123151026224, 0.5563798982651478],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{
                {GrayLevel[0], RectangleBox[{0, 0}]}, 
                {GrayLevel[0], RectangleBox[{1, -1}]}, 
                {RGBColor[
                 0.5517409716001453, 0.7226268672047083, 0.04296745155978088],
                  RectangleBox[{0, -1}, {2, 1}]}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.3678273144000969, 0.48175124480313886`, 
                 0.028644967706520585`],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.5517409716001453, 0.7226268672047083, \
0.04296745155978088]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.5517409716001453, 0.7226268672047083, 
                   0.04296745155978088]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.5517409716001453, 0.7226268672047083, 0.04296745155978088],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{
                {GrayLevel[0], RectangleBox[{0, 0}]}, 
                {GrayLevel[0], RectangleBox[{1, -1}]}, 
                {RGBColor[
                 0.2471012449687613, 0.6622219052252245, 
                  0.34136700529740893`], RectangleBox[{0, -1}, {2, 1}]}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.16473416331250754`, 0.4414812701501497, 
                 0.22757800353160595`],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.2471012449687613, 0.6622219052252245, \
0.34136700529740893]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.2471012449687613, 0.6622219052252245, 
                   0.34136700529740893`]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.2471012449687613, 0.6622219052252245, 0.34136700529740893`],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{
                {GrayLevel[0], RectangleBox[{0, 0}]}, 
                {GrayLevel[0], RectangleBox[{1, -1}]}, 
                {RGBColor[
                 0.00852878273374924, 0.7623891609381206, 0.495048201930645], 
                 RectangleBox[{0, -1}, {2, 1}]}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.005685855155832828, 0.5082594406254137, 0.33003213462043],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.00852878273374924, 0.7623891609381206, \
0.495048201930645]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.00852878273374924, 0.7623891609381206, 0.495048201930645]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.00852878273374924, 0.7623891609381206, 0.495048201930645],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{
                {GrayLevel[0], RectangleBox[{0, 0}]}, 
                {GrayLevel[0], RectangleBox[{1, -1}]}, 
                {RGBColor[
                 0.410530117230961, 0.65951899493187, 0.31274019237510875`], 
                 RectangleBox[{0, -1}, {2, 1}]}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.2736867448206407, 0.43967932995458003`, 
                 0.20849346158340584`],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.410530117230961, 0.65951899493187, \
0.31274019237510875]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.410530117230961, 0.65951899493187, 0.31274019237510875`]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.410530117230961, 0.65951899493187, 0.31274019237510875`],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{
                {GrayLevel[0], RectangleBox[{0, 0}]}, 
                {GrayLevel[0], RectangleBox[{1, -1}]}, 
                {RGBColor[
                 0.14914425266109754`, 0.8632288046219025, 
                  0.2165769996518021], RectangleBox[{0, -1}, {2, 1}]}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.09942950177406504, 0.575485869747935, 0.14438466643453474`],
               
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.14914425266109754, 0.8632288046219025, \
0.2165769996518021]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.14914425266109754`, 0.8632288046219025, 
                   0.2165769996518021]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.14914425266109754`, 0.8632288046219025, 0.2165769996518021],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{
                {GrayLevel[0], RectangleBox[{0, 0}]}, 
                {GrayLevel[0], RectangleBox[{1, -1}]}, 
                {RGBColor[
                 0.5019554020533212, 0.5771425709059108, 0.4324648041012522], 
                 RectangleBox[{0, -1}, {2, 1}]}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.3346369347022142, 0.3847617139372739, 0.2883098694008348],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.5019554020533212, 0.5771425709059108, \
0.4324648041012522]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.5019554020533212, 0.5771425709059108, 0.4324648041012522]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.5019554020533212, 0.5771425709059108, 0.4324648041012522],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{
                {GrayLevel[0], RectangleBox[{0, 0}]}, 
                {GrayLevel[0], RectangleBox[{1, -1}]}, 
                {RGBColor[
                 0.2375846642639532, 0.7953276430316651, 0.9346352336682711], 
                 RectangleBox[{0, -1}, {2, 1}]}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.1583897761759688, 0.5302184286877768, 0.6230901557788474],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.2375846642639532, 0.7953276430316651, \
0.9346352336682711]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.2375846642639532, 0.7953276430316651, 0.9346352336682711]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.2375846642639532, 0.7953276430316651, 0.9346352336682711],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{
                {GrayLevel[0], RectangleBox[{0, 0}]}, 
                {GrayLevel[0], RectangleBox[{1, -1}]}, 
                {RGBColor[
                 0.5670638896981823, 0.30694748662903737`, 
                  0.07724772234151844], RectangleBox[{0, -1}, {2, 1}]}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.3780425931321216, 0.2046316577526916, 0.0514984815610123],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.5670638896981823, 0.30694748662903737, \
0.07724772234151844]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.5670638896981823, 0.30694748662903737`, 
                   0.07724772234151844]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.5670638896981823, 0.30694748662903737`, 0.07724772234151844],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{
                {GrayLevel[0], RectangleBox[{0, 0}]}, 
                {GrayLevel[0], RectangleBox[{1, -1}]}, 
                {RGBColor[
                 0.9836330486106633, 0.9337141420685637, 
                  0.45110780147188234`], RectangleBox[{0, -1}, {2, 1}]}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.6557553657404422, 0.6224760947123759, 0.30073853431458825`],
               
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.9836330486106633, 0.9337141420685637, \
0.45110780147188234]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.9836330486106633, 0.9337141420685637, 
                   0.45110780147188234`]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.9836330486106633, 0.9337141420685637, 0.45110780147188234`],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{
                {GrayLevel[0], RectangleBox[{0, 0}]}, 
                {GrayLevel[0], RectangleBox[{1, -1}]}, 
                {RGBColor[
                 0.548151102001315, 0.9273818734933321, 0.6138604019189067], 
                 RectangleBox[{0, -1}, {2, 1}]}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.3654340680008767, 0.6182545823288881, 0.4092402679459378],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.548151102001315, 0.9273818734933321, \
0.6138604019189067]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.548151102001315, 0.9273818734933321, 0.6138604019189067]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.548151102001315, 0.9273818734933321, 0.6138604019189067],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{
                {GrayLevel[0], RectangleBox[{0, 0}]}, 
                {GrayLevel[0], RectangleBox[{1, -1}]}, 
                {RGBColor[
                 0.08996343949980967, 0.7502285322367264, 0.7647837622874905],
                  RectangleBox[{0, -1}, {2, 1}]}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.05997562633320645, 0.5001523548244843, 0.5098558415249936],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.08996343949980967, 0.7502285322367264, \
0.7647837622874905]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.08996343949980967, 0.7502285322367264, 
                   0.7647837622874905]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.08996343949980967, 0.7502285322367264, 0.7647837622874905],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{
                {GrayLevel[0], RectangleBox[{0, 0}]}, 
                {GrayLevel[0], RectangleBox[{1, -1}]}, 
                {RGBColor[
                 0.9554445238224603, 0.9118174885785313, 0.7586039763217882], 
                 RectangleBox[{0, -1}, {2, 1}]}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.6369630158816402, 0.6078783257190209, 0.5057359842145255],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.9554445238224603, 0.9118174885785313, \
0.7586039763217882]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.9554445238224603, 0.9118174885785313, 0.7586039763217882]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.9554445238224603, 0.9118174885785313, 0.7586039763217882],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{
                {GrayLevel[0], RectangleBox[{0, 0}]}, 
                {GrayLevel[0], RectangleBox[{1, -1}]}, 
                {RGBColor[
                 0.12407876246761118`, 0.8951986963374581, 0.405054951518828],
                  RectangleBox[{0, -1}, {2, 1}]}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.08271917497840746, 0.5967991308916387, 0.2700366343458853],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.12407876246761118, 0.8951986963374581, \
0.405054951518828]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.12407876246761118`, 0.8951986963374581, 
                   0.405054951518828]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.12407876246761118`, 0.8951986963374581, 0.405054951518828],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{
                {GrayLevel[0], RectangleBox[{0, 0}]}, 
                {GrayLevel[0], RectangleBox[{1, -1}]}, 
                {RGBColor[
                 0.3518853673765441, 0.6267881822227646, 0.01601455063963053],
                  RectangleBox[{0, -1}, {2, 1}]}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.23459024491769606`, 0.41785878814850974`, 
                 0.010676367093087022`],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.3518853673765441, 0.6267881822227646, \
0.01601455063963053]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.3518853673765441, 0.6267881822227646, 
                   0.01601455063963053]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.3518853673765441, 0.6267881822227646, 0.01601455063963053],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{
                {GrayLevel[0], RectangleBox[{0, 0}]}, 
                {GrayLevel[0], RectangleBox[{1, -1}]}, 
                {RGBColor[
                 0.38175543134617906`, 0.6109792496345561, 
                  0.30321055377645356`], RectangleBox[{0, -1}, {2, 1}]}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.2545036208974527, 0.4073194997563707, 0.2021403691843024],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.38175543134617906, 0.6109792496345561, \
0.30321055377645356]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.38175543134617906`, 0.6109792496345561, 
                   0.30321055377645356`]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.38175543134617906`, 0.6109792496345561, 0.30321055377645356`],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{
                {GrayLevel[0], RectangleBox[{0, 0}]}, 
                {GrayLevel[0], RectangleBox[{1, -1}]}, 
                {RGBColor[
                 0.5015968883258048, 0.9477341972992892, 0.7518749706067847], 
                 RectangleBox[{0, -1}, {2, 1}]}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.3343979255505366, 0.6318227981995261, 0.5012499804045232],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.5015968883258048, 0.9477341972992892, \
0.7518749706067847]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.5015968883258048, 0.9477341972992892, 0.7518749706067847]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.5015968883258048, 0.9477341972992892, 0.7518749706067847],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{
                {GrayLevel[0], RectangleBox[{0, 0}]}, 
                {GrayLevel[0], RectangleBox[{1, -1}]}, 
                {RGBColor[
                 0.4853791041906068, 0.9983056811536988, 
                  0.059586297674913524`], RectangleBox[{0, -1}, {2, 1}]}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.3235860694604046, 0.6655371207691325, 0.03972419844994235],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.4853791041906068, 0.9983056811536988, \
0.059586297674913524]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.4853791041906068, 0.9983056811536988, 
                   0.059586297674913524`]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.4853791041906068, 0.9983056811536988, 0.059586297674913524`],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{
                {GrayLevel[0], RectangleBox[{0, 0}]}, 
                {GrayLevel[0], RectangleBox[{1, -1}]}, 
                {RGBColor[
                 0.39598681356054666`, 0.5894657294683947, 
                  0.2897133293523855], RectangleBox[{0, -1}, {2, 1}]}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.26399120904036444`, 0.3929771529789298, 0.193142219568257],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.39598681356054666, 0.5894657294683947, \
0.2897133293523855]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.39598681356054666`, 0.5894657294683947, 
                   0.2897133293523855]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.39598681356054666`, 0.5894657294683947, 0.2897133293523855],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{
                {GrayLevel[0], RectangleBox[{0, 0}]}, 
                {GrayLevel[0], RectangleBox[{1, -1}]}, 
                {RGBColor[
                 0.06510008212093177, 0.7580810151353965, 0.4838966525370989],
                  RectangleBox[{0, -1}, {2, 1}]}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.04340005474728785, 0.5053873434235977, 0.322597768358066],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.06510008212093177, 0.7580810151353965, \
0.4838966525370989]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.06510008212093177, 0.7580810151353965, 
                   0.4838966525370989]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.06510008212093177, 0.7580810151353965, 0.4838966525370989],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{
                {GrayLevel[0], RectangleBox[{0, 0}]}, 
                {GrayLevel[0], RectangleBox[{1, -1}]}, 
                {RGBColor[
                 0.02229677965825383, 0.35028891391213257`, 
                  0.0684550207396537], RectangleBox[{0, -1}, {2, 1}]}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.01486451977216922, 0.2335259426080884, 
                 0.045636680493102474`],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.02229677965825383, 0.35028891391213257, \
0.0684550207396537]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.02229677965825383, 0.35028891391213257`, 
                   0.0684550207396537]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.02229677965825383, 0.35028891391213257`, 0.0684550207396537],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{
                {GrayLevel[0], RectangleBox[{0, 0}]}, 
                {GrayLevel[0], RectangleBox[{1, -1}]}, 
                {RGBColor[
                 0.15578960479774717`, 0.33156505911261824`, 
                  0.10795082362400787`], RectangleBox[{0, -1}, {2, 1}]}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.10385973653183145`, 0.22104337274174551`, 
                 0.07196721574933859],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.15578960479774717, 0.33156505911261824, \
0.10795082362400787]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.15578960479774717`, 0.33156505911261824`, 
                   0.10795082362400787`]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.15578960479774717`, 0.33156505911261824`, 0.10795082362400787`],
            
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{
                {GrayLevel[0], RectangleBox[{0, 0}]}, 
                {GrayLevel[0], RectangleBox[{1, -1}]}, 
                {RGBColor[
                 0.9666406011133539, 0.6653552686335491, 0.5546554666254075], 
                 RectangleBox[{0, -1}, {2, 1}]}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.6444270674089027, 0.44357017908903273`, 
                 0.36977031108360503`],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.9666406011133539, 0.6653552686335491, \
0.5546554666254075]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.9666406011133539, 0.6653552686335491, 0.5546554666254075]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.9666406011133539, 0.6653552686335491, 0.5546554666254075],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{
                {GrayLevel[0], RectangleBox[{0, 0}]}, 
                {GrayLevel[0], RectangleBox[{1, -1}]}, 
                {RGBColor[
                 0.21832422216206182`, 0.4452088456726624, 
                  0.34195667187604584`], RectangleBox[{0, -1}, {2, 1}]}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.14554948144137456`, 0.2968058971151083, 
                 0.22797111458403058`],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.21832422216206182, 0.4452088456726624, \
0.34195667187604584]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.21832422216206182`, 0.4452088456726624, 
                   0.34195667187604584`]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.21832422216206182`, 0.4452088456726624, 0.34195667187604584`],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{
                {GrayLevel[0], RectangleBox[{0, 0}]}, 
                {GrayLevel[0], RectangleBox[{1, -1}]}, 
                {RGBColor[
                 0.4939446101923697, 0.31678858836269796`, 
                  0.11346988660388835`], RectangleBox[{0, -1}, {2, 1}]}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.3292964067949131, 0.21119239224179864`, 0.0756465910692589],
               
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.4939446101923697, 0.31678858836269796, \
0.11346988660388835]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.4939446101923697, 0.31678858836269796`, 
                   0.11346988660388835`]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.4939446101923697, 0.31678858836269796`, 0.11346988660388835`],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{
                {GrayLevel[0], RectangleBox[{0, 0}]}, 
                {GrayLevel[0], RectangleBox[{1, -1}]}, 
                {RGBColor[
                 0.9566388456878347, 0.9651195544633302, 0.9076564789046491], 
                 RectangleBox[{0, -1}, {2, 1}]}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.6377592304585565, 0.6434130363088868, 0.605104319269766],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.9566388456878347, 0.9651195544633302, \
0.9076564789046491]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.9566388456878347, 0.9651195544633302, 0.9076564789046491]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.9566388456878347, 0.9651195544633302, 0.9076564789046491],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{
                {GrayLevel[0], RectangleBox[{0, 0}]}, 
                {GrayLevel[0], RectangleBox[{1, -1}]}, 
                {RGBColor[
                 0.4000855073593619, 0.39588066174906866`, 
                  0.1685452332949151], RectangleBox[{0, -1}, {2, 1}]}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.26672367157290794`, 0.2639204411660458, 
                 0.11236348886327674`],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.4000855073593619, 0.39588066174906866, \
0.1685452332949151]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.4000855073593619, 0.39588066174906866`, 
                   0.1685452332949151]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.4000855073593619, 0.39588066174906866`, 0.1685452332949151],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{
                {GrayLevel[0], RectangleBox[{0, 0}]}, 
                {GrayLevel[0], RectangleBox[{1, -1}]}, 
                {RGBColor[
                 0.5700736595139675, 0.4069545472059297, 0.1981313907220874], 
                 RectangleBox[{0, -1}, {2, 1}]}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.380049106342645, 0.27130303147061985`, 0.13208759381472496`],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.5700736595139675, 0.4069545472059297, \
0.1981313907220874]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.5700736595139675, 0.4069545472059297, 0.1981313907220874]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.5700736595139675, 0.4069545472059297, 0.1981313907220874],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{
                {GrayLevel[0], RectangleBox[{0, 0}]}, 
                {GrayLevel[0], RectangleBox[{1, -1}]}, 
                {RGBColor[
                 0.16637070232988593`, 0.6273450506223697, 
                  0.6129198387249786], RectangleBox[{0, -1}, {2, 1}]}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.1109138015532573, 0.41823003374824647`, 0.4086132258166524],
               
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.16637070232988593, 0.6273450506223697, \
0.6129198387249786]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.16637070232988593`, 0.6273450506223697, 
                   0.6129198387249786]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.16637070232988593`, 0.6273450506223697, 0.6129198387249786],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{
                {GrayLevel[0], RectangleBox[{0, 0}]}, 
                {GrayLevel[0], RectangleBox[{1, -1}]}, 
                {RGBColor[
                 0.15217789308335927`, 0.6805446503579162, 
                  0.7536712821543405], RectangleBox[{0, -1}, {2, 1}]}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.10145192872223951`, 0.45369643357194417`, 
                 0.5024475214362271],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.15217789308335927, 0.6805446503579162, \
0.7536712821543405]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.15217789308335927`, 0.6805446503579162, 
                   0.7536712821543405]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.15217789308335927`, 0.6805446503579162, 0.7536712821543405],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{
                {GrayLevel[0], RectangleBox[{0, 0}]}, 
                {GrayLevel[0], RectangleBox[{1, -1}]}, 
                {RGBColor[
                 0.011500166973726689`, 0.9344737120630893, 
                  0.41519231703372195`], RectangleBox[{0, -1}, {2, 1}]}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.00766677798248446, 0.6229824747087263, 0.2767948780224813],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.011500166973726689, 0.9344737120630893, \
0.41519231703372195]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.011500166973726689`, 0.9344737120630893, 
                   0.41519231703372195`]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.011500166973726689`, 0.9344737120630893, 0.41519231703372195`],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{
                {GrayLevel[0], RectangleBox[{0, 0}]}, 
                {GrayLevel[0], RectangleBox[{1, -1}]}, 
                {RGBColor[
                 0.6487763190386047, 0.9218976224198998, 0.711816672844579], 
                 RectangleBox[{0, -1}, {2, 1}]}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.43251754602573644`, 0.6145984149466, 0.47454444856305267`],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.6487763190386047, 0.9218976224198998, \
0.711816672844579]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.6487763190386047, 0.9218976224198998, 0.711816672844579]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.6487763190386047, 0.9218976224198998, 0.711816672844579],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{
                {GrayLevel[0], RectangleBox[{0, 0}]}, 
                {GrayLevel[0], RectangleBox[{1, -1}]}, 
                {RGBColor[
                 0.47327935747334204`, 0.8834140175937308, 
                  0.33245673464773584`], RectangleBox[{0, -1}, {2, 1}]}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.3155195716488947, 0.5889426783958206, 0.22163782309849056`],
               
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.47327935747334204, 0.8834140175937308, \
0.33245673464773584]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.47327935747334204`, 0.8834140175937308, 
                   0.33245673464773584`]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.47327935747334204`, 0.8834140175937308, 0.33245673464773584`],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{
                {GrayLevel[0], RectangleBox[{0, 0}]}, 
                {GrayLevel[0], RectangleBox[{1, -1}]}, 
                {RGBColor[
                 0.25560515056407795`, 0.8012401319897553, 
                  0.15094027368448049`], RectangleBox[{0, -1}, {2, 1}]}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.17040343370938532`, 0.5341600879931703, 0.100626849122987],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.25560515056407795, 0.8012401319897553, \
0.15094027368448049]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.25560515056407795`, 0.8012401319897553, 
                   0.15094027368448049`]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.25560515056407795`, 0.8012401319897553, 0.15094027368448049`],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{
                {GrayLevel[0], RectangleBox[{0, 0}]}, 
                {GrayLevel[0], RectangleBox[{1, -1}]}, 
                {RGBColor[
                 0.13360546814982577`, 0.7871863239201633, 
                  0.018599162734135977`], RectangleBox[{0, -1}, {2, 1}]}},
               AspectRatio->1,
               Frame->True,
               FrameStyle->RGBColor[
                0.08907031209988385, 0.5247908826134422, 
                 0.012399441822757318`],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.13360546814982577, 0.7871863239201633, \
0.018599162734135977]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.13360546814982577`, 0.7871863239201633, 
                   0.018599162734135977`]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.13360546814982577`, 0.7871863239201633, 0.018599162734135977`],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{
                {GrayLevel[0], RectangleBox[{0, 0}]}, 
                {GrayLevel[0], RectangleBox[{1, -1}]}, 
                {RGBColor[
                 0.38337417819768205`, 0.4988952587556723, 
                  0.08321860516969015], RectangleBox[{0, -1}, {2, 1}]}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.25558278546512136`, 0.33259683917044824`, 
                 0.05547907011312677],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.38337417819768205, 0.4988952587556723, \
0.08321860516969015]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.38337417819768205`, 0.4988952587556723, 
                   0.08321860516969015]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.38337417819768205`, 0.4988952587556723, 0.08321860516969015],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{
                {GrayLevel[0], RectangleBox[{0, 0}]}, 
                {GrayLevel[0], RectangleBox[{1, -1}]}, 
                {RGBColor[
                 0.4181367040733106, 0.49313383402211364`, 
                  0.10167945128775124`], RectangleBox[{0, -1}, {2, 1}]}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.2787578027155404, 0.32875588934807576`, 0.06778630085850083],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.4181367040733106, 0.49313383402211364, \
0.10167945128775124]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.4181367040733106, 0.49313383402211364`, 
                   0.10167945128775124`]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.4181367040733106, 0.49313383402211364`, 0.10167945128775124`],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{
                {GrayLevel[0], RectangleBox[{0, 0}]}, 
                {GrayLevel[0], RectangleBox[{1, -1}]}, 
                {RGBColor[
                 0.4812053533680498, 0.873332380181423, 0.327028956990717], 
                 RectangleBox[{0, -1}, {2, 1}]}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.3208035689120332, 0.5822215867876154, 0.218019304660478],
               FrameTicks->None,
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.4812053533680498, 0.873332380181423, \
0.327028956990717]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.4812053533680498, 0.873332380181423, 0.327028956990717]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[0.4812053533680498, 0.873332380181423, 0.327028956990717],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{
                {GrayLevel[0], RectangleBox[{0, 0}]}, 
                {GrayLevel[0], RectangleBox[{1, -1}]}, 
                {RGBColor[
                 0.5269434582467774, 0.8294337802982428, 0.1734709900484559], 
                 RectangleBox[{0, -1}, {2, 1}]}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.3512956388311849, 0.5529558535321619, 0.1156473266989706],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.5269434582467774, 0.8294337802982428, \
0.1734709900484559]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.5269434582467774, 0.8294337802982428, 0.1734709900484559]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.5269434582467774, 0.8294337802982428, 0.1734709900484559],
            Editable->False,
            Selectable->False]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{
                {GrayLevel[0], RectangleBox[{0, 0}]}, 
                {GrayLevel[0], RectangleBox[{1, -1}]}, 
                {RGBColor[
                 0.37266534273681007`, 0.38750269832660855`, 
                  0.3948182017762212], RectangleBox[{0, -1}, {2, 1}]}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.24844356182454005`, 0.25833513221773907`, 
                 0.2632121345174808],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.37266534273681007, 0.38750269832660855, \
0.3948182017762212]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.37266534273681007`, 0.38750269832660855`, 
                   0.3948182017762212]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.37266534273681007`, 0.38750269832660855`, 0.3948182017762212],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{
                {GrayLevel[0], RectangleBox[{0, 0}]}, 
                {GrayLevel[0], RectangleBox[{1, -1}]}, 
                {RGBColor[
                 0.733606571264461, 0.4291909747287308, 0.4301886698173236], 
                 RectangleBox[{0, -1}, {2, 1}]}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.4890710475096407, 0.28612731648582057`, 
                 0.28679244654488245`],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.733606571264461, 0.4291909747287308, \
0.4301886698173236]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.733606571264461, 0.4291909747287308, 0.4301886698173236]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.733606571264461, 0.4291909747287308, 0.4301886698173236],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{
                {GrayLevel[0], RectangleBox[{0, 0}]}, 
                {GrayLevel[0], RectangleBox[{1, -1}]}, 
                {RGBColor[
                 0.17707863410973768`, 0.672607405954065, 0.8338273497920801],
                  RectangleBox[{0, -1}, {2, 1}]}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.11805242273982512`, 0.44840493730271, 0.5558848998613868],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.17707863410973768, 0.672607405954065, \
0.8338273497920801]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.17707863410973768`, 0.672607405954065, 
                   0.8338273497920801]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.17707863410973768`, 0.672607405954065, 0.8338273497920801],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{
                {GrayLevel[0], RectangleBox[{0, 0}]}, 
                {GrayLevel[0], RectangleBox[{1, -1}]}, 
                {RGBColor[
                 0.8745580077995285, 0.08910005366925322, 0.5820198361552016],
                  RectangleBox[{0, -1}, {2, 1}]}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.5830386718663524, 0.05940003577950215, 0.3880132241034677],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.8745580077995285, 0.08910005366925322, \
0.5820198361552016]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.8745580077995285, 0.08910005366925322, 
                   0.5820198361552016]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.8745580077995285, 0.08910005366925322, 0.5820198361552016],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{
                {GrayLevel[0], RectangleBox[{0, 0}]}, 
                {GrayLevel[0], RectangleBox[{1, -1}]}, 
                {RGBColor[
                 0.9090294322469556, 0.2839329014344203, 0.5231271919589293], 
                 RectangleBox[{0, -1}, {2, 1}]}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.6060196214979705, 0.1892886009562802, 0.3487514613059529],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.9090294322469556, 0.2839329014344203, \
0.5231271919589293]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.9090294322469556, 0.2839329014344203, 0.5231271919589293]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.9090294322469556, 0.2839329014344203, 0.5231271919589293],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{
                {GrayLevel[0], RectangleBox[{0, 0}]}, 
                {GrayLevel[0], RectangleBox[{1, -1}]}, 
                {RGBColor[
                 0.4864384781423896, 0.2590016473319656, 0.8939198034327294], 
                 RectangleBox[{0, -1}, {2, 1}]}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.3242923187615931, 0.17266776488797708`, 0.5959465356218197],
               
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.4864384781423896, 0.2590016473319656, \
0.8939198034327294]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.4864384781423896, 0.2590016473319656, 0.8939198034327294]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.4864384781423896, 0.2590016473319656, 0.8939198034327294],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{
                {GrayLevel[0], RectangleBox[{0, 0}]}, 
                {GrayLevel[0], RectangleBox[{1, -1}]}, 
                {RGBColor[
                 0.2674220618976657, 0.5345197867819858, 0.7888815584252213], 
                 RectangleBox[{0, -1}, {2, 1}]}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.17828137459844381`, 0.35634652452132387`, 
                 0.5259210389501476],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.2674220618976657, 0.5345197867819858, \
0.7888815584252213]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.2674220618976657, 0.5345197867819858, 0.7888815584252213]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.2674220618976657, 0.5345197867819858, 0.7888815584252213],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{
                {GrayLevel[0], RectangleBox[{0, 0}]}, 
                {GrayLevel[0], RectangleBox[{1, -1}]}, 
                {RGBColor[
                 0.18736123677107708`, 0.3952086052502788, 0.86460527303447], 
                 RectangleBox[{0, -1}, {2, 1}]}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.12490749118071806`, 0.26347240350018586`, 
                 0.5764035153563134],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.18736123677107708, 0.3952086052502788, \
0.86460527303447]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.18736123677107708`, 0.3952086052502788, 0.86460527303447]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.18736123677107708`, 0.3952086052502788, 0.86460527303447],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{
                {GrayLevel[0], RectangleBox[{0, 0}]}, 
                {GrayLevel[0], RectangleBox[{1, -1}]}, 
                {RGBColor[
                 0.7776461280660796, 0.8643601244579295, 0.9944319426310919], 
                 RectangleBox[{0, -1}, {2, 1}]}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.5184307520440531, 0.5762400829719531, 0.6629546284207279],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.7776461280660796, 0.8643601244579295, \
0.9944319426310919]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.7776461280660796, 0.8643601244579295, 0.9944319426310919]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.7776461280660796, 0.8643601244579295, 0.9944319426310919],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{
                {GrayLevel[0], RectangleBox[{0, 0}]}, 
                {GrayLevel[0], RectangleBox[{1, -1}]}, 
                {RGBColor[
                 0.10244743490058794`, 0.1869170597224914, 
                  0.6271170684614624], RectangleBox[{0, -1}, {2, 1}]}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.0682982899337253, 0.1246113731483276, 0.41807804564097495`],
               
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.10244743490058794, 0.1869170597224914, \
0.6271170684614624]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.10244743490058794`, 0.1869170597224914, 
                   0.6271170684614624]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.10244743490058794`, 0.1869170597224914, 0.6271170684614624],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{
                {GrayLevel[0], RectangleBox[{0, 0}]}, 
                {GrayLevel[0], RectangleBox[{1, -1}]}, 
                {RGBColor[
                 0.4573447796522936, 0.007181376876192136, 0.566195028583903],
                  RectangleBox[{0, -1}, {2, 1}]}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.30489651976819576`, 0.004787584584128091, 
                 0.3774633523892687],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.4573447796522936, 0.007181376876192136, \
0.566195028583903]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.4573447796522936, 0.007181376876192136, 
                   0.566195028583903]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.4573447796522936, 0.007181376876192136, 0.566195028583903],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{
                {GrayLevel[0], RectangleBox[{0, 0}]}, 
                {GrayLevel[0], RectangleBox[{1, -1}]}, 
                {RGBColor[
                 0.23258722219837846`, 0.08344742427005825, 
                  0.30644177688225716`], RectangleBox[{0, -1}, {2, 1}]}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.15505814813225233`, 0.05563161618003883, 
                 0.20429451792150477`],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.23258722219837846, 0.08344742427005825, \
0.30644177688225716]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.23258722219837846`, 0.08344742427005825, 
                   0.30644177688225716`]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.23258722219837846`, 0.08344742427005825, 0.30644177688225716`],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{
                {GrayLevel[0], RectangleBox[{0, 0}]}, 
                {GrayLevel[0], RectangleBox[{1, -1}]}, 
                {RGBColor[
                 0.711485166849398, 0.017375777675906035`, 
                  0.7454946682315056], RectangleBox[{0, -1}, {2, 1}]}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.47432344456626535`, 0.011583851783937357`, 
                 0.4969964454876704],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.711485166849398, 0.017375777675906035, \
0.7454946682315056]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.711485166849398, 0.017375777675906035`, 
                   0.7454946682315056]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.711485166849398, 0.017375777675906035`, 0.7454946682315056],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{
                {GrayLevel[0], RectangleBox[{0, 0}]}, 
                {GrayLevel[0], RectangleBox[{1, -1}]}, 
                {RGBColor[
                 0.31452599923983104`, 0.6908103742720597, 
                  0.9463506847311731], RectangleBox[{0, -1}, {2, 1}]}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.2096839994932207, 0.4605402495147065, 0.6309004564874487],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.31452599923983104, 0.6908103742720597, \
0.9463506847311731]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.31452599923983104`, 0.6908103742720597, 
                   0.9463506847311731]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.31452599923983104`, 0.6908103742720597, 0.9463506847311731],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{
                {GrayLevel[0], RectangleBox[{0, 0}]}, 
                {GrayLevel[0], RectangleBox[{1, -1}]}, 
                {RGBColor[
                 0.922559309792595, 0.2703946335791436, 0.09665543181913394], 
                 RectangleBox[{0, -1}, {2, 1}]}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.6150395398617301, 0.18026308905276242`, 0.0644369545460893],
               
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.922559309792595, 0.2703946335791436, \
0.09665543181913394]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.922559309792595, 0.2703946335791436, 0.09665543181913394]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.922559309792595, 0.2703946335791436, 0.09665543181913394],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{
                {GrayLevel[0], RectangleBox[{0, 0}]}, 
                {GrayLevel[0], RectangleBox[{1, -1}]}, 
                {RGBColor[
                 0.11122524183982829`, 0.12772449779541217`, 
                  0.6139200516853858], RectangleBox[{0, -1}, {2, 1}]}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.0741501612265522, 0.08514966519694145, 0.40928003445692385`],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.11122524183982829, 0.12772449779541217, \
0.6139200516853858]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.11122524183982829`, 0.12772449779541217`, 
                   0.6139200516853858]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.11122524183982829`, 0.12772449779541217`, 0.6139200516853858],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{
                {GrayLevel[0], RectangleBox[{0, 0}]}, 
                {GrayLevel[0], RectangleBox[{1, -1}]}, 
                {RGBColor[
                 0.6357194627252103, 0.15357943517679362`, 0.860476954867391],
                  RectangleBox[{0, -1}, {2, 1}]}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.4238129751501402, 0.10238629011786242`, 0.5736513032449273],
               
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.6357194627252103, 0.15357943517679362, \
0.860476954867391]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.6357194627252103, 0.15357943517679362`, 
                   0.860476954867391]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.6357194627252103, 0.15357943517679362`, 0.860476954867391],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{
                {GrayLevel[0], RectangleBox[{0, 0}]}, 
                {GrayLevel[0], RectangleBox[{1, -1}]}, 
                {RGBColor[
                 0.4431832834876257, 0.18321465791748515`, 
                  0.7764518003586576], RectangleBox[{0, -1}, {2, 1}]}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.2954555223250838, 0.12214310527832344`, 0.5176345335724384],
               
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.4431832834876257, 0.18321465791748515, \
0.7764518003586576]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.4431832834876257, 0.18321465791748515`, 
                   0.7764518003586576]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.4431832834876257, 0.18321465791748515`, 0.7764518003586576],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{
                {GrayLevel[0], RectangleBox[{0, 0}]}, 
                {GrayLevel[0], RectangleBox[{1, -1}]}, 
                {RGBColor[
                 0.3553518860908462, 0.6443320866741731, 0.7499636864238166], 
                 RectangleBox[{0, -1}, {2, 1}]}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.2369012573938975, 0.42955472444944875`, 0.4999757909492111],
               
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.3553518860908462, 0.6443320866741731, \
0.7499636864238166]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.3553518860908462, 0.6443320866741731, 0.7499636864238166]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.3553518860908462, 0.6443320866741731, 0.7499636864238166],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{
                {GrayLevel[0], RectangleBox[{0, 0}]}, 
                {GrayLevel[0], RectangleBox[{1, -1}]}, 
                {RGBColor[
                 0.8943854155561495, 0.03560200287351467, 
                  0.16578917868909593`], RectangleBox[{0, -1}, {2, 1}]}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.5962569437040997, 0.023734668582343115`, 
                 0.11052611912606396`],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.8943854155561495, 0.03560200287351467, \
0.16578917868909593]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.8943854155561495, 0.03560200287351467, 
                   0.16578917868909593`]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.8943854155561495, 0.03560200287351467, 0.16578917868909593`],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{
                {GrayLevel[0], RectangleBox[{0, 0}]}, 
                {GrayLevel[0], RectangleBox[{1, -1}]}, 
                {RGBColor[
                 0.6672396717157738, 0.3586192991395154, 0.8976595916455246], 
                 RectangleBox[{0, -1}, {2, 1}]}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.4448264478105159, 0.23907953275967694`, 0.598439727763683],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.6672396717157738, 0.3586192991395154, \
0.8976595916455246]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.6672396717157738, 0.3586192991395154, 0.8976595916455246]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.6672396717157738, 0.3586192991395154, 0.8976595916455246],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{
                {GrayLevel[0], RectangleBox[{0, 0}]}, 
                {GrayLevel[0], RectangleBox[{1, -1}]}, 
                {RGBColor[
                 0.37001635641206, 0.3047563933568622, 0.7684408201506054], 
                 RectangleBox[{0, -1}, {2, 1}]}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.24667757094137333`, 0.20317092890457483`, 
                 0.5122938801004037],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.37001635641206, 0.3047563933568622, \
0.7684408201506054]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.37001635641206, 0.3047563933568622, 0.7684408201506054]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[0.37001635641206, 0.3047563933568622, 0.7684408201506054],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{
                {GrayLevel[0], RectangleBox[{0, 0}]}, 
                {GrayLevel[0], RectangleBox[{1, -1}]}, 
                {RGBColor[
                 0.38698691150966935`, 0.10328204902950966`, 
                  0.8013210231747274], RectangleBox[{0, -1}, {2, 1}]}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.2579912743397796, 0.06885469935300645, 0.5342140154498183],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.38698691150966935, 0.10328204902950966, \
0.8013210231747274]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.38698691150966935`, 0.10328204902950966`, 
                   0.8013210231747274]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.38698691150966935`, 0.10328204902950966`, 0.8013210231747274],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{
                {GrayLevel[0], RectangleBox[{0, 0}]}, 
                {GrayLevel[0], RectangleBox[{1, -1}]}, 
                {RGBColor[
                 0.29215345853340424`, 0.35497646703617836`, 
                  0.6346432521789236], RectangleBox[{0, -1}, {2, 1}]}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.19476897235560284`, 0.2366509780241189, 
                 0.42309550145261576`],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.29215345853340424, 0.35497646703617836, \
0.6346432521789236]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.29215345853340424`, 0.35497646703617836`, 
                   0.6346432521789236]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.29215345853340424`, 0.35497646703617836`, 0.6346432521789236],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{
                {GrayLevel[0], RectangleBox[{0, 0}]}, 
                {GrayLevel[0], RectangleBox[{1, -1}]}, 
                {RGBColor[
                 0.9678407581110904, 0.025426491397912976`, 
                  0.587777889276665], RectangleBox[{0, -1}, {2, 1}]}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.6452271720740603, 0.01695099426527532, 0.3918519261844433],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.9678407581110904, 0.025426491397912976, \
0.587777889276665]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.9678407581110904, 0.025426491397912976`, 
                   0.587777889276665]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.9678407581110904, 0.025426491397912976`, 0.587777889276665],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{
                {GrayLevel[0], RectangleBox[{0, 0}]}, 
                {GrayLevel[0], RectangleBox[{1, -1}]}, 
                {RGBColor[
                 0.4918965330955356, 0.29233426982370303`, 
                  0.5281824844462943], RectangleBox[{0, -1}, {2, 1}]}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.3279310220636904, 0.19488951321580203`, 
                 0.35212165629752956`],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.4918965330955356, 0.29233426982370303, \
0.5281824844462943]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.4918965330955356, 0.29233426982370303`, 
                   0.5281824844462943]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.4918965330955356, 0.29233426982370303`, 0.5281824844462943],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{
                {GrayLevel[0], RectangleBox[{0, 0}]}, 
                {GrayLevel[0], RectangleBox[{1, -1}]}, 
                {RGBColor[
                 0.1252423737911874, 0.5183189386335805, 0.7491160058315705], 
                 RectangleBox[{0, -1}, {2, 1}]}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.08349491586079161, 0.34554595908905367`, 0.4994106705543803],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.1252423737911874, 0.5183189386335805, \
0.7491160058315705]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.1252423737911874, 0.5183189386335805, 0.7491160058315705]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.1252423737911874, 0.5183189386335805, 0.7491160058315705],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{
                {GrayLevel[0], RectangleBox[{0, 0}]}, 
                {GrayLevel[0], RectangleBox[{1, -1}]}, 
                {RGBColor[
                 0.9765556387211944, 0.12357617097291551`, 
                  0.5068373458296718], RectangleBox[{0, -1}, {2, 1}]}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.6510370924807963, 0.08238411398194367, 0.33789156388644787`],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.9765556387211944, 0.12357617097291551, \
0.5068373458296718]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.9765556387211944, 0.12357617097291551`, 
                   0.5068373458296718]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.9765556387211944, 0.12357617097291551`, 0.5068373458296718],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{
                {GrayLevel[0], RectangleBox[{0, 0}]}, 
                {GrayLevel[0], RectangleBox[{1, -1}]}, 
                {RGBColor[
                 0.8227934753153485, 0.3797246867796864, 0.6782582898466567], 
                 RectangleBox[{0, -1}, {2, 1}]}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.5485289835435657, 0.25314979118645764`, 
                 0.45217219323110447`],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.8227934753153485, 0.3797246867796864, \
0.6782582898466567]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.8227934753153485, 0.3797246867796864, 0.6782582898466567]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.8227934753153485, 0.3797246867796864, 0.6782582898466567],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{
                {GrayLevel[0], RectangleBox[{0, 0}]}, 
                {GrayLevel[0], RectangleBox[{1, -1}]}, 
                {RGBColor[
                 0.6820734720667967, 0.43856527685111324`, 
                  0.8695673460178908], RectangleBox[{0, -1}, {2, 1}]}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.45471564804453113`, 0.29237685123407553`, 
                 0.5797115640119272],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.6820734720667967, 0.43856527685111324, \
0.8695673460178908]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.6820734720667967, 0.43856527685111324`, 
                   0.8695673460178908]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.6820734720667967, 0.43856527685111324`, 0.8695673460178908],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{
                {GrayLevel[0], RectangleBox[{0, 0}]}, 
                {GrayLevel[0], RectangleBox[{1, -1}]}, 
                {RGBColor[
                 0.11654903299881392`, 0.07006336344132391, 0.56484752468554],
                  RectangleBox[{0, -1}, {2, 1}]}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.07769935533254262, 0.04670890896088261, 
                 0.37656501645702667`],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.11654903299881392, 0.07006336344132391, \
0.56484752468554]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.11654903299881392`, 0.07006336344132391, 
                   0.56484752468554]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.11654903299881392`, 0.07006336344132391, 0.56484752468554],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{
                {GrayLevel[0], RectangleBox[{0, 0}]}, 
                {GrayLevel[0], RectangleBox[{1, -1}]}, 
                {RGBColor[
                 0.6402988781363921, 0.035330434441392944`, 
                  0.28001275709114415`], RectangleBox[{0, -1}, {2, 1}]}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.4268659187575947, 0.02355362296092863, 0.18667517139409612`],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.6402988781363921, 0.035330434441392944, \
0.28001275709114415]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.6402988781363921, 0.035330434441392944`, 
                   0.28001275709114415`]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.6402988781363921, 0.035330434441392944`, 0.28001275709114415`],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{
                {GrayLevel[0], RectangleBox[{0, 0}]}, 
                {GrayLevel[0], RectangleBox[{1, -1}]}, 
                {RGBColor[
                 0.4249737173056105, 0.08087713350797054, 0.5561568741925262],
                  RectangleBox[{0, -1}, {2, 1}]}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.2833158115370737, 0.053918089005313696`, 
                 0.37077124946168416`],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.4249737173056105, 0.08087713350797054, \
0.5561568741925262]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.4249737173056105, 0.08087713350797054, 
                   0.5561568741925262]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.4249737173056105, 0.08087713350797054, 0.5561568741925262],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{
                {GrayLevel[0], RectangleBox[{0, 0}]}, 
                {GrayLevel[0], RectangleBox[{1, -1}]}, 
                {RGBColor[
                 0.7495302686726302, 0.3453338459340154, 0.3119406215616949], 
                 RectangleBox[{0, -1}, {2, 1}]}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.4996868457817535, 0.23022256395601026`, 
                 0.20796041437446328`],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.7495302686726302, 0.3453338459340154, \
0.3119406215616949]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.7495302686726302, 0.3453338459340154, 0.3119406215616949]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.7495302686726302, 0.3453338459340154, 0.3119406215616949],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{
                {GrayLevel[0], RectangleBox[{0, 0}]}, 
                {GrayLevel[0], RectangleBox[{1, -1}]}, 
                {RGBColor[
                 0.836090631447431, 0.10393312541533217`, 0.9133348768403533],
                  RectangleBox[{0, -1}, {2, 1}]}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.5573937542982874, 0.06928875027688812, 0.6088899178935689],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.836090631447431, 0.10393312541533217, \
0.9133348768403533]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.836090631447431, 0.10393312541533217`, 
                   0.9133348768403533]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.836090631447431, 0.10393312541533217`, 0.9133348768403533],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{
                {GrayLevel[0], RectangleBox[{0, 0}]}, 
                {GrayLevel[0], RectangleBox[{1, -1}]}, 
                {RGBColor[
                 0.19151655035273674`, 0.14390156161230028`, 
                  0.5247101500257152], RectangleBox[{0, -1}, {2, 1}]}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.12767770023515784`, 0.09593437440820018, 
                 0.34980676668381017`],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.19151655035273674, 0.14390156161230028, \
0.5247101500257152]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.19151655035273674`, 0.14390156161230028`, 
                   0.5247101500257152]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.19151655035273674`, 0.14390156161230028`, 0.5247101500257152],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{
                {GrayLevel[0], RectangleBox[{0, 0}]}, 
                {GrayLevel[0], RectangleBox[{1, -1}]}, 
                {RGBColor[
                 0.8789399682999111, 0.042929493135203334`, 
                  0.19233219566452364`], RectangleBox[{0, -1}, {2, 1}]}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.5859599788666074, 0.028619662090135556`, 0.1282214637763491],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.8789399682999111, 0.042929493135203334, \
0.19233219566452364]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.8789399682999111, 0.042929493135203334`, 
                   0.19233219566452364`]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.8789399682999111, 0.042929493135203334`, 0.19233219566452364`],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{
                {GrayLevel[0], RectangleBox[{0, 0}]}, 
                {GrayLevel[0], RectangleBox[{1, -1}]}, 
                {RGBColor[
                 0.8279081820793655, 0.007601665021679249, 
                  0.007776314948584773], RectangleBox[{0, -1}, {2, 1}]}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.5519387880529103, 0.0050677766811195, 0.005184209965723182],
               
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.8279081820793655, 0.007601665021679249, \
0.007776314948584773]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.8279081820793655, 0.007601665021679249, 
                   0.007776314948584773]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.8279081820793655, 0.007601665021679249, 0.007776314948584773],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{
                {GrayLevel[0], RectangleBox[{0, 0}]}, 
                {GrayLevel[0], RectangleBox[{1, -1}]}, 
                {RGBColor[
                 0.8905220469868362, 0.6720465313460078, 0.8782899541874138], 
                 RectangleBox[{0, -1}, {2, 1}]}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.5936813646578909, 0.44803102089733854`, 0.5855266361249426],
               
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.8905220469868362, 0.6720465313460078, \
0.8782899541874138]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.8905220469868362, 0.6720465313460078, 0.8782899541874138]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.8905220469868362, 0.6720465313460078, 0.8782899541874138],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{
                {GrayLevel[0], RectangleBox[{0, 0}]}, 
                {GrayLevel[0], RectangleBox[{1, -1}]}, 
                {RGBColor[
                 0.4739838883353795, 0.01643240988333261, 0.7672816104627056],
                  RectangleBox[{0, -1}, {2, 1}]}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.31598925889025303`, 0.01095493992222174, 0.5115210736418038],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.4739838883353795, 0.01643240988333261, \
0.7672816104627056]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.4739838883353795, 0.01643240988333261, 
                   0.7672816104627056]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.4739838883353795, 0.01643240988333261, 0.7672816104627056],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{
                {GrayLevel[0], RectangleBox[{0, 0}]}, 
                {GrayLevel[0], RectangleBox[{1, -1}]}, 
                {RGBColor[
                 0.73262590528079, 0.4345872718612065, 0.9513218213654053], 
                 RectangleBox[{0, -1}, {2, 1}]}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.48841727018719333`, 0.289724847907471, 0.634214547576937],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.73262590528079, 0.4345872718612065, \
0.9513218213654053]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.73262590528079, 0.4345872718612065, 0.9513218213654053]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[0.73262590528079, 0.4345872718612065, 0.9513218213654053],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{
                {GrayLevel[0], RectangleBox[{0, 0}]}, 
                {GrayLevel[0], RectangleBox[{1, -1}]}, 
                {RGBColor[
                 0.7193138046226939, 0.736637476380962, 0.9909551197977506], 
                 RectangleBox[{0, -1}, {2, 1}]}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.4795425364151293, 0.49109165092064133`, 0.6606367465318338],
               
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.7193138046226939, 0.736637476380962, \
0.9909551197977506]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.7193138046226939, 0.736637476380962, 0.9909551197977506]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.7193138046226939, 0.736637476380962, 0.9909551197977506],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{
                {GrayLevel[0], RectangleBox[{0, 0}]}, 
                {GrayLevel[0], RectangleBox[{1, -1}]}, 
                {RGBColor[
                 0.5532261835871646, 0.1424067735626049, 0.6840947116434117], 
                 RectangleBox[{0, -1}, {2, 1}]}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.3688174557247764, 0.0949378490417366, 0.45606314109560786`],
               
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.5532261835871646, 0.1424067735626049, \
0.6840947116434117]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.5532261835871646, 0.1424067735626049, 0.6840947116434117]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.5532261835871646, 0.1424067735626049, 0.6840947116434117],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{
                {GrayLevel[0], RectangleBox[{0, 0}]}, 
                {GrayLevel[0], RectangleBox[{1, -1}]}, 
                {RGBColor[
                 0.24015696649735507`, 0.2276921291555416, 
                  0.5618669828113934], RectangleBox[{0, -1}, {2, 1}]}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.16010464433157007`, 0.15179475277036109`, 
                 0.37457798854092894`],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.24015696649735507, 0.2276921291555416, \
0.5618669828113934]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.24015696649735507`, 0.2276921291555416, 
                   0.5618669828113934]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.24015696649735507`, 0.2276921291555416, 0.5618669828113934],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{
                {GrayLevel[0], RectangleBox[{0, 0}]}, 
                {GrayLevel[0], RectangleBox[{1, -1}]}, 
                {RGBColor[
                 0.3614530023699991, 0.23838000474075272`, 0.351099450461986],
                  RectangleBox[{0, -1}, {2, 1}]}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.24096866824666607`, 0.1589200031605018, 
                 0.23406630030799067`],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.3614530023699991, 0.23838000474075272, \
0.351099450461986]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.3614530023699991, 0.23838000474075272`, 
                   0.351099450461986]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.3614530023699991, 0.23838000474075272`, 0.351099450461986],
            Editable->False,
            Selectable->False]}], "}"}]}], "}"}]], "ExerciseOutput",
       ExpressionUUID->"e8eba6a1-0e95-4997-955b-815c5e219d2f"],
      Apply[TextCell, 
       Cell[
        BoxData[
         RowBox[{"{", 
           RowBox[{
             RowBox[{"{", 
               RowBox[{
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}}, {{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8116438051434329, 0.8547919864863347, 
                    0.7807710853793401], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    RGBColor[
                    0.541095870095622, 0.5698613243242232, 
                    0.5205140569195601], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None, ImageCache -> 
                    GraphicsData[
                    "CompressedBitmap", 
                    "eJzzTSzJSM1NLMlMTlRwL0osyMhMLlZwyy8CCjEzMjAwcIGwAgOI/R/\
IhBIc\n/1+9vcv4/+WbO4z/X7y+DRRi/j9/6Yz/85aAMQMLiGT8P2fxNMb/67csZwQp\n\
Bytq72v6v2Xfuv+Hzu4G8g6c3gkkD53d9X/zvrX/5yyaxoBQ2Tmh5f/B07v+\n\
X753Gsi7eOcEkLx87+T/g2d2ga1AVXng1E6gmpNA3vlbxyHqQabTSSXITTB3\n\
ngS78xTYV5gqQX4Hqgb5/RTI7wfP7ASKrUVT2TWxFawaiIFBCSQZ/7f1NTGC\n\
ghimiBEA6jf2Gw=="]], 
                    "RGBColor[0.8116438051434329, 0.8547919864863347, \
0.7807710853793401]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.8116438051434329, 0.8547919864863347, 
                    0.7807710853793401]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.8116438051434329, 0.8547919864863347, 0.7807710853793401],
                   Editable -> False, Selectable -> False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}}, {{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.2983278570382957, 0.9907444932950316, 
                    0.9284043344039434], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    RGBColor[
                    0.19888523802553046`, 0.6604963288633544, 
                    0.6189362229359623], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None, ImageCache -> 
                    GraphicsData[
                    "CompressedBitmap", 
                    "eJzzTSzJSM1NLMlMTlRwL0osyMhMLlZwyy8CCjEzMjAwcIGwAgOI/R/\
IhBIc\n/9+8ucP4/zWIePH6NlCI+X/09tX/o7aBMQMLiGT8H751FeP/qkNbwSrBivSW\n\
zv5vf/fCf5d394E85zf3gCSQ/d/q3sX/YVtXMTCCDAarNF4257/767v//f5/\n\
BPJ8/78HkkD2f2egapAVaCpf3YGq8fn7FqIeZDqdVHoARdHd6fLuARaVznfO\n\
/Xd/cxfIA5oOIt/c/W8HDA80lSvm/TdePve/0bI5EH1AEsgGhx4wmOEqGQE1\nxe1R"]], 
                    "RGBColor[0.2983278570382957, 0.9907444932950316, \
0.9284043344039434]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.2983278570382957, 0.9907444932950316, 
                    0.9284043344039434]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.2983278570382957, 0.9907444932950316, 0.9284043344039434],
                   Editable -> False, Selectable -> False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}}, {{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}}, {{{{{{{
                    RGBColor[0.18676117011450066`, 0.5486089602170863, 
                    0.04303247680226141], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    RGBColor[
                    0.12450744674300045`, 0.3657393068113909, 
                    0.028688317868174273`], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None, ImageCache -> 
                    GraphicsData[
                    "CompressedBitmap", 
                    "eJzzTSzJSM1NLMlMTlRwL0osyMhMLlZwyy8CCjEzMjAwcIGwAgOI/R/\
IhBIc\n/9+8u8/4//Xbe4z/X7y+zcDA/t+nxpTxv0elIeP/vCmRYCmgQub/0hGM/1Ur\n\
WP5rNLICeRoNYLKR9b9CKQNQtQEDI8gksEqFGPb/us1c/w36uIE8g14w2ccN\n\
Vg00HF1lExdMTQ9UPch0eqkk2p1aVZwg1UAe0HQQCdSpWs6CrjKWHawaiBlY\n\
QCQjKOAYIYEKUcQIAKMnns0="]], 
                    "RGBColor[0.18676117011450066, 0.5486089602170863, \
0.04303247680226141]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.18676117011450066`, 0.5486089602170863, 
                    0.04303247680226141]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.18676117011450066`, 0.5486089602170863, 
                   0.04303247680226141], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}}, {{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.4044608902823441, 0.9788998961090443, 
                    0.8108975624714536], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    RGBColor[
                    0.2696405935215628, 0.6525999307393628, 
                    0.5405983749809691], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None, ImageCache -> 
                    GraphicsData[
                    "CompressedBitmap", 
                    "eJzzTSzJSM1NLMlMTlRwL0osyMhMLlZwyy8CCjEzMjAwcIGwAgOI/R/\
IhBIc\n/1+/ucsIJO4w/n/x+jZQiPl/5tY5QDz7f8bW2QwsIJLxf+rmWYz/Ww+uYvz/\n\
6s1dsCKHRe3/w29v+R/7+hCQF/vqIIh8feh/yJ2t/1O3zGQAmQlR6bKk83/i\n\
y4P/M/9dBvIy/lwEWfHv8v+4N4fAVqCqTHhxAKom/dd5iHqQ6XRSmfgKmzsP\n\
Y1EZdWvL/4SXIF8DTQeRQB+G396KptJ1Wdd/l6WdIB3AoASSjP8dFrczgoIY\npogRANi76cs="]],
                     "RGBColor[0.4044608902823441, 0.9788998961090443, \
0.8108975624714536]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.4044608902823441, 0.9788998961090443, 
                    0.8108975624714536]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.4044608902823441, 0.9788998961090443, 0.8108975624714536],
                   Editable -> False, Selectable -> False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}}, {{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.5308001574813235, 0.9503472359039511, 
                    0.8646083755834806], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    RGBColor[
                    0.35386677165421565`, 0.6335648239359675, 
                    0.5764055837223204], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None, ImageCache -> 
                    GraphicsData[
                    "CompressedBitmap", 
                    "eJzzTSzJSM1NLMlMTlRwL0osyMhMLlZwyy8CCjEzMjAwcIGwAgOI/R/\
IhBIc\n/1+/ucP4/xWIePH6NgMD0//KTYtZgcQixv9lGxYy/p+4bz1YHqia+X/ovAn/\n\
i68c+F/z5DyQV/3oLJAEsv8XXj0IUs3ACDIOrDJywaT/dY/O/u/89gDI6/hy\n\
D0gC2f9rHp8DGY6msvbhGaia9k93IOpBptNJZR3QTRjuBPoKU2Xp5QNAX50D\n\
8oCmA0kgGxweqCqjFk3+H7lwEkgHAwuIZPwfOn8CIyhkYYoYAR1x61Q="]], 
                    "RGBColor[0.5308001574813235, 0.9503472359039511, \
0.8646083755834806]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.5308001574813235, 0.9503472359039511, 
                    0.8646083755834806]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.5308001574813235, 0.9503472359039511, 0.8646083755834806],
                   Editable -> False, Selectable -> False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}}, {{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.5926608241659339, 0.4671421812435703, 
                    0.027570072930602985`], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    RGBColor[
                    0.3951072161106226, 0.3114281208290469, 
                    0.01838004862040199], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None, ImageCache -> 
                    GraphicsData[
                    "CompressedBitmap", 
                    "eJy9kLEOgkAMhq9BgvEpeAMdfAZNSNTZzROIkAgokqiLURzFWXw2E12NR\
F+h\ntgeLTk4O/fO397V3155MPDeQiW9LsxvLmefbC7MTxVTSQAjR4DAFeyRbSR2L\n\
1w3w8bwC3osLlTRM523clSFqrICbsAWYZ0NFKkhaAlMHMAuAssOUlTxux4Lo\n\
pgAerEinr+MxMvC8NijLV6zkFc1XfJJZaFTMaVnxPP1P5O/v3E8MpvnXISt3\n\
pu436Q50RVPQKkkBRxadp7zUEoI3ltyzyA=="]], 
                    "RGBColor[0.5926608241659339, 0.4671421812435703, \
0.027570072930602985]"], Appearance -> None, BaseStyle -> {}, 
                   BaselinePosition -> Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.5926608241659339, 0.4671421812435703, 
                    0.027570072930602985`]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.5926608241659339, 0.4671421812435703, 
                   0.027570072930602985`], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}}, {{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.49843743964638865`, 0.7588128836239783, 
                    0.6588996785867525], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    RGBColor[
                    0.3322916264309258, 0.5058752557493189, 
                    0.43926645239116835`], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None, ImageCache -> 
                    GraphicsData[
                    "CompressedBitmap", 
                    "eJzzTSzJSM1NLMlMTlRwL0osyMhMLlZwyy8CCjEzMjAwcIGwAgOI/R/\
IhBIc\n/1+/vcv4/xWIePH6NgMD+//SGe2M/4umtTL+71s1EywFVMj8P6A253/O8on/\n\
S7fOBfJKNs8GkqVb5vzPWj4BpJqBEWQSWGVIQ/7/8i1z/zceWQ3kNRxaCSQb\n\
D68CqwYajqaybPOc/w2HVwF59QdXQNSDTKeTSrA7j64BqQGrB7oZhzvzV0z6\n\
Xw72O9B0IAnSCQ4PFJWhjQVg1UDMwAIiGUEBxwgJVIgiRgB+pNRf"]], 
                    "RGBColor[0.49843743964638865, 0.7588128836239783, \
0.6588996785867525]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.49843743964638865`, 0.7588128836239783, 
                    0.6588996785867525]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.49843743964638865`, 0.7588128836239783, 
                   0.6588996785867525], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}}, {{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.6788691428209239, 0.8865118691450595, 
                    0.06859340947663295], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    RGBColor[
                    0.4525794285472826, 0.5910079127633731, 
                    0.04572893965108864], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None, ImageCache -> 
                    GraphicsData[
                    "CompressedBitmap", 
                    "eJzzTSzJSM1NLMlMTlRwL0osyMhMLlZwyy8CCjEzMjAwcIGwAgOI/R/\
IhBIc\n/1+9vc/4/9Wbe4z/X7y+DRRi/t+70vJ/DwQzsIBIxv9dK0wZ/y/cHgNU+fYe\n\
WFH+FLb/U49y/V94hRvIW3AZRALZ/6ccY/nftdyUAaTyPlhl0TSe/wsvC/zf\n\
8EwQyFv3BESufyYIVg2yAlXlgksC/9eD1ax9BFUPMp1OKhdeEfi/EexOiPoN\n\
IHdexaZy2lH+/4suC4D8fglEgnw4DRgeqCqLp/OAVRdN5YHoA5FTecCh14uk\nkhEADTzQcQ=="]],
                     "RGBColor[0.6788691428209239, 0.8865118691450595, \
0.06859340947663295]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.6788691428209239, 0.8865118691450595, 
                    0.06859340947663295]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.6788691428209239, 0.8865118691450595, 
                   0.06859340947663295], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}}, {{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.3966954095359472, 0.9303983446364068, 
                    0.27133513969525125`], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    RGBColor[
                    0.26446360635729815`, 0.6202655630909379, 
                    0.18089009313016752`], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None, ImageCache -> 
                    GraphicsData[
                    "CompressedBitmap", 
                    "eJzzTSzJSM1NLMlMTlRwL0osyMhMLlZwyy8CCjEzMjAwcIGwAgOI/R/\
IhBHM\n/1+/vff/9RswZmABkYxA4j4jhPXi9W0GBvb/6etDGP+nrA1g/N+8p4jx/6u3\n\
d4Gamf/bzdL8H3re4n/0fVsgL/quDYi8b/s/6ILJ/+S1AQxgQ8Aqnebo/Y+/\n\
6/A//aM7kJf23g1IAtn/Y+7ZgAxHUxl3xwGqJvWtK0Q9yHQ6qYy/h8WdQF9h\n\
qow4Z/M/7q4jkAc0HUTedQSHB6pK53l6/53m6oF0AAMYSDL+t5utyQgJVGDo\nAxUxAgAU/tQn"]],
                     "RGBColor[0.3966954095359472, 0.9303983446364068, \
0.27133513969525125]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.3966954095359472, 0.9303983446364068, 
                    0.27133513969525125`]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.3966954095359472, 0.9303983446364068, 
                   0.27133513969525125`], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}}, {{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}}, {{{{{{{
                    RGBColor[0.7496777159050012, 0.8414031368083361, 
                    0.29000881481349006`], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    RGBColor[
                    0.4997851439366675, 0.5609354245388908, 
                    0.19333920987566006`], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None, ImageCache -> 
                    GraphicsData[
                    "CompressedBitmap", 
                    "eJzzTSzJSM1NLMlMTlRwL0osyMhMLlZwyy8CCjEzMjAwcIGwAgOI/R/\
IhBIc\n/1+9vcf4/9UbIPHi9W0GBvb/0xaHMf6fvDCI8f+KzcVAqbd3gQqZ/1f36Pxf\n\
utv2/+ZTTkDexhOOQHLTKSegmOX/KQuDGEAq74FV1vUZ/t90wvX/ods+QN6B\n\
m95A8uBtn/+bTjqCDEdTufG46/+DYDX7r3tB1INMp5PKTSfd/h8GuxOi/hDI\n\
nUBfYapcttvx/+aTriC/HweRm066Av1ug6ayvt8QrLquzwCiD0wagEMPWSUj\nAKhj1Qs="]], 
                    "RGBColor[0.7496777159050012, 0.8414031368083361, \
0.29000881481349006]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.7496777159050012, 0.8414031368083361, 
                    0.29000881481349006`]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.7496777159050012, 0.8414031368083361, 
                   0.29000881481349006`], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}}, {{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.1722869702422274, 0.42066881136044554`, 
                    0.18877704427888808`], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    RGBColor[
                    0.11485798016148493`, 0.28044587424029704`, 
                    0.12585136285259207`], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None, ImageCache -> 
                    GraphicsData[
                    "CompressedBitmap", 
                    "eJy9kMEKgkAQhneyIHqBDhWsYGGh0DuEmYfOQRC0WKCoFNZD9I6BXQPLV\
5hm\nFrt46tRhfuaf+fZnmbW6RsdMXeNQST9X5ygOL3J5ymlkgBCixyUF90htLV18\n\
VQ/AsioAn+VdiBYGadDBIAkAvcgDTG8x7d8F0Qb2FwM0txO0lE3O2mtVNg43\n\
JtMCOE6TI1/i9OCik83JOanWbK5pCm+Softlkprn9H+RP/9zspsxTY7SWeml\n\
uR03yZXUNJVoswIfDviyXwg+4WWg0g=="]], 
                    "RGBColor[0.1722869702422274, 0.42066881136044554, \
0.18877704427888808]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.1722869702422274, 0.42066881136044554`, 
                    0.18877704427888808`]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.1722869702422274, 0.42066881136044554`, 
                   0.18877704427888808`], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}}, {{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.020568097401979735`, 0.32843933224376776`, 
                    0.2578912775452169], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    RGBColor[
                    0.013712064934653156`, 0.2189595548291785, 
                    0.17192751836347794`], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None, ImageCache -> 
                    GraphicsData[
                    "CompressedBitmap", 
                    "eJzzTSzJSM1NLMlMTlRwL0osyMhMLlZwyy8CCjEzMjAwcIGwAgOI/R/\
IhBLs\n/9++v8cIJO4z/n/zDsh68fo2AwP7f9P4IMb/xtF+jP9j6gpAUneBqpn/Mxip\n\
/2dwNf3P4G0F4nlZgkhvy/8Mjob/DaL9GEAm3QOrZDbX+c/qZ/ufNcwFyGMN\n\
dQKRYU5g1UDDsakMdQapCXGCqAeZTi+V/gh3gtWHOeNyp6clULUdSI2fLYgE\n\
6gSFB5JKpv/MFjqsINWM/xmM1RkhQQkxhBEAudWXww=="]], 
                    "RGBColor[0.020568097401979735, 0.32843933224376776, \
0.2578912775452169]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.020568097401979735`, 0.32843933224376776`, 
                    0.2578912775452169]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.020568097401979735`, 0.32843933224376776`, 
                   0.2578912775452169], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}}, {{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.4276762158276948, 0.9445301871184215, 
                    0.6339408432442302], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    RGBColor[
                    0.2851174772184632, 0.629686791412281, 
                    0.4226272288294868], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None, ImageCache -> 
                    GraphicsData[
                    "CompressedBitmap", 
                    "eJzzTSzJSM1NLMlMTlRwL0osyMhMLlZwyy8CCjEzMjAwcIGwAgOI/R/\
IhBIc\n/1+/ucv4/xWIePH6NgMD+/+cjS2M/zPXNzH+b983HSwFVMj832Vuxv+Yyz3/\n\
kx9PA/KSHoJIIPt/5OVukGoGRpBJYJUe87P/pz2c/j//6xIgL+/zYiAJZP9P\n\
fjQdZDiaytQH06Bqcj8ugqgHmU4nlWmPsLjzMTZ3xl/qBfkKyAOaDiRBPgSF\n\
B6pKz4U5/z0WZIN0MLCASMb/LvMyGCGBClHECACYENjC"]], 
                    "RGBColor[0.4276762158276948, 0.9445301871184215, \
0.6339408432442302]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.4276762158276948, 0.9445301871184215, 
                    0.6339408432442302]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.4276762158276948, 0.9445301871184215, 0.6339408432442302],
                   Editable -> False, Selectable -> False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}}, {{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.3449333805776824, 0.8214093187031501, 
                    0.00535396147946221], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    RGBColor[
                    0.22995558705178828`, 0.5476062124687668, 
                    0.003569307652974807], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None, ImageCache -> 
                    GraphicsData[
                    "CompressedBitmap", 
                    "eJy9kM0KQVEUhff2k/\
IU9wEMGDBgjAxQlFAGp5tiIMLclHgG8QgGPIDrBSQj\n\
xVQuz7DsrWtAxgZntfY531qddt4MW82OGbZtY2X7ptdq2wMr0+3LlZ+JKKzH\n\
IvUQ60kI7uPCuKu49zPj6p6IfDDLWBBmEWM05lHGaFVh3B5nifgRnxByG0Jx\n\
p1Nhqyoe6TUJHSHWzheZnDLKDqN+ZJlqB1XxKDqk5V9kacseU917vLb/ifz5\n\
z90vMr+RXkcZaVeVpO7jk0zNGCmhJUEBVUZiLO+y2TfET1Zat4A="]], 
                    "RGBColor[0.3449333805776824, 0.8214093187031501, \
0.00535396147946221]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.3449333805776824, 0.8214093187031501, 
                    0.00535396147946221]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.3449333805776824, 0.8214093187031501, 
                   0.00535396147946221], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}}, {{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.9595114792486563, 0.9614567195621035, 
                    0.09956803288245264], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    RGBColor[
                    0.6396743194991042, 0.6409711463747357, 
                    0.06637868858830176], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None, ImageCache -> 
                    GraphicsData[
                    "CompressedBitmap", 
                    "eJy9kDEOgkAQRXeDhVELl0JixzUsbLXyDhJigoXRIPcR8AKCvZ5CLUykA\
ESj\nLSFU48wGC62sLObnz+TtzOaPDMeazAxnahr60DYW1tRc6oO5jSOFM8YaVDoj\n\
D2grqcP9GXGUC4fb44wjBcJtH8JQFquRctgEPQ67/ViSElqtWnA8tiG7qtil\n\
KSl6OJ2aEAQ9RmQkSc8TkCQalGUXu6IgRQ9ZpsoTn2QcaxWT5xVP2/9Epumv\n\
/zwcOkRjh9tlAhrmIb7I9VqA7wt6gVGicnDdFqeI3xB/AbUZ4RI="]], 
                    "RGBColor[0.9595114792486563, 0.9614567195621035, \
0.09956803288245264]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.9595114792486563, 0.9614567195621035, 
                    0.09956803288245264]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.9595114792486563, 0.9614567195621035, 
                   0.09956803288245264], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}}, {{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.13927723404143122`, 0.9837658758454813, 
                    0.6275322853052734], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    RGBColor[
                    0.09285148936095415, 0.6558439172303209, 
                    0.41835485687018226`], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None, ImageCache -> 
                    GraphicsData[
                    "CompressedBitmap", 
                    "eJzzTSzJSM1NLMlMTlRwL0osyMhMLlZwyy8CCjEzMjAwcIGwAgOI/R/\
IhBIc\n/9+8ucv4/zWIePH6NgMD+3/Xbc2M/x23NDL+zzw0DSwFVMj8X2hJ+n+pO13/\n\
Zd5MBfJkXk8BkW+m/he52/nfcWsjAyPIJLBKiaVZ/xVfTf2v8n8RkKfydyGI\n\
/L/ov8zbqSDD0VW+nAJT83sBRD3IdHqpfE2sO+Vvd4N8BeQBTQeRQB+CwgNN\n\
5fLs/xLLskA6GFhAJCMo4BghgQpRxAgA9sTMoQ=="]], 
                    "RGBColor[0.13927723404143122, 0.9837658758454813, \
0.6275322853052734]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.13927723404143122`, 0.9837658758454813, 
                    0.6275322853052734]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.13927723404143122`, 0.9837658758454813, 
                   0.6275322853052734], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}}, {{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.4129872979782936, 0.599123151026224, 
                    0.5563798982651478], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    RGBColor[
                    0.2753248653188624, 0.3994154340174827, 
                    0.3709199321767652], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None, ImageCache -> 
                    GraphicsData[
                    "CompressedBitmap", 
                    "eJy9kMEKgkAQhncoKHoKX8VDduoYFEK2itEWUVRQSIdw9ah2zR4tukdir\
zDN\naKdOnTrMx/zLtz/L9uVu5i/lTnnS6G3keqa8rWGtNnTUACFEh8cQvCOtH7Sx\n\
eN0Bi5LwKG5CtFDpAHB6OgDGeQb4LO8kNtB0bRzqAJ1EU3KSsKLGQXggey+A\n\
myqz64/RzWJcXM+U5nlGpB0nqebyL1Om0cdRl7T2uf1P5u/vtOMj25Soncg3\n\
R1HwZVpTp7JpRJMJaEob6k+tJXgD7z7ECA=="]], 
                    "RGBColor[0.4129872979782936, 0.599123151026224, \
0.5563798982651478]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.4129872979782936, 0.599123151026224, 
                    0.5563798982651478]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.4129872979782936, 0.599123151026224, 0.5563798982651478], 
                  Editable -> False, Selectable -> False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}}, {{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.5517409716001453, 0.7226268672047083, 
                    0.04296745155978088], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    RGBColor[
                    0.3678273144000969, 0.48175124480313886`, 
                    0.028644967706520585`], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None, ImageCache -> 
                    GraphicsData[
                    "CompressedBitmap", 
                    "eJzzTSzJSM1NLMlMTlRwL0osyMhMLlZwyy8CCjEzMjAwcIGwAgOI/R/\
IhBIc\n/1+/vc/4/9Xbe4z/X7y+zcDA/r9msinj/8qJhoz/pyyLBEsBFTL/jywHii5g\n\
+d+0hhXIa1wFIptWs/4vm8cAVG3AwAgyCawytor9f8sarv/9u7mBvL6dILJ/\n\
FzdYNdBwNJXNq7n+9+0CqendAVUPMp1OKsHu3ANWA1YPdDMOd1Yv5ASpBvKA\n\
pgPJFqAdFfNZ0FTGVbODVQMxAwuIZAQFHCMkUCGKGAGne7gp"]], 
                    "RGBColor[0.5517409716001453, 0.7226268672047083, \
0.04296745155978088]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.5517409716001453, 0.7226268672047083, 
                    0.04296745155978088]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.5517409716001453, 0.7226268672047083, 
                   0.04296745155978088], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}}, {{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.2471012449687613, 0.6622219052252245, 
                    0.34136700529740893`], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    RGBColor[
                    0.16473416331250754`, 0.4414812701501497, 
                    0.22757800353160595`], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None, ImageCache -> 
                    GraphicsData[
                    "CompressedBitmap", 
                    "eJzzTSzJSM1NLMlMTlRwL0osyMhMLlZwyy8CCjEzMjAwcIGwAgOI/R/\
IhBIc\n/9+8vcf4/zWIePH6NlCI+X9IT+z/4G4wZmABkYz/AzqjGP+XLKwEqbwLVqSa\n\
a/rfaJLnf/N5fkCe2RwwOdfvv95E1//+nVEMjCCDwSq1Ciz/W80L+u+wJhLI\n\
s18VASJXRwJV+4OtQFM5N/C/w2qwmpXhEPUg0+mlEuhOx7Ugd0LUA92Mw53m\n\
k33+W88LBPKApoPIeYHg8EBTWWgFVA3ClsCgBJKMwIAzYwQFMUwRIwBLSbvK\n"]], 
                    "RGBColor[0.2471012449687613, 0.6622219052252245, \
0.34136700529740893]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.2471012449687613, 0.6622219052252245, 
                    0.34136700529740893`]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.2471012449687613, 0.6622219052252245, 
                   0.34136700529740893`], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}}, {{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.00852878273374924, 0.7623891609381206, 
                    0.495048201930645], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    RGBColor[
                    0.005685855155832828, 0.5082594406254137, 
                    0.33003213462043], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None, ImageCache -> 
                    GraphicsData[
                    "CompressedBitmap", 
                    "eJzzTSzJSM1NLMlMTlRwL0osyMhMLlZwyy8CCjEzMjAwcIGwAgOI/R/\
IhBIc\n/9++vcf4/83bu4z/X7y+DRRi/m88swiIC0GYgQVEMv43npbH+D96dSdYJVgR\n\
Q13Af4YVOf8ZtpWAeFuKQeTWEqBY5n+96XkMjCCDwSoZG4P/M20t+890tAHI\n\
YzpcDyKPNIBVg6xAU7mlFCgLVnOoDqIeZDq9VILceQzsToj6ozjduTLvP9O2\n\
MpCaLaUgEqiTYUU2usqmELBqIAYGJZBkBAacPyMoiGGKGAHkFLyi"]], 
                    "RGBColor[0.00852878273374924, 0.7623891609381206, \
0.495048201930645]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.00852878273374924, 0.7623891609381206, 
                    0.495048201930645]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.00852878273374924, 0.7623891609381206, 0.495048201930645],
                   Editable -> False, Selectable -> False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}}, {{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.410530117230961, 0.65951899493187, 
                    0.31274019237510875`], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    RGBColor[
                    0.2736867448206407, 0.43967932995458003`, 
                    0.20849346158340584`], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None, ImageCache -> 
                    GraphicsData[
                    "CompressedBitmap", 
                    "eJzzTSzJSM1NLMlMTlRwL0osyMhMLlZwyy8CCjEzMjAwcIGwAgOI/R/\
IhBKc\n/1+/vcf4/8Xr2wwM7P8zuyMZ/6d1hDL+b11Qyvj/1du7QDXM/x1zDP5HTHT6\n\
Hz/XA8iLn+0OIud4/A+dYAdSzcAIMgSs0jXf5H/SXK//2auDgLyslYFAMntV\n\
0P8EoGqg4WgqE+d4/c9aBVKTuSIAoh5kOp1UJs31/p+9BuxOsHqgm3G4M3qS\n\
K0g1kAc0HUiCdEYCwwNVpVuBKVA1CJswsIBIRlDAMUICFaKIEQAxM7eZ"]], 
                    "RGBColor[0.410530117230961, 0.65951899493187, \
0.31274019237510875]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.410530117230961, 0.65951899493187, 
                    0.31274019237510875`]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.410530117230961, 0.65951899493187, 0.31274019237510875`], 
                  Editable -> False, Selectable -> False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}}, {{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.14914425266109754`, 0.8632288046219025, 
                    0.2165769996518021], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    RGBColor[
                    0.09942950177406504, 0.575485869747935, 
                    0.14438466643453474`], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None, ImageCache -> 
                    GraphicsData[
                    "CompressedBitmap", 
                    "eJzzTSzJSM1NLMlMTlRwL0osyMhMLlZwyy8CCjEzMjAwcIGwAgOI/R/\
IhBIc\n/9+8vc/4//Wbe4z/X7y+zcDA/t9tmS/jf6clnoz/M7fmAKXe3gMqZP4vPEHh\n\
v8wBnf9y5/WBPLmzYPK8/n+xA+og1QyMIJPAKiUnqf5XPmv8X+2BOZCndg9M\n\
PjD/L3dOH2Q4usozxjA1d6DqQabTS+U5LO48j02l4gEDkGogD2g6iATqBIUH\n\
msrJqmDVQMzAAiIZQQHHCAlUiCJGAJNns/w="]], 
                    "RGBColor[0.14914425266109754, 0.8632288046219025, \
0.2165769996518021]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.14914425266109754`, 0.8632288046219025, 
                    0.2165769996518021]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.14914425266109754`, 0.8632288046219025, 
                   0.2165769996518021], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}}, {{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.5019554020533212, 0.5771425709059108, 
                    0.4324648041012522], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    RGBColor[
                    0.3346369347022142, 0.3847617139372739, 
                    0.2883098694008348], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None, ImageCache -> 
                    GraphicsData[
                    "CompressedBitmap", 
                    
                    "eJzzTSzJSM1NLMlMTlRwL0osyMhMLlZwyy8CCjEzMjAwcIGwAgOI/R/\
IhBIc\n/1+/u8f4/9Xbu4z/X7y+zcDA/r+0IYvxf1FtGuP/vunNYCmgQub/AbGu/3Pr\n\
Yv+XdqQCeaXtKSCyI/V/dk00UHU6AyPIJLDKkETP/xWd6f+bphYAeY1T8oEk\n\
kP2/DKgaaDiayvKONKiahsl5EPUg0+mkknh3FjQk/C/vTAfygKaDSKBOcHig\n\
qAxN8gKrBmIGFhDJCAo4RkigQhQxAgAPCcFR"]], 
                    "RGBColor[0.5019554020533212, 0.5771425709059108, \
0.4324648041012522]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.5019554020533212, 0.5771425709059108, 
                    0.4324648041012522]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.5019554020533212, 0.5771425709059108, 0.4324648041012522],
                   Editable -> False, Selectable -> False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}}, {{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.2375846642639532, 0.7953276430316651, 
                    0.9346352336682711], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    RGBColor[
                    0.1583897761759688, 0.5302184286877768, 
                    0.6230901557788474], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None, ImageCache -> 
                    GraphicsData[
                    "CompressedBitmap", 
                    "eJzzTSzJSM1NLMlMTlRwL0osyMhMLlZwyy8CCjEzMjAwcIGwAgOI/R/\
IhBIc\n/9+8vcP4/zWIePH6NgMD+/+guWsY//vNWsX4v3jdNrAUUCHzf+XmOf8NNlz8\n\
b7rvAZBnsuc+iNz34L/O+kv//WavZmAEmQRWqdE297/F3nv/7c5/AvJsz34A\n\
kec//TfZ+wBkOLrKPXf/20HUnH4HUQ8ynV4q997/bw92J0S9Hcid+x5iUWm6\n\
4fx/y333gDyg6SBy3z1weKCpbJ8PVD0PpIOBBUQyggKOERKoEEWMACn61t0=\n"]], 
                    "RGBColor[0.2375846642639532, 0.7953276430316651, \
0.9346352336682711]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.2375846642639532, 0.7953276430316651, 
                    0.9346352336682711]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.2375846642639532, 0.7953276430316651, 0.9346352336682711],
                   Editable -> False, Selectable -> False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}}, {{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.5670638896981823, 0.30694748662903737`, 
                    0.07724772234151844], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    RGBColor[
                    0.3780425931321216, 0.2046316577526916, 
                    0.0514984815610123], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None, ImageCache -> 
                    GraphicsData[
                    "CompressedBitmap", 
                    "eJzzTSzJSM1NLMlMTlRwL0osyMhMLlZwyy8CCjEzMjAwcIGwAgOI/R/\
IhBIc\n/1+/v8/4/9W7e4z/X7y+zcDA/r8uxorxf1WEKeP/qdWxYCmgQub/0Xrs/2sc\n\
eP63ufICea1gEsj+X2XD9r86woyBEWQSWGW8Me//dg+h/5MDRIC8Sf4gEsgG\n\
qwYajqayDagSomaiH1Q9yHQ6qWz3xOJON2wq61wEQapBvvYAkSCdoPBAVZlg\n\
wvs/HoSNeRlYQCTj/2h9dkZIoEIUMQIAa8em4w=="]], 
                    "RGBColor[0.5670638896981823, 0.30694748662903737, \
0.07724772234151844]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.5670638896981823, 0.30694748662903737`, 
                    0.07724772234151844]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.5670638896981823, 0.30694748662903737`, 
                   0.07724772234151844], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}}, {{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.9836330486106633, 0.9337141420685637, 
                    0.45110780147188234`], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    RGBColor[
                    0.6557553657404422, 0.6224760947123759, 
                    0.30073853431458825`], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None, ImageCache -> 
                    GraphicsData[
                    "CompressedBitmap", 
                    "eJy9kD1uwkAQhXdkaHIKnwYo4AzIgUgsEIHAuUFuwU8aknQGCSiRuEGgh\
jWU\ncYwRSovQY2YJBRJ1inl6s/p2dvYVPL/y9Oz5uuS52ZbXrOhS2800WnzkkFLq\n\
QcpV4sH2Kg6iJES0s6XSosRiCN/xigkH01Ed06EtlRIljANNmM9emUyMhQad\n\
HNaLR+y2mrs4FGUPsyxiEmhFdryQ7708fsI68PvC3engs7JHsqnaJ27JyNT+\n\
mOO+feFl+j+R8ebOntt7e66+yvyrmsRpRNnbPG7Jz7cCPvp5ucFRshIG3RxJ\n\
xBKlQHQGDkP9TA=="]], 
                    "RGBColor[0.9836330486106633, 0.9337141420685637, \
0.45110780147188234]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.9836330486106633, 0.9337141420685637, 
                    0.45110780147188234`]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.9836330486106633, 0.9337141420685637, 
                   0.45110780147188234`], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}}, {{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.548151102001315, 0.9273818734933321, 
                    0.6138604019189067], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    RGBColor[
                    0.3654340680008767, 0.6182545823288881, 
                    0.4092402679459378], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None, ImageCache -> 
                    GraphicsData[
                    "CompressedBitmap", 
                    "eJy9kEEOwVAQhuelROIUPQ0re4taNIhaCCmiYUFJsECC2KCcQFzAGTiAt\
mtR\nxA3GTMuCdG0xf/5575s/k0mpNS1fUmvFrCondbWiFbNVOVHW6UkSABDnkoE9\n\
kv2IhN7dQe/mF0RZBV5ZLt4ZIIatvSnQ2LUFzg8L+ro7NCdheplD4zhA051S\n\
17FZyWP91GcahJ/HpLIuYM+e4eS5pW782JCSR9OZcfgP2T1P38zoZgU8p/+J\n\
7Dkhe7phezaPQ6apo3RSnmzQPb7JzEZDxSrwBERYBaZXOREc1fNPKV6Mk+ej\n"]], 
                    "RGBColor[0.548151102001315, 0.9273818734933321, \
0.6138604019189067]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.548151102001315, 0.9273818734933321, 
                    0.6138604019189067]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.548151102001315, 0.9273818734933321, 0.6138604019189067], 
                  Editable -> False, Selectable -> False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}}, {{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.08996343949980967, 0.7502285322367264, 
                    0.7647837622874905], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    RGBColor[
                    0.05997562633320645, 0.5001523548244843, 
                    0.5098558415249936], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None, ImageCache -> 
                    GraphicsData[
                    "CompressedBitmap", 
                    "eJzzTSzJSM1NLMlMTlRwL0osyMhMLlZwyy8CCjEzMjAwcAMxlwIDiP0fy\
IQS\nHP/fvL3LCCTuMP5/8fo2mGBgYP9vN30qA/N/q2lT/scuW/T/1Zs7DFApoChn\n\
Tf1/vmWr/gts3g7kCWzcysDyX2DTtv9cK9b8N5w4Eaj6NkIxf33jf1GgpPih\n\
Y0Ce+IEjQMXiB4/+F9y687/ZlMlYFG/cClIAUrz/MEjxgSP/BbfsoLtikJsP\n\
HwcpBmphAbkf6OZd2BWLAENDdPM2IE8UHBogzfzA0MBU3NAE1gDEQGUgkvk/\n\
V239f7PJk1ACmREAHGzqDA=="]], 
                    "RGBColor[0.08996343949980967, 0.7502285322367264, \
0.7647837622874905]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.08996343949980967, 0.7502285322367264, 
                    0.7647837622874905]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.08996343949980967, 0.7502285322367264, 
                   0.7647837622874905], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}}, {{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.9554445238224603, 0.9118174885785313, 
                    0.7586039763217882], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    RGBColor[
                    0.6369630158816402, 0.6078783257190209, 
                    0.5057359842145255], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None, ImageCache -> 
                    GraphicsData[
                    "CompressedBitmap", 
                    "eJzzTSzJSM1NLMlMTlRwL0osyMhMLlZwyy8CCjEzMjAwcAMxlwIDiP0fy\
IQS\nTP9fvr3L+v/lm7sMzCAmkHXn/4vXtxkYwSQDUHTjmqlAPAWEGVjAJPP/9asn\n\
/9+9feH/F2/uIKmcN73u/9XTK/4/u70VyHtyczOQfHZry/+b51b9X7tiAgMT\n\
XOWCmQ3/H9/c8v/H2yNA3rfXh4DkjzeH/7+8u/3/+lWT0FQ+urEZqOYwkPfl\n\
5UGQ+leH/j+/s41OKp/cArnzKNidh8HuPPL/5T1s7rwC9PuTWyC/A00Hh8CW\n\
/9fPrkJTuWh24/+FsxpAOoDhCSKZ/8+fUfd//cqJKOHJCABJWxEB"]], 
                    "RGBColor[0.9554445238224603, 0.9118174885785313, \
0.7586039763217882]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.9554445238224603, 0.9118174885785313, 
                    0.7586039763217882]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.9554445238224603, 0.9118174885785313, 0.7586039763217882],
                   Editable -> False, Selectable -> False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}}, {{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.12407876246761118`, 0.8951986963374581, 
                    0.405054951518828], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    RGBColor[
                    0.08271917497840746, 0.5967991308916387, 
                    0.2700366343458853], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None, ImageCache -> 
                    GraphicsData[
                    "CompressedBitmap", 
                    "eJzzTSzJSM1NLMlMTlRwL0osyMhMLlZwyy8CCjEzMjAwcAMxlwIDiP0fy\
IQS\nHP/fvL3H+P/1m7uM/1+8vg0mGBjY/zuvSmNg/m+/Ivl/4rbq/y/f3GGASgFF\n\
+ac4/Bc/HvZf4lockCdxNZaBBUjG/Rc6GfbfbFns/5ev7yAUi05z+S93JeG/\n\
wotMIE/hWQZQscLzzP9SNxL+W69IwKL4cjxYGVDxk3SQ4qcZ/6Wux9Nd8VUs\n\
br6Jw80yxyJBGoA8ucsJQMUgD0ucjMSieIbrf9HpLiBNQGUgkvm/wFTH/9bL\n\
E1ACmREAdJ/hUw=="]], 
                    "RGBColor[0.12407876246761118, 0.8951986963374581, \
0.405054951518828]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.12407876246761118`, 0.8951986963374581, 
                    0.405054951518828]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.12407876246761118`, 0.8951986963374581, 
                   0.405054951518828], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}}, {{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.3518853673765441, 0.6267881822227646, 
                    0.01601455063963053], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    RGBColor[
                    0.23459024491769606`, 0.41785878814850974`, 
                    0.010676367093087022`], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None, ImageCache -> 
                    GraphicsData[
                    "CompressedBitmap", 
                    "eJzzTSzJSM1NLMlMTlRwL0osyMhMLlZwyy8CCjEzMjAwcAMxlwIDiP0fy\
IQR\nzP9fv7v///VbMGZgAZMIsRevbzMwgkkGpv9J7Uas/xPbjYDycS0G/6tmBv5/\n\
+eYuTB4oap7O8N+rk+F/4BQQL2AyA9A8IPu/ZxfD//AGVZBqhGLrLOb/IVNZ\n\
/scsYgHyoheyMIDZ/4OnM/yPbtbCVBw8hQWsjPl/1AKQYiD7f9A0uismyc1+\n\
3SwgDQxgOxjA7P8+PVgU22QDcRZYE1AZiIQEZ3STFkogMwIAd+HeOA=="]], 
                    "RGBColor[0.3518853673765441, 0.6267881822227646, \
0.01601455063963053]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.3518853673765441, 0.6267881822227646, 
                    0.01601455063963053]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.3518853673765441, 0.6267881822227646, 
                   0.01601455063963053], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}}, {{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.38175543134617906`, 0.6109792496345561, 
                    0.30321055377645356`], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    RGBColor[
                    0.2545036208974527, 0.4073194997563707, 
                    0.2021403691843024], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None, ImageCache -> 
                    GraphicsData[
                    "CompressedBitmap", 
                    "eJzzTSzJSM1NLMlMTlRwL0osyMhMLlZwyy8CCjEzMjAwcAMxlwIDiP0fy\
IQS\nHP9fv7vH+P/1WyDx4vVtMAEUZ/6f1hr5P7UlAoQZWMAk8/+kptD/tdML/r98\n\
c4cBodImRf9/YKv9/4gJrkBeeL8LUH3EBJf//u12/6Nr/UCqEYod0o3/R090\n\
/588zx9k4Fw/oOLkeX7/oya7/Y9vCMJUHDXBHayM+X/iHF+g4qS5vv8jJ9Fd\n\
cfREDyxudseuOLTdGaQByIsCkixgzcEdjpiKHTNM/jumm4A0AZU5pJuAg9MA\n\
phAeyIwA7RXiEA=="]], 
                    "RGBColor[0.38175543134617906, 0.6109792496345561, \
0.30321055377645356]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.38175543134617906`, 0.6109792496345561, 
                    0.30321055377645356`]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.38175543134617906`, 0.6109792496345561, 
                   0.30321055377645356`], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}}, {{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.5015968883258048, 0.9477341972992892, 
                    0.7518749706067847], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    RGBColor[
                    0.3343979255505366, 0.6318227981995261, 
                    0.5012499804045232], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None, ImageCache -> 
                    GraphicsData[
                    "CompressedBitmap", 
                    "eJzzTSzJSM1NLMlMTlRwL0osyMhMLlZwyy8CCjEzMjAwcAMxlwIDiP0fy\
IQS\nHP9fv7nL+P/VmzuM/1+8vg0mGBjY/5dunMLA/L94/aT/XbsX/H/55g4DVAoo\n\
GjC39n/O5eX/S59sAfJKH21iYPlf+njz/5zrK//nru3//xJuDlA6ZH79//KH\n\
m/83fTsM5DV+OQhU3PT10P/y59v+F6yfiKm47MEmoLJDQF7DpwNAxY2fD/4v\n\
e7qV3orLH4HcfATs5kNgNx/G7eb8S8uBGkChUf4AFBogD+ddW4mpOHRhw/+Q\n\
BfUgTUBlIJL5f+C82v8F6yagBDIjAAnLBmY="]], 
                    "RGBColor[0.5015968883258048, 0.9477341972992892, \
0.7518749706067847]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.5015968883258048, 0.9477341972992892, 
                    0.7518749706067847]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.5015968883258048, 0.9477341972992892, 0.7518749706067847],
                   Editable -> False, Selectable -> False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}}, {{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.4853791041906068, 0.9983056811536988, 
                    0.059586297674913524`], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    RGBColor[
                    0.3235860694604046, 0.6655371207691325, 
                    0.03972419844994235], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None, ImageCache -> 
                    GraphicsData[
                    "CompressedBitmap", 
                    "eJy9kDsKwkAQhjduhBgxXiG9jYWFJ9BKBcUDBBEMvpMt1d6T+\
Oh91F5DUcRG\nTRTEA/zORkHEysZiPv4ZvmGXyVmiVm1awq5YZtaxOjW74pqZtkMjrjDGolS6\n\
yWQGxRc0eP5OwdnfKjh66wA05xDLNNxnMTUgR3eRwnBVxsnbsLeZH6mwdxqc\n\
qyYdoioz7EMI9VlC2m+5ONYhLgYGiFPXJ6oyQ9wjaC2S37LrG4HG0QtkynBv\n\
f5fF9Yc/N7YxCN+gjt4gmTLqe+1bLk11FCe6XCJNkqMwDqM1T34cWXkAn+Lu\nJg=="]], 
                    "RGBColor[0.4853791041906068, 0.9983056811536988, \
0.059586297674913524]"], Appearance -> None, BaseStyle -> {}, 
                   BaselinePosition -> Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.4853791041906068, 0.9983056811536988, 
                    0.059586297674913524`]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.4853791041906068, 0.9983056811536988, 
                   0.059586297674913524`], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}}, {{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.39598681356054666`, 0.5894657294683947, 
                    0.2897133293523855], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    RGBColor[
                    0.26399120904036444`, 0.3929771529789298, 
                    0.193142219568257], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None, ImageCache -> 
                    GraphicsData[
                    "CompressedBitmap", 
                    "eJzzTSzJSM1NLMlMTlRwL0osyMhMLlZwyy8CCjEzMjAwcAMxlwIDiP0fy\
IQS\nHP9fv7vH+P/1WyDx4vVtMAEUZ/6f3hT2P70RjBlYwCTz/5T64P/1U/L+v3xz\n\
hwGh0i5B539Io83/6C4noMroLkegWFCj1f/YKh80lU7JBv/jelz+p8/wAfLS\n\
pnuDTJ7h/T+21/l/Ym0ASDWq4thuF7Ay5v+p07yAitOme/2P6aG74rgeVyxu\n\
dsGuOLzJAaQByIvrdgUqBmkOa7bDVOycYgjUAMIGQGVAFjgsdf8n1gSghBsj\nAJYY3so="]], 
                    
                    "RGBColor[0.39598681356054666, 0.5894657294683947, \
0.2897133293523855]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.39598681356054666`, 0.5894657294683947, 
                    0.2897133293523855]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.39598681356054666`, 0.5894657294683947, 
                   0.2897133293523855], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}}, {{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.06510008212093177, 0.7580810151353965, 
                    0.4838966525370989], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    RGBColor[
                    0.04340005474728785, 0.5053873434235977, 
                    0.322597768358066], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None, ImageCache -> 
                    GraphicsData[
                    "CompressedBitmap", 
                    "eJzzTSzJSM1NLMlMTlRwL0osyMhMLlZwyy8CCjEzMjAwcAMxlwIDiP0fy\
IQS\nHP/fvL3HCCTuMv5/8fo2mGBgYP9vPaOAgfm/+bTc/9HLm/+/enOHASoFFGWt\n\
9f3PuTzzP9fWQiCPa3MBA8t/ri2F/1lWZvzXm5QBUo1QzN0Q+F9gS/F/wSO1\n\
QJ7goRqgYsHDtf+5txX/N56ajUXx5iKgghqQ4oPVIMWHav5zby2iu2KQm4+C\n\
3XwY7OYjeNzMvyL7v8DWYiAPaAdQMUgz18osLIobg8AagBioDEQy/2er8/tv\n\
PCUbJZAZATFh29c="]], 
                    "RGBColor[0.06510008212093177, 0.7580810151353965, \
0.4838966525370989]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.06510008212093177, 0.7580810151353965, 
                    0.4838966525370989]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.06510008212093177, 0.7580810151353965, 
                   0.4838966525370989], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}}, {{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.02229677965825383, 0.35028891391213257`, 
                    0.0684550207396537], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    RGBColor[
                    0.01486451977216922, 0.2335259426080884, 
                    0.045636680493102474`], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None, ImageCache -> 
                    GraphicsData[
                    "CompressedBitmap", 
                    "eJzzTSzJSM1NLMlMTlRwL0osyMhMLlZwyy8CCjEzMjAwcAMxlwIDiP0fy\
IQS\n7P/fvrvPwPz/7fv7/9+8u/f/xevbDIxgkoH9v1mSJVDKON70f1h12P9Xb+7A\n\
pICiDGZs/xm8uP4zBHCDeP7cDCwg9n8GD9b/GhE6INUIxSzWPP/ZQgT+s0UL\n\
AnlsUYJAxUD2f4Ygnv+6MYZYFAcLgJUBFUeCFUcBFQfSXzFJbvbjB5kOUgYk\n\
gWHiww1TCAs3pv8sNjysINUgeQt2dHkGRgDU5bKR"]], 
                    "RGBColor[0.02229677965825383, 0.35028891391213257, \
0.0684550207396537]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.02229677965825383, 0.35028891391213257`, 
                    0.0684550207396537]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.02229677965825383, 0.35028891391213257`, 
                   0.0684550207396537], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}}, {{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}}, {{{{{{{
                    RGBColor[0.15578960479774717`, 0.33156505911261824`, 
                    0.10795082362400787`], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    RGBColor[
                    0.10385973653183145`, 0.22104337274174551`, 
                    0.07196721574933859], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None, ImageCache -> 
                    GraphicsData[
                    "CompressedBitmap", 
                    "eJzzTSzJSM1NLMlMTlRwL0osyMhMLlZwyy8CCjEzMjAwcAMxlwIDiP0fy\
IQS\nHP/fvL/P+P/1u3uM/1+8vg0mGBjY/7vH2zEw/3eOsfqfUhH1/+WbOwxQKaCo\n\
iBHvf1k34f8KPqJAnoK3KAMLiP1f0oX/v1WoEUg1QrGUudB/1QCp/xrhMkCe\n\
RpgMUDGQ/V/RT+y/faQZFsX+UmBlQMWhYMVhQMW+9FdMipuVvSRApgOVgUjm\n\
/3IeIjCFsHBj+i9lIcQKUg2UFzXh/W8fgSLPwAgA9ae1tA=="]], 
                    "RGBColor[0.15578960479774717, 0.33156505911261824, \
0.10795082362400787]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.15578960479774717`, 0.33156505911261824`, 
                    0.10795082362400787`]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.15578960479774717`, 0.33156505911261824`, 
                   0.10795082362400787`], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}}, {{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.9666406011133539, 0.6653552686335491, 
                    0.5546554666254075], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    RGBColor[
                    0.6444270674089027, 0.44357017908903273`, 
                    0.36977031108360503`], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None, ImageCache -> 
                    GraphicsData[
                    "CompressedBitmap", 
                    "eJzzTSzJSM1NLMlMTlRwL0osyMhMLlZwyy8CCjEzMjAwcAMxlwIDiP0fy\
IQS\nnP9fvr3L9P/F69tAHvP/zT2V/zd3gzEDC5hk/r+xs/z/nrnd/1+8ucPACFe5\n\
MDfq//VJlf9fzGsC8p7NbQSqB7L/355c+X99axFINULxooLY/0/ntfz/tbYf\n\
yPuxug+o+Nea/v+vF7T839hRiqn4ydzm/z/W9AF531b1AhUDtfx/Ob+Z3oqf\n\
gdy8DuzmNWA3r8Xj5muTq/8/m98C5D2Z1wxUDNJ8c0oVpuIlhXH/FwM1ADUB\n\
lYFISHBuaC9FCWRGACBBBlU="]], 
                    "RGBColor[0.9666406011133539, 0.6653552686335491, \
0.5546554666254075]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.9666406011133539, 0.6653552686335491, 
                    0.5546554666254075]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.9666406011133539, 0.6653552686335491, 0.5546554666254075],
                   Editable -> False, Selectable -> False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}}, {{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.21832422216206182`, 0.4452088456726624, 
                    0.34195667187604584`], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    RGBColor[
                    0.14554948144137456`, 0.2968058971151083, 
                    0.22797111458403058`], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None, ImageCache -> 
                    GraphicsData[
                    "CompressedBitmap", 
                    "eJzzTSzJSM1NLMlMTlRwL0osyMhMLlZwyy8CCjEzMjAwcAMxlwIDiP0fy\
IQS\nHP/fvLvH+P81iHjx+jaYYGBg/x+QH8vA/N8nO+p/dmvJ/5dv7jBApYCiCu6m\n\
/3USPP8bZPgBefrpfgws//Uz/P5rxrv9d0kNBqlGKFb1tvxvkh3037IkEsiz\n\
KI4AKrYoifxvmBXw3yMzHIvirMD/lkBlQMVF4SDFxRH/DTP96a4Y6GYrsJst\n\
wW62xOdmw2Sf/6ZZgUBlQDuAYnpJXjCFSOGm6mMFVA3ClkCVIJL5v6K7GYZK\nRgDFZcuz"]], 
                    "RGBColor[0.21832422216206182, 0.4452088456726624, \
0.34195667187604584]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.21832422216206182`, 0.4452088456726624, 
                    0.34195667187604584`]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.21832422216206182`, 0.4452088456726624, 
                   0.34195667187604584`], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}}, {{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.4939446101923697, 0.31678858836269796`, 
                    0.11346988660388835`], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    RGBColor[
                    0.3292964067949131, 0.21119239224179864`, 
                    0.0756465910692589], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None, ImageCache -> 
                    GraphicsData[
                    "CompressedBitmap", 
                    "eJzzTSzJSM1NLMlMTlRwL0osyMhMLlZwyy8CCjEzMjAwcAMxlwIDiP0fy\
IQS\nHP9fv7/P+P/Vu3uM/1+8vg0mgOLM/0vi7P+XxIIxAwuYZP5fFGX9v7M8+v/L\n\
N3cYECr9Dfj+ZzuJ/C/xEAPyit3FQOrdxf5nOwj8zwk2BqlGKA42Ff5f5i39\n\
vyFYFsirD5IFKm4Ikv1f5iX+Pz/cHFNxKVAxSBnz/7pAkOL6QNn/pZ50V1zm\n\
Q4Kb89wkQRqAPKAdQMUgD+e6iGIqDjET/h8MwqbCQGUgkvl/gBEfTCE8kBkB\ngLjP2w=="]], 
                    "RGBColor[0.4939446101923697, 0.31678858836269796, \
0.11346988660388835]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.4939446101923697, 0.31678858836269796`, 
                    0.11346988660388835`]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.4939446101923697, 0.31678858836269796`, 
                   0.11346988660388835`], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}}, {{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.9566388456878347, 0.9651195544633302, 
                    0.9076564789046491], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    RGBColor[
                    0.6377592304585565, 0.6434130363088868, 
                    0.605104319269766], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None, ImageCache -> 
                    GraphicsData[
                    "CompressedBitmap", 
                    "eJzzTSzJSM1NLMlMTlRwL0osyMhMLlZwyy8CCjEzMjAwcAMxlwIDiP0fy\
IQS\nnP9fvrnD9P/F69tAHvP/TVtW/N+0GYwZWMAk8/8Nm5b/371v0/8Xb24zMMJV\n\
zl8w/f/V66f+P3t+C8h78uwGkHz6/Ob/m7fP/V+3YSkDwsyFi2b8f/z0+v8f\n\
v14Ded9+vASS33+9+v/y9R2Q2WgqHz25BlXz5dtzIPn1x4v/z1/eppNKoD+w\n\
uPMuFpVXrp2E+hpoOpB8/Oz6/xs3z6KpXLxk1v9Fi2eCdADDE0Qy/1+wcMb/\n\
9RuXoYQnIwCAcgwx"]], 
                    "RGBColor[0.9566388456878347, 0.9651195544633302, \
0.9076564789046491]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.9566388456878347, 0.9651195544633302, 
                    0.9076564789046491]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.9566388456878347, 0.9651195544633302, 0.9076564789046491],
                   Editable -> False, Selectable -> False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}}, {{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.4000855073593619, 0.39588066174906866`, 
                    0.1685452332949151], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    RGBColor[
                    0.26672367157290794`, 0.2639204411660458, 
                    0.11236348886327674`], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None, ImageCache -> 
                    GraphicsData[
                    "CompressedBitmap", 
                    "eJzzTSzJSM1NLMlMTlRwL0osyMhMLlZwyy8CCjEzMjAwcAMxlwIDiP0fy\
IQS\nHP9fv7vPCCTuMf5/8fo2mACKM//PyHAHYjcQZmABk8z/U1Oc/9fXJ/5/+eYO\n\
A0KlvZ3E/9AQxf8x0cpAlSCS+X9wkNz/uDhrNJXOTrL/4+M0/mekawN56Wna\n\
IJPTtf/Hxar+T0qyB6lGVRwXqwFWxvw/LRWkGMj+HxtDd8UkuTkiXA2kAagM\n\
RDL/Dw9TgilECgoXZ1mwaiAGqgSRoICU/J+UiKqSEQBrx84J"]], 
                    "RGBColor[0.4000855073593619, 0.39588066174906866, \
0.1685452332949151]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.4000855073593619, 0.39588066174906866`, 
                    0.1685452332949151]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.4000855073593619, 0.39588066174906866`, 
                   0.1685452332949151], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}}, {{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.5700736595139675, 0.4069545472059297, 
                    0.1981313907220874], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    RGBColor[
                    0.380049106342645, 0.27130303147061985`, 
                    0.13208759381472496`], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None, ImageCache -> 
                    GraphicsData[
                    "CompressedBitmap", 
                    "eJzzTSzJSM1NLMlMTlRwL0osyMhMLlZwyy8CCjEzMjAwcAMxlwIDiP0fy\
IQS\nHP9fv7vP+P/Vu3uM/1+8vg0mgOLM/+szvf7XQTADC5hk/l+T5v5/YmPK/5dv\n\
7jAgVMY6yP6vCdf43xanDeS1xmoD1QPZ/2tCVf6XxzuAVCMUJ7go/W9P1P8/\n\
OcsYyJuUaQxUDGT/70jQ+V+V7IKpuC1BH6yM+f/EDJBiIPt/ezzdFZPk5roo\n\
HZAGIK89QR+oGKS5LkITU3GiqxJYAxADlYFIUHDK/a9MdkYJZEYAR03cIw==\n"]], 
                    "RGBColor[0.5700736595139675, 0.4069545472059297, \
0.1981313907220874]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.5700736595139675, 0.4069545472059297, 
                    0.1981313907220874]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.5700736595139675, 0.4069545472059297, 0.1981313907220874],
                   Editable -> False, Selectable -> False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}}, {{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.16637070232988593`, 0.6273450506223697, 
                    0.6129198387249786], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    RGBColor[
                    0.1109138015532573, 0.41823003374824647`, 
                    0.4086132258166524], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None, ImageCache -> 
                    GraphicsData[
                    "CompressedBitmap", 
                    "eJzzTSzJSM1NLMlMTlRwL0osyMhMLlZwyy8CCjEzMjAwcAMxlwIDiP0fy\
IQR\nzP/fvLv7/81bMGZgAZMQsddAsRevbzMwgkkG9v+e7Y1AKdeW+v9pMyf9f/nm\n\
DkwKKCqWnvJfobPtv9KUiUCe0uQJQKOA7P/SXe3/bRqqQKoRimWy0v+rT534\n\
X2vRPCBPa+FcoGIg+7/y9Mn/HZtrsSieMgGsDKh4wRyQ4oVz/ytPm0R3xaS4\n\
WbW7HaQByFMHhgkLWLNCTwcWxdkZYA1ADFQGIpn/iwOD07GpFiWQGQEEJu9C\n"]], 
                    "RGBColor[0.16637070232988593, 0.6273450506223697, \
0.6129198387249786]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.16637070232988593`, 0.6273450506223697, 
                    0.6129198387249786]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.16637070232988593`, 0.6273450506223697, 
                   0.6129198387249786], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}}, {{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.15217789308335927`, 0.6805446503579162, 
                    0.7536712821543405], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    RGBColor[
                    0.10145192872223951`, 0.45369643357194417`, 
                    0.5024475214362271], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None, ImageCache -> 
                    GraphicsData[
                    "CompressedBitmap", 
                    "eJzzTSzJSM1NLMlMTlRwL0osyMhMLlZwyy8CCjEzMjAwcAMxlwIDiP0fy\
IQS\nHP/fvL3L+P/12zuM/1+8vg0mGBjY/7v3TWFg/u/cPel/yvwF/1++ucMAlQKK\n\
ihTU/pedtvy//KItQJ78wk0MLED25v8S01f+t2rvB6q+jVAsVVz/XwUoqb7x\n\
MJCnvv4gULH6hkP/FZZs+2/fNRGL4oWbQApAitcdAClef/C/wuKtdFcMcvOm\n\
IyDFQC0sIPfjdrPS9OX/VRaDQkMFHBogzXIzVmJRXNIA1gDEQGUgkvm/KDA4\n\
7bsmoAQyIwBxEukr"]], 
                    "RGBColor[0.15217789308335927, 0.6805446503579162, \
0.7536712821543405]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.15217789308335927`, 0.6805446503579162, 
                    0.7536712821543405]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.15217789308335927`, 0.6805446503579162, 
                   0.7536712821543405], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}}, {{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.011500166973726689`, 0.9344737120630893, 
                    0.41519231703372195`], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    RGBColor[
                    0.00766677798248446, 0.6229824747087263, 
                    0.2767948780224813], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None, ImageCache -> 
                    GraphicsData[
                    "CompressedBitmap", 
                    "eJy90L9OAkEQBvA5Fht5iets6OAJNDkqSwuiCexeiCAYDFLyJoC8AP96H\
oIE\nS+9OjQ2BOxFe4GNmE0NMaGgs5svM5jfJZq51u1p51O2ar91CSz9Va/6z6zVb\n\
/KQcIspwnbskPbj9DYUkiZDEtuhM0kEchw6W6zcbzBTy03vkJ7YobVMhN67g\n\
ZtbBKg7oIKl7CZoXQR9apqjMnt416LWIi2EJq3VwwKm+BxX6ULsGT+qnzlht\n\
G6AvH9mxOYIDYxnj7wfBmzro0/w7jk758/xOFgSHRjAv0+L2CB4UkHrxZImZ\n\
JB+wd4XsyPw5srMHLITwrA=="]], 
                    "RGBColor[0.011500166973726689, 0.9344737120630893, \
0.41519231703372195]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.011500166973726689`, 0.9344737120630893, 
                    0.41519231703372195`]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.011500166973726689`, 0.9344737120630893, 
                   0.41519231703372195`], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}}, {{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.6487763190386047, 0.9218976224198998, 
                    0.711816672844579], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    RGBColor[
                    0.43251754602573644`, 0.6145984149466, 
                    0.47454444856305267`], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None, ImageCache -> 
                    GraphicsData[
                    "CompressedBitmap", 
                    "eJy9kMFOwkAURaepK/2Jfo2u+\
IiGmIBJ0SAhuDVoJISGpZ2CuBHa0riUln8g\n\
uqaDsATawidc3tQYNMSti3fz7s2Z5M3N6ZXCuaFXinldOyvrV4Vi/lo7vSxT\n\
pCqMsROaY43JHbR+i4p1OsM6yYYdZbrPlnHElEwZpY1XEw9fQ6RUFfd+Czzs\n\
YJWIH+SFVYU56YLPPHKPkUu8JTyYHz3ceg2sYrGHDbsGHrlwtiG5fjoieLAJ\n\
YM993PnNQ9iaOhikAbmX+I3gfjIC/xz+N8yFC3c7zm4OCHY2IezFHze3J0+w\n\
hWzDmso25Ifb78+HcKl7A6NTk48Ik0p18irqw+avkpUdhKAhVg=="]], 
                    "RGBColor[0.6487763190386047, 0.9218976224198998, \
0.711816672844579]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.6487763190386047, 0.9218976224198998, 
                    0.711816672844579]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.6487763190386047, 0.9218976224198998, 0.711816672844579], 
                  Editable -> False, Selectable -> False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}}, {{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.47327935747334204`, 0.8834140175937308, 
                    0.33245673464773584`], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    RGBColor[
                    0.3155195716488947, 0.5889426783958206, 
                    0.22163782309849056`], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None, ImageCache -> 
                    GraphicsData[
                    "CompressedBitmap", 
                    "eJzzTSzJSM1NLMlMTlRwL0osyMhMLlZwyy8CCjEzMjAwcAMxlwIDiP0fy\
IQS\nHP9fv73H+P/VGyDx4vVtMAEUZ/5fuDLmf+EKMGZgAZPM//OXR/5v21L8/+Wb\n\
OwwIld6TTP6nHXH/n3/ZF8jLu+QDVJ9/yfd/2nGX/xlLgv+/fH0Hodh/isX/\n\
wov+/6ufhgN5VY/DgIqrn4T/L7zq9z9nWTim4oIL/mBlzP8rH4YCFVc9Cvtf\n\
cMWX3ooLLwVguvkaDjdnHvYCaQDyCi76g0LvYsD/jGMemIoDpln+959qCdIE\n\
0jrVAqgYZIDPZNP/2UvDQAENU8wIADku93o="]], 
                    "RGBColor[0.47327935747334204, 0.8834140175937308, \
0.33245673464773584]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.47327935747334204`, 0.8834140175937308, 
                    0.33245673464773584`]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.47327935747334204`, 0.8834140175937308, 
                   0.33245673464773584`], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}}, {{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.25560515056407795`, 0.8012401319897553, 
                    0.15094027368448049`], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    RGBColor[
                    0.17040343370938532`, 0.5341600879931703, 
                    0.100626849122987], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None, ImageCache -> 
                    GraphicsData[
                    "CompressedBitmap", 
                    "eJzzTSzJSM1NLMlMTlRwL0osyMhMLlZwyy8CCjEzMjAwcAMxlwIDiP0fy\
IQS\nHP/fvL3P+P/123uM/1+8vg0mgOLM/0PmufwPmQvGDCxgkvl/4BzH//lrEv6/\n\
fHOHAaFSrUX0v8lGmf+W++WBKi32yQPFDDdL/vecaYmmUrtd6r/NPuX/zhfU\n\
gDzHc2pA9Y7n1f5bHVT47zvbFqQaTfFe5f9O58CKz4AVnwUqPkB/xXA3O4Hd\n\
7AR0s/UhHIotNir+t92vDOQB7QAqBmk22yyHRXGHFFgDEAOVgUjm/+qtYv99\n\
Z9mihBsjAAqp244="]], 
                    "RGBColor[0.25560515056407795, 0.8012401319897553, \
0.15094027368448049]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.25560515056407795`, 0.8012401319897553, 
                    0.15094027368448049`]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.25560515056407795`, 0.8012401319897553, 
                   0.15094027368448049`], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}}, {{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}}, {{{{{{{
                    RGBColor[0.13360546814982577`, 0.7871863239201633, 
                    0.018599162734135977`], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    RGBColor[
                    0.08907031209988385, 0.5247908826134422, 
                    0.012399441822757318`], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None, ImageCache -> 
                    GraphicsData[
                    "CompressedBitmap", 
                    "eJzzTSzJSM1NLMlMTlRwL0osyMhMLlZwyy8CCjEzMjAwcAMxlwIDiP0fy\
IQS\nHP/fvL3P+P81iHjx+jaYYGBg/+86x4iB+b/jLIP/SasC/798c5cBKgUUFWxi\n\
+C+5juG/1B4GBpb/UrtBYiIbGP5bTFdFUyneyvxfYTfrf6WzrECe0ilWoHql\n\
M6z/ZfYx/LedqQVSjaZ4F1DxabDik2DFp4CK99JfMcLNp+Fu3o9Dsdx61v8K\n\
e0CKgXYAFYM0S23EprgNogGIgcpAJPN/oWagwhlaKOHGCAANkMjF"]], 
                    "RGBColor[0.13360546814982577, 0.7871863239201633, \
0.018599162734135977]"], Appearance -> None, BaseStyle -> {}, 
                   BaselinePosition -> Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.13360546814982577`, 0.7871863239201633, 
                    0.018599162734135977`]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.13360546814982577`, 0.7871863239201633, 
                   0.018599162734135977`], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}}, {{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.38337417819768205`, 0.4988952587556723, 
                    0.08321860516969015], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    RGBColor[
                    0.25558278546512136`, 0.33259683917044824`, 
                    0.05547907011312677], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None, ImageCache -> 
                    GraphicsData[
                    "CompressedBitmap", 
                    "eJzzTSzJSM1NLMlMTlRwL0osyMhMLlZwyy8CCjEzMjAwcAMxlwIDiP0fy\
IQS\nHP9fv7vP+P/123uM/1+8vg0mgOLM/9PKrP+nQjADC5hk/p9UbP6/tjvi/8s3\n\
dxgQKm0COP4H5fD+jyzhA/IigCQLiP3fP4fjf0yuHkg1QrFDCN//mHLh/ymN\n\
okBecoMoUDGQ/T+qnP9/QqExpuLoMmGwMqDt9SDFQPb/yDK6KybJzaH5QiAN\n\
QB7QDqBikObgPD5MxY6hfGANQAxUBiKBwRnI+T++wBglkBkBEMvR1Q=="]], 
                    "RGBColor[0.38337417819768205, 0.4988952587556723, \
0.08321860516969015]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.38337417819768205`, 0.4988952587556723, 
                    0.08321860516969015]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.38337417819768205`, 0.4988952587556723, 
                   0.08321860516969015], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}}, {{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.4181367040733106, 0.49313383402211364`, 
                    0.10167945128775124`], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    RGBColor[
                    0.2787578027155404, 0.32875588934807576`, 
                    0.06778630085850083], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None, ImageCache -> 
                    GraphicsData[
                    "CompressedBitmap", 
                    "eJzzTSzJSM1NLMlMTlRwL0osyMhMLlZwyy8CCjEzMjAwcAMxlwIDiP0fy\
IQS\nHP9fv7vP+P/123uM/1+8vg0mGBjY/2eV2jIw/08vtvzf2BX1/+WbOwxQKaCo\n\
kz/P/6hswf+JxcJAXgKQZAGx/0dk8/5PyDECqUYodgsW/J9SJvE/t0EKyMup\n\
lwIqBrL/J5eJ/E8pMMNUnFwqAVbG/D+7DqQYyP6fVEp3xSS5OTZPDKQByAPa\n\
AVQM0hydK4Sp2D1EEKwBiIHKQCQwOAN4/qfkm6EEMiMAnV7N8A=="]], 
                    "RGBColor[0.4181367040733106, 0.49313383402211364, \
0.10167945128775124]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.4181367040733106, 0.49313383402211364`, 
                    0.10167945128775124`]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.4181367040733106, 0.49313383402211364`, 
                   0.10167945128775124`], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}}, {{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.4812053533680498, 0.873332380181423, 0.327028956990717], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    RGBColor[
                    0.3208035689120332, 0.5822215867876154, 
                    0.218019304660478], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None, ImageCache -> 
                    GraphicsData[
                    "CompressedBitmap", 
                    "eJzzTSzJSM1NLMlMTlRwL0osyMhMLlZwyy8CCjEzMjAwcAMxlwIDiP0fy\
IQS\nHP9fv73H+P/VGyDx4vVtMMHAwP6/eHkMA/P/gqUR/zu2FP1/+eYOA1QKKOo7\n\
wfh/xiHX/4UXvUFqLngxsPwvvOD1P+OI0/+sRUH/X76+g1AcOMn8f/F53/+1\n\
j0OBvJqHIUDFtY9C/hdf9vmftyQMU3HROV+wMub/1feDgYprHgT/L7rkTW/F\n\
xRf8MN18BYebsw96gDQAeUXnfYGKQR7OOuKGqThoisX/wMkWIE0grZPNgYpB\n\
BvhNNPmfuyQUFNAwxYwA2wnvuw=="]], 
                    "RGBColor[0.4812053533680498, 0.873332380181423, \
0.327028956990717]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.4812053533680498, 0.873332380181423, 0.327028956990717]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.4812053533680498, 0.873332380181423, 0.327028956990717], 
                  Editable -> False, Selectable -> False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}}, {{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.5269434582467774, 0.8294337802982428, 
                    0.1734709900484559], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    RGBColor[
                    0.3512956388311849, 0.5529558535321619, 
                    0.1156473266989706], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None, ImageCache -> 
                    GraphicsData[
                    "CompressedBitmap", 
                    "eJzzTSzJSM1NLMlMTlRwL0osyMhMLlZwyy8CCjEzMjAwcAMxlwIDiP0fy\
IQS\nHP9fv73P+P/V23uM/1+8vg0mgOLM/ysXuf+vXOgGwgwsYJL5f/kC5/+96xP/\n\
v3xzhwGhMrRL4n/RDqX/1cdVgLzqoypA9dXHVP4X7Zb7XzjX+v/L13cQiiN7\n\
ZP/XHtX833FDB8hrv6YDVNxxXed/7UnV/yXz7TEV1xzRBCtj/t92BaS4/arO\n\
/5oTdFeM1c2ncCgu3aH2v/aYJpAHtAOoGKS5ZLcSpuKoXlmwBiAGKgORzP/D\n\
uiT/l8yzRwlkRgAYBe1+"]], 
                    "RGBColor[0.5269434582467774, 0.8294337802982428, \
0.1734709900484559]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.5269434582467774, 0.8294337802982428, 
                    0.1734709900484559]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.5269434582467774, 0.8294337802982428, 0.1734709900484559],
                   Editable -> False, Selectable -> False]}], "}"}], ",", 
             RowBox[{"{", 
               RowBox[{
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}}, {{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.37266534273681007`, 0.38750269832660855`, 
                    0.3948182017762212], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    RGBColor[
                    0.24844356182454005`, 0.25833513221773907`, 
                    0.2632121345174808], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None, ImageCache -> 
                    GraphicsData[
                    "CompressedBitmap", 
                    "eJy9kM1qwlAUhE9IQbEvkecQNFShXUkVo4n5ufY2SRMXoqibQsEH9Wdts\
fgK\n41wRpLjqpos7zJz7DRxOR6/KfKpXk1Q7Lws9Lyfp0nmeLTiyLRF55Ks5Yjxo\n\
r1LF8bS3KDsLh+PmIiIVZEUmNnT2jq/1J75/tnL94rTeaOK172EYxkyDUSQP\n\
xqPT9RAmkaFvcPOphVGioPOC6S37IEyPIFJQenwPB3FywWyM05wwPfww+W/4\n\
Tzv3h74pMAWxImzKPc+/h91WGy4LLBEzas7pElS/jmydAcmb1LY="]], 
                    "RGBColor[0.37266534273681007, 0.38750269832660855, \
0.3948182017762212]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.37266534273681007`, 0.38750269832660855`, 
                    0.3948182017762212]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.37266534273681007`, 0.38750269832660855`, 
                   0.3948182017762212], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}}, {{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.733606571264461, 0.4291909747287308, 
                    0.4301886698173236], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    RGBColor[
                    0.4890710475096407, 0.28612731648582057`, 
                    0.28679244654488245`], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None, ImageCache -> 
                    GraphicsData[
                    "CompressedBitmap", 
                    "eJzzTSzJSM1NLMlMTlRwL0osyMhMLlZwyy8CCjEzMjAwcAMxlwIDiP0fy\
IQS\nHP9fvbvHCCTuMv5/8fo2mGBgYP8/JSeTgfn/5My0/4uba/+/fHOHASoFFK10\n\
cfm/KCb2//rkFCBvbVIKA8v/dckp/5dExfzvS04EqUYorvHw+L8uLf3/vvwC\n\
IG9PXj5Q8d78gv8bU9P+T0xPwVS8FiixF6iM+f/u3DygYqCW/xtSUumtGOTm\n\
/WA37wW7eR8+Ny+OT/i/Pi0dFBqpaaDQAGpeEhuHqbjW0xOsAYiBykAk8/8q\n\
F9f/E9KSUQKZEQDY1el2"]], 
                    "RGBColor[0.733606571264461, 0.4291909747287308, \
0.4301886698173236]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.733606571264461, 0.4291909747287308, 
                    0.4301886698173236]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.733606571264461, 0.4291909747287308, 0.4301886698173236], 
                  Editable -> False, Selectable -> False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}}, {{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.17707863410973768`, 0.672607405954065, 
                    0.8338273497920801], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    RGBColor[
                    0.11805242273982512`, 0.44840493730271, 
                    0.5558848998613868], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None, ImageCache -> 
                    GraphicsData[
                    "CompressedBitmap", 
                    "eJzzTSzJSM1NLMlMTlRwL0osyMhMLlZwyy8CCjEzMjAwcAMxlwIDiP0fy\
IQR\nzP/fvL0LxHdAmIEVRDL+fw0iXry+DSYYGNj/e/XMB6p065r7P33eqv8v39xh\n\
gEoBRSXzuv8rTdn5X3XBCQaW/6rzjwPF5Kbu+W/fOhuo8jaSSrnC3v9aC479\n\
111/E8jTXXsdqF533Y3/aotO/XfumAtSjaZ4/lGggusgxWuughSvvfZfbeFJ\n\
uisGuXkD2M3rwG5eD3LzaeyK1afu/K+1EBQIQDuAikGalaftwaK4qA+sAYiB\n\
ykAkJCydO+aghDAjAMwm9l4="]], 
                    "RGBColor[0.17707863410973768, 0.672607405954065, \
0.8338273497920801]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.17707863410973768`, 0.672607405954065, 
                    0.8338273497920801]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.17707863410973768`, 0.672607405954065, 
                   0.8338273497920801], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}}, {{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8745580077995285, 0.08910005366925322, 
                    0.5820198361552016], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    RGBColor[
                    0.5830386718663524, 0.05940003577950215, 
                    0.3880132241034677], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None, ImageCache -> 
                    GraphicsData[
                    "CompressedBitmap", 
                    "eJzzTSzJSM1NLMlMTlRwL0osyMhMLlZwyy8CCjEzMjAwcAMxlwIDiP0fy\
IQS\nHP9fvb/L+P8liHjx+jaYYGBg/7/cvpaB+f9S6+r/m+P6/r98e4cBKgUUncgZ\n\
//8wX/3/SwKdQN4FgQ4Glv8XBTr/H+Oq/7/YqOz/i7d3EIon8yf9vyDa9f+x\n\
+DQg76H4VKDiR+LT/l8R7P6/1LwSU/F50U6wMub/98WnABU/EJ/6/7JgF70V\n\
X8Ti5qu43HxIpBHkSSAPaAdQMcjDR/kbMRVP5U/+PwWoAagJqAzIAopN4or/\n\
vwSoEDmQGQEYw+cy"]], 
                    "RGBColor[0.8745580077995285, 0.08910005366925322, \
0.5820198361552016]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.8745580077995285, 0.08910005366925322, 
                    0.5820198361552016]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.8745580077995285, 0.08910005366925322, 
                   0.5820198361552016], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}}, {{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.9090294322469556, 0.2839329014344203, 
                    0.5231271919589293], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    RGBColor[
                    0.6060196214979705, 0.1892886009562802, 
                    0.3487514613059529], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None, ImageCache -> 
                    GraphicsData[
                    "CompressedBitmap", 
                    "eJzzTSzJSM1NLMlMTlRwL0osyMhMLlZwyy8CCjEzMjAwcAMxlwIDiP0fy\
IQR\nzP9fvb/3/yUEM7CCSMb/L9/dZfz/4vVtMMHAwP5/TWQpUOWqsOL/24vb/798\n\
c4cBKgUUna4V+v+UddH/Ww7VQN5N+yoGFiBZ/f+sedH/FX55/1+8uYNQPFM/\n\
4v8N55r/b7zaQVZ7tgEVv/Zs/3/Hofb/qqBCTMXXnavBypj/v/BoBSp+6dH2\n\
/7ZDDb0V33TBdPNdRxxuPmVfAtIA5AHtACoGefisTQmm4tkGkf9nGUT8n2kQ\n\
AVQGIpn/z9AJ/b8yqAAlkBkBJ7/6WQ=="]], 
                    "RGBColor[0.9090294322469556, 0.2839329014344203, \
0.5231271919589293]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.9090294322469556, 0.2839329014344203, 
                    0.5231271919589293]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.9090294322469556, 0.2839329014344203, 0.5231271919589293],
                   Editable -> False, Selectable -> False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}}, {{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.4864384781423896, 0.2590016473319656, 
                    0.8939198034327294], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    RGBColor[
                    0.3242923187615931, 0.17266776488797708`, 
                    0.5959465356218197], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None, ImageCache -> 
                    GraphicsData[
                    "CompressedBitmap", 
                    "eJzzTSzJSM1NLMlMTlRwL0osyMhMLlZwyy8CCjEzMjAwcAMxlwIDiP0fy\
IQS\nHP9fv7/D+P/VOyDx4vVtMAEUZ/5fErb8f3HYMhBmYAGTzP8Lg5f+7yzc8P/l\n\
m9sMCJV+6lP/Z5oe/19kdR2kxvIqUH2R5bX/mUan/2d7LwapRigO0pn2v8T2\n\
yv86lxdAXq3TM6DiOqfn/0usbv7P81+KqbjY9vL/WudnQF6N0xOg4lqnp/+L\n\
rW7QW3GJ7VWYm53BbnYGufkWdsU5lsf+l9hdBfKAdgAVgzycbXYKU3Gwzgyg\n\
hukgTUBlIJL5v7/GVKDCJSiBzAgAS2Dy8w=="]], 
                    "RGBColor[0.4864384781423896, 0.2590016473319656, \
0.8939198034327294]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.4864384781423896, 0.2590016473319656, 
                    0.8939198034327294]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.4864384781423896, 0.2590016473319656, 0.8939198034327294],
                   Editable -> False, Selectable -> False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}}, {{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.2674220618976657, 0.5345197867819858, 
                    0.7888815584252213], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    RGBColor[
                    0.17828137459844381`, 0.35634652452132387`, 
                    0.5259210389501476], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None, ImageCache -> 
                    GraphicsData[
                    "CompressedBitmap", 
                    "eJzzTSzJSM1NLMlMTlRwL0osyMhMLlZwyy8CCjEzMjAwcAMxlwIDiP0fy\
IQS\nHP/fvLvL+P/12zuM/1+8vg0mgOLM/8OqZgLxDBBmYAGTzP+DK6b/L+hf8v/l\n\
mzsMCJUaYc3/zUvW/7ep3QvkWdfsBqq3rt3z36R443/voilA1UjG6ka1/rev\n\
3/3fresskOfaeQqo2LXrzH+b+n3//UunYVFctwuo7DSQ59JxEqjYpfPUf5u6\n\
vXRXjOTm01A329bvx67Yumz9f4f6PUAe0A6gYpBmi7KNWBRHt4E1ADFQGYhk\n\
/q8Z3gxUOBUlkBkBPTvwaA=="]], 
                    "RGBColor[0.2674220618976657, 0.5345197867819858, \
0.7888815584252213]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.2674220618976657, 0.5345197867819858, 
                    0.7888815584252213]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.2674220618976657, 0.5345197867819858, 0.7888815584252213],
                   Editable -> False, Selectable -> False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}}, {{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.18736123677107708`, 0.3952086052502788, 
                    0.86460527303447], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    RGBColor[
                    0.12490749118071806`, 0.26347240350018586`, 
                    0.5764035153563134], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None, ImageCache -> 
                    GraphicsData[
                    "CompressedBitmap", 
                    "eJzzTSzJSM1NLMlMTlRwL0osyMhMLlZwyy8CCjEzMjAwcAMxlwIDiP0fy\
IQS\nHP/fvLvD+P81iHjx+jaYYGBg+u+TsZgVSCxiYP7vkbLwf0b92v8v39xhgMoD\n\
RaXt+v+rhBz4rxF9HsjTiD7LwAIkz/1XDDr83yFuPlD1bYRiBaeJ/3Xizv43\n\
SH8A5Bmk3QMqNki//18z9uJ/l6SFWBTHngErAypOvQNSnHb3v2bMBborjjuH\n\
xc2XsCvWDD/wXzfuHJCnG3cGqFgX6GG1sENYFDtPBmqYBMJAZSASFJwT/rsk\n\
LkAJZEYAVIPkxA=="]], 
                    "RGBColor[0.18736123677107708, 0.3952086052502788, \
0.86460527303447]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.18736123677107708`, 0.3952086052502788, 
                    0.86460527303447]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.18736123677107708`, 0.3952086052502788, 0.86460527303447],
                   Editable -> False, Selectable -> False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}}, {{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.7776461280660796, 0.8643601244579295, 
                    0.9944319426310919], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    RGBColor[
                    0.5184307520440531, 0.5762400829719531, 
                    0.6629546284207279], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None, ImageCache -> 
                    GraphicsData[
                    "CompressedBitmap", 
                    "eJzzTSzJSM1NLMlMTlRwL0osyMhMLlZwyy8CCjEzMjAwcAMxlwIDiP0fy\
IQS\nHP9fvb3D+P/VGyDx4vVtMMHAwP5/1rItDMz/ZyzZ/H/F5t3/X765zQCVAoo2\n\
9C/7v/rAvf87z78H8nacfcfA8n/nuff/1x1+/H/qok3/X8LNAUo3T1wOVPLm\n\
/6kH/4G84/f+AxWfuP///+6Ln/9PBxqPoXj7mdf/T9wDKT525x9Q8fG7///v\n\
uvCR3op3nHsLdfMJsJtPAt285xION685cBcYAm9AoXHmNVAxyMPrDj3EVNwy\n\
eeX/5kkrgHg5UBmIZP7fOGH5/2mLN6EEMiMA6jsa9w=="]], 
                    "RGBColor[0.7776461280660796, 0.8643601244579295, \
0.9944319426310919]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.7776461280660796, 0.8643601244579295, 
                    0.9944319426310919]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.7776461280660796, 0.8643601244579295, 0.9944319426310919],
                   Editable -> False, Selectable -> False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}}, {{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.10244743490058794`, 0.1869170597224914, 
                    0.6271170684614624], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    RGBColor[
                    0.0682982899337253, 0.1246113731483276, 
                    0.41807804564097495`], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None, ImageCache -> 
                    GraphicsData[
                    "CompressedBitmap", 
                    "eJzzTSzJSM1NLMlMTlRwL0osyMhMLlZwyy8CCjEzMjAwcAMxlwIDiP0fy\
IQS\nHP/fvL/L+P/NOyDx4vVtMMHAwP7fwaeZgfm/jUfj/7jMyf9fvbnDAJUCinJL\n\
pf8XVOn6L6wxFcgT1pjCwAJi/+dV7P5v7FD7/+WbOwjFggpZ/yV0pv6XMlgE\n\
5EkZLAQqBrL/i2hO/2/h2oBN8RSwMpDiBWDFC4GKp9FfMQluFtPs/i+hCwoN\n\
CV1QaADZ/4XUerApzgZrAGKgMhDJ/J9HOh2osB4lkBkB2v7JSg=="]], 
                    "RGBColor[0.10244743490058794, 0.1869170597224914, \
0.6271170684614624]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.10244743490058794`, 0.1869170597224914, 
                    0.6271170684614624]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.10244743490058794`, 0.1869170597224914, 
                   0.6271170684614624], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}}, {{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.4573447796522936, 0.007181376876192136, 
                    0.566195028583903], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    RGBColor[
                    0.30489651976819576`, 0.004787584584128091, 
                    0.3774633523892687], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None, ImageCache -> 
                    GraphicsData[
                    "CompressedBitmap", 
                    "eJy9kLEOwVAUhs+\
9bUJ4iU4WI89ADLXZJFxNo602mqqSSDdqMeD1sJNGeIPj\n\
3Goi0sliOH/+89/vJDe/LkLL9ERoG0JrB8K3bGOmtaYBRQoDgCpNRQPpkWwu\n\
ZUyfF4bpg+SanjIBKKHfXIGCbmOJSW+Ht/sZ8idKO9BHA1Y4gQ1tDqxBlR5H\n\
lI1roaQ/sM4G6PEEF/xIW8QPBJNHD7bo1BdF2OWbDFNwzvcEk0cXkn/DP/3Z\n\
5LE8kI2RqtmxCXER7rJhdkBDmNR3nU49+iqZvQBhlM7z"]], 
                    "RGBColor[0.4573447796522936, 0.007181376876192136, \
0.566195028583903]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.4573447796522936, 0.007181376876192136, 
                    0.566195028583903]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.4573447796522936, 0.007181376876192136, 
                   0.566195028583903], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}}, {{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.23258722219837846`, 0.08344742427005825, 
                    0.30644177688225716`], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    RGBColor[
                    0.15505814813225233`, 0.05563161618003883, 
                    0.20429451792150477`], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None, ImageCache -> 
                    GraphicsData[
                    "CompressedBitmap", 
                    "eJzzTSzJSM1NLMlMTlRwL0osyMhMLlZwyy8CCjEzMjAwcAMxlwIDiP0fy\
IQS\nHP/fvL/H+P81iHjx+jaYAIoz/w+yiwTiCBBmYAGTzP/9rUL/58YV/H/59g4D\n\
QqUyh/5/fR6H/8Z8bkCVRnyuQDEdDrv/7oZ+aCo1+Iz/mwt7/LcRDQCqtBb1\n\
B4qZ8Lv99zYLwqnSH6zSbwBUev63BbvTBupOdxwqTYRc/lsIewJVAk0Hihny\n\
OaKrZAIqNGEFqQbKq3AaYJjECACIFbL4"]], 
                    "RGBColor[0.23258722219837846, 0.08344742427005825, \
0.30644177688225716]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.23258722219837846`, 0.08344742427005825, 
                    0.30644177688225716`]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.23258722219837846`, 0.08344742427005825, 
                   0.30644177688225716`], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}}, {{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.711485166849398, 0.017375777675906035`, 
                    0.7454946682315056], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    RGBColor[
                    0.47432344456626535`, 0.011583851783937357`, 
                    0.4969964454876704], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None, ImageCache -> 
                    GraphicsData[
                    "CompressedBitmap", 
                    "eJzzTSzJSM1NLMlMTlRwL0osyMhMLlZwyy8CCjEzMjAwcAMxlwIDiP0fy\
IQS\nHP9ffbjL+P/V+zuM/1+8vg0mGBjY/080m8zA/L/feOL/heEL/r98e4cBKgUU\n\
LWWo+T+XYen/lQybGFj+r2DYCBSbx7D8f7dGH1DlbSSVFcx1/1eybPy/g+Ug\n\
kLeNZT9Q/XaWA/9XM2z536c7AaQaVfEKlg0gBUDeVpZ9QMVALf9XMWymt2KQ\n\
m3eyHALyQFpYQO7H7eZ5LMCgYNkE5AHtACoGaZ4PDA4MxZXM9WANQAxUBiIh\n\
YdkLVogIYUYA4tDhkw=="]], 
                    "RGBColor[0.711485166849398, 0.017375777675906035, \
0.7454946682315056]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.711485166849398, 0.017375777675906035`, 
                    0.7454946682315056]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.711485166849398, 0.017375777675906035`, 
                   0.7454946682315056], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}}, {{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.31452599923983104`, 0.6908103742720597, 
                    0.9463506847311731], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    RGBColor[
                    0.2096839994932207, 0.4605402495147065, 
                    0.6309004564874487], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None, ImageCache -> 
                    GraphicsData[
                    "CompressedBitmap", 
                    "eJzzTSzJSM1NLMlMTlRwL0osyMhMLlZwyy8CCjEzMjAwcAMxlwIDiP0fy\
IQS\nHP/fvL3D+P81iHjx+jaYAIoz/4/pXwfEa0GYgQVMMv+P7Fn7v3T+1v8v39xm\n\
QKjUL5z333HG5f/uSx4DVbotfgQUs595/X9Qx2o0lSYl8/97LXnwP2jzVyAv\n\
cONnoPrATV/+ey579j+sew1INZrixfeBCj4DeQEbPgIVB2z89N9j6RN6K/Ze\n\
8vB/0BawmzeB3bwZj5tdZ1787730IZDntfgBUDHIw86zrmIqNi1d+N+0ZAFI\n\
E1AZiGT+b1g4/39oF2q4MQIA7ED/RA=="]], 
                    "RGBColor[0.31452599923983104, 0.6908103742720597, \
0.9463506847311731]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.31452599923983104`, 0.6908103742720597, 
                    0.9463506847311731]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.31452599923983104`, 0.6908103742720597, 
                   0.9463506847311731], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}}, {{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.922559309792595, 0.2703946335791436, 
                    0.09665543181913394], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    RGBColor[
                    0.6150395398617301, 0.18026308905276242`, 
                    0.0644369545460893], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None, ImageCache -> 
                    GraphicsData[
                    "CompressedBitmap", 
                    "eJzzTSzJSM1NLMlMTlRwL0osyMhMLlZwyy8CCjEzMjAwcAMxlwIDiP0fy\
IQS\nHP9fvr/P+P/lu3uM/1+8vg0mGBjY/68Nt2Fg/r8mxOL/jqLI/y/f3GGASgFF\n\
Z2py/T9rIfD/rq0QkHfbRoiB5f8dG6H/F0x4/q/0Mfj/4s0dhOLZegL/bzuI\n\
/3/vLgnkvXWTBCp+5yb5/76t8P/VAaaYim8BFYOUMf9/7QpS/MZV8v89+iu+\n\
g8XND+xwKD5rI/r/jqM4kAe0A6gY5OHzloKYiucCFc8BYqAmoDIQyfx/lhY3\n\
WCFyIDMCALsu2vM="]], 
                    "RGBColor[0.922559309792595, 0.2703946335791436, \
0.09665543181913394]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.922559309792595, 0.2703946335791436, 
                    0.09665543181913394]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.922559309792595, 0.2703946335791436, 0.09665543181913394],
                   Editable -> False, Selectable -> False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}}, {{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.11122524183982829`, 0.12772449779541217`, 
                    0.6139200516853858], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    RGBColor[
                    0.0741501612265522, 0.08514966519694145, 
                    0.40928003445692385`], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None, ImageCache -> 
                    GraphicsData[
                    "CompressedBitmap", 
                    "eJzzTSzJSM1NLMlMTlRwL0osyMhMLlZwyy8CCjEzMjAwcAMxlwIDiP0fy\
IQS\nHP/fvL/L+P/1OyDx4vVtMMHAwP7fybWRgfm/nWP9//ikSf9fvb3DAJUCivIK\n\
pPwXlmj/Lyo5kYEFTDL/5xfu+G9qUfX/5RtklcJi6f+l5Cf9l1GcD+TJKM4D\n\
qgey/4tJT/lvZVsLUo2ueCJYGUjxXLDieUDFk+mvmAQ3S8h2gDQAeUA7gIpB\n\
mkUkO7EpzgBrAGKgMhDJ/J9PMOW/pU0tSggzAgC+q8SU"]], 
                    "RGBColor[0.11122524183982829, 0.12772449779541217, \
0.6139200516853858]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.11122524183982829`, 0.12772449779541217`, 
                    0.6139200516853858]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.11122524183982829`, 0.12772449779541217`, 
                   0.6139200516853858], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}}, {{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.6357194627252103, 0.15357943517679362`, 
                    0.860476954867391], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    RGBColor[
                    0.4238129751501402, 0.10238629011786242`, 
                    0.5736513032449273], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None, ImageCache -> 
                    GraphicsData[
                    "CompressedBitmap", 
                    "eJzzTSzJSM1NLMlMTlRwL0osyMhMLlZwyy8CCjEzMjAwcAMxlwIDiP0fy\
IQS\nHP9fvb/D+P/VOyDx4vVtMMHAwP6/3WMRA/P/VpcF/2ekrvn/8s0dBqgUUDRD\n\
pO9/t+z+/9PkzwF5U+XPMLAA2Wf/90gc+t9gPQ+o+jZCcbbUhP/TVc78X6J+\n\
H8hbrH4XqHiJ+r3/MxQu/G92WICpeJrKabAy5v+L1G8DFS9Wv/N/usJ5eiue\n\
rnIWi5svYlfcq7QfpAHIA9oBVAzycK/cQUzFOVKTgBomgjBQGYgEBqdo//8m\n\
h/kogcwIAKLA6+w="]], 
                    "RGBColor[0.6357194627252103, 0.15357943517679362, \
0.860476954867391]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.6357194627252103, 0.15357943517679362`, 
                    0.860476954867391]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.6357194627252103, 0.15357943517679362`, 
                   0.860476954867391], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}}, {{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.4431832834876257, 0.18321465791748515`, 
                    0.7764518003586576], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    RGBColor[
                    0.2954555223250838, 0.12214310527832344`, 
                    0.5176345335724384], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None, ImageCache -> 
                    GraphicsData[
                    "CompressedBitmap", 
                    "eJzzTSzJSM1NLMlMTlRwL0osyMhMLlZwyy8CCjEzMjAwcAMxlwIDiP0fy\
IQS\nHP9fv7/L+P/1uzuM/1+8vg0mGBjY/+f6TGdg/p/lMfV/c+aS/y/f3GGASgFF\n\
3SQb/ycor/mfrr4LyEtT38HAAmTv/B+nsP5/iv0koOrbCMVe8s3/s7R3/C/W\n\
PwXkFekfByou1j/xP1Njz/8MlymYijO1twOVnQDyCvWPARUDtfzP0NhNb8XI\n\
bj4BdvNJoJv3YlecpLHmf6bOTqCyTJ0dQLFE1fUwhUjh5i3fAlYNxECVIBIY\n\
llKN/9PBKhEhzAgA6rneEQ=="]], 
                    "RGBColor[0.4431832834876257, 0.18321465791748515, \
0.7764518003586576]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.4431832834876257, 0.18321465791748515`, 
                    0.7764518003586576]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.4431832834876257, 0.18321465791748515`, 
                   0.7764518003586576], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}}, {{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.3553518860908462, 0.6443320866741731, 
                    0.7499636864238166], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    RGBColor[
                    0.2369012573938975, 0.42955472444944875`, 
                    0.4999757909492111], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None, ImageCache -> 
                    GraphicsData[
                    "CompressedBitmap", 
                    "eJzzTSzJSM1NLMlMTlRwL0osyMhMLlZwyy8CCjEzMjAwcAMxlwIDiP0fy\
IQS\nHP9fv73LCCTuMP5/8fo2mACKM/9P6pz8PxGCGVjAJPP/uPaJ/6tmL/j/8s0d\n\
BoRK86ya/969y/4HzdgM5AVO3whUHzRj03+vvhX/w5v6gKqRjLXOrfsfOnPT\n\
/9hlh4C8mKUHgIpjlx38HzJr6//o1gmYikNmbAQqOwjkRS/ZD1QM1PI/eOYW\n\
eiuGuPkw2M0HwW4+hNvN/v3LgBpAoQG0A6gYpNm3fwWmYpu8+v82QA1ATUBl\n\
IBISnBCFiEBmBACC7vhC"]], 
                    "RGBColor[0.3553518860908462, 0.6443320866741731, \
0.7499636864238166]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.3553518860908462, 0.6443320866741731, 
                    0.7499636864238166]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.3553518860908462, 0.6443320866741731, 0.7499636864238166],
                   Editable -> False, Selectable -> False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}}, {{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8943854155561495, 0.03560200287351467, 
                    0.16578917868909593`], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    RGBColor[
                    0.5962569437040997, 0.023734668582343115`, 
                    0.11052611912606396`], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None, ImageCache -> 
                    GraphicsData[
                    "CompressedBitmap", 
                    "eJzzTSzJSM1NLMlMTlRwL0osyMhMLlZwyy8CCjEzMjAwcAMxlwIDiP0fy\
IQS\nTP9ffbjP+v/lh/sMzCDm/5fv7/1/8fo2AyOYZGD/v9LCDSi1wsT5/5aIxP8v\n\
396BSQFFpzCI/z/OqPD/GpMSA8v/q0CS+f9JBtn/S7Ws/79AUTmNTeb/FQ71\n\
/y84tYC8Z0CS5f9zTq3/N5hV/i/XtwepRlV8Gaj4GVjxE7Dip0DF1+mv+CoW\n\
N9/EpfgYhypIA5AHtAOoGOThk8yKmIpnABVPB2KgJqAyEMn8fyqjxP9lQIXI\nIcwIAN4c1yU="]],
                     "RGBColor[0.8943854155561495, 0.03560200287351467, \
0.16578917868909593]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.8943854155561495, 0.03560200287351467, 
                    0.16578917868909593`]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.8943854155561495, 0.03560200287351467, 
                   0.16578917868909593`], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}}, {{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.6672396717157738, 0.3586192991395154, 
                    0.8976595916455246], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    RGBColor[
                    0.4448264478105159, 0.23907953275967694`, 
                    0.598439727763683], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None, ImageCache -> 
                    GraphicsData[
                    "CompressedBitmap", 
                    "eJzzTSzJSM1NLMlMTlRwL0osyMhMLlZwyy8CCjEzMjAwcAMxlwIDiP0fy\
IQS\n7P9fvbvDwPz/1fs7INb/F69vMzCCSQb2/93Jy4FSHQnL/s+p3vj/5Ru4FFA0\n\
13za/0neJ/7PD7oB5M0NvMbA8n9e0PX/k73O/G+JXAJSjVBcYDP9/7zQq//X\n\
xr4E8lbHPAcqXhP74v+CkFv/22OXYSqeG3Ll/xqgMub/q6KfAhWvjnn2f37w\n\
TXornhd67f86sJvXgN28Fuzm29gVT/Y//n9+6DUgb17IFVBoAD08xfc0puJC\n\
25n/C2xngDQBlYFIYHBaTPvfHrMUJZAZAQGh/Mc="]], 
                    "RGBColor[0.6672396717157738, 0.3586192991395154, \
0.8976595916455246]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.6672396717157738, 0.3586192991395154, 
                    0.8976595916455246]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.6672396717157738, 0.3586192991395154, 0.8976595916455246],
                   Editable -> False, Selectable -> False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}}, {{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.37001635641206, 0.3047563933568622, 0.7684408201506054], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    RGBColor[
                    0.24667757094137333`, 0.20317092890457483`, 
                    0.5122938801004037], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None, ImageCache -> 
                    GraphicsData[
                    "CompressedBitmap", 
                    "eJzzTSzJSM1NLMlMTlRwL0osyMhMLlZwyy8CCjEzMjAwcAMxlwIDiP0fy\
IQS\nHP9fv7/L+P/1uzuM/1+8vg0mGBjY/6fETGNg/p8YOeV/Tdni/y/f3GGASgFF\n\
rfQa/vs5rP4f6roDyAtx3cbAAmRv/+9ru/Z/VOAkoOrbCMV2xk3/Izy2/08I\n\
OA7kxfsfBSpO8D/2P9xt1/+40CmYisM9tgGVHQPy4vyOABXH+x39H+a2k96K\n\
IzxBbj4BdvMxsJuP/w93341dcZDLapAGIA9oB1AxyMMBjmsxFdubNANxE0gT\n\
UBmIBAanQQNQ4WSUQGYEAEcG4mo="]], 
                    "RGBColor[0.37001635641206, 0.3047563933568622, \
0.7684408201506054]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.37001635641206, 0.3047563933568622, 0.7684408201506054]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.37001635641206, 0.3047563933568622, 0.7684408201506054], 
                  Editable -> False, Selectable -> False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}}, {{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.38698691150966935`, 0.10328204902950966`, 
                    0.8013210231747274], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    RGBColor[
                    0.2579912743397796, 0.06885469935300645, 
                    0.5342140154498183], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None, ImageCache -> 
                    GraphicsData[
                    "CompressedBitmap", 
                    "eJzzTSzJSM1NLMlMTlRwL0osyMhMLlZwyy8CCjEzMjAwcAMxlwIDiP0fy\
IQS\nHP9fv7/LCCTuMP5/8fo2mGBgYP+f5jiLgfl/su2M/3UJy/6/fHuHASoFFLXl\n\
af0fLLjpf5TwASAvUngfAwuQvf9/IO+W/zEm04CqbyMUOwq1/4+V2Pc/VeoC\n\
kJcidQ6oOFXq/P9okYP/EyxnYCqOkdgLVga0XeoMUHGK1Nn/USIH6K0Yu5sP\n\
YVccJr4RqGE/kAe0A6gYpDlEaDOmYiehDrAGIAYqA5HA4ORtBSqcjhLIjACo\nTtsg"]], 
                    "RGBColor[0.38698691150966935, 0.10328204902950966, \
0.8013210231747274]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.38698691150966935`, 0.10328204902950966`, 
                    0.8013210231747274]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.38698691150966935`, 0.10328204902950966`, 
                   0.8013210231747274], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}}, {{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.29215345853340424`, 0.35497646703617836`, 
                    0.6346432521789236], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    RGBColor[
                    0.19476897235560284`, 0.2366509780241189, 
                    0.42309550145261576`], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None, ImageCache -> 
                    GraphicsData[
                    "CompressedBitmap", 
                    "eJzzTSzJSM1NLMlMTlRwL0osyMhMLlZwyy8CCjEzMjAwcAMxlwIDiP0fy\
IQS\n7P/fvLvLwPz/zfu7/1+/u/v/xevbDIxgkoH9f1RSC1AqPL7pf0n1lP8v39yB\n\
SQFFdcwy/tt69/x3CpoG5DkGTmNg+e8YNO2/pWfvf/+IOpBqhGJD6+z/rqHT\n\
//vELgHyvGMWAxV7xy757xQy839wTCMWxSHTwMqY/3tFLwIq9opZ/N8peAa9\n\
FbthcbMzLjc7+veCNAB5QDuAikEetvPtw1RsZJMDxNn/jayzgcpAJPN/PfMM\n\
oMIGlEBmBACO/N5s"]], 
                    "RGBColor[0.29215345853340424, 0.35497646703617836, \
0.6346432521789236]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.29215345853340424`, 0.35497646703617836`, 
                    0.6346432521789236]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.29215345853340424`, 0.35497646703617836`, 
                   0.6346432521789236], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}}, {{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.9678407581110904, 0.025426491397912976`, 
                    0.587777889276665], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    RGBColor[
                    0.6452271720740603, 0.01695099426527532, 
                    0.3918519261844433], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None, ImageCache -> 
                    GraphicsData[
                    "CompressedBitmap", 
                    "eJzzTSzJSM1NLMlMTlRwL0osyMhMLlZwyy8CCjEzMjAwcAMxlwIDiP0fy\
IQS\nHP9ffrjL+P/leyDx4vVtMAEUZ/6/xazu/2YIZmABk8z/NxlX/98b3v//xds7\n\
DAiVixgS/t9gaPz/kqEbyHvO0AVUD2T/vwMU26BZDlKNULyYJfn/M7ae/7/Z\n\
ZgB5P9mmAxUD2f/fMPT+36RXhan4KVs3WBnz/+9s04CKgez/rxh66K34OSlu\n\
vs7WBNIA5AHtACoGab7F0IypeClLyv8lQA1ATUBlIBISnBshCuGBzAgAOBvw\nJQ=="]], 
                    "RGBColor[0.9678407581110904, 0.025426491397912976, \
0.587777889276665]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.9678407581110904, 0.025426491397912976`, 
                    0.587777889276665]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.9678407581110904, 0.025426491397912976`, 
                   0.587777889276665], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}}, {{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.4918965330955356, 0.29233426982370303`, 
                    0.5281824844462943], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    RGBColor[
                    0.3279310220636904, 0.19488951321580203`, 
                    0.35212165629752956`], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None, ImageCache -> 
                    GraphicsData[
                    "CompressedBitmap", 
                    "eJy9kEFqwmAQhSekUKmXyAGKUJdCBbXGhYpCxKK7IIKKkjaZv6smWZqcU\
du1\nVtEjPOcXQUTddjHDmzffg2GaLo+GM5fHA9eq+e7HaDwILNvzxTINIspKPVmk\n\
NUSeWgab/a+Bv92PgdVmcWxEj+D+F5nw3xkpJ1hvl3Raidt67mLyGiAoh5op\n\
f9OD1pgUGNO2p+kz7Lz0oKoR4mYqU9RIBI4bKVQlhtfxr2GuhkfMRFifCxzV\n\
E3Al+m9Y2Tdufrtz86ykdEAmtkOBdXhaVNdwJ9+Hk+/pkGCixGvnuvCcz4sn\nGweVN9w+"]], 
                    "RGBColor[0.4918965330955356, 0.29233426982370303, \
0.5281824844462943]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.4918965330955356, 0.29233426982370303`, 
                    0.5281824844462943]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.4918965330955356, 0.29233426982370303`, 
                   0.5281824844462943], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}}, {{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.1252423737911874, 0.5183189386335805, 
                    0.7491160058315705], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    RGBColor[
                    0.08349491586079161, 0.34554595908905367`, 
                    0.4994106705543803], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None, ImageCache -> 
                    GraphicsData[
                    "CompressedBitmap", 
                    "eJzzTSzJSM1NLMlMTlRwL0osyMhMLlZwyy8CCjEzMjAwcAMxlwIDiP0fy\
IQS\nHP/fvLvL+P/12zuM/1+8vg0mGBjY/ztXTGZg/m9fNvF/Yu+C/y/f3GGASgFF\n\
+YNr/osXLPsvUbkZyJOo2MjAAmRv+i9UsOK/WUEfUPVthGLR8Lr/ctWb/iu0\n\
HQLyFFoPABUrtB38L1W99b918QQsiqs2ApUdBClu2Q9S3Hrgv1TVFrorBrv5\n\
MNjNB8FuPoTbzTLFy4AaQKEBtAOoGKRZomgFFsUR9WANQAxUBiKZ/wuE1EAV\nIgKZEQA2Hd/N"]],
                     "RGBColor[0.1252423737911874, 0.5183189386335805, \
0.7491160058315705]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.1252423737911874, 0.5183189386335805, 
                    0.7491160058315705]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.1252423737911874, 0.5183189386335805, 0.7491160058315705],
                   Editable -> False, Selectable -> False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}}, {{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.9765556387211944, 0.12357617097291551`, 
                    0.5068373458296718], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    RGBColor[
                    0.6510370924807963, 0.08238411398194367, 
                    0.33789156388644787`], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None, ImageCache -> 
                    GraphicsData[
                    "CompressedBitmap", 
                    "eJzzTSzJSM1NLMlMTlRwL0osyMhMLlZwyy8CCjEzMjAwcAMxlwIDiP0fy\
IQS\nHP9fvr/H+P/lu7uM/1+8vg0mGBjY/29xKWZg/r/ZofD/vqS2/y/e3mGASgFF\n\
F/MH/b8lnvf/lUQ5kPdSooyBBcT+f08o7/9G8+z/L97cQSheIhr6/4Vcxf+/\n\
Cs1A3m+FJqBiIPv/O6nK/5tt8jAVP5crBytj/v9ToRGoGMj+/0aqgt6KX5Li\n\
5psyBSBPAnnPgSQL2MN3JAowFS8TDfu/FKgBqAmoDEQCg1Mg6P8mkEKkQGYE\nAGRs6h4="]], 
                    "RGBColor[0.9765556387211944, 0.12357617097291551, \
0.5068373458296718]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.9765556387211944, 0.12357617097291551`, 
                    0.5068373458296718]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.9765556387211944, 0.12357617097291551`, 
                   0.5068373458296718], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}}, {{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}}, {{{{{{{
                    RGBColor[0.8227934753153485, 0.3797246867796864, 
                    0.6782582898466567], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    RGBColor[
                    0.5485289835435657, 0.25314979118645764`, 
                    0.45217219323110447`], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None, ImageCache -> 
                    GraphicsData[
                    "CompressedBitmap", 
                    "eJzzTSzJSM1NLMlMTlRwL0osyMhMLlZwyy8CCjEzMjAwcAMxlwIDiP0fy\
IQS\nHP9fvbvL+P8liHjx+jaYYGBg+r8grYuBA0h2glhIuPP/vOSO/2vrZv5/+eYO\n\
VDUD8/9Om/z/2wKn/j8asQjIOxy+gIHl/5GIhf93+k//Pzum5f8LZMXdDkX/\n\
D0cv/H8teQOQdyVpHVDx1eT1/49HLf4/N6ENU/GhqAVAZeuBvEuJa4GKLyet\n\
+38schG9FUPcvBHs5vVgN2/4fwKXm7eFTvt/JBocGlGg0ABp3hk8HVNxj2Px\n\
/27HIpAmoDIQCQrOArBCYBgzwFQyAgAcaQQO"]], 
                    "RGBColor[0.8227934753153485, 0.3797246867796864, \
0.6782582898466567]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.8227934753153485, 0.3797246867796864, 
                    0.6782582898466567]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.8227934753153485, 0.3797246867796864, 0.6782582898466567],
                   Editable -> False, Selectable -> False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}}, {{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.6820734720667967, 0.43856527685111324`, 
                    0.8695673460178908], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    RGBColor[
                    0.45471564804453113`, 0.29237685123407553`, 
                    0.5797115640119272], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None, ImageCache -> 
                    GraphicsData[
                    "CompressedBitmap", 
                    "eJzzTSzJSM1NLMlMTlRwL0osyMhMLlZwyy8CCjEzMjAwcAMxlwIDiP0fy\
IQS\nnP9fvbvD9P/F69tAHvP/3rwlQLwYhBlYwCTz/+7sRf/nta77//LNHQZGuMoC\n\
twn/p8Uf+r8o7SKQtzD1PFD9orQL/6fHHv3fnrIAqPo2QnGx16T/izLP/99Y\n\
9AjIW1/4AKh4Q9HD/0syLv/vyliEqXhhxrn/G4DKmP+vK7gHVLy+8P7/xemX\n\
6K14UeaF/5vAbt4AdvNGsJuvYFc8Peng/8WZ50GhkXEOFBpAD89IOIKpuMR7\n\
ClDDZJAmoDIgCxycE/93ZixECWRGAJLo/O8="]], 
                    "RGBColor[0.6820734720667967, 0.43856527685111324, \
0.8695673460178908]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.6820734720667967, 0.43856527685111324`, 
                    0.8695673460178908]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.6820734720667967, 0.43856527685111324`, 
                   0.8695673460178908], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}}, {{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.11654903299881392`, 0.07006336344132391, 
                    0.56484752468554], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    RGBColor[
                    0.07769935533254262, 0.04670890896088261, 
                    0.37656501645702667`], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None, ImageCache -> 
                    GraphicsData[
                    "CompressedBitmap", 
                    "eJzzTSzJSM1NLMlMTlRwL0osyMhMLlZwyy8CCjEzMjAwcAMxlwIDiP0fy\
IQS\n7P/fvL/LwPz/zYe7/1+/v/v/xevbDIxgkoH9v5NtNVDKzrLif0JMz/9Xb+/A\n\
pICifGwx/0W5qv+Lc7cCeeLcLQwsIPZ/Qdbq/6b6Jf9fvr2DUCzCE/9fRrDt\n\
v5zQJCBPTmgiUDGQ/V+Cp/2/lUk5NsWtYGUgxRPAiicCFbfRXzEJbpYSqAVp\n\
ACoDkcz/xbhrYQoZkFUmgFUDMVAliGT+z88eA1RZhhLCjAC1bsOG"]], 
                    "RGBColor[0.11654903299881392, 0.07006336344132391, \
0.56484752468554]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.11654903299881392`, 0.07006336344132391, 
                    0.56484752468554]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.11654903299881392`, 0.07006336344132391, 
                   0.56484752468554], Editable -> False, Selectable -> False],
                  ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}}, {{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.6402988781363921, 0.035330434441392944`, 
                    0.28001275709114415`], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    RGBColor[
                    0.4268659187575947, 0.02355362296092863, 
                    0.18667517139409612`], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None, ImageCache -> 
                    GraphicsData[
                    "CompressedBitmap", 
                    "eJzzTSzJSM1NLMlMTlRwL0osyMhMLlZwyy8CCjEzMjAwcAMxlwIDiP0fy\
IQS\nHP9ffbjH+P/VeyDx4vVtMMHAwP6/wyKUgfl/q0nQ/5kRef9fvr3DAJUCimYy\n\
aP/vYbT6P53JHsibxmTHwAJk2/3vZbD436jlDVKNUJzDZvB/BofT/6WcnkDe\n\
Ek4PoOKlnB7/ZzI7/G/R98dUPB2oGKSM+f9iTneg4iWc7v9n0F8xdjc7Ylfc\n\
x2EH1OAM5AHtACoGae5jtsFUnAtUnAPBQGUgEhicjDr/myEK4YHMCABtwssf\n"]], 
                    "RGBColor[0.6402988781363921, 0.035330434441392944, \
0.28001275709114415]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.6402988781363921, 0.035330434441392944`, 
                    0.28001275709114415`]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.6402988781363921, 0.035330434441392944`, 
                   0.28001275709114415`], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}}, {{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.4249737173056105, 0.08087713350797054, 
                    0.5561568741925262], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    RGBColor[
                    0.2833158115370737, 0.053918089005313696`, 
                    0.37077124946168416`], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None, ImageCache -> 
                    GraphicsData[
                    "CompressedBitmap", 
                    "eJzzTSzJSM1NLMlMTlRwL0osyMhMLlZwyy8CCjEzMjAwcAMxlwIDiP0fy\
IQS\nnP9fv7/L9P/F69sMDOz/s+2qGJj/Z1hV/G+K6/7/8u0dBkaIFFDUmSP6fzRP\n\
1f8kvmYgL5GviYEFxP4fyVH1P9GwGKQaodidL+5/qnDr/zzRCUBermg/UDGQ\n\
/T+Fv/V/qlkZpuIU4RawMub/OaJ9QMVA9v9k/hZ6KybJzXFCNSANQB7QDqBi\n\
kOYYvmpMxR588WANQAxUBiKBwckZDVRYihLIjAAoYcjg"]], 
                    "RGBColor[0.4249737173056105, 0.08087713350797054, \
0.5561568741925262]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.4249737173056105, 0.08087713350797054, 
                    0.5561568741925262]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.4249737173056105, 0.08087713350797054, 
                   0.5561568741925262], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}}, {{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.7495302686726302, 0.3453338459340154, 
                    0.3119406215616949], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    RGBColor[
                    0.4996868457817535, 0.23022256395601026`, 
                    0.20796041437446328`], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None, ImageCache -> 
                    GraphicsData[
                    "CompressedBitmap", 
                    
                    "eJzzTSzJSM1NLMlMTlRwL0osyMhMLlZwyy8CCjEzMjAwcAMxlwIDiP0fy\
IQR\nzP9fvb/3/9U7MGZgAZMIsRevbzMwgkkG9v/TEiOBUlPiwv4vrSr8//LNHZgU\n\
ULTa1OD/Uk+n/5v9PYC8jX7uQKM2+bv/X+5u/39CuD9INUJxnZXJ/03BXv8P\n\
RQUBeQciA4GKD0YF/t8S6Pl/cnQwpuKNQV7/DwKVMf/fHxEAVHwgMuD/5gAP\n\
eiveFOz9/zDYzQfBbj6Ez83LfF3/bw7yBoVGkBcoNIA2Lfd2xlRcb236vw6E\n\
rUyAykAk8/8ac8P/kyAK4YHMCABXHe94"]], 
                    "RGBColor[0.7495302686726302, 0.3453338459340154, \
0.3119406215616949]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.7495302686726302, 0.3453338459340154, 
                    0.3119406215616949]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.7495302686726302, 0.3453338459340154, 0.3119406215616949],
                   Editable -> False, Selectable -> False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}}, {{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.836090631447431, 0.10393312541533217`, 
                    0.9133348768403533], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    RGBColor[
                    0.5573937542982874, 0.06928875027688812, 
                    0.6088899178935689], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None, ImageCache -> 
                    GraphicsData[
                    "CompressedBitmap", 
                    "eJzzTSzJSM1NLMlMTlRwL0osyMhMLlZwyy8CCjEzMjAwcAMxlwIDiP0fy\
IQS\nHP9fvb/D+P8liHjx+jaYAIoz/1/kuPL/QghmYAGTzP8X2K74vy5h0/+Xb28z\n\
IFR288z4v1PozP8TIreBvGMit4Dqj4vc/r+H7/z/uSbL/r94i2Rsr9DM/8ck\n\
b/6/Kf0WyLsu/Rqo+Ib0m/+nRO/+n2+5HFPxUckbYGXM/69KvwQqvib96v9J\n\
0Tv0VnxM8haGm0+L3sOueKf46f/HJW8BeUA7gIpBHt4jfA5TcZ/QbKCGWSBN\n\
QGUgEhicvDP/zwMqRA5kRgC0if1y"]], 
                    "RGBColor[0.836090631447431, 0.10393312541533217, \
0.9133348768403533]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.836090631447431, 0.10393312541533217`, 
                    0.9133348768403533]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.836090631447431, 0.10393312541533217`, 
                   0.9133348768403533], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}}, {{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.19151655035273674`, 0.14390156161230028`, 
                    0.5247101500257152], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    RGBColor[
                    0.12767770023515784`, 0.09593437440820018, 
                    0.34980676668381017`], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None, ImageCache -> 
                    GraphicsData[
                    "CompressedBitmap", 
                    "eJzzTSzJSM1NLMlMTlRwL0osyMhMLlZwyy8CCjEzMjAwcAMxlwIDiP0fy\
IQS\nHP/fvL/H+P/1u7uM/1+8vg0mGBjY//u4lTIw//d0Kv6fmdL+/+WbOwxQKaCo\n\
jFDofzXpov+astUMLGCS+b+SWPF/R8s8NJWKEhH/dZVq/xuqdgB5hqrtQPVA\n\
9n8tubr/rnaFINXoimvAykCK28CK24GKa+mvmAQ3aymU/NdTqgXy9JRqgIqB\n\
7P/qMiXYFEeCNQAxUBmIBIalcChQYQFKuDECAPjoxNY="]], 
                    "RGBColor[0.19151655035273674, 0.14390156161230028, \
0.5247101500257152]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.19151655035273674`, 0.14390156161230028`, 
                    0.5247101500257152]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.19151655035273674`, 0.14390156161230028`, 
                   0.5247101500257152], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}}, {{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8789399682999111, 0.042929493135203334`, 
                    0.19233219566452364`], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    RGBColor[
                    0.5859599788666074, 0.028619662090135556`, 
                    0.1282214637763491], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None, ImageCache -> 
                    GraphicsData[
                    "CompressedBitmap", 
                    "eJzzTSzJSM1NLMlMTlRwL0osyMhMLlZwyy8CCjEzMjAwcAMxlwIDiP0fy\
IQS\nHP9ffbjP+P/l+3uM/1+8vg0mGBjY/y+39GJg/r/U1O3/5siU/y/f3mGASgFF\n\
JzLK/D/MrPb/EosmkHcRSLKA2P+PMSj/X6xt///F2zsIxZPZFf9f4NL9/4Tb\n\
EMh7BCRZ/j/mNvx/hVXr/1IDZ0zF54GKH4EVPwArfghUfJn+ii9icfNVXIoP\n\
cWoBNegBlV0Aksz/j7KowxQihdtUoMopQAzUAeQBWUD1IN2TmGT/LwGqfokw\nlhEAG1rSRA=="]],
                     "RGBColor[0.8789399682999111, 0.042929493135203334, \
0.19233219566452364]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.8789399682999111, 0.042929493135203334`, 
                    0.19233219566452364`]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.8789399682999111, 0.042929493135203334`, 
                   0.19233219566452364`], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}}, {{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8279081820793655, 0.007601665021679249, 
                    0.007776314948584773], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    RGBColor[
                    0.5519387880529103, 0.0050677766811195, 
                    0.005184209965723182], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None, ImageCache -> 
                    GraphicsData[
                    "CompressedBitmap", 
                    "eJzzTSzJSM1NLMlMTlRwL0osyMhMLlZwyy8CCjEzMjAwcAMxlwIDiP0fy\
IQS\nHP9ffbjP+P/leyDx4vVtMMHAwP5/oYkhA/P/+cYG/9eG+v9/+fYuA1QKKNoF\n\
1LcdiI+BeUeAJMv/o0D+LiCeo6b8/8XbuwjFPYyM/48wMf2/zsQE5F0Fkiz/\n\
rwH5J4CK52lrYCo+DJS8ClZ8Gaz4CpB/nP6Ksbn5JC7F24GSR8HKjoC17EIo\n\
RAq3XqDKHggGqgSRkLCcC1SJHMKMAHvWxHs="]], 
                    "RGBColor[0.8279081820793655, 0.007601665021679249, \
0.007776314948584773]"], Appearance -> None, BaseStyle -> {}, 
                   BaselinePosition -> Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.8279081820793655, 0.007601665021679249, 
                    0.007776314948584773]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.8279081820793655, 0.007601665021679249, 
                   0.007776314948584773], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}}, {{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.8905220469868362, 0.6720465313460078, 
                    0.8782899541874138], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    RGBColor[
                    0.5936813646578909, 0.44803102089733854`, 
                    0.5855266361249426], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None, ImageCache -> 
                    GraphicsData[
                    "CompressedBitmap", 
                    "eJy9j81OwlAQhW9TF0Zfok+jKx+\
iISawAKXyCibGuNHe6q63EOJPpHXjE2hE\n\
dtJyARNcKOWvis9wnHs1wQTXLuZkzuSbk5ktu5LfLtqVQs62Nh17N1/I7Vkb\n\
Ow6NTIMxtk61ZjHVg9ofWcX754uBTMnsY6CF5iaujuq4/C62otXExWENt36E\n\
bD5gC9ItHaPp3qMrOuSkHxMvRYIWf0R9P8Bs/ivWK7voiDam0YjcuDEkeBKm\n\
6Fe7OD+oLcOJ/4RxOCSXXr8SPGq8oRfI/4aliDG90TeH+uYoxXO19zf8wO8g\n\
g5hcItoEq4dbXnMZPnM8nJa5WtKrnGAVwEsnGs4WsPEFy64cpA=="]], 
                    "RGBColor[0.8905220469868362, 0.6720465313460078, \
0.8782899541874138]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.8905220469868362, 0.6720465313460078, 
                    0.8782899541874138]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.8905220469868362, 0.6720465313460078, 0.8782899541874138],
                   Editable -> False, Selectable -> False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}}, {{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.4739838883353795, 0.01643240988333261, 
                    0.7672816104627056], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    RGBColor[
                    0.31598925889025303`, 0.01095493992222174, 
                    0.5115210736418038], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None, ImageCache -> 
                    GraphicsData[
                    "CompressedBitmap", 
                    "eJzzTSzJSM1NLMlMTlRwL0osyMhMLlZwyy8CCjEzMjAwcAMxlwIDiP0fy\
IQS\nHP9ff7jL+P/V+zuM/1+8vg0mGBjY/xeZTWVg/l9gPOV/e/ii/y/f3mGASgFF\n\
fRjq/6czrPqfz7ADyMtj2MbAAmRv/5/GsPZ/psZEoOrbCMUBzI3/C1m2/a9m\n\
OQHkVbEcBSquZjn2v5Bh1/9c3cmYigtYtgKVHQPyKlmOABUDtfwvYNhJb8XI\n\
bj4GdvNxoJt3Y1ecybIKqGE7KMRYQKEB0pwJDA0MxYHMTWANQAxUBiKZ//sC\n\
gzNHdxJKIDMCAKl32cI="]], 
                    "RGBColor[0.4739838883353795, 0.01643240988333261, \
0.7672816104627056]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.4739838883353795, 0.01643240988333261, 
                    0.7672816104627056]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.4739838883353795, 0.01643240988333261, 
                   0.7672816104627056], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}}, {{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.73262590528079, 0.4345872718612065, 0.9513218213654053], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    RGBColor[
                    0.48841727018719333`, 0.289724847907471, 
                    0.634214547576937], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None, ImageCache -> 
                    GraphicsData[
                    "CompressedBitmap", 
                    "eJzzTSzJSM1NLMlMTlRwL0osyMhMLlZwyy8CCjEzMjAwcAMxlwIDiP0fy\
IQS\nnP9fvbvD9P/F69sMDOz/p+SuY2D+Pzlr7f/FLdv+v3xzm4ERIgUUrXSd/39R\n\
3NX/61OfAnlrUx4zsPxfl/rk/5KYG//7kteAVCMU13gu+L8u49H/fYXfgbw9\n\
BV+BivcWfvu/Mf3F/4npazEVr01/+H8vUBnz/935n4GK9xR8+b8h7Rm9Fa/L\n\
ePx/P9jNe8Fu3ofPzYsTL/9fn/EYFBrpD0GhAfTwkvjrmIprvRYBNSwEaQIq\n\
A5HM/6tcF/yfkL4GJZAZAfqM+y4="]], 
                    "RGBColor[0.73262590528079, 0.4345872718612065, \
0.9513218213654053]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.73262590528079, 0.4345872718612065, 0.9513218213654053]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.73262590528079, 0.4345872718612065, 0.9513218213654053], 
                  Editable -> False, Selectable -> False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}}, {{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}}, {{{{{{{
                    RGBColor[0.7193138046226939, 0.736637476380962, 
                    0.9909551197977506], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    RGBColor[
                    0.4795425364151293, 0.49109165092064133`, 
                    0.6606367465318338], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None, ImageCache -> 
                    GraphicsData[
                    "CompressedBitmap", 
                    "eJzzTSzJSM1NLMlMTlRwL0osyMhMLlZwyy8CCjEzMjAwcAMxlwIDiP0fy\
IQS\nnP9fvb3D9P/F69sMDOz/J03dzMD8v3/Spv+Llu76//LNbQZGiBRQtKxy6f95\n\
i+/+X73hPZC3ct1bBpb/q9a//79gyaP/Pf0bQaoRiitrlgElX//ftf8/kLdj\n\
73+g4p37/v9fu/HT/76JmzAVr1z3CqQAyNu+5y9QMVDL/zUbPtBb8ar1b/7v\n\
PgBSDNLCAnI/bjfPX3wHGBpvgLxV616BQ+MNMDQeYCquql0B1LAcpAmoDESC\n\
gnMZUOFGlEBmBADPwgqQ"]], 
                    "RGBColor[0.7193138046226939, 0.736637476380962, \
0.9909551197977506]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.7193138046226939, 0.736637476380962, 
                    0.9909551197977506]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.7193138046226939, 0.736637476380962, 0.9909551197977506], 
                  Editable -> False, Selectable -> False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}}, {{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.5532261835871646, 0.1424067735626049, 
                    0.6840947116434117], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    RGBColor[
                    0.3688174557247764, 0.0949378490417366, 
                    0.45606314109560786`], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None, ImageCache -> 
                    GraphicsData[
                    "CompressedBitmap", 
                    "eJzzTSzJSM1NLMlMTlRwL0osyMhMLlZwyy8CCjEzMjAwcAMxlwIDiP0fy\
IQS\nHP9fv7/L+P/VOyDx4vVtMAEUZ/5f49YNxF0gzMACJpn/Vzl1/p+QMvP/yzd3\n\
GBAqI4UK/ldKTfvfJLMYyGuUWQhU3ySz6H+F6Iz/JZatINUIxbESxf9bFBf9\n\
71fZCOT1qawHKu5X2fC/RXbJ/3K7dkzFzYoLgco2AHm9KuuAioFa/jfLLqa3\n\
YoibN4HdvAHs5o243VwtPx2oARQaQDuAikGaq6RnYCqOkygBawBioDIQyfw/\n\
SrgQphAeyIwAAp7l+g=="]], 
                    "RGBColor[0.5532261835871646, 0.1424067735626049, \
0.6840947116434117]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.5532261835871646, 0.1424067735626049, 
                    0.6840947116434117]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.5532261835871646, 0.1424067735626049, 0.6840947116434117],
                   Editable -> False, Selectable -> False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}}, {{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.24015696649735507`, 0.2276921291555416, 
                    0.5618669828113934], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    RGBColor[
                    0.16010464433157007`, 0.15179475277036109`, 
                    0.37457798854092894`], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None, ImageCache -> 
                    GraphicsData[
                    "CompressedBitmap", 
                    "eJzzTSzJSM1NLMlMTlRwL0osyMhMLlZwyy8CCjEzMjAwcAMxlwIDiP0fy\
IQS\nHP/fvL/L+P/1OyDx4vVtMMHAwP4/OKiagfl/gF/F/7zcnv8v39xhgEoBRVWU\n\
Yv4b6lX/NzVqAfJMDJsZWIBky3897er/Hm4lINUIxZrq8f8tzdr+21lPBPJs\n\
rSYAFdtaTfxvZtz238e7HJviVqDiCWDF/WDFE4CKW+mvuO2/vQ3IzSAtLCD3\n\
43azmXHtf0vzNiAPaAdQMUizkX4NNsUJYA1ADFQGIpn/qwKD08erDCWQGQEY\ntc7C"]], 
                    "RGBColor[0.24015696649735507, 0.2276921291555416, \
0.5618669828113934]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.24015696649735507`, 0.2276921291555416, 
                    0.5618669828113934]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.24015696649735507`, 0.2276921291555416, 
                   0.5618669828113934], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}}}}}}}, {{{{{{{
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}}}}}}}, {{{{{{{
                    RGBColor[
                    0.3614530023699991, 0.23838000474075272`, 
                    0.351099450461986], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}}}}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    RGBColor[
                    0.24096866824666607`, 0.1589200031605018, 
                    0.23406630030799067`], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None, ImageCache -> 
                    GraphicsData[
                    "CompressedBitmap", 
                    "eJzzTSzJSM1NLMlMTlRwL0osyMhMLlZwyy8CCjEzMjAwcAMxlwIDiP0fy\
IQS\nHP9fv7/H+P/1OyDx4vVtMMHAwP4/KTiegfl/fEDM/+r80v8v39xhgEoBRS1U\n\
zP/7GHr/DzYNBPKCTAIYWP4HmwT+99bz/B/hEQpSjVBso2n9P8wy5H+cXQyQ\n\
F2sbDVQcZxvzP9Qs+H+MTySm4lDL4P+xdtFAXoxtFFAxUMv/ELMgeisGu9ke\n\
7GY7sJvt8Lg5wMwPpAHIA9oBVAzS7Gfkg6aY6b+tpg0rSAMoEFXNYdLwoGUE\nAJL5x88="]], 
                    "RGBColor[0.3614530023699991, 0.23838000474075272, \
0.351099450461986]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.3614530023699991, 0.23838000474075272`, 
                    0.351099450461986]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.3614530023699991, 0.23838000474075272`, 
                   0.351099450461986], Editable -> False, Selectable -> 
                  False]}], "}"}]}], "}"}]], "ExerciseOutput", Selectable -> 
        False, Copyable -> False, Editable -> False, ShowCellBracket -> 
        False]]], " "}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Center}}},
   GridBoxBackground->{"Columns" -> {{
        RGBColor[1, 1, 1]}}},
   GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{1}}}],
  FrameMargins->0]], "ExerciseOutput",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellFrame->{{1, 1}, {1, 1}},
 ShowCellBracket->False,
 CellFrameColor->RGBColor[0.85, 0.85, 0.85],
 LineBreakWithin->
  Automatic,ExpressionUUID->"16a2a7b1-1e66-436b-a294-d063a247159b"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Make a feature space plot for both upper and lowercase letters of the \
alphabet.",
 StyleBox[ButtonBox["\[NonBreakingSpace]\[RightGuillemet]",
  Appearance->None,
  Evaluator->Automatic,
  Method->"Preemptive",
  ButtonFunction:>(SelectionMove[
     ButtonNotebook[], All, ButtonCell, AutoScroll -> False]; 
   FrontEndExecute[
     FrontEndToken[
      ButtonNotebook[], "OpenCloseGroup"]])],
  FontColor->RGBColor[1, 0.501961, 0]]
}], "Exercise",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellDingbat->Cell[
  "+22.7", "ExerciseNumber", FontColor -> 
   RGBColor[0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]],
 ShowCellBracket->
  False,ExpressionUUID->"b52d2315-f6ec-4354-8fa2-94cff4cb2445"],

Cell[BoxData[
 PaneBox[GridBox[{
    {" ", 
     StyleBox[
      RowBox[{"Expected", " ", 
       RowBox[{"output", ":"}]}],
      Editable->False,
      Selectable->False,
      StripOnInput->False,
      FontColor->RGBColor[0.45, 0.45, 0.45]], " "},
    {" ", 
     InterpretationBox[Cell[BoxData[
       GraphicsBox[{{}, {{}, 
          {Hue[0.67, 0.6, 0.6], Opacity[0], PointBox[CompressedData["
1:eJwBUQOu/CFib1JlAgAAADQAAAACAAAAWasgD2RLBsCJyBzvAdwGwADJlHjw
jBLAeSLcCVEE+L/F6yCsb00HwBY4Eu6Ujuy/LmiMbTmSD8Afq5U+ryXUP3mM
L1jQpwfAJsWw7HDD8b/IO6uvPzIZQF7SAxBJCum/lLz/FX05GcB+ciLyR73k
v4I/dGoOXBHAyfod02uxA8C8xJzt4P0WQJzyIaNTsdg/C7DTpoxs5b95qkWS
7N0QwNHy30fttABA67jNnzjq5b/lTfbKRRUXQJ6Dz7QFeNg/n8VZnOWj7L8n
knfRxlz4vwAX09QKFhDAVcGYXLa4A8Bhn4WkH7wPwGLq1tKzVOK/aSxqWPm9
EsBj/iQJYzXxv20jlp5QRhLApG7ORH+IpD9n9QLi57ATQHdkENtccvC/jZsr
xY61BMDYnFXi8SP9v+dSeae/1xZAvWzC4I1Y8L+4ES3VqkYGwAZeDHl7teQ/
txfaThYX9T93hYgJw3QSwOiYgkxvkeQ/dij6aq6nAcAXyRUodv4AQIkhO7KH
APC/ylhFeNh+9D+fmsU3DgETwD4NABwgkvK/w0YSCUOBA8BF8BZw3V4LwLJM
Ri/AORHAms7QGmOu8b8MZtuZ8VwSQLRcC7CkJfi//LFJ49ZXCEBH/grIQJIC
wHdTRgGdDxFAp9GlFUL85D9G6FX0joYNQIInVF/npPI/1ePIOuiVDUCTuwO1
wK/4v8LjsAeObQpAMElfjnwc4j9MRXenNrThP8lvECh1VhdAkBptZyov3z/d
T9YOL4X7v3Yk/MLw0Ok/2hzJPjIrAkDhItbcwOb0P4I9P1KAvdO/7gmGYb3o
AkDm9fsyVgTkP/NmFDoJrMG/Y7YiwJyT8D94xY9RAqDYP8uAWvak9QPA/3yc
BtbqCECs7YOdZd/3P2ifCTfv/AZAXb1TTy8aCMDILj/5NJoJQNsAwjA2Rfk/
JduAb6j2A0BwHZT2oU3hv3sC2KjkrBNAKV3To6zuG0DAf0+zOSreP+ZMYjTb
J/6/8kytNCbU8z/NhzUgCIMOQHq6bpmjQArAaoH5STh35D/Vx02gW+sBwLT/
imgwlwVADaPFklQx8T8KKdRs/8cPQKxHF4rKxwjA/TdLulXMDkBezxuHb6wI
QMo9nrI=
            "]]}, {}}, {}, {}, {{}, {}}, {{}, {InsetBox[
            PaneBox[
             FrameBox[
              StyleBox[
               GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmIOIAax/1MVfH/36tW7T6hi75YWODJAQEznxAI9Bv/5
IBVPt4MEJm5/8PT60iZ/kKzjjHf///9+sBHITNv+CmLefH+QONjEp51gYwom
rr5052yTHlwcZMWh1RNjHPWgtoDNgTjmN1TB00oGBr3OE2D2p4kghTEzVm+c
UQmyN2bpdagp1w91FvjDXLrxHXWDhsYAALgCdNE=
                 "], {{0, 0}, {8, 
                 19}}, {0, 255},
                 ColorFunction->RGBColor],
                ImageSize->{8, 19},
                PlotRange->{{0, 8}, {0, 19}}],
               StripOnInput->False,
               Opacity->1,
               FontOpacity->1,
               $CellContext`LineOpacity -> 1,
               $CellContext`FrontFaceOpacity -> 1,
               $CellContext`BackFaceOpacity -> 1],
              LabelStyle -> {},
              Frame -> True,
              Background->Directive[
                Opacity[0]],
              ContentPadding->False,
              FrameMargins->2,
              FrameStyle->None,
              RoundingRadius->4,
              StripOnInput->False],
             
             FrameMargins->
              0], {-2.7868119413227928, -2.857425563875101}, {0, 0}], InsetBox[
            PaneBox[
             FrameBox[
              StyleBox[
               GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmIOIAax/1Md/P7+7tW777/h/E8z/Bkc09L0GCBAr3P7
HYj4fH8wd/Wh65f2FoClVz/4DlLvyOA48RJU96u9QBn/GZdg4mcRxjoyMMQs
xRQHGes/H6qgYON3mDlAHlgZxF6gmsqlq+dDnDX/+ieY+hnzm2LAzvSfCHMn
insQAM1ehPhEPaCvMMX/f//0CSlYqAwAru1ogw==
                 "], {{0, 0}, {8, 
                 19}}, {0, 255},
                 ColorFunction->RGBColor],
                ImageSize->{8, 19},
                PlotRange->{{0, 8}, {0, 19}}],
               StripOnInput->False,
               Opacity->1,
               FontOpacity->1,
               $CellContext`LineOpacity -> 1,
               $CellContext`FrontFaceOpacity -> 1,
               $CellContext`BackFaceOpacity -> 1],
              LabelStyle -> {},
              Frame -> True,
              Background->Directive[
                Opacity[0]],
              ContentPadding->False,
              FrameMargins->2,
              FrameStyle->None,
              RoundingRadius->4,
              StripOnInput->False],
             
             FrameMargins->
              0], {-4.637636074143529, -1.5010538468506225}, {0, 0}], InsetBox[
            PaneBox[
             FrameBox[
              StyleBox[
               GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmJ2IAax/1MJfHr37tW7T79h3N+vThQ4MsCA/+pLr/7/
f9AEYutN3H72zp0Tnf4MlRsffLo0AyiUtvQOilEgQb29r/5jCDKsfvAbWfD7
9flAQcemQzBbIbLfV6eBba2csXR+px4DQ9MhiFnvtk+EOsq/YMb1dyhGDRIA
AEmSUzY=
                 "], {{0, 0}, {7, 19}}, {0, 255},
                 ColorFunction->RGBColor],
                ImageSize->{7, 19},
                PlotRange->{{0, 7}, {0, 19}}],
               StripOnInput->False,
               Opacity->1,
               FontOpacity->1,
               $CellContext`LineOpacity -> 1,
               $CellContext`FrontFaceOpacity -> 1,
               $CellContext`BackFaceOpacity -> 1],
              LabelStyle -> {},
              Frame -> True,
              Background->Directive[
                Opacity[0]],
              ContentPadding->False,
              FrameMargins->2,
              FrameStyle->None,
              RoundingRadius->4,
              StripOnInput->False],
             
             FrameMargins->
              0], {-2.9128106544062313, -0.8924049997165209}, {0, 0}], 
           InsetBox[
            PaneBox[
             FrameBox[
              StyleBox[
               GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmIOIAax/1MZfH/36tWn77+Rhd5dWu3PAAWVnU16DAzz
L336//16GkjAf+mJ69dPLIUomHj23adLM4CMzkPvIHo/nZ2IJK63/SnUZIgy
uPqld76jiX+/vhTIcOzcCzMHKg504VKIxZUzls5oYoDZC1L0++nSphig8xj0
/NPADppx9h2a935fn49QjwTg9uIQ/4QRUL8/ffr0G0OUbAAA6cVhWQ==
                 
                 "], {{0, 0}, {8, 19}}, {0, 255},
                 ColorFunction->RGBColor],
                ImageSize->{8, 19},
                PlotRange->{{0, 8}, {0, 19}}],
               StripOnInput->False,
               Opacity->1,
               FontOpacity->1,
               $CellContext`LineOpacity -> 1,
               $CellContext`FrontFaceOpacity -> 1,
               $CellContext`BackFaceOpacity -> 1],
              LabelStyle -> {},
              Frame -> True,
              Background->Directive[
                Opacity[0]],
              ContentPadding->False,
              FrameMargins->2,
              FrameStyle->None,
              RoundingRadius->4,
              StripOnInput->False],
             
             FrameMargins->
              0], {-3.9463985975717355, 0.314800082319083}, {0, 0}], 
           InsetBox[
            PaneBox[
             FrameBox[
              StyleBox[
               GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmJ2IAax/1MJfP/07tWrd99/w/jvzjb5M8BB5dKz//8/
bdIDMvVmbD/74MH1jRMLmlZf/3RpBlBo4tlPyEZBBGOaJs4AgolgcsZqiKBj
QVNnExB0FsSAjPp+fT7I8O1PIRrvzAda2Ql0y+o0kKUFM1ZvnN8E0jXxLFj+
1erOND2we9I6N76jls+pCgBA10GE
                 "], {{0, 0}, {7, 19}}, {0, 255},
                 
                 ColorFunction->RGBColor],
                ImageSize->{7, 19},
                PlotRange->{{0, 7}, {0, 19}}],
               StripOnInput->False,
               Opacity->1,
               FontOpacity->1,
               $CellContext`LineOpacity -> 1,
               $CellContext`FrontFaceOpacity -> 1,
               $CellContext`BackFaceOpacity -> 1],
              LabelStyle -> {},
              Frame -> True,
              Background->Directive[
                Opacity[0]],
              ContentPadding->False,
              FrameMargins->2,
              FrameStyle->None,
              RoundingRadius->4,
              StripOnInput->False],
             
             FrameMargins->
              0], {-2.9569403543005675, -1.1102151151392916}, {0, 0}], 
           InsetBox[
            PaneBox[
             FrameBox[
              StyleBox[
               
               GraphicsBox[
                RasterBox[{{{255, 255, 255}, {255, 255, 255}, {255, 255, 
                 255}, {255, 255, 255}, {255, 255, 255}}, {{255, 255, 255}, {
                 255, 255, 255}, {255, 255, 255}, {255, 255, 255}, {255, 255, 
                 255}}, {{255, 255, 255}, {255, 255, 255}, {255, 255, 255}, {
                 255, 255, 255}, {255, 255, 255}}, {{255, 255, 255}, {255, 
                 255, 255}, {255, 255, 255}, {255, 255, 255}, {255, 255, 
                 255}}, {{255, 255, 255}, {210, 152, 79}, {0, 65, 152}, {242, 
                 255, 255}, {255, 255, 255}}, {{255, 255, 255}, {210, 152, 
                 65}, {0, 46, 152}, {242, 255, 255}, {255, 255, 255}}, {{255, 
                 255, 255}, {210, 152, 65}, {0, 46, 152}, {242, 255, 255}, {
                 255, 255, 255}}, {{255, 255, 255}, {210, 152, 65}, {0, 46, 
                 152}, {242, 255, 255}, {255, 255, 255}}, {{255, 255, 255}, {
                 210, 152, 65}, {0, 46, 152}, {242, 255, 255}, {255, 255, 
                 255}}, {{255, 255, 255}, {215, 159, 79}, {0, 46, 152}, {247, 
                 255, 255}, {255, 255, 255}}, {{224, 189, 159}, {92, 65, 0}, {
                 0, 0, 65}, {112, 130, 137}, {189, 224, 247}}, {{220, 177, 
                 130}, {46, 0, 0}, {0, 0, 0}, {65, 65, 79}, {165, 215, 
                 242}}, {{255, 255, 255}, {215, 159, 79}, {0, 65, 159}, {251, 
                 255, 255}, {255, 255, 255}}, {{255, 255, 255}, {205, 145, 
                 65}, {0, 0, 102}, {194, 220, 229}, {229, 229, 238}}, {{255, 
                 255, 255}, {242, 210, 165}, {0, 0, 0}, {0, 0, 0}, {0, 0, 
                 137}}, {{255, 255, 255}, {255, 255, 255}, {251, 242, 229}, {
                 220, 215, 220}, {229, 238, 242}}, {{255, 255, 255}, {255, 
                 255, 255}, {255, 255, 255}, {255, 255, 255}, {255, 255, 
                 255}}, {{255, 255, 255}, {255, 255, 255}, {255, 255, 255}, {
                 255, 255, 255}, {255, 255, 255}}, {{255, 255, 255}, {255, 
                 255, 255}, {255, 255, 255}, {255, 255, 255}, {255, 255, 
                 255}}}, {{0, 0}, {5, 19}}, {0, 255},
                 ColorFunction->RGBColor],
                ImageSize->{5, 19},
                PlotRange->{{0, 5}, {0, 19}}],
               StripOnInput->False,
               Opacity->1,
               FontOpacity->1,
               $CellContext`LineOpacity -> 1,
               $CellContext`FrontFaceOpacity -> 1,
               $CellContext`BackFaceOpacity -> 1],
              LabelStyle -> {},
              Frame -> True,
              Background->Directive[
                Opacity[0]],
              ContentPadding->False,
              FrameMargins->2,
              FrameStyle->None,
              RoundingRadius->4,
              StripOnInput->False],
             
             FrameMargins->
              0], {6.299071068598046, -0.7825055420676781}, {0, 0}], 
           InsetBox[
            PaneBox[
             FrameBox[
              StyleBox[
               GraphicsBox[RasterBox[CompressedData["
1:eJzNkKGOxCAQhic5c36fYF+g78ATkKxGrcBe7VlcJa4vUFVVVXVmFQaDqUFg
MBUVYxAV7ADZ3GWf4L5kkh+Yn3/gev+63T8A4EL1SVV0Lpx79JuzbvM7nrmR
NsXgL1L/pJwPMwB083a0JjcrOlKPHd1I+4vHMyGmhGElN9OWHAO80S3hzGg5
gNCrD8FXXtFRM2C9HrUepzVgfpGWviMzl7LOxU0bAQ0t+9kXfTxIy6bRkh5s
83tBPWusOnzX1yzGTEoUKQYTU/mFaJSod3cUIjnjk/uN/+c8ATefUqA=
                 
                 "], {{0, 0}, {8, 19}}, {0, 255},
                 ColorFunction->RGBColor],
                ImageSize->{8, 19},
                PlotRange->{{0, 8}, {0, 19}}],
               StripOnInput->False,
               Opacity->1,
               FontOpacity->1,
               $CellContext`LineOpacity -> 1,
               $CellContext`FrontFaceOpacity -> 1,
               $CellContext`BackFaceOpacity -> 1],
              LabelStyle -> {},
              Frame -> True,
              Background->Directive[
                Opacity[0]],
              ContentPadding->False,
              FrameMargins->2,
              FrameStyle->None,
              RoundingRadius->4,
              StripOnInput->False],
             
             FrameMargins->
              0], {-6.306141227468419, -0.6481055955114952}, {0, 0}], InsetBox[
            PaneBox[
             FrameBox[
              StyleBox[
               GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmIOIAax/9McfJrhyOA48SyUc2k+A4P/2U+Y4jMYGBzJ
F59xCas4Q9r8d2Dxdyc6geInwOLzYxhAQK9g/tKJ/iCW/9nvUPV6Tas3TkwD
SztO3PsAyf2X8PsLWXyiHoNeJ6b4/++fPn3/TUYAEgUAWvd3fQ==
                 "], {{0,
                  0}, {8, 19}}, {0, 255},
                 ColorFunction->RGBColor],
                ImageSize->{8, 19},
                PlotRange->{{0, 8}, {0, 19}}],
               StripOnInput->False,
               Opacity->1,
               FontOpacity->1,
               $CellContext`LineOpacity -> 1,
               $CellContext`FrontFaceOpacity -> 1,
               $CellContext`BackFaceOpacity -> 1],
              LabelStyle -> {},
              Frame -> True,
              Background->Directive[
                Opacity[0]],
              ContentPadding->False,
              FrameMargins->2,
              FrameStyle->None,
              RoundingRadius->4,
              StripOnInput->False],
             
             FrameMargins->
              0], {-4.339898742051334, -2.461631440498739}, {0, 0}], 
           InsetBox[
            PaneBox[
             FrameBox[
              StyleBox[
               
               GraphicsBox[
                RasterBox[{{{255, 255, 255}, {255, 255, 255}, {255, 255, 
                 255}, {255, 255, 255}}, {{255, 255, 255}, {255, 255, 255}, {
                 255, 255, 255}, {255, 255, 255}}, {{255, 255, 255}, {255, 
                 255, 255}, {255, 255, 255}, {255, 255, 255}}, {{255, 255, 
                 255}, {255, 255, 255}, {255, 255, 255}, {255, 255, 255}}, {{
                 255, 255, 242}, {152, 65, 0}, {65, 145, 205}, {255, 255, 
                 255}}, {{255, 255, 242}, {152, 65, 0}, {65, 145, 205}, {255, 
                 255, 255}}, {{255, 255, 242}, {152, 65, 0}, {65, 145, 205}, {
                 255, 255, 255}}, {{255, 255, 242}, {152, 65, 0}, {65, 145, 
                 205}, {255, 255, 255}}, {{255, 255, 242}, {152, 65, 0}, {65, 
                 145, 205}, {255, 255, 255}}, {{255, 255, 242}, {152, 65, 
                 0}, {65, 145, 205}, {255, 255, 255}}, {{255, 255, 242}, {152,
                  46, 0}, {46, 145, 205}, {255, 255, 255}}, {{255, 255, 
                 242}, {177, 121, 79}, {121, 171, 215}, {255, 255, 255}}, {{
                 255, 255, 255}, {251, 247, 247}, {251, 251, 255}, {255, 255, 
                 255}}, {{255, 247, 205}, {65, 0, 0}, {0, 46, 145}, {242, 255,
                  255}}, {{255, 251, 224}, {145, 102, 79}, {102, 145, 189}, {
                 251, 255, 255}}, {{255, 255, 255}, {255, 255, 255}, {255, 
                 255, 255}, {255, 255, 255}}, {{255, 255, 255}, {255, 255, 
                 255}, {255, 255, 255}, {255, 255, 255}}, {{255, 255, 255}, {
                 255, 255, 255}, {255, 255, 255}, {255, 255, 255}}, {{255, 
                 255, 255}, {255, 255, 255}, {255, 255, 255}, {255, 255, 
                 255}}}, {{0, 0}, {4, 19}}, {0, 255},
                 ColorFunction->RGBColor],
                ImageSize->{4, 19},
                PlotRange->{{0, 4}, {0, 19}}],
               StripOnInput->False,
               Opacity->1,
               FontOpacity->1,
               $CellContext`LineOpacity -> 1,
               $CellContext`FrontFaceOpacity -> 1,
               $CellContext`BackFaceOpacity -> 1],
              LabelStyle -> {},
              Frame -> True,
              Background->Directive[
                Opacity[0]],
              ContentPadding->False,
              FrameMargins->2,
              FrameStyle->None,
              RoundingRadius->4,
              StripOnInput->False],
             
             FrameMargins->
              0], {5.74792834538783, 0.3858231633273961}, {0, 0}], InsetBox[
            PaneBox[
             FrameBox[
              StyleBox[
               
               GraphicsBox[
                RasterBox[{{{247, 242, 234}, {224, 224, 224}, {234, 242, 
                 255}, {255, 255, 255}}, {{177, 92, 0}, {0, 0, 0}, {0, 0, 
                 46}, {177, 224, 247}}, {{247, 238, 234}, {224, 210, 177}, {
                 65, 0, 0}, {79, 145, 205}}, {{255, 255, 255}, {255, 255, 
                 242}, {159, 65, 0}, {65, 145, 205}}, {{255, 255, 255}, {255, 
                 255, 242}, {152, 65, 0}, {65, 145, 205}}, {{255, 255, 255}, {
                 255, 255, 242}, {152, 65, 0}, {65, 145, 205}}, {{255, 255, 
                 255}, {255, 255, 242}, {152, 65, 0}, {65, 145, 205}}, {{255, 
                 255, 255}, {255, 255, 242}, {152, 65, 0}, {65, 145, 205}}, {{
                 255, 255, 255}, {255, 255, 242}, {152, 65, 0}, {65, 145, 
                 205}}, {{255, 255, 255}, {255, 255, 242}, {152, 65, 0}, {65, 
                 145, 205}}, {{255, 255, 255}, {255, 255, 242}, {152, 46, 
                 0}, {46, 145, 205}}, {{255, 255, 255}, {255, 255, 242}, {177,
                  121, 79}, {121, 171, 215}}, {{255, 255, 255}, {255, 255, 
                 255}, {251, 247, 247}, {251, 251, 255}}, {{255, 255, 255}, {
                 255, 247, 205}, {65, 0, 0}, {0, 46, 145}}, {{255, 255, 
                 255}, {255, 251, 224}, {152, 102, 79}, {102, 145, 189}}, {{
                 255, 255, 255}, {255, 255, 255}, {255, 255, 255}, {255, 255, 
                 255}}, {{255, 255, 255}, {255, 255, 255}, {255, 255, 255}, {
                 255, 255, 255}}, {{255, 255, 255}, {255, 255, 255}, {255, 
                 255, 255}, {255, 255, 255}}, {{255, 255, 255}, {255, 255, 
                 255}, {255, 255, 255}, {255, 255, 255}}}, {{0, 0}, {4, 
                 19}}, {0, 255},
                 ColorFunction->RGBColor],
                ImageSize->{4, 19},
                PlotRange->{{0, 4}, {0, 19}}],
               StripOnInput->False,
               Opacity->1,
               FontOpacity->1,
               $CellContext`LineOpacity -> 1,
               $CellContext`FrontFaceOpacity -> 1,
               $CellContext`BackFaceOpacity -> 1],
              LabelStyle -> {},
              Frame -> True,
              Background->Directive[
                Opacity[0]],
              ContentPadding->False,
              FrameMargins->2,
              FrameStyle->None,
              RoundingRadius->4,
              StripOnInput->False],
             
             FrameMargins->
              0], {-0.6695006616914737, -4.216722760679311}, {0, 0}], InsetBox[
            PaneBox[
             FrameBox[
              StyleBox[
               GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmJ2IAax/9MEfJrhyOA44yyEc2d1AdgisODES2D5E/5A
obSlIEEw69Kn73sr9RgYHA+9AknPBwlCQcHq6xAzQYKOMWCZmDvIFs2//u7s
DJDo/LMIwYkg9tkZMUDxpr1PkQWB7I1NMY7+naiCqI7HEJyox6DXiSb4//un
T99/UynMwAAAWXY8rQ==
                 "], {{0, 0}, {7, 19}}, {0, 255},
                 ColorFunction->RGBColor],
                ImageSize->{7, 19},
                PlotRange->{{0, 7}, {0, 19}}],
               StripOnInput->False,
               Opacity->1,
               FontOpacity->1,
               $CellContext`LineOpacity -> 1,
               $CellContext`FrontFaceOpacity -> 1,
               $CellContext`BackFaceOpacity -> 1],
              LabelStyle -> {},
              Frame -> True,
              Background->Directive[
                Opacity[0]],
              ContentPadding->False,
              FrameMargins->2,
              FrameStyle->None,
              RoundingRadius->4,
              StripOnInput->False],
             
             FrameMargins->
              0], {2.088343202134958, -0.6848414536632651}, {0, 0}], 
           InsetBox[
            PaneBox[
             FrameBox[
              StyleBox[
               
               GraphicsBox[
                RasterBox[{{{255, 255, 255}, {255, 255, 255}, {255, 255, 
                 255}, {255, 255, 255}}, {{255, 255, 255}, {255, 255, 255}, {
                 255, 255, 255}, {255, 255, 255}}, {{255, 255, 255}, {255, 
                 255, 255}, {255, 255, 255}, {255, 255, 255}}, {{255, 255, 
                 255}, {255, 255, 251}, {238, 234, 238}, {247, 251, 255}}, {{
                 255, 255, 247}, {171, 102, 0}, {0, 0, 0}, {130, 200, 
                 238}}, {{255, 255, 242}, {152, 65, 0}, {0, 112, 165}, {234, 
                 251, 255}}, {{255, 255, 242}, {152, 65, 0}, {65, 145, 210}, {
                 255, 255, 255}}, {{255, 255, 242}, {152, 65, 0}, {65, 145, 
                 205}, {255, 255, 255}}, {{255, 255, 242}, {152, 65, 0}, {65, 
                 145, 205}, {255, 255, 255}}, {{255, 255, 242}, {152, 65, 
                 0}, {65, 145, 205}, {255, 255, 255}}, {{255, 255, 242}, {152,
                  65, 0}, {65, 145, 205}, {255, 255, 255}}, {{255, 255, 
                 242}, {152, 65, 0}, {65, 145, 205}, {255, 255, 255}}, {{255, 
                 255, 242}, {152, 65, 0}, {65, 145, 205}, {255, 255, 255}}, {{
                 255, 255, 242}, {152, 65, 0}, {65, 145, 205}, {255, 255, 
                 255}}, {{255, 255, 242}, {145, 46, 0}, {46, 137, 205}, {255, 
                 255, 255}}, {{255, 255, 255}, {247, 242, 242}, {247, 251, 
                 255}, {255, 255, 255}}, {{255, 255, 255}, {255, 255, 255}, {
                 255, 255, 255}, {255, 255, 255}}, {{255, 255, 255}, {255, 
                 255, 255}, {255, 255, 255}, {255, 255, 255}}, {{255, 255, 
                 255}, {255, 255, 255}, {255, 255, 255}, {255, 255, 255}}}, {{
                 0, 0}, {4, 19}}, {0, 255},
                 ColorFunction->RGBColor],
                ImageSize->{4, 19},
                PlotRange->{{0, 4}, {0, 19}}],
               StripOnInput->False,
               Opacity->1,
               FontOpacity->1,
               $CellContext`LineOpacity -> 1,
               $CellContext`FrontFaceOpacity -> 1,
               $CellContext`BackFaceOpacity -> 1],
              LabelStyle -> {},
              Frame -> True,
              Background->Directive[
                Opacity[0]],
              ContentPadding->False,
              FrameMargins->2,
              FrameStyle->None,
              RoundingRadius->4,
              StripOnInput->False],
             
             FrameMargins->
              0], {5.770774050982685, 0.38232557923589094}, {0, 0}], 
           InsetBox[
            PaneBox[
             FrameBox[
              StyleBox[
               GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmIeIAax/w868GmGI4PjxLMQzvWlaQwMMWe/gznfL/kz
MEw8+w5NzaUZQGH/E58gas464lZzlmw1My6hqIG65yyyexjSlr5DqNFbfR2s
6NVePbgaoDAQOBbMn9HkyAAFlTNmVILFl4LUf1pdEDP/0NnVTWAhvZjtd949
2DsDorhg/onftAv1oQAAv+g8EQ==
                 "], {{0, 0}, {12, 19}}, {0, 255},
                 ColorFunction->RGBColor],
                ImageSize->{12, 19},
                PlotRange->{{0, 12}, {0, 19}}],
               StripOnInput->False,
               Opacity->1,
               FontOpacity->1,
               $CellContext`LineOpacity -> 1,
               $CellContext`FrontFaceOpacity -> 1,
               $CellContext`BackFaceOpacity -> 1],
              LabelStyle -> {},
              Frame -> True,
              Background->Directive[
                Opacity[0]],
              ContentPadding->False,
              FrameMargins->2,
              FrameStyle->None,
              RoundingRadius->4,
              StripOnInput->False],
             
             FrameMargins->
              0], {-0.8950069478725488, -1.5226505453403065}, {0, 0}], 
           InsetBox[
            PaneBox[
             FrameBox[
              StyleBox[
               GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmIOIAax/9McfJrhyOA48SyUc2k+A4P/2U+Y4jMYGBzJ
F59xCas4Q8z8d2Dxdyc6geInIOL+DCCgVzB/6UQw0//sd5D46oKY+ScubeyM
AUs7Ttz7gPaBQzUAADjwg9Q=
                 "], {{0, 0}, {8, 19}}, {0, 255},
                 ColorFunction->RGBColor],
                ImageSize->{8, 19},
                PlotRange->{{0, 8}, {0, 19}}],
               StripOnInput->False,
               Opacity->1,
               FontOpacity->1,
               $CellContext`LineOpacity -> 1,
               $CellContext`FrontFaceOpacity -> 1,
               $CellContext`BackFaceOpacity -> 1],
              LabelStyle -> {},
              Frame -> True,
              Background->Directive[
                Opacity[0]],
              ContentPadding->False,
              FrameMargins->2,
              FrameStyle->None,
              RoundingRadius->4,
              StripOnInput->False],
             
             FrameMargins->
              0], {-4.021525693305875, -2.4651915773503483}, {0, 0}], InsetBox[
            PaneBox[
             FrameBox[
              StyleBox[
               GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmIOIAax/1MbfHr37tW7T7+Rhd6drXRkgAK9mO13PoFF
nzbpgfgz9l66c3a1P0gu5tL3/58uzQCyClbfgZoG4W68A2bo7X0HM/P7pRgG
BseJZyEKNj6AWfj9rD9Y/Pv1+UBx/4knIMIPNlYCuU2HXgFVrE4DW9a5dPWM
SrCTmp5CNb9a3ZmmB3ZmTMEMqDOHCAAAMu92wA==
                 "], {{0, 0}, {8, 
                 19}}, {0, 255},
                 ColorFunction->RGBColor],
                ImageSize->{8, 19},
                PlotRange->{{0, 8}, {0, 19}}],
               StripOnInput->False,
               Opacity->1,
               FontOpacity->1,
               $CellContext`LineOpacity -> 1,
               $CellContext`FrontFaceOpacity -> 1,
               $CellContext`BackFaceOpacity -> 1],
              LabelStyle -> {},
              Frame -> True,
              Background->Directive[
                Opacity[0]],
              ContentPadding->False,
              FrameMargins->2,
              FrameStyle->None,
              RoundingRadius->4,
              StripOnInput->False],
             
             FrameMargins->
              0], {-3.966857228591764, -0.5728396528205162}, {0, 0}], InsetBox[
            PaneBox[
             FrameBox[
              StyleBox[
               GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmIOIAax//////v799+//2OATzP0GPQmnsUi7sjgiEt8
xnWgee9evfuOMPDTfH+gPQx6DBCg17n9DpK4XufqQ9cv7S0AS69+8B1m/iWo
7ld7gTL+My5h2AviMsQsxRQHGes/H6qgYON3mDlAHljZpxlg9zA4Vi5dPT8N
bO/865+A4qsLYiZu3Du/EuJc/4nbr2MGyqAFAB6AaRc=
                 "], {{0, 0}, {8,
                  19}}, {0, 255},
                 ColorFunction->RGBColor],
                ImageSize->{8, 19},
                PlotRange->{{0, 8}, {0, 19}}],
               StripOnInput->False,
               Opacity->1,
               FontOpacity->1,
               $CellContext`LineOpacity -> 1,
               $CellContext`FrontFaceOpacity -> 1,
               $CellContext`BackFaceOpacity -> 1],
              LabelStyle -> {},
              Frame -> True,
              Background->Directive[
                Opacity[0]],
              ContentPadding->False,
              FrameMargins->2,
              FrameStyle->None,
              RoundingRadius->4,
              StripOnInput->False],
             
             FrameMargins->
              0], {-4.685521489601435, -1.075533900948266}, {0, 0}], 
           InsetBox[
            PaneBox[
             FrameBox[
              StyleBox[
               GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmIOIAax/2OA799/Ywp+ujQDqHjGpU9YxSeefQfX/e7V
q0+//3+/sxQu/u7San8GKHAEkzOA4t+vp4GY/ktPXL9+YilEHKgeYmDnIaiB
38/OQBLX2/70N5q9EMbSO9/RxL9fBznAsXMvVPzsRJh7vi+FWFw5Y+mMJj2Y
vSBFv58ubYoBizg2zZiY5h+zEWbs4AcALexiLw==
                 "], {{0, 0}, {8, 
                 19}}, {0, 255},
                 ColorFunction->RGBColor],
                ImageSize->{8, 19},
                PlotRange->{{0, 8}, {0, 19}}],
               StripOnInput->False,
               Opacity->1,
               FontOpacity->1,
               $CellContext`LineOpacity -> 1,
               $CellContext`FrontFaceOpacity -> 1,
               $CellContext`BackFaceOpacity -> 1],
              LabelStyle -> {},
              Frame -> True,
              Background->Directive[
                Opacity[0]],
              ContentPadding->False,
              FrameMargins->2,
              FrameStyle->None,
              RoundingRadius->4,
              StripOnInput->False],
             
             FrameMargins->
              0], {-4.568666913903923, 0.04010389056130961}, {0, 0}], InsetBox[
            PaneBox[
             FrameBox[
              StyleBox[
               
               GraphicsBox[
                RasterBox[{{{255, 255, 255}, {255, 255, 255}, {255, 255, 
                 255}, {255, 255, 255}, {255, 255, 255}}, {{255, 255, 255}, {
                 255, 255, 255}, {255, 255, 255}, {255, 255, 255}, {255, 255, 
                 255}}, {{255, 255, 255}, {255, 255, 255}, {255, 255, 255}, {
                 255, 255, 255}, {255, 255, 255}}, {{255, 255, 255}, {255, 
                 255, 255}, {255, 255, 255}, {255, 255, 255}, {255, 255, 
                 255}}, {{255, 255, 242}, {152, 65, 0}, {65, 145, 205}, {255, 
                 255, 255}, {255, 255, 255}}, {{255, 255, 242}, {152, 65, 
                 0}, {65, 145, 205}, {255, 255, 255}, {255, 255, 255}}, {{255,
                  255, 242}, {152, 65, 0}, {65, 145, 205}, {255, 255, 255}, {
                 255, 255, 255}}, {{255, 255, 242}, {152, 65, 0}, {65, 145, 
                 205}, {255, 255, 255}, {255, 255, 255}}, {{255, 255, 242}, {
                 152, 65, 0}, {46, 145, 205}, {255, 255, 255}, {255, 255, 
                 255}}, {{255, 255, 242}, {152, 79, 0}, {0, 0, 112}, {210, 
                 247, 255}, {255, 255, 255}}, {{255, 255, 242}, {159, 79, 
                 0}, {0, 0, 0}, {0, 46, 92}, {130, 137, 145}}, {{255, 255, 
                 242}, {171, 112, 102}, {159, 200, 205}, {165, 112, 65}, {0, 
                 0, 0}}, {{255, 255, 255}, {255, 255, 255}, {255, 255, 255}, {
                 255, 255, 255}, {255, 255, 255}}, {{255, 255, 255}, {255, 
                 255, 255}, {255, 255, 255}, {255, 255, 255}, {255, 255, 
                 255}}, {{255, 255, 255}, {255, 255, 255}, {255, 255, 255}, {
                 255, 255, 255}, {255, 255, 255}}, {{255, 255, 255}, {255, 
                 255, 255}, {255, 255, 255}, {255, 255, 255}, {255, 255, 
                 255}}, {{255, 255, 255}, {255, 255, 255}, {255, 255, 255}, {
                 255, 255, 255}, {255, 255, 255}}, {{255, 255, 255}, {255, 
                 255, 255}, {255, 255, 255}, {255, 255, 255}, {255, 255, 
                 255}}, {{255, 255, 255}, {255, 255, 255}, {255, 255, 255}, {
                 255, 255, 255}, {255, 255, 255}}}, {{0, 0}, {5, 19}}, {0, 
                 255},
                 ColorFunction->RGBColor],
                ImageSize->{5, 19},
                PlotRange->{{0, 5}, {0, 19}}],
               StripOnInput->False,
               Opacity->1,
               FontOpacity->1,
               $CellContext`LineOpacity -> 1,
               $CellContext`FrontFaceOpacity -> 1,
               $CellContext`BackFaceOpacity -> 1],
              LabelStyle -> {},
              Frame -> True,
              Background->Directive[
                Opacity[0]],
              ContentPadding->False,
              FrameMargins->2,
              FrameStyle->None,
              RoundingRadius->4,
              StripOnInput->False],
             
             FrameMargins->
              0], {4.9227595629030025, -1.0279205853642261}, {0, 0}], InsetBox[
            PaneBox[
             FrameBox[
              StyleBox[
               GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmI2IAax/1MAPr179+rdu99g9tOzq9P0GGDAf+P1T2dn
+DPoFey99ODVg7Od/gwMejOQta4uAIpMBDF/v9q7tNMRrC1mxon/ny4VgNmO
aU3bzz4FKT07EcidcfYTXPPvO6tBdlTO3759KdDSmPnXgYLXt0/0BztAL6Zy
751P/wcUAADbsxXI
                 "], {{0, 0}, {6, 19}}, {0, 255},
                 ColorFunction->RGBColor],
                ImageSize->{6, 19},
                PlotRange->{{0, 6}, {0, 19}}],
               StripOnInput->False,
               Opacity->1,
               FontOpacity->1,
               $CellContext`LineOpacity -> 1,
               $CellContext`FrontFaceOpacity -> 1,
               $CellContext`BackFaceOpacity -> 1],
              LabelStyle -> {},
              Frame -> True,
              Background->Directive[
                Opacity[0]],
              ContentPadding->False,
              FrameMargins->2,
              FrameStyle->None,
              RoundingRadius->4,
              StripOnInput->False],
             
             FrameMargins->
              0], {-2.5886512187893858, -1.8212756005466897}, {0, 0}], 
           InsetBox[
            PaneBox[
             FrameBox[
              StyleBox[
               
               GraphicsBox[
                RasterBox[{{{255, 255, 255}, {255, 255, 255}, {255, 255, 
                 255}, {255, 255, 255}, {255, 255, 255}}, {{255, 255, 255}, {
                 255, 255, 255}, {255, 255, 255}, {255, 255, 255}, {255, 255, 
                 255}}, {{255, 255, 255}, {255, 255, 255}, {255, 255, 255}, {
                 255, 255, 255}, {255, 255, 255}}, {{255, 255, 255}, {255, 
                 255, 255}, {255, 251, 247}, {234, 234, 238}, {247, 251, 
                 255}}, {{255, 255, 255}, {251, 229, 189}, {79, 0, 0}, {0, 0, 
                 0}, {0, 0, 92}}, {{255, 255, 255}, {210, 145, 79}, {0, 0, 
                 65}, {165, 200, 210}, {210, 205, 220}}, {{255, 255, 255}, {
                 210, 152, 65}, {0, 46, 152}, {247, 255, 255}, {255, 255, 
                 255}}, {{255, 255, 255}, {210, 152, 65}, {0, 46, 152}, {242, 
                 255, 255}, {255, 255, 255}}, {{255, 255, 255}, {210, 152, 
                 65}, {0, 46, 152}, {242, 255, 255}, {255, 255, 255}}, {{255, 
                 255, 255}, {215, 159, 79}, {0, 46, 152}, {247, 255, 255}, {
                 255, 255, 255}}, {{200, 165, 137}, {102, 79, 0}, {0, 0, 
                 65}, {121, 137, 130}, {137, 159, 194}}, {{177, 130, 92}, {46,
                  46, 0}, {0, 0, 0}, {79, 79, 79}, {79, 121, 177}}, {{255, 
                 255, 255}, {215, 152, 65}, {0, 46, 152}, {247, 255, 255}, {
                 255, 255, 255}}, {{255, 255, 255}, {220, 177, 130}, {92, 130,
                  177}, {247, 255, 255}, {255, 255, 255}}, {{255, 255, 255}, {
                 255, 255, 255}, {255, 255, 255}, {255, 255, 255}, {255, 255, 
                 255}}, {{255, 255, 255}, {255, 255, 255}, {255, 255, 255}, {
                 255, 255, 255}, {255, 255, 255}}, {{255, 255, 255}, {255, 
                 255, 255}, {255, 255, 255}, {255, 255, 255}, {255, 255, 
                 255}}, {{255, 255, 255}, {255, 255, 255}, {255, 255, 255}, {
                 255, 255, 255}, {255, 255, 255}}, {{255, 255, 255}, {255, 
                 255, 255}, {255, 255, 255}, {255, 255, 255}, {255, 255, 
                 255}}}, {{0, 0}, {5, 19}}, {0, 255},
                 ColorFunction->RGBColor],
                ImageSize->{5, 19},
                PlotRange->{{0, 5}, {0, 19}}],
               StripOnInput->False,
               Opacity->1,
               FontOpacity->1,
               $CellContext`LineOpacity -> 1,
               $CellContext`FrontFaceOpacity -> 1,
               $CellContext`BackFaceOpacity -> 1],
              LabelStyle -> {},
              Frame -> True,
              Background->Directive[
                Opacity[0]],
              ContentPadding->False,
              FrameMargins->2,
              FrameStyle->None,
              RoundingRadius->4,
              StripOnInput->False],
             
             FrameMargins->
              0], {5.7106920402336305, -1.0216196803728927}, {0, 0}], InsetBox[
            PaneBox[
             FrameBox[
              StyleBox[
               GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmIOIAax/1MV/P7+7tWrd99RBZ8emsgABTEzJhYAybOf
gMKvJuoBRdI2nr20d34BWNYfJP7prD+QNeMSRO/11QVQ8e8gcceJZyHi36/P
APIwxT9dIiT+CU0c6DbHE0Dx33c6/R2bNt6Bmb/a37HyOppPBjEAAGsvgAA=

                 "], {{0, 0}, {8, 19}}, {0, 255},
                 ColorFunction->RGBColor],
                ImageSize->{8, 19},
                PlotRange->{{0, 8}, {0, 19}}],
               StripOnInput->False,
               Opacity->1,
               FontOpacity->1,
               $CellContext`LineOpacity -> 1,
               $CellContext`FrontFaceOpacity -> 1,
               $CellContext`BackFaceOpacity -> 1],
              LabelStyle -> {},
              Frame -> True,
              Background->Directive[
                Opacity[0]],
              ContentPadding->False,
              FrameMargins->2,
              FrameStyle->None,
              RoundingRadius->4,
              StripOnInput->False],
             
             FrameMargins->
              0], {-2.784505525052932, 0.6471536030030058}, {0, 0}], 
           InsetBox[
            PaneBox[
             FrameBox[
              StyleBox[
               GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmJ2IAax/9MM3FldADQ/Zv4lJLF3M/wZQECv8ylM6PeD
jUCBzvkT9RgYll7/DhG8BFKX9uD70yaQ2hNgMRCboXI7kHV2oiMDQ8GD//+/
X58PFJt44t1/EHspkD3j0qe9TUCTYmAmPagE61pd4J828dBvmKWX5hc4Fiyl
nd/JBgCNoFMq
                 "], {{0, 0}, {7, 19}}, {0, 255},
                 ColorFunction->RGBColor],
                ImageSize->{7, 19},
                PlotRange->{{0, 7}, {0, 19}}],
               StripOnInput->False,
               Opacity->1,
               FontOpacity->1,
               $CellContext`LineOpacity -> 1,
               $CellContext`FrontFaceOpacity -> 1,
               $CellContext`BackFaceOpacity -> 1],
              LabelStyle -> {},
              Frame -> True,
              Background->Directive[
                Opacity[0]],
              ContentPadding->False,
              FrameMargins->2,
              FrameStyle->None,
              RoundingRadius->4,
              StripOnInput->False],
             
             FrameMargins->
              0], {1.3181365089562698, -4.614025258023836}, {0, 0}], 
           InsetBox[
            PaneBox[
             FrameBox[
              StyleBox[
               GraphicsBox[RasterBox[CompressedData["
1:eJzNUKEOwyAQvWRycl+wH+g/8AVNplEVtaudravEzaFQU6gqTFUNBlODwNRM
IGoQFeyALPuDbSSX3Lv37t0L5+Z6aQ4AcMI6YqU+/st7MoJx6nlLIBiOoOrk
/uFV4gGY9ogMpxl19q1Y1Q03KAEyzGhwJwjaCkAsIfP72KE9N0nG/KbRjWvd
p9mSeYs8YSZ6hTMhBwBqY1R5C0MFK/J1bNe+ysepwONOJoUOJRIp+aesaIVN
xk6W2BNr6+6R+eg1rwkdXcnmGCXD6L7yz79/LxCaB3E=
                 "], {{0, 0}, {
                 11, 19}}, {0, 255},
                 ColorFunction->RGBColor],
                ImageSize->{11, 19},
                PlotRange->{{0, 11}, {0, 19}}],
               StripOnInput->False,
               Opacity->1,
               FontOpacity->1,
               $CellContext`LineOpacity -> 1,
               $CellContext`FrontFaceOpacity -> 1,
               $CellContext`BackFaceOpacity -> 1],
              LabelStyle -> {},
              Frame -> True,
              Background->Directive[
                Opacity[0]],
              ContentPadding->False,
              FrameMargins->2,
              FrameStyle->None,
              RoundingRadius->4,
              StripOnInput->False],
             
             FrameMargins->
              0], {0.6427532667483122, -2.20687564445421}, {0, 0}], InsetBox[
            PaneBox[
             FrameBox[
              StyleBox[
               GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmJ2IAax/9MALI1hYNBregpmf7q0FGhL2tLr36+DGDFL
7/z//6pJD8isfABWcKjTESg8sROoh2H+pU9QI35fL2AAAf/OQ0gGPwVrZNCr
3P4bJnR2BsiyzomVQPGJZ9+BtD7YCFLTBNT4fb4/yKI7v/+fnV/g6N906TtI
y/c7G2P0/JfC7RpMAACyCUvs
                 "], {{0, 0}, {7, 19}}, {0, 255},
                 ColorFunction->RGBColor],
                ImageSize->{7, 19},
                PlotRange->{{0, 7}, {0, 19}}],
               StripOnInput->False,
               Opacity->1,
               FontOpacity->1,
               $CellContext`LineOpacity -> 1,
               $CellContext`FrontFaceOpacity -> 1,
               $CellContext`BackFaceOpacity -> 1],
              LabelStyle -> {},
              Frame -> True,
              Background->Directive[
                Opacity[0]],
              ContentPadding->False,
              FrameMargins->2,
              FrameStyle->None,
              RoundingRadius->4,
              StripOnInput->False],
             
             FrameMargins->
              0], {2.1242488032959375, -1.0001294099948572}, {0, 0}], InsetBox[
            PaneBox[
             FrameBox[
              StyleBox[
               GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmJ2IAax///+/unTp9//UcDZTj2gFINewdl3CMHvr+6c
PbExBijuP/8TqvpPZ2cAhZfe+Y4s+PvpRqApjhNPIAue6PQHmcxQ+QCh7jrQ
TP/KSqDi+ZegBr/a2wS0/sS7VzP0GPSaDkEsme8Pshpox6UZQFbBnd//fz/Y
CDJr+1OQMQ9WA9kzzn460ekIVHcWatLTJrCK1QX+MRMPwb15aWmBY9rS/4MP
AADCf0PM
                 "], {{0, 0}, {7, 19}}, {0, 255},
                 ColorFunction->RGBColor],
                ImageSize->{7, 19},
                PlotRange->{{0, 7}, {0, 19}}],
               StripOnInput->False,
               Opacity->1,
               FontOpacity->1,
               $CellContext`LineOpacity -> 1,
               $CellContext`FrontFaceOpacity -> 1,
               $CellContext`BackFaceOpacity -> 1],
              LabelStyle -> {},
              Frame -> True,
              Background->Directive[
                Opacity[0]],
              ContentPadding->False,
              FrameMargins->2,
              FrameStyle->None,
              RoundingRadius->4,
              StripOnInput->False],
             
             FrameMargins->
              0], {1.2809681604463088, -4.75103079932765}, {0, 0}], InsetBox[
            PaneBox[
             FrameBox[
              StyleBox[
               GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmI2IAax/1MJnJ3hz4ACHF8d6gTRep2Hzp44dOjQ3r0n
/v//vbFAj4HB/9A7JJ3fL8WAlE9EFnt3YiJQLGbpdWQrDnUCrdDb+OD376cn
OiubOjsndoJMA1nx/c7GGEf/GDBIS4vxj2milr/IAwCABhbm
                 "], {{0, 
                 0}, {6, 19}}, {0, 255},
                 ColorFunction->RGBColor],
                ImageSize->{6, 19},
                PlotRange->{{0, 6}, {0, 19}}],
               StripOnInput->False,
               Opacity->1,
               FontOpacity->1,
               $CellContext`LineOpacity -> 1,
               $CellContext`FrontFaceOpacity -> 1,
               $CellContext`BackFaceOpacity -> 1],
              LabelStyle -> {},
              Frame -> True,
              Background->Directive[
                Opacity[0]],
              ContentPadding->False,
              FrameMargins->2,
              FrameStyle->None,
              RoundingRadius->4,
              StripOnInput->False],
             
             FrameMargins->
              0], {-1.160675153137006, -2.4381161411955374}, {0, 0}], InsetBox[
            PaneBox[
             FrameBox[
              StyleBox[
               GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmIOIAax/9MYpDEwOHaeQBa5s7qAgUFvI5BgaHqKEP40
3x8o3PnuUCdQYun171Dhd4ccGRj8Z1z6//1SDAM6WP3g9///v7dX6gHZMzbu
3bt3NUiNXucriNYTQKMcD30C2Ql0hv/8S1AzwUYVbH/6/foMoPKNIEMg4Pd2
oKvS5m/sdGTQm/gOyc3vTkyE2Jg2/zqK935fh7hq49Pf/1HBu6d37jzAEKUZ
AAAubmtE
                 "], {{0, 0}, {8, 19}}, {0, 255},
                 ColorFunction->RGBColor],
                ImageSize->{8, 19},
                PlotRange->{{0, 8}, {0, 19}}],
               StripOnInput->False,
               Opacity->1,
               FontOpacity->1,
               $CellContext`LineOpacity -> 1,
               $CellContext`FrontFaceOpacity -> 1,
               $CellContext`BackFaceOpacity -> 1],
              LabelStyle -> {},
              Frame -> True,
              Background->Directive[
                Opacity[0]],
              ContentPadding->False,
              FrameMargins->2,
              FrameStyle->None,
              RoundingRadius->4,
              StripOnInput->False],
             
             FrameMargins->
              0], {-3.421320796680478, -4.306397188821551}, {0, 0}], 
           InsetBox[
            PaneBox[
             FrameBox[
              StyleBox[
               GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmJOIAax/9MVfJofw4AE9GIqZ1x69Rsq5Q8Uidl44sSJ
Q3uXTiwAK0i79B0m5T//O8yUdycmAuU6T7yDSjnO+AS34elGoNTEszAphspL
T189ffrg0qGNBY5Arv+JT3C7UFxyCNkZek0Pvv/+/undpe0z9IBumn8JIYWw
6/dSMPcdkq47n4CaXl0/BJJhSFsNNvHTRD00q9Jgdv3/9PTBnTt3gPjBg6ev
3n36TdOwxwEAOkaHZg==
                 "], {{0, 0}, {9, 19}}, {0, 255},
                 ColorFunction->RGBColor],
                ImageSize->{9, 19},
                PlotRange->{{0, 9}, {0, 19}}],
               StripOnInput->False,
               Opacity->1,
               FontOpacity->1,
               $CellContext`LineOpacity -> 1,
               $CellContext`FrontFaceOpacity -> 1,
               $CellContext`BackFaceOpacity -> 1],
              LabelStyle -> {},
              Frame -> True,
              Background->Directive[
                Opacity[0]],
              ContentPadding->False,
              FrameMargins->2,
              FrameStyle->None,
              RoundingRadius->4,
              StripOnInput->False],
             
             FrameMargins->
              0], {-1.1050749824034143, 4.590765384689359}, {0, 0}], 
           InsetBox[
            PaneBox[
             FrameBox[
              StyleBox[
               GraphicsBox[RasterBox[CompressedData["
1:eJy1j6EOwyAQhkmmpvcEe4G+A0+wZBpVUbvZ2bnKOhwKVbUHOIOqmTmNwMwg
TmAQFQyyrOkybP/kwvF/3A8c28u53THGDrn2uUqfNtQciDzR/Os6o05sEZdg
P743fTEaoWHCCXpRdqOLKb3uTW47jEtGQHR5iVYXoO3/3QFlRhJDDamMhmcV
lane+MpvIpYXCVUZSwlVgfymLYU5epAdv47fkxEGwVbitwetg72dDAAYdFTL
3lZv0BSv+g==
                 "], {{0, 0}, {9, 19}}, {0, 255},
                 ColorFunction->RGBColor],
                ImageSize->{9, 19},
                PlotRange->{{0, 9}, {0, 19}}],
               StripOnInput->False,
               Opacity->1,
               FontOpacity->1,
               $CellContext`LineOpacity -> 1,
               $CellContext`FrontFaceOpacity -> 1,
               $CellContext`BackFaceOpacity -> 1],
              LabelStyle -> {},
              Frame -> True,
              Background->Directive[
                Opacity[0]],
              ContentPadding->False,
              FrameMargins->2,
              FrameStyle->None,
              RoundingRadius->4,
              StripOnInput->False],
             
             FrameMargins->
              0], {-1.5091902615293238, 3.0428903347840315}, {0, 0}], InsetBox[
            PaneBox[
             FrameBox[
              StyleBox[
               GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmJOIAax/9MVfJofwwAHjv4FSw/dQUj5A8ViVh86sXf1
DH+wgpj5ZxFS/vO/Q1U+nQiS1tv7CiblOOMTzJTfd5YC5dJW38GU+v/9EtBy
x4lnsUmd9ccl9emEIw6pS2DPzLj0CSql13Tn06d3T6+v7gR70n/GO7D+iXoM
yCCmafWr3zCznz64c+fOAzDx6tPv/wMBAFbNk4I=
                 "], {{0, 0}, {9, 
                 19}}, {0, 255},
                 ColorFunction->RGBColor],
                ImageSize->{9, 19},
                PlotRange->{{0, 9}, {0, 19}}],
               StripOnInput->False,
               Opacity->1,
               FontOpacity->1,
               $CellContext`LineOpacity -> 1,
               $CellContext`FrontFaceOpacity -> 1,
               $CellContext`BackFaceOpacity -> 1],
              LabelStyle -> {},
              Frame -> True,
              Background->Directive[
                Opacity[0]],
              ContentPadding->False,
              FrameMargins->2,
              FrameStyle->None,
              RoundingRadius->4,
              StripOnInput->False],
             
             FrameMargins->
              0], {-2.3214126232485657, 4.265247363965378}, {0, 0}], 
           InsetBox[
            PaneBox[
             FrameBox[
              StyleBox[
               GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmIOIAax/9McfJofw4AGJp59BxL3BzL952/cvhECVm+8
/u43VNx//ndMc4DijjOwizMUHLp+5zoQXLr+AGQIXBwJdJ5AEm+6/u7dKzD4
9B3JHFz26iHUv3r1Dqzm00Q9dH8d+gSWePrgzp07D6AAxPxEvdDEBQCIi2wv

                 "], {{0, 0}, {8, 19}}, {0, 255},
                 ColorFunction->RGBColor],
                ImageSize->{8, 19},
                PlotRange->{{0, 8}, {0, 19}}],
               StripOnInput->False,
               Opacity->1,
               FontOpacity->1,
               $CellContext`LineOpacity -> 1,
               $CellContext`FrontFaceOpacity -> 1,
               $CellContext`BackFaceOpacity -> 1],
              LabelStyle -> {},
              Frame -> True,
              Background->Directive[
                Opacity[0]],
              ContentPadding->False,
              FrameMargins->2,
              FrameStyle->None,
              RoundingRadius->4,
              StripOnInput->False],
             
             FrameMargins->
              0], {0.6557932303244812, 3.690702351447757}, {0, 0}], InsetBox[
            PaneBox[
             FrameBox[
              StyleBox[
               GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmJ2IAax/9MEfJofw8DgP/8TquAMfwYGxxnv0FSCBT9h
CvrP/44pyOA/Y/Xq1UuXLp0/f++ldzBBBIiZfwlm5kRiLdJruv7u3SsoAJk5
UY8BDYCUPn1w586dB1AAYlIYRlgBAIEXRQ0=
                 "], {{0, 0}, {7, 19}}, {
                 0, 255},
                 ColorFunction->RGBColor],
                ImageSize->{7, 19},
                PlotRange->{{0, 7}, {0, 19}}],
               StripOnInput->False,
               Opacity->1,
               FontOpacity->1,
               $CellContext`LineOpacity -> 1,
               $CellContext`FrontFaceOpacity -> 1,
               $CellContext`BackFaceOpacity -> 1],
              LabelStyle -> {},
              Frame -> True,
              Background->Directive[
                Opacity[0]],
              ContentPadding->False,
              FrameMargins->2,
              FrameStyle->None,
              RoundingRadius->4,
              StripOnInput->False],
             
             FrameMargins->
              0], {1.1652597163942748, 3.6981968491131547}, {0, 0}], 
           InsetBox[
            PaneBox[
             FrameBox[
              StyleBox[
               GraphicsBox[RasterBox[CompressedData["
1:eJy1jyESwyAQRZmpqu4JeoHcISfITDUqIrY9Q1xk3DoUqqoHqEFhMJiYiJgY
xAoMAkGBNm06E5s/szPLf+xnOdfXS30ghJxiHWOlPuwpi2gMWv9nzpLTgnxF
Wz675KPss1HBQyglWEvjoZMYgunS/UbZJcLripBeoRt5Anz8pTtVZmQ1RAQ6
zzhNl+cyYrnJyM93iGLQg5jce6oTZuMzfmjydnaDhYEnWN7YYKz3bhRQFjeF
n0kBDVmrbDWuVsZJiWeU1JPfCt9VL6yXmfQ=
                 "], {{0, 0}, {9, 19}}, {
                 0, 255},
                 ColorFunction->RGBColor],
                ImageSize->{9, 19},
                PlotRange->{{0, 9}, {0, 19}}],
               StripOnInput->False,
               Opacity->1,
               FontOpacity->1,
               $CellContext`LineOpacity -> 1,
               $CellContext`FrontFaceOpacity -> 1,
               $CellContext`BackFaceOpacity -> 1],
              LabelStyle -> {},
              Frame -> True,
              Background->Directive[
                Opacity[0]],
              ContentPadding->False,
              FrameMargins->2,
              FrameStyle->None,
              RoundingRadius->4,
              StripOnInput->False],
             
             FrameMargins->
              0], {-1.5429083891756121, 3.303493557058091}, {0, 0}], 
           InsetBox[
            PaneBox[
             FrameBox[
              StyleBox[
               GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmIuIAax/w8Y+DQ/hoHBf/4nuMD3S2lAgRmXILIz/BkY
HGe8Qyg/CxKYeBaqFyyLpBeL7He47O9LMWiyDAWHrt+5DgJ3rp+YD+T7o8ii
AxRZvabr7969AoF3r+5s1EOTRXHVJYJuhuudCDRIb+I7JFlHoEDnCajvn955
8BShFeilVw/uPH33/f/AAQC6adIj
                 "], {{0, 0}, {10, 19}}, {0, 255},
                 ColorFunction->RGBColor],
                ImageSize->{10, 19},
                PlotRange->{{0, 10}, {0, 19}}],
               StripOnInput->False,
               Opacity->1,
               FontOpacity->1,
               $CellContext`LineOpacity -> 1,
               $CellContext`FrontFaceOpacity -> 1,
               $CellContext`BackFaceOpacity -> 1],
              LabelStyle -> {},
              Frame -> True,
              Background->Directive[
                Opacity[0]],
              ContentPadding->False,
              FrameMargins->2,
              FrameStyle->None,
              RoundingRadius->4,
              StripOnInput->False],
             
             FrameMargins->
              0], {0.5659773617465245, 0.5532487173860914}, {0, 0}], 
           InsetBox[
            PaneBox[
             FrameBox[
              StyleBox[
               
               GraphicsBox[
                RasterBox[{{{255, 255, 255}, {255, 255, 255}, {255, 255, 
                 255}, {255, 255, 255}}, {{255, 255, 255}, {255, 255, 255}, {
                 255, 255, 255}, {255, 255, 255}}, {{255, 255, 255}, {255, 
                 255, 255}, {255, 255, 255}, {255, 255, 255}}, {{255, 255, 
                 255}, {255, 255, 255}, {255, 255, 255}, {255, 255, 255}}, {{
                 255, 255, 242}, {159, 92, 0}, {0, 79, 159}, {242, 255, 
                 255}}, {{255, 255, 242}, {152, 79, 0}, {0, 65, 152}, {238, 
                 255, 255}}, {{255, 255, 242}, {159, 79, 0}, {0, 65, 152}, {
                 242, 255, 255}}, {{255, 255, 242}, {159, 79, 0}, {0, 65, 
                 152}, {242, 255, 255}}, {{255, 255, 242}, {159, 79, 0}, {0, 
                 65, 152}, {242, 255, 255}}, {{255, 255, 242}, {159, 79, 0}, {
                 0, 65, 152}, {242, 255, 255}}, {{255, 255, 242}, {159, 79, 
                 0}, {0, 65, 152}, {242, 255, 255}}, {{255, 255, 242}, {159, 
                 79, 0}, {0, 65, 152}, {242, 255, 255}}, {{255, 255, 242}, {
                 159, 79, 0}, {0, 65, 152}, {242, 255, 255}}, {{255, 255, 
                 242}, {145, 46, 0}, {0, 46, 145}, {238, 255, 255}}, {{255, 
                 255, 255}, {242, 229, 220}, {224, 229, 242}, {255, 255, 
                 255}}, {{255, 255, 255}, {255, 255, 255}, {255, 255, 255}, {
                 255, 255, 255}}, {{255, 255, 255}, {255, 255, 255}, {255, 
                 255, 255}, {255, 255, 255}}, {{255, 255, 255}, {255, 255, 
                 255}, {255, 255, 255}, {255, 255, 255}}, {{255, 255, 255}, {
                 255, 255, 255}, {255, 255, 255}, {255, 255, 255}}}, {{0, 
                 0}, {4, 19}}, {0, 255},
                 ColorFunction->RGBColor],
                ImageSize->{4, 19},
                PlotRange->{{0, 4}, {0, 19}}],
               StripOnInput->False,
               Opacity->1,
               FontOpacity->1,
               $CellContext`LineOpacity -> 1,
               $CellContext`FrontFaceOpacity -> 1,
               $CellContext`BackFaceOpacity -> 1],
              LabelStyle -> {},
              Frame -> True,
              Background->Directive[
                Opacity[0]],
              ContentPadding->False,
              FrameMargins->2,
              FrameStyle->None,
              RoundingRadius->4,
              StripOnInput->False],
             
             FrameMargins->
              0], {5.8344312915832655, 0.4872537622472146}, {0, 0}], 
           InsetBox[
            PaneBox[
             FrameBox[
              StyleBox[
               GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmJ2IAax/1MDvHsFBO9+w/m/n85I02OAgpi9D74DxS7N
cARyOlcfOrsXzPJfChL9/vTspacQTZdm+DMwpF3/jmIyWND/xCcsgmdpL3h2
ItClemi2//709M6dp7//0wQAAJQIVgs=
                 "], {{0, 0}, {7, 19}}, {0, 
                 255},
                 ColorFunction->RGBColor],
                ImageSize->{7, 19},
                PlotRange->{{0, 7}, {0, 19}}],
               StripOnInput->False,
               Opacity->1,
               FontOpacity->1,
               $CellContext`LineOpacity -> 1,
               $CellContext`FrontFaceOpacity -> 1,
               $CellContext`BackFaceOpacity -> 1],
              LabelStyle -> {},
              Frame -> True,
              Background->Directive[
                Opacity[0]],
              ContentPadding->False,
              FrameMargins->2,
              FrameStyle->None,
              RoundingRadius->4,
              StripOnInput->False],
             
             FrameMargins->
              0], {-1.7200155810905848, 0.8067554291057053}, {0, 0}], InsetBox[
            PaneBox[
             FrameBox[
              StyleBox[
               GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmJOIAax/9MVfJofw8DgP/8TXODpdkcGBr2mQ0CpGf4M
DI4z3kElvq9OA7rOce+r3yBdICmork9nZwAl/GechRoIlGJIOwuSe9WpB2QX
XP/9H0mKgSFm4vallUC6cvtTFGfAQcz8d3D3QHTFzNi7tAAsc+k/mpTjjO//
/28sANk08cQ7NCkw/+lER5DLtz+FuOPTRKBavYlQpZ8upYGtvAT2zKendx48
RQTG73dP71y/8+43JSFMMgAABnOZsw==
                 "], {{0, 0}, {9, 19}}, {0, 
                 255},
                 ColorFunction->RGBColor],
                ImageSize->{9, 19},
                PlotRange->{{0, 9}, {0, 19}}],
               StripOnInput->False,
               Opacity->1,
               FontOpacity->1,
               $CellContext`LineOpacity -> 1,
               $CellContext`FrontFaceOpacity -> 1,
               $CellContext`BackFaceOpacity -> 1],
              LabelStyle -> {},
              Frame -> True,
              Background->Directive[
                Opacity[0]],
              ContentPadding->False,
              FrameMargins->2,
              FrameStyle->None,
              RoundingRadius->4,
              StripOnInput->False],
             
             FrameMargins->
              0], {2.2710919289707876, 1.3063362718987082}, {0, 0}], 
           InsetBox[
            PaneBox[
             FrameBox[
              StyleBox[
               GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmJ2IAax/9MEfJofw4AK/EGC/iDG/I3bN4LB6o2HoIL+
87+jaQcKOs74NECCE/UYGPQmvkPz0tM7D56iKqQBAAD4rFL4
                 "], {{0, 
                 0}, {7, 19}}, {0, 255},
                 ColorFunction->RGBColor],
                ImageSize->{7, 19},
                PlotRange->{{0, 7}, {0, 19}}],
               StripOnInput->False,
               Opacity->1,
               FontOpacity->1,
               $CellContext`LineOpacity -> 1,
               $CellContext`FrontFaceOpacity -> 1,
               $CellContext`BackFaceOpacity -> 1],
              LabelStyle -> {},
              Frame -> True,
              Background->Directive[
                Opacity[0]],
              ContentPadding->False,
              FrameMargins->2,
              FrameStyle->None,
              RoundingRadius->4,
              StripOnInput->False],
             
             FrameMargins->
              0], {-0.30844123870789286, 2.3636424654989616}, {0, 0}], 
           InsetBox[
            PaneBox[
             FrameBox[
              StyleBox[
               GraphicsBox[RasterBox[CompressedData["
1:eJzNUKEOwyAQvWRycl+wH+g/8AUk06iK2dXW1lXicKiqfkBVzVQNpmYGgcEg
JmoQFQxYl5Yt09sll9x794573DG/nPIdABx87n2G2v1FTBwDouI7OTG01LNq
AdD1npDbWlDs/3VulXP2QzA6pwuIgZh1lr8J2M1KBkBGNSCAzpgm9YD50FcA
ReeN+BbmPSfpC2Xt11MR/JkgxSRbBRw/d5dyjoQdScSYvQQRZ5tT9GUWzS4C
GhA00q5nEiyM1MMCtZJSr+24RkupTMr9Lh7V3PPK
                 "], {{0, 0}, {11, 
                 19}}, {0, 255},
                 ColorFunction->RGBColor],
                ImageSize->{11, 19},
                PlotRange->{{0, 11}, {0, 19}}],
               StripOnInput->False,
               Opacity->1,
               FontOpacity->1,
               $CellContext`LineOpacity -> 1,
               $CellContext`FrontFaceOpacity -> 1,
               $CellContext`BackFaceOpacity -> 1],
              LabelStyle -> {},
              Frame -> True,
              Background->Directive[
                Opacity[0]],
              ContentPadding->False,
              FrameMargins->2,
              FrameStyle->None,
              RoundingRadius->4,
              StripOnInput->False],
             
             FrameMargins->
              0], {0.6255293842111171, -0.1380626233665719}, {0, 0}], InsetBox[
            PaneBox[
             FrameBox[
              StyleBox[
               GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmIuIAax/w8Y+DTfn8Fx4lk4/93ZGUD3xMy/BJGd4Ygs
+7RJDyjJ4A8VQZG9s7qAAQz8Z2DIfj8bw8Dg2Ll6RgxcPUL2UKcjUNOJV3ea
GFBlZ1z//2472DHX//+/5I9qr//8vasrgZIFd8Dm+yPpBfoIApoOvfqPKRsD
louZ/wnibrAs3OSJYA+uvvP7P0wW6Di9TqgfPz19cOfBO6TQ+/3qwZ2nn37/
HzgAADmbx5k=
                 "], {{0, 0}, {10, 19}}, {0, 255},
                 ColorFunction->RGBColor],
                ImageSize->{10, 19},
                PlotRange->{{0, 10}, {0, 19}}],
               StripOnInput->False,
               Opacity->1,
               FontOpacity->1,
               $CellContext`LineOpacity -> 1,
               $CellContext`FrontFaceOpacity -> 1,
               $CellContext`BackFaceOpacity -> 1],
              LabelStyle -> {},
              Frame -> True,
              Background->Directive[
                Opacity[0]],
              ContentPadding->False,
              FrameMargins->2,
              FrameStyle->None,
              RoundingRadius->4,
              StripOnInput->False],
             
             FrameMargins->
              0], {1.0360381608292293, 0.3847661777973239}, {0, 0}], 
           InsetBox[
            PaneBox[
             FrameBox[
              StyleBox[
               GraphicsBox[RasterBox[CompressedData["
1:eJzFkKEOgzAQhknmZvcEewHeYU9AMo1CYIedxVXi6qZQVX2AmipMTU0NogaD
qKipQLC7LpCS+e1Pmvz3f3fXptfqca9OWZZd4JzhoF9/ocU7D1q+gBX0lu26
UWl3NEuCWd4wIaVgdY4VkXOEU4tlY8LWHXSNzQRwGHuwNRvTi0yPnNvFKwqG
ap/SoF8Qdsp5TaM50C10n1kyuJS6+E4KI14V8eKQLO5LiEodo6FDXhI++RC8
5S2WRaf2TaxJPgO+48kP74AOa6QASTO59d96A6IhyfA=
                 "], {{0, 0}, {
                 10, 19}}, {0, 255},
                 ColorFunction->RGBColor],
                ImageSize->{10, 19},
                PlotRange->{{0, 10}, {0, 19}}],
               StripOnInput->False,
               Opacity->1,
               FontOpacity->1,
               $CellContext`LineOpacity -> 1,
               $CellContext`FrontFaceOpacity -> 1,
               $CellContext`BackFaceOpacity -> 1],
              LabelStyle -> {},
              Frame -> True,
              Background->Directive[
                Opacity[0]],
              ContentPadding->False,
              FrameMargins->2,
              FrameStyle->None,
              RoundingRadius->4,
              StripOnInput->False],
             
             FrameMargins->
              0], {-2.494943546902595, 3.1146660343653134}, {0, 0}], 
           InsetBox[
            PaneBox[
             FrameBox[
              StyleBox[
               GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmJOIAax/9MVfJofw8DgP/8TNqkZ/gwMjjPeYdUFlsKq
CySl1/n0///f33//xpRCAjGVSx98R5aK2X7i7NkTh5Z2poGk/ee/g0v5z/8O
M+XSDKCLHU98wuKMTyc6UaT0mu58+vTp3bs7ZzeCTUy7DjLl00Q9BlTguPQS
1Jefnj64c+cOED948ODVq3eo7qcTAADeHKSZ
                 "], {{0, 0}, {9, 19}}, {
                 0, 255},
                 ColorFunction->RGBColor],
                ImageSize->{9, 19},
                PlotRange->{{0, 9}, {0, 19}}],
               StripOnInput->False,
               Opacity->1,
               FontOpacity->1,
               $CellContext`LineOpacity -> 1,
               $CellContext`FrontFaceOpacity -> 1,
               $CellContext`BackFaceOpacity -> 1],
              LabelStyle -> {},
              Frame -> True,
              Background->Directive[
                Opacity[0]],
              ContentPadding->False,
              FrameMargins->2,
              FrameStyle->None,
              RoundingRadius->4,
              StripOnInput->False],
             
             FrameMargins->
              0], {1.4920402672713449, 2.873503141385232}, {0, 0}], InsetBox[
            PaneBox[
             FrameBox[
              StyleBox[
               GraphicsBox[RasterBox[CompressedData["
1:eJzFUCESgzAQZKauti/oB/oHXsBMNQqBbSwWh8TFoVAoVFVMFCYmJiYCg0FE
xERE0EtaaMBV9WZuZm83t7m7a/a4Z6coii6QZ0iHlx9DjZwSQuggJn1QWhRH
aySNCCQ74BTIFFNtF2u0sR9BEvztuaUNHbeemVaOjAvChGDPwr+r6OzFqXRV
Ie32g0DOoQTZiBYg6mQ4nGxzIDtpNMcAarYb3vDGk+qtIjKH6tqiNPNgULu1
/ZwYDDVLAOWdCYxbvzf31FA7Pa36SRujx750ZVKzzakLDuhX748nHoU7PqFi
Usu/4wUE+7cr
                 "], {{0, 0}, {10, 19}}, {0, 255},
                 ColorFunction->RGBColor],
                ImageSize->{10, 19},
                PlotRange->{{0, 10}, {0, 19}}],
               StripOnInput->False,
               Opacity->1,
               FontOpacity->1,
               $CellContext`LineOpacity -> 1,
               $CellContext`FrontFaceOpacity -> 1,
               $CellContext`BackFaceOpacity -> 1],
              LabelStyle -> {},
              Frame -> True,
              Background->Directive[
                Opacity[0]],
              ContentPadding->False,
              FrameMargins->2,
              FrameStyle->None,
              RoundingRadius->4,
              StripOnInput->False],
             
             FrameMargins->
              0], {-3.0127855489187554, 3.2002963516623346}, {0, 0}], InsetBox[
            PaneBox[
             FrameBox[
              StyleBox[
               GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmJOIAax/9MVfJofw8DgP/8TjH+o05+BQW/jg99AqRlA
puOMd2Dx3w9WA92mV7n9N0QXQgpsAoPjoXcwA8FS34GsExOBEgVLryPsAkoB
Jf399UA0Q9P2O6hSegVNnZ1NlRBp/4knkAyc/x2q8h3Yus5XSHbBHX8dJOd4
4hNMSq/pzqdPn969un5iNUiT3kSIgydCrEcA/43XoWZ8evrgzp07Dx6A8NNX
735TN7CJAwAqBZCP
                 "], {{0, 0}, {9, 19}}, {0, 255},
                 ColorFunction->RGBColor],
                ImageSize->{9, 19},
                PlotRange->{{0, 9}, {0, 19}}],
               StripOnInput->False,
               Opacity->1,
               FontOpacity->1,
               $CellContext`LineOpacity -> 1,
               $CellContext`FrontFaceOpacity -> 1,
               $CellContext`BackFaceOpacity -> 1],
              LabelStyle -> {},
              Frame -> True,
              Background->Directive[
                Opacity[0]],
              ContentPadding->False,
              FrameMargins->2,
              FrameStyle->None,
              RoundingRadius->4,
              StripOnInput->False],
             
             FrameMargins->
              0], {1.5793973831751404, 2.495438452834963}, {0, 0}], InsetBox[
            PaneBox[
             FrameBox[
              StyleBox[
               GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmIOIAax/1MZ/P707t2rd+++I0S+n13d6cgAB3qdG68D
Re+sTgPx/CtXHzp76ezezhg9IG/GpU//fz/dvvEEQvvvS/4MDI6dJ9CseXpo
IlB9zPxLCJFLezvTIPY4HnoFFvp0qckfaqtjWufZVxBTP80HC/o3Lb3+CsmZ
n04ANTs2HcLw0dNKkP6ms08//f7+6dL2iXp6BUBnAsGrszMYkIF/E0QcHApP
zx7aCwRnrz/9TX5gkgAAmoFq1w==
                 "], {{0, 0}, {8, 19}}, {0, 255},
                 
                 ColorFunction->RGBColor],
                ImageSize->{8, 19},
                PlotRange->{{0, 8}, {0, 19}}],
               StripOnInput->False,
               Opacity->1,
               FontOpacity->1,
               $CellContext`LineOpacity -> 1,
               $CellContext`FrontFaceOpacity -> 1,
               $CellContext`BackFaceOpacity -> 1],
              LabelStyle -> {},
              Frame -> True,
              Background->Directive[
                Opacity[0]],
              ContentPadding->False,
              FrameMargins->2,
              FrameStyle->None,
              RoundingRadius->4,
              StripOnInput->False],
             
             FrameMargins->
              0], {-0.5407266441333558, 4.918841016945062}, {0, 0}], 
           InsetBox[
            PaneBox[
             FrameBox[
              StyleBox[
               GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmIOIAax/9MJfFoaw8DgP/8ThvgMfwYGxxnvMMTng8Ux
1dNZ/Pund69evfr07nqTHgODXtP1dyDuq3ffJzJgBZ2fXj24c+fOAyC4g6Af
PMWwh9oAAL/Hhh0=
                 "], {{0, 0}, {8, 19}}, {0, 255},
                 ColorFunction->RGBColor],
                ImageSize->{8, 19},
                PlotRange->{{0, 8}, {0, 19}}],
               StripOnInput->False,
               Opacity->1,
               FontOpacity->1,
               $CellContext`LineOpacity -> 1,
               $CellContext`FrontFaceOpacity -> 1,
               $CellContext`BackFaceOpacity -> 1],
              LabelStyle -> {},
              Frame -> True,
              Background->Directive[
                Opacity[0]],
              ContentPadding->False,
              FrameMargins->2,
              FrameStyle->None,
              RoundingRadius->4,
              StripOnInput->False],
             
             FrameMargins->
              0], {6.983080444121961, 0.4713272334174654}, {0, 0}], InsetBox[
            PaneBox[
             FrameBox[
              StyleBox[
               GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmIuIAax/9MB/P7+7t2rd+8+YcpcWt3EAAd6MdvvINR8
ujQfJOhYufHQiUMbZziCOAV3fkNN3F6px8AQcxam/NOJiUDpGZcg/E8g1Y4z
EGZ9v+TPwJC29DpcVq/zEMIR388CZR0nnoXLwtj0kPWHyYI80HkCWRboCT2Y
yLundx68+o4cpq8e3Hn66TdmkNINAAB5At0y
                 "], {{0, 0}, {10, 
                 19}}, {0, 255},
                 ColorFunction->RGBColor],
                ImageSize->{10, 19},
                PlotRange->{{0, 10}, {0, 19}}],
               StripOnInput->False,
               Opacity->1,
               FontOpacity->1,
               $CellContext`LineOpacity -> 1,
               $CellContext`FrontFaceOpacity -> 1,
               $CellContext`BackFaceOpacity -> 1],
              LabelStyle -> {},
              Frame -> True,
              Background->Directive[
                Opacity[0]],
              ContentPadding->False,
              FrameMargins->2,
              FrameStyle->None,
              RoundingRadius->4,
              StripOnInput->False],
             
             FrameMargins->
              0], {-1.8847305341958474, 1.2392942483609741}, {0, 0}], InsetBox[
            PaneBox[
             FrameBox[
              StyleBox[
               GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmIOIAax/9MHvDvkD7TMsfMVqvCDjZUMYLDxwW8k4e9L
Y4CKYxwZGGLmX0IIfzoBFKncfv1Qpx6D3sR3MOFXe5uAJmx/9f/ToU4Q4ynE
qN8b04C8plcwjWmr74DNvgQye+IJiInzgc7yn/8J6MATIL0zLn2CmHlnKVCz
46F3/7cXAIXTrsNc9/vBRgaQG56CvJO2EcnRT0GOcJz/4M6dB+++o3j9KUiI
grAjCgAAqK92FQ==
                 "], {{0, 0}, {8, 19}}, {0, 255},
                 ColorFunction->RGBColor],
                ImageSize->{8, 19},
                PlotRange->{{0, 8}, {0, 19}}],
               StripOnInput->False,
               Opacity->1,
               FontOpacity->1,
               $CellContext`LineOpacity -> 1,
               $CellContext`FrontFaceOpacity -> 1,
               $CellContext`BackFaceOpacity -> 1],
              LabelStyle -> {},
              Frame -> True,
              Background->Directive[
                Opacity[0]],
              ContentPadding->False,
              FrameMargins->2,
              FrameStyle->None,
              RoundingRadius->4,
              StripOnInput->False],
             
             FrameMargins->
              0], {3.8139803425155834, -3.281562040988601}, {0, 0}], 
           InsetBox[
            PaneBox[
             FrameBox[
              StyleBox[
               GraphicsBox[RasterBox[CompressedData["
1:eJzNUSFyhTAUzExtXU/QC+QOOUFmqlFf1BaLxSHjcFEoFOorTFVMDAaDiMEg
ImIiEPn7Ap8eoNOZvpkw2cdmd/Pyfvv6uL0wxt6wXrFon/5jBV0gmhi3/cDe
KmCpzA9lnz8ZVT2uR8MoSVi0/qK4nmcOr8dDRomMWTHFk7PeK8BOl1DayNmA
0nQaXz2fpO+aM96uboDS6FOkMNKuEwKUgzuV4VTeU3JoNnabWsG4CimSUJXd
o5XkNCNXXzChhrZgvKEbmQb6DdzjrBGunQKaS18eWZXxz5zCBvThIHKPLpgp
0oTssHTHcaKw6pxLWghxdY4lWiSSegqbW9w1quSBtnBNDj9Xv//qDf+gHv7V
Goo=
                 "], {{0, 0}, {12, 19}}, {0, 255},
                 ColorFunction->RGBColor],
                ImageSize->{12, 19},
                PlotRange->{{0, 12}, {0, 19}}],
               StripOnInput->False,
               Opacity->1,
               FontOpacity->1,
               $CellContext`LineOpacity -> 1,
               $CellContext`FrontFaceOpacity -> 1,
               $CellContext`BackFaceOpacity -> 1],
              LabelStyle -> {},
              Frame -> True,
              Background->Directive[
                Opacity[0]],
              ContentPadding->False,
              FrameMargins->2,
              FrameStyle->None,
              RoundingRadius->4,
              StripOnInput->False],
             
             FrameMargins->
              0], {0.6395532078568469, -2.2399208568321947}, {0, 0}], InsetBox[
            PaneBox[
             FrameBox[
              StyleBox[
               GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmIOIAax/9MYzI8BWtL0AMb9dGk+kJ+29PqnSzNAjNV3
wMLvZjiCeNe/A9nfV6eB2UDRQ51AVuVGmO6n20ES81d3AhXrdb5CsuXERH8G
MJh/6ROy7d+vzwcLF9z5jSz8aT5UOUPM/Etw0VcQ6/beOTsDKO146B1E+EEl
UFSv6SlI3wmQzZV7gczrYCM6T0AVXQJpYVh65/unVw+u33n6HW7o709A/qtP
KNbTAgAAGKFtWA==
                 "], {{0, 0}, {8, 19}}, {0, 255},
                 ColorFunction->RGBColor],
                ImageSize->{8, 19},
                PlotRange->{{0, 8}, {0, 19}}],
               StripOnInput->False,
               Opacity->1,
               FontOpacity->1,
               $CellContext`LineOpacity -> 1,
               $CellContext`FrontFaceOpacity -> 1,
               $CellContext`BackFaceOpacity -> 1],
              LabelStyle -> {},
              Frame -> True,
              Background->Directive[
                Opacity[0]],
              ContentPadding->False,
              FrameMargins->2,
              FrameStyle->None,
              RoundingRadius->4,
              StripOnInput->False],
             
             FrameMargins->
              0], {2.6988228003901558, 1.0745435460359574}, {0, 0}], 
           InsetBox[
            PaneBox[
             FrameBox[
              StyleBox[
               GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmJ2IAax/9MOfD/rz8Aw8ewnNEFHkOA7bCpRBT+BVV5C
0X5naRrQzY5NexFCv6+DhEDAce8rmLLVQDG97dfPFgCppkNgZXeAbIaYpb//
/780A2ibHlDxg9UgsfkQK96dAFqn13koBmTSDLith5r0gAIP7tx58O47koPf
3bn+gNxwwQcALj1NGg==
                 "], {{0, 0}, {7, 19}}, {0, 255},
                 ColorFunction->RGBColor],
                ImageSize->{7, 19},
                PlotRange->{{0, 7}, {0, 19}}],
               StripOnInput->False,
               Opacity->1,
               FontOpacity->1,
               $CellContext`LineOpacity -> 1,
               $CellContext`FrontFaceOpacity -> 1,
               $CellContext`BackFaceOpacity -> 1],
              LabelStyle -> {},
              Frame -> True,
              Background->Directive[
                Opacity[0]],
              ContentPadding->False,
              FrameMargins->2,
              FrameStyle->None,
              RoundingRadius->4,
              StripOnInput->False],
             
             FrameMargins->
              0], {3.9726551534887493, -3.0975542820314867}, {0, 0}], InsetBox[
            PaneBox[
             FrameBox[
              StyleBox[
               GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmIOIAax/9MYXJofw4ABHCee/XR9KZjpv3rv3o1QsHrv
pVdALScm+jMw6K2+8xvDsDuVIC1NDzAkPp2dATJrxllMB+yt1ANKrX6AYdr3
S2lgp7zC0PLuUCdQJm3pdajhr6Dg06cHnSDDHLc//f3/+wk9TI81nfj///er
B3fu3HkAB0DO03ffSQ850gAA3T9u/Q==
                 "], {{0, 0}, {8, 19}}, {0, 
                 255},
                 ColorFunction->RGBColor],
                ImageSize->{8, 19},
                PlotRange->{{0, 8}, {0, 19}}],
               StripOnInput->False,
               Opacity->1,
               FontOpacity->1,
               $CellContext`LineOpacity -> 1,
               $CellContext`FrontFaceOpacity -> 1,
               $CellContext`BackFaceOpacity -> 1],
              LabelStyle -> {},
              Frame -> True,
              Background->Directive[
                Opacity[0]],
              ContentPadding->False,
              FrameMargins->2,
              FrameStyle->None,
              RoundingRadius->4,
              StripOnInput->False],
             
             FrameMargins->
              0], {3.8497728876309325, 3.084197097336001}, {0, 0}]}}},
        AspectRatio->1,
        Axes->{False, False},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{False, False}, {False, False}},
        FrameLabel->{{None, None}, {None, None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        ImagePadding->All,
        ImageSize->{292.76953125, Automatic},
        Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              (Identity[#]& )[
               Part[#, 1]], 
              (Identity[#]& )[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              (Identity[#]& )[
               Part[#, 1]], 
              (Identity[#]& )[
               Part[#, 2]]}& )}},
        PlotRange->All,
        PlotRangeClipping->False,
        PlotRangePadding->{{
           Scaled[0.05], 
           Scaled[0.05]}, {
           Scaled[0.05], 
           Scaled[0.05]}},
        Ticks->{Automatic, Automatic}]], "ExerciseOutput",ExpressionUUID->
       "b4c3a41a-8b9b-4cbe-9243-ae2bce3315c7"],
      Apply[TextCell, 
       Cell[
        BoxData[
         GraphicsBox[{{}, {{{}, {{{{
                 Hue[0.67, 0.6, 0.6], 
                 Opacity[0], 
                 PointBox[CompressedData["
1:eJwBUQOu/CFib1JlAgAAADQAAAACAAAAWasgD2RLBsCJyBzvAdwGwADJlHjw
jBLAeSLcCVEE+L/F6yCsb00HwBY4Eu6Ujuy/LmiMbTmSD8Afq5U+ryXUP3mM
L1jQpwfAJsWw7HDD8b/IO6uvPzIZQF7SAxBJCum/lLz/FX05GcB+ciLyR73k
v4I/dGoOXBHAyfod02uxA8C8xJzt4P0WQJzyIaNTsdg/C7DTpoxs5b95qkWS
7N0QwNHy30fttABA67jNnzjq5b/lTfbKRRUXQJ6Dz7QFeNg/n8VZnOWj7L8n
knfRxlz4vwAX09QKFhDAVcGYXLa4A8Bhn4WkH7wPwGLq1tKzVOK/aSxqWPm9
EsBj/iQJYzXxv20jlp5QRhLApG7ORH+IpD9n9QLi57ATQHdkENtccvC/jZsr
xY61BMDYnFXi8SP9v+dSeae/1xZAvWzC4I1Y8L+4ES3VqkYGwAZeDHl7teQ/
txfaThYX9T93hYgJw3QSwOiYgkxvkeQ/dij6aq6nAcAXyRUodv4AQIkhO7KH
APC/ylhFeNh+9D+fmsU3DgETwD4NABwgkvK/w0YSCUOBA8BF8BZw3V4LwLJM
Ri/AORHAms7QGmOu8b8MZtuZ8VwSQLRcC7CkJfi//LFJ49ZXCEBH/grIQJIC
wHdTRgGdDxFAp9GlFUL85D9G6FX0joYNQIInVF/npPI/1ePIOuiVDUCTuwO1
wK/4v8LjsAeObQpAMElfjnwc4j9MRXenNrThP8lvECh1VhdAkBptZyov3z/d
T9YOL4X7v3Yk/MLw0Ok/2hzJPjIrAkDhItbcwOb0P4I9P1KAvdO/7gmGYb3o
AkDm9fsyVgTkP/NmFDoJrMG/Y7YiwJyT8D94xY9RAqDYP8uAWvak9QPA/3yc
BtbqCECs7YOdZd/3P2ifCTfv/AZAXb1TTy8aCMDILj/5NJoJQNsAwjA2Rfk/
JduAb6j2A0BwHZT2oU3hv3sC2KjkrBNAKV3To6zuG0DAf0+zOSreP+ZMYjTb
J/6/8kytNCbU8z/NhzUgCIMOQHq6bpmjQArAaoH5STh35D/Vx02gW+sBwLT/
imgwlwVADaPFklQx8T8KKdRs/8cPQKxHF4rKxwjA/TdLulXMDkBezxuHb6wI
QMo9nrI=
                  "]]}}}}, {}}}, {}, {}, {{}, {}}, {{{{}}}, {{{
               InsetBox[
                PaneBox[
                 FrameBox[
                  StyleBox[
                   GraphicsBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmIOIAax/1MVfH/36tW7T6hi75YWODJAQEznxAI9Bv/5
IBVPt4MEJm5/8PT60iZ/kKzjjHf///9+sBHITNv+CmLefH+QONjEp51gYwom
rr5052yTHlwcZMWh1RNjHPWgtoDNgTjmN1TB00oGBr3OE2D2p4kghTEzVm+c
UQmyN2bpdagp1w91FvjDXLrxHXWDhsYAALgCdNE=
                    "], {{0, 0}, {8, 
                    19}}, {0, 255}, ColorFunction -> RGBColor], 
                    ImageSize -> {8, 19}, PlotRange -> {{0, 8}, {0, 19}}], 
                   StripOnInput -> False, $CellContext`LineOpacity -> 
                   1, $CellContext`FrontFaceOpacity -> 1, Opacity -> 1, 
                   FontOpacity -> 1, $CellContext`BackFaceOpacity -> 1], 
                  LabelStyle -> {}, Frame -> True, Background -> Directive[
                    Opacity[0]], ContentPadding -> False, FrameMargins -> 2, 
                  FrameStyle -> None, RoundingRadius -> 4, StripOnInput -> 
                  False], FrameMargins -> 
                 0], {-2.7868119413227928`, -2.857425563875101}, {0, 0}], 
               InsetBox[
                PaneBox[
                 FrameBox[
                  StyleBox[
                   GraphicsBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmIOIAax/1Md/P7+7tW777/h/E8z/Bkc09L0GCBAr3P7
HYj4fH8wd/Wh65f2FoClVz/4DlLvyOA48RJU96u9QBn/GZdg4mcRxjoyMMQs
xRQHGes/H6qgYON3mDlAHlgZxF6gmsqlq+dDnDX/+ieY+hnzm2LAzvSfCHMn
insQAM1ehPhEPaCvMMX/f//0CSlYqAwAru1ogw==
                    "], {{0, 0}, {8, 
                    19}}, {0, 255}, ColorFunction -> RGBColor], 
                    ImageSize -> {8, 19}, PlotRange -> {{0, 8}, {0, 19}}], 
                   StripOnInput -> False, $CellContext`LineOpacity -> 
                   1, $CellContext`FrontFaceOpacity -> 1, Opacity -> 1, 
                   FontOpacity -> 1, $CellContext`BackFaceOpacity -> 1], 
                  LabelStyle -> {}, Frame -> True, Background -> Directive[
                    Opacity[0]], ContentPadding -> False, FrameMargins -> 2, 
                  FrameStyle -> None, RoundingRadius -> 4, StripOnInput -> 
                  False], FrameMargins -> 
                 0], {-4.637636074143529, -1.5010538468506225`}, {0, 0}], 
               InsetBox[
                PaneBox[
                 FrameBox[
                  StyleBox[
                   GraphicsBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmJ2IAax/1MJfHr37tW7T79h3N+vThQ4MsCA/+pLr/7/
f9AEYutN3H72zp0Tnf4MlRsffLo0AyiUtvQOilEgQb29r/5jCDKsfvAbWfD7
9flAQcemQzBbIbLfV6eBba2csXR+px4DQ9MhiFnvtk+EOsq/YMb1dyhGDRIA
AEmSUzY=
                    "], {{0, 0}, {7, 19}}, {0, 255}, ColorFunction -> 
                    RGBColor], ImageSize -> {7, 19}, 
                    PlotRange -> {{0, 7}, {0, 19}}], StripOnInput -> 
                   False, $CellContext`LineOpacity -> 
                   1, $CellContext`FrontFaceOpacity -> 1, Opacity -> 1, 
                   FontOpacity -> 1, $CellContext`BackFaceOpacity -> 1], 
                  LabelStyle -> {}, Frame -> True, Background -> Directive[
                    Opacity[0]], ContentPadding -> False, FrameMargins -> 2, 
                  FrameStyle -> None, RoundingRadius -> 4, StripOnInput -> 
                  False], FrameMargins -> 
                 0], {-2.9128106544062313`, -0.8924049997165209}, {0, 0}], 
               InsetBox[
                PaneBox[
                 FrameBox[
                  StyleBox[
                   GraphicsBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmIOIAax/1MZfH/36tWn77+Rhd5dWu3PAAWVnU16DAzz
L336//16GkjAf+mJ69dPLIUomHj23adLM4CMzkPvIHo/nZ2IJK63/SnUZIgy
uPqld76jiX+/vhTIcOzcCzMHKg504VKIxZUzls5oYoDZC1L0++nSphig8xj0
/NPADppx9h2a935fn49QjwTg9uIQ/4QRUL8/ffr0G0OUbAAA6cVhWQ==
                    
                    "], {{0, 0}, {8, 19}}, {0, 255}, ColorFunction -> 
                    RGBColor], ImageSize -> {8, 19}, 
                    PlotRange -> {{0, 8}, {0, 19}}], StripOnInput -> 
                   False, $CellContext`LineOpacity -> 
                   1, $CellContext`FrontFaceOpacity -> 1, Opacity -> 1, 
                   FontOpacity -> 1, $CellContext`BackFaceOpacity -> 1], 
                  LabelStyle -> {}, Frame -> True, Background -> Directive[
                    Opacity[0]], ContentPadding -> False, FrameMargins -> 2, 
                  FrameStyle -> None, RoundingRadius -> 4, StripOnInput -> 
                  False], FrameMargins -> 0], {-3.9463985975717355`, 
                0.314800082319083}, {0, 0}], 
               InsetBox[
                PaneBox[
                 FrameBox[
                  StyleBox[
                   GraphicsBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmJ2IAax/1MJfP/07tWrd99/w/jvzjb5M8BB5dKz//8/
bdIDMvVmbD/74MH1jRMLmlZf/3RpBlBo4tlPyEZBBGOaJs4AgolgcsZqiKBj
QVNnExB0FsSAjPp+fT7I8O1PIRrvzAda2Ql0y+o0kKUFM1ZvnN8E0jXxLFj+
1erOND2we9I6N76jls+pCgBA10GE
                    "], {{0, 0}, {7, 19}}, {0, 
                    255}, ColorFunction -> RGBColor], ImageSize -> {7, 19}, 
                    PlotRange -> {{0, 7}, {0, 19}}], StripOnInput -> 
                   False, $CellContext`LineOpacity -> 
                   1, $CellContext`FrontFaceOpacity -> 1, Opacity -> 1, 
                   FontOpacity -> 1, $CellContext`BackFaceOpacity -> 1], 
                  LabelStyle -> {}, Frame -> True, Background -> Directive[
                    Opacity[0]], ContentPadding -> False, FrameMargins -> 2, 
                  FrameStyle -> None, RoundingRadius -> 4, StripOnInput -> 
                  False], FrameMargins -> 
                 0], {-2.9569403543005675`, -1.1102151151392916`}, {0, 0}], 
               InsetBox[
                PaneBox[
                 FrameBox[
                  StyleBox[
                   GraphicsBox[
                    
                    RasterBox[{{{255, 255, 255}, {255, 255, 255}, {255, 255, 
                    255}, {255, 255, 255}, {255, 255, 255}}, {{255, 255, 
                    255}, {255, 255, 255}, {255, 255, 255}, {255, 255, 255}, {
                    255, 255, 255}}, {{255, 255, 255}, {255, 255, 255}, {255, 
                    255, 255}, {255, 255, 255}, {255, 255, 255}}, {{255, 255, 
                    255}, {255, 255, 255}, {255, 255, 255}, {255, 255, 255}, {
                    255, 255, 255}}, {{255, 255, 255}, {210, 152, 79}, {0, 65,
                     152}, {242, 255, 255}, {255, 255, 255}}, {{255, 255, 
                    255}, {210, 152, 65}, {0, 46, 152}, {242, 255, 255}, {255,
                     255, 255}}, {{255, 255, 255}, {210, 152, 65}, {0, 46, 
                    152}, {242, 255, 255}, {255, 255, 255}}, {{255, 255, 
                    255}, {210, 152, 65}, {0, 46, 152}, {242, 255, 255}, {255,
                     255, 255}}, {{255, 255, 255}, {210, 152, 65}, {0, 46, 
                    152}, {242, 255, 255}, {255, 255, 255}}, {{255, 255, 
                    255}, {215, 159, 79}, {0, 46, 152}, {247, 255, 255}, {255,
                     255, 255}}, {{224, 189, 159}, {92, 65, 0}, {0, 0, 65}, {
                    112, 130, 137}, {189, 224, 247}}, {{220, 177, 130}, {46, 
                    0, 0}, {0, 0, 0}, {65, 65, 79}, {165, 215, 242}}, {{255, 
                    255, 255}, {215, 159, 79}, {0, 65, 159}, {251, 255, 
                    255}, {255, 255, 255}}, {{255, 255, 255}, {205, 145, 
                    65}, {0, 0, 102}, {194, 220, 229}, {229, 229, 238}}, {{
                    255, 255, 255}, {242, 210, 165}, {0, 0, 0}, {0, 0, 0}, {0,
                     0, 137}}, {{255, 255, 255}, {255, 255, 255}, {251, 242, 
                    229}, {220, 215, 220}, {229, 238, 242}}, {{255, 255, 
                    255}, {255, 255, 255}, {255, 255, 255}, {255, 255, 255}, {
                    255, 255, 255}}, {{255, 255, 255}, {255, 255, 255}, {255, 
                    255, 255}, {255, 255, 255}, {255, 255, 255}}, {{255, 255, 
                    255}, {255, 255, 255}, {255, 255, 255}, {255, 255, 255}, {
                    255, 255, 255}}}, {{0, 0}, {5, 19}}, {0, 255}, 
                    ColorFunction -> RGBColor], ImageSize -> {5, 19}, 
                    PlotRange -> {{0, 5}, {0, 19}}], StripOnInput -> 
                   False, $CellContext`LineOpacity -> 
                   1, $CellContext`FrontFaceOpacity -> 1, Opacity -> 1, 
                   FontOpacity -> 1, $CellContext`BackFaceOpacity -> 1], 
                  LabelStyle -> {}, Frame -> True, Background -> Directive[
                    Opacity[0]], ContentPadding -> False, FrameMargins -> 2, 
                  FrameStyle -> None, RoundingRadius -> 4, StripOnInput -> 
                  False], FrameMargins -> 0], {
                6.299071068598046, -0.7825055420676781}, {0, 0}], 
               InsetBox[
                PaneBox[
                 FrameBox[
                  StyleBox[
                   GraphicsBox[
                    RasterBox[CompressedData["
1:eJzNkKGOxCAQhic5c36fYF+g78ATkKxGrcBe7VlcJa4vUFVVVXVmFQaDqUFg
MBUVYxAV7ADZ3GWf4L5kkh+Yn3/gev+63T8A4EL1SVV0Lpx79JuzbvM7nrmR
NsXgL1L/pJwPMwB083a0JjcrOlKPHd1I+4vHMyGmhGElN9OWHAO80S3hzGg5
gNCrD8FXXtFRM2C9HrUepzVgfpGWviMzl7LOxU0bAQ0t+9kXfTxIy6bRkh5s
83tBPWusOnzX1yzGTEoUKQYTU/mFaJSod3cUIjnjk/uN/+c8ATefUqA=
                    
                    "], {{0, 0}, {8, 19}}, {0, 255}, ColorFunction -> 
                    RGBColor], ImageSize -> {8, 19}, 
                    PlotRange -> {{0, 8}, {0, 19}}], StripOnInput -> 
                   False, $CellContext`LineOpacity -> 
                   1, $CellContext`FrontFaceOpacity -> 1, Opacity -> 1, 
                   FontOpacity -> 1, $CellContext`BackFaceOpacity -> 1], 
                  LabelStyle -> {}, Frame -> True, Background -> Directive[
                    Opacity[0]], ContentPadding -> False, FrameMargins -> 2, 
                  FrameStyle -> None, RoundingRadius -> 4, StripOnInput -> 
                  False], FrameMargins -> 
                 0], {-6.306141227468419, -0.6481055955114952}, {0, 0}], 
               InsetBox[
                PaneBox[
                 FrameBox[
                  StyleBox[
                   GraphicsBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmIOIAax/9McfJrhyOA48SyUc2k+A4P/2U+Y4jMYGBzJ
F59xCas4Q9r8d2Dxdyc6geInwOLzYxhAQK9g/tKJ/iCW/9nvUPV6Tas3TkwD
SztO3PsAyf2X8PsLWXyiHoNeJ6b4/++fPn3/TUYAEgUAWvd3fQ==
                    
                    "], {{0, 0}, {8, 19}}, {0, 255}, ColorFunction -> 
                    RGBColor], ImageSize -> {8, 19}, 
                    PlotRange -> {{0, 8}, {0, 19}}], StripOnInput -> 
                   False, $CellContext`LineOpacity -> 
                   1, $CellContext`FrontFaceOpacity -> 1, Opacity -> 1, 
                   FontOpacity -> 1, $CellContext`BackFaceOpacity -> 1], 
                  LabelStyle -> {}, Frame -> True, Background -> Directive[
                    Opacity[0]], ContentPadding -> False, FrameMargins -> 2, 
                  FrameStyle -> None, RoundingRadius -> 4, StripOnInput -> 
                  False], FrameMargins -> 
                 0], {-4.339898742051334, -2.461631440498739}, {0, 0}], 
               InsetBox[
                PaneBox[
                 FrameBox[
                  StyleBox[
                   GraphicsBox[
                    
                    RasterBox[{{{255, 255, 255}, {255, 255, 255}, {255, 255, 
                    255}, {255, 255, 255}}, {{255, 255, 255}, {255, 255, 
                    255}, {255, 255, 255}, {255, 255, 255}}, {{255, 255, 
                    255}, {255, 255, 255}, {255, 255, 255}, {255, 255, 
                    255}}, {{255, 255, 255}, {255, 255, 255}, {255, 255, 
                    255}, {255, 255, 255}}, {{255, 255, 242}, {152, 65, 0}, {
                    65, 145, 205}, {255, 255, 255}}, {{255, 255, 242}, {152, 
                    65, 0}, {65, 145, 205}, {255, 255, 255}}, {{255, 255, 
                    242}, {152, 65, 0}, {65, 145, 205}, {255, 255, 255}}, {{
                    255, 255, 242}, {152, 65, 0}, {65, 145, 205}, {255, 255, 
                    255}}, {{255, 255, 242}, {152, 65, 0}, {65, 145, 205}, {
                    255, 255, 255}}, {{255, 255, 242}, {152, 65, 0}, {65, 145,
                     205}, {255, 255, 255}}, {{255, 255, 242}, {152, 46, 0}, {
                    46, 145, 205}, {255, 255, 255}}, {{255, 255, 242}, {177, 
                    121, 79}, {121, 171, 215}, {255, 255, 255}}, {{255, 255, 
                    255}, {251, 247, 247}, {251, 251, 255}, {255, 255, 
                    255}}, {{255, 247, 205}, {65, 0, 0}, {0, 46, 145}, {242, 
                    255, 255}}, {{255, 251, 224}, {145, 102, 79}, {102, 145, 
                    189}, {251, 255, 255}}, {{255, 255, 255}, {255, 255, 
                    255}, {255, 255, 255}, {255, 255, 255}}, {{255, 255, 
                    255}, {255, 255, 255}, {255, 255, 255}, {255, 255, 
                    255}}, {{255, 255, 255}, {255, 255, 255}, {255, 255, 
                    255}, {255, 255, 255}}, {{255, 255, 255}, {255, 255, 
                    255}, {255, 255, 255}, {255, 255, 255}}}, {{0, 0}, {4, 
                    19}}, {0, 255}, ColorFunction -> RGBColor], 
                    ImageSize -> {4, 19}, PlotRange -> {{0, 4}, {0, 19}}], 
                   StripOnInput -> False, $CellContext`LineOpacity -> 
                   1, $CellContext`FrontFaceOpacity -> 1, Opacity -> 1, 
                   FontOpacity -> 1, $CellContext`BackFaceOpacity -> 1], 
                  LabelStyle -> {}, Frame -> True, Background -> Directive[
                    Opacity[0]], ContentPadding -> False, FrameMargins -> 2, 
                  FrameStyle -> None, RoundingRadius -> 4, StripOnInput -> 
                  False], FrameMargins -> 0], {5.74792834538783, 
                0.3858231633273961}, {0, 0}], 
               InsetBox[
                PaneBox[
                 FrameBox[
                  StyleBox[
                   GraphicsBox[
                    
                    RasterBox[{{{247, 242, 234}, {224, 224, 224}, {234, 242, 
                    255}, {255, 255, 255}}, {{177, 92, 0}, {0, 0, 0}, {0, 0, 
                    46}, {177, 224, 247}}, {{247, 238, 234}, {224, 210, 
                    177}, {65, 0, 0}, {79, 145, 205}}, {{255, 255, 255}, {255,
                     255, 242}, {159, 65, 0}, {65, 145, 205}}, {{255, 255, 
                    255}, {255, 255, 242}, {152, 65, 0}, {65, 145, 205}}, {{
                    255, 255, 255}, {255, 255, 242}, {152, 65, 0}, {65, 145, 
                    205}}, {{255, 255, 255}, {255, 255, 242}, {152, 65, 0}, {
                    65, 145, 205}}, {{255, 255, 255}, {255, 255, 242}, {152, 
                    65, 0}, {65, 145, 205}}, {{255, 255, 255}, {255, 255, 
                    242}, {152, 65, 0}, {65, 145, 205}}, {{255, 255, 255}, {
                    255, 255, 242}, {152, 65, 0}, {65, 145, 205}}, {{255, 255,
                     255}, {255, 255, 242}, {152, 46, 0}, {46, 145, 205}}, {{
                    255, 255, 255}, {255, 255, 242}, {177, 121, 79}, {121, 
                    171, 215}}, {{255, 255, 255}, {255, 255, 255}, {251, 247, 
                    247}, {251, 251, 255}}, {{255, 255, 255}, {255, 247, 
                    205}, {65, 0, 0}, {0, 46, 145}}, {{255, 255, 255}, {255, 
                    251, 224}, {152, 102, 79}, {102, 145, 189}}, {{255, 255, 
                    255}, {255, 255, 255}, {255, 255, 255}, {255, 255, 
                    255}}, {{255, 255, 255}, {255, 255, 255}, {255, 255, 
                    255}, {255, 255, 255}}, {{255, 255, 255}, {255, 255, 
                    255}, {255, 255, 255}, {255, 255, 255}}, {{255, 255, 
                    255}, {255, 255, 255}, {255, 255, 255}, {255, 255, 
                    255}}}, {{0, 0}, {4, 19}}, {0, 255}, ColorFunction -> 
                    RGBColor], ImageSize -> {4, 19}, 
                    PlotRange -> {{0, 4}, {0, 19}}], StripOnInput -> 
                   False, $CellContext`LineOpacity -> 
                   1, $CellContext`FrontFaceOpacity -> 1, Opacity -> 1, 
                   FontOpacity -> 1, $CellContext`BackFaceOpacity -> 1], 
                  LabelStyle -> {}, Frame -> True, Background -> Directive[
                    Opacity[0]], ContentPadding -> False, FrameMargins -> 2, 
                  FrameStyle -> None, RoundingRadius -> 4, StripOnInput -> 
                  False], FrameMargins -> 
                 0], {-0.6695006616914737, -4.216722760679311}, {0, 0}], 
               InsetBox[
                PaneBox[
                 FrameBox[
                  StyleBox[
                   GraphicsBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmJ2IAax/9MEfJrhyOA44yyEc2d1AdgisODES2D5E/5A
obSlIEEw69Kn73sr9RgYHA+9AknPBwlCQcHq6xAzQYKOMWCZmDvIFs2//u7s
DJDo/LMIwYkg9tkZMUDxpr1PkQWB7I1NMY7+naiCqI7HEJyox6DXiSb4//un
T99/UynMwAAAWXY8rQ==
                    "], {{0, 0}, {7, 19}}, {0, 255}, 
                    ColorFunction -> RGBColor], ImageSize -> {7, 19}, 
                    PlotRange -> {{0, 7}, {0, 19}}], StripOnInput -> 
                   False, $CellContext`LineOpacity -> 
                   1, $CellContext`FrontFaceOpacity -> 1, Opacity -> 1, 
                   FontOpacity -> 1, $CellContext`BackFaceOpacity -> 1], 
                  LabelStyle -> {}, Frame -> True, Background -> Directive[
                    Opacity[0]], ContentPadding -> False, FrameMargins -> 2, 
                  FrameStyle -> None, RoundingRadius -> 4, StripOnInput -> 
                  False], FrameMargins -> 0], {
                2.088343202134958, -0.6848414536632651}, {0, 0}], 
               InsetBox[
                PaneBox[
                 FrameBox[
                  StyleBox[
                   GraphicsBox[
                    
                    RasterBox[{{{255, 255, 255}, {255, 255, 255}, {255, 255, 
                    255}, {255, 255, 255}}, {{255, 255, 255}, {255, 255, 
                    255}, {255, 255, 255}, {255, 255, 255}}, {{255, 255, 
                    255}, {255, 255, 255}, {255, 255, 255}, {255, 255, 
                    255}}, {{255, 255, 255}, {255, 255, 251}, {238, 234, 
                    238}, {247, 251, 255}}, {{255, 255, 247}, {171, 102, 0}, {
                    0, 0, 0}, {130, 200, 238}}, {{255, 255, 242}, {152, 65, 
                    0}, {0, 112, 165}, {234, 251, 255}}, {{255, 255, 242}, {
                    152, 65, 0}, {65, 145, 210}, {255, 255, 255}}, {{255, 255,
                     242}, {152, 65, 0}, {65, 145, 205}, {255, 255, 255}}, {{
                    255, 255, 242}, {152, 65, 0}, {65, 145, 205}, {255, 255, 
                    255}}, {{255, 255, 242}, {152, 65, 0}, {65, 145, 205}, {
                    255, 255, 255}}, {{255, 255, 242}, {152, 65, 0}, {65, 145,
                     205}, {255, 255, 255}}, {{255, 255, 242}, {152, 65, 0}, {
                    65, 145, 205}, {255, 255, 255}}, {{255, 255, 242}, {152, 
                    65, 0}, {65, 145, 205}, {255, 255, 255}}, {{255, 255, 
                    242}, {152, 65, 0}, {65, 145, 205}, {255, 255, 255}}, {{
                    255, 255, 242}, {145, 46, 0}, {46, 137, 205}, {255, 255, 
                    255}}, {{255, 255, 255}, {247, 242, 242}, {247, 251, 
                    255}, {255, 255, 255}}, {{255, 255, 255}, {255, 255, 
                    255}, {255, 255, 255}, {255, 255, 255}}, {{255, 255, 
                    255}, {255, 255, 255}, {255, 255, 255}, {255, 255, 
                    255}}, {{255, 255, 255}, {255, 255, 255}, {255, 255, 
                    255}, {255, 255, 255}}}, {{0, 0}, {4, 19}}, {0, 255}, 
                    ColorFunction -> RGBColor], ImageSize -> {4, 19}, 
                    PlotRange -> {{0, 4}, {0, 19}}], StripOnInput -> 
                   False, $CellContext`LineOpacity -> 
                   1, $CellContext`FrontFaceOpacity -> 1, Opacity -> 1, 
                   FontOpacity -> 1, $CellContext`BackFaceOpacity -> 1], 
                  LabelStyle -> {}, Frame -> True, Background -> Directive[
                    Opacity[0]], ContentPadding -> False, FrameMargins -> 2, 
                  FrameStyle -> None, RoundingRadius -> 4, StripOnInput -> 
                  False], FrameMargins -> 0], {5.770774050982685, 
                0.38232557923589094`}, {0, 0}], 
               InsetBox[
                PaneBox[
                 FrameBox[
                  StyleBox[
                   GraphicsBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmIeIAax/w868GmGI4PjxLMQzvWlaQwMMWe/gznfL/kz
MEw8+w5NzaUZQGH/E58gas464lZzlmw1My6hqIG65yyyexjSlr5DqNFbfR2s
6NVePbgaoDAQOBbMn9HkyAAFlTNmVILFl4LUf1pdEDP/0NnVTWAhvZjtd949
2DsDorhg/onftAv1oQAAv+g8EQ==
                    "], {{0, 0}, {12, 19}}, {0, 
                    255}, ColorFunction -> RGBColor], ImageSize -> {12, 19}, 
                    PlotRange -> {{0, 12}, {0, 19}}], StripOnInput -> 
                   False, $CellContext`LineOpacity -> 
                   1, $CellContext`FrontFaceOpacity -> 1, Opacity -> 1, 
                   FontOpacity -> 1, $CellContext`BackFaceOpacity -> 1], 
                  LabelStyle -> {}, Frame -> True, Background -> Directive[
                    Opacity[0]], ContentPadding -> False, FrameMargins -> 2, 
                  FrameStyle -> None, RoundingRadius -> 4, StripOnInput -> 
                  False], FrameMargins -> 
                 0], {-0.8950069478725488, -1.5226505453403065`}, {0, 0}], 
               InsetBox[
                PaneBox[
                 FrameBox[
                  StyleBox[
                   GraphicsBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmIOIAax/9McfJrhyOA48SyUc2k+A4P/2U+Y4jMYGBzJ
F59xCas4Q8z8d2Dxdyc6geInIOL+DCCgVzB/6UQw0//sd5D46oKY+ScubeyM
AUs7Ttz7gPaBQzUAADjwg9Q=
                    "], {{0, 0}, {8, 19}}, {0, 255}, 
                    ColorFunction -> RGBColor], ImageSize -> {8, 19}, 
                    PlotRange -> {{0, 8}, {0, 19}}], StripOnInput -> 
                   False, $CellContext`LineOpacity -> 
                   1, $CellContext`FrontFaceOpacity -> 1, Opacity -> 1, 
                   FontOpacity -> 1, $CellContext`BackFaceOpacity -> 1], 
                  LabelStyle -> {}, Frame -> True, Background -> Directive[
                    Opacity[0]], ContentPadding -> False, FrameMargins -> 2, 
                  FrameStyle -> None, RoundingRadius -> 4, StripOnInput -> 
                  False], FrameMargins -> 
                 0], {-4.021525693305875, -2.4651915773503483`}, {0, 0}], 
               InsetBox[
                PaneBox[
                 FrameBox[
                  StyleBox[
                   GraphicsBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmIOIAax/1MbfHr37tW7T7+Rhd6drXRkgAK9mO13PoFF
nzbpgfgz9l66c3a1P0gu5tL3/58uzQCyClbfgZoG4W68A2bo7X0HM/P7pRgG
BseJZyEKNj6AWfj9rD9Y/Pv1+UBx/4knIMIPNlYCuU2HXgFVrE4DW9a5dPWM
SrCTmp5CNb9a3ZmmB3ZmTMEMqDOHCAAAMu92wA==
                    "], {{0, 0}, {8, 
                    19}}, {0, 255}, ColorFunction -> RGBColor], 
                    ImageSize -> {8, 19}, PlotRange -> {{0, 8}, {0, 19}}], 
                   StripOnInput -> False, $CellContext`LineOpacity -> 
                   1, $CellContext`FrontFaceOpacity -> 1, Opacity -> 1, 
                   FontOpacity -> 1, $CellContext`BackFaceOpacity -> 1], 
                  LabelStyle -> {}, Frame -> True, Background -> Directive[
                    Opacity[0]], ContentPadding -> False, FrameMargins -> 2, 
                  FrameStyle -> None, RoundingRadius -> 4, StripOnInput -> 
                  False], FrameMargins -> 
                 0], {-3.966857228591764, -0.5728396528205162}, {0, 0}], 
               InsetBox[
                PaneBox[
                 FrameBox[
                  StyleBox[
                   GraphicsBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmIOIAax//////v799+//2OATzP0GPQmnsUi7sjgiEt8
xnWgee9evfuOMPDTfH+gPQx6DBCg17n9DpK4XufqQ9cv7S0AS69+8B1m/iWo
7ld7gTL+My5h2AviMsQsxRQHGes/H6qgYON3mDlAHljZpxlg9zA4Vi5dPT8N
bO/865+A4qsLYiZu3Du/EuJc/4nbr2MGyqAFAB6AaRc=
                    "], {{0, 
                    0}, {8, 19}}, {0, 255}, ColorFunction -> RGBColor], 
                    ImageSize -> {8, 19}, PlotRange -> {{0, 8}, {0, 19}}], 
                   StripOnInput -> False, $CellContext`LineOpacity -> 
                   1, $CellContext`FrontFaceOpacity -> 1, Opacity -> 1, 
                   FontOpacity -> 1, $CellContext`BackFaceOpacity -> 1], 
                  LabelStyle -> {}, Frame -> True, Background -> Directive[
                    Opacity[0]], ContentPadding -> False, FrameMargins -> 2, 
                  FrameStyle -> None, RoundingRadius -> 4, StripOnInput -> 
                  False], FrameMargins -> 
                 0], {-4.685521489601435, -1.075533900948266}, {0, 0}], 
               InsetBox[
                PaneBox[
                 FrameBox[
                  StyleBox[
                   GraphicsBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmIOIAax/2OA799/Ywp+ujQDqHjGpU9YxSeefQfX/e7V
q0+//3+/sxQu/u7San8GKHAEkzOA4t+vp4GY/ktPXL9+YilEHKgeYmDnIaiB
38/OQBLX2/70N5q9EMbSO9/RxL9fBznAsXMvVPzsRJh7vi+FWFw5Y+mMJj2Y
vSBFv58ubYoBizg2zZiY5h+zEWbs4AcALexiLw==
                    "], {{0, 0}, {8, 
                    19}}, {0, 255}, ColorFunction -> RGBColor], 
                    ImageSize -> {8, 19}, PlotRange -> {{0, 8}, {0, 19}}], 
                   StripOnInput -> False, $CellContext`LineOpacity -> 
                   1, $CellContext`FrontFaceOpacity -> 1, Opacity -> 1, 
                   FontOpacity -> 1, $CellContext`BackFaceOpacity -> 1], 
                  LabelStyle -> {}, Frame -> True, Background -> Directive[
                    Opacity[0]], ContentPadding -> False, FrameMargins -> 2, 
                  FrameStyle -> None, RoundingRadius -> 4, StripOnInput -> 
                  False], FrameMargins -> 0], {-4.568666913903923, 
                0.04010389056130961}, {0, 0}], 
               InsetBox[
                PaneBox[
                 FrameBox[
                  StyleBox[
                   GraphicsBox[
                    
                    RasterBox[{{{255, 255, 255}, {255, 255, 255}, {255, 255, 
                    255}, {255, 255, 255}, {255, 255, 255}}, {{255, 255, 
                    255}, {255, 255, 255}, {255, 255, 255}, {255, 255, 255}, {
                    255, 255, 255}}, {{255, 255, 255}, {255, 255, 255}, {255, 
                    255, 255}, {255, 255, 255}, {255, 255, 255}}, {{255, 255, 
                    255}, {255, 255, 255}, {255, 255, 255}, {255, 255, 255}, {
                    255, 255, 255}}, {{255, 255, 242}, {152, 65, 0}, {65, 145,
                     205}, {255, 255, 255}, {255, 255, 255}}, {{255, 255, 
                    242}, {152, 65, 0}, {65, 145, 205}, {255, 255, 255}, {255,
                     255, 255}}, {{255, 255, 242}, {152, 65, 0}, {65, 145, 
                    205}, {255, 255, 255}, {255, 255, 255}}, {{255, 255, 
                    242}, {152, 65, 0}, {65, 145, 205}, {255, 255, 255}, {255,
                     255, 255}}, {{255, 255, 242}, {152, 65, 0}, {46, 145, 
                    205}, {255, 255, 255}, {255, 255, 255}}, {{255, 255, 
                    242}, {152, 79, 0}, {0, 0, 112}, {210, 247, 255}, {255, 
                    255, 255}}, {{255, 255, 242}, {159, 79, 0}, {0, 0, 0}, {0,
                     46, 92}, {130, 137, 145}}, {{255, 255, 242}, {171, 112, 
                    102}, {159, 200, 205}, {165, 112, 65}, {0, 0, 0}}, {{255, 
                    255, 255}, {255, 255, 255}, {255, 255, 255}, {255, 255, 
                    255}, {255, 255, 255}}, {{255, 255, 255}, {255, 255, 
                    255}, {255, 255, 255}, {255, 255, 255}, {255, 255, 
                    255}}, {{255, 255, 255}, {255, 255, 255}, {255, 255, 
                    255}, {255, 255, 255}, {255, 255, 255}}, {{255, 255, 
                    255}, {255, 255, 255}, {255, 255, 255}, {255, 255, 255}, {
                    255, 255, 255}}, {{255, 255, 255}, {255, 255, 255}, {255, 
                    255, 255}, {255, 255, 255}, {255, 255, 255}}, {{255, 255, 
                    255}, {255, 255, 255}, {255, 255, 255}, {255, 255, 255}, {
                    255, 255, 255}}, {{255, 255, 255}, {255, 255, 255}, {255, 
                    255, 255}, {255, 255, 255}, {255, 255, 255}}}, {{0, 0}, {
                    5, 19}}, {0, 255}, ColorFunction -> RGBColor], 
                    ImageSize -> {5, 19}, PlotRange -> {{0, 5}, {0, 19}}], 
                   StripOnInput -> False, $CellContext`LineOpacity -> 
                   1, $CellContext`FrontFaceOpacity -> 1, Opacity -> 1, 
                   FontOpacity -> 1, $CellContext`BackFaceOpacity -> 1], 
                  LabelStyle -> {}, Frame -> True, Background -> Directive[
                    Opacity[0]], ContentPadding -> False, FrameMargins -> 2, 
                  FrameStyle -> None, RoundingRadius -> 4, StripOnInput -> 
                  False], FrameMargins -> 0], {
                4.9227595629030025`, -1.0279205853642261`}, {0, 0}], 
               InsetBox[
                PaneBox[
                 FrameBox[
                  StyleBox[
                   GraphicsBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmI2IAax/1MAPr179+rdu99g9tOzq9P0GGDAf+P1T2dn
+DPoFey99ODVg7Od/gwMejOQta4uAIpMBDF/v9q7tNMRrC1mxon/ny4VgNmO
aU3bzz4FKT07EcidcfYTXPPvO6tBdlTO3759KdDSmPnXgYLXt0/0BztAL6Zy
751P/wcUAADbsxXI
                    "], {{0, 0}, {6, 19}}, {0, 255}, 
                    ColorFunction -> RGBColor], ImageSize -> {6, 19}, 
                    PlotRange -> {{0, 6}, {0, 19}}], StripOnInput -> 
                   False, $CellContext`LineOpacity -> 
                   1, $CellContext`FrontFaceOpacity -> 1, Opacity -> 1, 
                   FontOpacity -> 1, $CellContext`BackFaceOpacity -> 1], 
                  LabelStyle -> {}, Frame -> True, Background -> Directive[
                    Opacity[0]], ContentPadding -> False, FrameMargins -> 2, 
                  FrameStyle -> None, RoundingRadius -> 4, StripOnInput -> 
                  False], FrameMargins -> 
                 0], {-2.5886512187893858`, -1.8212756005466897`}, {0, 0}], 
               InsetBox[
                PaneBox[
                 FrameBox[
                  StyleBox[
                   GraphicsBox[
                    
                    RasterBox[{{{255, 255, 255}, {255, 255, 255}, {255, 255, 
                    255}, {255, 255, 255}, {255, 255, 255}}, {{255, 255, 
                    255}, {255, 255, 255}, {255, 255, 255}, {255, 255, 255}, {
                    255, 255, 255}}, {{255, 255, 255}, {255, 255, 255}, {255, 
                    255, 255}, {255, 255, 255}, {255, 255, 255}}, {{255, 255, 
                    255}, {255, 255, 255}, {255, 251, 247}, {234, 234, 238}, {
                    247, 251, 255}}, {{255, 255, 255}, {251, 229, 189}, {79, 
                    0, 0}, {0, 0, 0}, {0, 0, 92}}, {{255, 255, 255}, {210, 
                    145, 79}, {0, 0, 65}, {165, 200, 210}, {210, 205, 
                    220}}, {{255, 255, 255}, {210, 152, 65}, {0, 46, 152}, {
                    247, 255, 255}, {255, 255, 255}}, {{255, 255, 255}, {210, 
                    152, 65}, {0, 46, 152}, {242, 255, 255}, {255, 255, 
                    255}}, {{255, 255, 255}, {210, 152, 65}, {0, 46, 152}, {
                    242, 255, 255}, {255, 255, 255}}, {{255, 255, 255}, {215, 
                    159, 79}, {0, 46, 152}, {247, 255, 255}, {255, 255, 
                    255}}, {{200, 165, 137}, {102, 79, 0}, {0, 0, 65}, {121, 
                    137, 130}, {137, 159, 194}}, {{177, 130, 92}, {46, 46, 
                    0}, {0, 0, 0}, {79, 79, 79}, {79, 121, 177}}, {{255, 255, 
                    255}, {215, 152, 65}, {0, 46, 152}, {247, 255, 255}, {255,
                     255, 255}}, {{255, 255, 255}, {220, 177, 130}, {92, 130, 
                    177}, {247, 255, 255}, {255, 255, 255}}, {{255, 255, 
                    255}, {255, 255, 255}, {255, 255, 255}, {255, 255, 255}, {
                    255, 255, 255}}, {{255, 255, 255}, {255, 255, 255}, {255, 
                    255, 255}, {255, 255, 255}, {255, 255, 255}}, {{255, 255, 
                    255}, {255, 255, 255}, {255, 255, 255}, {255, 255, 255}, {
                    255, 255, 255}}, {{255, 255, 255}, {255, 255, 255}, {255, 
                    255, 255}, {255, 255, 255}, {255, 255, 255}}, {{255, 255, 
                    255}, {255, 255, 255}, {255, 255, 255}, {255, 255, 255}, {
                    255, 255, 255}}}, {{0, 0}, {5, 19}}, {0, 255}, 
                    ColorFunction -> RGBColor], ImageSize -> {5, 19}, 
                    PlotRange -> {{0, 5}, {0, 19}}], StripOnInput -> 
                   False, $CellContext`LineOpacity -> 
                   1, $CellContext`FrontFaceOpacity -> 1, Opacity -> 1, 
                   FontOpacity -> 1, $CellContext`BackFaceOpacity -> 1], 
                  LabelStyle -> {}, Frame -> True, Background -> Directive[
                    Opacity[0]], ContentPadding -> False, FrameMargins -> 2, 
                  FrameStyle -> None, RoundingRadius -> 4, StripOnInput -> 
                  False], FrameMargins -> 0], {
                5.7106920402336305`, -1.0216196803728927`}, {0, 0}], 
               InsetBox[
                PaneBox[
                 FrameBox[
                  StyleBox[
                   GraphicsBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmIOIAax/1MV/P7+7tWrd99RBZ8emsgABTEzJhYAybOf
gMKvJuoBRdI2nr20d34BWNYfJP7prD+QNeMSRO/11QVQ8e8gcceJZyHi36/P
APIwxT9dIiT+CU0c6DbHE0Dx33c6/R2bNt6Bmb/a37HyOppPBjEAAGsvgAA=

                    "], {{0, 0}, {8, 19}}, {0, 255}, ColorFunction -> 
                    RGBColor], ImageSize -> {8, 19}, 
                    PlotRange -> {{0, 8}, {0, 19}}], StripOnInput -> 
                   False, $CellContext`LineOpacity -> 
                   1, $CellContext`FrontFaceOpacity -> 1, Opacity -> 1, 
                   FontOpacity -> 1, $CellContext`BackFaceOpacity -> 1], 
                  LabelStyle -> {}, Frame -> True, Background -> Directive[
                    Opacity[0]], ContentPadding -> False, FrameMargins -> 2, 
                  FrameStyle -> None, RoundingRadius -> 4, StripOnInput -> 
                  False], FrameMargins -> 0], {-2.784505525052932, 
                0.6471536030030058}, {0, 0}], 
               InsetBox[
                PaneBox[
                 FrameBox[
                  StyleBox[
                   GraphicsBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmJ2IAax/9MM3FldADQ/Zv4lJLF3M/wZQECv8ylM6PeD
jUCBzvkT9RgYll7/DhG8BFKX9uD70yaQ2hNgMRCboXI7kHV2oiMDQ8GD//+/
X58PFJt44t1/EHspkD3j0qe9TUCTYmAmPagE61pd4J828dBvmKWX5hc4Fiyl
nd/JBgCNoFMq
                    "], {{0, 0}, {7, 19}}, {0, 255}, 
                    ColorFunction -> RGBColor], ImageSize -> {7, 19}, 
                    PlotRange -> {{0, 7}, {0, 19}}], StripOnInput -> 
                   False, $CellContext`LineOpacity -> 
                   1, $CellContext`FrontFaceOpacity -> 1, Opacity -> 1, 
                   FontOpacity -> 1, $CellContext`BackFaceOpacity -> 1], 
                  LabelStyle -> {}, Frame -> True, Background -> Directive[
                    Opacity[0]], ContentPadding -> False, FrameMargins -> 2, 
                  FrameStyle -> None, RoundingRadius -> 4, StripOnInput -> 
                  False], FrameMargins -> 0], {
                1.3181365089562698`, -4.614025258023836}, {0, 0}], 
               InsetBox[
                PaneBox[
                 FrameBox[
                  StyleBox[
                   GraphicsBox[
                    RasterBox[CompressedData["
1:eJzNUKEOwyAQvWRycl+wH+g/8AVNplEVtaudravEzaFQU6gqTFUNBlODwNRM
IGoQFeyALPuDbSSX3Lv37t0L5+Z6aQ4AcMI6YqU+/st7MoJx6nlLIBiOoOrk
/uFV4gGY9ogMpxl19q1Y1Q03KAEyzGhwJwjaCkAsIfP72KE9N0nG/KbRjWvd
p9mSeYs8YSZ6hTMhBwBqY1R5C0MFK/J1bNe+ysepwONOJoUOJRIp+aesaIVN
xk6W2BNr6+6R+eg1rwkdXcnmGCXD6L7yz79/LxCaB3E=
                    "], {{0, 
                    0}, {11, 19}}, {0, 255}, ColorFunction -> RGBColor], 
                    ImageSize -> {11, 19}, PlotRange -> {{0, 11}, {0, 19}}], 
                   StripOnInput -> False, $CellContext`LineOpacity -> 
                   1, $CellContext`FrontFaceOpacity -> 1, Opacity -> 1, 
                   FontOpacity -> 1, $CellContext`BackFaceOpacity -> 1], 
                  LabelStyle -> {}, Frame -> True, Background -> Directive[
                    Opacity[0]], ContentPadding -> False, FrameMargins -> 2, 
                  FrameStyle -> None, RoundingRadius -> 4, StripOnInput -> 
                  False], FrameMargins -> 0], {
                0.6427532667483122, -2.20687564445421}, {0, 0}], 
               InsetBox[
                PaneBox[
                 FrameBox[
                  StyleBox[
                   GraphicsBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmJ2IAax/9MALI1hYNBregpmf7q0FGhL2tLr36+DGDFL
7/z//6pJD8isfABWcKjTESg8sROoh2H+pU9QI35fL2AAAf/OQ0gGPwVrZNCr
3P4bJnR2BsiyzomVQPGJZ9+BtD7YCFLTBNT4fb4/yKI7v/+fnV/g6N906TtI
y/c7G2P0/JfC7RpMAACyCUvs
                    "], {{0, 0}, {7, 19}}, {0, 255}, 
                    ColorFunction -> RGBColor], ImageSize -> {7, 19}, 
                    PlotRange -> {{0, 7}, {0, 19}}], StripOnInput -> 
                   False, $CellContext`LineOpacity -> 
                   1, $CellContext`FrontFaceOpacity -> 1, Opacity -> 1, 
                   FontOpacity -> 1, $CellContext`BackFaceOpacity -> 1], 
                  LabelStyle -> {}, Frame -> True, Background -> Directive[
                    Opacity[0]], ContentPadding -> False, FrameMargins -> 2, 
                  FrameStyle -> None, RoundingRadius -> 4, StripOnInput -> 
                  False], FrameMargins -> 0], {
                2.1242488032959375`, -1.0001294099948572`}, {0, 0}], 
               InsetBox[
                PaneBox[
                 FrameBox[
                  StyleBox[
                   GraphicsBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmJ2IAax///+/unTp9//UcDZTj2gFINewdl3CMHvr+6c
PbExBijuP/8TqvpPZ2cAhZfe+Y4s+PvpRqApjhNPIAue6PQHmcxQ+QCh7jrQ
TP/KSqDi+ZegBr/a2wS0/sS7VzP0GPSaDkEsme8Pshpox6UZQFbBnd//fz/Y
CDJr+1OQMQ9WA9kzzn460ekIVHcWatLTJrCK1QX+MRMPwb15aWmBY9rS/4MP
AADCf0PM
                    "], {{0, 0}, {7, 19}}, {0, 255}, ColorFunction -> 
                    RGBColor], ImageSize -> {7, 19}, 
                    PlotRange -> {{0, 7}, {0, 19}}], StripOnInput -> 
                   False, $CellContext`LineOpacity -> 
                   1, $CellContext`FrontFaceOpacity -> 1, Opacity -> 1, 
                   FontOpacity -> 1, $CellContext`BackFaceOpacity -> 1], 
                  LabelStyle -> {}, Frame -> True, Background -> Directive[
                    Opacity[0]], ContentPadding -> False, FrameMargins -> 2, 
                  FrameStyle -> None, RoundingRadius -> 4, StripOnInput -> 
                  False], FrameMargins -> 0], {
                1.2809681604463088`, -4.75103079932765}, {0, 0}], 
               InsetBox[
                PaneBox[
                 FrameBox[
                  StyleBox[
                   GraphicsBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmI2IAax/1MJnJ3hz4ACHF8d6gTRep2Hzp44dOjQ3r0n
/v//vbFAj4HB/9A7JJ3fL8WAlE9EFnt3YiJQLGbpdWQrDnUCrdDb+OD376cn
OiubOjsndoJMA1nx/c7GGEf/GDBIS4vxj2milr/IAwCABhbm
                    "], {{0, 
                    0}, {6, 19}}, {0, 255}, ColorFunction -> RGBColor], 
                    ImageSize -> {6, 19}, PlotRange -> {{0, 6}, {0, 19}}], 
                   StripOnInput -> False, $CellContext`LineOpacity -> 
                   1, $CellContext`FrontFaceOpacity -> 1, Opacity -> 1, 
                   FontOpacity -> 1, $CellContext`BackFaceOpacity -> 1], 
                  LabelStyle -> {}, Frame -> True, Background -> Directive[
                    Opacity[0]], ContentPadding -> False, FrameMargins -> 2, 
                  FrameStyle -> None, RoundingRadius -> 4, StripOnInput -> 
                  False], FrameMargins -> 
                 0], {-1.160675153137006, -2.4381161411955374`}, {0, 0}], 
               InsetBox[
                PaneBox[
                 FrameBox[
                  StyleBox[
                   GraphicsBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmIOIAax/9MYpDEwOHaeQBa5s7qAgUFvI5BgaHqKEP40
3x8o3PnuUCdQYun171Dhd4ccGRj8Z1z6//1SDAM6WP3g9///v7dX6gHZMzbu
3bt3NUiNXucriNYTQKMcD30C2Ql0hv/8S1AzwUYVbH/6/foMoPKNIEMg4Pd2
oKvS5m/sdGTQm/gOyc3vTkyE2Jg2/zqK935fh7hq49Pf/1HBu6d37jzAEKUZ
AAAubmtE
                    "], {{0, 0}, {8, 19}}, {0, 255}, ColorFunction -> 
                    RGBColor], ImageSize -> {8, 19}, 
                    PlotRange -> {{0, 8}, {0, 19}}], StripOnInput -> 
                   False, $CellContext`LineOpacity -> 
                   1, $CellContext`FrontFaceOpacity -> 1, Opacity -> 1, 
                   FontOpacity -> 1, $CellContext`BackFaceOpacity -> 1], 
                  LabelStyle -> {}, Frame -> True, Background -> Directive[
                    Opacity[0]], ContentPadding -> False, FrameMargins -> 2, 
                  FrameStyle -> None, RoundingRadius -> 4, StripOnInput -> 
                  False], FrameMargins -> 
                 0], {-3.421320796680478, -4.306397188821551}, {0, 0}], 
               InsetBox[
                PaneBox[
                 FrameBox[
                  StyleBox[
                   GraphicsBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmJOIAax/9MVfJofw4AE9GIqZ1x69Rsq5Q8Uidl44sSJ
Q3uXTiwAK0i79B0m5T//O8yUdycmAuU6T7yDSjnO+AS34elGoNTEszAphspL
T189ffrg0qGNBY5Arv+JT3C7UFxyCNkZek0Pvv/+/undpe0z9IBumn8JIYWw
6/dSMPcdkq47n4CaXl0/BJJhSFsNNvHTRD00q9Jgdv3/9PTBnTt3gPjBg6ev
3n36TdOwxwEAOkaHZg==
                    "], {{0, 0}, {9, 19}}, {0, 255}, 
                    ColorFunction -> RGBColor], ImageSize -> {9, 19}, 
                    PlotRange -> {{0, 9}, {0, 19}}], StripOnInput -> 
                   False, $CellContext`LineOpacity -> 
                   1, $CellContext`FrontFaceOpacity -> 1, Opacity -> 1, 
                   FontOpacity -> 1, $CellContext`BackFaceOpacity -> 1], 
                  LabelStyle -> {}, Frame -> True, Background -> Directive[
                    Opacity[0]], ContentPadding -> False, FrameMargins -> 2, 
                  FrameStyle -> None, RoundingRadius -> 4, StripOnInput -> 
                  False], FrameMargins -> 0], {-1.1050749824034143`, 
                4.590765384689359}, {0, 0}], 
               InsetBox[
                PaneBox[
                 FrameBox[
                  StyleBox[
                   GraphicsBox[
                    RasterBox[CompressedData["
1:eJy1j6EOwyAQhkmmpvcEe4G+A0+wZBpVUbvZ2bnKOhwKVbUHOIOqmTmNwMwg
TmAQFQyyrOkybP/kwvF/3A8c28u53THGDrn2uUqfNtQciDzR/Os6o05sEZdg
P743fTEaoWHCCXpRdqOLKb3uTW47jEtGQHR5iVYXoO3/3QFlRhJDDamMhmcV
lane+MpvIpYXCVUZSwlVgfymLYU5epAdv47fkxEGwVbitwetg72dDAAYdFTL
3lZv0BSv+g==
                    "], {{0, 0}, {9, 19}}, {0, 255}, 
                    ColorFunction -> RGBColor], ImageSize -> {9, 19}, 
                    PlotRange -> {{0, 9}, {0, 19}}], StripOnInput -> 
                   False, $CellContext`LineOpacity -> 
                   1, $CellContext`FrontFaceOpacity -> 1, Opacity -> 1, 
                   FontOpacity -> 1, $CellContext`BackFaceOpacity -> 1], 
                  LabelStyle -> {}, Frame -> True, Background -> Directive[
                    Opacity[0]], ContentPadding -> False, FrameMargins -> 2, 
                  FrameStyle -> None, RoundingRadius -> 4, StripOnInput -> 
                  False], FrameMargins -> 0], {-1.5091902615293238`, 
                3.0428903347840315`}, {0, 0}], 
               InsetBox[
                PaneBox[
                 FrameBox[
                  StyleBox[
                   GraphicsBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmJOIAax/9MVfJofwwAHjv4FSw/dQUj5A8ViVh86sXf1
DH+wgpj5ZxFS/vO/Q1U+nQiS1tv7CiblOOMTzJTfd5YC5dJW38GU+v/9EtBy
x4lnsUmd9ccl9emEIw6pS2DPzLj0CSql13Tn06d3T6+v7gR70n/GO7D+iXoM
yCCmafWr3zCznz64c+fOAzDx6tPv/wMBAFbNk4I=
                    "], {{0, 0}, {9, 
                    19}}, {0, 255}, ColorFunction -> RGBColor], 
                    ImageSize -> {9, 19}, PlotRange -> {{0, 9}, {0, 19}}], 
                   StripOnInput -> False, $CellContext`LineOpacity -> 
                   1, $CellContext`FrontFaceOpacity -> 1, Opacity -> 1, 
                   FontOpacity -> 1, $CellContext`BackFaceOpacity -> 1], 
                  LabelStyle -> {}, Frame -> True, Background -> Directive[
                    Opacity[0]], ContentPadding -> False, FrameMargins -> 2, 
                  FrameStyle -> None, RoundingRadius -> 4, StripOnInput -> 
                  False], FrameMargins -> 0], {-2.3214126232485657`, 
                4.265247363965378}, {0, 0}], 
               InsetBox[
                PaneBox[
                 FrameBox[
                  StyleBox[
                   GraphicsBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmIOIAax/9McfJofw4AGJp59BxL3BzL952/cvhECVm+8
/u43VNx//ndMc4DijjOwizMUHLp+5zoQXLr+AGQIXBwJdJ5AEm+6/u7dKzD4
9B3JHFz26iHUv3r1Dqzm00Q9dH8d+gSWePrgzp07D6AAxPxEvdDEBQCIi2wv

                    "], {{0, 0}, {8, 19}}, {0, 255}, ColorFunction -> 
                    RGBColor], ImageSize -> {8, 19}, 
                    PlotRange -> {{0, 8}, {0, 19}}], StripOnInput -> 
                   False, $CellContext`LineOpacity -> 
                   1, $CellContext`FrontFaceOpacity -> 1, Opacity -> 1, 
                   FontOpacity -> 1, $CellContext`BackFaceOpacity -> 1], 
                  LabelStyle -> {}, Frame -> True, Background -> Directive[
                    Opacity[0]], ContentPadding -> False, FrameMargins -> 2, 
                  FrameStyle -> None, RoundingRadius -> 4, StripOnInput -> 
                  False], FrameMargins -> 0], {0.6557932303244812, 
                3.690702351447757}, {0, 0}], 
               InsetBox[
                PaneBox[
                 FrameBox[
                  StyleBox[
                   GraphicsBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmJ2IAax/9MEfJofw8DgP/8TquAMfwYGxxnv0FSCBT9h
CvrP/44pyOA/Y/Xq1UuXLp0/f++ldzBBBIiZfwlm5kRiLdJruv7u3SsoAJk5
UY8BDYCUPn1w586dB1AAYlIYRlgBAIEXRQ0=
                    "], {{0, 0}, {7, 
                    19}}, {0, 255}, ColorFunction -> RGBColor], 
                    ImageSize -> {7, 19}, PlotRange -> {{0, 7}, {0, 19}}], 
                   StripOnInput -> False, $CellContext`LineOpacity -> 
                   1, $CellContext`FrontFaceOpacity -> 1, Opacity -> 1, 
                   FontOpacity -> 1, $CellContext`BackFaceOpacity -> 1], 
                  LabelStyle -> {}, Frame -> True, Background -> Directive[
                    Opacity[0]], ContentPadding -> False, FrameMargins -> 2, 
                  FrameStyle -> None, RoundingRadius -> 4, StripOnInput -> 
                  False], FrameMargins -> 0], {1.1652597163942748`, 
                3.6981968491131547`}, {0, 0}], 
               InsetBox[
                PaneBox[
                 FrameBox[
                  StyleBox[
                   GraphicsBox[
                    RasterBox[CompressedData["
1:eJy1jyESwyAQRZmpqu4JeoHcISfITDUqIrY9Q1xk3DoUqqoHqEFhMJiYiJgY
xAoMAkGBNm06E5s/szPLf+xnOdfXS30ghJxiHWOlPuwpi2gMWv9nzpLTgnxF
Wz675KPss1HBQyglWEvjoZMYgunS/UbZJcLripBeoRt5Anz8pTtVZmQ1RAQ6
zzhNl+cyYrnJyM93iGLQg5jce6oTZuMzfmjydnaDhYEnWN7YYKz3bhRQFjeF
n0kBDVmrbDWuVsZJiWeU1JPfCt9VL6yXmfQ=
                    "], {{0, 0}, {9, 
                    19}}, {0, 255}, ColorFunction -> RGBColor], 
                    ImageSize -> {9, 19}, PlotRange -> {{0, 9}, {0, 19}}], 
                   StripOnInput -> False, $CellContext`LineOpacity -> 
                   1, $CellContext`FrontFaceOpacity -> 1, Opacity -> 1, 
                   FontOpacity -> 1, $CellContext`BackFaceOpacity -> 1], 
                  LabelStyle -> {}, Frame -> True, Background -> Directive[
                    Opacity[0]], ContentPadding -> False, FrameMargins -> 2, 
                  FrameStyle -> None, RoundingRadius -> 4, StripOnInput -> 
                  False], FrameMargins -> 0], {-1.5429083891756121`, 
                3.303493557058091}, {0, 0}], 
               InsetBox[
                PaneBox[
                 FrameBox[
                  StyleBox[
                   GraphicsBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmIuIAax/w8Y+DQ/hoHBf/4nuMD3S2lAgRmXILIz/BkY
HGe8Qyg/CxKYeBaqFyyLpBeL7He47O9LMWiyDAWHrt+5DgJ3rp+YD+T7o8ii
AxRZvabr7969AoF3r+5s1EOTRXHVJYJuhuudCDRIb+I7JFlHoEDnCajvn955
8BShFeilVw/uPH33/f/AAQC6adIj
                    "], {{0, 0}, {10, 19}}, {0, 
                    255}, ColorFunction -> RGBColor], ImageSize -> {10, 19}, 
                    PlotRange -> {{0, 10}, {0, 19}}], StripOnInput -> 
                   False, $CellContext`LineOpacity -> 
                   1, $CellContext`FrontFaceOpacity -> 1, Opacity -> 1, 
                   FontOpacity -> 1, $CellContext`BackFaceOpacity -> 1], 
                  LabelStyle -> {}, Frame -> True, Background -> Directive[
                    Opacity[0]], ContentPadding -> False, FrameMargins -> 2, 
                  FrameStyle -> None, RoundingRadius -> 4, StripOnInput -> 
                  False], FrameMargins -> 0], {0.5659773617465245, 
                0.5532487173860914}, {0, 0}], 
               InsetBox[
                PaneBox[
                 FrameBox[
                  StyleBox[
                   GraphicsBox[
                    
                    RasterBox[{{{255, 255, 255}, {255, 255, 255}, {255, 255, 
                    255}, {255, 255, 255}}, {{255, 255, 255}, {255, 255, 
                    255}, {255, 255, 255}, {255, 255, 255}}, {{255, 255, 
                    255}, {255, 255, 255}, {255, 255, 255}, {255, 255, 
                    255}}, {{255, 255, 255}, {255, 255, 255}, {255, 255, 
                    255}, {255, 255, 255}}, {{255, 255, 242}, {159, 92, 0}, {
                    0, 79, 159}, {242, 255, 255}}, {{255, 255, 242}, {152, 79,
                     0}, {0, 65, 152}, {238, 255, 255}}, {{255, 255, 242}, {
                    159, 79, 0}, {0, 65, 152}, {242, 255, 255}}, {{255, 255, 
                    242}, {159, 79, 0}, {0, 65, 152}, {242, 255, 255}}, {{255,
                     255, 242}, {159, 79, 0}, {0, 65, 152}, {242, 255, 
                    255}}, {{255, 255, 242}, {159, 79, 0}, {0, 65, 152}, {242,
                     255, 255}}, {{255, 255, 242}, {159, 79, 0}, {0, 65, 
                    152}, {242, 255, 255}}, {{255, 255, 242}, {159, 79, 0}, {
                    0, 65, 152}, {242, 255, 255}}, {{255, 255, 242}, {159, 79,
                     0}, {0, 65, 152}, {242, 255, 255}}, {{255, 255, 242}, {
                    145, 46, 0}, {0, 46, 145}, {238, 255, 255}}, {{255, 255, 
                    255}, {242, 229, 220}, {224, 229, 242}, {255, 255, 
                    255}}, {{255, 255, 255}, {255, 255, 255}, {255, 255, 
                    255}, {255, 255, 255}}, {{255, 255, 255}, {255, 255, 
                    255}, {255, 255, 255}, {255, 255, 255}}, {{255, 255, 
                    255}, {255, 255, 255}, {255, 255, 255}, {255, 255, 
                    255}}, {{255, 255, 255}, {255, 255, 255}, {255, 255, 
                    255}, {255, 255, 255}}}, {{0, 0}, {4, 19}}, {0, 255}, 
                    ColorFunction -> RGBColor], ImageSize -> {4, 19}, 
                    PlotRange -> {{0, 4}, {0, 19}}], StripOnInput -> 
                   False, $CellContext`LineOpacity -> 
                   1, $CellContext`FrontFaceOpacity -> 1, Opacity -> 1, 
                   FontOpacity -> 1, $CellContext`BackFaceOpacity -> 1], 
                  LabelStyle -> {}, Frame -> True, Background -> Directive[
                    Opacity[0]], ContentPadding -> False, FrameMargins -> 2, 
                  FrameStyle -> None, RoundingRadius -> 4, StripOnInput -> 
                  False], FrameMargins -> 0], {5.8344312915832655`, 
                0.4872537622472146}, {0, 0}], 
               InsetBox[
                PaneBox[
                 FrameBox[
                  StyleBox[
                   GraphicsBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmJ2IAax/1MDvHsFBO9+w/m/n85I02OAgpi9D74DxS7N
cARyOlcfOrsXzPJfChL9/vTspacQTZdm+DMwpF3/jmIyWND/xCcsgmdpL3h2
ItClemi2//709M6dp7//0wQAAJQIVgs=
                    "], {{0, 0}, {7, 19}}, {
                    0, 255}, ColorFunction -> RGBColor], ImageSize -> {7, 19},
                     PlotRange -> {{0, 7}, {0, 19}}], StripOnInput -> 
                   False, $CellContext`LineOpacity -> 
                   1, $CellContext`FrontFaceOpacity -> 1, Opacity -> 1, 
                   FontOpacity -> 1, $CellContext`BackFaceOpacity -> 1], 
                  LabelStyle -> {}, Frame -> True, Background -> Directive[
                    Opacity[0]], ContentPadding -> False, FrameMargins -> 2, 
                  FrameStyle -> None, RoundingRadius -> 4, StripOnInput -> 
                  False], FrameMargins -> 0], {-1.7200155810905848`, 
                0.8067554291057053}, {0, 0}], 
               InsetBox[
                PaneBox[
                 FrameBox[
                  StyleBox[
                   GraphicsBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmJOIAax/9MVfJofw8DgP/8TXODpdkcGBr2mQ0CpGf4M
DI4z3kElvq9OA7rOce+r3yBdICmork9nZwAl/GechRoIlGJIOwuSe9WpB2QX
XP/9H0mKgSFm4vallUC6cvtTFGfAQcz8d3D3QHTFzNi7tAAsc+k/mpTjjO//
/28sANk08cQ7NCkw/+lER5DLtz+FuOPTRKBavYlQpZ8upYGtvAT2zKendx48
RQTG73dP71y/8+43JSFMMgAABnOZsw==
                    "], {{0, 0}, {9, 19}}, {
                    0, 255}, ColorFunction -> RGBColor], ImageSize -> {9, 19},
                     PlotRange -> {{0, 9}, {0, 19}}], StripOnInput -> 
                   False, $CellContext`LineOpacity -> 
                   1, $CellContext`FrontFaceOpacity -> 1, Opacity -> 1, 
                   FontOpacity -> 1, $CellContext`BackFaceOpacity -> 1], 
                  LabelStyle -> {}, Frame -> True, Background -> Directive[
                    Opacity[0]], ContentPadding -> False, FrameMargins -> 2, 
                  FrameStyle -> None, RoundingRadius -> 4, StripOnInput -> 
                  False], FrameMargins -> 0], {2.2710919289707876`, 
                1.3063362718987082`}, {0, 0}], 
               InsetBox[
                PaneBox[
                 FrameBox[
                  StyleBox[
                   GraphicsBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmJ2IAax/9MEfJofw4AK/EGC/iDG/I3bN4LB6o2HoIL+
87+jaQcKOs74NECCE/UYGPQmvkPz0tM7D56iKqQBAAD4rFL4
                    "], {{0, 
                    0}, {7, 19}}, {0, 255}, ColorFunction -> RGBColor], 
                    ImageSize -> {7, 19}, PlotRange -> {{0, 7}, {0, 19}}], 
                   StripOnInput -> False, $CellContext`LineOpacity -> 
                   1, $CellContext`FrontFaceOpacity -> 1, Opacity -> 1, 
                   FontOpacity -> 1, $CellContext`BackFaceOpacity -> 1], 
                  LabelStyle -> {}, Frame -> True, Background -> Directive[
                    Opacity[0]], ContentPadding -> False, FrameMargins -> 2, 
                  FrameStyle -> None, RoundingRadius -> 4, StripOnInput -> 
                  False], FrameMargins -> 0], {-0.30844123870789286`, 
                2.3636424654989616`}, {0, 0}], 
               InsetBox[
                PaneBox[
                 FrameBox[
                  StyleBox[
                   GraphicsBox[
                    RasterBox[CompressedData["
1:eJzNUKEOwyAQvWRycl+wH+g/8AUk06iK2dXW1lXicKiqfkBVzVQNpmYGgcEg
JmoQFQxYl5Yt09sll9x794573DG/nPIdABx87n2G2v1FTBwDouI7OTG01LNq
AdD1npDbWlDs/3VulXP2QzA6pwuIgZh1lr8J2M1KBkBGNSCAzpgm9YD50FcA
ReeN+BbmPSfpC2Xt11MR/JkgxSRbBRw/d5dyjoQdScSYvQQRZ5tT9GUWzS4C
GhA00q5nEiyM1MMCtZJSr+24RkupTMr9Lh7V3PPK
                    "], {{0, 0}, {11,
                     19}}, {0, 255}, ColorFunction -> RGBColor], 
                    ImageSize -> {11, 19}, PlotRange -> {{0, 11}, {0, 19}}], 
                   StripOnInput -> False, $CellContext`LineOpacity -> 
                   1, $CellContext`FrontFaceOpacity -> 1, Opacity -> 1, 
                   FontOpacity -> 1, $CellContext`BackFaceOpacity -> 1], 
                  LabelStyle -> {}, Frame -> True, Background -> Directive[
                    Opacity[0]], ContentPadding -> False, FrameMargins -> 2, 
                  FrameStyle -> None, RoundingRadius -> 4, StripOnInput -> 
                  False], FrameMargins -> 0], {
                0.6255293842111171, -0.1380626233665719}, {0, 0}], 
               InsetBox[
                PaneBox[
                 FrameBox[
                  StyleBox[
                   GraphicsBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmIuIAax/w8Y+DTfn8Fx4lk4/93ZGUD3xMy/BJGd4Ygs
+7RJDyjJ4A8VQZG9s7qAAQz8Z2DIfj8bw8Dg2Ll6RgxcPUL2UKcjUNOJV3ea
GFBlZ1z//2472DHX//+/5I9qr//8vasrgZIFd8Dm+yPpBfoIApoOvfqPKRsD
louZ/wnibrAs3OSJYA+uvvP7P0wW6Di9TqgfPz19cOfBO6TQ+/3qwZ2nn37/
HzgAADmbx5k=
                    "], {{0, 0}, {10, 19}}, {0, 255}, 
                    ColorFunction -> RGBColor], ImageSize -> {10, 19}, 
                    PlotRange -> {{0, 10}, {0, 19}}], StripOnInput -> 
                   False, $CellContext`LineOpacity -> 
                   1, $CellContext`FrontFaceOpacity -> 1, Opacity -> 1, 
                   FontOpacity -> 1, $CellContext`BackFaceOpacity -> 1], 
                  LabelStyle -> {}, Frame -> True, Background -> Directive[
                    Opacity[0]], ContentPadding -> False, FrameMargins -> 2, 
                  FrameStyle -> None, RoundingRadius -> 4, StripOnInput -> 
                  False], FrameMargins -> 0], {1.0360381608292293`, 
                0.3847661777973239}, {0, 0}], 
               InsetBox[
                PaneBox[
                 FrameBox[
                  StyleBox[
                   GraphicsBox[
                    RasterBox[CompressedData["
1:eJzFkKEOgzAQhknmZvcEewHeYU9AMo1CYIedxVXi6qZQVX2AmipMTU0NogaD
qKipQLC7LpCS+e1Pmvz3f3fXptfqca9OWZZd4JzhoF9/ocU7D1q+gBX0lu26
UWl3NEuCWd4wIaVgdY4VkXOEU4tlY8LWHXSNzQRwGHuwNRvTi0yPnNvFKwqG
ap/SoF8Qdsp5TaM50C10n1kyuJS6+E4KI14V8eKQLO5LiEodo6FDXhI++RC8
5S2WRaf2TaxJPgO+48kP74AOa6QASTO59d96A6IhyfA=
                    "], {{0, 
                    0}, {10, 19}}, {0, 255}, ColorFunction -> RGBColor], 
                    ImageSize -> {10, 19}, PlotRange -> {{0, 10}, {0, 19}}], 
                   StripOnInput -> False, $CellContext`LineOpacity -> 
                   1, $CellContext`FrontFaceOpacity -> 1, Opacity -> 1, 
                   FontOpacity -> 1, $CellContext`BackFaceOpacity -> 1], 
                  LabelStyle -> {}, Frame -> True, Background -> Directive[
                    Opacity[0]], ContentPadding -> False, FrameMargins -> 2, 
                  FrameStyle -> None, RoundingRadius -> 4, StripOnInput -> 
                  False], FrameMargins -> 0], {-2.494943546902595, 
                3.1146660343653134`}, {0, 0}], 
               InsetBox[
                PaneBox[
                 FrameBox[
                  StyleBox[
                   GraphicsBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmJOIAax/9MVfJofw8DgP/8TNqkZ/gwMjjPeYdUFlsKq
CySl1/n0///f33//xpRCAjGVSx98R5aK2X7i7NkTh5Z2poGk/ee/g0v5z/8O
M+XSDKCLHU98wuKMTyc6UaT0mu58+vTp3bs7ZzeCTUy7DjLl00Q9BlTguPQS
1Jefnj64c+cOED948ODVq3eo7qcTAADeHKSZ
                    "], {{0, 0}, {9, 
                    19}}, {0, 255}, ColorFunction -> RGBColor], 
                    ImageSize -> {9, 19}, PlotRange -> {{0, 9}, {0, 19}}], 
                   StripOnInput -> False, $CellContext`LineOpacity -> 
                   1, $CellContext`FrontFaceOpacity -> 1, Opacity -> 1, 
                   FontOpacity -> 1, $CellContext`BackFaceOpacity -> 1], 
                  LabelStyle -> {}, Frame -> True, Background -> Directive[
                    Opacity[0]], ContentPadding -> False, FrameMargins -> 2, 
                  FrameStyle -> None, RoundingRadius -> 4, StripOnInput -> 
                  False], FrameMargins -> 0], {1.4920402672713449`, 
                2.873503141385232}, {0, 0}], 
               InsetBox[
                PaneBox[
                 FrameBox[
                  StyleBox[
                   GraphicsBox[
                    RasterBox[CompressedData["
1:eJzFUCESgzAQZKauti/oB/oHXsBMNQqBbSwWh8TFoVAoVFVMFCYmJiYCg0FE
xERE0EtaaMBV9WZuZm83t7m7a/a4Z6coii6QZ0iHlx9DjZwSQuggJn1QWhRH
aySNCCQ74BTIFFNtF2u0sR9BEvztuaUNHbeemVaOjAvChGDPwr+r6OzFqXRV
Ie32g0DOoQTZiBYg6mQ4nGxzIDtpNMcAarYb3vDGk+qtIjKH6tqiNPNgULu1
/ZwYDDVLAOWdCYxbvzf31FA7Pa36SRujx750ZVKzzakLDuhX748nHoU7PqFi
Usu/4wUE+7cr
                    "], {{0, 0}, {10, 19}}, {0, 255}, 
                    ColorFunction -> RGBColor], ImageSize -> {10, 19}, 
                    PlotRange -> {{0, 10}, {0, 19}}], StripOnInput -> 
                   False, $CellContext`LineOpacity -> 
                   1, $CellContext`FrontFaceOpacity -> 1, Opacity -> 1, 
                   FontOpacity -> 1, $CellContext`BackFaceOpacity -> 1], 
                  LabelStyle -> {}, Frame -> True, Background -> Directive[
                    Opacity[0]], ContentPadding -> False, FrameMargins -> 2, 
                  FrameStyle -> None, RoundingRadius -> 4, StripOnInput -> 
                  False], FrameMargins -> 0], {-3.0127855489187554`, 
                3.2002963516623346`}, {0, 0}], 
               InsetBox[
                PaneBox[
                 FrameBox[
                  StyleBox[
                   GraphicsBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmJOIAax/9MVfJofw8DgP/8TjH+o05+BQW/jg99AqRlA
puOMd2Dx3w9WA92mV7n9N0QXQgpsAoPjoXcwA8FS34GsExOBEgVLryPsAkoB
Jf399UA0Q9P2O6hSegVNnZ1NlRBp/4knkAyc/x2q8h3Yus5XSHbBHX8dJOd4
4hNMSq/pzqdPn969un5iNUiT3kSIgydCrEcA/43XoWZ8evrgzp07Dx6A8NNX
735TN7CJAwAqBZCP
                    "], {{0, 0}, {9, 19}}, {0, 255}, 
                    ColorFunction -> RGBColor], ImageSize -> {9, 19}, 
                    PlotRange -> {{0, 9}, {0, 19}}], StripOnInput -> 
                   False, $CellContext`LineOpacity -> 
                   1, $CellContext`FrontFaceOpacity -> 1, Opacity -> 1, 
                   FontOpacity -> 1, $CellContext`BackFaceOpacity -> 1], 
                  LabelStyle -> {}, Frame -> True, Background -> Directive[
                    Opacity[0]], ContentPadding -> False, FrameMargins -> 2, 
                  FrameStyle -> None, RoundingRadius -> 4, StripOnInput -> 
                  False], FrameMargins -> 0], {1.5793973831751404`, 
                2.495438452834963}, {0, 0}], 
               InsetBox[
                PaneBox[
                 FrameBox[
                  StyleBox[
                   GraphicsBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmIOIAax/1MZ/P707t2rd+++I0S+n13d6cgAB3qdG68D
Re+sTgPx/CtXHzp76ezezhg9IG/GpU//fz/dvvEEQvvvS/4MDI6dJ9CseXpo
IlB9zPxLCJFLezvTIPY4HnoFFvp0qckfaqtjWufZVxBTP80HC/o3Lb3+CsmZ
n04ANTs2HcLw0dNKkP6ms08//f7+6dL2iXp6BUBnAsGrszMYkIF/E0QcHApP
zx7aCwRnrz/9TX5gkgAAmoFq1w==
                    "], {{0, 0}, {8, 19}}, {0, 
                    255}, ColorFunction -> RGBColor], ImageSize -> {8, 19}, 
                    PlotRange -> {{0, 8}, {0, 19}}], StripOnInput -> 
                   False, $CellContext`LineOpacity -> 
                   1, $CellContext`FrontFaceOpacity -> 1, Opacity -> 1, 
                   FontOpacity -> 1, $CellContext`BackFaceOpacity -> 1], 
                  LabelStyle -> {}, Frame -> True, Background -> Directive[
                    Opacity[0]], ContentPadding -> False, FrameMargins -> 2, 
                  FrameStyle -> None, RoundingRadius -> 4, StripOnInput -> 
                  False], FrameMargins -> 0], {-0.5407266441333558, 
                4.918841016945062}, {0, 0}], 
               InsetBox[
                PaneBox[
                 FrameBox[
                  StyleBox[
                   GraphicsBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmIOIAax/9MJfFoaw8DgP/8ThvgMfwYGxxnvMMTng8Ux
1dNZ/Pund69evfr07nqTHgODXtP1dyDuq3ffJzJgBZ2fXj24c+fOAyC4g6Af
PMWwh9oAAL/Hhh0=
                    "], {{0, 0}, {8, 19}}, {0, 255}, 
                    ColorFunction -> RGBColor], ImageSize -> {8, 19}, 
                    PlotRange -> {{0, 8}, {0, 19}}], StripOnInput -> 
                   False, $CellContext`LineOpacity -> 
                   1, $CellContext`FrontFaceOpacity -> 1, Opacity -> 1, 
                   FontOpacity -> 1, $CellContext`BackFaceOpacity -> 1], 
                  LabelStyle -> {}, Frame -> True, Background -> Directive[
                    Opacity[0]], ContentPadding -> False, FrameMargins -> 2, 
                  FrameStyle -> None, RoundingRadius -> 4, StripOnInput -> 
                  False], FrameMargins -> 0], {6.983080444121961, 
                0.4713272334174654}, {0, 0}], 
               InsetBox[
                PaneBox[
                 FrameBox[
                  StyleBox[
                   GraphicsBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmIuIAax/9MB/P7+7t2rd+8+YcpcWt3EAAd6MdvvINR8
ujQfJOhYufHQiUMbZziCOAV3fkNN3F6px8AQcxam/NOJiUDpGZcg/E8g1Y4z
EGZ9v+TPwJC29DpcVq/zEMIR388CZR0nnoXLwtj0kPWHyYI80HkCWRboCT2Y
yLundx68+o4cpq8e3Hn66TdmkNINAAB5At0y
                    "], {{0, 0}, {10, 
                    19}}, {0, 255}, ColorFunction -> RGBColor], 
                    ImageSize -> {10, 19}, PlotRange -> {{0, 10}, {0, 19}}], 
                   StripOnInput -> False, $CellContext`LineOpacity -> 
                   1, $CellContext`FrontFaceOpacity -> 1, Opacity -> 1, 
                   FontOpacity -> 1, $CellContext`BackFaceOpacity -> 1], 
                  LabelStyle -> {}, Frame -> True, Background -> Directive[
                    Opacity[0]], ContentPadding -> False, FrameMargins -> 2, 
                  FrameStyle -> None, RoundingRadius -> 4, StripOnInput -> 
                  False], FrameMargins -> 0], {-1.8847305341958474`, 
                1.2392942483609741`}, {0, 0}], 
               InsetBox[
                PaneBox[
                 FrameBox[
                  StyleBox[
                   GraphicsBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmIOIAax/9MHvDvkD7TMsfMVqvCDjZUMYLDxwW8k4e9L
Y4CKYxwZGGLmX0IIfzoBFKncfv1Qpx6D3sR3MOFXe5uAJmx/9f/ToU4Q4ynE
qN8b04C8plcwjWmr74DNvgQye+IJiInzgc7yn/8J6MATIL0zLn2CmHlnKVCz
46F3/7cXAIXTrsNc9/vBRgaQG56CvJO2EcnRT0GOcJz/4M6dB+++o3j9KUiI
grAjCgAAqK92FQ==
                    "], {{0, 0}, {8, 19}}, {0, 255}, 
                    ColorFunction -> RGBColor], ImageSize -> {8, 19}, 
                    PlotRange -> {{0, 8}, {0, 19}}], StripOnInput -> 
                   False, $CellContext`LineOpacity -> 
                   1, $CellContext`FrontFaceOpacity -> 1, Opacity -> 1, 
                   FontOpacity -> 1, $CellContext`BackFaceOpacity -> 1], 
                  LabelStyle -> {}, Frame -> True, Background -> Directive[
                    Opacity[0]], ContentPadding -> False, FrameMargins -> 2, 
                  FrameStyle -> None, RoundingRadius -> 4, StripOnInput -> 
                  False], FrameMargins -> 0], {
                3.8139803425155834`, -3.281562040988601}, {0, 0}], 
               InsetBox[
                PaneBox[
                 FrameBox[
                  StyleBox[
                   GraphicsBox[
                    RasterBox[CompressedData["
1:eJzNUSFyhTAUzExtXU/QC+QOOUFmqlFf1BaLxSHjcFEoFOorTFVMDAaDiMEg
ImIiEPn7Ap8eoNOZvpkw2cdmd/Pyfvv6uL0wxt6wXrFon/5jBV0gmhi3/cDe
KmCpzA9lnz8ZVT2uR8MoSVi0/qK4nmcOr8dDRomMWTHFk7PeK8BOl1DayNmA
0nQaXz2fpO+aM96uboDS6FOkMNKuEwKUgzuV4VTeU3JoNnabWsG4CimSUJXd
o5XkNCNXXzChhrZgvKEbmQb6DdzjrBGunQKaS18eWZXxz5zCBvThIHKPLpgp
0oTssHTHcaKw6pxLWghxdY4lWiSSegqbW9w1quSBtnBNDj9Xv//qDf+gHv7V
Goo=
                    "], {{0, 0}, {12, 19}}, {0, 255}, ColorFunction -> 
                    RGBColor], ImageSize -> {12, 19}, 
                    PlotRange -> {{0, 12}, {0, 19}}], StripOnInput -> 
                   False, $CellContext`LineOpacity -> 
                   1, $CellContext`FrontFaceOpacity -> 1, Opacity -> 1, 
                   FontOpacity -> 1, $CellContext`BackFaceOpacity -> 1], 
                  LabelStyle -> {}, Frame -> True, Background -> Directive[
                    Opacity[0]], ContentPadding -> False, FrameMargins -> 2, 
                  FrameStyle -> None, RoundingRadius -> 4, StripOnInput -> 
                  False], FrameMargins -> 0], {
                0.6395532078568469, -2.2399208568321947`}, {0, 0}], 
               InsetBox[
                PaneBox[
                 FrameBox[
                  StyleBox[
                   GraphicsBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmIOIAax/9MYzI8BWtL0AMb9dGk+kJ+29PqnSzNAjNV3
wMLvZjiCeNe/A9nfV6eB2UDRQ51AVuVGmO6n20ES81d3AhXrdb5CsuXERH8G
MJh/6ROy7d+vzwcLF9z5jSz8aT5UOUPM/Etw0VcQ6/beOTsDKO146B1E+EEl
UFSv6SlI3wmQzZV7gczrYCM6T0AVXQJpYVh65/unVw+u33n6HW7o709A/qtP
KNbTAgAAGKFtWA==
                    "], {{0, 0}, {8, 19}}, {0, 255}, 
                    ColorFunction -> RGBColor], ImageSize -> {8, 19}, 
                    PlotRange -> {{0, 8}, {0, 19}}], StripOnInput -> 
                   False, $CellContext`LineOpacity -> 
                   1, $CellContext`FrontFaceOpacity -> 1, Opacity -> 1, 
                   FontOpacity -> 1, $CellContext`BackFaceOpacity -> 1], 
                  LabelStyle -> {}, Frame -> True, Background -> Directive[
                    Opacity[0]], ContentPadding -> False, FrameMargins -> 2, 
                  FrameStyle -> None, RoundingRadius -> 4, StripOnInput -> 
                  False], FrameMargins -> 0], {2.6988228003901558`, 
                1.0745435460359574`}, {0, 0}], 
               InsetBox[
                PaneBox[
                 FrameBox[
                  StyleBox[
                   GraphicsBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmJ2IAax/9MOfD/rz8Aw8ewnNEFHkOA7bCpRBT+BVV5C
0X5naRrQzY5NexFCv6+DhEDAce8rmLLVQDG97dfPFgCppkNgZXeAbIaYpb//
/780A2ibHlDxg9UgsfkQK96dAFqn13koBmTSDLith5r0gAIP7tx58O47koPf
3bn+gNxwwQcALj1NGg==
                    "], {{0, 0}, {7, 19}}, {0, 255}, 
                    ColorFunction -> RGBColor], ImageSize -> {7, 19}, 
                    PlotRange -> {{0, 7}, {0, 19}}], StripOnInput -> 
                   False, $CellContext`LineOpacity -> 
                   1, $CellContext`FrontFaceOpacity -> 1, Opacity -> 1, 
                   FontOpacity -> 1, $CellContext`BackFaceOpacity -> 1], 
                  LabelStyle -> {}, Frame -> True, Background -> Directive[
                    Opacity[0]], ContentPadding -> False, FrameMargins -> 2, 
                  FrameStyle -> None, RoundingRadius -> 4, StripOnInput -> 
                  False], FrameMargins -> 0], {
                3.9726551534887493`, -3.0975542820314867`}, {0, 0}], 
               InsetBox[
                PaneBox[
                 FrameBox[
                  StyleBox[
                   GraphicsBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmJmYGAQBmIOIAax/9MYXJofw4ABHCee/XR9KZjpv3rv3o1QsHrv
pVdALScm+jMw6K2+8xvDsDuVIC1NDzAkPp2dATJrxllMB+yt1ANKrX6AYdr3
S2lgp7zC0PLuUCdQJm3pdajhr6Dg06cHnSDDHLc//f3/+wk9TI81nfj///er
B3fu3HkAB0DO03ffSQ850gAA3T9u/Q==
                    "], {{0, 0}, {8, 19}}, {
                    0, 255}, ColorFunction -> RGBColor], ImageSize -> {8, 19},
                     PlotRange -> {{0, 8}, {0, 19}}], StripOnInput -> 
                   False, $CellContext`LineOpacity -> 
                   1, $CellContext`FrontFaceOpacity -> 1, Opacity -> 1, 
                   FontOpacity -> 1, $CellContext`BackFaceOpacity -> 1], 
                  LabelStyle -> {}, Frame -> True, Background -> Directive[
                    Opacity[0]], ContentPadding -> False, FrameMargins -> 2, 
                  FrameStyle -> None, RoundingRadius -> 4, StripOnInput -> 
                  False], FrameMargins -> 0], {3.8497728876309325`, 
                3.084197097336001}, {0, 0}]}}}}}, AspectRatio -> 1, 
          Axes -> {False, False}, AxesLabel -> {None, None}, 
          AxesOrigin -> {0, 0}, DisplayFunction -> Identity, 
          Frame -> {{False, False}, {False, False}}, 
          FrameLabel -> {{None, None}, {None, None}}, 
          FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
          GridLines -> {None, None}, GridLinesStyle -> Directive[
            GrayLevel[0.5, 0.4]], ImagePadding -> All, 
          ImageSize -> {292.76953125, Automatic}, 
          Method -> {"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                (Identity[#]& )[
                 Part[#, 1]], 
                (Identity[#]& )[
                 Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                (Identity[#]& )[
                 Part[#, 1]], 
                (Identity[#]& )[
                 Part[#, 2]]}& )}}, PlotRange -> All, PlotRangeClipping -> 
          False, PlotRangePadding -> {{
             Scaled[0.05], 
             Scaled[0.05]}, {
             Scaled[0.05], 
             Scaled[0.05]}}, Ticks -> {Automatic, Automatic}]], 
        "ExerciseOutput", Selectable -> False, Copyable -> False, Editable -> 
        False, ShowCellBracket -> False]]], " "}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Center}}},
   GridBoxBackground->{"Columns" -> {{
        RGBColor[1, 1, 1]}}},
   GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{1}}}],
  FrameMargins->0]], "ExerciseOutput",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellFrame->{{1, 1}, {1, 1}},
 ShowCellBracket->False,
 CellFrameColor->RGBColor[0.85, 0.85, 0.85],
 LineBreakWithin->
  Automatic,ExpressionUUID->"6e52e124-4058-40dd-b75e-84bc127f8309"]
}, Closed]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Q&A", "QASection",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"p:127",ExpressionUUID->"3cc8e1d4-33e3-4369-aebd-61cc169c2bee"],

Cell["\<\
How come I\[CloseCurlyQuote]m getting different results from the ones shown \
here?\
\>", "Question",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"ed0b3070-f8a8-454e-8cd9-891a49d328a9"],

Cell[TextData[{
 "Probably because Wolfram Language machine learning functions are \
continually getting more training\[LongDash]and so their results may change, \
hopefully always getting better. For ",
 ButtonBox["TextRecognize",
  BaseStyle->"Link"],
 ", the results can depend in detail on the fonts used, and exactly how they\
\[CloseCurlyQuote]re rendered and rasterized on your computer."
}], "Answer",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"b80fb4c7-83ff-465f-b9c6-75ab0456a10f"],

Cell[TextData[{
 "How does ",
 ButtonBox["ImageIdentify",
  BaseStyle->"Link"],
 " work inside?"
}], "Question",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:28",ExpressionUUID->"6b340d24-60d4-4df9-ba66-91e22a2379e6"],

Cell["\<\
It\[CloseCurlyQuote]s based on artificial neural networks inspired by the way \
brains seem to work. It\[CloseCurlyQuote]s been trained with millions of \
example images, from which it\[CloseCurlyQuote]s progressively learned to \
make distinctions. And a bit like in the game of \
\[OpenCurlyDoubleQuote]twenty questions\[CloseCurlyDoubleQuote], by using \
enough of these distinctions it can eventually determine what an image is of.\
\
\>", "Answer",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"586dfff2-24ce-43b1-82a9-d3ac175b934c"],

Cell[TextData[{
 "How many kinds of things can ",
 ButtonBox["ImageIdentify",
  BaseStyle->"Link"],
 " recognize?"
}], "Question",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"6236fb81-eb31-4a9b-8fbb-14dc9625bd54"],

Cell["\<\
At least 10,000\[LongDash]which is more than a typical human. (There are \
about 5000 \[OpenCurlyDoubleQuote]picturable nouns\[CloseCurlyDoubleQuote] in \
English.) \
\>", "Answer",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:29",ExpressionUUID->"d3365875-81d4-4cc7-9013-7e34489410af"],

Cell[TextData[{
 "What makes ",
 ButtonBox["ImageIdentify",
  BaseStyle->"Link"],
 " give a wrong answer?"
}], "Question",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"cd253324-9318-4d0c-9363-ccb2062db95b"],

Cell[TextData[{
 "A common cause is that what it\[CloseCurlyQuote]s asked about isn\
\[CloseCurlyQuote]t close enough to anything it\[CloseCurlyQuote]s been \
trained on. This can happen if something is in an unusual configuration or \
environment (for example, if a boat is not on a bluish background). ",
 ButtonBox["ImageIdentify",
  BaseStyle->"Link"],
 " usually tries to find some kind of match, and the mistakes it makes often \
seem very \[OpenCurlyDoubleQuote]humanlike\[CloseCurlyDoubleQuote]."
}], "Answer",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"1f74f53b-a377-4425-aa0b-02bd214b4e80"],

Cell[TextData[{
 "Can I ask ",
 ButtonBox["ImageIdentify",
  BaseStyle->"Link"],
 " ",
 "the probabilities it assigns to different identifications",
 "?"
}], "Question",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"1b931045-1634-4559-a619-a642ff61097b"],

Cell[TextData[{
 "Yes. For example, to find the probabilities for the top 10 identifications \
in all categories use ",
 Cell[BoxData[
  RowBox[{
   ButtonBox["ImageIdentify",
    BaseStyle->"CodeLink"], "[", 
   RowBox[{
    StyleBox["image", "CodeVariable"], ",", "All", ",", "10", ",", 
    "\"\<Probability\>\""}], "]"}]], "InlineCode",ExpressionUUID->
  "952384ce-7ed2-4e81-a10b-649158a261b3"],
 "."
}], "Answer",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:30",ExpressionUUID->"550d330d-248f-43d3-888c-ec339c5f25f2"],

Cell[TextData[{
 "How many examples does ",
 ButtonBox["Classify",
  BaseStyle->"Link"],
 " typically need to work well?"
}], "Question",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"7bc4795b-e325-4d96-93d5-ef630494c4f7"],

Cell["\<\
If the general area (like everyday images) is one it already knows well, then \
as few as a hundred. But in areas that are new, it can take many millions of \
examples to achieve good results. \
\>", "Answer",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"34ee50a7-55aa-43ec-936e-89b9abc916a1"],

Cell[TextData[{
 "How does ",
 ButtonBox["Nearest",
  BaseStyle->"Link"],
 " figure out a distance between colors?"
}], "Question",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"9b77af72-daf8-483d-8c72-d1937b1ec264"],

Cell[TextData[{
 "It uses",
 " the function ",
 ButtonBox["ColorDistance",
  BaseStyle->"Link"],
 ", which is based on a model of human color vision."
}], "Answer",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:31",ExpressionUUID->"b66aeffe-eb0e-4102-b5f0-e8880f22ec2e"],

Cell[TextData[{
 "How does ",
 ButtonBox["Nearest",
  BaseStyle->"Link"],
 " determine nearby words?"
}], "Question",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"6c9e24e3-3af5-42ee-b019-63d01b6849cd"],

Cell[TextData[{
 "By looking at those at the smallest ",
 ButtonBox["EditDistance",
  BaseStyle->"Link"],
 ", that is, reached by the smallest number of single-letter insertions, \
deletions and substitutions."
}], "Answer",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:32",ExpressionUUID->"b79db81e-8729-4681-a066-a5b646edcba9"],

Cell["Can a single graph have several disconnected parts?", "Question",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:33",ExpressionUUID->"42d77bdb-d92f-4898-b644-d935f3f38196"],

Cell[TextData[{
 "Absolutely. An example is the ",
 ButtonBox["last graph in this section",
  BaseStyle->"Hyperlink",
  ButtonData->{
   "EIWL2-22-machine-learning.nb", "graph-with-disconnected-parts"}],
 ". "
}], "Answer",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"5dc44c25-205b-4803-ac03-d844f28be576"],

Cell[TextData[{
 "What features does ",
 ButtonBox["FeatureSpacePlot",
  BaseStyle->"Link"],
 " use?"
}], "Question",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"40be2379-3bab-40d4-b1f7-713b8747dab9"],

Cell["\<\
There\[CloseCurlyQuote]s no easy answer. When it\[CloseCurlyQuote]s given a \
collection of things, it\[CloseCurlyQuote]ll learn features that distinguish \
them\[LongDash]though it\[CloseCurlyQuote]s typically primed by having seen \
many other things of the same general type (like images).\
\>", "Answer",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"6be64909-f29c-4bb0-8897-9d38efc8ce86"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Tech Notes", "TechNoteSection",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"3f685e17-6180-4ead-b806-7e746cb0e00d"],

Cell["\<\
The Wolfram Language stores its latest machine learning classifiers in the \
cloud\[LongDash]but if you\[CloseCurlyQuote]re using a desktop system, they\
\[CloseCurlyQuote]ll automatically be downloaded, and then they\
\[CloseCurlyQuote]ll run locally.\
\>", "TechNote",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"36a4d462-0bb8-41e3-a544-ad231c942764"],

Cell[TextData[{
 ButtonBox["BarcodeImage",
  BaseStyle->"Link"],
 " and ",
 ButtonBox["BarcodeRecognize",
  BaseStyle->"Link"],
 " work with bar codes and QR codes ",
 "instead of pure text",
 "."
}], "TechNote",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:34",ExpressionUUID->"73c56276-55c6-4a65-8f1f-1b78204a8750"],

Cell[TextData[{
 ButtonBox["ImageIdentify",
  BaseStyle->"Link"],
 " is the core of what the ",
 ButtonBox["imageidentify.com",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.imageidentify.com"], None},
  ButtonNote->"http://www.imageidentify.com"],
 " website does."
}], "TechNote",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:35",ExpressionUUID->"eb8e4138-3ea9-4899-abb0-1ba32f00f291"],

Cell[TextData[{
 "If you just give ",
 ButtonBox["Classify",
  BaseStyle->"Link"],
 " training examples, it\[CloseCurlyQuote]ll produce a ",
 ButtonBox["ClassifierFunction",
  BaseStyle->"Link"],
 " that can later be applied to many different pieces of data. This is pretty \
much always how ",
 ButtonBox["Classify",
  BaseStyle->"Link"],
 " is used in practice."
}], "TechNote",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->{
  "LastCellOfAPage", 
   "i:36"},ExpressionUUID->"9fc5ce4f-dcf6-474c-b44f-6f489bcf6f33"],

Cell[TextData[{
 "You can get a large standard training set of handwritten digits using ",
 Cell[BoxData[
  RowBox[{
   ButtonBox["ResourceData",
    BaseStyle->"CodeLink"], "[", "\"\<MNIST\>\"", "]"}]], "InlineCode",
  ExpressionUUID->"2b4d62b3-07f5-4780-b224-6ab875fc6719"],
 "."
}], "TechNote",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:37",ExpressionUUID->"ef7ef911-d05f-400b-976a-66aa0b15482a"],

Cell[TextData[{
 ButtonBox["Classify",
  BaseStyle->"Link"],
 " automatically picks between methods such as ",
 StyleBox["logistic regression",
  FontSlant->"Italic"],
 ", ",
 StyleBox["naive Bayes",
  FontSlant->"Italic"],
 ", ",
 StyleBox["random forests",
  FontSlant->"Italic"],
 " and ",
 StyleBox["support vector machines",
  FontSlant->"Italic"],
 ", as well as ",
 StyleBox["neural networks",
  FontSlant->"Italic"],
 "."
}], "TechNote",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:38",ExpressionUUID->"e3fa5da4-8345-4c4a-927b-04fcb7c6381b"],

Cell[TextData[{
 ButtonBox["FindClusters",
  BaseStyle->"Link"],
 " does ",
 StyleBox["unsupervised machine learning",
  FontSlant->"Italic"],
 ", where the computer just looks at data without being told anything about \
it. ",
 ButtonBox["Classify",
  BaseStyle->"Link"],
 " does ",
 StyleBox["supervised machine learning",
  FontSlant->"Italic"],
 ", being given a set of training examples. "
}], "TechNote",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:39",ExpressionUUID->"d6d16db5-34bb-4da5-86d6-3cd96f62dee5"],

Cell[TextData[{
 ButtonBox["Dendrogram",
  BaseStyle->"Link"],
 " does ",
 StyleBox["hierarchical clustering",
  FontSlant->"Italic"],
 ", and can be used to reconstruct evolutionary trees in areas like \
bioinformatics and historical linguistics."
}], "TechNote",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:40",ExpressionUUID->"7c857f2b-faac-4fac-8e04-8de3cd40cf7c"],

Cell[TextData[{
 ButtonBox["FeatureSpacePlot",
  BaseStyle->"Link"],
 " does ",
 StyleBox["dimension reduction",
  FontSlant->"Italic"],
 ", taking data that\[CloseCurlyQuote]s represented by many parameters, and \
finding a good way to \[OpenCurlyDoubleQuote]project\[CloseCurlyDoubleQuote] \
these down so they can be plotted in 2D."
}], "TechNote",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:41",ExpressionUUID->"3c7dc8bf-5ce3-4292-9920-7c2776cb7105"],

Cell[TextData[{
 Cell[BoxData[
  RowBox[{
   ButtonBox["Rasterize",
    BaseStyle->"CodeLink"], "/@", 
   RowBox[{
    ButtonBox["Alphabet",
     BaseStyle->"CodeLink"], "[", " ", "]"}]}]], "InlineCode",ExpressionUUID->
  "9c2c364e-f65d-4d53-aae3-e2cecd032846"],
 " is a better way to make a list of rasterized letters, but we won\
\[CloseCurlyQuote]t talk about ",
 Cell[BoxData["/@"], "InlineCode",ExpressionUUID->
  "b76f7821-2e13-43e8-94e8-ada6f7a10ba1"],
 " until ",
 ButtonBox["Section 25",
  BaseStyle->"Hyperlink",
  ButtonData->{"EIWL2-25-ways-to-apply-functions.nb", None}],
 "."
}], "TechNote",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"dc498b4e-1068-46c0-8243-4772295a2273"],

Cell[TextData[{
 ButtonBox["FeatureExtraction",
  BaseStyle->"Link"],
 " lets you get out the feature vectors used by ",
 ButtonBox["FeatureSpacePlot",
  BaseStyle->"Link"],
 "."
}], "TechNote",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:42",ExpressionUUID->"6d05fccc-7ee0-42c4-926e-547d449189bd"],

Cell[TextData[{
 ButtonBox["FeatureNearest",
  BaseStyle->"Link"],
 " is like ",
 ButtonBox["Nearest",
  BaseStyle->"Link"],
 " except that it learns what should be considered near by looking at the \
actual data you give. It\[CloseCurlyQuote]s what you need to do something \
like build an image-search function. "
}], "TechNote",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:43",ExpressionUUID->"f02996cd-a39b-49f9-b5d5-bcfe9ad1be0c"],

Cell[TextData[{
 "You can build and train your own neural nets in the Wolfram Language using \
functions like ",
 ButtonBox["NetChain",
  BaseStyle->"Link"],
 ", ",
 ButtonBox["NetGraph",
  BaseStyle->"Link"],
 " and ",
 ButtonBox["NetTrain",
  BaseStyle->"Link"],
 ". ",
 ButtonBox["NetModel",
  BaseStyle->"Link"],
 " gives access to prebuilt nets."
}], "TechNote",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:44",ExpressionUUID->"7551e191-b9ae-4518-8c3a-38abbb03b21c"]
}, Open  ]],

Cell[CellGroupData[{

Cell["More to Explore", "MoreExploreSection",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"f0c7b673-8112-4f0d-8022-67ba20a48a1e"],

Cell[TextData[ButtonBox["Guide to Machine Learning in the Wolfram Language\
\[NonBreakingSpace]\[RightGuillemet]",
 BaseStyle->"Link",
 ButtonData->"paclet:guide/MachineLearning"]], "MoreExplore",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->
  "LastCellOfAPage",ExpressionUUID->"5c7969a5-4286-49bd-91be-e54f0f45e870"]
}, Open  ]]
},
Saveable->False,
WindowToolbars->{},
BlinkingCellInsertionPoint->False,
CellInsertionPointCell->None,
WindowSize->{830, 800},
WindowMargins->Automatic,
WindowPersistentStyles->{
 WindowFrame, WindowMargins, WindowSize, Magnification},
WindowTitle->"Machine Learning: Elementary Introduction to the Wolfram \
Language",
DockedCells->{
  Cell[
   BoxData[
    TagBox[
     GridBox[{{
        TemplateBox[{
         "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]", 
          "\"\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\"", 
          GraphicsBox[
           TagBox[
            RasterBox[CompressedData["
1:eJztl01IVFEUxyctMFzUysjIyUDCTauiIJFM6ENpM4NEtJrBUaSYZMYPhCRm
rYuoICgiW0VEBVIUEbTNEMTAIqRsk6JGCVFBHx7//+4JLo/36DqvB4Ie+Mk7
7+t3733nHpzq9NlEW0ksFsuX4U8i1duQy6X6kpuRtGTzHe3ZTOuxbFemPZPb
ny7FyZ2gEqwHInICfJToguOIReywPVHHlYDzcY4hJHZ486giyBOXtfms5Pms
Bs9zUBDTow6DJOgBT8DP/+B5CepAPbgqZm+zT70Bt9VXCx6H8DwE28Gw5ufB
IT2eA1N6PKquC0V4xtUxqfkE6ARD4BHYAx5Y938Gu8GdZXq4VsNWngIfwDzY
Aa6Bm55nOKYq8NXRw29eb+Uz4JSVd4Nn4IbPs2fARUdPQcfLWAQJ8Mq6Tkdd
gGcEHHT0sHYn9Jg1dcnnnhf6vnee8xzXVkcP9wdr97eY7z0NnlrX74qpxffg
iOZ2VDp6kvqOe6AVXAb7xNQB462YNfsCfoBzoE1MzTEqHD096mgE98WsEec4
Jqamvvk8cx2kwWuw19HDXnIAbNAx03ka9IO8mO+3ScyebRZTi01i1rqguHjY
r3aJWaugOA5O6vEC+K6ebWDW0cNgv6oBnwKus87KwKDmv8BRMOBz77/6G/sV
e8lkwHWuTwm4pQ7WzGIRHgb7FXsJ9/mI5z2si42gXMw8/ByuHgb7FXsJ9yX3
IPfHFjF1xTl5v0exnrCx5gnn+fu7JC7h/z/0Y52+P+rfWX9iCXVYErg=
             "], {{0,
              34}, {26, 0}}, {0, 255}, ColorFunction -> RGBColor], 
            BoxForm`ImageTag[
            "Byte", ColorSpace -> "RGB", Interleaving -> True, Magnification -> 
             1], Selectable -> False], DefaultBaseStyle -> "ImageGraphics", 
           ImageSize -> Magnification[1], ImageSizeRaw -> {26, 34}, 
           PlotRange -> {{0, 26}, {0, 34}}], 
          GraphicsBox[
           TagBox[
            RasterBox[CompressedData["
1:eJztXUuS47gRLX8WXtYRaJ+gl17SS+8U4/CeM+H2hDdtRY8jHF6ZR9AReATt
qrwyj6AjcO+ZaN0gLZCZwEMiQVJqSd2qwYvgdBGf/AF4+LFqfvvd37/56y+f
np5++M3pP998+88/fPz47b/+9Hx6+fOHH/72/Yf3f/njh3+8//79x99/96tT
4u9Oz79/8fT066cY9NNLSz++9uPz0+uOPv3n3Zj+40vj083npZktd5IVdJzk
hvT9pHOq78uc9I75rD/KA31n6/z03+dY1lRX64jkQh3LLpevbWI7t6N/Esv/
vdSJDpcOdpr5M74lvk/tt6VPL1VG3j7v79Qedr2XLlevoKDgsTHx8Cud+OTA
XDKM7yfOijnmlB+XC9zvuGfMm+HhqfwR8sjLY54ddbJuw05yesL7Sp2qHtY1
4+F8VjZ4Xajf2/q6Gd/HuUDH6OTvZOM21jHZmm0TsTvH/d531WZOn5o3x3lL
Ys22pnFN87Bezs6CgoLHhFsnMqd1IW1cz26TsrO8nOdSX8bgO+CwZlmHzf2L
OoXbYE08y/2e80AXcDGkbVEuzEXbIAvmA9S/kvuz+aIL5yeJHbTlVHbcQwzT
/BDncT5l6xXuLyh4k4C1Xfb8wZe9Bfcrnr0J949r43H9vV9bl2Oyn2w88Te/
Yx0+DxmiOiddiSyDk2/B/cEGFWPm/GkOeDmavo5zQ5wnaYX7CwreJvy61HGb
cc7uy63g/rEMPLEeg/tl7cxrZa/DpStZ2TOfFTo1Vy5yP88Zk02vGzkTic54
prjx/JDuFWJ501nXXCwS/Wev+9m+aN/Bdrk8dUYVZE1zv7n/4vScHQUFBY8L
f2fpz99PP1v8vob71ROV8efSruxYfj9xojujVuf92cfg/mWdPf88yDp9ed0f
8uXMZJIxroP5zN3ar6Tn6cGOsK5efd6f8S1/3n/6Nzrbirl7sj852yFuk87P
Zfzzmr1VQUHBY2M6+x/HPJnnCddY9yOXjevmkz7kqhut+xPZS9zv1/juvnvc
N3STTv5+R8XCsi+2Y+Joyy67fLijxifxXbhf5uzkeyZ/zt/yt0ADzrXs06RH
fJ7uKI7TnXfh/oKCnwvgDiD67u8W5/1JmZuc92vOndbus9wvd+D+TEq+ZQ3v
wpNTebkTMO5S4b4gZ5dp9xlnPp7/cR7F73v0g9/K4v7Ff4c17VEK9xcUvE2M
vJR828dcpc/m3wL3e05fvsPktW/0jY7n02m9PSS6FP+infHvJlyZ+4352p/h
671AWi5wv/+2R/Y5hfsLCt4icKzD2cpe3xmOZS8484nuIm/E/efqpJXfLkIc
hihdvtnP7YvcuYq/Ww1nM7EM/v5I2y5zzCV3vXJeF/YCg7Yx8kv2LMj9MofI
7/YV7i8oeJOY1vhwxh+e5JvPS+5643vGG3H/mTr9efYi9/vf5+qUHebc6O0P
c4M8e+Mc3rzLDWcvF3C/P6fnuSdno5xX+d/Lm7mnKNxfUPDmodeeBZdjXD+P
sYw5v6CgoKCgoKCgoKCgoKCgoKCgoKCgoKCgoKCgoKCgoKCgoKCgoKCgoOBr
BxE9n57aPV/aloLr4dSeFbdr9m/CXlmf60fVPXTdGi5mHLvqS9uyhNz45fTm
9LTu3y9jXcFacHu1/NRXktlmnprzXb8ZcQ19Pxdw3K7WTtcG2+bQ30nf4fQc
7zXX3BIuZhy79kryKhl3Kt1K23J6tVK2OX7Bh69mbFv+FkzgeVpg/r9bL5CZ
Q8v5D8n99+S1jP4W43hm3Zvbfivuz/nN6Y7/b/57dCcdwzX6K/T9VqXfgvuj
MYZpBPPluWPRGr9KdkdfyXz8iDxzLzi+5/Ac+d/PHkfQB7bcT+SpOP/huJ+m
PflDcj/Eu7+NZV7PXbn/nrhWf70X97NMGdM1v+M6b8tp0q+T/+/cCh/ISrsG
h1wLj8Yz9wJN5z3C+x3/3KgyY7/g8XeE8vn/z1dAncnP7Rk3xOsrRof9SHiF
6x/gXc4Zxb6dkvuO4v1oT/G6R/JQhvt3w/mNsmuUAbL3Kk/rF50tlNnyv3tV
VvQk8SWDA0HeJba3UFfi2UIbYb2Dtol9HyBf4thr+1a0/Vbpk3bdUYoWZRP0
M8Nu3dai38ntVLmEs9jHAylAvu6zkT4lC9tI+yKx2yt5jZJh6TO5FmQKz6O/
e7DJv4PPOF6cPh1jHweK+4H2S2yUdnT+yzkz1hkobifpmxsK3HNkeysKYy6q
Z8TA25nJrykdv63hK/ogequZmCFqMtZfZI9nHIsSr0bZvKW0H3nZNMW3W5Cx
4bwOftZcRErG0SqXqROt+4146jEkcPZIv+gytmC/ORpp77hOBfk9hfY5gFxs
syPIGYz2OHL5HeftVLqgUXajjcJrggr6j9drxHWO+0XHEWUs2N5COnG5DduB
aVhfbMW4DqT4SNu30PYt1JUz/IEC9+vYNcr3WsVvzu6aYuA4S//+Xcr9PYUx
Vis5EoOR3wxZDZTRvmjewHg+G/51YFevdam4SnsPYOfR6lOUtiv6LmPK4n4d
I91G6HMFaRi33rBdxwPXN6u5aCa/A3nYBtKndH/BdulADtoXjQUK9/g5H1tD
jo59ZdiD+a68tDPOix3EqTb8dn0SuUivtYntdGU8Ry/FWwPyrfEvfjT8/sw2
Hw25so4R3h0otNWg5EgZbCdp43fqfc96fd80bPZtB3Zu4F307SBN0Km6En/x
p9V1Vfk57u8usB25H9dcYheuBSVGnRH7Z1Wvh3o5WzBN+qbEYfTD0O39Vr7X
/C593rJbxoXo92sh8MXkEMtmpa+DNOl/yTyiYq59ETt7CuM8GrOgbwv1RJ81
12xQptgKunCtKjokFr3hp+wVrDbMxUig98IbitcRWp7E6cD5yE/S18W/41MG
lk0q38nG8St9uNV+UeifjREjgV47VUoO1rHGs6uLY1F4sTbigvviDuo74LgU
e5GTxL4NxecoTS52ZLRTLt4cx1YeyLf6jqCH52iVMWKH8Yx4At4PIFfGS63K
1DO6TP6E2O4hntomwbOqJzIP/C7xrzJxneP+s22nzFwDduCYiPq7jrOSl/hu
2ELWe8bvtdwv7Tpn99wYjOKTszmnf6WsJe5vjTTxD/di0RhBG6C+jFVXRniy
ARsaUnMH6MT5Rfw/qvfV3J+xbUfqPG0uTpSO2zV9Zzafy1jjt13ha2/YJnEU
v/ReCetYPjo+30I7aHsiHieY3/l9y++yj+lJ7Q8pPmPRwHVTEjsrzcqnM877
oU6vn5xeupz75dHr/npGV44/8cynA1lZu1V935/Fzpm43or7W5U+GDJ1H/sa
ud/a22q7H5n7BVZfrjL6JCbST/H8we/dDJ1Nzn8rHksxUmm4Lu4hJkvcr+Px
2dxP8ZnPTrfDgq89pAknu7EjXHtYqBP5SBPvH0BOS2EsYhwkrYc4bpRM5H55
RE8H9Vt+pC9k19or4ymoM/lWPMWfjVXH0kvruL/D94zcc7jf2WmdidUzNmXj
BeWlzc2zAlW2hbQk1mfYvsRDuEeMzkUgrp1RJvGdwt5X1iXCI7iX9z5k7OlU
uo69xZ9ipz6vQBuX+BrP2a39eGPo6zKyTF0Z2zXXJby8BKjjoM9PPf/O2a9t
ps/n/tbQoeXdnPspvneQ9brm47Xc731iO7cUjzWpg/OBnKVpXdhOms/ceHHj
WOb/PcVj34/1mZhIu+tvNyIOtmK3Nt6kznwonK/WUEbSJHbjOSyFfdhGyzXi
jW2gY4W6XPmN2GXUqWd04fjvKb3LOpD6bmRNvCjufw7VTFw/l/u17Tnuxz1h
C+W8Hoq/F9zN+C79aU9qH2vE/8i6OoL7UiXb6ZL92pxNObvP5n6ly/nTqnrO
1i3F34HUGTlbKOPHLa3jfvFP4iRjpJmxG2Ng3YNondhXdhS+sSEK/QbHQqPr
WXGbsWlHcDdqlJmLx2rup5iHWq6LY8/Jxn7W5nSQ3YfEhx2F71twnYAxi3y2
dFE6XqSM9IGBfxZdlWGLq79hfXKXKWN7MGIl/nczbZekZeKtgbGaW3MIjmTw
HLwvcr+KF8IaB/Wcj6S+veI0HO/OXpnL+zlZSq7Umf3Gmi7k/hnbTe43/CKr
HKXfkUkc0fdWyfD9GcrgXhfL1Zxfq7x2xnfLbuvs2rLRp62IR2XEQNDMyHG+
JvdCtIL7M3aMZxUz+qJ5PCNno+pY40XfCUXjl87jfjzzIYI7OChzbe7XaJVM
iWVuLb523a8x3skauhyk76CPOA4GsvsFzhsI/J0NXebA6RWpeQnkRnn8c63K
JGlWvvHgPOj0bLUNbJ9LT85+tF7LD8r8XRQu2/Cj71yljt6jJT7SNJYaZccG
5Ro2ZeNFExdI+2bPe5S/FaTVa2ynMOd72y15hj6JWa6MtJfpO5RpQW8utjWX
S3RBf9lQ/O1E5PuS3RT+Fo3ui+Z4UHU3FL5bxnhLDLJxMmwQ+2ScJf3W6pfK
v+z5qOGvtrmy0g0dpk96/KIeVS7X1lK/Ql8N+7LxyOm09BsPyh3HhZJZqXe0
zepDbgwPFP4+hoxpUnWlD1VaF8j2bavjQGHe6Sic0yfraCi7pRV9suC+4H4g
87w/4ygoKHgcUNhb4f2YnMsTLawpztTVa5kUzhH7a+kpuC0o3vc2X9qegoKC
80Hp78Phmr+7si48q5O9hqwdrzbHFNwWFL61rr60LQUFBZeDwt9N7Sl8O1nf
SFdD4XuijtQ3RXP4P6lulfg=
             "], {{0, 34}, {383, 0}}, {0, 255}, 
             ColorFunction -> RGBColor], 
            BoxForm`ImageTag[
            "Byte", ColorSpace -> "RGB", Interleaving -> True, Magnification -> 
             1], Selectable -> False], DefaultBaseStyle -> "ImageGraphics", 
           ImageSize -> Magnification[1], ImageSizeRaw -> {383, 34}, 
           PlotRange -> {{0, 383}, {0, 34}}]}, "RowWithSeparators"], 
        PaneBox[
         StyleBox["\[VeryThinSpace]", ShowStringCharacters -> False], 
         Alignment -> Right, ImageSize -> {174, 47}], 
        PaneBox[
         PaneBox[
          TemplateBox[{"\[ThinSpace]", "\" \"", 
            TagBox[
             TooltipBox[
              PaneSelectorBox[{False -> ButtonBox[
                  PaneBox[
                   GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UJAPiDmBmIUBO/j//z8jEDcA8W8g3oBFnhmIZ/9HgE9o8mxAvBZJ/hsQuyPJ
8wPxfiT5N0BsjiQvCsTnkOSfALEWkrwSEN9Bkr8OxDJobniAJP8ZZCYWfxCj
RpGQXcS4mVi/ExuGxMYFmlp4nAIAG14fWQ==
                    "], {{0, 14}, {9, 
                    0}}, {0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], DefaultBaseStyle -> "ImageGraphics",
                     ImageSizeRaw -> {9, 14}, PlotRange -> {{0, 9}, {0, 14}}, 
                    ImageSize -> Magnification[1]], ImageSize -> {35, 30}, 
                   Alignment -> Center], 
                  ButtonFunction :> (
                   NotebookLocate[{"EIWL2-21-graphs-and-networks.nb", ""}, 
                    FrontEnd`HistoryData :> {
                    EvaluationNotebook[]}]& ), Enabled -> True, Appearance -> 
                  None, Evaluator -> Automatic, Method -> "Preemptive"], True -> 
                ButtonBox[
                  PaneBox[
                   GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UJAPiDmBmIUBO/j//z8jEDcA8W8g3oBFnhmIZ/9HgE9o8mxAvBZJ/hsQuyPJ
8wPxfiT5N0BsjiQvCsTnkOSfALEWkrwSEN9Bkr8OxDJobniAJP8ZZCYWfxCj
RpGQXcS4mVi/ExuGxMYFmlp4nAIAG14fWQ==
                    "], {{0, 14}, {9, 
                    0}}, {0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], DefaultBaseStyle -> "ImageGraphics",
                     ImageSizeRaw -> {9, 14}, PlotRange -> {{0, 9}, {0, 14}}, 
                    ImageSize -> Magnification[1]], ImageSize -> {35, 30}, 
                   Alignment -> Center], 
                  ButtonFunction :> (
                   NotebookLocate[{"EIWL2-21-graphs-and-networks.nb", ""}, 
                    FrontEnd`HistoryData :> {
                    EvaluationNotebook[]}]& ), Enabled -> True, Appearance -> 
                  None, Background -> RGBColor[0.835294, 0.364706, 0.0196078],
                   Evaluator -> Automatic, Method -> "Preemptive"]}, 
               Dynamic[
                CurrentValue["MouseOver"]], ImageSize -> Automatic, 
               FrameMargins -> 0], "\"Graphs and Networks\"", TooltipDelay -> 
              0.15, LabelStyle -> "TextStyling"], 
             Annotation[#, "Graphs and Networks", "Tooltip"]& ], 
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {5, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[5], Selectable -> False], 
            TagBox[
             TooltipBox[
              PaneSelectorBox[{False -> ButtonBox[
                  PaneBox[
                   GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UJAfiDmBmAWI////vwKIfwFxMQMOAJT7+R8B6nGoSf+PCjpwqMskUl0SEP9F
UtcHxIxY1EWjqZuOQ10Mmr2TcNj7BEnNP1LNIeQeIDsZn78IhQ8x4fwfNb4a
cPgTFu8l2ORBAAC+1hnm
                    "], {{0, 15}, {9, 0}}, {0, 255}, 
                    ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], DefaultBaseStyle -> "ImageGraphics",
                     ImageSizeRaw -> {9, 15}, PlotRange -> {{0, 9}, {0, 15}}, 
                    ImageSize -> Magnification[1]], ImageSize -> {35, 30}, 
                   Alignment -> Center], 
                  ButtonFunction :> (
                   NotebookLocate[{"EIWL2-23-more-about-numbers.nb", ""}, 
                    FrontEnd`HistoryData :> {
                    EvaluationNotebook[]}]& ), Appearance -> None, Evaluator -> 
                  Automatic, Method -> "Preemptive"], True -> ButtonBox[
                  PaneBox[
                   GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UJAfiDmBmAWI////vwKIfwFxMQMOAJT7+R8B6nGoSf+PCjpwqMskUl0SEP9F
UtcHxIxY1EWjqZuOQ10Mmr2TcNj7BEnNP1LNIeQeIDsZn78IhQ8x4fwfNb4a
cPgTFu8l2ORBAAC+1hnm
                    "], {{0, 15}, {9, 0}}, {0, 255}, 
                    ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], DefaultBaseStyle -> "ImageGraphics",
                     ImageSizeRaw -> {9, 15}, PlotRange -> {{0, 9}, {0, 15}}, 
                    ImageSize -> Magnification[1]], ImageSize -> {35, 30}, 
                   Alignment -> Center], 
                  ButtonFunction :> (
                   NotebookLocate[{"EIWL2-23-more-about-numbers.nb", ""}, 
                    FrontEnd`HistoryData :> {
                    EvaluationNotebook[]}]& ), Appearance -> None, Background -> 
                  RGBColor[0.835294, 0.364706, 0.0196078], Evaluator -> 
                  Automatic, Method -> "Preemptive"]}, 
               Dynamic[
                CurrentValue["MouseOver"]], ImageSize -> Automatic, 
               FrameMargins -> 0], "\"More about Numbers\"", TooltipDelay -> 
              0.15, LabelStyle -> "TextStyling"], 
             Annotation[#, "More about Numbers", "Tooltip"]& ]}, 
           "RowWithSeparators"], Alignment -> Right], ImageSize -> {100, 30}, 
         FrameMargins -> {{0, 6}, {0, 0}}, Alignment -> Right], 
        ActionMenuBox[
         PaneSelectorBox[{True -> PanelBox[
             GraphicsBox[
              TagBox[
               RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UBAkIQ3ELED8////Jf/pA0D2/KWTXSB7ZtPBPrA9DKOAYgAMR1Eg9gPiABpi
P6g912mcLmAAZM9XOtkFsicKiNcD8QYaYpD5UQOdXoYD+E/HMooO9iDbR7c6
BQDxtyEt
                "], {{0, 16}, {27, 0}}, {0, 255}, ColorFunction -> 
                RGBColor], 
               BoxForm`ImageTag[
               "Byte", ColorSpace -> "RGB", Interleaving -> True, 
                Magnification -> 1], Selectable -> False], DefaultBaseStyle -> 
              "ImageGraphics", ImageSize -> Magnification[1], 
              ImageSizeRaw -> {27, 16}, PlotRange -> {{0, 27}, {0, 16}}], 
             Appearance -> None, Background -> 
             RGBColor[0.835294, 0.364706, 0.0196078], ImageSize -> {35, 30}, 
             Alignment -> Center], False -> PanelBox[
             GraphicsBox[
              TagBox[
               RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UBAkIQ3ELED8////Jf/pA0D2/KWTXSB7ZtPBPrA9DKOAYgAMR1Eg9gPiABpi
P6g912mcLmAAZM9XOtkFsicKiNcD8QYaYpD5UQOdXoYD+E/HMooO9iDbR7c6
BQDxtyEt
                "], {{0, 16}, {27, 0}}, {0, 255}, ColorFunction -> 
                RGBColor], 
               BoxForm`ImageTag[
               "Byte", ColorSpace -> "RGB", Interleaving -> True, 
                Magnification -> 1], Selectable -> False], DefaultBaseStyle -> 
              "ImageGraphics", ImageSize -> Magnification[1], 
              ImageSizeRaw -> {27, 16}, PlotRange -> {{0, 27}, {0, 16}}], 
             Appearance -> None, Background -> 
             RGBColor[0.952941, 0.509804, 0], ImageSize -> {35, 30}, 
             Alignment -> Center]}, 
          Dynamic[
           CurrentValue["MouseOver"]]], {
         "Preface" :> 
          NotebookLocate[{"EIWL2-0a-preface.nb", ""}, FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "What Is the Wolfram Language?" :> 
          NotebookLocate[{"EIWL2-0b-what-is-the-wolfram-language.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "Practicalities of Using the Wolfram Language" :> 
          NotebookLocate[{
            "EIWL2-0c-practicalities-of-using-the-wolfram-language.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "Other Resources" :> 
          NotebookLocate[{"EIWL2-0d-other-resources.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "\[ThickSpace]\[ThickSpace]\[ThinSpace]1\[ThickSpace]\[ThickSpace]|\
\[ThickSpace]\[ThickSpace]Starting Out: Elementary Arithmetic" :> 
          NotebookLocate[{
            "EIWL2-01-starting-out-elementary-arithmetic.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "\[ThickSpace]\[ThickSpace]\[ThinSpace]2\[ThickSpace]\[ThickSpace]|\
\[ThickSpace]\[ThickSpace]Introducing Functions" :> 
          NotebookLocate[{"EIWL2-02-introducing-functions.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "\[ThickSpace]\[ThickSpace]\[ThinSpace]3\[ThickSpace]\[ThickSpace]|\
\[ThickSpace]\[ThickSpace]First Look at Lists" :> 
          NotebookLocate[{"EIWL2-03-first-look-at-lists.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          
          "\[ThickSpace]\[ThickSpace]\[ThinSpace]4\[ThickSpace]\[ThickSpace]|\
\[ThickSpace]\[ThickSpace]Displaying Lists" :> 
          NotebookLocate[{"EIWL2-04-displaying-lists.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "\[ThickSpace]\[ThickSpace]\[ThinSpace]5\[ThickSpace]\[ThickSpace]|\
\[ThickSpace]\[ThickSpace]Operations on Lists" :> 
          NotebookLocate[{"EIWL2-05-operations-on-lists.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "\[ThickSpace]\[ThickSpace]\[ThinSpace]6\[ThickSpace]\[ThickSpace]|\
\[ThickSpace]\[ThickSpace]Making Tables" :> 
          NotebookLocate[{"EIWL2-06-making-tables.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "\[ThickSpace]\[ThickSpace]\[ThinSpace]7\[ThickSpace]\[ThickSpace]|\
\[ThickSpace]\[ThickSpace]Colors and Styles" :> 
          NotebookLocate[{"EIWL2-07-colors-and-styles.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "\[ThickSpace]\[ThickSpace]\[ThinSpace]8\[ThickSpace]\[ThickSpace]|\
\[ThickSpace]\[ThickSpace]Basic Graphics Objects" :> 
          NotebookLocate[{"EIWL2-08-basic-graphics-objects.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "\[ThickSpace]\[ThickSpace]\[ThinSpace]9\[ThickSpace]\[ThickSpace]|\
\[ThickSpace]\[ThickSpace]Interactive Manipulation" :> 
          NotebookLocate[{"EIWL2-09-interactive-manipulation.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "10\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Images" :> 
          NotebookLocate[{"EIWL2-10-images.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "11\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Strings and \
Text" :> NotebookLocate[{"EIWL2-11-strings-and-text.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "12\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Sound" :> 
          NotebookLocate[{"EIWL2-12-sound.nb", ""}, FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "13\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Arrays, or \
Lists of Lists" :> 
          NotebookLocate[{"EIWL2-13-arrays-or-lists-of-lists.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "14\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Coordinates \
and Graphics" :> 
          NotebookLocate[{"EIWL2-14-coordinates-and-graphics.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "15\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]The Scope \
of the Wolfram Language" :> 
          NotebookLocate[{
            "EIWL2-15-the-scope-of-the-wolfram-language.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "16\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Real\
\[Hyphen]World Data" :> 
          NotebookLocate[{"EIWL2-16-real-world-data.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "17\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Units" :> 
          NotebookLocate[{"EIWL2-17-units.nb", ""}, FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "18\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]\
Geocomputation" :> 
          NotebookLocate[{"EIWL2-18-geocomputation.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "19\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Dates and \
Times" :> NotebookLocate[{"EIWL2-19-dates-and-times.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "20\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Options" :> 
          NotebookLocate[{"EIWL2-20-options.nb", ""}, FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "21\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Graphs and \
Networks" :> 
          NotebookLocate[{"EIWL2-21-graphs-and-networks.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          
          "22\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Machine \
Learning" :> 
          NotebookLocate[{"EIWL2-22-machine-learning.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "23\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]More about \
Numbers" :> NotebookLocate[{"EIWL2-23-more-about-numbers.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "24\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]More Forms \
of Visualization" :> 
          NotebookLocate[{"EIWL2-24-more-forms-of-visualization.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "25\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Ways to \
Apply Functions" :> 
          NotebookLocate[{"EIWL2-25-ways-to-apply-functions.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "26\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Pure \
Anonymous Functions" :> 
          NotebookLocate[{"EIWL2-26-pure-anonymous-functions.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "27\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Applying \
Functions Repeatedly" :> 
          NotebookLocate[{"EIWL2-27-applying-functions-repeatedly.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "28\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Tests and \
Conditionals" :> 
          NotebookLocate[{"EIWL2-28-tests-and-conditionals.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "29\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]More about \
Pure Functions" :> 
          NotebookLocate[{"EIWL2-29-more-about-pure-functions.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "30\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Rearranging \
Lists" :> NotebookLocate[{"EIWL2-30-rearranging-lists.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          
          "31\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Parts of \
Lists" :> NotebookLocate[{"EIWL2-31-parts-of-lists.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "32\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Patterns" :> 
          NotebookLocate[{"EIWL2-32-patterns.nb", ""}, FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "33\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Expressions \
and Their Structure" :> 
          NotebookLocate[{"EIWL2-33-expressions-and-their-structure.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "34\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]\
Associations" :> 
          NotebookLocate[{"EIWL2-34-associations.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "35\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Natural \
Language Understanding" :> 
          NotebookLocate[{"EIWL2-35-natural-language-understanding.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "36\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Creating \
Websites and Apps" :> 
          NotebookLocate[{"EIWL2-36-creating-websites-and-apps.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "37\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Layout and \
Display" :> NotebookLocate[{"EIWL2-37-layout-and-display.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "38\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Assigning \
Names to Things" :> 
          NotebookLocate[{"EIWL2-38-assigning-names-to-things.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "39\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Immediate \
and Delayed Values" :> 
          NotebookLocate[{"EIWL2-39-immediate-and-delayed-values.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "40\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Defining \
Your Own Functions" :> 
          NotebookLocate[{"EIWL2-40-defining-your-own-functions.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "41\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]More about \
Patterns" :> 
          NotebookLocate[{"EIWL2-41-more-about-patterns.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "42\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]String \
Patterns and Templates " :> 
          NotebookLocate[{"EIWL2-42-string-patterns-and-templates.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "43\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Storing \
Things" :> NotebookLocate[{"EIWL2-43-storing-things.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "44\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Importing \
and Exporting" :> 
          NotebookLocate[{"EIWL2-44-importing-and-exporting.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "45\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Datasets" :> 
          NotebookLocate[{"EIWL2-45-datasets.nb", ""}, FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "46\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Writing \
Good Code" :> 
          NotebookLocate[{"EIWL2-46-writing-good-code.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "47\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Debugging \
Your Code" :> 
          NotebookLocate[{"EIWL2-47-debugging-your-code.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "What We Haven\[CloseCurlyQuote]t Discussed" :> 
          NotebookLocate[{"EIWL2-what-we-havent-discussed.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "Afterword: Being a Programmer" :> 
          NotebookLocate[{"EIWL2-being-a-programmer.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "Answers to Exercises" :> 
          NotebookLocate[{"EIWL2-answers-to-exercises.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "Index" :> 
          NotebookLocate[{"EIWL2-book-index.nb", ""}, FrontEnd`HistoryData :> {
              EvaluationNotebook[]}]}, Appearance -> None]}}, 
      GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Center}}}, 
      GridBoxItemSize -> {
       "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], "Grid"]], 
   "Text", ShowCellBracket -> False, CellFrame -> {{0, 0}, {3, 0}}, 
   Selectable -> False, CellFrameColor -> 
   RGBColor[0.835294, 0.364706, 0.0196078], CellMargins -> {{0, 0}, {0, -1}}, 
   CellFrameMargins -> {{27, 0}, {1, 7}}, Background -> 
   RGBColor[0.952941, 0.509804, 0], CellTags -> "DockedCellLogoCell"], 
  Cell["SECOND EDITION", "Text", FontFamily -> "Source Sans Pro", 
   CellFrame -> {{0, 0}, {3, 0}}, ShowCellBracket -> False, 
   CellMargins -> {{0, 0}, {-1, -1}}, CellFrameMargins -> {{66, 0}, {2, 4}}, 
   CellFrameColor -> RGBColor[0.952941, 0.509804, 0], FontSize -> 10, 
   FontTracking -> "Extended", FontColor -> RGBColor[1, 0.929412, 0.721569], 
   Background -> RGBColor[0.862745, 0.309804, 0], CellTags -> 
   "DockedCellLogoCell"]},
PrintingStartingPageNumber->180,
PageHeaders->{{
   Cell[
    TextData[{
      StyleBox[
       CounterBox["Page"], "PageNumber"], 
      StyleBox[
      "    An Elementary Introduction to the Wolfram Language", "Header"]}], 
    "Header", CellMargins -> {{37, Inherited}, {Inherited, Inherited}}], None,
    None}, {None, None, 
   Cell[
    TextData[{
      StyleBox[
       CounterBox["Section"], "Header"], 
      StyleBox[" | Machine Learning \[LongDash] wolfr.am/eiwl-", "Header"], 
      StyleBox[
       CounterBox["Section"], "Header"], 
      StyleBox["    ", "Header"], 
      StyleBox[
       CounterBox["Page"], "PageNumber"]}], "Header", 
    CellMargins -> {{Inherited, 17}, {Inherited, Inherited}}]}},
PrintingOptions->{"FirstPageHeader"->True},
ShowCellBracket->Automatic,
ShowAutoSpellCheck->False,
ShowPredictiveInterface->False,
ShowSyntaxStyles->False,
Magnification->1.,
FrontEndVersion->"11.1 for Mac OS X x86 (32-bit, 64-bit Kernel) (April 18, \
2017)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[StyleDefinitions -> "Default.nb"]], 
   Cell[
    CellGroupData[{
      Cell[
      "Style Environments", "Section", 
       CellChangeTimes -> {{3.64661165091824*^9, 3.646611654013329*^9}, 
         3.6485723794335403`*^9, 3.651347081728628*^9, 3.651347179462186*^9, 
         3.651347384135805*^9, 3.651348171662589*^9}], 
      Cell[
       StyleData[All, "Working"], CellInsertionPointCell -> 
       FEPrivate`FrontEndResource["FEExpressions", "CellInsertionMenu"], 
       CreateCellID -> True, $CellContext`GhostCellInEmptyNotebook -> False], 
      
      Cell[
       StyleData[All, "Printout"], 
       PrintingOptions -> {
        "PageSize" -> {504, 720}, "PrintRegistrationMarks" -> True}, 
       Magnification -> 0.6]}, Closed]], 
   Cell[
    CellGroupData[{
      Cell["Styles for Headers and Footers", "Section"], 
      Cell[
       StyleData["Header"], StyleMenuListing -> None, FontFamily -> "Verdana",
        FontSize -> 7, FontSlant -> "Plain", FontColor -> GrayLevel[0.6]], 
      Cell[
       StyleData["PageNumber"], CellMargins -> {{0, 0}, {4, 1}}, 
       StyleMenuListing -> None, FontFamily -> "Verdana", FontSize -> 7, 
       FontWeight -> "Bold", FontSlant -> "Plain", FontColor -> 
       GrayLevel[0]]}, Closed]], 
   Cell[
    CellGroupData[{
      Cell[
      "WPL Specific", "Section", 
       CellChangeTimes -> {{3.6556608433734913`*^9, 3.6556608489412746`*^9}}], 
      Cell[
       StyleData["Link"], FontFamily -> "Source Sans Pro", FontSize :> 
       If[CurrentValue[
           EvaluationCell[], "FontFamily"] === "Source Sans Pro", Inherited, 
         If[CurrentValue[
            EvaluationCell[], "FontFamily"] === "WolframCodeSans", Inherited, 
          Inherited 0.9]], FontColor -> GrayLevel[0]], 
      Cell[
       StyleData["CodeLink"], 
       ButtonBoxOptions -> {
        Appearance -> None, ButtonFunction :> (FEPrivate`FrontEndExecute[
           FrontEndToken["OpenHelpLink", {
             Part[#, 1], Null}]]& ), ButtonSource -> ButtonContents, 
         Evaluator -> None, Method -> "Preemptive"}]}, Closed]], 
   Cell[
    CellGroupData[{
      Cell[
      "Custom Styles", "Section", 
       CellChangeTimes -> {{3.646611660445352*^9, 3.646611669493331*^9}}], 
      Cell[
       StyleData["Notebook"], PageWidth -> 700, 
       PrintingOptions -> {
        "InnerOuterMargins" -> {35, 16}, "PaperOrientation" -> "Portrait", 
         "PaperSize" -> {504, 720}, 
         "PrintingMargins" -> {{20, 20}, {54, 54}}}, CellLabelAutoDelete -> 
       False, ShowSyntaxStyles -> True, 
       AutoStyleOptions -> {
        "FormattingErrorTooltips" -> False, "HighlightComments" -> False, 
         "HighlightEmphasizedSyntaxErrors" -> False, 
         "HighlightExcessArguments" -> False, "HighlightFormattingErrors" -> 
         False, "HighlightGlobalToLocalScopeConflicts" -> False, 
         "HighlightGraphicsCompatibilityProblems" -> False, 
         "HighlightLocalScopeConflicts" -> False, "HighlightMissingArguments" -> 
         False, "HighlightNoKernelPresent" -> False, 
         "HighlightOrderOfEvaluationConflicts" -> False, "HighlightStrings" -> 
         True, "HighlightSymbolContexts" -> False, "HighlightSymbolShadowing" -> 
         False, "HighlightSyntaxErrors" -> False, "HighlightUndefinedSymbols" -> 
         False, "HighlightUnknownOptions" -> False, 
         "HighlightUnwantedAssignments" -> False}, MenuSortingValue -> None, 
       GraphicsBoxOptions -> {ImageSize -> 240}, 
       Graphics3DBoxOptions -> {ImageSize -> 240}], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Title"], CellMargins -> {{64, Inherited}, {50, 72}}, 
          MenuCommandKey -> None, FontFamily -> "Verdana", FontSize -> 42, 
          FontWeight -> "Bold", FontColor -> GrayLevel[0.4]], 
         Cell[
          StyleData["Title", "Printout"], 
          CellMargins -> {{64, Inherited}, {50, 72}}]}, Closed]], 
      Cell[
       StyleData["Chapter"], MenuCommandKey -> None], 
      Cell[
       StyleData["Subchapter"], MenuCommandKey -> None], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Section"], CellFrame -> {{0, 0}, {0, 0}}, CellDingbat -> 
          Cell[
            TextData[
             CounterBox["Section"], 
             StyleBox[
             "|\[NegativeThinSpace]", FontColor -> 
              RGBColor[
               0.9019607843137255, 0.4117647058823529, 0.027450980392156862`],
               FontFamily -> "Courier", FontSize -> 36, FontWeight -> Plain]],
             "SectionNumber"], CellMargins -> {{96, Inherited}, {12, 44}}, 
          Evaluatable -> True, CellGroupingRules -> {"SectionGrouping", 60}, 
          PageBreakAbove -> True, ShowCellLabel -> False, 
          CellFrameLabelMargins -> {{2, Inherited}, {Inherited, Inherited}}, 
          CellChangeTimes -> {3.652728456208679*^9, 3.652728527108994*^9}, 
          CounterIncrements -> "Section", 
          CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
            "Exercise", 0}}, FontFamily -> "Source Sans Pro Semibold", 
          FontSize -> 26, FontSlant -> "Plain", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          InterpretationBoxOptions -> {Editable -> True}], 
         Cell[
          StyleData["Section", "Printout"], 
          CellMargins -> {{96, Inherited}, {12, 2}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["SectionDoubleDigit"], CellFrame -> {{0, 0}, {0, 0}}, 
          CellDingbat -> Cell[
            TextData[
             CounterBox["Section"], 
             StyleBox[
             "|\[NegativeThinSpace]", FontColor -> 
              RGBColor[
               0.9019607843137255, 0.4117647058823529, 0.027450980392156862`],
               FontFamily -> "Courier", FontSize -> 36, FontWeight -> Plain]],
             "SectionNumber"], CellMargins -> {{112, Inherited}, {12, 44}}, 
          Evaluatable -> True, CellGroupingRules -> {"SectionGrouping", 60}, 
          PageBreakAbove -> True, ShowCellLabel -> False, 
          CellFrameLabelMargins -> {{2, Inherited}, {Inherited, Inherited}}, 
          CellChangeTimes -> {3.652728456208679*^9, 3.652728527108994*^9}, 
          CounterIncrements -> "Section", 
          CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
            "Exercise", 0}}, FontFamily -> "Source Sans Pro Semibold", 
          FontSize -> 26, FontSlant -> "Plain", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          InterpretationBoxOptions -> {Editable -> True}], 
         Cell[
          StyleData["SectionDoubleDigit", "Printout"], 
          CellMargins -> {{112, Inherited}, {12, 2}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["SectionNumber"], CellBaseline -> Baseline, FontFamily -> 
          "Source Sans Pro Semibold", FontSize -> 26, FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
         Cell[
          StyleData["SectionNumber", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["SectionInline"], FontFamily -> 
          "Source Sans Pro Semibold", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
         Cell[
          StyleData["SectionInline", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["SectionNoDingbat"], 
          CellMargins -> {{64, Inherited}, {12, 44}}, Evaluatable -> True, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakAbove -> 
          True, ShowCellLabel -> False, 
          CellFrameLabelMargins -> {{2, Inherited}, {Inherited, Inherited}}, 
          CellChangeTimes -> {3.652728456208679*^9, 3.652728527108994*^9}, 
          CounterIncrements -> "Section", 
          CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
            "Exercise", 0}}, FontFamily -> "Source Sans Pro Semibold", 
          FontSize -> 26, FontSlant -> "Plain", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          InterpretationBoxOptions -> {Editable -> True}], 
         Cell[
          StyleData["SectionNoDingbat", "Printout"], 
          CellMargins -> {{64, Inherited}, {12, 2}}]}, Closed]], 
      Cell[
       StyleData["AnswerKeyNumberedSection"], 
       CellMargins -> {{64, Inherited}, {8, 28}}, Evaluatable -> True, 
       CellGroupingRules -> {"SectionGrouping", 60}, PageBreakAbove -> True, 
       ShowCellLabel -> False, 
       CellFrameLabelMargins -> {{2, Inherited}, {Inherited, Inherited}}, 
       CellChangeTimes -> {3.652728456208679*^9, 3.652728527108994*^9}, 
       CounterIncrements -> "Section", 
       CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
         "Exercise", 0}}, FontFamily -> "Source Sans Pro Semibold", FontSize -> 
       18, FontSlant -> "Plain", FontColor -> 
       RGBColor[
        0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
       InterpretationBoxOptions -> {Editable -> True}], 
      Cell[
       StyleData["AnswerKeySectionNumber"], CellBaseline -> Baseline, 
       FontFamily -> "Source Sans Pro Semibold", FontSize -> 18, FontColor -> 
       RGBColor[
        0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
      Cell[
       StyleData["IndexLinkGuide"], 
       CellMargins -> {{64, Inherited}, {48, 28}}, Evaluatable -> True, 
       CellGroupingRules -> {"SectionGrouping", 60}, PageBreakAbove -> True, 
       ShowCellLabel -> False, 
       CellFrameLabelMargins -> {{2, Inherited}, {Inherited, Inherited}}, 
       CellChangeTimes -> {3.652728456208679*^9, 3.652728527108994*^9}, 
       CounterIncrements -> "Section", 
       CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
         "Exercise", 0}}, FontFamily -> "Source Sans Pro", FontSize -> 14, 
       FontSlant -> "Plain", FontColor -> 
       RGBColor[
        0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
       InterpretationBoxOptions -> {Editable -> True}], 
      Cell[
       StyleData["Index"], MenuSortingValue -> 10000, FontFamily -> 
       "Source Sans Pro", FontSize -> 11], 
      Cell[
       StyleData["IndexSubentry"], MenuSortingValue -> 10000, FontFamily -> 
       "Source Sans Pro", FontSize -> 11], 
      Cell[
       StyleData["FunctionName"], MenuSortingValue -> 10000, FontFamily -> 
       "Source Sans Pro Semibold", FontWeight -> "Bold"], 
      Cell[
       StyleData["IndexColumn"], 
       CellMargins -> {{66, 0}, {Inherited, Inherited}}, TabSpacings -> {2.}, 
       MenuSortingValue -> 10000, FontFamily -> "Source Sans Pro", 
       GridBoxOptions -> {
        GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
         GridBoxItemSize -> {"Columns" -> {{25}}}, 
         GridBoxSpacings -> {"Columns" -> {{2}}}}], 
      Cell[
       StyleData["IndexSubsection"], 
       CellMargins -> {{64, Inherited}, {9, 28}}, 
       CellGroupingRules -> {"SectionGrouping", 40}, MenuSortingValue -> 
       10000, FontFamily -> "Source Sans Pro", FontSize -> 24], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Subsection"], CellMargins -> {{64, Inherited}, {12, 32}},
           FontFamily -> "Source Sans Pro Semibold", FontSize -> 18, 
          FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
         Cell[
          StyleData["Subsection", "Printout"], 
          CellMargins -> {{64, Inherited}, {12, 32}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ResourcesSubsection"], 
          CellMargins -> {{64, Inherited}, {4, 16}}, FontFamily -> 
          "Source Sans Pro Semibold", FontSize -> 15, FontSlant -> "Plain", 
          FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["ResourcesSubsection", "Printout"], 
          CellMargins -> {{64, Inherited}, {4, 16}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Subsubsection"], 
          CellMargins -> {{64, Inherited}, {6, 12}}, FontFamily -> 
          "Source Sans Pro Semibold", FontSize -> 16, FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
         Cell[
          StyleData["Subsubsection", "Printout"], 
          CellMargins -> {{64, Inherited}, {6, 12}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["VocabularySection"], PageWidth -> 700, 
          CellFrame -> {{0, 0}, {0, 3}}, 
          CellMargins -> {{64, Inherited}, {8, 24}}, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakBelow -> 
          False, CellFrameMargins -> {{8, 8}, {4, 6}}, CellFrameColor -> 
          RGBColor[0.901961, 0.411765, 0.027451], FontFamily -> 
          "Source Sans Pro", FontSize -> 18, FontSlant -> "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          GridBoxOptions -> {GridBoxAlignment -> {}}], 
         Cell[
          StyleData["VocabularySection", "Printout"], 
          CellMargins -> {{64, Inherited}, {8, 24}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["VocabularyTable", StyleDefinitions -> StyleData["Text"]],
           SpanMaxSize -> 1, FontFamily -> "Source Sans Pro Light", FontColor -> 
          GrayLevel[0.8], 
          GridBoxOptions -> {
           GridBoxAlignment -> {"Columns" -> {{Left}}}, 
            GridBoxDividers -> {"Columns" -> {{False}}, "Rows" -> {False, {
                 Directive[
                  Thickness[0.5], "VocabDivColor"]}, False}}, 
            GridBoxItemStyle -> {
             "Columns" -> {"VocabularyCode", Inherited, Inherited}, 
              "Rows" -> {{Automatic}}}, 
            GridBoxSpacings -> {
             "Columns" -> {{0, 1, 2, 1, 2}}, "Rows" -> {{1}}}}], 
         Cell[
          StyleData["VocabularyTable", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData[
          "VocabularyTable3Column", StyleDefinitions -> StyleData["Text"]], 
          SpanMaxSize -> 1, FontFamily -> "Source Sans Pro Light", FontColor -> 
          GrayLevel[0.8], 
          GridBoxOptions -> {
           GridBoxAlignment -> {"Columns" -> {{Left}}}, 
            GridBoxDividers -> {"Columns" -> {{False}}, "Rows" -> {False, {
                 Directive[
                  Thickness[0.5], "VocabDivColor"]}, False}}, 
            GridBoxItemStyle -> {
             "Columns" -> {
               "VocabularyCode", Inherited, "VocabularyCode", Inherited, 
                Inherited}, "Rows" -> {{Automatic}}}, 
            GridBoxSpacings -> {
             "Columns" -> {{0, 1, 2, 1, 2}}, "Rows" -> {{1}}}}], 
         Cell[
          StyleData["VocabularyTable3Column", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["VocabularyText"], FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Plain", FontSlant -> "Plain", 
          FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["VocabularyText", "Printout"], 
          CellMargins -> {{66, 10}, {7, 7}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["VocabularyCode", StyleDefinitions -> StyleData["Text"]], 
          Deletable -> False, FontFamily -> "Source Sans Pro", FontSize -> 14,
           FontWeight -> "Bold", FontColor -> GrayLevel[0.25], 
          GridBoxOptions -> {
           GridBoxAlignment -> {"Columns" -> {{Left}}}, 
            GridBoxDividers -> {
             "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {True, {True}, True}, "RowsIndexed" -> {}}}], 
         Cell[
          StyleData["VocabularyCode", "Printout"], FontColor -> 
          GrayLevel[0.25]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["VocabDivColor"], FontColor -> GrayLevel[0.8]], 
         Cell[
          StyleData["VocabDivColor", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ExerciseSection"], PageWidth -> 700, 
          CellFrame -> {{0, 0}, {0, 3}}, 
          CellMargins -> {{64, Inherited}, {8, 30}}, Evaluatable -> True, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakBelow -> 
          False, ShowCellLabel -> False, CellFrameMargins -> {{8, 8}, {4, 6}},
           CellFrameColor -> RGBColor[0.901961, 0.411765, 0.027451], 
          CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
            "Exercise", 0}}, FontFamily -> "Source Sans Pro", FontSize -> 18, 
          FontSlant -> "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          GridBoxOptions -> {GridBoxAlignment -> {}}], 
         Cell[
          StyleData["ExerciseSection", "Printout"], 
          CellMargins -> {{64, Inherited}, {8, 30}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Exercise"], PageWidth -> 700, CellDingbat -> Cell[
            TextData[{"  ", 
              CounterBox["Section"], ".", 
              CounterBox["Exercise"]}], "ExerciseNumber", FontColor -> 
            RGBColor[
             0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
          ShowGroupOpener -> True, CellMargins -> {{108, Inherited}, {4, 8}}, 
          CellGroupingRules -> {"SectionGrouping", 67}, CounterIncrements -> 
          "Exercise", MenuSortingValue -> 10020, MenuCommandKey -> "2", 
          FontFamily -> "Source Sans Pro", FontSize -> 14, FontWeight -> 
          "Plain", FontSlant -> "Plain", FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["Exercise", "Printout"], ShowGroupOpener -> False, 
          CellMargins -> {{110, Inherited}, {4, 8}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ExerciseNumber"], FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Bold", FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["ExerciseNumber", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ExerciseSubsection"], PageWidth -> 500, 
          CellFrame -> {{False, False}, {1, False}}, 
          CellMargins -> {{64, Inherited}, {8, 18}}, 
          CellGroupingRules -> {"SectionGrouping", 60}, CellFrameColor -> 
          RGBColor[0.65, 0.6, 0.6], FontFamily -> "Source Sans Pro", FontSize -> 
          18, FontSlant -> "Italic", FontColor -> RGBColor[0.65, 0.6, 0.6]], 
         Cell[
          StyleData["ExerciseSubsection", "Printout"], 
          CellFrame -> {{False, False}, {1, False}}, CellFrameColor -> 
          RGBColor[0.65, 0.6, 0.6]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ExerciseNote"], PageWidth -> 700, 
          CellMargins -> {{64, Inherited}, {4, 8}}, PageBreakBelow -> False, 
          MenuSortingValue -> 10050, FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Plain", FontSlant -> "Plain", 
          FontColor -> GrayLevel[0.25], $CellContext`ReturnCreatesNewCell -> 
          True], 
         Cell[
          StyleData["ExerciseNote", "Printout"], 
          CellMargins -> {{64, Inherited}, {4, 8}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["QASection"], PageWidth -> 700, 
          CellFrame -> {{0, 0}, {0, 3}}, 
          CellMargins -> {{64, Inherited}, {8, 30}}, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakBelow -> 
          False, CellFrameMargins -> {{8, 8}, {4, 6}}, CellFrameColor -> 
          RGBColor[0.901961, 0.411765, 0.027451], 
          CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
            "Question", 0}}, FontFamily -> "Source Sans Pro", FontSize -> 18, 
          FontSlant -> "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          GridBoxOptions -> {GridBoxAlignment -> {}}], 
         Cell[
          StyleData["QASection", "Printout"], 
          CellMargins -> {{64, Inherited}, {8, 30}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Question"], PageWidth -> 700, 
          CellMargins -> {{64, Inherited}, {2, 12}}, PageBreakBelow -> False, 
          CounterIncrements -> "Question", MenuSortingValue -> 10030, 
          MenuCommandKey -> "3", FontFamily -> "Source Sans Pro", FontSize -> 
          14, FontWeight -> "Bold", FontSlant -> 
          "Plain", $CellContext`ReturnCreatesNewCell -> 
          True, $CellContext`DefaultReturnCreatedCellStyle -> "Answer"], 
         Cell[
          StyleData["Question", "Printout"], 
          CellMargins -> {{65, Inherited}, {2, 12}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Answer"], PageWidth -> 700, 
          CellMargins -> {{66, 10}, {4, 1}}, LineSpacing -> {1.125, 1., 2.}, 
          MenuSortingValue -> 10032, FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Plain", FontSlant -> "Plain", 
          FontColor -> GrayLevel[0.25], $CellContext`ReturnCreatesNewCell -> 
          True, $CellContext`DefaultReturnCreatedCellStyle -> "Question"], 
         Cell[
          StyleData["Answer", "Printout"], 
          CellMargins -> {{66, 10}, {4, 1}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["QuestionNumber"], FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Bold", FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["QuestionNumber", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["TechNoteSection"], PageWidth -> 700, 
          CellFrame -> {{0, 0}, {0, 3}}, 
          CellMargins -> {{64, Inherited}, {8, 30}}, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakBelow -> 
          False, CellFrameMargins -> {{8, 8}, {4, 6}}, CellFrameColor -> 
          RGBColor[0.901961, 0.411765, 0.027451], FontFamily -> 
          "Source Sans Pro", FontSize -> 18, FontSlant -> "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          GridBoxOptions -> {GridBoxAlignment -> {}}], 
         Cell[
          StyleData["TechNoteSection", "Printout"], 
          CellMargins -> {{64, Inherited}, {8, 30}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["TechNote"], PageWidth -> 700, CellDingbat -> Cell[
            TextData[{"\[FilledSmallSquare]"}], FontSize -> 12, FontColor -> 
            GrayLevel[0.5]], CellMargins -> {{78, Inherited}, {4, 8}}, 
          CellChangeTimes -> {{3.651515120816633*^9, 3.651515125814807*^9}, 
            3.6515155174947033`*^9}, LineSpacing -> {1.25, 1., 2.}, 
          MenuSortingValue -> 10040, FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Plain", FontSlant -> "Plain", 
          FontColor -> GrayLevel[0.25], $CellContext`ReturnCreatesNewCell -> 
          True], 
         Cell[
          StyleData["TechNote", "Printout"], 
          CellMargins -> {{82, Inherited}, {4, 8}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["MoreExploreSection"], PageWidth -> 700, 
          CellFrame -> {{0, 0}, {0, 3}}, 
          CellMargins -> {{64, Inherited}, {8, 30}}, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakBelow -> 
          False, CellFrameMargins -> {{8, 8}, {4, 6}}, CellFrameColor -> 
          RGBColor[0.901961, 0.411765, 0.027451], FontFamily -> 
          "Source Sans Pro", FontSize -> 18, FontSlant -> "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          GridBoxOptions -> {GridBoxAlignment -> {}}], 
         Cell[
          StyleData["MoreExploreSection", "Printout"], 
          CellMargins -> {{64, Inherited}, {8, 30}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["MoreExplore"], PageWidth -> 700, 
          CellMargins -> {{64, Inherited}, {4, 8}}, PageBreakBelow -> False, 
          MenuSortingValue -> 10050, FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Plain", FontSlant -> "Plain", 
          FontColor -> GrayLevel[0], $CellContext`ReturnCreatesNewCell -> 
          True], 
         Cell[
          StyleData["MoreExplore", "Printout"], 
          CellMargins -> {{64, Inherited}, {4, 8}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["MoreExploreShortURL"], 
          CellMargins -> {{64, Inherited}, {4, 8}}, PageBreakBelow -> False, 
          FontFamily -> "Source Sans Pro Light", FontSize -> 14, FontSlant -> 
          "Plain", FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["MoreExploreShortURL", "Printout"], 
          CellMargins -> {{64, Inherited}, {4, 8}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Text"], CellMargins -> {{66, 10}, {4, 14}}, FontFamily -> 
          "Baskerville", FontSize -> 18, FontColor -> 
          GrayLevel[0], $CellContext`ReturnCreatesNewCell -> True], 
         Cell[
          StyleData["Text", "Printout"], CellMargins -> {{66, 10}, {7, 7}}]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ResourcesText"], CellMargins -> {{66, 10}, {2, 0}}, 
          FontFamily -> "Source Sans Pro", FontSize -> 14, FontWeight -> 
          "Plain", FontSlant -> "Plain", FontColor -> 
          GrayLevel[0], $CellContext`ReturnCreatesNewCell -> True], 
         Cell[
          StyleData["ResourcesText", "Printout"], 
          CellMargins -> {{66, 10}, {2, 0}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ResourcesLink"], CellMargins -> {{66, 10}, {2, 0}}, 
          FontFamily -> "Source Sans Pro", FontSize -> 14, FontWeight -> 
          "Plain", FontSlant -> "Italic", FontColor -> 
          GrayLevel[0], $CellContext`ReturnCreatesNewCell -> True], 
         Cell[
          StyleData["ResourcesLink", "Printout"], 
          CellMargins -> {{66, 10}, {2, 0}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["CodeCaption"], CellFrame -> {{0, 0}, {0, 0}}, 
          CellMargins -> {{66, 10}, {4, 12}}, PageBreakBelow -> False, 
          CellFrameColor -> GrayLevel[0.4], MenuSortingValue -> 10010, 
          MenuCommandKey -> "1", FontFamily -> "Source Sans Pro", FontSize -> 
          16, FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["CodeCaption", "Printout"], 
          CellMargins -> {{66, 10}, {4, 12}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Input"], CellMargins -> {{99, 10}, {3, 7}}, SpanMaxSize -> 
          1, FontSize -> 15], 
         Cell[
          StyleData["Input", "Printout"], CellMargins -> {{99, 10}, {3, 7}}]},
         Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Output"], CellMargins -> {{99, 10}, {14, 7}}, FontSize -> 
          15], 
         Cell[
          StyleData["Output", "Printout"], 
          CellMargins -> {{99, 10}, {14, 7}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["InputOnly"], CellMargins -> {{99, 10}, {25, 10}}, 
          SpanMaxSize -> 1, MenuSortingValue -> 1500, FontSize -> 15], 
         Cell[
          StyleData["InputOnly", "Printout"], 
          CellMargins -> {{99, 10}, {15, 10}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["CellLabel"], 
          CellLabelMargins -> {{12, Inherited}, {Inherited, Inherited}}, 
          LanguageCategory -> None, StyleMenuListing -> None, FontFamily -> 
          "Helvetica Neue", FontSize -> 9, FontWeight -> "Plain", FontSlant -> 
          "Plain", FontColor -> GrayLevel[0.5]], 
         Cell[
          StyleData["CellLabel", "Printout"], FontSize -> 8, FontColor -> 
          GrayLevel[0.5]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Message"], Editable -> False, 
          CellMargins -> {{66, Inherited}, {Inherited, Inherited}}, 
          CellGroupingRules -> "OutputGrouping", TextClipboardType -> 
          "PlainText", PageBreakWithin -> False, GroupPageBreakWithin -> 
          False, GeneratedCell -> True, CellAutoOverwrite -> True, 
          ShowCellLabel -> False, DefaultFormatType -> 
          DefaultOutputFormatType, ContextMenu -> 
          FEPrivate`FrontEndResource["ContextMenus", "Output"], 
          ShowAutoStyles -> False, ShowSyntaxStyles -> False, 
          AutoStyleOptions -> {
           "StringStyle" -> None, "SyntaxErrorStyle" -> None}, 
          HyphenationOptions -> {"HyphenationCharacter" -> "\[Continuation]"},
           AutoItalicWords -> {}, AutoQuoteCharacters -> {}, 
          PasteAutoQuoteCharacters -> {}, LanguageCategory -> None, 
          FormatType -> InputForm, ShowStringCharacters -> False, 
          CounterIncrements -> "Message", MenuSortingValue -> 1600, 
          StyleMenuListing -> None, FontFamily :> 
          CurrentValue["PanelFontFamily"], FontSize -> 11, FontColor -> 
          RGBColor[0.5072, 0.16933, 0.15221], $CellContext`StripStyleOnPaste -> 
          True], 
         Cell[
          StyleData["Message", "Printout"], 
          CellMargins -> {{100, Inherited}, {Inherited, Inherited}}, 
          CellFrameLabels -> {{None, None}, {None, None}}, FontColor -> 
          GrayLevel[0]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ExerciseInput", StyleDefinitions -> StyleData["Input"]], 
          CellMargins -> {{88, 10}, {4, 7}}, ShowCellLabel -> False, 
          SpanMaxSize -> 1, FontSize -> 
          14, $CellContext`GeneratedCellStyles -> {
           "Output" -> "ExerciseOutput"}], 
         Cell[
          StyleData["ExerciseInput", "Printout"], 
          CellMargins -> {{88, 10}, {4, 7}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData[
          "ExerciseOutput", StyleDefinitions -> StyleData["Output"]], 
          CellMargins -> {{88, 10}, {10, 4}}, ShowCellLabel -> False, 
          FontSize -> 14], 
         Cell[
          StyleData["ExerciseOutput", "Printout"], 
          CellMargins -> {{88, 10}, {10, 4}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Picture"], CellMargins -> {{66, 10}, {10, 10}}, 
          CellGroupingRules -> "GraphicsGrouping", StyleMenuListing -> None], 
         
         Cell[
          StyleData["Picture", "Printout"], 
          CellMargins -> {{66, 10}, {8, 8}}]}, Closed]], 
      Cell[
       StyleData["ExerciseSummaryCell"], PageWidth -> 700, CellFrame -> 0, 
       CellMargins -> {{64, Inherited}, {8, 10}}, 
       CellGroupingRules -> {"SectionGrouping", 64}, PageBreakBelow -> False, 
       ShowCellLabel -> False, CellFrameMargins -> 0, ShowStringCharacters -> 
       False, FontFamily -> "Source Sans Pro", FontSize -> 18, FontColor -> 
       RGBColor[1, 1, 1], 
       GridBoxOptions -> {GridBoxBackground -> {"Columns" -> {{
              RGBColor[0.990997, 0.539528, 0.155779], 
              RGBColor[0.989487, 0.434699, 0.0320439]}}, "Rows" -> {{None}}}, 
         GridBoxItemSize -> {"Columns" -> {
             Scaled[0.7], 
             Scaled[0.3]}, "Rows" -> {{Automatic}}}}], 
      Cell[
       StyleData["ExerciseSummaryHeading"], ShowStringCharacters -> False, 
       FontFamily -> "Source Sans Pro", FontSize -> 18, FontColor -> 
       RGBColor[1, 1, 1]], 
      Cell[
       StyleData["ExerciseSummarySubheading"], ShowStringCharacters -> False, 
       FontFamily -> "Source Sans Pro", FontSize -> 15, FontColor -> 
       RGBColor[1., 0.9294117647058824, 0.7215686274509804]], 
      Cell[
       StyleData["ExercisePreviewButtonText"], ShowStringCharacters -> False, 
       FontFamily -> "Source Sans Pro", FontSize -> 14, FontSlant -> "Plain", 
       FontColor -> RGBColor[0.6, 0.6, 0.6]], 
      Cell[
       StyleData["ExercisePreviewButtonTextHighlight"], ShowStringCharacters -> 
       False, FontFamily -> "Source Sans Pro", FontSize -> 14, FontSlant -> 
       "Plain", FontColor -> 
       RGBColor[
        0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]]}, 
     Open]], 
   Cell[
    CellGroupData[{
      Cell[
      "Inline and special formatting", "Section", 
       CellChangeTimes -> {{3.646681732592888*^9, 3.646681749414035*^9}}], 
      Cell[
       StyleData["Graphics"], MenuSortingValue -> None], 
      Cell[
       StyleData["Graphics3D"], MenuSortingValue -> None], 
      Cell[
       StyleData["StandardForm"], 
       InputAutoReplacements -> {
        "->" -> "\[Rule]", ":>" -> "\[RuleDelayed]", "<=" -> "\[LessEqual]", 
         ">=" -> "\[GreaterEqual]", "!=" -> "\[NotEqual]", "==" -> "\[Equal]",
          "@>" -> "\\[InlinePart]", "<->" -> "\[UndirectedEdge]", ParentList},
        LineSpacing -> {1.25, 0, 2}, SingleLetterItalics -> False, 
       StyleMenuListing -> None, FontFamily -> "Source Sans Pro", 
       PrivateFontOptions -> {"OperatorSubstitution" -> True}], 
      Cell[
       StyleData["OutputForm"], PageWidth -> DirectedInfinity[1], 
       TextAlignment -> Left, LineSpacing -> {0.6, 1}, 
       AutoQuoteCharacters -> {}, PasteAutoQuoteCharacters -> {}, 
       StyleMenuListing -> None, FontFamily -> "Source Sans Pro", 
       PrivateFontOptions -> {"OperatorSubstitution" -> True}], 
      Cell[
       StyleData["InputForm"], PageWidth -> DirectedInfinity[1], 
       InputAutoReplacements -> {}, AllowInlineCells -> False, Hyphenation -> 
       False, AutoQuoteCharacters -> {}, PasteAutoQuoteCharacters -> {}, 
       AutoSpacing -> False, NumberMarks -> True, AutoNumberFormatting -> 
       False, StyleMenuListing -> None, FontFamily -> "Source Sans Pro", 
       PrivateFontOptions -> {"OperatorSubstitution" -> True}], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["DetailsLink"], FontFamily -> "Source Sans Pro", FontSize :> 
          If[CurrentValue[
              EvaluationCell[], "FontFamily"] === "Source Sans Pro", 
            Inherited, 
            If[CurrentValue[
               EvaluationCell[], "FontFamily"] === "WolframCodeSans", 
             Inherited, Inherited 0.9]], FontColor -> GrayLevel[0], 
          ButtonBoxOptions -> {
           ButtonFunction :> (
             Function[$CellContext`t, 
              NotebookFind[$CellContext`t, "Notes", All, CellStyle]; 
              NotebookFind[$CellContext`t, "NotesSection", All, CellStyle, 
                AutoScroll -> Top]][
              Documentation`HelpLookup[
               StringJoin["ref/", #]]]& ), ButtonSource -> ButtonContents, 
            Evaluator -> Automatic}], 
         Cell[
          StyleData["DetailsLink", "Printout"], FontFamily -> 
          "Source Sans Pro", FontSize :> If[CurrentValue[
              EvaluationCell[], "FontFamily"] === "Source Sans Pro", 
            Inherited, 
            If[CurrentValue[
               EvaluationCell[], "FontFamily"] === "WolframCodeSans", 
             Inherited, Inherited 0.88]], FontColor -> GrayLevel[0]]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["LinkAlt"], FontFamily -> "Source Sans Pro", FontSize :> 
          If[CurrentValue[
              EvaluationCell[], "FontFamily"] === "Source Sans Pro", 
            Inherited, 
            If[CurrentValue[
               EvaluationCell[], "FontFamily"] === "WolframCodeSans", 
             Inherited, Inherited 0.9]], FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["LinkAlt", "Printout"], FontFamily -> "Source Sans Pro", 
          FontSize :> If[CurrentValue[
              EvaluationCell[], "FontFamily"] === "Source Sans Pro", 
            Inherited, 
            If[CurrentValue[
               EvaluationCell[], "FontFamily"] === "WolframCodeSans", 
             Inherited, Inherited 0.88]], FontColor -> GrayLevel[0]]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Hyperlink"], MenuSortingValue -> None, FontColor -> 
          RGBColor[0.3, 0.35, 0.5]], 
         Cell[
          StyleData["Hyperlink", "Printout"]]}, Closed]], 
      Cell[
       StyleData[
       "IndexNavigationLink", StyleDefinitions -> StyleData["Hyperlink"]], 
       MenuSortingValue -> None, FontColor -> 
       RGBColor[
        0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
      Cell[
       StyleData["Crosslink"], 
       ButtonBoxOptions -> {ButtonFunction :> (FrontEndExecute[{
            
            NotebookLocate[#2, "OpenInNewWindow" -> 
             CurrentValue["HyperlinkModifierKey"]]}]& ), Evaluator -> None, 
         Method -> "Queued"}], 
      Cell[
       StyleData["VocabularyLink"], FontColor -> GrayLevel[0], 
       ButtonBoxOptions -> {ButtonFunction :> (FrontEndExecute[{
            
            NotebookLocate[#2, "OpenInNewWindow" -> 
             CurrentValue["HyperlinkModifierKey"]]}]& ), Evaluator -> None, 
         Method -> "Queued"}], 
      Cell[
       StyleData["InlineCode"], SpanMaxSize -> 1, FontColor -> GrayLevel[0]], 
      
      Cell[
       StyleData["InlineCodeText"], SpanMaxSize -> 1, FontFamily -> 
       "Source Sans Pro", FontSize -> 0.95 Inherited], 
      Cell[
       StyleData["NoLabel"], ShowCellLabel -> 
       False, $CellContext`GeneratedCellStyles -> {
        "Output" -> "ExerciseOutput"}], 
      Cell[
       StyleData["MenuName"], FontFamily -> "Verdana", FontWeight -> "Bold", 
       FontColor -> GrayLevel[0.286275]], 
      Cell[
       StyleData["KeyEvent"], CellFrame -> {{0.5, 0.5}, {0.5, 0.5}}, 
       CellFrameMargins -> {{2, 2}, {2, 2}}, CellFrameColor -> GrayLevel[0.7],
        FontFamily -> "Verdana", FontColor -> GrayLevel[0.4]], 
      Cell[
       StyleData["KeyEventDelimiter"], FontColor -> GrayLevel[0.5]], 
      Cell[
       CellGroupData[{
         Cell["Key Styles", "Subsubsection"], 
         Cell[
          StyleData["Key0"], 
          TemplateBoxOptions -> {DisplayFunction -> (FrameBox[
              TagBox[
               GridBox[{{
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> GrayLevel[1], StripOnInput -> 
                   False]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Center}}, "Rows" -> {{Baseline}}}, AutoDelete -> 
                False, GridBoxDividers -> {"Rows" -> {{None}}}, 
                GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{1.45}}},
                 GridBoxSpacings -> {"Columns" -> {{0}}}, 
                BaselinePosition -> {{1, 1}, Baseline}], "Grid"], 
              RoundingRadius -> 4, Background -> 
              GrayLevel[0.9333333333333333], 
              FrameMargins -> {{0, 0}, {-2, -2}}, FrameStyle -> {
                GrayLevel[0.8352941176470589], 
                AbsoluteThickness[1]}, BaselinePosition -> Baseline, 
              StripOnInput -> False]& )}], 
         Cell[
          StyleData["Key1"], 
          TemplateBoxOptions -> {DisplayFunction -> (FrameBox[
              TagBox[
               GridBox[{{
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> 
                   GrayLevel[0.9333333333333333], StripOnInput -> False], 
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #2, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> GrayLevel[1], StripOnInput -> 
                   False]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Center}}, "Rows" -> {{Baseline}}}, AutoDelete -> 
                False, GridBoxDividers -> {
                 "ColumnsIndexed" -> {2 -> GrayLevel[0.8352941176470589]}, 
                  "Rows" -> {{None}}}, 
                GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{1.45}}},
                 GridBoxSpacings -> {"Columns" -> {{0}}}, 
                BaselinePosition -> {{1, 1}, Baseline}], "Grid"], 
              RoundingRadius -> 4, Background -> 
              GrayLevel[0.9333333333333333], 
              FrameMargins -> {{0, 0}, {-2, -2}}, FrameStyle -> {
                GrayLevel[0.8352941176470589], 
                AbsoluteThickness[1]}, BaselinePosition -> Baseline, 
              StripOnInput -> False]& )}], 
         Cell[
          StyleData["Key2"], 
          TemplateBoxOptions -> {DisplayFunction -> (FrameBox[
              TagBox[
               GridBox[{{
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> 
                   GrayLevel[0.9333333333333333], StripOnInput -> False], 
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #2, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> 
                   GrayLevel[0.9333333333333333], StripOnInput -> False], 
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #3, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> GrayLevel[1], StripOnInput -> 
                   False]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Center}}, "Rows" -> {{Baseline}}}, AutoDelete -> 
                False, GridBoxDividers -> {
                 "ColumnsIndexed" -> {
                   2 -> GrayLevel[0.8352941176470589], 3 -> 
                    GrayLevel[0.8352941176470589]}, "Rows" -> {{None}}}, 
                GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{1.45}}},
                 GridBoxSpacings -> {"Columns" -> {{0}}}, 
                BaselinePosition -> {{1, 1}, Baseline}], "Grid"], 
              RoundingRadius -> 4, Background -> 
              GrayLevel[0.9333333333333333], 
              FrameMargins -> {{0, 0}, {-2, -2}}, FrameStyle -> {
                GrayLevel[0.8352941176470589], 
                AbsoluteThickness[1]}, BaselinePosition -> Baseline, 
              StripOnInput -> False]& )}], 
         Cell[
          StyleData["Key3"], 
          TemplateBoxOptions -> {DisplayFunction -> (FrameBox[
              TagBox[
               GridBox[{{
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> 
                   GrayLevel[0.9333333333333333], StripOnInput -> False], 
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #2, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> 
                   GrayLevel[0.9333333333333333], StripOnInput -> False], 
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #3, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> 
                   GrayLevel[0.9333333333333333], StripOnInput -> False], 
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #4, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> GrayLevel[1], StripOnInput -> 
                   False]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Center}}, "Rows" -> {{Baseline}}}, AutoDelete -> 
                False, GridBoxDividers -> {
                 "ColumnsIndexed" -> {
                   2 -> GrayLevel[0.8352941176470589], 3 -> 
                    GrayLevel[0.8352941176470589], 4 -> 
                    GrayLevel[0.8352941176470589]}, "Rows" -> {{None}}}, 
                GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{1.45}}},
                 GridBoxSpacings -> {"Columns" -> {{0}}}, 
                BaselinePosition -> {{1, 1}, Baseline}], "Grid"], 
              RoundingRadius -> 4, Background -> 
              GrayLevel[0.9333333333333333], 
              FrameMargins -> {{0, 0}, {-2, -2}}, FrameStyle -> {
                GrayLevel[0.8352941176470589], 
                AbsoluteThickness[1]}, BaselinePosition -> Baseline, 
              StripOnInput -> False]& )}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Entity styles", "Subsubsection"], 
         Cell[
          StyleData["Entity"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
              FrameBox[
               PaneSelectorBox[{True -> GridBox[{{
                    
                    StyleBox[#, FontWeight -> "Bold", FontFamily -> 
                    "Source Sans Pro", FontColor -> 
                    RGBColor[0.395437, 0.20595, 0.061158]], 
                    StyleBox[
                    RowBox[{"(", #4, ")"}], FontFamily -> "Source Sans Pro", 
                    FontWeight -> "Plain", FontColor -> GrayLevel[0.65], 
                    Selectable -> False]}}, 
                   GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                   GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}},
                    BaselinePosition -> {1, 1}], False -> 
                 PaneBox[#, 
                   BaseStyle -> {
                    FontColor -> RGBColor[0.395437, 0.20595, 0.061158]}, 
                   BaselinePosition -> Baseline]}, 
                Dynamic[
                 CurrentValue[Evaluatable]], ImageSize -> Automatic, 
                BaselinePosition -> Baseline, 
                BaseStyle -> {FontFamily -> "Helvetica"}], FrameStyle -> 
               RGBColor[1., 0.504768, 0.], Background -> 
               RGBColor[1., 0.980392, 0.921569], 
               FrameMargins -> {{5, 5}, {1.5, 1.5}}, 
               ImageMargins -> {{2, 2}, {2, 2}}, BaselinePosition -> Baseline,
                RoundingRadius -> 4], #3, 
              BaseStyle -> {
               FontWeight -> "Plain", ShowStringCharacters -> False, 
                LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityFrameless"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
              PaneSelectorBox[{True -> GridBox[{{
                    
                    StyleBox[#, FontWeight -> "Bold", FontFamily -> 
                    "Source Sans Pro", FontColor -> 
                    RGBColor[0.395437, 0.20595, 0.061158]], 
                    StyleBox[
                    RowBox[{"(", #4, ")"}], FontFamily -> "Source Sans Pro", 
                    FontWeight -> "Plain", FontColor -> GrayLevel[0.65], 
                    Selectable -> False]}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                  BaselinePosition -> {1, 1}], False -> 
                PaneBox[#, 
                  BaseStyle -> {
                   FontColor -> RGBColor[0.395437, 0.20595, 0.061158]}, 
                  BaselinePosition -> Baseline]}, 
               Dynamic[
                CurrentValue[Evaluatable]], ImageSize -> Automatic, 
               BaselinePosition -> Baseline, 
               BaseStyle -> {FontFamily -> "Helvetica"}], #3, 
              BaseStyle -> {
               ShowStringCharacters -> False, LineIndent -> 0, 
                PrivateFontOptions -> {
                 FontWeight -> "Plain", "OperatorSubstitution" -> False}}]& ),
             Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityFramelessHot"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {
           DisplayFunction -> (PaneSelectorBox[{True -> GridBox[{{
                   
                   StyleBox[#, FontWeight -> "Bold", FontFamily -> 
                    "Source Sans Pro", FontColor -> GrayLevel[0]], 
                   StyleBox[
                    RowBox[{"(", #4, ")"}], FontWeight -> "Plain", FontFamily -> 
                    "Source Sans Pro", FontColor -> GrayLevel[0], Selectable -> 
                    False]}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                 BaselinePosition -> {1, 1}], False -> 
               PaneBox[#, BaseStyle -> {FontColor -> GrayLevel[0]}, 
                 BaselinePosition -> Baseline]}, 
              Dynamic[
               CurrentValue[Evaluatable]], ImageSize -> Automatic, 
              BaselinePosition -> Baseline, 
              BaseStyle -> {
               FontWeight -> "Plain", FontFamily -> "Helvetica", 
                ShowStringCharacters -> False, LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityClass"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
              FrameBox[
               PaneSelectorBox[{True -> GridBox[{{
                    PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], 
                    
                    StyleBox[#, FontWeight -> "Bold", FontFamily -> 
                    "Source Sans Pro", FontColor -> 
                    RGBColor[0.395437, 0.20595, 0.061158]], 
                    StyleBox[
                    RowBox[{"(", #4, ")"}], FontWeight -> "Plain", FontFamily -> 
                    "Source Sans Pro", FontColor -> GrayLevel[0.65], 
                    Selectable -> False]}}, 
                   GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                   GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}},
                    BaselinePosition -> {1, 2}], False -> GridBox[{{
                    PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], 
                    
                    StyleBox[#, FontColor -> 
                    RGBColor[0.395437, 0.20595, 0.061158]]}}, 
                   GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                   GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}},
                    BaselinePosition -> {1, 2}]}, 
                Dynamic[
                 CurrentValue[Evaluatable]], ImageSize -> Automatic, 
                BaselinePosition -> Baseline, 
                BaseStyle -> {FontFamily -> "Helvetica"}], FrameStyle -> 
               RGBColor[1., 0.504768, 0.], Background -> 
               RGBColor[1., 0.980392, 0.921569], 
               FrameMargins -> {{5, 5}, {1.5, 1.5}}, 
               ImageMargins -> {{2, 2}, {2, 2}}, BaselinePosition -> Baseline,
                RoundingRadius -> 4], #3, 
              BaseStyle -> {
               FontWeight -> "Plain", ShowStringCharacters -> False, 
                LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityClassFrameless"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
              PaneSelectorBox[{True -> GridBox[{{
                    PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], 
                    
                    StyleBox[#, FontWeight -> "Bold", FontFamily -> 
                    "Source Sans Pro", FontColor -> 
                    RGBColor[0.395437, 0.20595, 0.061158]], 
                    StyleBox[
                    RowBox[{"(", #4, ")"}], FontWeight -> "Plain", FontFamily -> 
                    "Source Sans Pro", FontColor -> GrayLevel[0.65], 
                    Selectable -> False]}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                  BaselinePosition -> {1, 2}], False -> GridBox[{{
                    PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], 
                    
                    StyleBox[#, FontColor -> 
                    RGBColor[0.395437, 0.20595, 0.061158]]}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                  BaselinePosition -> {1, 2}]}, 
               Dynamic[
                CurrentValue[Evaluatable]], ImageSize -> Automatic, 
               BaselinePosition -> Baseline, 
               BaseStyle -> {FontFamily -> "Helvetica"}], #3, 
              BaseStyle -> {
               FontWeight -> "Plain", ShowStringCharacters -> False, 
                LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityClassFramelessHot"], ShowStringCharacters -> False,
           TemplateBoxOptions -> {
           DisplayFunction -> (PaneSelectorBox[{True -> GridBox[{{
                   PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], 
                   
                   StyleBox[#, FontWeight -> "Bold", FontFamily -> 
                    "Source Sans Pro", FontColor -> GrayLevel[0]], 
                   StyleBox[
                    RowBox[{"(", #4, ")"}], FontWeight -> "Plain", FontFamily -> 
                    "Source Sans Pro", FontColor -> GrayLevel[0], Selectable -> 
                    False]}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                 BaselinePosition -> {1, 2}], False -> GridBox[{{
                   PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], 
                   StyleBox[#, FontColor -> GrayLevel[0]]}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                 BaselinePosition -> {1, 2}]}, 
              Dynamic[
               CurrentValue[Evaluatable]], ImageSize -> Automatic, 
              BaselinePosition -> Baseline, 
              BaseStyle -> {
               FontWeight -> "Plain", FontFamily -> "Helvetica", 
                ShowStringCharacters -> False, LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityProperty"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
              FrameBox[
               
               PaneBox[#, 
                BaseStyle -> {
                 FontSlant -> Italic, FontWeight -> Plain, FontFamily -> 
                  "Source Sans Pro", FontColor -> 
                  RGBColor[0.395437, 0.20595, 0.061158]}, BaselinePosition -> 
                Baseline], FrameStyle -> 
               RGBColor[0.94227, 0.703639, 0.033387], Background -> 
               RGBColor[1., 0.980392, 0.921569], 
               FrameMargins -> {{5, 5}, {1.5, 1.5}}, 
               ImageMargins -> {{2, 2}, {2, 2}}, BaselinePosition -> Baseline,
                RoundingRadius -> 4], #3, 
              BaseStyle -> {
               FontWeight -> "Plain", ShowStringCharacters -> False, 
                LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityPropertyClass"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
              FrameBox[
               PaneBox[
                GridBox[{{
                   PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], #}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                 BaselinePosition -> {1, 2}], 
                BaseStyle -> {
                 FontSlant -> Italic, FontWeight -> Plain, FontFamily -> 
                  "Source Sans Pro", FontColor -> 
                  RGBColor[0.395437, 0.20595, 0.061158]}, BaselinePosition -> 
                Baseline], FrameStyle -> 
               RGBColor[0.94227, 0.703639, 0.033387], Background -> 
               RGBColor[1., 0.980392, 0.921569], 
               FrameMargins -> {{5, 5}, {1.5, 1.5}}, 
               ImageMargins -> {{2, 2}, {2, 2}}, BaselinePosition -> Baseline,
                RoundingRadius -> 4], #3, 
              BaseStyle -> {
               FontWeight -> "Plain", ShowStringCharacters -> False, 
                LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityValue"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (FrameBox[
              
              GridBox[{{#, #2}}, GridBoxAlignment -> {"Rows" -> {{Baseline}}},
                GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}}, 
               GridBoxSpacings -> {"Columns" -> {{0}}}, 
               BaselinePosition -> {1, 1}], Background -> 
              RGBColor[{0.9921568627450981, 0.9529411764705882, 
                0.8509803921568627}], BaselinePosition -> Baseline, 
              FrameMargins -> {{1, 1}, {1, 1}}, ImageMargins -> 2, FrameStyle -> 
              RGBColor[{0.9333333333333333, 0.8470588235294118, 
                0.5529411764705883}], RoundingRadius -> 5]& )}]}, Closed]]}, 
     Closed]]}, Visible -> False, FrontEndVersion -> 
  "11.1 for Mac OS X x86 (32-bit, 64-bit Kernel) (April 18, 2017)", 
  StyleDefinitions -> "StylesheetFormatting.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "p:123"->{
  Cell[661, 24, 442, 11, 
  70, "SectionDoubleDigit", "ExpressionUUID" -> "05fd2f4f-5bfb-4f04-979d-
   a3ff8480e23b",
   CounterAssignments->{{"Section", 21}, {"Subsection", 0}, {
     "Subsubsection", 0}, {"Exercise", 0}},
   CellTags->"p:123"]},
 "i:1"->{
  Cell[1106, 37, 512, 12, 
  70, "Text", "ExpressionUUID" -> "52a3adbb-d1d8-451a-833c-b151ac46c68b",
   CellTags->"i:1"]},
 "i:2"->{
  Cell[1966, 61, 315, 10, 
  70, "Text", "ExpressionUUID" -> "06bba364-0c4c-4db1-aefd-ffd8cc702fa9",
   CellTags->"i:2"]},
 "i:3"->{
  Cell[2284, 73, 198, 4, 
  70, "CodeCaption", "ExpressionUUID" -> "0629a67c-2659-4616-af1a-583ee0cc67d4
   ",
   CellTags->"i:3"]},
 "i:4"->{
  Cell[4150, 121, 339, 8, 
  70, "Text", "ExpressionUUID" -> "4fb0b2cd-fe3b-4c21-b0d4-3b3356290189",
   CellTags->"i:4"]},
 "i:5"->{
  Cell[4492, 131, 187, 4, 
  70, "CodeCaption", "ExpressionUUID" -> "da59d4ed-3832-44ec-8225-4be5ac31156e
   ",
   CellTags->"i:5"]},
 "i:6"->{
  Cell[262510, 4381, 425, 12, 
  70, "Text", "ExpressionUUID" -> "64556c5a-367f-4a20-b2c9-495c1011cbbd",
   CellTags->"i:6"]},
 "i:7"->{
  Cell[262938, 4395, 213, 4, 
  70, "CodeCaption", "ExpressionUUID" -> "5264f021-7031-4f18-99af-269cd70f8453
   ",
   CellTags->"i:7"]},
 "LastCellOfAPage"->{
  Cell[264083, 4434, 217, 5, 
  70, "Output", "ExpressionUUID" -> "f5c551bb-c180-43f0-ac95-e6da62a064e8",
   Evaluatable->False,
   CellTags->"LastCellOfAPage"],
  Cell[325787, 5940, 427, 14, 
  70, "Text", "ExpressionUUID" -> "5f4570cd-f219-4dab-8e0a-c292afbd8d35",
   CellTags->{"LastCellOfAPage", "i:13"}],
  Cell[608159, 10719, 2504679, 41124, 
  70, "Output", "ExpressionUUID" -> "cb12d83c-76a2-4a5c-b8f0-a326db2fa761",
   Evaluatable->False,
   CellTags->"LastCellOfAPage"],
  Cell[3841171, 64679, 434, 11, 
  70, "Text", "ExpressionUUID" -> "7aa2628a-dec4-4229-bdd3-de7c07c2ea36",
   CellTags->{"NearestNeighborGraph", "LastCellOfAPage"}],
  Cell[4041204, 69721, 596, 15, 
  70, "Text", "ExpressionUUID" -> "adff9c50-1544-4e0b-8348-664d3ad0b2c8",
   CellTags->{"LastCellOfAPage", "i:23"}],
  Cell[4418292, 79840, 18451, 349, 
  70, "Output", "ExpressionUUID" -> "e7b53d17-22a8-41a1-a364-cf618517cc6b",
   Evaluatable->False,
   CellTags->"LastCellOfAPage"],
  Cell[4579689, 82965, 117073, 2170, 
  70, "Output", "ExpressionUUID" -> "b943b35d-bd3c-4cc6-b824-2af21a10d7b0",
   Evaluatable->False,
   CellTags->"LastCellOfAPage"],
  Cell[8735328, 155414, 764, 21, 
  70, "Exercise", "ExpressionUUID" -> "738c2071-5e8b-4de8-a233-3bd0ba9cea5a",
   CellTags->"LastCellOfAPage"],
  Cell[9510815, 172048, 544, 18, 
  70, "TechNote", "ExpressionUUID" -> "9fc5ce4f-dcf6-474c-b44f-6f489bcf6f33",
   CellTags->{"LastCellOfAPage", "i:36"}],
  Cell[9516063, 172238, 346, 8, 
  70, "MoreExplore", "ExpressionUUID" -> "5c7969a5-4286-49bd-91be-e54f0f45e870
   ",
   CellTags->"LastCellOfAPage"]},
 "p:124"->{
  Cell[264315, 4442, 568, 16, 
  70, "Text", "ExpressionUUID" -> "f273b17e-d96c-4ee7-ac8e-4b9925d7c7c8",
   CellTags->{"p:124", "i:8"}]},
 "i:8"->{
  Cell[264315, 4442, 568, 16, 
  70, "Text", "ExpressionUUID" -> "f273b17e-d96c-4ee7-ac8e-4b9925d7c7c8",
   CellTags->{"p:124", "i:8"}]},
 "i:9"->{
  Cell[289185, 4927, 451, 12, 
  70, "Text", "ExpressionUUID" -> "d24f88cd-2dda-463f-a5e5-b5478525e3e5",
   CellTags->"i:9"]},
 "i:10"->{
  Cell[291141, 4994, 244, 8, 
  70, "Text", "ExpressionUUID" -> "e6019b5f-f7df-4c82-be2a-83183974b3c1",
   CellTags->"i:10"]},
 "i:11"->{
  Cell[324644, 5905, 175, 4, 
  70, "Text", "ExpressionUUID" -> "de178ca6-fe13-4505-aeec-c3274b10a730",
   CellTags->"i:11"]},
 "i:12"->{
  Cell[324822, 5911, 263, 5, 
  70, "CodeCaption", "ExpressionUUID" -> "a6804c3a-3f69-4365-8e31-c6d0ad1209bf
   ",
   CellTags->"i:12"]},
 "i:13"->{
  Cell[325787, 5940, 427, 14, 
  70, "Text", "ExpressionUUID" -> "5f4570cd-f219-4dab-8e0a-c292afbd8d35",
   CellTags->{"LastCellOfAPage", "i:13"}]},
 "p:125"->{
  Cell[326217, 5956, 410, 11, 
  70, "Text", "ExpressionUUID" -> "f8cdde60-2827-4b95-bea5-ce8d66806581",
   CellTags->{"p:125", "i:14"}]},
 "i:14"->{
  Cell[326217, 5956, 410, 11, 
  70, "Text", "ExpressionUUID" -> "f8cdde60-2827-4b95-bea5-ce8d66806581",
   CellTags->{"p:125", "i:14"}]},
 "i:15"->{
  Cell[326630, 5969, 256, 5, 
  70, "CodeCaption", "ExpressionUUID" -> "4147d05f-fc3b-4923-9e86-648743da6e32
   ",
   CellTags->"i:15"]},
 "i:16"->{
  Cell[332481, 6084, 281, 10, 
  70, "Text", "ExpressionUUID" -> "e449994e-0a3b-4897-989b-bae9f0288e34",
   CellTags->"i:16"]},
 "i:17"->{
  Cell[348627, 6422, 303, 9, 
  70, "CodeCaption", "ExpressionUUID" -> "0d8cf8ca-6514-4324-9506-a4501cf7fbc6
   ",
   CellTags->"i:17"]},
 "i:18"->{
  Cell[3606713, 60008, 313, 9, 
  70, "CodeCaption", "ExpressionUUID" -> "23487128-efe2-47d3-8c8e-053664cdda7b
   ",
   CellTags->"i:18"]},
 "i:19"->{
  Cell[3758745, 62533, 389, 11, 
  70, "Text", "ExpressionUUID" -> "89b69608-9e5d-4b61-8e89-823422a4bdcd",
   CellTags->"i:19"]},
 "NearestNeighborGraph"->{
  Cell[3841171, 64679, 434, 11, 
  70, "Text", "ExpressionUUID" -> "7aa2628a-dec4-4229-bdd3-de7c07c2ea36",
   CellTags->{"NearestNeighborGraph", "LastCellOfAPage"}]},
 "graph-with-disconnected-parts"->{
  Cell[3841608, 64692, 321, 9, 
  70, "CodeCaption", "ExpressionUUID" -> "0402896f-5498-4406-a05a-985edbd3dde7
   ",
   CellTags->{"graph-with-disconnected-parts", "i:20"}]},
 "i:20"->{
  Cell[3841608, 64692, 321, 9, 
  70, "CodeCaption", "ExpressionUUID" -> "0402896f-5498-4406-a05a-985edbd3dde7
   ",
   CellTags->{"graph-with-disconnected-parts", "i:20"}]},
 "i:21"->{
  Cell[3947241, 67254, 319, 10, 
  70, "Text", "ExpressionUUID" -> "69f952ba-ad63-45ed-b1e9-864c9ea820af",
   CellTags->"i:21"]},
 "i:22"->{
  Cell[4040616, 69707, 585, 12, 
  70, "Text", "ExpressionUUID" -> "0bf4abb5-532d-4c48-b315-4d06c384a934",
   CellTags->"i:22"]},
 "i:23"->{
  Cell[4041204, 69721, 596, 15, 
  70, "Text", "ExpressionUUID" -> "adff9c50-1544-4e0b-8348-664d3ad0b2c8",
   CellTags->{"LastCellOfAPage", "i:23"}]},
 "i:24"->{
  Cell[4041803, 69738, 561, 14, 
  70, "Text", "ExpressionUUID" -> "b9896f6e-2e77-427c-9179-6df9e86ca0b0",
   CellTags->"i:24"]},
 "i:25"->{
  Cell[4144387, 72490, 342, 9, 
  70, "Text", "ExpressionUUID" -> "e4ac5c47-a82e-46d0-a36c-bad0dbf6184c",
   CellTags->"i:25"]},
 "i:26"->{
  Cell[4436758, 80192, 393, 10, 
  70, "Text", "ExpressionUUID" -> "4a2b7a34-3920-47aa-bf87-f2322dd962af",
   CellTags->"i:26"]},
 "i:27"->{
  Cell[4474468, 81141, 368, 10, 
  70, "Text", "ExpressionUUID" -> "0e762fda-aafc-49c3-8d9a-e9308eae53f9",
   CellTags->"i:27"]},
 "p:126"->{
  Cell[4696811, 85141, 176, 4, 
  70, "VocabularySection", "ExpressionUUID" -> "131c42fc-a098-4b2c-ac1c-
   fceab7d2cc6e",
   CellTags->"p:126"]},
 "p:127"->{
  Cell[9502346, 171757, 161, 4, 
  70, "QASection", "ExpressionUUID" -> "3cc8e1d4-33e3-4369-aebd-61cc169c2bee",
   
   CellTags->"p:127"]},
 "i:28"->{
  Cell[9503276, 171786, 248, 9, 
  70, "Question", "ExpressionUUID" -> "6b340d24-60d4-4df9-ba66-91e22a2379e6",
   CellTags->"i:28"]},
 "i:29"->{
  Cell[9504366, 171822, 327, 8, 
  70, "Answer", "ExpressionUUID" -> "d3365875-81d4-4cc7-9013-7e34489410af",
   CellTags->"i:29"]},
 "i:30"->{
  Cell[9505874, 171871, 554, 16, 
  70, "Answer", "ExpressionUUID" -> "550d330d-248f-43d3-888c-ec339c5f25f2",
   CellTags->"i:30"]},
 "i:31"->{
  Cell[9507287, 171921, 300, 10, 
  70, "Answer", "ExpressionUUID" -> "b66aeffe-eb0e-4102-b5f0-e8880f22ec2e",
   CellTags->"i:31"]},
 "i:32"->{
  Cell[9507830, 171944, 360, 10, 
  70, "Answer", "ExpressionUUID" -> "b79db81e-8729-4681-a066-a5b646edcba9",
   CellTags->"i:32"]},
 "i:33"->{
  Cell[9508193, 171956, 207, 4, 
  70, "Question", "ExpressionUUID" -> "42d77bdb-d92f-4898-b644-d935f3f38196",
   CellTags->"i:33"]},
 "i:34"->{
  Cell[9510027, 172017, 348, 13, 
  70, "TechNote", "ExpressionUUID" -> "73c56276-55c6-4a65-8f1f-1b78204a8750",
   CellTags->"i:34"]},
 "i:35"->{
  Cell[9510378, 172032, 434, 14, 
  70, "TechNote", "ExpressionUUID" -> "eb8e4138-3ea9-4899-abb0-1ba32f00f291",
   CellTags->"i:35"]},
 "i:36"->{
  Cell[9510815, 172048, 544, 18, 
  70, "TechNote", "ExpressionUUID" -> "9fc5ce4f-dcf6-474c-b44f-6f489bcf6f33",
   CellTags->{"LastCellOfAPage", "i:36"}]},
 "i:37"->{
  Cell[9511362, 172068, 433, 12, 
  70, "TechNote", "ExpressionUUID" -> "ef7ef911-d05f-400b-976a-66aa0b15482a",
   CellTags->"i:37"]},
 "i:38"->{
  Cell[9511798, 172082, 581, 23, 
  70, "TechNote", "ExpressionUUID" -> "e3fa5da4-8345-4c4a-927b-04fcb7c6381b",
   CellTags->"i:38"]},
 "i:39"->{
  Cell[9512382, 172107, 546, 18, 
  70, "TechNote", "ExpressionUUID" -> "d6d16db5-34bb-4da5-86d6-3cd96f62dee5",
   CellTags->"i:39"]},
 "i:40"->{
  Cell[9512931, 172127, 400, 12, 
  70, "TechNote", "ExpressionUUID" -> "7c857f2b-faac-4fac-8e04-8de3cd40cf7c",
   CellTags->"i:40"]},
 "i:41"->{
  Cell[9513334, 172141, 487, 13, 
  70, "TechNote", "ExpressionUUID" -> "3c7dc8bf-5ce3-4292-9920-7c2776cb7105",
   CellTags->"i:41"]},
 "i:42"->{
  Cell[9514552, 172180, 330, 11, 
  70, "TechNote", "ExpressionUUID" -> "6d05fccc-7ee0-42c4-926e-547d449189bd",
   CellTags->"i:42"]},
 "i:43"->{
  Cell[9514885, 172193, 467, 13, 
  70, "TechNote", "ExpressionUUID" -> "f02996cd-a39b-49f9-b5d5-bcfe9ad1be0c",
   CellTags->"i:43"]},
 "i:44"->{
  Cell[9515355, 172208, 503, 19, 
  70, "TechNote", "ExpressionUUID" -> "7551e191-b9ae-4518-8c3a-38abbb03b21c",
   CellTags->"i:44"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"p:123", 9607023, 174085},
 {"i:1", 9607281, 174092},
 {"i:2", 9607414, 174096},
 {"i:3", 9607547, 174100},
 {"i:4", 9607690, 174105},
 {"i:5", 9607823, 174109},
 {"i:6", 9607967, 174114},
 {"i:7", 9608104, 174118},
 {"LastCellOfAPage", 9608263, 174123},
 {"p:124", 9609862, 174159},
 {"i:8", 9610010, 174163},
 {"i:9", 9610158, 174167},
 {"i:10", 9610296, 174171},
 {"i:11", 9610434, 174175},
 {"i:12", 9610572, 174179},
 {"i:13", 9610721, 174184},
 {"p:125", 9610882, 174188},
 {"i:14", 9611032, 174192},
 {"i:15", 9611182, 174196},
 {"i:16", 9611331, 174201},
 {"i:17", 9611470, 174205},
 {"i:18", 9611619, 174210},
 {"i:19", 9611770, 174215},
 {"NearestNeighborGraph", 9611927, 174219},
 {"graph-with-disconnected-parts", 9612130, 174223},
 {"i:20", 9612316, 174228},
 {"i:21", 9612502, 174233},
 {"i:22", 9612643, 174237},
 {"i:23", 9612784, 174241},
 {"i:24", 9612946, 174245},
 {"i:25", 9613087, 174249},
 {"i:26", 9613227, 174253},
 {"i:27", 9613368, 174257},
 {"p:126", 9613510, 174261},
 {"p:127", 9613669, 174266},
 {"i:28", 9613820, 174271},
 {"i:29", 9613965, 174275},
 {"i:30", 9614108, 174279},
 {"i:31", 9614252, 174283},
 {"i:32", 9614396, 174287},
 {"i:33", 9614540, 174291},
 {"i:34", 9614685, 174295},
 {"i:35", 9614831, 174299},
 {"i:36", 9614977, 174303},
 {"i:37", 9615144, 174307},
 {"i:38", 9615290, 174311},
 {"i:39", 9615436, 174315},
 {"i:40", 9615582, 174319},
 {"i:41", 9615728, 174323},
 {"i:42", 9615874, 174327},
 {"i:43", 9616020, 174331},
 {"i:44", 9616166, 174335}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[661, 24, 442, 11, 70, "SectionDoubleDigit", "ExpressionUUID" -> \
"05fd2f4f-5bfb-4f04-979d-a3ff8480e23b",
 CounterAssignments->{{"Section", 21}, {"Subsection", 0}, {
   "Subsubsection", 0}, {"Exercise", 0}},
 CellTags->"p:123"],
Cell[1106, 37, 512, 12, 70, "Text", "ExpressionUUID" -> \
"52a3adbb-d1d8-451a-833c-b151ac46c68b",
 CellTags->"i:1"],
Cell[1621, 51, 342, 8, 70, "Text", "ExpressionUUID" -> \
"0a7295eb-4df9-473b-956a-dfaa59849cf0"],
Cell[1966, 61, 315, 10, 70, "Text", "ExpressionUUID" -> \
"06bba364-0c4c-4db1-aefd-ffd8cc702fa9",
 CellTags->"i:2"],
Cell[2284, 73, 198, 4, 70, "CodeCaption", "ExpressionUUID" -> \
"0629a67c-2659-4616-af1a-583ee0cc67d4",
 CellTags->"i:3"],
Cell[CellGroupData[{
Cell[2507, 81, 406, 9, 70, "Input", "ExpressionUUID" -> \
"4d9e6a71-aafd-4d93-b26f-83defc43a5aa"],
Cell[2916, 92, 1219, 26, 70, "Output", "ExpressionUUID" -> \
"28a5480e-df5f-421b-83b9-ae6d494b736f",
 Evaluatable->False]
}, Open  ]],
Cell[4150, 121, 339, 8, 70, "Text", "ExpressionUUID" -> \
"4fb0b2cd-fe3b-4c21-b0d4-3b3356290189",
 CellTags->"i:4"],
Cell[4492, 131, 187, 4, 70, "CodeCaption", "ExpressionUUID" -> \
"da59d4ed-3832-44ec-8225-4be5ac31156e",
 CellTags->"i:5"],
Cell[CellGroupData[{
Cell[4704, 139, 257398, 4228, 70, "Input", "ExpressionUUID" -> \
"ea56458a-8bbf-4fe9-a587-89886a67aeaa"],
Cell[262105, 4369, 390, 9, 70, "Output", "ExpressionUUID" -> \
"9381a61d-18c7-4bd1-8a73-3b495db30069",
 Evaluatable->False]
}, Open  ]],
Cell[262510, 4381, 425, 12, 70, "Text", "ExpressionUUID" -> \
"64556c5a-367f-4a20-b2c9-495c1011cbbd",
 CellTags->"i:6"],
Cell[262938, 4395, 213, 4, 70, "CodeCaption", "ExpressionUUID" -> \
"5264f021-7031-4f18-99af-269cd70f8453",
 CellTags->"i:7"],
Cell[CellGroupData[{
Cell[263176, 4403, 242, 6, 70, "Input", "ExpressionUUID" -> \
"5fc2416a-d360-4661-a79e-aba0e1e9dd8a"],
Cell[263421, 4411, 187, 4, 70, "Output", "ExpressionUUID" -> \
"72107f7d-3625-4cbe-9558-459c18c54c8b",
 Evaluatable->False]
}, Open  ]],
Cell[263623, 4418, 202, 5, 70, "CodeCaption", "ExpressionUUID" -> \
"1d5ebcfe-6d55-4a43-9754-ce3932a1e852"],
Cell[CellGroupData[{
Cell[263850, 4427, 230, 5, 70, "Input", "ExpressionUUID" -> \
"b0230faa-b374-4124-9aff-85a68cb86728"],
Cell[264083, 4434, 217, 5, 70, "Output", "ExpressionUUID" -> \
"f5c551bb-c180-43f0-ac95-e6da62a064e8",
 Evaluatable->False,
 CellTags->"LastCellOfAPage"]
}, Open  ]],
Cell[264315, 4442, 568, 16, 70, "Text", "ExpressionUUID" -> \
"f273b17e-d96c-4ee7-ac8e-4b9925d7c7c8",
 CellTags->{"p:124", "i:8"}],
Cell[264886, 4460, 270, 9, 70, "CodeCaption", "ExpressionUUID" -> \
"552a98b6-1d30-4bf5-b969-81787f41d5f5"],
Cell[CellGroupData[{
Cell[265181, 4473, 23814, 445, 70, "Input", "ExpressionUUID" -> \
"098c6067-2243-4f03-bf08-f8dc5bafcc24"],
Cell[288998, 4920, 172, 4, 70, "Output", "ExpressionUUID" -> \
"ff2099a0-3b78-4211-a972-ed7962a4ea7c",
 Evaluatable->False]
}, Open  ]],
Cell[289185, 4927, 451, 12, 70, "Text", "ExpressionUUID" -> \
"d24f88cd-2dda-463f-a5e5-b5478525e3e5",
 CellTags->"i:9"],
Cell[289639, 4941, 189, 4, 70, "CodeCaption", "ExpressionUUID" -> \
"df31b2c0-0bc6-4346-bed5-81351ccac965"],
Cell[CellGroupData[{
Cell[289853, 4949, 309, 8, 70, "Input", "ExpressionUUID" -> \
"f29e4422-4e76-4108-9fbd-a0d7f4142db5"],
Cell[290165, 4959, 195, 5, 70, "Output", "ExpressionUUID" -> \
"921432e9-c2e2-4b11-b98b-546f7b1a946b",
 Evaluatable->False]
}, Open  ]],
Cell[290375, 4967, 174, 4, 70, "CodeCaption", "ExpressionUUID" -> \
"fc40ab71-e432-44b4-9d32-d9dd88440e84"],
Cell[CellGroupData[{
Cell[290574, 4975, 319, 8, 70, "Input", "ExpressionUUID" -> \
"b3569762-0301-45a7-9c38-db5874ac6aae"],
Cell[290896, 4985, 230, 6, 70, "Output", "ExpressionUUID" -> \
"9dd1f2b1-9a74-4ff0-bf7d-249bee98a5a2",
 Evaluatable->False]
}, Open  ]],
Cell[291141, 4994, 244, 8, 70, "Text", "ExpressionUUID" -> \
"e6019b5f-f7df-4c82-be2a-83183974b3c1",
 CellTags->"i:10"],
Cell[291388, 5004, 220, 6, 70, "CodeCaption", "ExpressionUUID" -> \
"577882fa-0a63-4ea8-b829-bfd8e9cbc8b8"],
Cell[CellGroupData[{
Cell[291633, 5014, 28340, 755, 70, "Input", "ExpressionUUID" -> \
"1f74ce26-c56c-4c63-8162-1aaa120a7067"],
Cell[319976, 5771, 4653, 131, 70, "Output", "ExpressionUUID" -> \
"2c77c9e8-890d-4352-bfd9-41b0556ac4f9",
 Evaluatable->False]
}, Open  ]],
Cell[324644, 5905, 175, 4, 70, "Text", "ExpressionUUID" -> \
"de178ca6-fe13-4505-aeec-c3274b10a730",
 CellTags->"i:11"],
Cell[324822, 5911, 263, 5, 70, "CodeCaption", "ExpressionUUID" -> \
"a6804c3a-3f69-4365-8e31-c6d0ad1209bf",
 CellTags->"i:12"],
Cell[CellGroupData[{
Cell[325110, 5920, 241, 6, 70, "Input", "ExpressionUUID" -> \
"ab298494-4b2f-44fd-8bfb-cc458346e773"],
Cell[325354, 5928, 418, 9, 70, "Output", "ExpressionUUID" -> \
"34e30938-258b-48b8-9cb0-1ba4bcb23bad",
 Evaluatable->False]
}, Open  ]],
Cell[325787, 5940, 427, 14, 70, "Text", "ExpressionUUID" -> \
"5f4570cd-f219-4dab-8e0a-c292afbd8d35",
 CellTags->{"LastCellOfAPage", "i:13"}],
Cell[326217, 5956, 410, 11, 70, "Text", "ExpressionUUID" -> \
"f8cdde60-2827-4b95-bea5-ce8d66806581",
 CellTags->{"p:125", "i:14"}],
Cell[326630, 5969, 256, 5, 70, "CodeCaption", "ExpressionUUID" -> \
"4147d05f-fc3b-4923-9e86-648743da6e32",
 CellTags->"i:15"],
Cell[CellGroupData[{
Cell[326911, 5978, 291, 8, 70, "Input", "ExpressionUUID" -> \
"f9286690-99fd-4b9c-a76b-6937a69d1f30"],
Cell[327205, 5988, 5261, 93, 70, "Output", "ExpressionUUID" -> \
"330a2bf0-8806-4e3b-b9f2-44bbc08ecb44",
 Evaluatable->False]
}, Open  ]],
Cell[332481, 6084, 281, 10, 70, "Text", "ExpressionUUID" -> \
"e449994e-0a3b-4897-989b-bae9f0288e34",
 CellTags->"i:16"],
Cell[332765, 6096, 171, 4, 70, "CodeCaption", "ExpressionUUID" -> \
"a87fef7a-4389-4a6e-84bb-b11f9d7bcff0"],
Cell[CellGroupData[{
Cell[332961, 6104, 5263, 92, 70, "Input", "ExpressionUUID" -> \
"2336e457-2fea-4171-b22e-6e392a8846b0"],
Cell[338227, 6198, 185, 4, 70, "Output", "ExpressionUUID" -> \
"4427443f-0366-4809-8642-afacc5753e15",
 Evaluatable->False]
}, Open  ]],
Cell[338427, 6205, 336, 10, 70, "Text", "ExpressionUUID" -> \
"c89cc995-90a4-42e0-867d-ca15c00ccc81"],
Cell[338766, 6217, 216, 6, 70, "CodeCaption", "ExpressionUUID" -> \
"bcc5002e-e705-4a3c-b37c-f3b0344df360"],
Cell[CellGroupData[{
Cell[339007, 6227, 415, 12, 70, "Input", "ExpressionUUID" -> \
"56beddf4-14b2-43a3-9504-1075f201a0bd"],
Cell[339425, 6241, 9187, 178, 70, "Output", "ExpressionUUID" -> \
"8a347353-d51a-471a-ac35-360753685dc8",
 Evaluatable->False]
}, Open  ]],
Cell[348627, 6422, 303, 9, 70, "CodeCaption", "ExpressionUUID" -> \
"0d8cf8ca-6514-4324-9506-a4501cf7fbc6",
 CellTags->"i:17"],
Cell[CellGroupData[{
Cell[348955, 6435, 462, 13, 70, "Input", "ExpressionUUID" -> \
"d0046048-3560-4b38-9fcc-e96956060a11"],
Cell[349420, 6450, 302, 7, 70, "Output", "ExpressionUUID" -> \
"171ddbff-dbb8-4f77-ad63-9ce3d3cca163",
 Evaluatable->False]
}, Open  ]],
Cell[349737, 6460, 600, 14, 70, "Text", "ExpressionUUID" -> \
"9b3c3fa5-066c-404c-8d29-b8e285ff744f"],
Cell[350340, 6476, 185, 4, 70, "CodeCaption", "ExpressionUUID" -> \
"eb5f0825-0a0e-47b5-8998-1e34360954e4"],
Cell[CellGroupData[{
Cell[350550, 6484, 257606, 4233, 70, "Input", "ExpressionUUID" -> \
"e09a9f25-33d7-4eee-9d6b-9ccb6815485b"],
Cell[608159, 10719, 2504679, 41124, 70, "Output", "ExpressionUUID" -> \
"cb12d83c-76a2-4a5c-b8f0-a326db2fa761",
 Evaluatable->False,
 CellTags->"LastCellOfAPage"]
}, Open  ]],
Cell[3112853, 51846, 298, 9, 70, "CodeCaption", "ExpressionUUID" -> \
"e54a38c8-f2ce-4d81-ab9b-bb9d6d2e063e"],
Cell[CellGroupData[{
Cell[3113176, 51859, 257672, 4234, 70, "Input", "ExpressionUUID" -> \
"557b82c2-9583-4f8b-86f1-2d935602021e"],
Cell[3370851, 56095, 2948, 60, 70, "Output", "ExpressionUUID" -> \
"fba8ba62-03f1-4135-9648-f20fb5f94030",
 Evaluatable->False]
}, Open  ]],
Cell[3373814, 56158, 442, 11, 70, "Text", "ExpressionUUID" -> \
"c86528e9-c52a-40a8-82e9-baaf7aaf571e"],
Cell[3374259, 56171, 316, 9, 70, "CodeCaption", "ExpressionUUID" -> \
"baca2076-a519-4bf2-a586-8a2a423afacd"],
Cell[CellGroupData[{
Cell[3374600, 56184, 229629, 3771, 70, "Input", "ExpressionUUID" -> \
"6382d58b-6626-4c59-8d46-a10f4cb09a5c"],
Cell[3604232, 59957, 2466, 48, 70, "Output", "ExpressionUUID" -> \
"2b8e715a-8952-4748-a94b-8f282e228804",
 Evaluatable->False]
}, Open  ]],
Cell[3606713, 60008, 313, 9, 70, "CodeCaption", "ExpressionUUID" -> \
"23487128-efe2-47d3-8c8e-053664cdda7b",
 CellTags->"i:18"],
Cell[CellGroupData[{
Cell[3607051, 60021, 148762, 2446, 70, "Input", "ExpressionUUID" -> \
"a801d062-1990-49ee-8ac9-9aa7a38b8a06"],
Cell[3755816, 62469, 2441, 49, 70, "Output", "ExpressionUUID" -> \
"3aacbb05-489d-4d97-b946-af0a29357fb9",
 Evaluatable->False]
}, Open  ]],
Cell[3758272, 62521, 470, 10, 70, "Text", "ExpressionUUID" -> \
"2e670745-4ddc-41bd-8c56-8eb2751525fe"],
Cell[3758745, 62533, 389, 11, 70, "Text", "ExpressionUUID" -> \
"89b69608-9e5d-4b61-8e89-823422a4bdcd",
 CellTags->"i:19"],
Cell[3759137, 62546, 247, 5, 70, "CodeCaption", "ExpressionUUID" -> \
"b87a84b7-28e8-436f-be74-9c429491d4d8"],
Cell[CellGroupData[{
Cell[3759409, 62555, 40261, 1053, 70, "Input", "ExpressionUUID" -> \
"fe017016-2c55-4e4d-a60c-2b0db24d5c41"],
Cell[3799673, 63610, 41483, 1066, 70, "Output", "ExpressionUUID" -> \
"7f8024c3-f173-4436-8976-f28b42888074",
 Evaluatable->False]
}, Open  ]],
Cell[3841171, 64679, 434, 11, 70, "Text", "ExpressionUUID" -> \
"7aa2628a-dec4-4229-bdd3-de7c07c2ea36",
 CellTags->{"NearestNeighborGraph", "LastCellOfAPage"}],
Cell[3841608, 64692, 321, 9, 70, "CodeCaption", "ExpressionUUID" -> \
"0402896f-5498-4406-a05a-985edbd3dde7",
 CellTags->{"graph-with-disconnected-parts", "i:20"}],
Cell[CellGroupData[{
Cell[3841954, 64705, 41405, 1059, 70, "Input", "ExpressionUUID" -> \
"d97d91b8-2294-4c96-84ef-bc29cd7debf9"],
Cell[3883362, 65766, 63864, 1485, 70, "Output", "ExpressionUUID" -> \
"b3c568f6-7387-4914-95b8-f0259c6d69ab",
 Evaluatable->False]
}, Open  ]],
Cell[3947241, 67254, 319, 10, 70, "Text", "ExpressionUUID" -> \
"69f952ba-ad63-45ed-b1e9-864c9ea820af",
 CellTags->"i:21"],
Cell[3947563, 67266, 192, 4, 70, "CodeCaption", "ExpressionUUID" -> \
"836a38c6-3ea4-4f92-aa92-7ee1742cd7d0"],
Cell[CellGroupData[{
Cell[3947780, 67274, 40205, 1052, 70, "Input", "ExpressionUUID" -> \
"ebe62368-0d62-4063-ab63-8d9e4c94cb74"],
Cell[3987988, 68328, 52613, 1376, 70, "Output", "ExpressionUUID" -> \
"86ea6100-1117-4a65-82b7-44f5cecc2107",
 Evaluatable->False]
}, Open  ]],
Cell[4040616, 69707, 585, 12, 70, "Text", "ExpressionUUID" -> \
"0bf4abb5-532d-4c48-b315-4d06c384a934",
 CellTags->"i:22"],
Cell[4041204, 69721, 596, 15, 70, "Text", "ExpressionUUID" -> \
"adff9c50-1544-4e0b-8348-664d3ad0b2c8",
 CellTags->{"LastCellOfAPage", "i:23"}],
Cell[4041803, 69738, 561, 14, 70, "Text", "ExpressionUUID" -> \
"b9896f6e-2e77-427c-9179-6df9e86ca0b0",
 CellTags->"i:24"],
Cell[4042367, 69754, 250, 8, 70, "CodeCaption", "ExpressionUUID" -> \
"83274f01-a6ff-45cf-8ba8-967c7aa359e3"],
Cell[CellGroupData[{
Cell[4042642, 69766, 40211, 1052, 70, "Input", "ExpressionUUID" -> \
"4c16f64c-9e47-4916-a307-d8116fca4292"],
Cell[4082856, 70820, 61516, 1667, 70, "Output", "ExpressionUUID" -> \
"8ed0943d-5e39-43f9-b074-7baca2dceef9",
 Evaluatable->False]
}, Open  ]],
Cell[4144387, 72490, 342, 9, 70, "Text", "ExpressionUUID" -> \
"e4ac5c47-a82e-46d0-a36c-bad0dbf6184c",
 CellTags->"i:25"],
Cell[4144732, 72501, 247, 9, 70, "CodeCaption", "ExpressionUUID" -> \
"dbbe81e9-94c3-49de-9d40-422f27a7ec4a"],
Cell[CellGroupData[{
Cell[4145004, 72514, 207, 4, 70, "Input", "ExpressionUUID" -> \
"69b285f3-c8f4-4e38-b3e6-6d0487e4f870"],
Cell[4145214, 72520, 272312, 7292, 70, "Output", "ExpressionUUID" -> \
"e3823c68-a14d-4ebd-b59f-d7816b3c9394",
 Evaluatable->False]
}, Open  ]],
Cell[4417541, 79815, 211, 5, 70, "Text", "ExpressionUUID" -> \
"255ecc97-b8e2-4c69-b455-4e60c4501f3b"],
Cell[4417755, 79822, 198, 4, 70, "CodeCaption", "ExpressionUUID" -> \
"17a07685-9824-4943-a595-7f75b628e2f8"],
Cell[CellGroupData[{
Cell[4417978, 79830, 311, 8, 70, "Input", "ExpressionUUID" -> \
"bf08869a-bb0c-4d34-8533-73536ed20aeb"],
Cell[4418292, 79840, 18451, 349, 70, "Output", "ExpressionUUID" -> \
"e7b53d17-22a8-41a1-a364-cf618517cc6b",
 Evaluatable->False,
 CellTags->"LastCellOfAPage"]
}, Open  ]],
Cell[4436758, 80192, 393, 10, 70, "Text", "ExpressionUUID" -> \
"4a2b7a34-3920-47aa-bf87-f2322dd962af",
 CellTags->"i:26"],
Cell[CellGroupData[{
Cell[4437176, 80206, 359, 9, 70, "Input", "ExpressionUUID" -> \
"7e312daf-346b-411d-9c64-a08bd8d01ea6"],
Cell[4437538, 80217, 36915, 921, 70, "Output", "ExpressionUUID" -> \
"a572d25b-fe37-48d0-9f6e-4ff151cdb627",
 Evaluatable->False]
}, Open  ]],
Cell[4474468, 81141, 368, 10, 70, "Text", "ExpressionUUID" -> \
"0e762fda-aafc-49c3-8d9a-e9308eae53f9",
 CellTags->"i:27"],
Cell[4474839, 81153, 276, 8, 70, "CodeCaption", "ExpressionUUID" -> \
"0319f114-1d32-4efa-a630-915c6f332214"],
Cell[CellGroupData[{
Cell[4475140, 81165, 104546, 1798, 70, "Input", "ExpressionUUID" -> \
"8b26e3c2-012a-4bd7-84cf-62e01854f4c0"],
Cell[4579689, 82965, 117073, 2170, 70, "Output", "ExpressionUUID" -> \
"b943b35d-bd3c-4cc6-b824-2af21a10d7b0",
 Evaluatable->False,
 CellTags->"LastCellOfAPage"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[4696811, 85141, 176, 4, 70, "VocabularySection", "ExpressionUUID" -> \
"131c42fc-a098-4b2c-ac1c-fceab7d2cc6e",
 CellTags->"p:126"],
Cell[4696990, 85147, 3660, 100, 70, "VocabularyTable", "ExpressionUUID" -> \
"d0bad373-73cc-49c7-9807-23e082b7ee6b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4700687, 85252, 1780, 46, 70, "ExerciseSection", "ExpressionUUID" -> \
"c98854ab-51db-4961-8037-03152812aaca"],
Cell[CellGroupData[{
Cell[4702492, 85302, 1451, 45, 70, "ExerciseSummaryCell", "ExpressionUUID" -> \
"b8aa3732-2c32-4a23-ae59-afe25d253386"],
Cell[CellGroupData[{
Cell[4703968, 85351, 766, 21, 70, "Exercise", "ExpressionUUID" -> \
"c483262e-1c68-40ee-b0d6-e6545dc1c981"],
Cell[4704737, 85374, 1504, 39, 70, "ExerciseOutput", "ExpressionUUID" -> \
"63c61321-0efc-4a41-a8c0-be0495de3626"]
}, Closed]],
Cell[CellGroupData[{
Cell[4706278, 85418, 967, 28, 70, "Exercise", "ExpressionUUID" -> \
"8035c55a-2b29-4398-a7e1-3b307234a023"],
Cell[4707248, 85448, 1561, 40, 70, "ExerciseOutput", "ExpressionUUID" -> \
"22ec36be-c223-4e4d-a174-8327a0cfe71a"]
}, Closed]],
Cell[CellGroupData[{
Cell[4708846, 85493, 763, 21, 70, "Exercise", "ExpressionUUID" -> \
"5785c93a-425e-408b-9100-73146976e125"],
Cell[4709612, 85516, 3825, 84, 70, "ExerciseOutput", "ExpressionUUID" -> \
"0bec625a-275a-42f0-ba91-6414ee3fa541"]
}, Closed]],
Cell[CellGroupData[{
Cell[4713474, 85605, 781, 21, 70, "Exercise", "ExpressionUUID" -> \
"4425d5ea-34cf-4a43-856b-e4e2e6def2a7"],
Cell[4714258, 85628, 1091, 31, 70, "ExerciseOutput", "ExpressionUUID" -> \
"6cee5022-87d4-4424-875c-597e225c86fa"]
}, Closed]],
Cell[CellGroupData[{
Cell[4715386, 85664, 937, 27, 70, "Exercise", "ExpressionUUID" -> \
"0e2b209f-2f5a-44d4-be32-ae9b9e413e1a"],
Cell[4716326, 85693, 1623, 41, 70, "ExerciseOutput", "ExpressionUUID" -> \
"6c942a88-d8bb-4e3d-a81a-0ba29200e50d"]
}, Closed]],
Cell[CellGroupData[{
Cell[4717986, 85739, 741, 21, 70, "Exercise", "ExpressionUUID" -> \
"c94f3659-86d5-4dfa-8d8a-cbd72703f16d"],
Cell[4718730, 85762, 1229, 35, 70, "ExerciseOutput", "ExpressionUUID" -> \
"cef03ea9-d81d-43c9-8ad1-bd35237e59b3"]
}, Closed]],
Cell[CellGroupData[{
Cell[4719996, 85802, 780, 23, 70, "Exercise", "ExpressionUUID" -> \
"af443c34-261e-4a8b-a59f-877a63c4db71"],
Cell[4720779, 85827, 23153, 521, 70, "ExerciseOutput", "ExpressionUUID" -> \
"5e585379-7b05-407f-bbc5-dff17e65c83e"]
}, Closed]],
Cell[CellGroupData[{
Cell[4743969, 86353, 720, 20, 70, "Exercise", "ExpressionUUID" -> \
"612e4812-d260-4ba8-a2e3-97093bd88bf6"],
Cell[4744692, 86375, 1071, 31, 70, "ExerciseOutput", "ExpressionUUID" -> \
"6ba9273f-b00a-4858-910d-9cfebd81a79e"]
}, Closed]],
Cell[CellGroupData[{
Cell[4745800, 86411, 721, 20, 70, "Exercise", "ExpressionUUID" -> \
"a0507145-5aa8-480d-95f9-cf1a2690c435"],
Cell[4746524, 86433, 50945, 843, 70, "ExerciseOutput", "ExpressionUUID" -> \
"48ef6d41-3747-4fe3-99b8-67a38dc4535e"]
}, Closed]],
Cell[CellGroupData[{
Cell[4797506, 87281, 1071, 32, 70, "Exercise", "ExpressionUUID" -> \
"c2b22cc7-af72-4898-95de-9732b372ae81"],
Cell[4798580, 87315, 114418, 2334, 70, "ExerciseOutput", "ExpressionUUID" -> \
"4744fa2d-77db-4f26-978a-facb1764b980"]
}, Closed]],
Cell[CellGroupData[{
Cell[4913035, 89654, 777, 21, 70, "Exercise", "ExpressionUUID" -> \
"1b21d344-c47f-49e8-90e4-a55c8ec57007"],
Cell[4913815, 89677, 43524, 878, 70, "ExerciseOutput", "ExpressionUUID" -> \
"b9459cc2-e2ce-4d82-af94-7abe75776e33"]
}, Closed]],
Cell[CellGroupData[{
Cell[4957376, 90560, 723, 20, 70, "Exercise", "ExpressionUUID" -> \
"64f00d50-ec23-450f-9f15-64dce316ff7c"],
Cell[4958102, 90582, 3641848, 62098, 70, "ExerciseOutput", "ExpressionUUID" \
-> "75de5721-e697-483c-90bd-bc145d970409"]
}, Closed]],
Cell[CellGroupData[{
Cell[8599987, 152685, 787, 21, 70, "Exercise", "ExpressionUUID" -> \
"1e08a798-a622-4a19-8a63-70661e9e2624"],
Cell[8600777, 152708, 92998, 1852, 70, "ExerciseOutput", "ExpressionUUID" -> \
"6433f86c-2e4d-4a39-ac55-a48ee69401d6"]
}, Closed]],
Cell[CellGroupData[{
Cell[8693812, 154565, 880, 24, 70, "Exercise", "ExpressionUUID" -> \
"54d781eb-9c41-4a78-89a9-f7ae2bc22039"],
Cell[8694695, 154591, 1584, 41, 70, "ExerciseOutput", "ExpressionUUID" -> \
"e37ac0c6-4af1-4453-b852-55c815038b19"]
}, Closed]],
Cell[CellGroupData[{
Cell[8696316, 154637, 735, 20, 70, "Exercise", "ExpressionUUID" -> \
"add4548d-4996-4940-90e5-7e7787706248"],
Cell[8697054, 154659, 38237, 750, 70, "ExerciseOutput", "ExpressionUUID" -> \
"68e438ae-4a11-4f9c-b198-24be83e1f39e"]
}, Closed]],
Cell[CellGroupData[{
Cell[8735328, 155414, 764, 21, 70, "Exercise", "ExpressionUUID" -> \
"738c2071-5e8b-4de8-a233-3bd0ba9cea5a",
 CellTags->"LastCellOfAPage"],
Cell[8736095, 155437, 72764, 1632, 70, "ExerciseOutput", "ExpressionUUID" -> \
"b208f6b0-9f35-40c6-9e94-f371ca873c25"]
}, Closed]],
Cell[CellGroupData[{
Cell[8808896, 157074, 774, 21, 70, "Exercise", "ExpressionUUID" -> \
"08c7e264-4b4d-4788-a56d-c651bdba0a27"],
Cell[8809673, 157097, 3754, 84, 70, "ExerciseOutput", "ExpressionUUID" -> \
"f6cd4f12-e8f4-4266-b045-073b65dda894"]
}, Closed]],
Cell[CellGroupData[{
Cell[8813464, 157186, 776, 21, 70, "Exercise", "ExpressionUUID" -> \
"b3821203-b4e0-4b24-aefd-6aaec906c008"],
Cell[8814243, 157209, 1089, 31, 70, "ExerciseOutput", "ExpressionUUID" -> \
"02579f6d-b8c3-4d4a-8c20-5b51a6129152"]
}, Closed]],
Cell[CellGroupData[{
Cell[8815369, 157245, 1116, 35, 70, "Exercise", "ExpressionUUID" -> \
"ae8fb412-c572-4309-898e-196ad228b62b"],
Cell[8816488, 157282, 12162, 279, 70, "ExerciseOutput", "ExpressionUUID" -> \
"3b7ec25b-11ef-4eaf-b2ed-fbb226479dce"]
}, Closed]],
Cell[CellGroupData[{
Cell[8828687, 157566, 1065, 30, 70, "Exercise", "ExpressionUUID" -> \
"90dc848e-df55-46ce-bd47-2763b110454b"],
Cell[8829755, 157598, 2022, 55, 70, "ExerciseOutput", "ExpressionUUID" -> \
"06583770-2523-4653-8035-2249e8e4df02"]
}, Closed]],
Cell[CellGroupData[{
Cell[8831814, 157658, 775, 21, 70, "Exercise", "ExpressionUUID" -> \
"1fc2d00c-96ce-4fc3-8258-0d69cde6c752"],
Cell[8832592, 157681, 9941, 199, 70, "ExerciseOutput", "ExpressionUUID" -> \
"8e506c4c-d78b-47f3-9e78-f4482301fda5"]
}, Closed]],
Cell[CellGroupData[{
Cell[8842570, 157885, 729, 20, 70, "Exercise", "ExpressionUUID" -> \
"b30441eb-a999-49ec-9bac-3fccc1c77f86"],
Cell[8843302, 157907, 506325, 10659, 70, "ExerciseOutput", "ExpressionUUID" \
-> "16a2a7b1-1e66-436b-a294-d063a247159b"]
}, Closed]],
Cell[CellGroupData[{
Cell[9349664, 168571, 747, 21, 70, "Exercise", "ExpressionUUID" -> \
"b52d2315-f6ec-4354-8fa2-94cff4cb2445"],
Cell[9350414, 168594, 151871, 3156, 70, "ExerciseOutput", "ExpressionUUID" -> \
"6e52e124-4058-40dd-b75e-84bc127f8309"]
}, Closed]]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[9502346, 171757, 161, 4, 70, "QASection", "ExpressionUUID" -> \
"3cc8e1d4-33e3-4369-aebd-61cc169c2bee",
 CellTags->"p:127"],
Cell[9502510, 171763, 231, 7, 70, "Question", "ExpressionUUID" -> \
"ed0b3070-f8a8-454e-8cd9-891a49d328a9"],
Cell[9502744, 171772, 529, 12, 70, "Answer", "ExpressionUUID" -> \
"b80fb4c7-83ff-465f-b9c6-75ab0456a10f"],
Cell[9503276, 171786, 248, 9, 70, "Question", "ExpressionUUID" -> \
"6b340d24-60d4-4df9-ba66-91e22a2379e6",
 CellTags->"i:28"],
Cell[9503527, 171797, 583, 12, 70, "Answer", "ExpressionUUID" -> \
"586dfff2-24ce-43b1-82a9-d3ac175b934c"],
Cell[9504113, 171811, 250, 9, 70, "Question", "ExpressionUUID" -> \
"6236fb81-eb31-4a9b-8fbb-14dc9625bd54"],
Cell[9504366, 171822, 327, 8, 70, "Answer", "ExpressionUUID" -> \
"d3365875-81d4-4cc7-9013-7e34489410af",
 CellTags->"i:29"],
Cell[9504696, 171832, 242, 9, 70, "Question", "ExpressionUUID" -> \
"cd253324-9318-4d0c-9363-ccb2062db95b"],
Cell[9504941, 171843, 638, 13, 70, "Answer", "ExpressionUUID" -> \
"1f74f53b-a377-4425-aa0b-02bd214b4e80"],
Cell[9505582, 171858, 289, 11, 70, "Question", "ExpressionUUID" -> \
"1b931045-1634-4559-a619-a642ff61097b"],
Cell[9505874, 171871, 554, 16, 70, "Answer", "ExpressionUUID" -> \
"550d330d-248f-43d3-888c-ec339c5f25f2",
 CellTags->"i:30"],
Cell[9506431, 171889, 257, 9, 70, "Question", "ExpressionUUID" -> \
"7bc4795b-e325-4d96-93d5-ef630494c4f7"],
Cell[9506691, 171900, 339, 8, 70, "Answer", "ExpressionUUID" -> \
"34ee50a7-55aa-43ec-936e-89b9abc916a1"],
Cell[9507033, 171910, 251, 9, 70, "Question", "ExpressionUUID" -> \
"9b77af72-daf8-483d-8c72-d1937b1ec264"],
Cell[9507287, 171921, 300, 10, 70, "Answer", "ExpressionUUID" -> \
"b66aeffe-eb0e-4102-b5f0-e8880f22ec2e",
 CellTags->"i:31"],
Cell[9507590, 171933, 237, 9, 70, "Question", "ExpressionUUID" -> \
"6c9e24e3-3af5-42ee-b019-63d01b6849cd"],
Cell[9507830, 171944, 360, 10, 70, "Answer", "ExpressionUUID" -> \
"b79db81e-8729-4681-a066-a5b646edcba9",
 CellTags->"i:32"],
Cell[9508193, 171956, 207, 4, 70, "Question", "ExpressionUUID" -> \
"42d77bdb-d92f-4898-b644-d935f3f38196",
 CellTags->"i:33"],
Cell[9508403, 171962, 343, 11, 70, "Answer", "ExpressionUUID" -> \
"5dc44c25-205b-4803-ac03-d844f28be576"],
Cell[9508749, 171975, 237, 9, 70, "Question", "ExpressionUUID" -> \
"40be2379-3bab-40d4-b1f7-713b8747dab9"],
Cell[9508989, 171986, 438, 9, 70, "Answer", "ExpressionUUID" -> \
"6be64909-f29c-4bb0-8897-9d38efc8ce86"]
}, Open  ]],
Cell[CellGroupData[{
Cell[9509464, 172000, 157, 4, 70, "TechNoteSection", "ExpressionUUID" -> \
"3f685e17-6180-4ead-b806-7e746cb0e00d"],
Cell[9509624, 172006, 400, 9, 70, "TechNote", "ExpressionUUID" -> \
"36a4d462-0bb8-41e3-a544-ad231c942764"],
Cell[9510027, 172017, 348, 13, 70, "TechNote", "ExpressionUUID" -> \
"73c56276-55c6-4a65-8f1f-1b78204a8750",
 CellTags->"i:34"],
Cell[9510378, 172032, 434, 14, 70, "TechNote", "ExpressionUUID" -> \
"eb8e4138-3ea9-4899-abb0-1ba32f00f291",
 CellTags->"i:35"],
Cell[9510815, 172048, 544, 18, 70, "TechNote", "ExpressionUUID" -> \
"9fc5ce4f-dcf6-474c-b44f-6f489bcf6f33",
 CellTags->{"LastCellOfAPage", "i:36"}],
Cell[9511362, 172068, 433, 12, 70, "TechNote", "ExpressionUUID" -> \
"ef7ef911-d05f-400b-976a-66aa0b15482a",
 CellTags->"i:37"],
Cell[9511798, 172082, 581, 23, 70, "TechNote", "ExpressionUUID" -> \
"e3fa5da4-8345-4c4a-927b-04fcb7c6381b",
 CellTags->"i:38"],
Cell[9512382, 172107, 546, 18, 70, "TechNote", "ExpressionUUID" -> \
"d6d16db5-34bb-4da5-86d6-3cd96f62dee5",
 CellTags->"i:39"],
Cell[9512931, 172127, 400, 12, 70, "TechNote", "ExpressionUUID" -> \
"7c857f2b-faac-4fac-8e04-8de3cd40cf7c",
 CellTags->"i:40"],
Cell[9513334, 172141, 487, 13, 70, "TechNote", "ExpressionUUID" -> \
"3c7dc8bf-5ce3-4292-9920-7c2776cb7105",
 CellTags->"i:41"],
Cell[9513824, 172156, 725, 22, 70, "TechNote", "ExpressionUUID" -> \
"dc498b4e-1068-46c0-8243-4772295a2273"],
Cell[9514552, 172180, 330, 11, 70, "TechNote", "ExpressionUUID" -> \
"6d05fccc-7ee0-42c4-926e-547d449189bd",
 CellTags->"i:42"],
Cell[9514885, 172193, 467, 13, 70, "TechNote", "ExpressionUUID" -> \
"f02996cd-a39b-49f9-b5d5-bcfe9ad1be0c",
 CellTags->"i:43"],
Cell[9515355, 172208, 503, 19, 70, "TechNote", "ExpressionUUID" -> \
"7551e191-b9ae-4518-8c3a-38abbb03b21c",
 CellTags->"i:44"]
}, Open  ]],
Cell[CellGroupData[{
Cell[9515895, 172232, 165, 4, 70, "MoreExploreSection", "ExpressionUUID" -> \
"f0c7b673-8112-4f0d-8022-67ba20a48a1e"],
Cell[9516063, 172238, 346, 8, 70, "MoreExplore", "ExpressionUUID" -> \
"5c7969a5-4286-49bd-91be-e54f0f45e870",
 CellTags->"LastCellOfAPage"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
(* NotebookSignature 0QcVRDUWgy6G2kI7SkOAdMwU *)
